#! /usr/bin/perl -CA
#                ^^^   This allows Unicode command-line arguments to be
#                      accepted if the underlying system supports it.
#                      If it causes an error, your version of Perl does
#                      not support this feature.  You can remove the option
#                      and continue to use the program with all other forms
#                      of arguments.

        use utf8;

=head1 NAME

unum - Interconvert numbers, Unicode, and HTML/XHTML characters

=head1 SYNOPSIS

B<unum> I<argument...>

=head1 DESCRIPTION

The B<unum> program is a command line utility which allows you to
convert decimal, octal, hexadecimal, and binary numbers; Unicode
character and block names; and HTML/XHTML character reference names and
numbers into one another.  It can be used as an on-line special
character reference for Web authors.

=head2 Arguments

The command line may contain any number of the following
forms of I<argument>.

=over 10

=item S<>123

Decimal number.

=item S<>0371

Octal number preceded by a zero.

=item S<>0x1D351

Hexadecimal number preceded by C<0x>.  Letters may be upper or
lower case, but the C<x> must be lower case.

=item S<>0b110101

Binary number.

=item b=I<block>

Unicode character blocks matching I<block> are listed.
The I<block> specification may be a regular expression.
For example, C<b=greek> lists all Greek character blocks
in Unicode.

=item c=I<char>...

The Unicode character codes for the characters I<char>... are listed.
If the first character is not a decimal digit and the second not an
equal sign, the C<c=> may be omitted.

=item h=I<entity>

List all HTML/XHTML character references matching I<entity>, which may 
be a regular expression.  Matching is case-insensitive, so C<h=alpha> 
finds both C<&Alpha;> and C<&alpha;>.  If the reference is composed of 
multiple Unicode code points, the components are printed after the name 
of the composed character reference.

=item '&#I<number>;&#xI<hexnum>;...'

List the characters corresponding to the specified HTML/XHTML
character entities, which may be given in either decimal or
hexadecimal.  Note that the "x" in XHTML entities must be lower case.
On most Unix-like operating systems, you'll need to quote the argument
so the ampersand, octothorpe, and semicolon aren't interpreted by the
shell.

=item l=I<block>

List all Unicode blocks matching I<block> and all characters
within each block; C<l=goth> lists the C<Gothic> block
and the 32 characters it contains.

=item n=I<name>

List all Unicode character whose names match I<name>, which may be
a regular expression.  For example, C<n=telephone> finds the twelve
Unicode characters for telephone symbols.

=back

=head2 Output

For number or character arguments, the value(s) are listed in
all of the input formats, save binary.

   Octal  Decimal      Hex        HTML    Character   Unicode
     056       46     0x2E    &period;    "."         FULL STOP

If the terminal font cannot display the character being listed,
the "Character" field will contain whatever default is shown in
such circumstances.  Control characters are shown as a Perl
hexadecimal escape.  If multiple HTML named character references
map to the same Unicode code point, all are shown separated by
commas.

Unicode blocks are listed as follows:

    Start        End  Unicode Block
   U+2460 -   U+24FF  Enclosed Alphanumerics
  U+1D400 -  U+1D7FF  Mathematical Alphanumeric Symbols


=head1 VERSION

This is B<unum> version 2.1, released on September 12th, 2017.
The current version of this program is always posted at
http://www.fourmilab.ch/webtools/unum/.

=head1 AUTHOR

John Walker

http://www.fourmilab.ch/

=head1 BUGS

Specification of Unicode characters on the command line requires
an operating system and shell which support that feature and a
version of Perl with the B<-CA> command line option
(v5.8.5 has it, but v5.8.0 does not; I don't know in which
intermediate release it was introduced).  If your version of
Perl does not implement this switch, you'll have to remove it
from the C<#!> statement at the top of the program, and Unicode
characters on the command line will not be interpreted correctly.

If you specify a regular expression, be sure to quote the argument
if it contains any characters the shell would otherwise interpret.

If you run B<perldoc> on the compressed version of the program,
a large amount of gibberish will be displayed after the end of the
embedded documentation.  B<perldoc> gets confused by sequences in
the compressed data table and tries to interpret it as documentation.
This doesn't happen with the uncompressed version.

Please report any bugs to bugs@fourmilab.ch.

=head1 COPYRIGHT

This is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut

    use strict;
    use warnings;

    sub usage {
        print << "EOD";
usage: unum arg...
    Arguments:
        147               Decimal number
        0371              Octal number
        0xfa75            Hexadecimal number (letters may be A-F or a-f)
        0b11010011        Binary number
        '&#8747;&#x3c0;'  One or more XHTML numeric entities (hex or decimal)
        xyz               The characters xyz (non-digit)
        c=7Y              The characters 7Y (any Unicode characters)
        b=cherokee        List Unicode blocks containing "CHEROKEE" (b=. to list all)
        h=alpha           List XHTML entities containing "alpha" (h=. to list all)
        n=aggravation     Unicode characters with "AGGRAVATION" in the name
        n=^greek.*rho     Unicode characters beginning with "GREEK" and containing "RHO"
        l=gothic          List all characters in matching Unicode blocks

        All name queries are case-insensitive and accept regular
        expressions.  Be sure to quote regular expressions if they
        contain characters with meaning to the shell.

        Run perldoc on this program or visit:
            http://www.fourmilab.ch/webtools/unum/
        for additional information.
    Version 2.1, September 2017
EOD
    }

    my (@HTML_CHARACTER_REFERENCES, @HTML_COMPOSED_CHARACTER_REFERENCES,
        %UNICODE_NAMES, @UNICODE_BLOCKS);

    binmode(STDOUT, ":utf8");

    if ($#ARGV < 0) {
        usage();
        exit(0);
    }

    init_names();

    my ($chartitle, $blocktitle) = (0, 0);
    my $arg = 0;
    while ($#ARGV >= 0) {
        my $n = shift();

        $arg++;
        if ($n =~ m/^\d/) {

            #   Number                  List numeric and character representations

            #   Argument is a number: use oct() to convert to binary
            $n = oct($n) if ($n =~ m/^0/);

        } elsif ($n =~ m/^(b|l)=(.+)/) {

            #   b=<block name>          List Unicode blocks matching name

            my $bl = $1;
            my $cpat = qr/$2/i;
            my $listall = $bl =~ m/l/i;

            my $k;
            for $k (@UNICODE_BLOCKS) {
                if ($k->[2] =~ m/$cpat/) {
                    if (!$blocktitle) {
                        $chartitle = 0;
                        $blocktitle = 1;
                        print("   Start        End  Unicode Block\n");
                    }
                    printf("%8s - %8s  %s\n",
                        sprintf("U+%04X", $k->[0]),
                        sprintf("U+%04X", $k->[1]),
                        $k->[2]);

                    if ($listall) {
                        for (my $i = $k->[0]; $i <= $k->[1]; $i++) {
                            showchar($i);
                        }
                    }
                }
            }
            next;

        } elsif ($n =~ m/^h=(.+)/) {

            #   h=<character name>      List HTML character entities matching name

            my $cpat = qr/$1/i;

            #   Scan through the table of names and build a hash of all
            #   the code points that matches map to.  Then sort those
            #   code points in ascending order and display them,
            #   counting on showchar() to show all of the character
            #   reference names which mapped from the code points
            #   displayed.

            my %htmlCodePoints;
            for (my $i = 0; $i < scalar(@HTML_CHARACTER_REFERENCES); $i += 2) {
                if ($HTML_CHARACTER_REFERENCES[$i] =~ m/$cpat/) {
                    $htmlCodePoints{$HTML_CHARACTER_REFERENCES[$i + 1]} = 1;
                }
            }

            my $k;
            for $k (sort {$a <=> $b} keys(%htmlCodePoints)) {
                showchar($k);
            }

            #   Now we must scan through the table of composed character
            #   references.  These are logical characters which are made
            #   up by combining multiple code points.

            for (my $i = 0; $i < scalar(@HTML_COMPOSED_CHARACTER_REFERENCES); $i += 2) {
                if ($HTML_COMPOSED_CHARACTER_REFERENCES[$i] =~ m/$cpat/) {
                    my $hcp = $HTML_COMPOSED_CHARACTER_REFERENCES[$i + 1];
                    print("                                &$HTML_COMPOSED_CHARACTER_REFERENCES[$i]; =\n");
                    $chartitle = 0;
                    while ($hcp =~ s/\s*(\d+)(?:,\s*)?//) {
                        $k = $1;
                        showchar($k);
                    }
                    $chartitle = 0;
                }
            }
            next;

        } elsif ($n =~ m/^n=(.+)/) {

            #   n=<character name>      List Unicode characters matching name

            my $cpat = qr/$1/i;

            #   The following would be faster if we selected matching
            #   characters into an auxiliary array and then sorted
            #   the selected ones before printing.  In fact, the time it
            #   takes to sort the entire list is less than that consumed
            #   in init_names() loading it, so there's little point bothering
            #   with this refinement.
            my $k;
            for $k (sort {oct("0x$a") <=> oct("0x$b")} keys(%UNICODE_NAMES)) {
                if ($UNICODE_NAMES{$k} =~ m/$cpat/) {
                    showchar(oct("0x$k"));
                }
            }
            next;

        } elsif ($n =~ m/^&#/) {

            #   '&#NNN;&#xNNNN;...'     One or more XHTML numeric entities

            my @htmlent;
            while ($n =~ s/&#(x?[0-9A-Fa-f]+);//) {
                my $hch = $1;
                $hch =~ s/^x/0x/;
                push(@htmlent, $hch);
            }
            unshift(@ARGV, @htmlent);
            next;

        } else {

            #   =<char>... or c=<char>...   List code for one or more characters

            #   If argument is an equal sign followed by a single
            #   character, take the second character as the argument.
            #   This allows treating digits as characters to be looked
            #   up.
            $n =~ s/^c?=(.+)$/$1/i;

            while ($n =~ s/^(.)//) {
                showchar(ord($1));
            }
            next;
        }

        showchar($n);
    }

    #   Show a numeric code in all its manifestations

    sub showchar {
        my ($n) = @_;


        my $ch = ((($n >= 32) && ($n < 128)) || ($n > 160)) ?
            chr($n) :
            sprintf("\\x{%X}", $n);

        #   Determine the Unicode character code as best we can

        my $u = uname($n);
        if (!defined($u)) {
            $u = ublock($n);
            if (defined($u)) {
                $u = sprintf("%s U+%05X", $u, $n);
            } else {
                $u = sprintf("Undefined U+%05X", $n);
            }
        }

        if (!$chartitle) {
            $blocktitle = 0;
            $chartitle = 1;
            print("   Octal  Decimal      Hex        HTML    Character   Unicode\n");
        }

        #   With the advent of HTML5, (aka, W3C meets crap sandwich), the mapping
        #   of named character references to Unicode code points is many-to-many.
        #   If there is more than one character reference name for the given
        #   code point, list all of them separated by commas.  They are listed
        #   in the vaguely alphabetical order given in the W3C table.  We only
        #   display direct mappings of code points to named character references,
        #   not composed character references of which the code point is a
        #   part.

        my ($htmlcr);
        for (my $i = 0; $i < scalar(@HTML_CHARACTER_REFERENCES); $i += 2) {
            if ($HTML_CHARACTER_REFERENCES[$i + 1] == $n) {
                if ($htmlcr) {
                    $htmlcr .= ",";
                }
                $htmlcr .= "&" . $HTML_CHARACTER_REFERENCES[$i] . ";";
            }
        }
        if (!$htmlcr) {
            $htmlcr = sprintf("&#%d;", $n);
        }

        printf("%8s %8d %8s %11s    %-8s    %s\n",
            sprintf("0%lo", $n),
            $n,
            sprintf("0x%X", $n),
            $htmlcr,
            sprintf("\"%s\"", $ch),
            $u);
    }

=pod

The Unicode character tables are based upon the Unicode 10.0.0
(2017) standard.

The control characters in this B<unum> version have been annotated
with their Unicode abbreviations, names, and for U+0000 to U+001F,
the Ctrl-key code which generates them.

The HTML named character references are from the World Wide Web
Consortium HTML standard.  Some browsers may not support all of
these references.

=cut

    sub uname {
        my $code = shift;
        if ($code >= 0x4E00) {
            if ($code >= 0xD800 && $code <= 0xF8FF) {
                # Surrogate and private
                if ($code <= 0xDFFF) {
                    return "<surrogate>";
                } else {
                    return "<private>";
                }
            }

        }
        $UNICODE_NAMES{sprintf("%04X", $code)}
    }

    sub ublock {
        my $code = shift;
        # XXX: could use a binary search, but I am too lazy today...
        my $block;
        for $block (@UNICODE_BLOCKS) {
            return $block->[2] if $block->[0] <= $code && $block->[1] >= $code;
        }
        undef;
    }

    sub init_names {
        #   Pre-dimension array and hash bucket sizes to reduce overhead
        #   in dynamic allocation as they are built below.
        $#UNICODE_BLOCKS = 283;
        $#HTML_CHARACTER_REFERENCES = 2032;
        $#HTML_COMPOSED_CHARACTER_REFERENCES = 93;
        keys %UNICODE_NAMES = 136755;

        #   The following code allows us to build two versions of the program
        #   from the same template file.  The table of Unicode code points
        #   is enormous (7.7 Mb as of Unicode 10.0), and we'd prefer not
        #   to carry it around within this program.  We read the table from
        #   a __DATA__ block appended to the program.  Following this can
        #   either be the table itself, appended from a separate file when
        #   the program is built, or the table compressed with bzip2,
        #   preceded by a single text line that says "COMPRESSED".  If
        #   that sentinel is read, we switch the data stream to binary and
        #   feed it through bunzip, creating a temporary file.  Then we
        #   read the temporary file to load the data.  Otherwise, we
        #   continue to read and process the embedded uncompressed table.

        my $l;
        while ($l = <DATA>) {
            if ($l =~ m/^COMPRESSED/) {
                use File::Temp qw(tempfile);
                my ($fh, $filename) = tempfile("unumXXXXXX", DIR => "/tmp",
                                               SUFFIX => ".tmp", UNLINK => 1);
                {
                    local $/ = undef;       # Set to read entire file at once
                    binmode(DATA);
                    open(UCHARS, "| bunzip2 -c >$filename") ||
                        die("Unable to open pipe to bunzip2 code point database");
                    print(UCHARS <DATA>);
                    close(UCHARS);
                }

                while ($l = <$fh>) {
                    chop($l);
                    my($code, $name) = split(' ', $l, 2);
                    $UNICODE_NAMES{$code} = $name;
                }
                close($fh);
                last;
            } else {
                do {
                    chop($l);
                    my($code, $name) = split(' ', $l, 2);
                    $UNICODE_NAMES{$code} = $name;
                } while ($l = <DATA>);
                last;
            }
        }
        close(DATA);

        @UNICODE_BLOCKS = (
        #  start   end        block name
          [0x0000, 0x007F => 'Basic Latin'],
          [0x0080, 0x00FF => 'Latin-1 Supplement'],
          [0x0100, 0x017F => 'Latin Extended-A'],
          [0x0180, 0x024F => 'Latin Extended-B'],
          [0x0250, 0x02AF => 'IPA Extensions'],
          [0x02B0, 0x02FF => 'Spacing Modifier Letters'],
          [0x0300, 0x036F => 'Combining Diacritical Marks'],
          [0x0370, 0x03FF => 'Greek and Coptic'],
          [0x0400, 0x04FF => 'Cyrillic'],
          [0x0500, 0x052F => 'Cyrillic Supplement'],
          [0x0530, 0x058F => 'Armenian'],
          [0x0590, 0x05FF => 'Hebrew'],
          [0x0600, 0x06FF => 'Arabic'],
          [0x0700, 0x074F => 'Syriac'],
          [0x0750, 0x077F => 'Arabic Supplement'],
          [0x0780, 0x07BF => 'Thaana'],
          [0x07C0, 0x07FF => 'NKo'],
          [0x0800, 0x083F => 'Samaritan'],
          [0x0840, 0x085F => 'Mandaic'],
          [0x0860, 0x086F => 'Syriac Supplement'],
          [0x08A0, 0x08FF => 'Arabic Extended-A'],
          [0x0900, 0x097F => 'Devanagari'],
          [0x0980, 0x09FF => 'Bengali'],
          [0x0A00, 0x0A7F => 'Gurmukhi'],
          [0x0A80, 0x0AFF => 'Gujarati'],
          [0x0B00, 0x0B7F => 'Oriya'],
          [0x0B80, 0x0BFF => 'Tamil'],
          [0x0C00, 0x0C7F => 'Telugu'],
          [0x0C80, 0x0CFF => 'Kannada'],
          [0x0D00, 0x0D7F => 'Malayalam'],
          [0x0D80, 0x0DFF => 'Sinhala'],
          [0x0E00, 0x0E7F => 'Thai'],
          [0x0E80, 0x0EFF => 'Lao'],
          [0x0F00, 0x0FFF => 'Tibetan'],
          [0x1000, 0x109F => 'Myanmar'],
          [0x10A0, 0x10FF => 'Georgian'],
          [0x1100, 0x11FF => 'Hangul Jamo'],
          [0x1200, 0x137F => 'Ethiopic'],
          [0x1380, 0x139F => 'Ethiopic Supplement'],
          [0x13A0, 0x13FF => 'Cherokee'],
          [0x1400, 0x167F => 'Unified Canadian Aboriginal Syllabics'],
          [0x1680, 0x169F => 'Ogham'],
          [0x16A0, 0x16FF => 'Runic'],
          [0x1700, 0x171F => 'Tagalog'],
          [0x1720, 0x173F => 'Hanunoo'],
          [0x1740, 0x175F => 'Buhid'],
          [0x1760, 0x177F => 'Tagbanwa'],
          [0x1780, 0x17FF => 'Khmer'],
          [0x1800, 0x18AF => 'Mongolian'],
          [0x18B0, 0x18FF => 'Unified Canadian Aboriginal Syllabics Extended'],
          [0x1900, 0x194F => 'Limbu'],
          [0x1950, 0x197F => 'Tai Le'],
          [0x1980, 0x19DF => 'New Tai Lue'],
          [0x19E0, 0x19FF => 'Khmer Symbols'],
          [0x1A00, 0x1A1F => 'Buginese'],
          [0x1A20, 0x1AAF => 'Tai Tham'],
          [0x1AB0, 0x1AFF => 'Combining Diacritical Marks Extended'],
          [0x1B00, 0x1B7F => 'Balinese'],
          [0x1B80, 0x1BBF => 'Sundanese'],
          [0x1BC0, 0x1BFF => 'Batak'],
          [0x1C00, 0x1C4F => 'Lepcha'],
          [0x1C50, 0x1C7F => 'Ol Chiki'],
          [0x1C80, 0x1C8F => 'Cyrillic Extended-C'],
          [0x1CC0, 0x1CCF => 'Sundanese Supplement'],
          [0x1CD0, 0x1CFF => 'Vedic Extensions'],
          [0x1D00, 0x1D7F => 'Phonetic Extensions'],
          [0x1D80, 0x1DBF => 'Phonetic Extensions Supplement'],
          [0x1DC0, 0x1DFF => 'Combining Diacritical Marks Supplement'],
          [0x1E00, 0x1EFF => 'Latin Extended Additional'],
          [0x1F00, 0x1FFF => 'Greek Extended'],
          [0x2000, 0x206F => 'General Punctuation'],
          [0x2070, 0x209F => 'Superscripts and Subscripts'],
          [0x20A0, 0x20CF => 'Currency Symbols'],
          [0x20D0, 0x20FF => 'Combining Diacritical Marks for Symbols'],
          [0x2100, 0x214F => 'Letterlike Symbols'],
          [0x2150, 0x218F => 'Number Forms'],
          [0x2190, 0x21FF => 'Arrows'],
          [0x2200, 0x22FF => 'Mathematical Operators'],
          [0x2300, 0x23FF => 'Miscellaneous Technical'],
          [0x2400, 0x243F => 'Control Pictures'],
          [0x2440, 0x245F => 'Optical Character Recognition'],
          [0x2460, 0x24FF => 'Enclosed Alphanumerics'],
          [0x2500, 0x257F => 'Box Drawing'],
          [0x2580, 0x259F => 'Block Elements'],
          [0x25A0, 0x25FF => 'Geometric Shapes'],
          [0x2600, 0x26FF => 'Miscellaneous Symbols'],
          [0x2700, 0x27BF => 'Dingbats'],
          [0x27C0, 0x27EF => 'Miscellaneous Mathematical Symbols-A'],
          [0x27F0, 0x27FF => 'Supplemental Arrows-A'],
          [0x2800, 0x28FF => 'Braille Patterns'],
          [0x2900, 0x297F => 'Supplemental Arrows-B'],
          [0x2980, 0x29FF => 'Miscellaneous Mathematical Symbols-B'],
          [0x2A00, 0x2AFF => 'Supplemental Mathematical Operators'],
          [0x2B00, 0x2BFF => 'Miscellaneous Symbols and Arrows'],
          [0x2C00, 0x2C5F => 'Glagolitic'],
          [0x2C60, 0x2C7F => 'Latin Extended-C'],
          [0x2C80, 0x2CFF => 'Coptic'],
          [0x2D00, 0x2D2F => 'Georgian Supplement'],
          [0x2D30, 0x2D7F => 'Tifinagh'],
          [0x2D80, 0x2DDF => 'Ethiopic Extended'],
          [0x2DE0, 0x2DFF => 'Cyrillic Extended-A'],
          [0x2E00, 0x2E7F => 'Supplemental Punctuation'],
          [0x2E80, 0x2EFF => 'CJK Radicals Supplement'],
          [0x2F00, 0x2FDF => 'Kangxi Radicals'],
          [0x2FF0, 0x2FFF => 'Ideographic Description Characters'],
          [0x3000, 0x303F => 'CJK Symbols and Punctuation'],
          [0x3040, 0x309F => 'Hiragana'],
          [0x30A0, 0x30FF => 'Katakana'],
          [0x3100, 0x312F => 'Bopomofo'],
          [0x3130, 0x318F => 'Hangul Compatibility Jamo'],
          [0x3190, 0x319F => 'Kanbun'],
          [0x31A0, 0x31BF => 'Bopomofo Extended'],
          [0x31C0, 0x31EF => 'CJK Strokes'],
          [0x31F0, 0x31FF => 'Katakana Phonetic Extensions'],
          [0x3200, 0x32FF => 'Enclosed CJK Letters and Months'],
          [0x3300, 0x33FF => 'CJK Compatibility'],
          [0x3400, 0x4DBF => 'CJK Unified Ideographs Extension A'],
          [0x4DC0, 0x4DFF => 'Yijing Hexagram Symbols'],
          [0x4E00, 0x9FFF => 'CJK Unified Ideographs'],
          [0xA000, 0xA48F => 'Yi Syllables'],
          [0xA490, 0xA4CF => 'Yi Radicals'],
          [0xA4D0, 0xA4FF => 'Lisu'],
          [0xA500, 0xA63F => 'Vai'],
          [0xA640, 0xA69F => 'Cyrillic Extended-B'],
          [0xA6A0, 0xA6FF => 'Bamum'],
          [0xA700, 0xA71F => 'Modifier Tone Letters'],
          [0xA720, 0xA7FF => 'Latin Extended-D'],
          [0xA800, 0xA82F => 'Syloti Nagri'],
          [0xA830, 0xA83F => 'Common Indic Number Forms'],
          [0xA840, 0xA87F => 'Phags-pa'],
          [0xA880, 0xA8DF => 'Saurashtra'],
          [0xA8E0, 0xA8FF => 'Devanagari Extended'],
          [0xA900, 0xA92F => 'Kayah Li'],
          [0xA930, 0xA95F => 'Rejang'],
          [0xA960, 0xA97F => 'Hangul Jamo Extended-A'],
          [0xA980, 0xA9DF => 'Javanese'],
          [0xA9E0, 0xA9FF => 'Myanmar Extended-B'],
          [0xAA00, 0xAA5F => 'Cham'],
          [0xAA60, 0xAA7F => 'Myanmar Extended-A'],
          [0xAA80, 0xAADF => 'Tai Viet'],
          [0xAAE0, 0xAAFF => 'Meetei Mayek Extensions'],
          [0xAB00, 0xAB2F => 'Ethiopic Extended-A'],
          [0xAB30, 0xAB6F => 'Latin Extended-E'],
          [0xAB70, 0xABBF => 'Cherokee Supplement'],
          [0xABC0, 0xABFF => 'Meetei Mayek'],
          [0xAC00, 0xD7AF => 'Hangul Syllables'],
          [0xD7B0, 0xD7FF => 'Hangul Jamo Extended-B'],
          [0xD800, 0xDB7F => 'High Surrogates'],
          [0xDB80, 0xDBFF => 'High Private Use Surrogates'],
          [0xDC00, 0xDFFF => 'Low Surrogates'],
          [0xE000, 0xF8FF => 'Private Use Area'],
          [0xF900, 0xFAFF => 'CJK Compatibility Ideographs'],
          [0xFB00, 0xFB4F => 'Alphabetic Presentation Forms'],
          [0xFB50, 0xFDFF => 'Arabic Presentation Forms-A'],
          [0xFE00, 0xFE0F => 'Variation Selectors'],
          [0xFE10, 0xFE1F => 'Vertical Forms'],
          [0xFE20, 0xFE2F => 'Combining Half Marks'],
          [0xFE30, 0xFE4F => 'CJK Compatibility Forms'],
          [0xFE50, 0xFE6F => 'Small Form Variants'],
          [0xFE70, 0xFEFF => 'Arabic Presentation Forms-B'],
          [0xFF00, 0xFFEF => 'Halfwidth and Fullwidth Forms'],
          [0xFFF0, 0xFFFF => 'Specials'],
          [0x10000, 0x1007F => 'Linear B Syllabary'],
          [0x10080, 0x100FF => 'Linear B Ideograms'],
          [0x10100, 0x1013F => 'Aegean Numbers'],
          [0x10140, 0x1018F => 'Ancient Greek Numbers'],
          [0x10190, 0x101CF => 'Ancient Symbols'],
          [0x101D0, 0x101FF => 'Phaistos Disc'],
          [0x10280, 0x1029F => 'Lycian'],
          [0x102A0, 0x102DF => 'Carian'],
          [0x102E0, 0x102FF => 'Coptic Epact Numbers'],
          [0x10300, 0x1032F => 'Old Italic'],
          [0x10330, 0x1034F => 'Gothic'],
          [0x10350, 0x1037F => 'Old Permic'],
          [0x10380, 0x1039F => 'Ugaritic'],
          [0x103A0, 0x103DF => 'Old Persian'],
          [0x10400, 0x1044F => 'Deseret'],
          [0x10450, 0x1047F => 'Shavian'],
          [0x10480, 0x104AF => 'Osmanya'],
          [0x104B0, 0x104FF => 'Osage'],
          [0x10500, 0x1052F => 'Elbasan'],
          [0x10530, 0x1056F => 'Caucasian Albanian'],
          [0x10600, 0x1077F => 'Linear A'],
          [0x10800, 0x1083F => 'Cypriot Syllabary'],
          [0x10840, 0x1085F => 'Imperial Aramaic'],
          [0x10860, 0x1087F => 'Palmyrene'],
          [0x10880, 0x108AF => 'Nabataean'],
          [0x108E0, 0x108FF => 'Hatran'],
          [0x10900, 0x1091F => 'Phoenician'],
          [0x10920, 0x1093F => 'Lydian'],
          [0x10980, 0x1099F => 'Meroitic Hieroglyphs'],
          [0x109A0, 0x109FF => 'Meroitic Cursive'],
          [0x10A00, 0x10A5F => 'Kharoshthi'],
          [0x10A60, 0x10A7F => 'Old South Arabian'],
          [0x10A80, 0x10A9F => 'Old North Arabian'],
          [0x10AC0, 0x10AFF => 'Manichaean'],
          [0x10B00, 0x10B3F => 'Avestan'],
          [0x10B40, 0x10B5F => 'Inscriptional Parthian'],
          [0x10B60, 0x10B7F => 'Inscriptional Pahlavi'],
          [0x10B80, 0x10BAF => 'Psalter Pahlavi'],
          [0x10C00, 0x10C4F => 'Old Turkic'],
          [0x10C80, 0x10CFF => 'Old Hungarian'],
          [0x10E60, 0x10E7F => 'Rumi Numeral Symbols'],
          [0x11000, 0x1107F => 'Brahmi'],
          [0x11080, 0x110CF => 'Kaithi'],
          [0x110D0, 0x110FF => 'Sora Sompeng'],
          [0x11100, 0x1114F => 'Chakma'],
          [0x11150, 0x1117F => 'Mahajani'],
          [0x11180, 0x111DF => 'Sharada'],
          [0x111E0, 0x111FF => 'Sinhala Archaic Numbers'],
          [0x11200, 0x1124F => 'Khojki'],
          [0x11280, 0x112AF => 'Multani'],
          [0x112B0, 0x112FF => 'Khudawadi'],
          [0x11300, 0x1137F => 'Grantha'],
          [0x11400, 0x1147F => 'Newa'],
          [0x11480, 0x114DF => 'Tirhuta'],
          [0x11580, 0x115FF => 'Siddham'],
          [0x11600, 0x1165F => 'Modi'],
          [0x11660, 0x1167F => 'Mongolian Supplement'],
          [0x11680, 0x116CF => 'Takri'],
          [0x11700, 0x1173F => 'Ahom'],
          [0x118A0, 0x118FF => 'Warang Citi'],
          [0x11A00, 0x11A4F => 'Zanabazar Square'],
          [0x11A50, 0x11AAF => 'Soyombo'],
          [0x11AC0, 0x11AFF => 'Pau Cin Hau'],
          [0x11C00, 0x11C6F => 'Bhaiksuki'],
          [0x11C70, 0x11CBF => 'Marchen'],
          [0x11D00, 0x11D5F => 'Masaram Gondi'],
          [0x12000, 0x123FF => 'Cuneiform'],
          [0x12400, 0x1247F => 'Cuneiform Numbers and Punctuation'],
          [0x12480, 0x1254F => 'Early Dynastic Cuneiform'],
          [0x13000, 0x1342F => 'Egyptian Hieroglyphs'],
          [0x14400, 0x1467F => 'Anatolian Hieroglyphs'],
          [0x16800, 0x16A3F => 'Bamum Supplement'],
          [0x16A40, 0x16A6F => 'Mro'],
          [0x16AD0, 0x16AFF => 'Bassa Vah'],
          [0x16B00, 0x16B8F => 'Pahawh Hmong'],
          [0x16F00, 0x16F9F => 'Miao'],
          [0x16FE0, 0x16FFF => 'Ideographic Symbols and Punctuation'],
          [0x17000, 0x187FF => 'Tangut'],
          [0x18800, 0x18AFF => 'Tangut Components'],
          [0x1B000, 0x1B0FF => 'Kana Supplement'],
          [0x1B100, 0x1B12F => 'Kana Extended-A'],
          [0x1B170, 0x1B2FF => 'Nushu'],
          [0x1BC00, 0x1BC9F => 'Duployan'],
          [0x1BCA0, 0x1BCAF => 'Shorthand Format Controls'],
          [0x1D000, 0x1D0FF => 'Byzantine Musical Symbols'],
          [0x1D100, 0x1D1FF => 'Musical Symbols'],
          [0x1D200, 0x1D24F => 'Ancient Greek Musical Notation'],
          [0x1D300, 0x1D35F => 'Tai Xuan Jing Symbols'],
          [0x1D360, 0x1D37F => 'Counting Rod Numerals'],
          [0x1D400, 0x1D7FF => 'Mathematical Alphanumeric Symbols'],
          [0x1D800, 0x1DAAF => 'Sutton SignWriting'],
          [0x1E000, 0x1E02F => 'Glagolitic Supplement'],
          [0x1E800, 0x1E8DF => 'Mende Kikakui'],
          [0x1E900, 0x1E95F => 'Adlam'],
          [0x1EE00, 0x1EEFF => 'Arabic Mathematical Alphabetic Symbols'],
          [0x1F000, 0x1F02F => 'Mahjong Tiles'],
          [0x1F030, 0x1F09F => 'Domino Tiles'],
          [0x1F0A0, 0x1F0FF => 'Playing Cards'],
          [0x1F100, 0x1F1FF => 'Enclosed Alphanumeric Supplement'],
          [0x1F200, 0x1F2FF => 'Enclosed Ideographic Supplement'],
          [0x1F300, 0x1F5FF => 'Miscellaneous Symbols and Pictographs'],
          [0x1F600, 0x1F64F => 'Emoticons'],
          [0x1F650, 0x1F67F => 'Ornamental Dingbats'],
          [0x1F680, 0x1F6FF => 'Transport and Map Symbols'],
          [0x1F700, 0x1F77F => 'Alchemical Symbols'],
          [0x1F780, 0x1F7FF => 'Geometric Shapes Extended'],
          [0x1F800, 0x1F8FF => 'Supplemental Arrows-C'],
          [0x1F900, 0x1F9FF => 'Supplemental Symbols and Pictographs'],
          [0x20000, 0x2A6DF => 'CJK Unified Ideographs Extension B'],
          [0x2A700, 0x2B73F => 'CJK Unified Ideographs Extension C'],
          [0x2B740, 0x2B81F => 'CJK Unified Ideographs Extension D'],
          [0x2B820, 0x2CEAF => 'CJK Unified Ideographs Extension E'],
          [0x2CEB0, 0x2EBEF => 'CJK Unified Ideographs Extension F'],
          [0x2F800, 0x2FA1F => 'CJK Compatibility Ideographs Supplement'],
          [0xE0000, 0xE007F => 'Tags'],
          [0xE0100, 0xE01EF => 'Variation Selectors Supplement'],
          [0xF0000, 0xFFFFF => 'Supplementary Private Use Area-A'],
          [0x100000, 0x10FFFF => 'Supplementary Private Use Area-B'],
        );

        #   HTML5 Named Character References

        @HTML_CHARACTER_REFERENCES = (
            #   From https://www.w3.org/TR/html5/entities.json
            'Aacute', 193,
            'aacute', 225,
            'Abreve', 258,
            'abreve', 259,
            'ac', 8766,
            'acd', 8767,
            'Acirc', 194,
            'acirc', 226,
            'acute', 180,
            'Acy', 1040,
            'acy', 1072,
            'AElig', 198,
            'aelig', 230,
            'af', 8289,
            'Afr', 120068,
            'afr', 120094,
            'Agrave', 192,
            'agrave', 224,
            'alefsym', 8501,
            'aleph', 8501,
            'Alpha', 913,
            'alpha', 945,
            'Amacr', 256,
            'amacr', 257,
            'amalg', 10815,
            'AMP', 38,
            'amp', 38,
            'And', 10835,
            'and', 8743,
            'andand', 10837,
            'andd', 10844,
            'andslope', 10840,
            'andv', 10842,
            'ang', 8736,
            'ange', 10660,
            'angle', 8736,
            'angmsd', 8737,
            'angmsdaa', 10664,
            'angmsdab', 10665,
            'angmsdac', 10666,
            'angmsdad', 10667,
            'angmsdae', 10668,
            'angmsdaf', 10669,
            'angmsdag', 10670,
            'angmsdah', 10671,
            'angrt', 8735,
            'angrtvb', 8894,
            'angrtvbd', 10653,
            'angsph', 8738,
            'angst', 197,
            'angzarr', 9084,
            'Aogon', 260,
            'aogon', 261,
            'Aopf', 120120,
            'aopf', 120146,
            'ap', 8776,
            'apacir', 10863,
            'apE', 10864,
            'ape', 8778,
            'apid', 8779,
            'apos', 39,
            'ApplyFunction', 8289,
            'approx', 8776,
            'approxeq', 8778,
            'Aring', 197,
            'aring', 229,
            'Ascr', 119964,
            'ascr', 119990,
            'Assign', 8788,
            'ast', 42,
            'asymp', 8776,
            'asympeq', 8781,
            'Atilde', 195,
            'atilde', 227,
            'Auml', 196,
            'auml', 228,
            'awconint', 8755,
            'awint', 10769,
            'backcong', 8780,
            'backepsilon', 1014,
            'backprime', 8245,
            'backsim', 8765,
            'backsimeq', 8909,
            'Backslash', 8726,
            'Barv', 10983,
            'barvee', 8893,
            'Barwed', 8966,
            'barwed', 8965,
            'barwedge', 8965,
            'bbrk', 9141,
            'bbrktbrk', 9142,
            'bcong', 8780,
            'Bcy', 1041,
            'bcy', 1073,
            'bdquo', 8222,
            'becaus', 8757,
            'Because', 8757,
            'because', 8757,
            'bemptyv', 10672,
            'bepsi', 1014,
            'bernou', 8492,
            'Bernoullis', 8492,
            'Beta', 914,
            'beta', 946,
            'beth', 8502,
            'between', 8812,
            'Bfr', 120069,
            'bfr', 120095,
            'bigcap', 8898,
            'bigcirc', 9711,
            'bigcup', 8899,
            'bigodot', 10752,
            'bigoplus', 10753,
            'bigotimes', 10754,
            'bigsqcup', 10758,
            'bigstar', 9733,
            'bigtriangledown', 9661,
            'bigtriangleup', 9651,
            'biguplus', 10756,
            'bigvee', 8897,
            'bigwedge', 8896,
            'bkarow', 10509,
            'blacklozenge', 10731,
            'blacksquare', 9642,
            'blacktriangle', 9652,
            'blacktriangledown', 9662,
            'blacktriangleleft', 9666,
            'blacktriangleright', 9656,
            'blank', 9251,
            'blk12', 9618,
            'blk14', 9617,
            'blk34', 9619,
            'block', 9608,
            'bNot', 10989,
            'bnot', 8976,
            'Bopf', 120121,
            'bopf', 120147,
            'bot', 8869,
            'bottom', 8869,
            'bowtie', 8904,
            'boxbox', 10697,
            'boxDL', 9559,
            'boxDl', 9558,
            'boxdL', 9557,
            'boxdl', 9488,
            'boxDR', 9556,
            'boxDr', 9555,
            'boxdR', 9554,
            'boxdr', 9484,
            'boxH', 9552,
            'boxh', 9472,
            'boxHD', 9574,
            'boxHd', 9572,
            'boxhD', 9573,
            'boxhd', 9516,
            'boxHU', 9577,
            'boxHu', 9575,
            'boxhU', 9576,
            'boxhu', 9524,
            'boxminus', 8863,
            'boxplus', 8862,
            'boxtimes', 8864,
            'boxUL', 9565,
            'boxUl', 9564,
            'boxuL', 9563,
            'boxul', 9496,
            'boxUR', 9562,
            'boxUr', 9561,
            'boxuR', 9560,
            'boxur', 9492,
            'boxV', 9553,
            'boxv', 9474,
            'boxVH', 9580,
            'boxVh', 9579,
            'boxvH', 9578,
            'boxvh', 9532,
            'boxVL', 9571,
            'boxVl', 9570,
            'boxvL', 9569,
            'boxvl', 9508,
            'boxVR', 9568,
            'boxVr', 9567,
            'boxvR', 9566,
            'boxvr', 9500,
            'bprime', 8245,
            'Breve', 728,
            'breve', 728,
            'brvbar', 166,
            'Bscr', 8492,
            'bscr', 119991,
            'bsemi', 8271,
            'bsim', 8765,
            'bsime', 8909,
            'bsol', 92,
            'bsolb', 10693,
            'bsolhsub', 10184,
            'bull', 8226,
            'bullet', 8226,
            'bump', 8782,
            'bumpE', 10926,
            'bumpe', 8783,
            'Bumpeq', 8782,
            'bumpeq', 8783,
            'Cacute', 262,
            'cacute', 263,
            'Cap', 8914,
            'cap', 8745,
            'capand', 10820,
            'capbrcup', 10825,
            'capcap', 10827,
            'capcup', 10823,
            'capdot', 10816,
            'CapitalDifferentialD', 8517,
            'caret', 8257,
            'caron', 711,
            'Cayleys', 8493,
            'ccaps', 10829,
            'Ccaron', 268,
            'ccaron', 269,
            'Ccedil', 199,
            'ccedil', 231,
            'Ccirc', 264,
            'ccirc', 265,
            'Cconint', 8752,
            'ccups', 10828,
            'ccupssm', 10832,
            'Cdot', 266,
            'cdot', 267,
            'cedil', 184,
            'Cedilla', 184,
            'cemptyv', 10674,
            'cent', 162,
            'CenterDot', 183,
            'centerdot', 183,
            'Cfr', 8493,
            'cfr', 120096,
            'CHcy', 1063,
            'chcy', 1095,
            'check', 10003,
            'checkmark', 10003,
            'Chi', 935,
            'chi', 967,
            'cir', 9675,
            'circ', 710,
            'circeq', 8791,
            'circlearrowleft', 8634,
            'circlearrowright', 8635,
            'circledast', 8859,
            'circledcirc', 8858,
            'circleddash', 8861,
            'CircleDot', 8857,
            'circledR', 174,
            'circledS', 9416,
            'CircleMinus', 8854,
            'CirclePlus', 8853,
            'CircleTimes', 8855,
            'cirE', 10691,
            'cire', 8791,
            'cirfnint', 10768,
            'cirmid', 10991,
            'cirscir', 10690,
            'ClockwiseContourIntegral', 8754,
            'CloseCurlyDoubleQuote', 8221,
            'CloseCurlyQuote', 8217,
            'clubs', 9827,
            'clubsuit', 9827,
            'Colon', 8759,
            'colon', 58,
            'Colone', 10868,
            'colone', 8788,
            'coloneq', 8788,
            'comma', 44,
            'commat', 64,
            'comp', 8705,
            'compfn', 8728,
            'complement', 8705,
            'complexes', 8450,
            'cong', 8773,
            'congdot', 10861,
            'Congruent', 8801,
            'Conint', 8751,
            'conint', 8750,
            'ContourIntegral', 8750,
            'Copf', 8450,
            'copf', 120148,
            'coprod', 8720,
            'Coproduct', 8720,
            'COPY', 169,
            'copy', 169,
            'copysr', 8471,
            'CounterClockwiseContourIntegral', 8755,
            'crarr', 8629,
            'Cross', 10799,
            'cross', 10007,
            'Cscr', 119966,
            'cscr', 119992,
            'csub', 10959,
            'csube', 10961,
            'csup', 10960,
            'csupe', 10962,
            'ctdot', 8943,
            'cudarrl', 10552,
            'cudarrr', 10549,
            'cuepr', 8926,
            'cuesc', 8927,
            'cularr', 8630,
            'cularrp', 10557,
            'Cup', 8915,
            'cup', 8746,
            'cupbrcap', 10824,
            'CupCap', 8781,
            'cupcap', 10822,
            'cupcup', 10826,
            'cupdot', 8845,
            'cupor', 10821,
            'curarr', 8631,
            'curarrm', 10556,
            'curlyeqprec', 8926,
            'curlyeqsucc', 8927,
            'curlyvee', 8910,
            'curlywedge', 8911,
            'curren', 164,
            'curvearrowleft', 8630,
            'curvearrowright', 8631,
            'cuvee', 8910,
            'cuwed', 8911,
            'cwconint', 8754,
            'cwint', 8753,
            'cylcty', 9005,
            'Dagger', 8225,
            'dagger', 8224,
            'daleth', 8504,
            'Darr', 8609,
            'dArr', 8659,
            'darr', 8595,
            'dash', 8208,
            'Dashv', 10980,
            'dashv', 8867,
            'dbkarow', 10511,
            'dblac', 733,
            'Dcaron', 270,
            'dcaron', 271,
            'Dcy', 1044,
            'dcy', 1076,
            'DD', 8517,
            'dd', 8518,
            'ddagger', 8225,
            'ddarr', 8650,
            'DDotrahd', 10513,
            'ddotseq', 10871,
            'deg', 176,
            'Del', 8711,
            'Delta', 916,
            'delta', 948,
            'demptyv', 10673,
            'dfisht', 10623,
            'Dfr', 120071,
            'dfr', 120097,
            'dHar', 10597,
            'dharl', 8643,
            'dharr', 8642,
            'DiacriticalAcute', 180,
            'DiacriticalDot', 729,
            'DiacriticalDoubleAcute', 733,
            'DiacriticalGrave', 96,
            'DiacriticalTilde', 732,
            'diam', 8900,
            'Diamond', 8900,
            'diamond', 8900,
            'diamondsuit', 9830,
            'diams', 9830,
            'die', 168,
            'DifferentialD', 8518,
            'digamma', 989,
            'disin', 8946,
            'div', 247,
            'divide', 247,
            'divideontimes', 8903,
            'divonx', 8903,
            'DJcy', 1026,
            'djcy', 1106,
            'dlcorn', 8990,
            'dlcrop', 8973,
            'dollar', 36,
            'Dopf', 120123,
            'dopf', 120149,
            'Dot', 168,
            'dot', 729,
            'DotDot', 8412,
            'doteq', 8784,
            'doteqdot', 8785,
            'DotEqual', 8784,
            'dotminus', 8760,
            'dotplus', 8724,
            'dotsquare', 8865,
            'doublebarwedge', 8966,
            'DoubleContourIntegral', 8751,
            'DoubleDot', 168,
            'DoubleDownArrow', 8659,
            'DoubleLeftArrow', 8656,
            'DoubleLeftRightArrow', 8660,
            'DoubleLeftTee', 10980,
            'DoubleLongLeftArrow', 10232,
            'DoubleLongLeftRightArrow', 10234,
            'DoubleLongRightArrow', 10233,
            'DoubleRightArrow', 8658,
            'DoubleRightTee', 8872,
            'DoubleUpArrow', 8657,
            'DoubleUpDownArrow', 8661,
            'DoubleVerticalBar', 8741,
            'DownArrow', 8595,
            'Downarrow', 8659,
            'downarrow', 8595,
            'DownArrowBar', 10515,
            'DownArrowUpArrow', 8693,
            'DownBreve', 785,
            'downdownarrows', 8650,
            'downharpoonleft', 8643,
            'downharpoonright', 8642,
            'DownLeftRightVector', 10576,
            'DownLeftTeeVector', 10590,
            'DownLeftVector', 8637,
            'DownLeftVectorBar', 10582,
            'DownRightTeeVector', 10591,
            'DownRightVector', 8641,
            'DownRightVectorBar', 10583,
            'DownTee', 8868,
            'DownTeeArrow', 8615,
            'drbkarow', 10512,
            'drcorn', 8991,
            'drcrop', 8972,
            'Dscr', 119967,
            'dscr', 119993,
            'DScy', 1029,
            'dscy', 1109,
            'dsol', 10742,
            'Dstrok', 272,
            'dstrok', 273,
            'dtdot', 8945,
            'dtri', 9663,
            'dtrif', 9662,
            'duarr', 8693,
            'duhar', 10607,
            'dwangle', 10662,
            'DZcy', 1039,
            'dzcy', 1119,
            'dzigrarr', 10239,
            'Eacute', 201,
            'eacute', 233,
            'easter', 10862,
            'Ecaron', 282,
            'ecaron', 283,
            'ecir', 8790,
            'Ecirc', 202,
            'ecirc', 234,
            'ecolon', 8789,
            'Ecy', 1069,
            'ecy', 1101,
            'eDDot', 10871,
            'Edot', 278,
            'eDot', 8785,
            'edot', 279,
            'ee', 8519,
            'efDot', 8786,
            'Efr', 120072,
            'efr', 120098,
            'eg', 10906,
            'Egrave', 200,
            'egrave', 232,
            'egs', 10902,
            'egsdot', 10904,
            'el', 10905,
            'Element', 8712,
            'elinters', 9191,
            'ell', 8467,
            'els', 10901,
            'elsdot', 10903,
            'Emacr', 274,
            'emacr', 275,
            'empty', 8709,
            'emptyset', 8709,
            'EmptySmallSquare', 9723,
            'emptyv', 8709,
            'EmptyVerySmallSquare', 9643,
            'emsp', 8195,
            'emsp13', 8196,
            'emsp14', 8197,
            'ENG', 330,
            'eng', 331,
            'ensp', 8194,
            'Eogon', 280,
            'eogon', 281,
            'Eopf', 120124,
            'eopf', 120150,
            'epar', 8917,
            'eparsl', 10723,
            'eplus', 10865,
            'epsi', 949,
            'Epsilon', 917,
            'epsilon', 949,
            'epsiv', 1013,
            'eqcirc', 8790,
            'eqcolon', 8789,
            'eqsim', 8770,
            'eqslantgtr', 10902,
            'eqslantless', 10901,
            'Equal', 10869,
            'equals', 61,
            'EqualTilde', 8770,
            'equest', 8799,
            'Equilibrium', 8652,
            'equiv', 8801,
            'equivDD', 10872,
            'eqvparsl', 10725,
            'erarr', 10609,
            'erDot', 8787,
            'Escr', 8496,
            'escr', 8495,
            'esdot', 8784,
            'Esim', 10867,
            'esim', 8770,
            'Eta', 919,
            'eta', 951,
            'ETH', 208,
            'eth', 240,
            'Euml', 203,
            'euml', 235,
            'euro', 8364,
            'excl', 33,
            'exist', 8707,
            'Exists', 8707,
            'expectation', 8496,
            'ExponentialE', 8519,
            'exponentiale', 8519,
            'fallingdotseq', 8786,
            'Fcy', 1060,
            'fcy', 1092,
            'female', 9792,
            'ffilig', 64259,
            'fflig', 64256,
            'ffllig', 64260,
            'Ffr', 120073,
            'ffr', 120099,
            'filig', 64257,
            'FilledSmallSquare', 9724,
            'FilledVerySmallSquare', 9642,
            'flat', 9837,
            'fllig', 64258,
            'fltns', 9649,
            'fnof', 402,
            'Fopf', 120125,
            'fopf', 120151,
            'ForAll', 8704,
            'forall', 8704,
            'fork', 8916,
            'forkv', 10969,
            'Fouriertrf', 8497,
            'fpartint', 10765,
            'frac12', 189,
            'frac13', 8531,
            'frac14', 188,
            'frac15', 8533,
            'frac16', 8537,
            'frac18', 8539,
            'frac23', 8532,
            'frac25', 8534,
            'frac34', 190,
            'frac35', 8535,
            'frac38', 8540,
            'frac45', 8536,
            'frac56', 8538,
            'frac58', 8541,
            'frac78', 8542,
            'frasl', 8260,
            'frown', 8994,
            'Fscr', 8497,
            'fscr', 119995,
            'gacute', 501,
            'Gamma', 915,
            'gamma', 947,
            'Gammad', 988,
            'gammad', 989,
            'gap', 10886,
            'Gbreve', 286,
            'gbreve', 287,
            'Gcedil', 290,
            'Gcirc', 284,
            'gcirc', 285,
            'Gcy', 1043,
            'gcy', 1075,
            'Gdot', 288,
            'gdot', 289,
            'gE', 8807,
            'ge', 8805,
            'gEl', 10892,
            'gel', 8923,
            'geq', 8805,
            'geqq', 8807,
            'geqslant', 10878,
            'ges', 10878,
            'gescc', 10921,
            'gesdot', 10880,
            'gesdoto', 10882,
            'gesdotol', 10884,
            'gesles', 10900,
            'Gfr', 120074,
            'gfr', 120100,
            'Gg', 8921,
            'gg', 8811,
            'ggg', 8921,
            'gimel', 8503,
            'GJcy', 1027,
            'gjcy', 1107,
            'gl', 8823,
            'gla', 10917,
            'glE', 10898,
            'glj', 10916,
            'gnap', 10890,
            'gnapprox', 10890,
            'gnE', 8809,
            'gne', 10888,
            'gneq', 10888,
            'gneqq', 8809,
            'gnsim', 8935,
            'Gopf', 120126,
            'gopf', 120152,
            'grave', 96,
            'GreaterEqual', 8805,
            'GreaterEqualLess', 8923,
            'GreaterFullEqual', 8807,
            'GreaterGreater', 10914,
            'GreaterLess', 8823,
            'GreaterSlantEqual', 10878,
            'GreaterTilde', 8819,
            'Gscr', 119970,
            'gscr', 8458,
            'gsim', 8819,
            'gsime', 10894,
            'gsiml', 10896,
            'GT', 62,
            'Gt', 8811,
            'gt', 62,
            'gtcc', 10919,
            'gtcir', 10874,
            'gtdot', 8919,
            'gtlPar', 10645,
            'gtquest', 10876,
            'gtrapprox', 10886,
            'gtrarr', 10616,
            'gtrdot', 8919,
            'gtreqless', 8923,
            'gtreqqless', 10892,
            'gtrless', 8823,
            'gtrsim', 8819,
            'Hacek', 711,
            'hairsp', 8202,
            'half', 189,
            'hamilt', 8459,
            'HARDcy', 1066,
            'hardcy', 1098,
            'hArr', 8660,
            'harr', 8596,
            'harrcir', 10568,
            'harrw', 8621,
            'Hat', 94,
            'hbar', 8463,
            'Hcirc', 292,
            'hcirc', 293,
            'hearts', 9829,
            'heartsuit', 9829,
            'hellip', 8230,
            'hercon', 8889,
            'Hfr', 8460,
            'hfr', 120101,
            'HilbertSpace', 8459,
            'hksearow', 10533,
            'hkswarow', 10534,
            'hoarr', 8703,
            'homtht', 8763,
            'hookleftarrow', 8617,
            'hookrightarrow', 8618,
            'Hopf', 8461,
            'hopf', 120153,
            'horbar', 8213,
            'HorizontalLine', 9472,
            'Hscr', 8459,
            'hscr', 119997,
            'hslash', 8463,
            'Hstrok', 294,
            'hstrok', 295,
            'HumpDownHump', 8782,
            'HumpEqual', 8783,
            'hybull', 8259,
            'hyphen', 8208,
            'Iacute', 205,
            'iacute', 237,
            'ic', 8291,
            'Icirc', 206,
            'icirc', 238,
            'Icy', 1048,
            'icy', 1080,
            'Idot', 304,
            'IEcy', 1045,
            'iecy', 1077,
            'iexcl', 161,
            'iff', 8660,
            'Ifr', 8465,
            'ifr', 120102,
            'Igrave', 204,
            'igrave', 236,
            'ii', 8520,
            'iiiint', 10764,
            'iiint', 8749,
            'iinfin', 10716,
            'iiota', 8489,
            'IJlig', 306,
            'ijlig', 307,
            'Im', 8465,
            'Imacr', 298,
            'imacr', 299,
            'image', 8465,
            'ImaginaryI', 8520,
            'imagline', 8464,
            'imagpart', 8465,
            'imath', 305,
            'imof', 8887,
            'imped', 437,
            'Implies', 8658,
            'in', 8712,
            'incare', 8453,
            'infin', 8734,
            'infintie', 10717,
            'inodot', 305,
            'Int', 8748,
            'int', 8747,
            'intcal', 8890,
            'integers', 8484,
            'Integral', 8747,
            'intercal', 8890,
            'Intersection', 8898,
            'intlarhk', 10775,
            'intprod', 10812,
            'InvisibleComma', 8291,
            'InvisibleTimes', 8290,
            'IOcy', 1025,
            'iocy', 1105,
            'Iogon', 302,
            'iogon', 303,
            'Iopf', 120128,
            'iopf', 120154,
            'Iota', 921,
            'iota', 953,
            'iprod', 10812,
            'iquest', 191,
            'Iscr', 8464,
            'iscr', 119998,
            'isin', 8712,
            'isindot', 8949,
            'isinE', 8953,
            'isins', 8948,
            'isinsv', 8947,
            'isinv', 8712,
            'it', 8290,
            'Itilde', 296,
            'itilde', 297,
            'Iukcy', 1030,
            'iukcy', 1110,
            'Iuml', 207,
            'iuml', 239,
            'Jcirc', 308,
            'jcirc', 309,
            'Jcy', 1049,
            'jcy', 1081,
            'Jfr', 120077,
            'jfr', 120103,
            'jmath', 567,
            'Jopf', 120129,
            'jopf', 120155,
            'Jscr', 119973,
            'jscr', 119999,
            'Jsercy', 1032,
            'jsercy', 1112,
            'Jukcy', 1028,
            'jukcy', 1108,
            'Kappa', 922,
            'kappa', 954,
            'kappav', 1008,
            'Kcedil', 310,
            'kcedil', 311,
            'Kcy', 1050,
            'kcy', 1082,
            'Kfr', 120078,
            'kfr', 120104,
            'kgreen', 312,
            'KHcy', 1061,
            'khcy', 1093,
            'KJcy', 1036,
            'kjcy', 1116,
            'Kopf', 120130,
            'kopf', 120156,
            'Kscr', 119974,
            'kscr', 120000,
            'lAarr', 8666,
            'Lacute', 313,
            'lacute', 314,
            'laemptyv', 10676,
            'lagran', 8466,
            'Lambda', 923,
            'lambda', 955,
            'Lang', 10218,
            'lang', 10216,
            'langd', 10641,
            'langle', 10216,
            'lap', 10885,
            'Laplacetrf', 8466,
            'laquo', 171,
            'Larr', 8606,
            'lArr', 8656,
            'larr', 8592,
            'larrb', 8676,
            'larrbfs', 10527,
            'larrfs', 10525,
            'larrhk', 8617,
            'larrlp', 8619,
            'larrpl', 10553,
            'larrsim', 10611,
            'larrtl', 8610,
            'lat', 10923,
            'lAtail', 10523,
            'latail', 10521,
            'late', 10925,
            'lBarr', 10510,
            'lbarr', 10508,
            'lbbrk', 10098,
            'lbrace', 123,
            'lbrack', 91,
            'lbrke', 10635,
            'lbrksld', 10639,
            'lbrkslu', 10637,
            'Lcaron', 317,
            'lcaron', 318,
            'Lcedil', 315,
            'lcedil', 316,
            'lceil', 8968,
            'lcub', 123,
            'Lcy', 1051,
            'lcy', 1083,
            'ldca', 10550,
            'ldquo', 8220,
            'ldquor', 8222,
            'ldrdhar', 10599,
            'ldrushar', 10571,
            'ldsh', 8626,
            'lE', 8806,
            'le', 8804,
            'LeftAngleBracket', 10216,
            'LeftArrow', 8592,
            'Leftarrow', 8656,
            'leftarrow', 8592,
            'LeftArrowBar', 8676,
            'LeftArrowRightArrow', 8646,
            'leftarrowtail', 8610,
            'LeftCeiling', 8968,
            'LeftDoubleBracket', 10214,
            'LeftDownTeeVector', 10593,
            'LeftDownVector', 8643,
            'LeftDownVectorBar', 10585,
            'LeftFloor', 8970,
            'leftharpoondown', 8637,
            'leftharpoonup', 8636,
            'leftleftarrows', 8647,
            'LeftRightArrow', 8596,
            'Leftrightarrow', 8660,
            'leftrightarrow', 8596,
            'leftrightarrows', 8646,
            'leftrightharpoons', 8651,
            'leftrightsquigarrow', 8621,
            'LeftRightVector', 10574,
            'LeftTee', 8867,
            'LeftTeeArrow', 8612,
            'LeftTeeVector', 10586,
            'leftthreetimes', 8907,
            'LeftTriangle', 8882,
            'LeftTriangleBar', 10703,
            'LeftTriangleEqual', 8884,
            'LeftUpDownVector', 10577,
            'LeftUpTeeVector', 10592,
            'LeftUpVector', 8639,
            'LeftUpVectorBar', 10584,
            'LeftVector', 8636,
            'LeftVectorBar', 10578,
            'lEg', 10891,
            'leg', 8922,
            'leq', 8804,
            'leqq', 8806,
            'leqslant', 10877,
            'les', 10877,
            'lescc', 10920,
            'lesdot', 10879,
            'lesdoto', 10881,
            'lesdotor', 10883,
            'lesges', 10899,
            'lessapprox', 10885,
            'lessdot', 8918,
            'lesseqgtr', 8922,
            'lesseqqgtr', 10891,
            'LessEqualGreater', 8922,
            'LessFullEqual', 8806,
            'LessGreater', 8822,
            'lessgtr', 8822,
            'LessLess', 10913,
            'lesssim', 8818,
            'LessSlantEqual', 10877,
            'LessTilde', 8818,
            'lfisht', 10620,
            'lfloor', 8970,
            'Lfr', 120079,
            'lfr', 120105,
            'lg', 8822,
            'lgE', 10897,
            'lHar', 10594,
            'lhard', 8637,
            'lharu', 8636,
            'lharul', 10602,
            'lhblk', 9604,
            'LJcy', 1033,
            'ljcy', 1113,
            'Ll', 8920,
            'll', 8810,
            'llarr', 8647,
            'llcorner', 8990,
            'Lleftarrow', 8666,
            'llhard', 10603,
            'lltri', 9722,
            'Lmidot', 319,
            'lmidot', 320,
            'lmoust', 9136,
            'lmoustache', 9136,
            'lnap', 10889,
            'lnapprox', 10889,
            'lnE', 8808,
            'lne', 10887,
            'lneq', 10887,
            'lneqq', 8808,
            'lnsim', 8934,
            'loang', 10220,
            'loarr', 8701,
            'lobrk', 10214,
            'LongLeftArrow', 10229,
            'Longleftarrow', 10232,
            'longleftarrow', 10229,
            'LongLeftRightArrow', 10231,
            'Longleftrightarrow', 10234,
            'longleftrightarrow', 10231,
            'longmapsto', 10236,
            'LongRightArrow', 10230,
            'Longrightarrow', 10233,
            'longrightarrow', 10230,
            'looparrowleft', 8619,
            'looparrowright', 8620,
            'lopar', 10629,
            'Lopf', 120131,
            'lopf', 120157,
            'loplus', 10797,
            'lotimes', 10804,
            'lowast', 8727,
            'lowbar', 95,
            'LowerLeftArrow', 8601,
            'LowerRightArrow', 8600,
            'loz', 9674,
            'lozenge', 9674,
            'lozf', 10731,
            'lpar', 40,
            'lparlt', 10643,
            'lrarr', 8646,
            'lrcorner', 8991,
            'lrhar', 8651,
            'lrhard', 10605,
            'lrm', 8206,
            'lrtri', 8895,
            'lsaquo', 8249,
            'Lscr', 8466,
            'lscr', 120001,
            'Lsh', 8624,
            'lsh', 8624,
            'lsim', 8818,
            'lsime', 10893,
            'lsimg', 10895,
            'lsqb', 91,
            'lsquo', 8216,
            'lsquor', 8218,
            'Lstrok', 321,
            'lstrok', 322,
            'LT', 60,
            'Lt', 8810,
            'lt', 60,
            'ltcc', 10918,
            'ltcir', 10873,
            'ltdot', 8918,
            'lthree', 8907,
            'ltimes', 8905,
            'ltlarr', 10614,
            'ltquest', 10875,
            'ltri', 9667,
            'ltrie', 8884,
            'ltrif', 9666,
            'ltrPar', 10646,
            'lurdshar', 10570,
            'luruhar', 10598,
            'macr', 175,
            'male', 9794,
            'malt', 10016,
            'maltese', 10016,
            'Map', 10501,
            'map', 8614,
            'mapsto', 8614,
            'mapstodown', 8615,
            'mapstoleft', 8612,
            'mapstoup', 8613,
            'marker', 9646,
            'mcomma', 10793,
            'Mcy', 1052,
            'mcy', 1084,
            'mdash', 8212,
            'mDDot', 8762,
            'measuredangle', 8737,
            'MediumSpace', 8287,
            'Mellintrf', 8499,
            'Mfr', 120080,
            'mfr', 120106,
            'mho', 8487,
            'micro', 181,
            'mid', 8739,
            'midast', 42,
            'midcir', 10992,
            'middot', 183,
            'minus', 8722,
            'minusb', 8863,
            'minusd', 8760,
            'minusdu', 10794,
            'MinusPlus', 8723,
            'mlcp', 10971,
            'mldr', 8230,
            'mnplus', 8723,
            'models', 8871,
            'Mopf', 120132,
            'mopf', 120158,
            'mp', 8723,
            'Mscr', 8499,
            'mscr', 120002,
            'mstpos', 8766,
            'Mu', 924,
            'mu', 956,
            'multimap', 8888,
            'mumap', 8888,
            'nabla', 8711,
            'Nacute', 323,
            'nacute', 324,
            'nap', 8777,
            'napos', 329,
            'napprox', 8777,
            'natur', 9838,
            'natural', 9838,
            'naturals', 8469,
            'nbsp', 160,
            'ncap', 10819,
            'Ncaron', 327,
            'ncaron', 328,
            'Ncedil', 325,
            'ncedil', 326,
            'ncong', 8775,
            'ncup', 10818,
            'Ncy', 1053,
            'ncy', 1085,
            'ndash', 8211,
            'ne', 8800,
            'nearhk', 10532,
            'neArr', 8663,
            'nearr', 8599,
            'nearrow', 8599,
            'NegativeMediumSpace', 8203,
            'NegativeThickSpace', 8203,
            'NegativeThinSpace', 8203,
            'NegativeVeryThinSpace', 8203,
            'nequiv', 8802,
            'nesear', 10536,
            'NestedGreaterGreater', 8811,
            'NestedLessLess', 8810,
            'NewLine', 10,
            'nexist', 8708,
            'nexists', 8708,
            'Nfr', 120081,
            'nfr', 120107,
            'nge', 8817,
            'ngeq', 8817,
            'ngsim', 8821,
            'ngt', 8815,
            'ngtr', 8815,
            'nhArr', 8654,
            'nharr', 8622,
            'nhpar', 10994,
            'ni', 8715,
            'nis', 8956,
            'nisd', 8954,
            'niv', 8715,
            'NJcy', 1034,
            'njcy', 1114,
            'nlArr', 8653,
            'nlarr', 8602,
            'nldr', 8229,
            'nle', 8816,
            'nLeftarrow', 8653,
            'nleftarrow', 8602,
            'nLeftrightarrow', 8654,
            'nleftrightarrow', 8622,
            'nleq', 8816,
            'nless', 8814,
            'nlsim', 8820,
            'nlt', 8814,
            'nltri', 8938,
            'nltrie', 8940,
            'nmid', 8740,
            'NoBreak', 8288,
            'NonBreakingSpace', 160,
            'Nopf', 8469,
            'nopf', 120159,
            'Not', 10988,
            'not', 172,
            'NotCongruent', 8802,
            'NotCupCap', 8813,
            'NotDoubleVerticalBar', 8742,
            'NotElement', 8713,
            'NotEqual', 8800,
            'NotExists', 8708,
            'NotGreater', 8815,
            'NotGreaterEqual', 8817,
            'NotGreaterLess', 8825,
            'NotGreaterTilde', 8821,
            'notin', 8713,
            'notinva', 8713,
            'notinvb', 8951,
            'notinvc', 8950,
            'NotLeftTriangle', 8938,
            'NotLeftTriangleEqual', 8940,
            'NotLess', 8814,
            'NotLessEqual', 8816,
            'NotLessGreater', 8824,
            'NotLessTilde', 8820,
            'notni', 8716,
            'notniva', 8716,
            'notnivb', 8958,
            'notnivc', 8957,
            'NotPrecedes', 8832,
            'NotPrecedesSlantEqual', 8928,
            'NotReverseElement', 8716,
            'NotRightTriangle', 8939,
            'NotRightTriangleEqual', 8941,
            'NotSquareSubsetEqual', 8930,
            'NotSquareSupersetEqual', 8931,
            'NotSubsetEqual', 8840,
            'NotSucceeds', 8833,
            'NotSucceedsSlantEqual', 8929,
            'NotSupersetEqual', 8841,
            'NotTilde', 8769,
            'NotTildeEqual', 8772,
            'NotTildeFullEqual', 8775,
            'NotTildeTilde', 8777,
            'NotVerticalBar', 8740,
            'npar', 8742,
            'nparallel', 8742,
            'npolint', 10772,
            'npr', 8832,
            'nprcue', 8928,
            'nprec', 8832,
            'nrArr', 8655,
            'nrarr', 8603,
            'nRightarrow', 8655,
            'nrightarrow', 8603,
            'nrtri', 8939,
            'nrtrie', 8941,
            'nsc', 8833,
            'nsccue', 8929,
            'Nscr', 119977,
            'nscr', 120003,
            'nshortmid', 8740,
            'nshortparallel', 8742,
            'nsim', 8769,
            'nsime', 8772,
            'nsimeq', 8772,
            'nsmid', 8740,
            'nspar', 8742,
            'nsqsube', 8930,
            'nsqsupe', 8931,
            'nsub', 8836,
            'nsube', 8840,
            'nsubseteq', 8840,
            'nsucc', 8833,
            'nsup', 8837,
            'nsupe', 8841,
            'nsupseteq', 8841,
            'ntgl', 8825,
            'Ntilde', 209,
            'ntilde', 241,
            'ntlg', 8824,
            'ntriangleleft', 8938,
            'ntrianglelefteq', 8940,
            'ntriangleright', 8939,
            'ntrianglerighteq', 8941,
            'Nu', 925,
            'nu', 957,
            'num', 35,
            'numero', 8470,
            'numsp', 8199,
            'nVDash', 8879,
            'nVdash', 8878,
            'nvDash', 8877,
            'nvdash', 8876,
            'nvHarr', 10500,
            'nvinfin', 10718,
            'nvlArr', 10498,
            'nvrArr', 10499,
            'nwarhk', 10531,
            'nwArr', 8662,
            'nwarr', 8598,
            'nwarrow', 8598,
            'nwnear', 10535,
            'Oacute', 211,
            'oacute', 243,
            'oast', 8859,
            'ocir', 8858,
            'Ocirc', 212,
            'ocirc', 244,
            'Ocy', 1054,
            'ocy', 1086,
            'odash', 8861,
            'Odblac', 336,
            'odblac', 337,
            'odiv', 10808,
            'odot', 8857,
            'odsold', 10684,
            'OElig', 338,
            'oelig', 339,
            'ofcir', 10687,
            'Ofr', 120082,
            'ofr', 120108,
            'ogon', 731,
            'Ograve', 210,
            'ograve', 242,
            'ogt', 10689,
            'ohbar', 10677,
            'ohm', 937,
            'oint', 8750,
            'olarr', 8634,
            'olcir', 10686,
            'olcross', 10683,
            'oline', 8254,
            'olt', 10688,
            'Omacr', 332,
            'omacr', 333,
            'Omega', 937,
            'omega', 969,
            'Omicron', 927,
            'omicron', 959,
            'omid', 10678,
            'ominus', 8854,
            'Oopf', 120134,
            'oopf', 120160,
            'opar', 10679,
            'OpenCurlyDoubleQuote', 8220,
            'OpenCurlyQuote', 8216,
            'operp', 10681,
            'oplus', 8853,
            'Or', 10836,
            'or', 8744,
            'orarr', 8635,
            'ord', 10845,
            'order', 8500,
            'orderof', 8500,
            'ordf', 170,
            'ordm', 186,
            'origof', 8886,
            'oror', 10838,
            'orslope', 10839,
            'orv', 10843,
            'oS', 9416,
            'Oscr', 119978,
            'oscr', 8500,
            'Oslash', 216,
            'oslash', 248,
            'osol', 8856,
            'Otilde', 213,
            'otilde', 245,
            'Otimes', 10807,
            'otimes', 8855,
            'otimesas', 10806,
            'Ouml', 214,
            'ouml', 246,
            'ovbar', 9021,
            'OverBar', 8254,
            'OverBrace', 9182,
            'OverBracket', 9140,
            'OverParenthesis', 9180,
            'par', 8741,
            'para', 182,
            'parallel', 8741,
            'parsim', 10995,
            'parsl', 11005,
            'part', 8706,
            'PartialD', 8706,
            'Pcy', 1055,
            'pcy', 1087,
            'percnt', 37,
            'period', 46,
            'permil', 8240,
            'perp', 8869,
            'pertenk', 8241,
            'Pfr', 120083,
            'pfr', 120109,
            'Phi', 934,
            'phi', 966,
            'phiv', 981,
            'phmmat', 8499,
            'phone', 9742,
            'Pi', 928,
            'pi', 960,
            'pitchfork', 8916,
            'piv', 982,
            'planck', 8463,
            'planckh', 8462,
            'plankv', 8463,
            'plus', 43,
            'plusacir', 10787,
            'plusb', 8862,
            'pluscir', 10786,
            'plusdo', 8724,
            'plusdu', 10789,
            'pluse', 10866,
            'PlusMinus', 177,
            'plusmn', 177,
            'plussim', 10790,
            'plustwo', 10791,
            'pm', 177,
            'Poincareplane', 8460,
            'pointint', 10773,
            'Popf', 8473,
            'popf', 120161,
            'pound', 163,
            'Pr', 10939,
            'pr', 8826,
            'prap', 10935,
            'prcue', 8828,
            'prE', 10931,
            'pre', 10927,
            'prec', 8826,
            'precapprox', 10935,
            'preccurlyeq', 8828,
            'Precedes', 8826,
            'PrecedesEqual', 10927,
            'PrecedesSlantEqual', 8828,
            'PrecedesTilde', 8830,
            'preceq', 10927,
            'precnapprox', 10937,
            'precneqq', 10933,
            'precnsim', 8936,
            'precsim', 8830,
            'Prime', 8243,
            'prime', 8242,
            'primes', 8473,
            'prnap', 10937,
            'prnE', 10933,
            'prnsim', 8936,
            'prod', 8719,
            'Product', 8719,
            'profalar', 9006,
            'profline', 8978,
            'profsurf', 8979,
            'prop', 8733,
            'Proportion', 8759,
            'Proportional', 8733,
            'propto', 8733,
            'prsim', 8830,
            'prurel', 8880,
            'Pscr', 119979,
            'pscr', 120005,
            'Psi', 936,
            'psi', 968,
            'puncsp', 8200,
            'Qfr', 120084,
            'qfr', 120110,
            'qint', 10764,
            'Qopf', 8474,
            'qopf', 120162,
            'qprime', 8279,
            'Qscr', 119980,
            'qscr', 120006,
            'quaternions', 8461,
            'quatint', 10774,
            'quest', 63,
            'questeq', 8799,
            'QUOT', 34,
            'quot', 34,
            'rAarr', 8667,
            'Racute', 340,
            'racute', 341,
            'radic', 8730,
            'raemptyv', 10675,
            'Rang', 10219,
            'rang', 10217,
            'rangd', 10642,
            'range', 10661,
            'rangle', 10217,
            'raquo', 187,
            'Rarr', 8608,
            'rArr', 8658,
            'rarr', 8594,
            'rarrap', 10613,
            'rarrb', 8677,
            'rarrbfs', 10528,
            'rarrc', 10547,
            'rarrfs', 10526,
            'rarrhk', 8618,
            'rarrlp', 8620,
            'rarrpl', 10565,
            'rarrsim', 10612,
            'Rarrtl', 10518,
            'rarrtl', 8611,
            'rarrw', 8605,
            'rAtail', 10524,
            'ratail', 10522,
            'ratio', 8758,
            'rationals', 8474,
            'RBarr', 10512,
            'rBarr', 10511,
            'rbarr', 10509,
            'rbbrk', 10099,
            'rbrace', 125,
            'rbrack', 93,
            'rbrke', 10636,
            'rbrksld', 10638,
            'rbrkslu', 10640,
            'Rcaron', 344,
            'rcaron', 345,
            'Rcedil', 342,
            'rcedil', 343,
            'rceil', 8969,
            'rcub', 125,
            'Rcy', 1056,
            'rcy', 1088,
            'rdca', 10551,
            'rdldhar', 10601,
            'rdquo', 8221,
            'rdquor', 8221,
            'rdsh', 8627,
            'Re', 8476,
            'real', 8476,
            'realine', 8475,
            'realpart', 8476,
            'reals', 8477,
            'rect', 9645,
            'REG', 174,
            'reg', 174,
            'ReverseElement', 8715,
            'ReverseEquilibrium', 8651,
            'ReverseUpEquilibrium', 10607,
            'rfisht', 10621,
            'rfloor', 8971,
            'Rfr', 8476,
            'rfr', 120111,
            'rHar', 10596,
            'rhard', 8641,
            'rharu', 8640,
            'rharul', 10604,
            'Rho', 929,
            'rho', 961,
            'rhov', 1009,
            'RightAngleBracket', 10217,
            'RightArrow', 8594,
            'Rightarrow', 8658,
            'rightarrow', 8594,
            'RightArrowBar', 8677,
            'RightArrowLeftArrow', 8644,
            'rightarrowtail', 8611,
            'RightCeiling', 8969,
            'RightDoubleBracket', 10215,
            'RightDownTeeVector', 10589,
            'RightDownVector', 8642,
            'RightDownVectorBar', 10581,
            'RightFloor', 8971,
            'rightharpoondown', 8641,
            'rightharpoonup', 8640,
            'rightleftarrows', 8644,
            'rightleftharpoons', 8652,
            'rightrightarrows', 8649,
            'rightsquigarrow', 8605,
            'RightTee', 8866,
            'RightTeeArrow', 8614,
            'RightTeeVector', 10587,
            'rightthreetimes', 8908,
            'RightTriangle', 8883,
            'RightTriangleBar', 10704,
            'RightTriangleEqual', 8885,
            'RightUpDownVector', 10575,
            'RightUpTeeVector', 10588,
            'RightUpVector', 8638,
            'RightUpVectorBar', 10580,
            'RightVector', 8640,
            'RightVectorBar', 10579,
            'ring', 730,
            'risingdotseq', 8787,
            'rlarr', 8644,
            'rlhar', 8652,
            'rlm', 8207,
            'rmoust', 9137,
            'rmoustache', 9137,
            'rnmid', 10990,
            'roang', 10221,
            'roarr', 8702,
            'robrk', 10215,
            'ropar', 10630,
            'Ropf', 8477,
            'ropf', 120163,
            'roplus', 10798,
            'rotimes', 10805,
            'RoundImplies', 10608,
            'rpar', 41,
            'rpargt', 10644,
            'rppolint', 10770,
            'rrarr', 8649,
            'Rrightarrow', 8667,
            'rsaquo', 8250,
            'Rscr', 8475,
            'rscr', 120007,
            'Rsh', 8625,
            'rsh', 8625,
            'rsqb', 93,
            'rsquo', 8217,
            'rsquor', 8217,
            'rthree', 8908,
            'rtimes', 8906,
            'rtri', 9657,
            'rtrie', 8885,
            'rtrif', 9656,
            'rtriltri', 10702,
            'RuleDelayed', 10740,
            'ruluhar', 10600,
            'rx', 8478,
            'Sacute', 346,
            'sacute', 347,
            'sbquo', 8218,
            'Sc', 10940,
            'sc', 8827,
            'scap', 10936,
            'Scaron', 352,
            'scaron', 353,
            'sccue', 8829,
            'scE', 10932,
            'sce', 10928,
            'Scedil', 350,
            'scedil', 351,
            'Scirc', 348,
            'scirc', 349,
            'scnap', 10938,
            'scnE', 10934,
            'scnsim', 8937,
            'scpolint', 10771,
            'scsim', 8831,
            'Scy', 1057,
            'scy', 1089,
            'sdot', 8901,
            'sdotb', 8865,
            'sdote', 10854,
            'searhk', 10533,
            'seArr', 8664,
            'searr', 8600,
            'searrow', 8600,
            'sect', 167,
            'semi', 59,
            'seswar', 10537,
            'setminus', 8726,
            'setmn', 8726,
            'sext', 10038,
            'Sfr', 120086,
            'sfr', 120112,
            'sfrown', 8994,
            'sharp', 9839,
            'SHCHcy', 1065,
            'shchcy', 1097,
            'SHcy', 1064,
            'shcy', 1096,
            'ShortDownArrow', 8595,
            'ShortLeftArrow', 8592,
            'shortmid', 8739,
            'shortparallel', 8741,
            'ShortRightArrow', 8594,
            'ShortUpArrow', 8593,
            'shy', 173,
            'Sigma', 931,
            'sigma', 963,
            'sigmaf', 962,
            'sigmav', 962,
            'sim', 8764,
            'simdot', 10858,
            'sime', 8771,
            'simeq', 8771,
            'simg', 10910,
            'simgE', 10912,
            'siml', 10909,
            'simlE', 10911,
            'simne', 8774,
            'simplus', 10788,
            'simrarr', 10610,
            'slarr', 8592,
            'SmallCircle', 8728,
            'smallsetminus', 8726,
            'smashp', 10803,
            'smeparsl', 10724,
            'smid', 8739,
            'smile', 8995,
            'smt', 10922,
            'smte', 10924,
            'SOFTcy', 1068,
            'softcy', 1100,
            'sol', 47,
            'solb', 10692,
            'solbar', 9023,
            'Sopf', 120138,
            'sopf', 120164,
            'spades', 9824,
            'spadesuit', 9824,
            'spar', 8741,
            'sqcap', 8851,
            'sqcup', 8852,
            'Sqrt', 8730,
            'sqsub', 8847,
            'sqsube', 8849,
            'sqsubset', 8847,
            'sqsubseteq', 8849,
            'sqsup', 8848,
            'sqsupe', 8850,
            'sqsupset', 8848,
            'sqsupseteq', 8850,
            'squ', 9633,
            'Square', 9633,
            'square', 9633,
            'SquareIntersection', 8851,
            'SquareSubset', 8847,
            'SquareSubsetEqual', 8849,
            'SquareSuperset', 8848,
            'SquareSupersetEqual', 8850,
            'SquareUnion', 8852,
            'squarf', 9642,
            'squf', 9642,
            'srarr', 8594,
            'Sscr', 119982,
            'sscr', 120008,
            'ssetmn', 8726,
            'ssmile', 8995,
            'sstarf', 8902,
            'Star', 8902,
            'star', 9734,
            'starf', 9733,
            'straightepsilon', 1013,
            'straightphi', 981,
            'strns', 175,
            'Sub', 8912,
            'sub', 8834,
            'subdot', 10941,
            'subE', 10949,
            'sube', 8838,
            'subedot', 10947,
            'submult', 10945,
            'subnE', 10955,
            'subne', 8842,
            'subplus', 10943,
            'subrarr', 10617,
            'Subset', 8912,
            'subset', 8834,
            'subseteq', 8838,
            'subseteqq', 10949,
            'SubsetEqual', 8838,
            'subsetneq', 8842,
            'subsetneqq', 10955,
            'subsim', 10951,
            'subsub', 10965,
            'subsup', 10963,
            'succ', 8827,
            'succapprox', 10936,
            'succcurlyeq', 8829,
            'Succeeds', 8827,
            'SucceedsEqual', 10928,
            'SucceedsSlantEqual', 8829,
            'SucceedsTilde', 8831,
            'succeq', 10928,
            'succnapprox', 10938,
            'succneqq', 10934,
            'succnsim', 8937,
            'succsim', 8831,
            'SuchThat', 8715,
            'Sum', 8721,
            'sum', 8721,
            'sung', 9834,
            'Sup', 8913,
            'sup', 8835,
            'sup1', 185,
            'sup2', 178,
            'sup3', 179,
            'supdot', 10942,
            'supdsub', 10968,
            'supE', 10950,
            'supe', 8839,
            'supedot', 10948,
            'Superset', 8835,
            'SupersetEqual', 8839,
            'suphsol', 10185,
            'suphsub', 10967,
            'suplarr', 10619,
            'supmult', 10946,
            'supnE', 10956,
            'supne', 8843,
            'supplus', 10944,
            'Supset', 8913,
            'supset', 8835,
            'supseteq', 8839,
            'supseteqq', 10950,
            'supsetneq', 8843,
            'supsetneqq', 10956,
            'supsim', 10952,
            'supsub', 10964,
            'supsup', 10966,
            'swarhk', 10534,
            'swArr', 8665,
            'swarr', 8601,
            'swarrow', 8601,
            'swnwar', 10538,
            'szlig', 223,
            'Tab', 9,
            'target', 8982,
            'Tau', 932,
            'tau', 964,
            'tbrk', 9140,
            'Tcaron', 356,
            'tcaron', 357,
            'Tcedil', 354,
            'tcedil', 355,
            'Tcy', 1058,
            'tcy', 1090,
            'tdot', 8411,
            'telrec', 8981,
            'Tfr', 120087,
            'tfr', 120113,
            'there4', 8756,
            'Therefore', 8756,
            'therefore', 8756,
            'Theta', 920,
            'theta', 952,
            'thetasym', 977,
            'thetav', 977,
            'thickapprox', 8776,
            'thicksim', 8764,
            'thinsp', 8201,
            'ThinSpace', 8201,
            'thkap', 8776,
            'thksim', 8764,
            'THORN', 222,
            'thorn', 254,
            'Tilde', 8764,
            'tilde', 732,
            'TildeEqual', 8771,
            'TildeFullEqual', 8773,
            'TildeTilde', 8776,
            'times', 215,
            'timesb', 8864,
            'timesbar', 10801,
            'timesd', 10800,
            'tint', 8749,
            'toea', 10536,
            'top', 8868,
            'topbot', 9014,
            'topcir', 10993,
            'Topf', 120139,
            'topf', 120165,
            'topfork', 10970,
            'tosa', 10537,
            'tprime', 8244,
            'TRADE', 8482,
            'trade', 8482,
            'triangle', 9653,
            'triangledown', 9663,
            'triangleleft', 9667,
            'trianglelefteq', 8884,
            'triangleq', 8796,
            'triangleright', 9657,
            'trianglerighteq', 8885,
            'tridot', 9708,
            'trie', 8796,
            'triminus', 10810,
            'TripleDot', 8411,
            'triplus', 10809,
            'trisb', 10701,
            'tritime', 10811,
            'trpezium', 9186,
            'Tscr', 119983,
            'tscr', 120009,
            'TScy', 1062,
            'tscy', 1094,
            'TSHcy', 1035,
            'tshcy', 1115,
            'Tstrok', 358,
            'tstrok', 359,
            'twixt', 8812,
            'twoheadleftarrow', 8606,
            'twoheadrightarrow', 8608,
            'Uacute', 218,
            'uacute', 250,
            'Uarr', 8607,
            'uArr', 8657,
            'uarr', 8593,
            'Uarrocir', 10569,
            'Ubrcy', 1038,
            'ubrcy', 1118,
            'Ubreve', 364,
            'ubreve', 365,
            'Ucirc', 219,
            'ucirc', 251,
            'Ucy', 1059,
            'ucy', 1091,
            'udarr', 8645,
            'Udblac', 368,
            'udblac', 369,
            'udhar', 10606,
            'ufisht', 10622,
            'Ufr', 120088,
            'ufr', 120114,
            'Ugrave', 217,
            'ugrave', 249,
            'uHar', 10595,
            'uharl', 8639,
            'uharr', 8638,
            'uhblk', 9600,
            'ulcorn', 8988,
            'ulcorner', 8988,
            'ulcrop', 8975,
            'ultri', 9720,
            'Umacr', 362,
            'umacr', 363,
            'uml', 168,
            'UnderBar', 95,
            'UnderBrace', 9183,
            'UnderBracket', 9141,
            'UnderParenthesis', 9181,
            'Union', 8899,
            'UnionPlus', 8846,
            'Uogon', 370,
            'uogon', 371,
            'Uopf', 120140,
            'uopf', 120166,
            'UpArrow', 8593,
            'Uparrow', 8657,
            'uparrow', 8593,
            'UpArrowBar', 10514,
            'UpArrowDownArrow', 8645,
            'UpDownArrow', 8597,
            'Updownarrow', 8661,
            'updownarrow', 8597,
            'UpEquilibrium', 10606,
            'upharpoonleft', 8639,
            'upharpoonright', 8638,
            'uplus', 8846,
            'UpperLeftArrow', 8598,
            'UpperRightArrow', 8599,
            'Upsi', 978,
            'upsi', 965,
            'upsih', 978,
            'Upsilon', 933,
            'upsilon', 965,
            'UpTee', 8869,
            'UpTeeArrow', 8613,
            'upuparrows', 8648,
            'urcorn', 8989,
            'urcorner', 8989,
            'urcrop', 8974,
            'Uring', 366,
            'uring', 367,
            'urtri', 9721,
            'Uscr', 119984,
            'uscr', 120010,
            'utdot', 8944,
            'Utilde', 360,
            'utilde', 361,
            'utri', 9653,
            'utrif', 9652,
            'uuarr', 8648,
            'Uuml', 220,
            'uuml', 252,
            'uwangle', 10663,
            'vangrt', 10652,
            'varepsilon', 1013,
            'varkappa', 1008,
            'varnothing', 8709,
            'varphi', 981,
            'varpi', 982,
            'varpropto', 8733,
            'vArr', 8661,
            'varr', 8597,
            'varrho', 1009,
            'varsigma', 962,
            'vartheta', 977,
            'vartriangleleft', 8882,
            'vartriangleright', 8883,
            'Vbar', 10987,
            'vBar', 10984,
            'vBarv', 10985,
            'Vcy', 1042,
            'vcy', 1074,
            'VDash', 8875,
            'Vdash', 8873,
            'vDash', 8872,
            'vdash', 8866,
            'Vdashl', 10982,
            'Vee', 8897,
            'vee', 8744,
            'veebar', 8891,
            'veeeq', 8794,
            'vellip', 8942,
            'Verbar', 8214,
            'verbar', 124,
            'Vert', 8214,
            'vert', 124,
            'VerticalBar', 8739,
            'VerticalLine', 124,
            'VerticalSeparator', 10072,
            'VerticalTilde', 8768,
            'VeryThinSpace', 8202,
            'Vfr', 120089,
            'vfr', 120115,
            'vltri', 8882,
            'Vopf', 120141,
            'vopf', 120167,
            'vprop', 8733,
            'vrtri', 8883,
            'Vscr', 119985,
            'vscr', 120011,
            'Vvdash', 8874,
            'vzigzag', 10650,
            'Wcirc', 372,
            'wcirc', 373,
            'wedbar', 10847,
            'Wedge', 8896,
            'wedge', 8743,
            'wedgeq', 8793,
            'weierp', 8472,
            'Wfr', 120090,
            'wfr', 120116,
            'Wopf', 120142,
            'wopf', 120168,
            'wp', 8472,
            'wr', 8768,
            'wreath', 8768,
            'Wscr', 119986,
            'wscr', 120012,
            'xcap', 8898,
            'xcirc', 9711,
            'xcup', 8899,
            'xdtri', 9661,
            'Xfr', 120091,
            'xfr', 120117,
            'xhArr', 10234,
            'xharr', 10231,
            'Xi', 926,
            'xi', 958,
            'xlArr', 10232,
            'xlarr', 10229,
            'xmap', 10236,
            'xnis', 8955,
            'xodot', 10752,
            'Xopf', 120143,
            'xopf', 120169,
            'xoplus', 10753,
            'xotime', 10754,
            'xrArr', 10233,
            'xrarr', 10230,
            'Xscr', 119987,
            'xscr', 120013,
            'xsqcup', 10758,
            'xuplus', 10756,
            'xutri', 9651,
            'xvee', 8897,
            'xwedge', 8896,
            'Yacute', 221,
            'yacute', 253,
            'YAcy', 1071,
            'yacy', 1103,
            'Ycirc', 374,
            'ycirc', 375,
            'Ycy', 1067,
            'ycy', 1099,
            'yen', 165,
            'Yfr', 120092,
            'yfr', 120118,
            'YIcy', 1031,
            'yicy', 1111,
            'Yopf', 120144,
            'yopf', 120170,
            'Yscr', 119988,
            'yscr', 120014,
            'YUcy', 1070,
            'yucy', 1102,
            'Yuml', 376,
            'yuml', 255,
            'Zacute', 377,
            'zacute', 378,
            'Zcaron', 381,
            'zcaron', 382,
            'Zcy', 1047,
            'zcy', 1079,
            'Zdot', 379,
            'zdot', 380,
            'zeetrf', 8488,
            'ZeroWidthSpace', 8203,
            'Zeta', 918,
            'zeta', 950,
            'Zfr', 8488,
            'zfr', 120119,
            'ZHcy', 1046,
            'zhcy', 1078,
            'zigrarr', 8669,
            'Zopf', 8484,
            'zopf', 120171,
            'Zscr', 119989,
            'zscr', 120015,
            'zwj', 8205,
            'zwnj', 8204,
        );

        #   HTML5 Composed Character References

        #   These are logical characters formed by combining multiple
        #   Unicode code points.  The code points which make up the
        #   character are given in a comma-separated string.

        @HTML_COMPOSED_CHARACTER_REFERENCES = (
            #   From https://www.w3.org/TR/html5/entities.json
            'acE', '8766, 819',
            'bne', '61, 8421',
            'bnequiv', '8801, 8421',
            'caps', '8745, 65024',
            'cups', '8746, 65024',
            'fjlig', '102, 106',
            'gesl', '8923, 65024',
            'gvertneqq', '8809, 65024',
            'gvnE', '8809, 65024',
            'lates', '10925, 65024',
            'lesg', '8922, 65024',
            'lvertneqq', '8808, 65024',
            'lvnE', '8808, 65024',
            'nang', '8736, 8402',
            'napE', '10864, 824',
            'napid', '8779, 824',
            'nbump', '8782, 824',
            'nbumpe', '8783, 824',
            'ncongdot', '10861, 824',
            'nedot', '8784, 824',
            'nesim', '8770, 824',
            'ngE', '8807, 824',
            'ngeqq', '8807, 824',
            'ngeqslant', '10878, 824',
            'nges', '10878, 824',
            'nGg', '8921, 824',
            'nGt', '8811, 8402',
            'nGtv', '8811, 824',
            'nlE', '8806, 824',
            'nleqq', '8806, 824',
            'nleqslant', '10877, 824',
            'nles', '10877, 824',
            'nLl', '8920, 824',
            'nLt', '8810, 8402',
            'nLtv', '8810, 824',
            'NotEqualTilde', '8770, 824',
            'NotGreaterFullEqual', '8807, 824',
            'NotGreaterGreater', '8811, 824',
            'NotGreaterSlantEqual', '10878, 824',
            'NotHumpDownHump', '8782, 824',
            'NotHumpEqual', '8783, 824',
            'notindot', '8949, 824',
            'notinE', '8953, 824',
            'NotLeftTriangleBar', '10703, 824',
            'NotLessLess', '8810, 824',
            'NotLessSlantEqual', '10877, 824',
            'NotNestedGreaterGreater', '10914, 824',
            'NotNestedLessLess', '10913, 824',
            'NotPrecedesEqual', '10927, 824',
            'NotRightTriangleBar', '10704, 824',
            'NotSquareSubset', '8847, 824',
            'NotSquareSuperset', '8848, 824',
            'NotSubset', '8834, 8402',
            'NotSucceedsEqual', '10928, 824',
            'NotSucceedsTilde', '8831, 824',
            'NotSuperset', '8835, 8402',
            'nparsl', '11005, 8421',
            'npart', '8706, 824',
            'npre', '10927, 824',
            'npreceq', '10927, 824',
            'nrarrc', '10547, 824',
            'nrarrw', '8605, 824',
            'nsce', '10928, 824',
            'nsubE', '10949, 824',
            'nsubset', '8834, 8402',
            'nsubseteqq', '10949, 824',
            'nsucceq', '10928, 824',
            'nsupE', '10950, 824',
            'nsupset', '8835, 8402',
            'nsupseteqq', '10950, 824',
            'nvap', '8781, 8402',
            'nvge', '8805, 8402',
            'nvgt', '62, 8402',
            'nvle', '8804, 8402',
            'nvlt', '60, 8402',
            'nvltrie', '8884, 8402',
            'nvrtrie', '8885, 8402',
            'nvsim', '8764, 8402',
            'race', '8765, 817',
            'smtes', '10924, 65024',
            'sqcaps', '8851, 65024',
            'sqcups', '8852, 65024',
            'ThickSpace', '8287, 8202',
            'varsubsetneq', '8842, 65024',
            'varsubsetneqq', '10955, 65024',
            'varsupsetneq', '8843, 65024',
            'varsupsetneqq', '10956, 65024',
            'vnsub', '8834, 8402',
            'vnsup', '8835, 8402',
            'vsubnE', '10955, 65024',
            'vsubne', '8842, 65024',
            'vsupnE', '10956, 65024',
            'vsupne', '8843, 65024',
        );
    }

__DATA__
0000 <control> NULL, NUL, Ctrl-@
0001 <control> START OF HEADING, SOH, Ctrl-A
0002 <control> START OF TEXT, STX, Ctrl-B
0003 <control> END OF TEXT, ETX, Ctrl-C
0004 <control> END OF TRANSMISSION, EOT, Ctrl-D
0005 <control> ENQUIRY, ENQ, Ctrl-E
0006 <control> ACKNOWLEDGE, ACK, Ctrl-F
0007 <control> BELL, ALERT, BEL, Ctrl-G
0008 <control> BACKSPACE, BS, Ctrl-H
0009 <control> CHARACTER TABULATION, HORIZONTAL TABULATION, HT TAB, Ctrl-I
000A <control> LINE FEED (LF), END OF LINE LINE FEED NEW LINE, EOL LF NL, Ctrl-J
000B <control> LINE TABULATION, VERTICAL TABULATION, VT, Ctrl-K
000C <control> FORM FEED (FF), FORM FEED, FF, Ctrl-L
000D <control> CARRIAGE RETURN (CR), CARRIAGE RETURN, CR, Ctrl-M
000E <control> SHIFT OUT, LOCKING-SHIFT ONE, SO, Ctrl-N
000F <control> SHIFT IN, LOCKING-SHIFT ZERO, SI, Ctrl-O
0010 <control> DATA LINK ESCAPE, DLE, Ctrl-P
0011 <control> DEVICE CONTROL ONE, DC1, Ctrl-Q
0012 <control> DEVICE CONTROL TWO, DC2, Ctrl-R
0013 <control> DEVICE CONTROL THREE, DC3, Ctrl-S
0014 <control> DEVICE CONTROL FOUR, DC4, Ctrl-T
0015 <control> NEGATIVE ACKNOWLEDGE, NAK, Ctrl-U
0016 <control> SYNCHRONOUS IDLE, SYN, Ctrl-V
0017 <control> END OF TRANSMISSION BLOCK, ETB, Ctrl-W
0018 <control> CANCEL, CAN, Ctrl-X
0019 <control> END OF MEDIUM, EOM, Ctrl-Y
001A <control> SUBSTITUTE, SUB, Ctrl-Z
001B <control> ESCAPE, ESC, Ctrl-[
001C <control> INFORMATION SEPARATOR FOUR, FILE SEPARATOR, FS, Ctrl-\
001D <control> INFORMATION SEPARATOR THREE, GROUP SEPARATOR, GS, Ctrl-]
001E <control> INFORMATION SEPARATOR TWO, RECORD SEPARATOR, RS, Ctrl-^
001F <control> INFORMATION SEPARATOR ONE, UNIT SEPARATOR, US, Ctrl-_
0020 SPACE, SP
0021 EXCLAMATION MARK
0022 QUOTATION MARK
0023 NUMBER SIGN
0024 DOLLAR SIGN
0025 PERCENT SIGN
0026 AMPERSAND
0027 APOSTROPHE
0028 LEFT PARENTHESIS
0029 RIGHT PARENTHESIS
002A ASTERISK
002B PLUS SIGN
002C COMMA
002D HYPHEN-MINUS
002E FULL STOP
002F SOLIDUS
0030 DIGIT ZERO
0031 DIGIT ONE
0032 DIGIT TWO
0033 DIGIT THREE
0034 DIGIT FOUR
0035 DIGIT FIVE
0036 DIGIT SIX
0037 DIGIT SEVEN
0038 DIGIT EIGHT
0039 DIGIT NINE
003A COLON
003B SEMICOLON
003C LESS-THAN SIGN
003D EQUALS SIGN
003E GREATER-THAN SIGN
003F QUESTION MARK
0040 COMMERCIAL AT
0041 LATIN CAPITAL LETTER A
0042 LATIN CAPITAL LETTER B
0043 LATIN CAPITAL LETTER C
0044 LATIN CAPITAL LETTER D
0045 LATIN CAPITAL LETTER E
0046 LATIN CAPITAL LETTER F
0047 LATIN CAPITAL LETTER G
0048 LATIN CAPITAL LETTER H
0049 LATIN CAPITAL LETTER I
004A LATIN CAPITAL LETTER J
004B LATIN CAPITAL LETTER K
004C LATIN CAPITAL LETTER L
004D LATIN CAPITAL LETTER M
004E LATIN CAPITAL LETTER N
004F LATIN CAPITAL LETTER O
0050 LATIN CAPITAL LETTER P
0051 LATIN CAPITAL LETTER Q
0052 LATIN CAPITAL LETTER R
0053 LATIN CAPITAL LETTER S
0054 LATIN CAPITAL LETTER T
0055 LATIN CAPITAL LETTER U
0056 LATIN CAPITAL LETTER V
0057 LATIN CAPITAL LETTER W
0058 LATIN CAPITAL LETTER X
0059 LATIN CAPITAL LETTER Y
005A LATIN CAPITAL LETTER Z
005B LEFT SQUARE BRACKET
005C REVERSE SOLIDUS
005D RIGHT SQUARE BRACKET
005E CIRCUMFLEX ACCENT
005F LOW LINE
0060 GRAVE ACCENT
0061 LATIN SMALL LETTER A
0062 LATIN SMALL LETTER B
0063 LATIN SMALL LETTER C
0064 LATIN SMALL LETTER D
0065 LATIN SMALL LETTER E
0066 LATIN SMALL LETTER F
0067 LATIN SMALL LETTER G
0068 LATIN SMALL LETTER H
0069 LATIN SMALL LETTER I
006A LATIN SMALL LETTER J
006B LATIN SMALL LETTER K
006C LATIN SMALL LETTER L
006D LATIN SMALL LETTER M
006E LATIN SMALL LETTER N
006F LATIN SMALL LETTER O
0070 LATIN SMALL LETTER P
0071 LATIN SMALL LETTER Q
0072 LATIN SMALL LETTER R
0073 LATIN SMALL LETTER S
0074 LATIN SMALL LETTER T
0075 LATIN SMALL LETTER U
0076 LATIN SMALL LETTER V
0077 LATIN SMALL LETTER W
0078 LATIN SMALL LETTER X
0079 LATIN SMALL LETTER Y
007A LATIN SMALL LETTER Z
007B LEFT CURLY BRACKET
007C VERTICAL LINE
007D RIGHT CURLY BRACKET
007E TILDE
007F <control> DELETE, DEL
0080 XXX, PAD, PADDING CHARACTER
0081 XXX, HOP, HIGH OCTET PRESET
0082 <control> BREAK PERMITTED HERE, BPH
0083 <control> NO BREAK HERE, NBH
0084 <control> XXX, INDEX, IND
0085 <control> NEXT LINE (NEL), NEXT LINE, NEL
0086 <control> START OF SELECTED AREA, SSA
0087 <control> END OF SELECTED AREA, ESA
0088 <control> CHARACTER TABULATION SET, HORIZONTAL TABULATION SET, HTS
0089 <control> CHARACTER TABULATION WITH JUSTIFICATION, HORIZONTAL TABULATION WITH JUSTIFICATION, HTJ
008A <control> LINE TABULATION SET, VERTICAL TABULATION SET, VTS
008B <control> PARTIAL LINE FORWARD, PARTIAL LINE DOWN, PLD
008C <control> PARTIAL LINE BACKWARD, PARTIAL LINE UP, PLU
008D <control> REVERSE LINE FEED, REVERSE INDEX, RI
008E <control> SINGLE SHIFT TWO, SINGLE-SHIFT-2, SS2
008F <control> SINGLE SHIFT THREE, SINGLE-SHIFT-3, SS3
0090 <control> DEVICE CONTROL STRING, DCS
0091 <control> PRIVATE USE ONE, PRIVATE USE-1, PU1
0092 <control> PRIVATE USE TWO, PRIVATE USE-2, PU2
0093 <control> SET TRANSMIT STATE, STS
0094 <control> CANCEL CHARACTER, CCH
0095 <control> MESSAGE WAITING, MW
0096 <control> START OF GUARDED AREA, START OF PROTECTED AREA, SPA
0097 <control> END OF GUARDED AREA, END OF PROTECTED AREA, EPA
0098 <control> START OF STRING, SOS
0099 XXX, SGC, SINGLE GRAPHIC CHARACTER INTRODUCER
009A <control> SINGLE CHARACTER INTRODUCER, SCI
009B <control> CONTROL SEQUENCE INTRODUCER, CSI
009C <control> STRING TERMINATOR, ST
009D <control> OPERATING SYSTEM COMMAND, OSC
009E <control> PRIVACY MESSAGE, PM
009F <control> APPLICATION PROGRAM COMMAND, APC
00A0 NO-BREAK SPACE, NBSP
00A1 INVERTED EXCLAMATION MARK
00A2 CENT SIGN
00A3 POUND SIGN
00A4 CURRENCY SIGN
00A5 YEN SIGN
00A6 BROKEN BAR
00A7 SECTION SIGN
00A8 DIAERESIS
00A9 COPYRIGHT SIGN
00AA FEMININE ORDINAL INDICATOR
00AB LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
00AC NOT SIGN
00AD SOFT HYPHEN, SHY
00AE REGISTERED SIGN
00AF MACRON
00B0 DEGREE SIGN
00B1 PLUS-MINUS SIGN
00B2 SUPERSCRIPT TWO
00B3 SUPERSCRIPT THREE
00B4 ACUTE ACCENT
00B5 MICRO SIGN
00B6 PILCROW SIGN
00B7 MIDDLE DOT
00B8 CEDILLA
00B9 SUPERSCRIPT ONE
00BA MASCULINE ORDINAL INDICATOR
00BB RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
00BC VULGAR FRACTION ONE QUARTER
00BD VULGAR FRACTION ONE HALF
00BE VULGAR FRACTION THREE QUARTERS
00BF INVERTED QUESTION MARK
00C0 LATIN CAPITAL LETTER A WITH GRAVE
00C1 LATIN CAPITAL LETTER A WITH ACUTE
00C2 LATIN CAPITAL LETTER A WITH CIRCUMFLEX
00C3 LATIN CAPITAL LETTER A WITH TILDE
00C4 LATIN CAPITAL LETTER A WITH DIAERESIS
00C5 LATIN CAPITAL LETTER A WITH RING ABOVE
00C6 LATIN CAPITAL LETTER AE
00C7 LATIN CAPITAL LETTER C WITH CEDILLA
00C8 LATIN CAPITAL LETTER E WITH GRAVE
00C9 LATIN CAPITAL LETTER E WITH ACUTE
00CA LATIN CAPITAL LETTER E WITH CIRCUMFLEX
00CB LATIN CAPITAL LETTER E WITH DIAERESIS
00CC LATIN CAPITAL LETTER I WITH GRAVE
00CD LATIN CAPITAL LETTER I WITH ACUTE
00CE LATIN CAPITAL LETTER I WITH CIRCUMFLEX
00CF LATIN CAPITAL LETTER I WITH DIAERESIS
00D0 LATIN CAPITAL LETTER ETH
00D1 LATIN CAPITAL LETTER N WITH TILDE
00D2 LATIN CAPITAL LETTER O WITH GRAVE
00D3 LATIN CAPITAL LETTER O WITH ACUTE
00D4 LATIN CAPITAL LETTER O WITH CIRCUMFLEX
00D5 LATIN CAPITAL LETTER O WITH TILDE
00D6 LATIN CAPITAL LETTER O WITH DIAERESIS
00D7 MULTIPLICATION SIGN
00D8 LATIN CAPITAL LETTER O WITH STROKE
00D9 LATIN CAPITAL LETTER U WITH GRAVE
00DA LATIN CAPITAL LETTER U WITH ACUTE
00DB LATIN CAPITAL LETTER U WITH CIRCUMFLEX
00DC LATIN CAPITAL LETTER U WITH DIAERESIS
00DD LATIN CAPITAL LETTER Y WITH ACUTE
00DE LATIN CAPITAL LETTER THORN
00DF LATIN SMALL LETTER SHARP S
00E0 LATIN SMALL LETTER A WITH GRAVE
00E1 LATIN SMALL LETTER A WITH ACUTE
00E2 LATIN SMALL LETTER A WITH CIRCUMFLEX
00E3 LATIN SMALL LETTER A WITH TILDE
00E4 LATIN SMALL LETTER A WITH DIAERESIS
00E5 LATIN SMALL LETTER A WITH RING ABOVE
00E6 LATIN SMALL LETTER AE
00E7 LATIN SMALL LETTER C WITH CEDILLA
00E8 LATIN SMALL LETTER E WITH GRAVE
00E9 LATIN SMALL LETTER E WITH ACUTE
00EA LATIN SMALL LETTER E WITH CIRCUMFLEX
00EB LATIN SMALL LETTER E WITH DIAERESIS
00EC LATIN SMALL LETTER I WITH GRAVE
00ED LATIN SMALL LETTER I WITH ACUTE
00EE LATIN SMALL LETTER I WITH CIRCUMFLEX
00EF LATIN SMALL LETTER I WITH DIAERESIS
00F0 LATIN SMALL LETTER ETH
00F1 LATIN SMALL LETTER N WITH TILDE
00F2 LATIN SMALL LETTER O WITH GRAVE
00F3 LATIN SMALL LETTER O WITH ACUTE
00F4 LATIN SMALL LETTER O WITH CIRCUMFLEX
00F5 LATIN SMALL LETTER O WITH TILDE
00F6 LATIN SMALL LETTER O WITH DIAERESIS
00F7 DIVISION SIGN
00F8 LATIN SMALL LETTER O WITH STROKE
00F9 LATIN SMALL LETTER U WITH GRAVE
00FA LATIN SMALL LETTER U WITH ACUTE
00FB LATIN SMALL LETTER U WITH CIRCUMFLEX
00FC LATIN SMALL LETTER U WITH DIAERESIS
00FD LATIN SMALL LETTER Y WITH ACUTE
00FE LATIN SMALL LETTER THORN
00FF LATIN SMALL LETTER Y WITH DIAERESIS
0100 LATIN CAPITAL LETTER A WITH MACRON
0101 LATIN SMALL LETTER A WITH MACRON
0102 LATIN CAPITAL LETTER A WITH BREVE
0103 LATIN SMALL LETTER A WITH BREVE
0104 LATIN CAPITAL LETTER A WITH OGONEK
0105 LATIN SMALL LETTER A WITH OGONEK
0106 LATIN CAPITAL LETTER C WITH ACUTE
0107 LATIN SMALL LETTER C WITH ACUTE
0108 LATIN CAPITAL LETTER C WITH CIRCUMFLEX
0109 LATIN SMALL LETTER C WITH CIRCUMFLEX
010A LATIN CAPITAL LETTER C WITH DOT ABOVE
010B LATIN SMALL LETTER C WITH DOT ABOVE
010C LATIN CAPITAL LETTER C WITH CARON
010D LATIN SMALL LETTER C WITH CARON
010E LATIN CAPITAL LETTER D WITH CARON
010F LATIN SMALL LETTER D WITH CARON
0110 LATIN CAPITAL LETTER D WITH STROKE
0111 LATIN SMALL LETTER D WITH STROKE
0112 LATIN CAPITAL LETTER E WITH MACRON
0113 LATIN SMALL LETTER E WITH MACRON
0114 LATIN CAPITAL LETTER E WITH BREVE
0115 LATIN SMALL LETTER E WITH BREVE
0116 LATIN CAPITAL LETTER E WITH DOT ABOVE
0117 LATIN SMALL LETTER E WITH DOT ABOVE
0118 LATIN CAPITAL LETTER E WITH OGONEK
0119 LATIN SMALL LETTER E WITH OGONEK
011A LATIN CAPITAL LETTER E WITH CARON
011B LATIN SMALL LETTER E WITH CARON
011C LATIN CAPITAL LETTER G WITH CIRCUMFLEX
011D LATIN SMALL LETTER G WITH CIRCUMFLEX
011E LATIN CAPITAL LETTER G WITH BREVE
011F LATIN SMALL LETTER G WITH BREVE
0120 LATIN CAPITAL LETTER G WITH DOT ABOVE
0121 LATIN SMALL LETTER G WITH DOT ABOVE
0122 LATIN CAPITAL LETTER G WITH CEDILLA
0123 LATIN SMALL LETTER G WITH CEDILLA
0124 LATIN CAPITAL LETTER H WITH CIRCUMFLEX
0125 LATIN SMALL LETTER H WITH CIRCUMFLEX
0126 LATIN CAPITAL LETTER H WITH STROKE
0127 LATIN SMALL LETTER H WITH STROKE
0128 LATIN CAPITAL LETTER I WITH TILDE
0129 LATIN SMALL LETTER I WITH TILDE
012A LATIN CAPITAL LETTER I WITH MACRON
012B LATIN SMALL LETTER I WITH MACRON
012C LATIN CAPITAL LETTER I WITH BREVE
012D LATIN SMALL LETTER I WITH BREVE
012E LATIN CAPITAL LETTER I WITH OGONEK
012F LATIN SMALL LETTER I WITH OGONEK
0130 LATIN CAPITAL LETTER I WITH DOT ABOVE
0131 LATIN SMALL LETTER DOTLESS I
0132 LATIN CAPITAL LIGATURE IJ
0133 LATIN SMALL LIGATURE IJ
0134 LATIN CAPITAL LETTER J WITH CIRCUMFLEX
0135 LATIN SMALL LETTER J WITH CIRCUMFLEX
0136 LATIN CAPITAL LETTER K WITH CEDILLA
0137 LATIN SMALL LETTER K WITH CEDILLA
0138 LATIN SMALL LETTER KRA
0139 LATIN CAPITAL LETTER L WITH ACUTE
013A LATIN SMALL LETTER L WITH ACUTE
013B LATIN CAPITAL LETTER L WITH CEDILLA
013C LATIN SMALL LETTER L WITH CEDILLA
013D LATIN CAPITAL LETTER L WITH CARON
013E LATIN SMALL LETTER L WITH CARON
013F LATIN CAPITAL LETTER L WITH MIDDLE DOT
0140 LATIN SMALL LETTER L WITH MIDDLE DOT
0141 LATIN CAPITAL LETTER L WITH STROKE
0142 LATIN SMALL LETTER L WITH STROKE
0143 LATIN CAPITAL LETTER N WITH ACUTE
0144 LATIN SMALL LETTER N WITH ACUTE
0145 LATIN CAPITAL LETTER N WITH CEDILLA
0146 LATIN SMALL LETTER N WITH CEDILLA
0147 LATIN CAPITAL LETTER N WITH CARON
0148 LATIN SMALL LETTER N WITH CARON
0149 LATIN SMALL LETTER N PRECEDED BY APOSTROPHE
014A LATIN CAPITAL LETTER ENG
014B LATIN SMALL LETTER ENG
014C LATIN CAPITAL LETTER O WITH MACRON
014D LATIN SMALL LETTER O WITH MACRON
014E LATIN CAPITAL LETTER O WITH BREVE
014F LATIN SMALL LETTER O WITH BREVE
0150 LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
0151 LATIN SMALL LETTER O WITH DOUBLE ACUTE
0152 LATIN CAPITAL LIGATURE OE
0153 LATIN SMALL LIGATURE OE
0154 LATIN CAPITAL LETTER R WITH ACUTE
0155 LATIN SMALL LETTER R WITH ACUTE
0156 LATIN CAPITAL LETTER R WITH CEDILLA
0157 LATIN SMALL LETTER R WITH CEDILLA
0158 LATIN CAPITAL LETTER R WITH CARON
0159 LATIN SMALL LETTER R WITH CARON
015A LATIN CAPITAL LETTER S WITH ACUTE
015B LATIN SMALL LETTER S WITH ACUTE
015C LATIN CAPITAL LETTER S WITH CIRCUMFLEX
015D LATIN SMALL LETTER S WITH CIRCUMFLEX
015E LATIN CAPITAL LETTER S WITH CEDILLA
015F LATIN SMALL LETTER S WITH CEDILLA
0160 LATIN CAPITAL LETTER S WITH CARON
0161 LATIN SMALL LETTER S WITH CARON
0162 LATIN CAPITAL LETTER T WITH CEDILLA
0163 LATIN SMALL LETTER T WITH CEDILLA
0164 LATIN CAPITAL LETTER T WITH CARON
0165 LATIN SMALL LETTER T WITH CARON
0166 LATIN CAPITAL LETTER T WITH STROKE
0167 LATIN SMALL LETTER T WITH STROKE
0168 LATIN CAPITAL LETTER U WITH TILDE
0169 LATIN SMALL LETTER U WITH TILDE
016A LATIN CAPITAL LETTER U WITH MACRON
016B LATIN SMALL LETTER U WITH MACRON
016C LATIN CAPITAL LETTER U WITH BREVE
016D LATIN SMALL LETTER U WITH BREVE
016E LATIN CAPITAL LETTER U WITH RING ABOVE
016F LATIN SMALL LETTER U WITH RING ABOVE
0170 LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
0171 LATIN SMALL LETTER U WITH DOUBLE ACUTE
0172 LATIN CAPITAL LETTER U WITH OGONEK
0173 LATIN SMALL LETTER U WITH OGONEK
0174 LATIN CAPITAL LETTER W WITH CIRCUMFLEX
0175 LATIN SMALL LETTER W WITH CIRCUMFLEX
0176 LATIN CAPITAL LETTER Y WITH CIRCUMFLEX
0177 LATIN SMALL LETTER Y WITH CIRCUMFLEX
0178 LATIN CAPITAL LETTER Y WITH DIAERESIS
0179 LATIN CAPITAL LETTER Z WITH ACUTE
017A LATIN SMALL LETTER Z WITH ACUTE
017B LATIN CAPITAL LETTER Z WITH DOT ABOVE
017C LATIN SMALL LETTER Z WITH DOT ABOVE
017D LATIN CAPITAL LETTER Z WITH CARON
017E LATIN SMALL LETTER Z WITH CARON
017F LATIN SMALL LETTER LONG S
0180 LATIN SMALL LETTER B WITH STROKE
0181 LATIN CAPITAL LETTER B WITH HOOK
0182 LATIN CAPITAL LETTER B WITH TOPBAR
0183 LATIN SMALL LETTER B WITH TOPBAR
0184 LATIN CAPITAL LETTER TONE SIX
0185 LATIN SMALL LETTER TONE SIX
0186 LATIN CAPITAL LETTER OPEN O
0187 LATIN CAPITAL LETTER C WITH HOOK
0188 LATIN SMALL LETTER C WITH HOOK
0189 LATIN CAPITAL LETTER AFRICAN D
018A LATIN CAPITAL LETTER D WITH HOOK
018B LATIN CAPITAL LETTER D WITH TOPBAR
018C LATIN SMALL LETTER D WITH TOPBAR
018D LATIN SMALL LETTER TURNED DELTA
018E LATIN CAPITAL LETTER REVERSED E
018F LATIN CAPITAL LETTER SCHWA
0190 LATIN CAPITAL LETTER OPEN E
0191 LATIN CAPITAL LETTER F WITH HOOK
0192 LATIN SMALL LETTER F WITH HOOK
0193 LATIN CAPITAL LETTER G WITH HOOK
0194 LATIN CAPITAL LETTER GAMMA
0195 LATIN SMALL LETTER HV
0196 LATIN CAPITAL LETTER IOTA
0197 LATIN CAPITAL LETTER I WITH STROKE
0198 LATIN CAPITAL LETTER K WITH HOOK
0199 LATIN SMALL LETTER K WITH HOOK
019A LATIN SMALL LETTER L WITH BAR
019B LATIN SMALL LETTER LAMBDA WITH STROKE
019C LATIN CAPITAL LETTER TURNED M
019D LATIN CAPITAL LETTER N WITH LEFT HOOK
019E LATIN SMALL LETTER N WITH LONG RIGHT LEG
019F LATIN CAPITAL LETTER O WITH MIDDLE TILDE
01A0 LATIN CAPITAL LETTER O WITH HORN
01A1 LATIN SMALL LETTER O WITH HORN
01A2 LATIN CAPITAL LETTER OI
01A3 LATIN SMALL LETTER OI
01A4 LATIN CAPITAL LETTER P WITH HOOK
01A5 LATIN SMALL LETTER P WITH HOOK
01A6 LATIN LETTER YR
01A7 LATIN CAPITAL LETTER TONE TWO
01A8 LATIN SMALL LETTER TONE TWO
01A9 LATIN CAPITAL LETTER ESH
01AA LATIN LETTER REVERSED ESH LOOP
01AB LATIN SMALL LETTER T WITH PALATAL HOOK
01AC LATIN CAPITAL LETTER T WITH HOOK
01AD LATIN SMALL LETTER T WITH HOOK
01AE LATIN CAPITAL LETTER T WITH RETROFLEX HOOK
01AF LATIN CAPITAL LETTER U WITH HORN
01B0 LATIN SMALL LETTER U WITH HORN
01B1 LATIN CAPITAL LETTER UPSILON
01B2 LATIN CAPITAL LETTER V WITH HOOK
01B3 LATIN CAPITAL LETTER Y WITH HOOK
01B4 LATIN SMALL LETTER Y WITH HOOK
01B5 LATIN CAPITAL LETTER Z WITH STROKE
01B6 LATIN SMALL LETTER Z WITH STROKE
01B7 LATIN CAPITAL LETTER EZH
01B8 LATIN CAPITAL LETTER EZH REVERSED
01B9 LATIN SMALL LETTER EZH REVERSED
01BA LATIN SMALL LETTER EZH WITH TAIL
01BB LATIN LETTER TWO WITH STROKE
01BC LATIN CAPITAL LETTER TONE FIVE
01BD LATIN SMALL LETTER TONE FIVE
01BE LATIN LETTER INVERTED GLOTTAL STOP WITH STROKE
01BF LATIN LETTER WYNN
01C0 LATIN LETTER DENTAL CLICK
01C1 LATIN LETTER LATERAL CLICK
01C2 LATIN LETTER ALVEOLAR CLICK
01C3 LATIN LETTER RETROFLEX CLICK
01C4 LATIN CAPITAL LETTER DZ WITH CARON
01C5 LATIN CAPITAL LETTER D WITH SMALL LETTER Z WITH CARON
01C6 LATIN SMALL LETTER DZ WITH CARON
01C7 LATIN CAPITAL LETTER LJ
01C8 LATIN CAPITAL LETTER L WITH SMALL LETTER J
01C9 LATIN SMALL LETTER LJ
01CA LATIN CAPITAL LETTER NJ
01CB LATIN CAPITAL LETTER N WITH SMALL LETTER J
01CC LATIN SMALL LETTER NJ
01CD LATIN CAPITAL LETTER A WITH CARON
01CE LATIN SMALL LETTER A WITH CARON
01CF LATIN CAPITAL LETTER I WITH CARON
01D0 LATIN SMALL LETTER I WITH CARON
01D1 LATIN CAPITAL LETTER O WITH CARON
01D2 LATIN SMALL LETTER O WITH CARON
01D3 LATIN CAPITAL LETTER U WITH CARON
01D4 LATIN SMALL LETTER U WITH CARON
01D5 LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
01D6 LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
01D7 LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
01D8 LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
01D9 LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
01DA LATIN SMALL LETTER U WITH DIAERESIS AND CARON
01DB LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
01DC LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
01DD LATIN SMALL LETTER TURNED E
01DE LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
01DF LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
01E0 LATIN CAPITAL LETTER A WITH DOT ABOVE AND MACRON
01E1 LATIN SMALL LETTER A WITH DOT ABOVE AND MACRON
01E2 LATIN CAPITAL LETTER AE WITH MACRON
01E3 LATIN SMALL LETTER AE WITH MACRON
01E4 LATIN CAPITAL LETTER G WITH STROKE
01E5 LATIN SMALL LETTER G WITH STROKE
01E6 LATIN CAPITAL LETTER G WITH CARON
01E7 LATIN SMALL LETTER G WITH CARON
01E8 LATIN CAPITAL LETTER K WITH CARON
01E9 LATIN SMALL LETTER K WITH CARON
01EA LATIN CAPITAL LETTER O WITH OGONEK
01EB LATIN SMALL LETTER O WITH OGONEK
01EC LATIN CAPITAL LETTER O WITH OGONEK AND MACRON
01ED LATIN SMALL LETTER O WITH OGONEK AND MACRON
01EE LATIN CAPITAL LETTER EZH WITH CARON
01EF LATIN SMALL LETTER EZH WITH CARON
01F0 LATIN SMALL LETTER J WITH CARON
01F1 LATIN CAPITAL LETTER DZ
01F2 LATIN CAPITAL LETTER D WITH SMALL LETTER Z
01F3 LATIN SMALL LETTER DZ
01F4 LATIN CAPITAL LETTER G WITH ACUTE
01F5 LATIN SMALL LETTER G WITH ACUTE
01F6 LATIN CAPITAL LETTER HWAIR
01F7 LATIN CAPITAL LETTER WYNN
01F8 LATIN CAPITAL LETTER N WITH GRAVE
01F9 LATIN SMALL LETTER N WITH GRAVE
01FA LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE
01FB LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE
01FC LATIN CAPITAL LETTER AE WITH ACUTE
01FD LATIN SMALL LETTER AE WITH ACUTE
01FE LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
01FF LATIN SMALL LETTER O WITH STROKE AND ACUTE
0200 LATIN CAPITAL LETTER A WITH DOUBLE GRAVE
0201 LATIN SMALL LETTER A WITH DOUBLE GRAVE
0202 LATIN CAPITAL LETTER A WITH INVERTED BREVE
0203 LATIN SMALL LETTER A WITH INVERTED BREVE
0204 LATIN CAPITAL LETTER E WITH DOUBLE GRAVE
0205 LATIN SMALL LETTER E WITH DOUBLE GRAVE
0206 LATIN CAPITAL LETTER E WITH INVERTED BREVE
0207 LATIN SMALL LETTER E WITH INVERTED BREVE
0208 LATIN CAPITAL LETTER I WITH DOUBLE GRAVE
0209 LATIN SMALL LETTER I WITH DOUBLE GRAVE
020A LATIN CAPITAL LETTER I WITH INVERTED BREVE
020B LATIN SMALL LETTER I WITH INVERTED BREVE
020C LATIN CAPITAL LETTER O WITH DOUBLE GRAVE
020D LATIN SMALL LETTER O WITH DOUBLE GRAVE
020E LATIN CAPITAL LETTER O WITH INVERTED BREVE
020F LATIN SMALL LETTER O WITH INVERTED BREVE
0210 LATIN CAPITAL LETTER R WITH DOUBLE GRAVE
0211 LATIN SMALL LETTER R WITH DOUBLE GRAVE
0212 LATIN CAPITAL LETTER R WITH INVERTED BREVE
0213 LATIN SMALL LETTER R WITH INVERTED BREVE
0214 LATIN CAPITAL LETTER U WITH DOUBLE GRAVE
0215 LATIN SMALL LETTER U WITH DOUBLE GRAVE
0216 LATIN CAPITAL LETTER U WITH INVERTED BREVE
0217 LATIN SMALL LETTER U WITH INVERTED BREVE
0218 LATIN CAPITAL LETTER S WITH COMMA BELOW
0219 LATIN SMALL LETTER S WITH COMMA BELOW
021A LATIN CAPITAL LETTER T WITH COMMA BELOW
021B LATIN SMALL LETTER T WITH COMMA BELOW
021C LATIN CAPITAL LETTER YOGH
021D LATIN SMALL LETTER YOGH
021E LATIN CAPITAL LETTER H WITH CARON
021F LATIN SMALL LETTER H WITH CARON
0220 LATIN CAPITAL LETTER N WITH LONG RIGHT LEG
0221 LATIN SMALL LETTER D WITH CURL
0222 LATIN CAPITAL LETTER OU
0223 LATIN SMALL LETTER OU
0224 LATIN CAPITAL LETTER Z WITH HOOK
0225 LATIN SMALL LETTER Z WITH HOOK
0226 LATIN CAPITAL LETTER A WITH DOT ABOVE
0227 LATIN SMALL LETTER A WITH DOT ABOVE
0228 LATIN CAPITAL LETTER E WITH CEDILLA
0229 LATIN SMALL LETTER E WITH CEDILLA
022A LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON
022B LATIN SMALL LETTER O WITH DIAERESIS AND MACRON
022C LATIN CAPITAL LETTER O WITH TILDE AND MACRON
022D LATIN SMALL LETTER O WITH TILDE AND MACRON
022E LATIN CAPITAL LETTER O WITH DOT ABOVE
022F LATIN SMALL LETTER O WITH DOT ABOVE
0230 LATIN CAPITAL LETTER O WITH DOT ABOVE AND MACRON
0231 LATIN SMALL LETTER O WITH DOT ABOVE AND MACRON
0232 LATIN CAPITAL LETTER Y WITH MACRON
0233 LATIN SMALL LETTER Y WITH MACRON
0234 LATIN SMALL LETTER L WITH CURL
0235 LATIN SMALL LETTER N WITH CURL
0236 LATIN SMALL LETTER T WITH CURL
0237 LATIN SMALL LETTER DOTLESS J
0238 LATIN SMALL LETTER DB DIGRAPH
0239 LATIN SMALL LETTER QP DIGRAPH
023A LATIN CAPITAL LETTER A WITH STROKE
023B LATIN CAPITAL LETTER C WITH STROKE
023C LATIN SMALL LETTER C WITH STROKE
023D LATIN CAPITAL LETTER L WITH BAR
023E LATIN CAPITAL LETTER T WITH DIAGONAL STROKE
023F LATIN SMALL LETTER S WITH SWASH TAIL
0240 LATIN SMALL LETTER Z WITH SWASH TAIL
0241 LATIN CAPITAL LETTER GLOTTAL STOP
0242 LATIN SMALL LETTER GLOTTAL STOP
0243 LATIN CAPITAL LETTER B WITH STROKE
0244 LATIN CAPITAL LETTER U BAR
0245 LATIN CAPITAL LETTER TURNED V
0246 LATIN CAPITAL LETTER E WITH STROKE
0247 LATIN SMALL LETTER E WITH STROKE
0248 LATIN CAPITAL LETTER J WITH STROKE
0249 LATIN SMALL LETTER J WITH STROKE
024A LATIN CAPITAL LETTER SMALL Q WITH HOOK TAIL
024B LATIN SMALL LETTER Q WITH HOOK TAIL
024C LATIN CAPITAL LETTER R WITH STROKE
024D LATIN SMALL LETTER R WITH STROKE
024E LATIN CAPITAL LETTER Y WITH STROKE
024F LATIN SMALL LETTER Y WITH STROKE
0250 LATIN SMALL LETTER TURNED A
0251 LATIN SMALL LETTER ALPHA
0252 LATIN SMALL LETTER TURNED ALPHA
0253 LATIN SMALL LETTER B WITH HOOK
0254 LATIN SMALL LETTER OPEN O
0255 LATIN SMALL LETTER C WITH CURL
0256 LATIN SMALL LETTER D WITH TAIL
0257 LATIN SMALL LETTER D WITH HOOK
0258 LATIN SMALL LETTER REVERSED E
0259 LATIN SMALL LETTER SCHWA
025A LATIN SMALL LETTER SCHWA WITH HOOK
025B LATIN SMALL LETTER OPEN E
025C LATIN SMALL LETTER REVERSED OPEN E
025D LATIN SMALL LETTER REVERSED OPEN E WITH HOOK
025E LATIN SMALL LETTER CLOSED REVERSED OPEN E
025F LATIN SMALL LETTER DOTLESS J WITH STROKE
0260 LATIN SMALL LETTER G WITH HOOK
0261 LATIN SMALL LETTER SCRIPT G
0262 LATIN LETTER SMALL CAPITAL G
0263 LATIN SMALL LETTER GAMMA
0264 LATIN SMALL LETTER RAMS HORN
0265 LATIN SMALL LETTER TURNED H
0266 LATIN SMALL LETTER H WITH HOOK
0267 LATIN SMALL LETTER HENG WITH HOOK
0268 LATIN SMALL LETTER I WITH STROKE
0269 LATIN SMALL LETTER IOTA
026A LATIN LETTER SMALL CAPITAL I
026B LATIN SMALL LETTER L WITH MIDDLE TILDE
026C LATIN SMALL LETTER L WITH BELT
026D LATIN SMALL LETTER L WITH RETROFLEX HOOK
026E LATIN SMALL LETTER LEZH
026F LATIN SMALL LETTER TURNED M
0270 LATIN SMALL LETTER TURNED M WITH LONG LEG
0271 LATIN SMALL LETTER M WITH HOOK
0272 LATIN SMALL LETTER N WITH LEFT HOOK
0273 LATIN SMALL LETTER N WITH RETROFLEX HOOK
0274 LATIN LETTER SMALL CAPITAL N
0275 LATIN SMALL LETTER BARRED O
0276 LATIN LETTER SMALL CAPITAL OE
0277 LATIN SMALL LETTER CLOSED OMEGA
0278 LATIN SMALL LETTER PHI
0279 LATIN SMALL LETTER TURNED R
027A LATIN SMALL LETTER TURNED R WITH LONG LEG
027B LATIN SMALL LETTER TURNED R WITH HOOK
027C LATIN SMALL LETTER R WITH LONG LEG
027D LATIN SMALL LETTER R WITH TAIL
027E LATIN SMALL LETTER R WITH FISHHOOK
027F LATIN SMALL LETTER REVERSED R WITH FISHHOOK
0280 LATIN LETTER SMALL CAPITAL R
0281 LATIN LETTER SMALL CAPITAL INVERTED R
0282 LATIN SMALL LETTER S WITH HOOK
0283 LATIN SMALL LETTER ESH
0284 LATIN SMALL LETTER DOTLESS J WITH STROKE AND HOOK
0285 LATIN SMALL LETTER SQUAT REVERSED ESH
0286 LATIN SMALL LETTER ESH WITH CURL
0287 LATIN SMALL LETTER TURNED T
0288 LATIN SMALL LETTER T WITH RETROFLEX HOOK
0289 LATIN SMALL LETTER U BAR
028A LATIN SMALL LETTER UPSILON
028B LATIN SMALL LETTER V WITH HOOK
028C LATIN SMALL LETTER TURNED V
028D LATIN SMALL LETTER TURNED W
028E LATIN SMALL LETTER TURNED Y
028F LATIN LETTER SMALL CAPITAL Y
0290 LATIN SMALL LETTER Z WITH RETROFLEX HOOK
0291 LATIN SMALL LETTER Z WITH CURL
0292 LATIN SMALL LETTER EZH
0293 LATIN SMALL LETTER EZH WITH CURL
0294 LATIN LETTER GLOTTAL STOP
0295 LATIN LETTER PHARYNGEAL VOICED FRICATIVE
0296 LATIN LETTER INVERTED GLOTTAL STOP
0297 LATIN LETTER STRETCHED C
0298 LATIN LETTER BILABIAL CLICK
0299 LATIN LETTER SMALL CAPITAL B
029A LATIN SMALL LETTER CLOSED OPEN E
029B LATIN LETTER SMALL CAPITAL G WITH HOOK
029C LATIN LETTER SMALL CAPITAL H
029D LATIN SMALL LETTER J WITH CROSSED-TAIL
029E LATIN SMALL LETTER TURNED K
029F LATIN LETTER SMALL CAPITAL L
02A0 LATIN SMALL LETTER Q WITH HOOK
02A1 LATIN LETTER GLOTTAL STOP WITH STROKE
02A2 LATIN LETTER REVERSED GLOTTAL STOP WITH STROKE
02A3 LATIN SMALL LETTER DZ DIGRAPH
02A4 LATIN SMALL LETTER DEZH DIGRAPH
02A5 LATIN SMALL LETTER DZ DIGRAPH WITH CURL
02A6 LATIN SMALL LETTER TS DIGRAPH
02A7 LATIN SMALL LETTER TESH DIGRAPH
02A8 LATIN SMALL LETTER TC DIGRAPH WITH CURL
02A9 LATIN SMALL LETTER FENG DIGRAPH
02AA LATIN SMALL LETTER LS DIGRAPH
02AB LATIN SMALL LETTER LZ DIGRAPH
02AC LATIN LETTER BILABIAL PERCUSSIVE
02AD LATIN LETTER BIDENTAL PERCUSSIVE
02AE LATIN SMALL LETTER TURNED H WITH FISHHOOK
02AF LATIN SMALL LETTER TURNED H WITH FISHHOOK AND TAIL
02B0 MODIFIER LETTER SMALL H
02B1 MODIFIER LETTER SMALL H WITH HOOK
02B2 MODIFIER LETTER SMALL J
02B3 MODIFIER LETTER SMALL R
02B4 MODIFIER LETTER SMALL TURNED R
02B5 MODIFIER LETTER SMALL TURNED R WITH HOOK
02B6 MODIFIER LETTER SMALL CAPITAL INVERTED R
02B7 MODIFIER LETTER SMALL W
02B8 MODIFIER LETTER SMALL Y
02B9 MODIFIER LETTER PRIME
02BA MODIFIER LETTER DOUBLE PRIME
02BB MODIFIER LETTER TURNED COMMA
02BC MODIFIER LETTER APOSTROPHE
02BD MODIFIER LETTER REVERSED COMMA
02BE MODIFIER LETTER RIGHT HALF RING
02BF MODIFIER LETTER LEFT HALF RING
02C0 MODIFIER LETTER GLOTTAL STOP
02C1 MODIFIER LETTER REVERSED GLOTTAL STOP
02C2 MODIFIER LETTER LEFT ARROWHEAD
02C3 MODIFIER LETTER RIGHT ARROWHEAD
02C4 MODIFIER LETTER UP ARROWHEAD
02C5 MODIFIER LETTER DOWN ARROWHEAD
02C6 MODIFIER LETTER CIRCUMFLEX ACCENT
02C7 CARON
02C8 MODIFIER LETTER VERTICAL LINE
02C9 MODIFIER LETTER MACRON
02CA MODIFIER LETTER ACUTE ACCENT
02CB MODIFIER LETTER GRAVE ACCENT
02CC MODIFIER LETTER LOW VERTICAL LINE
02CD MODIFIER LETTER LOW MACRON
02CE MODIFIER LETTER LOW GRAVE ACCENT
02CF MODIFIER LETTER LOW ACUTE ACCENT
02D0 MODIFIER LETTER TRIANGULAR COLON
02D1 MODIFIER LETTER HALF TRIANGULAR COLON
02D2 MODIFIER LETTER CENTRED RIGHT HALF RING
02D3 MODIFIER LETTER CENTRED LEFT HALF RING
02D4 MODIFIER LETTER UP TACK
02D5 MODIFIER LETTER DOWN TACK
02D6 MODIFIER LETTER PLUS SIGN
02D7 MODIFIER LETTER MINUS SIGN
02D8 BREVE
02D9 DOT ABOVE
02DA RING ABOVE
02DB OGONEK
02DC SMALL TILDE
02DD DOUBLE ACUTE ACCENT
02DE MODIFIER LETTER RHOTIC HOOK
02DF MODIFIER LETTER CROSS ACCENT
02E0 MODIFIER LETTER SMALL GAMMA
02E1 MODIFIER LETTER SMALL L
02E2 MODIFIER LETTER SMALL S
02E3 MODIFIER LETTER SMALL X
02E4 MODIFIER LETTER SMALL REVERSED GLOTTAL STOP
02E5 MODIFIER LETTER EXTRA-HIGH TONE BAR
02E6 MODIFIER LETTER HIGH TONE BAR
02E7 MODIFIER LETTER MID TONE BAR
02E8 MODIFIER LETTER LOW TONE BAR
02E9 MODIFIER LETTER EXTRA-LOW TONE BAR
02EA MODIFIER LETTER YIN DEPARTING TONE MARK
02EB MODIFIER LETTER YANG DEPARTING TONE MARK
02EC MODIFIER LETTER VOICING
02ED MODIFIER LETTER UNASPIRATED
02EE MODIFIER LETTER DOUBLE APOSTROPHE
02EF MODIFIER LETTER LOW DOWN ARROWHEAD
02F0 MODIFIER LETTER LOW UP ARROWHEAD
02F1 MODIFIER LETTER LOW LEFT ARROWHEAD
02F2 MODIFIER LETTER LOW RIGHT ARROWHEAD
02F3 MODIFIER LETTER LOW RING
02F4 MODIFIER LETTER MIDDLE GRAVE ACCENT
02F5 MODIFIER LETTER MIDDLE DOUBLE GRAVE ACCENT
02F6 MODIFIER LETTER MIDDLE DOUBLE ACUTE ACCENT
02F7 MODIFIER LETTER LOW TILDE
02F8 MODIFIER LETTER RAISED COLON
02F9 MODIFIER LETTER BEGIN HIGH TONE
02FA MODIFIER LETTER END HIGH TONE
02FB MODIFIER LETTER BEGIN LOW TONE
02FC MODIFIER LETTER END LOW TONE
02FD MODIFIER LETTER SHELF
02FE MODIFIER LETTER OPEN SHELF
02FF MODIFIER LETTER LOW LEFT ARROW
0300 COMBINING GRAVE ACCENT
0301 COMBINING ACUTE ACCENT
0302 COMBINING CIRCUMFLEX ACCENT
0303 COMBINING TILDE
0304 COMBINING MACRON
0305 COMBINING OVERLINE
0306 COMBINING BREVE
0307 COMBINING DOT ABOVE
0308 COMBINING DIAERESIS
0309 COMBINING HOOK ABOVE
030A COMBINING RING ABOVE
030B COMBINING DOUBLE ACUTE ACCENT
030C COMBINING CARON
030D COMBINING VERTICAL LINE ABOVE
030E COMBINING DOUBLE VERTICAL LINE ABOVE
030F COMBINING DOUBLE GRAVE ACCENT
0310 COMBINING CANDRABINDU
0311 COMBINING INVERTED BREVE
0312 COMBINING TURNED COMMA ABOVE
0313 COMBINING COMMA ABOVE
0314 COMBINING REVERSED COMMA ABOVE
0315 COMBINING COMMA ABOVE RIGHT
0316 COMBINING GRAVE ACCENT BELOW
0317 COMBINING ACUTE ACCENT BELOW
0318 COMBINING LEFT TACK BELOW
0319 COMBINING RIGHT TACK BELOW
031A COMBINING LEFT ANGLE ABOVE
031B COMBINING HORN
031C COMBINING LEFT HALF RING BELOW
031D COMBINING UP TACK BELOW
031E COMBINING DOWN TACK BELOW
031F COMBINING PLUS SIGN BELOW
0320 COMBINING MINUS SIGN BELOW
0321 COMBINING PALATALIZED HOOK BELOW
0322 COMBINING RETROFLEX HOOK BELOW
0323 COMBINING DOT BELOW
0324 COMBINING DIAERESIS BELOW
0325 COMBINING RING BELOW
0326 COMBINING COMMA BELOW
0327 COMBINING CEDILLA
0328 COMBINING OGONEK
0329 COMBINING VERTICAL LINE BELOW
032A COMBINING BRIDGE BELOW
032B COMBINING INVERTED DOUBLE ARCH BELOW
032C COMBINING CARON BELOW
032D COMBINING CIRCUMFLEX ACCENT BELOW
032E COMBINING BREVE BELOW
032F COMBINING INVERTED BREVE BELOW
0330 COMBINING TILDE BELOW
0331 COMBINING MACRON BELOW
0332 COMBINING LOW LINE
0333 COMBINING DOUBLE LOW LINE
0334 COMBINING TILDE OVERLAY
0335 COMBINING SHORT STROKE OVERLAY
0336 COMBINING LONG STROKE OVERLAY
0337 COMBINING SHORT SOLIDUS OVERLAY
0338 COMBINING LONG SOLIDUS OVERLAY
0339 COMBINING RIGHT HALF RING BELOW
033A COMBINING INVERTED BRIDGE BELOW
033B COMBINING SQUARE BELOW
033C COMBINING SEAGULL BELOW
033D COMBINING X ABOVE
033E COMBINING VERTICAL TILDE
033F COMBINING DOUBLE OVERLINE
0340 COMBINING GRAVE TONE MARK
0341 COMBINING ACUTE TONE MARK
0342 COMBINING GREEK PERISPOMENI
0343 COMBINING GREEK KORONIS
0344 COMBINING GREEK DIALYTIKA TONOS
0345 COMBINING GREEK YPOGEGRAMMENI
0346 COMBINING BRIDGE ABOVE
0347 COMBINING EQUALS SIGN BELOW
0348 COMBINING DOUBLE VERTICAL LINE BELOW
0349 COMBINING LEFT ANGLE BELOW
034A COMBINING NOT TILDE ABOVE
034B COMBINING HOMOTHETIC ABOVE
034C COMBINING ALMOST EQUAL TO ABOVE
034D COMBINING LEFT RIGHT ARROW BELOW
034E COMBINING UPWARDS ARROW BELOW
034F COMBINING GRAPHEME JOINER, CGJ
0350 COMBINING RIGHT ARROWHEAD ABOVE
0351 COMBINING LEFT HALF RING ABOVE
0352 COMBINING FERMATA
0353 COMBINING X BELOW
0354 COMBINING LEFT ARROWHEAD BELOW
0355 COMBINING RIGHT ARROWHEAD BELOW
0356 COMBINING RIGHT ARROWHEAD AND UP ARROWHEAD BELOW
0357 COMBINING RIGHT HALF RING ABOVE
0358 COMBINING DOT ABOVE RIGHT
0359 COMBINING ASTERISK BELOW
035A COMBINING DOUBLE RING BELOW
035B COMBINING ZIGZAG ABOVE
035C COMBINING DOUBLE BREVE BELOW
035D COMBINING DOUBLE BREVE
035E COMBINING DOUBLE MACRON
035F COMBINING DOUBLE MACRON BELOW
0360 COMBINING DOUBLE TILDE
0361 COMBINING DOUBLE INVERTED BREVE
0362 COMBINING DOUBLE RIGHTWARDS ARROW BELOW
0363 COMBINING LATIN SMALL LETTER A
0364 COMBINING LATIN SMALL LETTER E
0365 COMBINING LATIN SMALL LETTER I
0366 COMBINING LATIN SMALL LETTER O
0367 COMBINING LATIN SMALL LETTER U
0368 COMBINING LATIN SMALL LETTER C
0369 COMBINING LATIN SMALL LETTER D
036A COMBINING LATIN SMALL LETTER H
036B COMBINING LATIN SMALL LETTER M
036C COMBINING LATIN SMALL LETTER R
036D COMBINING LATIN SMALL LETTER T
036E COMBINING LATIN SMALL LETTER V
036F COMBINING LATIN SMALL LETTER X
0370 GREEK CAPITAL LETTER HETA
0371 GREEK SMALL LETTER HETA
0372 GREEK CAPITAL LETTER ARCHAIC SAMPI
0373 GREEK SMALL LETTER ARCHAIC SAMPI
0374 GREEK NUMERAL SIGN
0375 GREEK LOWER NUMERAL SIGN
0376 GREEK CAPITAL LETTER PAMPHYLIAN DIGAMMA
0377 GREEK SMALL LETTER PAMPHYLIAN DIGAMMA
037A GREEK YPOGEGRAMMENI
037B GREEK SMALL REVERSED LUNATE SIGMA SYMBOL
037C GREEK SMALL DOTTED LUNATE SIGMA SYMBOL
037D GREEK SMALL REVERSED DOTTED LUNATE SIGMA SYMBOL
037E GREEK QUESTION MARK
037F GREEK CAPITAL LETTER YOT
0384 GREEK TONOS
0385 GREEK DIALYTIKA TONOS
0386 GREEK CAPITAL LETTER ALPHA WITH TONOS
0387 GREEK ANO TELEIA
0388 GREEK CAPITAL LETTER EPSILON WITH TONOS
0389 GREEK CAPITAL LETTER ETA WITH TONOS
038A GREEK CAPITAL LETTER IOTA WITH TONOS
038C GREEK CAPITAL LETTER OMICRON WITH TONOS
038E GREEK CAPITAL LETTER UPSILON WITH TONOS
038F GREEK CAPITAL LETTER OMEGA WITH TONOS
0390 GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS
0391 GREEK CAPITAL LETTER ALPHA
0392 GREEK CAPITAL LETTER BETA
0393 GREEK CAPITAL LETTER GAMMA
0394 GREEK CAPITAL LETTER DELTA
0395 GREEK CAPITAL LETTER EPSILON
0396 GREEK CAPITAL LETTER ZETA
0397 GREEK CAPITAL LETTER ETA
0398 GREEK CAPITAL LETTER THETA
0399 GREEK CAPITAL LETTER IOTA
039A GREEK CAPITAL LETTER KAPPA
039B GREEK CAPITAL LETTER LAMDA
039C GREEK CAPITAL LETTER MU
039D GREEK CAPITAL LETTER NU
039E GREEK CAPITAL LETTER XI
039F GREEK CAPITAL LETTER OMICRON
03A0 GREEK CAPITAL LETTER PI
03A1 GREEK CAPITAL LETTER RHO
03A3 GREEK CAPITAL LETTER SIGMA
03A4 GREEK CAPITAL LETTER TAU
03A5 GREEK CAPITAL LETTER UPSILON
03A6 GREEK CAPITAL LETTER PHI
03A7 GREEK CAPITAL LETTER CHI
03A8 GREEK CAPITAL LETTER PSI
03A9 GREEK CAPITAL LETTER OMEGA
03AA GREEK CAPITAL LETTER IOTA WITH DIALYTIKA
03AB GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA
03AC GREEK SMALL LETTER ALPHA WITH TONOS
03AD GREEK SMALL LETTER EPSILON WITH TONOS
03AE GREEK SMALL LETTER ETA WITH TONOS
03AF GREEK SMALL LETTER IOTA WITH TONOS
03B0 GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS
03B1 GREEK SMALL LETTER ALPHA
03B2 GREEK SMALL LETTER BETA
03B3 GREEK SMALL LETTER GAMMA
03B4 GREEK SMALL LETTER DELTA
03B5 GREEK SMALL LETTER EPSILON
03B6 GREEK SMALL LETTER ZETA
03B7 GREEK SMALL LETTER ETA
03B8 GREEK SMALL LETTER THETA
03B9 GREEK SMALL LETTER IOTA
03BA GREEK SMALL LETTER KAPPA
03BB GREEK SMALL LETTER LAMDA
03BC GREEK SMALL LETTER MU
03BD GREEK SMALL LETTER NU
03BE GREEK SMALL LETTER XI
03BF GREEK SMALL LETTER OMICRON
03C0 GREEK SMALL LETTER PI
03C1 GREEK SMALL LETTER RHO
03C2 GREEK SMALL LETTER FINAL SIGMA
03C3 GREEK SMALL LETTER SIGMA
03C4 GREEK SMALL LETTER TAU
03C5 GREEK SMALL LETTER UPSILON
03C6 GREEK SMALL LETTER PHI
03C7 GREEK SMALL LETTER CHI
03C8 GREEK SMALL LETTER PSI
03C9 GREEK SMALL LETTER OMEGA
03CA GREEK SMALL LETTER IOTA WITH DIALYTIKA
03CB GREEK SMALL LETTER UPSILON WITH DIALYTIKA
03CC GREEK SMALL LETTER OMICRON WITH TONOS
03CD GREEK SMALL LETTER UPSILON WITH TONOS
03CE GREEK SMALL LETTER OMEGA WITH TONOS
03CF GREEK CAPITAL KAI SYMBOL
03D0 GREEK BETA SYMBOL
03D1 GREEK THETA SYMBOL
03D2 GREEK UPSILON WITH HOOK SYMBOL
03D3 GREEK UPSILON WITH ACUTE AND HOOK SYMBOL
03D4 GREEK UPSILON WITH DIAERESIS AND HOOK SYMBOL
03D5 GREEK PHI SYMBOL
03D6 GREEK PI SYMBOL
03D7 GREEK KAI SYMBOL
03D8 GREEK LETTER ARCHAIC KOPPA
03D9 GREEK SMALL LETTER ARCHAIC KOPPA
03DA GREEK LETTER STIGMA
03DB GREEK SMALL LETTER STIGMA
03DC GREEK LETTER DIGAMMA
03DD GREEK SMALL LETTER DIGAMMA
03DE GREEK LETTER KOPPA
03DF GREEK SMALL LETTER KOPPA
03E0 GREEK LETTER SAMPI
03E1 GREEK SMALL LETTER SAMPI
03E2 COPTIC CAPITAL LETTER SHEI
03E3 COPTIC SMALL LETTER SHEI
03E4 COPTIC CAPITAL LETTER FEI
03E5 COPTIC SMALL LETTER FEI
03E6 COPTIC CAPITAL LETTER KHEI
03E7 COPTIC SMALL LETTER KHEI
03E8 COPTIC CAPITAL LETTER HORI
03E9 COPTIC SMALL LETTER HORI
03EA COPTIC CAPITAL LETTER GANGIA
03EB COPTIC SMALL LETTER GANGIA
03EC COPTIC CAPITAL LETTER SHIMA
03ED COPTIC SMALL LETTER SHIMA
03EE COPTIC CAPITAL LETTER DEI
03EF COPTIC SMALL LETTER DEI
03F0 GREEK KAPPA SYMBOL
03F1 GREEK RHO SYMBOL
03F2 GREEK LUNATE SIGMA SYMBOL
03F3 GREEK LETTER YOT
03F4 GREEK CAPITAL THETA SYMBOL
03F5 GREEK LUNATE EPSILON SYMBOL
03F6 GREEK REVERSED LUNATE EPSILON SYMBOL
03F7 GREEK CAPITAL LETTER SHO
03F8 GREEK SMALL LETTER SHO
03F9 GREEK CAPITAL LUNATE SIGMA SYMBOL
03FA GREEK CAPITAL LETTER SAN
03FB GREEK SMALL LETTER SAN
03FC GREEK RHO WITH STROKE SYMBOL
03FD GREEK CAPITAL REVERSED LUNATE SIGMA SYMBOL
03FE GREEK CAPITAL DOTTED LUNATE SIGMA SYMBOL
03FF GREEK CAPITAL REVERSED DOTTED LUNATE SIGMA SYMBOL
0400 CYRILLIC CAPITAL LETTER IE WITH GRAVE
0401 CYRILLIC CAPITAL LETTER IO
0402 CYRILLIC CAPITAL LETTER DJE
0403 CYRILLIC CAPITAL LETTER GJE
0404 CYRILLIC CAPITAL LETTER UKRAINIAN IE
0405 CYRILLIC CAPITAL LETTER DZE
0406 CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I
0407 CYRILLIC CAPITAL LETTER YI
0408 CYRILLIC CAPITAL LETTER JE
0409 CYRILLIC CAPITAL LETTER LJE
040A CYRILLIC CAPITAL LETTER NJE
040B CYRILLIC CAPITAL LETTER TSHE
040C CYRILLIC CAPITAL LETTER KJE
040D CYRILLIC CAPITAL LETTER I WITH GRAVE
040E CYRILLIC CAPITAL LETTER SHORT U
040F CYRILLIC CAPITAL LETTER DZHE
0410 CYRILLIC CAPITAL LETTER A
0411 CYRILLIC CAPITAL LETTER BE
0412 CYRILLIC CAPITAL LETTER VE
0413 CYRILLIC CAPITAL LETTER GHE
0414 CYRILLIC CAPITAL LETTER DE
0415 CYRILLIC CAPITAL LETTER IE
0416 CYRILLIC CAPITAL LETTER ZHE
0417 CYRILLIC CAPITAL LETTER ZE
0418 CYRILLIC CAPITAL LETTER I
0419 CYRILLIC CAPITAL LETTER SHORT I
041A CYRILLIC CAPITAL LETTER KA
041B CYRILLIC CAPITAL LETTER EL
041C CYRILLIC CAPITAL LETTER EM
041D CYRILLIC CAPITAL LETTER EN
041E CYRILLIC CAPITAL LETTER O
041F CYRILLIC CAPITAL LETTER PE
0420 CYRILLIC CAPITAL LETTER ER
0421 CYRILLIC CAPITAL LETTER ES
0422 CYRILLIC CAPITAL LETTER TE
0423 CYRILLIC CAPITAL LETTER U
0424 CYRILLIC CAPITAL LETTER EF
0425 CYRILLIC CAPITAL LETTER HA
0426 CYRILLIC CAPITAL LETTER TSE
0427 CYRILLIC CAPITAL LETTER CHE
0428 CYRILLIC CAPITAL LETTER SHA
0429 CYRILLIC CAPITAL LETTER SHCHA
042A CYRILLIC CAPITAL LETTER HARD SIGN
042B CYRILLIC CAPITAL LETTER YERU
042C CYRILLIC CAPITAL LETTER SOFT SIGN
042D CYRILLIC CAPITAL LETTER E
042E CYRILLIC CAPITAL LETTER YU
042F CYRILLIC CAPITAL LETTER YA
0430 CYRILLIC SMALL LETTER A
0431 CYRILLIC SMALL LETTER BE
0432 CYRILLIC SMALL LETTER VE
0433 CYRILLIC SMALL LETTER GHE
0434 CYRILLIC SMALL LETTER DE
0435 CYRILLIC SMALL LETTER IE
0436 CYRILLIC SMALL LETTER ZHE
0437 CYRILLIC SMALL LETTER ZE
0438 CYRILLIC SMALL LETTER I
0439 CYRILLIC SMALL LETTER SHORT I
043A CYRILLIC SMALL LETTER KA
043B CYRILLIC SMALL LETTER EL
043C CYRILLIC SMALL LETTER EM
043D CYRILLIC SMALL LETTER EN
043E CYRILLIC SMALL LETTER O
043F CYRILLIC SMALL LETTER PE
0440 CYRILLIC SMALL LETTER ER
0441 CYRILLIC SMALL LETTER ES
0442 CYRILLIC SMALL LETTER TE
0443 CYRILLIC SMALL LETTER U
0444 CYRILLIC SMALL LETTER EF
0445 CYRILLIC SMALL LETTER HA
0446 CYRILLIC SMALL LETTER TSE
0447 CYRILLIC SMALL LETTER CHE
0448 CYRILLIC SMALL LETTER SHA
0449 CYRILLIC SMALL LETTER SHCHA
044A CYRILLIC SMALL LETTER HARD SIGN
044B CYRILLIC SMALL LETTER YERU
044C CYRILLIC SMALL LETTER SOFT SIGN
044D CYRILLIC SMALL LETTER E
044E CYRILLIC SMALL LETTER YU
044F CYRILLIC SMALL LETTER YA
0450 CYRILLIC SMALL LETTER IE WITH GRAVE
0451 CYRILLIC SMALL LETTER IO
0452 CYRILLIC SMALL LETTER DJE
0453 CYRILLIC SMALL LETTER GJE
0454 CYRILLIC SMALL LETTER UKRAINIAN IE
0455 CYRILLIC SMALL LETTER DZE
0456 CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I
0457 CYRILLIC SMALL LETTER YI
0458 CYRILLIC SMALL LETTER JE
0459 CYRILLIC SMALL LETTER LJE
045A CYRILLIC SMALL LETTER NJE
045B CYRILLIC SMALL LETTER TSHE
045C CYRILLIC SMALL LETTER KJE
045D CYRILLIC SMALL LETTER I WITH GRAVE
045E CYRILLIC SMALL LETTER SHORT U
045F CYRILLIC SMALL LETTER DZHE
0460 CYRILLIC CAPITAL LETTER OMEGA
0461 CYRILLIC SMALL LETTER OMEGA
0462 CYRILLIC CAPITAL LETTER YAT
0463 CYRILLIC SMALL LETTER YAT
0464 CYRILLIC CAPITAL LETTER IOTIFIED E
0465 CYRILLIC SMALL LETTER IOTIFIED E
0466 CYRILLIC CAPITAL LETTER LITTLE YUS
0467 CYRILLIC SMALL LETTER LITTLE YUS
0468 CYRILLIC CAPITAL LETTER IOTIFIED LITTLE YUS
0469 CYRILLIC SMALL LETTER IOTIFIED LITTLE YUS
046A CYRILLIC CAPITAL LETTER BIG YUS
046B CYRILLIC SMALL LETTER BIG YUS
046C CYRILLIC CAPITAL LETTER IOTIFIED BIG YUS
046D CYRILLIC SMALL LETTER IOTIFIED BIG YUS
046E CYRILLIC CAPITAL LETTER KSI
046F CYRILLIC SMALL LETTER KSI
0470 CYRILLIC CAPITAL LETTER PSI
0471 CYRILLIC SMALL LETTER PSI
0472 CYRILLIC CAPITAL LETTER FITA
0473 CYRILLIC SMALL LETTER FITA
0474 CYRILLIC CAPITAL LETTER IZHITSA
0475 CYRILLIC SMALL LETTER IZHITSA
0476 CYRILLIC CAPITAL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT
0477 CYRILLIC SMALL LETTER IZHITSA WITH DOUBLE GRAVE ACCENT
0478 CYRILLIC CAPITAL LETTER UK
0479 CYRILLIC SMALL LETTER UK
047A CYRILLIC CAPITAL LETTER ROUND OMEGA
047B CYRILLIC SMALL LETTER ROUND OMEGA
047C CYRILLIC CAPITAL LETTER OMEGA WITH TITLO
047D CYRILLIC SMALL LETTER OMEGA WITH TITLO
047E CYRILLIC CAPITAL LETTER OT
047F CYRILLIC SMALL LETTER OT
0480 CYRILLIC CAPITAL LETTER KOPPA
0481 CYRILLIC SMALL LETTER KOPPA
0482 CYRILLIC THOUSANDS SIGN
0483 COMBINING CYRILLIC TITLO
0484 COMBINING CYRILLIC PALATALIZATION
0485 COMBINING CYRILLIC DASIA PNEUMATA
0486 COMBINING CYRILLIC PSILI PNEUMATA
0487 COMBINING CYRILLIC POKRYTIE
0488 COMBINING CYRILLIC HUNDRED THOUSANDS SIGN
0489 COMBINING CYRILLIC MILLIONS SIGN
048A CYRILLIC CAPITAL LETTER SHORT I WITH TAIL
048B CYRILLIC SMALL LETTER SHORT I WITH TAIL
048C CYRILLIC CAPITAL LETTER SEMISOFT SIGN
048D CYRILLIC SMALL LETTER SEMISOFT SIGN
048E CYRILLIC CAPITAL LETTER ER WITH TICK
048F CYRILLIC SMALL LETTER ER WITH TICK
0490 CYRILLIC CAPITAL LETTER GHE WITH UPTURN
0491 CYRILLIC SMALL LETTER GHE WITH UPTURN
0492 CYRILLIC CAPITAL LETTER GHE WITH STROKE
0493 CYRILLIC SMALL LETTER GHE WITH STROKE
0494 CYRILLIC CAPITAL LETTER GHE WITH MIDDLE HOOK
0495 CYRILLIC SMALL LETTER GHE WITH MIDDLE HOOK
0496 CYRILLIC CAPITAL LETTER ZHE WITH DESCENDER
0497 CYRILLIC SMALL LETTER ZHE WITH DESCENDER
0498 CYRILLIC CAPITAL LETTER ZE WITH DESCENDER
0499 CYRILLIC SMALL LETTER ZE WITH DESCENDER
049A CYRILLIC CAPITAL LETTER KA WITH DESCENDER
049B CYRILLIC SMALL LETTER KA WITH DESCENDER
049C CYRILLIC CAPITAL LETTER KA WITH VERTICAL STROKE
049D CYRILLIC SMALL LETTER KA WITH VERTICAL STROKE
049E CYRILLIC CAPITAL LETTER KA WITH STROKE
049F CYRILLIC SMALL LETTER KA WITH STROKE
04A0 CYRILLIC CAPITAL LETTER BASHKIR KA
04A1 CYRILLIC SMALL LETTER BASHKIR KA
04A2 CYRILLIC CAPITAL LETTER EN WITH DESCENDER
04A3 CYRILLIC SMALL LETTER EN WITH DESCENDER
04A4 CYRILLIC CAPITAL LIGATURE EN GHE
04A5 CYRILLIC SMALL LIGATURE EN GHE
04A6 CYRILLIC CAPITAL LETTER PE WITH MIDDLE HOOK
04A7 CYRILLIC SMALL LETTER PE WITH MIDDLE HOOK
04A8 CYRILLIC CAPITAL LETTER ABKHASIAN HA
04A9 CYRILLIC SMALL LETTER ABKHASIAN HA
04AA CYRILLIC CAPITAL LETTER ES WITH DESCENDER
04AB CYRILLIC SMALL LETTER ES WITH DESCENDER
04AC CYRILLIC CAPITAL LETTER TE WITH DESCENDER
04AD CYRILLIC SMALL LETTER TE WITH DESCENDER
04AE CYRILLIC CAPITAL LETTER STRAIGHT U
04AF CYRILLIC SMALL LETTER STRAIGHT U
04B0 CYRILLIC CAPITAL LETTER STRAIGHT U WITH STROKE
04B1 CYRILLIC SMALL LETTER STRAIGHT U WITH STROKE
04B2 CYRILLIC CAPITAL LETTER HA WITH DESCENDER
04B3 CYRILLIC SMALL LETTER HA WITH DESCENDER
04B4 CYRILLIC CAPITAL LIGATURE TE TSE
04B5 CYRILLIC SMALL LIGATURE TE TSE
04B6 CYRILLIC CAPITAL LETTER CHE WITH DESCENDER
04B7 CYRILLIC SMALL LETTER CHE WITH DESCENDER
04B8 CYRILLIC CAPITAL LETTER CHE WITH VERTICAL STROKE
04B9 CYRILLIC SMALL LETTER CHE WITH VERTICAL STROKE
04BA CYRILLIC CAPITAL LETTER SHHA
04BB CYRILLIC SMALL LETTER SHHA
04BC CYRILLIC CAPITAL LETTER ABKHASIAN CHE
04BD CYRILLIC SMALL LETTER ABKHASIAN CHE
04BE CYRILLIC CAPITAL LETTER ABKHASIAN CHE WITH DESCENDER
04BF CYRILLIC SMALL LETTER ABKHASIAN CHE WITH DESCENDER
04C0 CYRILLIC LETTER PALOCHKA
04C1 CYRILLIC CAPITAL LETTER ZHE WITH BREVE
04C2 CYRILLIC SMALL LETTER ZHE WITH BREVE
04C3 CYRILLIC CAPITAL LETTER KA WITH HOOK
04C4 CYRILLIC SMALL LETTER KA WITH HOOK
04C5 CYRILLIC CAPITAL LETTER EL WITH TAIL
04C6 CYRILLIC SMALL LETTER EL WITH TAIL
04C7 CYRILLIC CAPITAL LETTER EN WITH HOOK
04C8 CYRILLIC SMALL LETTER EN WITH HOOK
04C9 CYRILLIC CAPITAL LETTER EN WITH TAIL
04CA CYRILLIC SMALL LETTER EN WITH TAIL
04CB CYRILLIC CAPITAL LETTER KHAKASSIAN CHE
04CC CYRILLIC SMALL LETTER KHAKASSIAN CHE
04CD CYRILLIC CAPITAL LETTER EM WITH TAIL
04CE CYRILLIC SMALL LETTER EM WITH TAIL
04CF CYRILLIC SMALL LETTER PALOCHKA
04D0 CYRILLIC CAPITAL LETTER A WITH BREVE
04D1 CYRILLIC SMALL LETTER A WITH BREVE
04D2 CYRILLIC CAPITAL LETTER A WITH DIAERESIS
04D3 CYRILLIC SMALL LETTER A WITH DIAERESIS
04D4 CYRILLIC CAPITAL LIGATURE A IE
04D5 CYRILLIC SMALL LIGATURE A IE
04D6 CYRILLIC CAPITAL LETTER IE WITH BREVE
04D7 CYRILLIC SMALL LETTER IE WITH BREVE
04D8 CYRILLIC CAPITAL LETTER SCHWA
04D9 CYRILLIC SMALL LETTER SCHWA
04DA CYRILLIC CAPITAL LETTER SCHWA WITH DIAERESIS
04DB CYRILLIC SMALL LETTER SCHWA WITH DIAERESIS
04DC CYRILLIC CAPITAL LETTER ZHE WITH DIAERESIS
04DD CYRILLIC SMALL LETTER ZHE WITH DIAERESIS
04DE CYRILLIC CAPITAL LETTER ZE WITH DIAERESIS
04DF CYRILLIC SMALL LETTER ZE WITH DIAERESIS
04E0 CYRILLIC CAPITAL LETTER ABKHASIAN DZE
04E1 CYRILLIC SMALL LETTER ABKHASIAN DZE
04E2 CYRILLIC CAPITAL LETTER I WITH MACRON
04E3 CYRILLIC SMALL LETTER I WITH MACRON
04E4 CYRILLIC CAPITAL LETTER I WITH DIAERESIS
04E5 CYRILLIC SMALL LETTER I WITH DIAERESIS
04E6 CYRILLIC CAPITAL LETTER O WITH DIAERESIS
04E7 CYRILLIC SMALL LETTER O WITH DIAERESIS
04E8 CYRILLIC CAPITAL LETTER BARRED O
04E9 CYRILLIC SMALL LETTER BARRED O
04EA CYRILLIC CAPITAL LETTER BARRED O WITH DIAERESIS
04EB CYRILLIC SMALL LETTER BARRED O WITH DIAERESIS
04EC CYRILLIC CAPITAL LETTER E WITH DIAERESIS
04ED CYRILLIC SMALL LETTER E WITH DIAERESIS
04EE CYRILLIC CAPITAL LETTER U WITH MACRON
04EF CYRILLIC SMALL LETTER U WITH MACRON
04F0 CYRILLIC CAPITAL LETTER U WITH DIAERESIS
04F1 CYRILLIC SMALL LETTER U WITH DIAERESIS
04F2 CYRILLIC CAPITAL LETTER U WITH DOUBLE ACUTE
04F3 CYRILLIC SMALL LETTER U WITH DOUBLE ACUTE
04F4 CYRILLIC CAPITAL LETTER CHE WITH DIAERESIS
04F5 CYRILLIC SMALL LETTER CHE WITH DIAERESIS
04F6 CYRILLIC CAPITAL LETTER GHE WITH DESCENDER
04F7 CYRILLIC SMALL LETTER GHE WITH DESCENDER
04F8 CYRILLIC CAPITAL LETTER YERU WITH DIAERESIS
04F9 CYRILLIC SMALL LETTER YERU WITH DIAERESIS
04FA CYRILLIC CAPITAL LETTER GHE WITH STROKE AND HOOK
04FB CYRILLIC SMALL LETTER GHE WITH STROKE AND HOOK
04FC CYRILLIC CAPITAL LETTER HA WITH HOOK
04FD CYRILLIC SMALL LETTER HA WITH HOOK
04FE CYRILLIC CAPITAL LETTER HA WITH STROKE
04FF CYRILLIC SMALL LETTER HA WITH STROKE
0500 CYRILLIC CAPITAL LETTER KOMI DE
0501 CYRILLIC SMALL LETTER KOMI DE
0502 CYRILLIC CAPITAL LETTER KOMI DJE
0503 CYRILLIC SMALL LETTER KOMI DJE
0504 CYRILLIC CAPITAL LETTER KOMI ZJE
0505 CYRILLIC SMALL LETTER KOMI ZJE
0506 CYRILLIC CAPITAL LETTER KOMI DZJE
0507 CYRILLIC SMALL LETTER KOMI DZJE
0508 CYRILLIC CAPITAL LETTER KOMI LJE
0509 CYRILLIC SMALL LETTER KOMI LJE
050A CYRILLIC CAPITAL LETTER KOMI NJE
050B CYRILLIC SMALL LETTER KOMI NJE
050C CYRILLIC CAPITAL LETTER KOMI SJE
050D CYRILLIC SMALL LETTER KOMI SJE
050E CYRILLIC CAPITAL LETTER KOMI TJE
050F CYRILLIC SMALL LETTER KOMI TJE
0510 CYRILLIC CAPITAL LETTER REVERSED ZE
0511 CYRILLIC SMALL LETTER REVERSED ZE
0512 CYRILLIC CAPITAL LETTER EL WITH HOOK
0513 CYRILLIC SMALL LETTER EL WITH HOOK
0514 CYRILLIC CAPITAL LETTER LHA
0515 CYRILLIC SMALL LETTER LHA
0516 CYRILLIC CAPITAL LETTER RHA
0517 CYRILLIC SMALL LETTER RHA
0518 CYRILLIC CAPITAL LETTER YAE
0519 CYRILLIC SMALL LETTER YAE
051A CYRILLIC CAPITAL LETTER QA
051B CYRILLIC SMALL LETTER QA
051C CYRILLIC CAPITAL LETTER WE
051D CYRILLIC SMALL LETTER WE
051E CYRILLIC CAPITAL LETTER ALEUT KA
051F CYRILLIC SMALL LETTER ALEUT KA
0520 CYRILLIC CAPITAL LETTER EL WITH MIDDLE HOOK
0521 CYRILLIC SMALL LETTER EL WITH MIDDLE HOOK
0522 CYRILLIC CAPITAL LETTER EN WITH MIDDLE HOOK
0523 CYRILLIC SMALL LETTER EN WITH MIDDLE HOOK
0524 CYRILLIC CAPITAL LETTER PE WITH DESCENDER
0525 CYRILLIC SMALL LETTER PE WITH DESCENDER
0526 CYRILLIC CAPITAL LETTER SHHA WITH DESCENDER
0527 CYRILLIC SMALL LETTER SHHA WITH DESCENDER
0528 CYRILLIC CAPITAL LETTER EN WITH LEFT HOOK
0529 CYRILLIC SMALL LETTER EN WITH LEFT HOOK
052A CYRILLIC CAPITAL LETTER DZZHE
052B CYRILLIC SMALL LETTER DZZHE
052C CYRILLIC CAPITAL LETTER DCHE
052D CYRILLIC SMALL LETTER DCHE
052E CYRILLIC CAPITAL LETTER EL WITH DESCENDER
052F CYRILLIC SMALL LETTER EL WITH DESCENDER
0531 ARMENIAN CAPITAL LETTER AYB
0532 ARMENIAN CAPITAL LETTER BEN
0533 ARMENIAN CAPITAL LETTER GIM
0534 ARMENIAN CAPITAL LETTER DA
0535 ARMENIAN CAPITAL LETTER ECH
0536 ARMENIAN CAPITAL LETTER ZA
0537 ARMENIAN CAPITAL LETTER EH
0538 ARMENIAN CAPITAL LETTER ET
0539 ARMENIAN CAPITAL LETTER TO
053A ARMENIAN CAPITAL LETTER ZHE
053B ARMENIAN CAPITAL LETTER INI
053C ARMENIAN CAPITAL LETTER LIWN
053D ARMENIAN CAPITAL LETTER XEH
053E ARMENIAN CAPITAL LETTER CA
053F ARMENIAN CAPITAL LETTER KEN
0540 ARMENIAN CAPITAL LETTER HO
0541 ARMENIAN CAPITAL LETTER JA
0542 ARMENIAN CAPITAL LETTER GHAD
0543 ARMENIAN CAPITAL LETTER CHEH
0544 ARMENIAN CAPITAL LETTER MEN
0545 ARMENIAN CAPITAL LETTER YI
0546 ARMENIAN CAPITAL LETTER NOW
0547 ARMENIAN CAPITAL LETTER SHA
0548 ARMENIAN CAPITAL LETTER VO
0549 ARMENIAN CAPITAL LETTER CHA
054A ARMENIAN CAPITAL LETTER PEH
054B ARMENIAN CAPITAL LETTER JHEH
054C ARMENIAN CAPITAL LETTER RA
054D ARMENIAN CAPITAL LETTER SEH
054E ARMENIAN CAPITAL LETTER VEW
054F ARMENIAN CAPITAL LETTER TIWN
0550 ARMENIAN CAPITAL LETTER REH
0551 ARMENIAN CAPITAL LETTER CO
0552 ARMENIAN CAPITAL LETTER YIWN
0553 ARMENIAN CAPITAL LETTER PIWR
0554 ARMENIAN CAPITAL LETTER KEH
0555 ARMENIAN CAPITAL LETTER OH
0556 ARMENIAN CAPITAL LETTER FEH
0559 ARMENIAN MODIFIER LETTER LEFT HALF RING
055A ARMENIAN APOSTROPHE
055B ARMENIAN EMPHASIS MARK
055C ARMENIAN EXCLAMATION MARK
055D ARMENIAN COMMA
055E ARMENIAN QUESTION MARK
055F ARMENIAN ABBREVIATION MARK
0561 ARMENIAN SMALL LETTER AYB
0562 ARMENIAN SMALL LETTER BEN
0563 ARMENIAN SMALL LETTER GIM
0564 ARMENIAN SMALL LETTER DA
0565 ARMENIAN SMALL LETTER ECH
0566 ARMENIAN SMALL LETTER ZA
0567 ARMENIAN SMALL LETTER EH
0568 ARMENIAN SMALL LETTER ET
0569 ARMENIAN SMALL LETTER TO
056A ARMENIAN SMALL LETTER ZHE
056B ARMENIAN SMALL LETTER INI
056C ARMENIAN SMALL LETTER LIWN
056D ARMENIAN SMALL LETTER XEH
056E ARMENIAN SMALL LETTER CA
056F ARMENIAN SMALL LETTER KEN
0570 ARMENIAN SMALL LETTER HO
0571 ARMENIAN SMALL LETTER JA
0572 ARMENIAN SMALL LETTER GHAD
0573 ARMENIAN SMALL LETTER CHEH
0574 ARMENIAN SMALL LETTER MEN
0575 ARMENIAN SMALL LETTER YI
0576 ARMENIAN SMALL LETTER NOW
0577 ARMENIAN SMALL LETTER SHA
0578 ARMENIAN SMALL LETTER VO
0579 ARMENIAN SMALL LETTER CHA
057A ARMENIAN SMALL LETTER PEH
057B ARMENIAN SMALL LETTER JHEH
057C ARMENIAN SMALL LETTER RA
057D ARMENIAN SMALL LETTER SEH
057E ARMENIAN SMALL LETTER VEW
057F ARMENIAN SMALL LETTER TIWN
0580 ARMENIAN SMALL LETTER REH
0581 ARMENIAN SMALL LETTER CO
0582 ARMENIAN SMALL LETTER YIWN
0583 ARMENIAN SMALL LETTER PIWR
0584 ARMENIAN SMALL LETTER KEH
0585 ARMENIAN SMALL LETTER OH
0586 ARMENIAN SMALL LETTER FEH
0587 ARMENIAN SMALL LIGATURE ECH YIWN
0589 ARMENIAN FULL STOP
058A ARMENIAN HYPHEN
058D RIGHT-FACING ARMENIAN ETERNITY SIGN
058E LEFT-FACING ARMENIAN ETERNITY SIGN
058F ARMENIAN DRAM SIGN
0591 HEBREW ACCENT ETNAHTA
0592 HEBREW ACCENT SEGOL
0593 HEBREW ACCENT SHALSHELET
0594 HEBREW ACCENT ZAQEF QATAN
0595 HEBREW ACCENT ZAQEF GADOL
0596 HEBREW ACCENT TIPEHA
0597 HEBREW ACCENT REVIA
0598 HEBREW ACCENT ZARQA
0599 HEBREW ACCENT PASHTA
059A HEBREW ACCENT YETIV
059B HEBREW ACCENT TEVIR
059C HEBREW ACCENT GERESH
059D HEBREW ACCENT GERESH MUQDAM
059E HEBREW ACCENT GERSHAYIM
059F HEBREW ACCENT QARNEY PARA
05A0 HEBREW ACCENT TELISHA GEDOLA
05A1 HEBREW ACCENT PAZER
05A2 HEBREW ACCENT ATNAH HAFUKH
05A3 HEBREW ACCENT MUNAH
05A4 HEBREW ACCENT MAHAPAKH
05A5 HEBREW ACCENT MERKHA
05A6 HEBREW ACCENT MERKHA KEFULA
05A7 HEBREW ACCENT DARGA
05A8 HEBREW ACCENT QADMA
05A9 HEBREW ACCENT TELISHA QETANA
05AA HEBREW ACCENT YERAH BEN YOMO
05AB HEBREW ACCENT OLE
05AC HEBREW ACCENT ILUY
05AD HEBREW ACCENT DEHI
05AE HEBREW ACCENT ZINOR
05AF HEBREW MARK MASORA CIRCLE
05B0 HEBREW POINT SHEVA
05B1 HEBREW POINT HATAF SEGOL
05B2 HEBREW POINT HATAF PATAH
05B3 HEBREW POINT HATAF QAMATS
05B4 HEBREW POINT HIRIQ
05B5 HEBREW POINT TSERE
05B6 HEBREW POINT SEGOL
05B7 HEBREW POINT PATAH
05B8 HEBREW POINT QAMATS
05B9 HEBREW POINT HOLAM
05BA HEBREW POINT HOLAM HASER FOR VAV
05BB HEBREW POINT QUBUTS
05BC HEBREW POINT DAGESH OR MAPIQ
05BD HEBREW POINT METEG
05BE HEBREW PUNCTUATION MAQAF
05BF HEBREW POINT RAFE
05C0 HEBREW PUNCTUATION PASEQ
05C1 HEBREW POINT SHIN DOT
05C2 HEBREW POINT SIN DOT
05C3 HEBREW PUNCTUATION SOF PASUQ
05C4 HEBREW MARK UPPER DOT
05C5 HEBREW MARK LOWER DOT
05C6 HEBREW PUNCTUATION NUN HAFUKHA
05C7 HEBREW POINT QAMATS QATAN
05D0 HEBREW LETTER ALEF
05D1 HEBREW LETTER BET
05D2 HEBREW LETTER GIMEL
05D3 HEBREW LETTER DALET
05D4 HEBREW LETTER HE
05D5 HEBREW LETTER VAV
05D6 HEBREW LETTER ZAYIN
05D7 HEBREW LETTER HET
05D8 HEBREW LETTER TET
05D9 HEBREW LETTER YOD
05DA HEBREW LETTER FINAL KAF
05DB HEBREW LETTER KAF
05DC HEBREW LETTER LAMED
05DD HEBREW LETTER FINAL MEM
05DE HEBREW LETTER MEM
05DF HEBREW LETTER FINAL NUN
05E0 HEBREW LETTER NUN
05E1 HEBREW LETTER SAMEKH
05E2 HEBREW LETTER AYIN
05E3 HEBREW LETTER FINAL PE
05E4 HEBREW LETTER PE
05E5 HEBREW LETTER FINAL TSADI
05E6 HEBREW LETTER TSADI
05E7 HEBREW LETTER QOF
05E8 HEBREW LETTER RESH
05E9 HEBREW LETTER SHIN
05EA HEBREW LETTER TAV
05F0 HEBREW LIGATURE YIDDISH DOUBLE VAV
05F1 HEBREW LIGATURE YIDDISH VAV YOD
05F2 HEBREW LIGATURE YIDDISH DOUBLE YOD
05F3 HEBREW PUNCTUATION GERESH
05F4 HEBREW PUNCTUATION GERSHAYIM
0600 ARABIC NUMBER SIGN
0601 ARABIC SIGN SANAH
0602 ARABIC FOOTNOTE MARKER
0603 ARABIC SIGN SAFHA
0604 ARABIC SIGN SAMVAT
0605 ARABIC NUMBER MARK ABOVE
0606 ARABIC-INDIC CUBE ROOT
0607 ARABIC-INDIC FOURTH ROOT
0608 ARABIC RAY
0609 ARABIC-INDIC PER MILLE SIGN
060A ARABIC-INDIC PER TEN THOUSAND SIGN
060B AFGHANI SIGN
060C ARABIC COMMA
060D ARABIC DATE SEPARATOR
060E ARABIC POETIC VERSE SIGN
060F ARABIC SIGN MISRA
0610 ARABIC SIGN SALLALLAHOU ALAYHE WASSALLAM
0611 ARABIC SIGN ALAYHE ASSALLAM
0612 ARABIC SIGN RAHMATULLAH ALAYHE
0613 ARABIC SIGN RADI ALLAHOU ANHU
0614 ARABIC SIGN TAKHALLUS
0615 ARABIC SMALL HIGH TAH
0616 ARABIC SMALL HIGH LIGATURE ALEF WITH LAM WITH YEH
0617 ARABIC SMALL HIGH ZAIN
0618 ARABIC SMALL FATHA
0619 ARABIC SMALL DAMMA
061A ARABIC SMALL KASRA
061B ARABIC SEMICOLON
061C ARABIC LETTER MARK, ALM
061E ARABIC TRIPLE DOT PUNCTUATION MARK
061F ARABIC QUESTION MARK
0620 ARABIC LETTER KASHMIRI YEH
0621 ARABIC LETTER HAMZA
0622 ARABIC LETTER ALEF WITH MADDA ABOVE
0623 ARABIC LETTER ALEF WITH HAMZA ABOVE
0624 ARABIC LETTER WAW WITH HAMZA ABOVE
0625 ARABIC LETTER ALEF WITH HAMZA BELOW
0626 ARABIC LETTER YEH WITH HAMZA ABOVE
0627 ARABIC LETTER ALEF
0628 ARABIC LETTER BEH
0629 ARABIC LETTER TEH MARBUTA
062A ARABIC LETTER TEH
062B ARABIC LETTER THEH
062C ARABIC LETTER JEEM
062D ARABIC LETTER HAH
062E ARABIC LETTER KHAH
062F ARABIC LETTER DAL
0630 ARABIC LETTER THAL
0631 ARABIC LETTER REH
0632 ARABIC LETTER ZAIN
0633 ARABIC LETTER SEEN
0634 ARABIC LETTER SHEEN
0635 ARABIC LETTER SAD
0636 ARABIC LETTER DAD
0637 ARABIC LETTER TAH
0638 ARABIC LETTER ZAH
0639 ARABIC LETTER AIN
063A ARABIC LETTER GHAIN
063B ARABIC LETTER KEHEH WITH TWO DOTS ABOVE
063C ARABIC LETTER KEHEH WITH THREE DOTS BELOW
063D ARABIC LETTER FARSI YEH WITH INVERTED V
063E ARABIC LETTER FARSI YEH WITH TWO DOTS ABOVE
063F ARABIC LETTER FARSI YEH WITH THREE DOTS ABOVE
0640 ARABIC TATWEEL
0641 ARABIC LETTER FEH
0642 ARABIC LETTER QAF
0643 ARABIC LETTER KAF
0644 ARABIC LETTER LAM
0645 ARABIC LETTER MEEM
0646 ARABIC LETTER NOON
0647 ARABIC LETTER HEH
0648 ARABIC LETTER WAW
0649 ARABIC LETTER ALEF MAKSURA
064A ARABIC LETTER YEH
064B ARABIC FATHATAN
064C ARABIC DAMMATAN
064D ARABIC KASRATAN
064E ARABIC FATHA
064F ARABIC DAMMA
0650 ARABIC KASRA
0651 ARABIC SHADDA
0652 ARABIC SUKUN
0653 ARABIC MADDAH ABOVE
0654 ARABIC HAMZA ABOVE
0655 ARABIC HAMZA BELOW
0656 ARABIC SUBSCRIPT ALEF
0657 ARABIC INVERTED DAMMA
0658 ARABIC MARK NOON GHUNNA
0659 ARABIC ZWARAKAY
065A ARABIC VOWEL SIGN SMALL V ABOVE
065B ARABIC VOWEL SIGN INVERTED SMALL V ABOVE
065C ARABIC VOWEL SIGN DOT BELOW
065D ARABIC REVERSED DAMMA
065E ARABIC FATHA WITH TWO DOTS
065F ARABIC WAVY HAMZA BELOW
0660 ARABIC-INDIC DIGIT ZERO
0661 ARABIC-INDIC DIGIT ONE
0662 ARABIC-INDIC DIGIT TWO
0663 ARABIC-INDIC DIGIT THREE
0664 ARABIC-INDIC DIGIT FOUR
0665 ARABIC-INDIC DIGIT FIVE
0666 ARABIC-INDIC DIGIT SIX
0667 ARABIC-INDIC DIGIT SEVEN
0668 ARABIC-INDIC DIGIT EIGHT
0669 ARABIC-INDIC DIGIT NINE
066A ARABIC PERCENT SIGN
066B ARABIC DECIMAL SEPARATOR
066C ARABIC THOUSANDS SEPARATOR
066D ARABIC FIVE POINTED STAR
066E ARABIC LETTER DOTLESS BEH
066F ARABIC LETTER DOTLESS QAF
0670 ARABIC LETTER SUPERSCRIPT ALEF
0671 ARABIC LETTER ALEF WASLA
0672 ARABIC LETTER ALEF WITH WAVY HAMZA ABOVE
0673 ARABIC LETTER ALEF WITH WAVY HAMZA BELOW
0674 ARABIC LETTER HIGH HAMZA
0675 ARABIC LETTER HIGH HAMZA ALEF
0676 ARABIC LETTER HIGH HAMZA WAW
0677 ARABIC LETTER U WITH HAMZA ABOVE
0678 ARABIC LETTER HIGH HAMZA YEH
0679 ARABIC LETTER TTEH
067A ARABIC LETTER TTEHEH
067B ARABIC LETTER BEEH
067C ARABIC LETTER TEH WITH RING
067D ARABIC LETTER TEH WITH THREE DOTS ABOVE DOWNWARDS
067E ARABIC LETTER PEH
067F ARABIC LETTER TEHEH
0680 ARABIC LETTER BEHEH
0681 ARABIC LETTER HAH WITH HAMZA ABOVE
0682 ARABIC LETTER HAH WITH TWO DOTS VERTICAL ABOVE
0683 ARABIC LETTER NYEH
0684 ARABIC LETTER DYEH
0685 ARABIC LETTER HAH WITH THREE DOTS ABOVE
0686 ARABIC LETTER TCHEH
0687 ARABIC LETTER TCHEHEH
0688 ARABIC LETTER DDAL
0689 ARABIC LETTER DAL WITH RING
068A ARABIC LETTER DAL WITH DOT BELOW
068B ARABIC LETTER DAL WITH DOT BELOW AND SMALL TAH
068C ARABIC LETTER DAHAL
068D ARABIC LETTER DDAHAL
068E ARABIC LETTER DUL
068F ARABIC LETTER DAL WITH THREE DOTS ABOVE DOWNWARDS
0690 ARABIC LETTER DAL WITH FOUR DOTS ABOVE
0691 ARABIC LETTER RREH
0692 ARABIC LETTER REH WITH SMALL V
0693 ARABIC LETTER REH WITH RING
0694 ARABIC LETTER REH WITH DOT BELOW
0695 ARABIC LETTER REH WITH SMALL V BELOW
0696 ARABIC LETTER REH WITH DOT BELOW AND DOT ABOVE
0697 ARABIC LETTER REH WITH TWO DOTS ABOVE
0698 ARABIC LETTER JEH
0699 ARABIC LETTER REH WITH FOUR DOTS ABOVE
069A ARABIC LETTER SEEN WITH DOT BELOW AND DOT ABOVE
069B ARABIC LETTER SEEN WITH THREE DOTS BELOW
069C ARABIC LETTER SEEN WITH THREE DOTS BELOW AND THREE DOTS ABOVE
069D ARABIC LETTER SAD WITH TWO DOTS BELOW
069E ARABIC LETTER SAD WITH THREE DOTS ABOVE
069F ARABIC LETTER TAH WITH THREE DOTS ABOVE
06A0 ARABIC LETTER AIN WITH THREE DOTS ABOVE
06A1 ARABIC LETTER DOTLESS FEH
06A2 ARABIC LETTER FEH WITH DOT MOVED BELOW
06A3 ARABIC LETTER FEH WITH DOT BELOW
06A4 ARABIC LETTER VEH
06A5 ARABIC LETTER FEH WITH THREE DOTS BELOW
06A6 ARABIC LETTER PEHEH
06A7 ARABIC LETTER QAF WITH DOT ABOVE
06A8 ARABIC LETTER QAF WITH THREE DOTS ABOVE
06A9 ARABIC LETTER KEHEH
06AA ARABIC LETTER SWASH KAF
06AB ARABIC LETTER KAF WITH RING
06AC ARABIC LETTER KAF WITH DOT ABOVE
06AD ARABIC LETTER NG
06AE ARABIC LETTER KAF WITH THREE DOTS BELOW
06AF ARABIC LETTER GAF
06B0 ARABIC LETTER GAF WITH RING
06B1 ARABIC LETTER NGOEH
06B2 ARABIC LETTER GAF WITH TWO DOTS BELOW
06B3 ARABIC LETTER GUEH
06B4 ARABIC LETTER GAF WITH THREE DOTS ABOVE
06B5 ARABIC LETTER LAM WITH SMALL V
06B6 ARABIC LETTER LAM WITH DOT ABOVE
06B7 ARABIC LETTER LAM WITH THREE DOTS ABOVE
06B8 ARABIC LETTER LAM WITH THREE DOTS BELOW
06B9 ARABIC LETTER NOON WITH DOT BELOW
06BA ARABIC LETTER NOON GHUNNA
06BB ARABIC LETTER RNOON
06BC ARABIC LETTER NOON WITH RING
06BD ARABIC LETTER NOON WITH THREE DOTS ABOVE
06BE ARABIC LETTER HEH DOACHASHMEE
06BF ARABIC LETTER TCHEH WITH DOT ABOVE
06C0 ARABIC LETTER HEH WITH YEH ABOVE
06C1 ARABIC LETTER HEH GOAL
06C2 ARABIC LETTER HEH GOAL WITH HAMZA ABOVE
06C3 ARABIC LETTER TEH MARBUTA GOAL
06C4 ARABIC LETTER WAW WITH RING
06C5 ARABIC LETTER KIRGHIZ OE
06C6 ARABIC LETTER OE
06C7 ARABIC LETTER U
06C8 ARABIC LETTER YU
06C9 ARABIC LETTER KIRGHIZ YU
06CA ARABIC LETTER WAW WITH TWO DOTS ABOVE
06CB ARABIC LETTER VE
06CC ARABIC LETTER FARSI YEH
06CD ARABIC LETTER YEH WITH TAIL
06CE ARABIC LETTER YEH WITH SMALL V
06CF ARABIC LETTER WAW WITH DOT ABOVE
06D0 ARABIC LETTER E
06D1 ARABIC LETTER YEH WITH THREE DOTS BELOW
06D2 ARABIC LETTER YEH BARREE
06D3 ARABIC LETTER YEH BARREE WITH HAMZA ABOVE
06D4 ARABIC FULL STOP
06D5 ARABIC LETTER AE
06D6 ARABIC SMALL HIGH LIGATURE SAD WITH LAM WITH ALEF MAKSURA
06D7 ARABIC SMALL HIGH LIGATURE QAF WITH LAM WITH ALEF MAKSURA
06D8 ARABIC SMALL HIGH MEEM INITIAL FORM
06D9 ARABIC SMALL HIGH LAM ALEF
06DA ARABIC SMALL HIGH JEEM
06DB ARABIC SMALL HIGH THREE DOTS
06DC ARABIC SMALL HIGH SEEN
06DD ARABIC END OF AYAH
06DE ARABIC START OF RUB EL HIZB
06DF ARABIC SMALL HIGH ROUNDED ZERO
06E0 ARABIC SMALL HIGH UPRIGHT RECTANGULAR ZERO
06E1 ARABIC SMALL HIGH DOTLESS HEAD OF KHAH
06E2 ARABIC SMALL HIGH MEEM ISOLATED FORM
06E3 ARABIC SMALL LOW SEEN
06E4 ARABIC SMALL HIGH MADDA
06E5 ARABIC SMALL WAW
06E6 ARABIC SMALL YEH
06E7 ARABIC SMALL HIGH YEH
06E8 ARABIC SMALL HIGH NOON
06E9 ARABIC PLACE OF SAJDAH
06EA ARABIC EMPTY CENTRE LOW STOP
06EB ARABIC EMPTY CENTRE HIGH STOP
06EC ARABIC ROUNDED HIGH STOP WITH FILLED CENTRE
06ED ARABIC SMALL LOW MEEM
06EE ARABIC LETTER DAL WITH INVERTED V
06EF ARABIC LETTER REH WITH INVERTED V
06F0 EXTENDED ARABIC-INDIC DIGIT ZERO
06F1 EXTENDED ARABIC-INDIC DIGIT ONE
06F2 EXTENDED ARABIC-INDIC DIGIT TWO
06F3 EXTENDED ARABIC-INDIC DIGIT THREE
06F4 EXTENDED ARABIC-INDIC DIGIT FOUR
06F5 EXTENDED ARABIC-INDIC DIGIT FIVE
06F6 EXTENDED ARABIC-INDIC DIGIT SIX
06F7 EXTENDED ARABIC-INDIC DIGIT SEVEN
06F8 EXTENDED ARABIC-INDIC DIGIT EIGHT
06F9 EXTENDED ARABIC-INDIC DIGIT NINE
06FA ARABIC LETTER SHEEN WITH DOT BELOW
06FB ARABIC LETTER DAD WITH DOT BELOW
06FC ARABIC LETTER GHAIN WITH DOT BELOW
06FD ARABIC SIGN SINDHI AMPERSAND
06FE ARABIC SIGN SINDHI POSTPOSITION MEN
06FF ARABIC LETTER HEH WITH INVERTED V
0700 SYRIAC END OF PARAGRAPH
0701 SYRIAC SUPRALINEAR FULL STOP
0702 SYRIAC SUBLINEAR FULL STOP
0703 SYRIAC SUPRALINEAR COLON
0704 SYRIAC SUBLINEAR COLON
0705 SYRIAC HORIZONTAL COLON
0706 SYRIAC COLON SKEWED LEFT
0707 SYRIAC COLON SKEWED RIGHT
0708 SYRIAC SUPRALINEAR COLON SKEWED LEFT
0709 SYRIAC SUBLINEAR COLON SKEWED RIGHT
070A SYRIAC CONTRACTION
070B SYRIAC HARKLEAN OBELUS
070C SYRIAC HARKLEAN METOBELUS
070D SYRIAC HARKLEAN ASTERISCUS
070F SYRIAC ABBREVIATION MARK
0710 SYRIAC LETTER ALAPH
0711 SYRIAC LETTER SUPERSCRIPT ALAPH
0712 SYRIAC LETTER BETH
0713 SYRIAC LETTER GAMAL
0714 SYRIAC LETTER GAMAL GARSHUNI
0715 SYRIAC LETTER DALATH
0716 SYRIAC LETTER DOTLESS DALATH RISH
0717 SYRIAC LETTER HE
0718 SYRIAC LETTER WAW
0719 SYRIAC LETTER ZAIN
071A SYRIAC LETTER HETH
071B SYRIAC LETTER TETH
071C SYRIAC LETTER TETH GARSHUNI
071D SYRIAC LETTER YUDH
071E SYRIAC LETTER YUDH HE
071F SYRIAC LETTER KAPH
0720 SYRIAC LETTER LAMADH
0721 SYRIAC LETTER MIM
0722 SYRIAC LETTER NUN
0723 SYRIAC LETTER SEMKATH
0724 SYRIAC LETTER FINAL SEMKATH
0725 SYRIAC LETTER E
0726 SYRIAC LETTER PE
0727 SYRIAC LETTER REVERSED PE
0728 SYRIAC LETTER SADHE
0729 SYRIAC LETTER QAPH
072A SYRIAC LETTER RISH
072B SYRIAC LETTER SHIN
072C SYRIAC LETTER TAW
072D SYRIAC LETTER PERSIAN BHETH
072E SYRIAC LETTER PERSIAN GHAMAL
072F SYRIAC LETTER PERSIAN DHALATH
0730 SYRIAC PTHAHA ABOVE
0731 SYRIAC PTHAHA BELOW
0732 SYRIAC PTHAHA DOTTED
0733 SYRIAC ZQAPHA ABOVE
0734 SYRIAC ZQAPHA BELOW
0735 SYRIAC ZQAPHA DOTTED
0736 SYRIAC RBASA ABOVE
0737 SYRIAC RBASA BELOW
0738 SYRIAC DOTTED ZLAMA HORIZONTAL
0739 SYRIAC DOTTED ZLAMA ANGULAR
073A SYRIAC HBASA ABOVE
073B SYRIAC HBASA BELOW
073C SYRIAC HBASA-ESASA DOTTED
073D SYRIAC ESASA ABOVE
073E SYRIAC ESASA BELOW
073F SYRIAC RWAHA
0740 SYRIAC FEMININE DOT
0741 SYRIAC QUSHSHAYA
0742 SYRIAC RUKKAKHA
0743 SYRIAC TWO VERTICAL DOTS ABOVE
0744 SYRIAC TWO VERTICAL DOTS BELOW
0745 SYRIAC THREE DOTS ABOVE
0746 SYRIAC THREE DOTS BELOW
0747 SYRIAC OBLIQUE LINE ABOVE
0748 SYRIAC OBLIQUE LINE BELOW
0749 SYRIAC MUSIC
074A SYRIAC BARREKH
074D SYRIAC LETTER SOGDIAN ZHAIN
074E SYRIAC LETTER SOGDIAN KHAPH
074F SYRIAC LETTER SOGDIAN FE
0750 ARABIC LETTER BEH WITH THREE DOTS HORIZONTALLY BELOW
0751 ARABIC LETTER BEH WITH DOT BELOW AND THREE DOTS ABOVE
0752 ARABIC LETTER BEH WITH THREE DOTS POINTING UPWARDS BELOW
0753 ARABIC LETTER BEH WITH THREE DOTS POINTING UPWARDS BELOW AND TWO DOTS ABOVE
0754 ARABIC LETTER BEH WITH TWO DOTS BELOW AND DOT ABOVE
0755 ARABIC LETTER BEH WITH INVERTED SMALL V BELOW
0756 ARABIC LETTER BEH WITH SMALL V
0757 ARABIC LETTER HAH WITH TWO DOTS ABOVE
0758 ARABIC LETTER HAH WITH THREE DOTS POINTING UPWARDS BELOW
0759 ARABIC LETTER DAL WITH TWO DOTS VERTICALLY BELOW AND SMALL TAH
075A ARABIC LETTER DAL WITH INVERTED SMALL V BELOW
075B ARABIC LETTER REH WITH STROKE
075C ARABIC LETTER SEEN WITH FOUR DOTS ABOVE
075D ARABIC LETTER AIN WITH TWO DOTS ABOVE
075E ARABIC LETTER AIN WITH THREE DOTS POINTING DOWNWARDS ABOVE
075F ARABIC LETTER AIN WITH TWO DOTS VERTICALLY ABOVE
0760 ARABIC LETTER FEH WITH TWO DOTS BELOW
0761 ARABIC LETTER FEH WITH THREE DOTS POINTING UPWARDS BELOW
0762 ARABIC LETTER KEHEH WITH DOT ABOVE
0763 ARABIC LETTER KEHEH WITH THREE DOTS ABOVE
0764 ARABIC LETTER KEHEH WITH THREE DOTS POINTING UPWARDS BELOW
0765 ARABIC LETTER MEEM WITH DOT ABOVE
0766 ARABIC LETTER MEEM WITH DOT BELOW
0767 ARABIC LETTER NOON WITH TWO DOTS BELOW
0768 ARABIC LETTER NOON WITH SMALL TAH
0769 ARABIC LETTER NOON WITH SMALL V
076A ARABIC LETTER LAM WITH BAR
076B ARABIC LETTER REH WITH TWO DOTS VERTICALLY ABOVE
076C ARABIC LETTER REH WITH HAMZA ABOVE
076D ARABIC LETTER SEEN WITH TWO DOTS VERTICALLY ABOVE
076E ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH BELOW
076F ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH AND TWO DOTS
0770 ARABIC LETTER SEEN WITH SMALL ARABIC LETTER TAH AND TWO DOTS
0771 ARABIC LETTER REH WITH SMALL ARABIC LETTER TAH AND TWO DOTS
0772 ARABIC LETTER HAH WITH SMALL ARABIC LETTER TAH ABOVE
0773 ARABIC LETTER ALEF WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE
0774 ARABIC LETTER ALEF WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE
0775 ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE
0776 ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE
0777 ARABIC LETTER FARSI YEH WITH EXTENDED ARABIC-INDIC DIGIT FOUR BELOW
0778 ARABIC LETTER WAW WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE
0779 ARABIC LETTER WAW WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE
077A ARABIC LETTER YEH BARREE WITH EXTENDED ARABIC-INDIC DIGIT TWO ABOVE
077B ARABIC LETTER YEH BARREE WITH EXTENDED ARABIC-INDIC DIGIT THREE ABOVE
077C ARABIC LETTER HAH WITH EXTENDED ARABIC-INDIC DIGIT FOUR BELOW
077D ARABIC LETTER SEEN WITH EXTENDED ARABIC-INDIC DIGIT FOUR ABOVE
077E ARABIC LETTER SEEN WITH INVERTED V
077F ARABIC LETTER KAF WITH TWO DOTS ABOVE
0780 THAANA LETTER HAA
0781 THAANA LETTER SHAVIYANI
0782 THAANA LETTER NOONU
0783 THAANA LETTER RAA
0784 THAANA LETTER BAA
0785 THAANA LETTER LHAVIYANI
0786 THAANA LETTER KAAFU
0787 THAANA LETTER ALIFU
0788 THAANA LETTER VAAVU
0789 THAANA LETTER MEEMU
078A THAANA LETTER FAAFU
078B THAANA LETTER DHAALU
078C THAANA LETTER THAA
078D THAANA LETTER LAAMU
078E THAANA LETTER GAAFU
078F THAANA LETTER GNAVIYANI
0790 THAANA LETTER SEENU
0791 THAANA LETTER DAVIYANI
0792 THAANA LETTER ZAVIYANI
0793 THAANA LETTER TAVIYANI
0794 THAANA LETTER YAA
0795 THAANA LETTER PAVIYANI
0796 THAANA LETTER JAVIYANI
0797 THAANA LETTER CHAVIYANI
0798 THAANA LETTER TTAA
0799 THAANA LETTER HHAA
079A THAANA LETTER KHAA
079B THAANA LETTER THAALU
079C THAANA LETTER ZAA
079D THAANA LETTER SHEENU
079E THAANA LETTER SAADHU
079F THAANA LETTER DAADHU
07A0 THAANA LETTER TO
07A1 THAANA LETTER ZO
07A2 THAANA LETTER AINU
07A3 THAANA LETTER GHAINU
07A4 THAANA LETTER QAAFU
07A5 THAANA LETTER WAAVU
07A6 THAANA ABAFILI
07A7 THAANA AABAAFILI
07A8 THAANA IBIFILI
07A9 THAANA EEBEEFILI
07AA THAANA UBUFILI
07AB THAANA OOBOOFILI
07AC THAANA EBEFILI
07AD THAANA EYBEYFILI
07AE THAANA OBOFILI
07AF THAANA OABOAFILI
07B0 THAANA SUKUN
07B1 THAANA LETTER NAA
07C0 NKO DIGIT ZERO
07C1 NKO DIGIT ONE
07C2 NKO DIGIT TWO
07C3 NKO DIGIT THREE
07C4 NKO DIGIT FOUR
07C5 NKO DIGIT FIVE
07C6 NKO DIGIT SIX
07C7 NKO DIGIT SEVEN
07C8 NKO DIGIT EIGHT
07C9 NKO DIGIT NINE
07CA NKO LETTER A
07CB NKO LETTER EE
07CC NKO LETTER I
07CD NKO LETTER E
07CE NKO LETTER U
07CF NKO LETTER OO
07D0 NKO LETTER O
07D1 NKO LETTER DAGBASINNA
07D2 NKO LETTER N
07D3 NKO LETTER BA
07D4 NKO LETTER PA
07D5 NKO LETTER TA
07D6 NKO LETTER JA
07D7 NKO LETTER CHA
07D8 NKO LETTER DA
07D9 NKO LETTER RA
07DA NKO LETTER RRA
07DB NKO LETTER SA
07DC NKO LETTER GBA
07DD NKO LETTER FA
07DE NKO LETTER KA
07DF NKO LETTER LA
07E0 NKO LETTER NA WOLOSO
07E1 NKO LETTER MA
07E2 NKO LETTER NYA
07E3 NKO LETTER NA
07E4 NKO LETTER HA
07E5 NKO LETTER WA
07E6 NKO LETTER YA
07E7 NKO LETTER NYA WOLOSO
07E8 NKO LETTER JONA JA
07E9 NKO LETTER JONA CHA
07EA NKO LETTER JONA RA
07EB NKO COMBINING SHORT HIGH TONE
07EC NKO COMBINING SHORT LOW TONE
07ED NKO COMBINING SHORT RISING TONE
07EE NKO COMBINING LONG DESCENDING TONE
07EF NKO COMBINING LONG HIGH TONE
07F0 NKO COMBINING LONG LOW TONE
07F1 NKO COMBINING LONG RISING TONE
07F2 NKO COMBINING NASALIZATION MARK
07F3 NKO COMBINING DOUBLE DOT ABOVE
07F4 NKO HIGH TONE APOSTROPHE
07F5 NKO LOW TONE APOSTROPHE
07F6 NKO SYMBOL OO DENNEN
07F7 NKO SYMBOL GBAKURUNEN
07F8 NKO COMMA
07F9 NKO EXCLAMATION MARK
07FA NKO LAJANYALAN
0800 SAMARITAN LETTER ALAF
0801 SAMARITAN LETTER BIT
0802 SAMARITAN LETTER GAMAN
0803 SAMARITAN LETTER DALAT
0804 SAMARITAN LETTER IY
0805 SAMARITAN LETTER BAA
0806 SAMARITAN LETTER ZEN
0807 SAMARITAN LETTER IT
0808 SAMARITAN LETTER TIT
0809 SAMARITAN LETTER YUT
080A SAMARITAN LETTER KAAF
080B SAMARITAN LETTER LABAT
080C SAMARITAN LETTER MIM
080D SAMARITAN LETTER NUN
080E SAMARITAN LETTER SINGAAT
080F SAMARITAN LETTER IN
0810 SAMARITAN LETTER FI
0811 SAMARITAN LETTER TSAADIY
0812 SAMARITAN LETTER QUF
0813 SAMARITAN LETTER RISH
0814 SAMARITAN LETTER SHAN
0815 SAMARITAN LETTER TAAF
0816 SAMARITAN MARK IN
0817 SAMARITAN MARK IN-ALAF
0818 SAMARITAN MARK OCCLUSION
0819 SAMARITAN MARK DAGESH
081A SAMARITAN MODIFIER LETTER EPENTHETIC YUT
081B SAMARITAN MARK EPENTHETIC YUT
081C SAMARITAN VOWEL SIGN LONG E
081D SAMARITAN VOWEL SIGN E
081E SAMARITAN VOWEL SIGN OVERLONG AA
081F SAMARITAN VOWEL SIGN LONG AA
0820 SAMARITAN VOWEL SIGN AA
0821 SAMARITAN VOWEL SIGN OVERLONG A
0822 SAMARITAN VOWEL SIGN LONG A
0823 SAMARITAN VOWEL SIGN A
0824 SAMARITAN MODIFIER LETTER SHORT A
0825 SAMARITAN VOWEL SIGN SHORT A
0826 SAMARITAN VOWEL SIGN LONG U
0827 SAMARITAN VOWEL SIGN U
0828 SAMARITAN MODIFIER LETTER I
0829 SAMARITAN VOWEL SIGN LONG I
082A SAMARITAN VOWEL SIGN I
082B SAMARITAN VOWEL SIGN O
082C SAMARITAN VOWEL SIGN SUKUN
082D SAMARITAN MARK NEQUDAA
0830 SAMARITAN PUNCTUATION NEQUDAA
0831 SAMARITAN PUNCTUATION AFSAAQ
0832 SAMARITAN PUNCTUATION ANGED
0833 SAMARITAN PUNCTUATION BAU
0834 SAMARITAN PUNCTUATION ATMAAU
0835 SAMARITAN PUNCTUATION SHIYYAALAA
0836 SAMARITAN ABBREVIATION MARK
0837 SAMARITAN PUNCTUATION MELODIC QITSA
0838 SAMARITAN PUNCTUATION ZIQAA
0839 SAMARITAN PUNCTUATION QITSA
083A SAMARITAN PUNCTUATION ZAEF
083B SAMARITAN PUNCTUATION TURU
083C SAMARITAN PUNCTUATION ARKAANU
083D SAMARITAN PUNCTUATION SOF MASHFAAT
083E SAMARITAN PUNCTUATION ANNAAU
0840 MANDAIC LETTER HALQA
0841 MANDAIC LETTER AB
0842 MANDAIC LETTER AG
0843 MANDAIC LETTER AD
0844 MANDAIC LETTER AH
0845 MANDAIC LETTER USHENNA
0846 MANDAIC LETTER AZ
0847 MANDAIC LETTER IT
0848 MANDAIC LETTER ATT
0849 MANDAIC LETTER AKSA
084A MANDAIC LETTER AK
084B MANDAIC LETTER AL
084C MANDAIC LETTER AM
084D MANDAIC LETTER AN
084E MANDAIC LETTER AS
084F MANDAIC LETTER IN
0850 MANDAIC LETTER AP
0851 MANDAIC LETTER ASZ
0852 MANDAIC LETTER AQ
0853 MANDAIC LETTER AR
0854 MANDAIC LETTER ASH
0855 MANDAIC LETTER AT
0856 MANDAIC LETTER DUSHENNA
0857 MANDAIC LETTER KAD
0858 MANDAIC LETTER AIN
0859 MANDAIC AFFRICATION MARK
085A MANDAIC VOCALIZATION MARK
085B MANDAIC GEMINATION MARK
085E MANDAIC PUNCTUATION
0860 SYRIAC LETTER MALAYALAM NGA
0861 SYRIAC LETTER MALAYALAM JA
0862 SYRIAC LETTER MALAYALAM NYA
0863 SYRIAC LETTER MALAYALAM TTA
0864 SYRIAC LETTER MALAYALAM NNA
0865 SYRIAC LETTER MALAYALAM NNNA
0866 SYRIAC LETTER MALAYALAM BHA
0867 SYRIAC LETTER MALAYALAM RA
0868 SYRIAC LETTER MALAYALAM LLA
0869 SYRIAC LETTER MALAYALAM LLLA
086A SYRIAC LETTER MALAYALAM SSA
08A0 ARABIC LETTER BEH WITH SMALL V BELOW
08A1 ARABIC LETTER BEH WITH HAMZA ABOVE
08A2 ARABIC LETTER JEEM WITH TWO DOTS ABOVE
08A3 ARABIC LETTER TAH WITH TWO DOTS ABOVE
08A4 ARABIC LETTER FEH WITH DOT BELOW AND THREE DOTS ABOVE
08A5 ARABIC LETTER QAF WITH DOT BELOW
08A6 ARABIC LETTER LAM WITH DOUBLE BAR
08A7 ARABIC LETTER MEEM WITH THREE DOTS ABOVE
08A8 ARABIC LETTER YEH WITH TWO DOTS BELOW AND HAMZA ABOVE
08A9 ARABIC LETTER YEH WITH TWO DOTS BELOW AND DOT ABOVE
08AA ARABIC LETTER REH WITH LOOP
08AB ARABIC LETTER WAW WITH DOT WITHIN
08AC ARABIC LETTER ROHINGYA YEH
08AD ARABIC LETTER LOW ALEF
08AE ARABIC LETTER DAL WITH THREE DOTS BELOW
08AF ARABIC LETTER SAD WITH THREE DOTS BELOW
08B0 ARABIC LETTER GAF WITH INVERTED STROKE
08B1 ARABIC LETTER STRAIGHT WAW
08B2 ARABIC LETTER ZAIN WITH INVERTED V ABOVE
08B3 ARABIC LETTER AIN WITH THREE DOTS BELOW
08B4 ARABIC LETTER KAF WITH DOT BELOW
08B6 ARABIC LETTER BEH WITH SMALL MEEM ABOVE
08B7 ARABIC LETTER PEH WITH SMALL MEEM ABOVE
08B8 ARABIC LETTER TEH WITH SMALL TEH ABOVE
08B9 ARABIC LETTER REH WITH SMALL NOON ABOVE
08BA ARABIC LETTER YEH WITH TWO DOTS BELOW AND SMALL NOON ABOVE
08BB ARABIC LETTER AFRICAN FEH
08BC ARABIC LETTER AFRICAN QAF
08BD ARABIC LETTER AFRICAN NOON
08D4 ARABIC SMALL HIGH WORD AR-RUB
08D5 ARABIC SMALL HIGH SAD
08D6 ARABIC SMALL HIGH AIN
08D7 ARABIC SMALL HIGH QAF
08D8 ARABIC SMALL HIGH NOON WITH KASRA
08D9 ARABIC SMALL LOW NOON WITH KASRA
08DA ARABIC SMALL HIGH WORD ATH-THALATHA
08DB ARABIC SMALL HIGH WORD AS-SAJDA
08DC ARABIC SMALL HIGH WORD AN-NISF
08DD ARABIC SMALL HIGH WORD SAKTA
08DE ARABIC SMALL HIGH WORD QIF
08DF ARABIC SMALL HIGH WORD WAQFA
08E0 ARABIC SMALL HIGH FOOTNOTE MARKER
08E1 ARABIC SMALL HIGH SIGN SAFHA
08E2 ARABIC DISPUTED END OF AYAH
08E3 ARABIC TURNED DAMMA BELOW
08E4 ARABIC CURLY FATHA
08E5 ARABIC CURLY DAMMA
08E6 ARABIC CURLY KASRA
08E7 ARABIC CURLY FATHATAN
08E8 ARABIC CURLY DAMMATAN
08E9 ARABIC CURLY KASRATAN
08EA ARABIC TONE ONE DOT ABOVE
08EB ARABIC TONE TWO DOTS ABOVE
08EC ARABIC TONE LOOP ABOVE
08ED ARABIC TONE ONE DOT BELOW
08EE ARABIC TONE TWO DOTS BELOW
08EF ARABIC TONE LOOP BELOW
08F0 ARABIC OPEN FATHATAN
08F1 ARABIC OPEN DAMMATAN
08F2 ARABIC OPEN KASRATAN
08F3 ARABIC SMALL HIGH WAW
08F4 ARABIC FATHA WITH RING
08F5 ARABIC FATHA WITH DOT ABOVE
08F6 ARABIC KASRA WITH DOT BELOW
08F7 ARABIC LEFT ARROWHEAD ABOVE
08F8 ARABIC RIGHT ARROWHEAD ABOVE
08F9 ARABIC LEFT ARROWHEAD BELOW
08FA ARABIC RIGHT ARROWHEAD BELOW
08FB ARABIC DOUBLE RIGHT ARROWHEAD ABOVE
08FC ARABIC DOUBLE RIGHT ARROWHEAD ABOVE WITH DOT
08FD ARABIC RIGHT ARROWHEAD ABOVE WITH DOT
08FE ARABIC DAMMA WITH DOT
08FF ARABIC MARK SIDEWAYS NOON GHUNNA
0900 DEVANAGARI SIGN INVERTED CANDRABINDU
0901 DEVANAGARI SIGN CANDRABINDU
0902 DEVANAGARI SIGN ANUSVARA
0903 DEVANAGARI SIGN VISARGA
0904 DEVANAGARI LETTER SHORT A
0905 DEVANAGARI LETTER A
0906 DEVANAGARI LETTER AA
0907 DEVANAGARI LETTER I
0908 DEVANAGARI LETTER II
0909 DEVANAGARI LETTER U
090A DEVANAGARI LETTER UU
090B DEVANAGARI LETTER VOCALIC R
090C DEVANAGARI LETTER VOCALIC L
090D DEVANAGARI LETTER CANDRA E
090E DEVANAGARI LETTER SHORT E
090F DEVANAGARI LETTER E
0910 DEVANAGARI LETTER AI
0911 DEVANAGARI LETTER CANDRA O
0912 DEVANAGARI LETTER SHORT O
0913 DEVANAGARI LETTER O
0914 DEVANAGARI LETTER AU
0915 DEVANAGARI LETTER KA
0916 DEVANAGARI LETTER KHA
0917 DEVANAGARI LETTER GA
0918 DEVANAGARI LETTER GHA
0919 DEVANAGARI LETTER NGA
091A DEVANAGARI LETTER CA
091B DEVANAGARI LETTER CHA
091C DEVANAGARI LETTER JA
091D DEVANAGARI LETTER JHA
091E DEVANAGARI LETTER NYA
091F DEVANAGARI LETTER TTA
0920 DEVANAGARI LETTER TTHA
0921 DEVANAGARI LETTER DDA
0922 DEVANAGARI LETTER DDHA
0923 DEVANAGARI LETTER NNA
0924 DEVANAGARI LETTER TA
0925 DEVANAGARI LETTER THA
0926 DEVANAGARI LETTER DA
0927 DEVANAGARI LETTER DHA
0928 DEVANAGARI LETTER NA
0929 DEVANAGARI LETTER NNNA
092A DEVANAGARI LETTER PA
092B DEVANAGARI LETTER PHA
092C DEVANAGARI LETTER BA
092D DEVANAGARI LETTER BHA
092E DEVANAGARI LETTER MA
092F DEVANAGARI LETTER YA
0930 DEVANAGARI LETTER RA
0931 DEVANAGARI LETTER RRA
0932 DEVANAGARI LETTER LA
0933 DEVANAGARI LETTER LLA
0934 DEVANAGARI LETTER LLLA
0935 DEVANAGARI LETTER VA
0936 DEVANAGARI LETTER SHA
0937 DEVANAGARI LETTER SSA
0938 DEVANAGARI LETTER SA
0939 DEVANAGARI LETTER HA
093A DEVANAGARI VOWEL SIGN OE
093B DEVANAGARI VOWEL SIGN OOE
093C DEVANAGARI SIGN NUKTA
093D DEVANAGARI SIGN AVAGRAHA
093E DEVANAGARI VOWEL SIGN AA
093F DEVANAGARI VOWEL SIGN I
0940 DEVANAGARI VOWEL SIGN II
0941 DEVANAGARI VOWEL SIGN U
0942 DEVANAGARI VOWEL SIGN UU
0943 DEVANAGARI VOWEL SIGN VOCALIC R
0944 DEVANAGARI VOWEL SIGN VOCALIC RR
0945 DEVANAGARI VOWEL SIGN CANDRA E
0946 DEVANAGARI VOWEL SIGN SHORT E
0947 DEVANAGARI VOWEL SIGN E
0948 DEVANAGARI VOWEL SIGN AI
0949 DEVANAGARI VOWEL SIGN CANDRA O
094A DEVANAGARI VOWEL SIGN SHORT O
094B DEVANAGARI VOWEL SIGN O
094C DEVANAGARI VOWEL SIGN AU
094D DEVANAGARI SIGN VIRAMA
094E DEVANAGARI VOWEL SIGN PRISHTHAMATRA E
094F DEVANAGARI VOWEL SIGN AW
0950 DEVANAGARI OM
0951 DEVANAGARI STRESS SIGN UDATTA
0952 DEVANAGARI STRESS SIGN ANUDATTA
0953 DEVANAGARI GRAVE ACCENT
0954 DEVANAGARI ACUTE ACCENT
0955 DEVANAGARI VOWEL SIGN CANDRA LONG E
0956 DEVANAGARI VOWEL SIGN UE
0957 DEVANAGARI VOWEL SIGN UUE
0958 DEVANAGARI LETTER QA
0959 DEVANAGARI LETTER KHHA
095A DEVANAGARI LETTER GHHA
095B DEVANAGARI LETTER ZA
095C DEVANAGARI LETTER DDDHA
095D DEVANAGARI LETTER RHA
095E DEVANAGARI LETTER FA
095F DEVANAGARI LETTER YYA
0960 DEVANAGARI LETTER VOCALIC RR
0961 DEVANAGARI LETTER VOCALIC LL
0962 DEVANAGARI VOWEL SIGN VOCALIC L
0963 DEVANAGARI VOWEL SIGN VOCALIC LL
0964 DEVANAGARI DANDA
0965 DEVANAGARI DOUBLE DANDA
0966 DEVANAGARI DIGIT ZERO
0967 DEVANAGARI DIGIT ONE
0968 DEVANAGARI DIGIT TWO
0969 DEVANAGARI DIGIT THREE
096A DEVANAGARI DIGIT FOUR
096B DEVANAGARI DIGIT FIVE
096C DEVANAGARI DIGIT SIX
096D DEVANAGARI DIGIT SEVEN
096E DEVANAGARI DIGIT EIGHT
096F DEVANAGARI DIGIT NINE
0970 DEVANAGARI ABBREVIATION SIGN
0971 DEVANAGARI SIGN HIGH SPACING DOT
0972 DEVANAGARI LETTER CANDRA A
0973 DEVANAGARI LETTER OE
0974 DEVANAGARI LETTER OOE
0975 DEVANAGARI LETTER AW
0976 DEVANAGARI LETTER UE
0977 DEVANAGARI LETTER UUE
0978 DEVANAGARI LETTER MARWARI DDA
0979 DEVANAGARI LETTER ZHA
097A DEVANAGARI LETTER HEAVY YA
097B DEVANAGARI LETTER GGA
097C DEVANAGARI LETTER JJA
097D DEVANAGARI LETTER GLOTTAL STOP
097E DEVANAGARI LETTER DDDA
097F DEVANAGARI LETTER BBA
0980 BENGALI ANJI
0981 BENGALI SIGN CANDRABINDU
0982 BENGALI SIGN ANUSVARA
0983 BENGALI SIGN VISARGA
0985 BENGALI LETTER A
0986 BENGALI LETTER AA
0987 BENGALI LETTER I
0988 BENGALI LETTER II
0989 BENGALI LETTER U
098A BENGALI LETTER UU
098B BENGALI LETTER VOCALIC R
098C BENGALI LETTER VOCALIC L
098F BENGALI LETTER E
0990 BENGALI LETTER AI
0993 BENGALI LETTER O
0994 BENGALI LETTER AU
0995 BENGALI LETTER KA
0996 BENGALI LETTER KHA
0997 BENGALI LETTER GA
0998 BENGALI LETTER GHA
0999 BENGALI LETTER NGA
099A BENGALI LETTER CA
099B BENGALI LETTER CHA
099C BENGALI LETTER JA
099D BENGALI LETTER JHA
099E BENGALI LETTER NYA
099F BENGALI LETTER TTA
09A0 BENGALI LETTER TTHA
09A1 BENGALI LETTER DDA
09A2 BENGALI LETTER DDHA
09A3 BENGALI LETTER NNA
09A4 BENGALI LETTER TA
09A5 BENGALI LETTER THA
09A6 BENGALI LETTER DA
09A7 BENGALI LETTER DHA
09A8 BENGALI LETTER NA
09AA BENGALI LETTER PA
09AB BENGALI LETTER PHA
09AC BENGALI LETTER BA
09AD BENGALI LETTER BHA
09AE BENGALI LETTER MA
09AF BENGALI LETTER YA
09B0 BENGALI LETTER RA
09B2 BENGALI LETTER LA
09B6 BENGALI LETTER SHA
09B7 BENGALI LETTER SSA
09B8 BENGALI LETTER SA
09B9 BENGALI LETTER HA
09BC BENGALI SIGN NUKTA
09BD BENGALI SIGN AVAGRAHA
09BE BENGALI VOWEL SIGN AA
09BF BENGALI VOWEL SIGN I
09C0 BENGALI VOWEL SIGN II
09C1 BENGALI VOWEL SIGN U
09C2 BENGALI VOWEL SIGN UU
09C3 BENGALI VOWEL SIGN VOCALIC R
09C4 BENGALI VOWEL SIGN VOCALIC RR
09C7 BENGALI VOWEL SIGN E
09C8 BENGALI VOWEL SIGN AI
09CB BENGALI VOWEL SIGN O
09CC BENGALI VOWEL SIGN AU
09CD BENGALI SIGN VIRAMA
09CE BENGALI LETTER KHANDA TA
09D7 BENGALI AU LENGTH MARK
09DC BENGALI LETTER RRA
09DD BENGALI LETTER RHA
09DF BENGALI LETTER YYA
09E0 BENGALI LETTER VOCALIC RR
09E1 BENGALI LETTER VOCALIC LL
09E2 BENGALI VOWEL SIGN VOCALIC L
09E3 BENGALI VOWEL SIGN VOCALIC LL
09E6 BENGALI DIGIT ZERO
09E7 BENGALI DIGIT ONE
09E8 BENGALI DIGIT TWO
09E9 BENGALI DIGIT THREE
09EA BENGALI DIGIT FOUR
09EB BENGALI DIGIT FIVE
09EC BENGALI DIGIT SIX
09ED BENGALI DIGIT SEVEN
09EE BENGALI DIGIT EIGHT
09EF BENGALI DIGIT NINE
09F0 BENGALI LETTER RA WITH MIDDLE DIAGONAL
09F1 BENGALI LETTER RA WITH LOWER DIAGONAL
09F2 BENGALI RUPEE MARK
09F3 BENGALI RUPEE SIGN
09F4 BENGALI CURRENCY NUMERATOR ONE
09F5 BENGALI CURRENCY NUMERATOR TWO
09F6 BENGALI CURRENCY NUMERATOR THREE
09F7 BENGALI CURRENCY NUMERATOR FOUR
09F8 BENGALI CURRENCY NUMERATOR ONE LESS THAN THE DENOMINATOR
09F9 BENGALI CURRENCY DENOMINATOR SIXTEEN
09FA BENGALI ISSHAR
09FB BENGALI GANDA MARK
09FC BENGALI LETTER VEDIC ANUSVARA
09FD BENGALI ABBREVIATION SIGN
0A01 GURMUKHI SIGN ADAK BINDI
0A02 GURMUKHI SIGN BINDI
0A03 GURMUKHI SIGN VISARGA
0A05 GURMUKHI LETTER A
0A06 GURMUKHI LETTER AA
0A07 GURMUKHI LETTER I
0A08 GURMUKHI LETTER II
0A09 GURMUKHI LETTER U
0A0A GURMUKHI LETTER UU
0A0F GURMUKHI LETTER EE
0A10 GURMUKHI LETTER AI
0A13 GURMUKHI LETTER OO
0A14 GURMUKHI LETTER AU
0A15 GURMUKHI LETTER KA
0A16 GURMUKHI LETTER KHA
0A17 GURMUKHI LETTER GA
0A18 GURMUKHI LETTER GHA
0A19 GURMUKHI LETTER NGA
0A1A GURMUKHI LETTER CA
0A1B GURMUKHI LETTER CHA
0A1C GURMUKHI LETTER JA
0A1D GURMUKHI LETTER JHA
0A1E GURMUKHI LETTER NYA
0A1F GURMUKHI LETTER TTA
0A20 GURMUKHI LETTER TTHA
0A21 GURMUKHI LETTER DDA
0A22 GURMUKHI LETTER DDHA
0A23 GURMUKHI LETTER NNA
0A24 GURMUKHI LETTER TA
0A25 GURMUKHI LETTER THA
0A26 GURMUKHI LETTER DA
0A27 GURMUKHI LETTER DHA
0A28 GURMUKHI LETTER NA
0A2A GURMUKHI LETTER PA
0A2B GURMUKHI LETTER PHA
0A2C GURMUKHI LETTER BA
0A2D GURMUKHI LETTER BHA
0A2E GURMUKHI LETTER MA
0A2F GURMUKHI LETTER YA
0A30 GURMUKHI LETTER RA
0A32 GURMUKHI LETTER LA
0A33 GURMUKHI LETTER LLA
0A35 GURMUKHI LETTER VA
0A36 GURMUKHI LETTER SHA
0A38 GURMUKHI LETTER SA
0A39 GURMUKHI LETTER HA
0A3C GURMUKHI SIGN NUKTA
0A3E GURMUKHI VOWEL SIGN AA
0A3F GURMUKHI VOWEL SIGN I
0A40 GURMUKHI VOWEL SIGN II
0A41 GURMUKHI VOWEL SIGN U
0A42 GURMUKHI VOWEL SIGN UU
0A47 GURMUKHI VOWEL SIGN EE
0A48 GURMUKHI VOWEL SIGN AI
0A4B GURMUKHI VOWEL SIGN OO
0A4C GURMUKHI VOWEL SIGN AU
0A4D GURMUKHI SIGN VIRAMA
0A51 GURMUKHI SIGN UDAAT
0A59 GURMUKHI LETTER KHHA
0A5A GURMUKHI LETTER GHHA
0A5B GURMUKHI LETTER ZA
0A5C GURMUKHI LETTER RRA
0A5E GURMUKHI LETTER FA
0A66 GURMUKHI DIGIT ZERO
0A67 GURMUKHI DIGIT ONE
0A68 GURMUKHI DIGIT TWO
0A69 GURMUKHI DIGIT THREE
0A6A GURMUKHI DIGIT FOUR
0A6B GURMUKHI DIGIT FIVE
0A6C GURMUKHI DIGIT SIX
0A6D GURMUKHI DIGIT SEVEN
0A6E GURMUKHI DIGIT EIGHT
0A6F GURMUKHI DIGIT NINE
0A70 GURMUKHI TIPPI
0A71 GURMUKHI ADDAK
0A72 GURMUKHI IRI
0A73 GURMUKHI URA
0A74 GURMUKHI EK ONKAR
0A75 GURMUKHI SIGN YAKASH
0A81 GUJARATI SIGN CANDRABINDU
0A82 GUJARATI SIGN ANUSVARA
0A83 GUJARATI SIGN VISARGA
0A85 GUJARATI LETTER A
0A86 GUJARATI LETTER AA
0A87 GUJARATI LETTER I
0A88 GUJARATI LETTER II
0A89 GUJARATI LETTER U
0A8A GUJARATI LETTER UU
0A8B GUJARATI LETTER VOCALIC R
0A8C GUJARATI LETTER VOCALIC L
0A8D GUJARATI VOWEL CANDRA E
0A8F GUJARATI LETTER E
0A90 GUJARATI LETTER AI
0A91 GUJARATI VOWEL CANDRA O
0A93 GUJARATI LETTER O
0A94 GUJARATI LETTER AU
0A95 GUJARATI LETTER KA
0A96 GUJARATI LETTER KHA
0A97 GUJARATI LETTER GA
0A98 GUJARATI LETTER GHA
0A99 GUJARATI LETTER NGA
0A9A GUJARATI LETTER CA
0A9B GUJARATI LETTER CHA
0A9C GUJARATI LETTER JA
0A9D GUJARATI LETTER JHA
0A9E GUJARATI LETTER NYA
0A9F GUJARATI LETTER TTA
0AA0 GUJARATI LETTER TTHA
0AA1 GUJARATI LETTER DDA
0AA2 GUJARATI LETTER DDHA
0AA3 GUJARATI LETTER NNA
0AA4 GUJARATI LETTER TA
0AA5 GUJARATI LETTER THA
0AA6 GUJARATI LETTER DA
0AA7 GUJARATI LETTER DHA
0AA8 GUJARATI LETTER NA
0AAA GUJARATI LETTER PA
0AAB GUJARATI LETTER PHA
0AAC GUJARATI LETTER BA
0AAD GUJARATI LETTER BHA
0AAE GUJARATI LETTER MA
0AAF GUJARATI LETTER YA
0AB0 GUJARATI LETTER RA
0AB2 GUJARATI LETTER LA
0AB3 GUJARATI LETTER LLA
0AB5 GUJARATI LETTER VA
0AB6 GUJARATI LETTER SHA
0AB7 GUJARATI LETTER SSA
0AB8 GUJARATI LETTER SA
0AB9 GUJARATI LETTER HA
0ABC GUJARATI SIGN NUKTA
0ABD GUJARATI SIGN AVAGRAHA
0ABE GUJARATI VOWEL SIGN AA
0ABF GUJARATI VOWEL SIGN I
0AC0 GUJARATI VOWEL SIGN II
0AC1 GUJARATI VOWEL SIGN U
0AC2 GUJARATI VOWEL SIGN UU
0AC3 GUJARATI VOWEL SIGN VOCALIC R
0AC4 GUJARATI VOWEL SIGN VOCALIC RR
0AC5 GUJARATI VOWEL SIGN CANDRA E
0AC7 GUJARATI VOWEL SIGN E
0AC8 GUJARATI VOWEL SIGN AI
0AC9 GUJARATI VOWEL SIGN CANDRA O
0ACB GUJARATI VOWEL SIGN O
0ACC GUJARATI VOWEL SIGN AU
0ACD GUJARATI SIGN VIRAMA
0AD0 GUJARATI OM
0AE0 GUJARATI LETTER VOCALIC RR
0AE1 GUJARATI LETTER VOCALIC LL
0AE2 GUJARATI VOWEL SIGN VOCALIC L
0AE3 GUJARATI VOWEL SIGN VOCALIC LL
0AE6 GUJARATI DIGIT ZERO
0AE7 GUJARATI DIGIT ONE
0AE8 GUJARATI DIGIT TWO
0AE9 GUJARATI DIGIT THREE
0AEA GUJARATI DIGIT FOUR
0AEB GUJARATI DIGIT FIVE
0AEC GUJARATI DIGIT SIX
0AED GUJARATI DIGIT SEVEN
0AEE GUJARATI DIGIT EIGHT
0AEF GUJARATI DIGIT NINE
0AF0 GUJARATI ABBREVIATION SIGN
0AF1 GUJARATI RUPEE SIGN
0AF9 GUJARATI LETTER ZHA
0AFA GUJARATI SIGN SUKUN
0AFB GUJARATI SIGN SHADDA
0AFC GUJARATI SIGN MADDAH
0AFD GUJARATI SIGN THREE-DOT NUKTA ABOVE
0AFE GUJARATI SIGN CIRCLE NUKTA ABOVE
0AFF GUJARATI SIGN TWO-CIRCLE NUKTA ABOVE
0B01 ORIYA SIGN CANDRABINDU
0B02 ORIYA SIGN ANUSVARA
0B03 ORIYA SIGN VISARGA
0B05 ORIYA LETTER A
0B06 ORIYA LETTER AA
0B07 ORIYA LETTER I
0B08 ORIYA LETTER II
0B09 ORIYA LETTER U
0B0A ORIYA LETTER UU
0B0B ORIYA LETTER VOCALIC R
0B0C ORIYA LETTER VOCALIC L
0B0F ORIYA LETTER E
0B10 ORIYA LETTER AI
0B13 ORIYA LETTER O
0B14 ORIYA LETTER AU
0B15 ORIYA LETTER KA
0B16 ORIYA LETTER KHA
0B17 ORIYA LETTER GA
0B18 ORIYA LETTER GHA
0B19 ORIYA LETTER NGA
0B1A ORIYA LETTER CA
0B1B ORIYA LETTER CHA
0B1C ORIYA LETTER JA
0B1D ORIYA LETTER JHA
0B1E ORIYA LETTER NYA
0B1F ORIYA LETTER TTA
0B20 ORIYA LETTER TTHA
0B21 ORIYA LETTER DDA
0B22 ORIYA LETTER DDHA
0B23 ORIYA LETTER NNA
0B24 ORIYA LETTER TA
0B25 ORIYA LETTER THA
0B26 ORIYA LETTER DA
0B27 ORIYA LETTER DHA
0B28 ORIYA LETTER NA
0B2A ORIYA LETTER PA
0B2B ORIYA LETTER PHA
0B2C ORIYA LETTER BA
0B2D ORIYA LETTER BHA
0B2E ORIYA LETTER MA
0B2F ORIYA LETTER YA
0B30 ORIYA LETTER RA
0B32 ORIYA LETTER LA
0B33 ORIYA LETTER LLA
0B35 ORIYA LETTER VA
0B36 ORIYA LETTER SHA
0B37 ORIYA LETTER SSA
0B38 ORIYA LETTER SA
0B39 ORIYA LETTER HA
0B3C ORIYA SIGN NUKTA
0B3D ORIYA SIGN AVAGRAHA
0B3E ORIYA VOWEL SIGN AA
0B3F ORIYA VOWEL SIGN I
0B40 ORIYA VOWEL SIGN II
0B41 ORIYA VOWEL SIGN U
0B42 ORIYA VOWEL SIGN UU
0B43 ORIYA VOWEL SIGN VOCALIC R
0B44 ORIYA VOWEL SIGN VOCALIC RR
0B47 ORIYA VOWEL SIGN E
0B48 ORIYA VOWEL SIGN AI
0B4B ORIYA VOWEL SIGN O
0B4C ORIYA VOWEL SIGN AU
0B4D ORIYA SIGN VIRAMA
0B56 ORIYA AI LENGTH MARK
0B57 ORIYA AU LENGTH MARK
0B5C ORIYA LETTER RRA
0B5D ORIYA LETTER RHA
0B5F ORIYA LETTER YYA
0B60 ORIYA LETTER VOCALIC RR
0B61 ORIYA LETTER VOCALIC LL
0B62 ORIYA VOWEL SIGN VOCALIC L
0B63 ORIYA VOWEL SIGN VOCALIC LL
0B66 ORIYA DIGIT ZERO
0B67 ORIYA DIGIT ONE
0B68 ORIYA DIGIT TWO
0B69 ORIYA DIGIT THREE
0B6A ORIYA DIGIT FOUR
0B6B ORIYA DIGIT FIVE
0B6C ORIYA DIGIT SIX
0B6D ORIYA DIGIT SEVEN
0B6E ORIYA DIGIT EIGHT
0B6F ORIYA DIGIT NINE
0B70 ORIYA ISSHAR
0B71 ORIYA LETTER WA
0B72 ORIYA FRACTION ONE QUARTER
0B73 ORIYA FRACTION ONE HALF
0B74 ORIYA FRACTION THREE QUARTERS
0B75 ORIYA FRACTION ONE SIXTEENTH
0B76 ORIYA FRACTION ONE EIGHTH
0B77 ORIYA FRACTION THREE SIXTEENTHS
0B82 TAMIL SIGN ANUSVARA
0B83 TAMIL SIGN VISARGA
0B85 TAMIL LETTER A
0B86 TAMIL LETTER AA
0B87 TAMIL LETTER I
0B88 TAMIL LETTER II
0B89 TAMIL LETTER U
0B8A TAMIL LETTER UU
0B8E TAMIL LETTER E
0B8F TAMIL LETTER EE
0B90 TAMIL LETTER AI
0B92 TAMIL LETTER O
0B93 TAMIL LETTER OO
0B94 TAMIL LETTER AU
0B95 TAMIL LETTER KA
0B99 TAMIL LETTER NGA
0B9A TAMIL LETTER CA
0B9C TAMIL LETTER JA
0B9E TAMIL LETTER NYA
0B9F TAMIL LETTER TTA
0BA3 TAMIL LETTER NNA
0BA4 TAMIL LETTER TA
0BA8 TAMIL LETTER NA
0BA9 TAMIL LETTER NNNA
0BAA TAMIL LETTER PA
0BAE TAMIL LETTER MA
0BAF TAMIL LETTER YA
0BB0 TAMIL LETTER RA
0BB1 TAMIL LETTER RRA
0BB2 TAMIL LETTER LA
0BB3 TAMIL LETTER LLA
0BB4 TAMIL LETTER LLLA
0BB5 TAMIL LETTER VA
0BB6 TAMIL LETTER SHA
0BB7 TAMIL LETTER SSA
0BB8 TAMIL LETTER SA
0BB9 TAMIL LETTER HA
0BBE TAMIL VOWEL SIGN AA
0BBF TAMIL VOWEL SIGN I
0BC0 TAMIL VOWEL SIGN II
0BC1 TAMIL VOWEL SIGN U
0BC2 TAMIL VOWEL SIGN UU
0BC6 TAMIL VOWEL SIGN E
0BC7 TAMIL VOWEL SIGN EE
0BC8 TAMIL VOWEL SIGN AI
0BCA TAMIL VOWEL SIGN O
0BCB TAMIL VOWEL SIGN OO
0BCC TAMIL VOWEL SIGN AU
0BCD TAMIL SIGN VIRAMA
0BD0 TAMIL OM
0BD7 TAMIL AU LENGTH MARK
0BE6 TAMIL DIGIT ZERO
0BE7 TAMIL DIGIT ONE
0BE8 TAMIL DIGIT TWO
0BE9 TAMIL DIGIT THREE
0BEA TAMIL DIGIT FOUR
0BEB TAMIL DIGIT FIVE
0BEC TAMIL DIGIT SIX
0BED TAMIL DIGIT SEVEN
0BEE TAMIL DIGIT EIGHT
0BEF TAMIL DIGIT NINE
0BF0 TAMIL NUMBER TEN
0BF1 TAMIL NUMBER ONE HUNDRED
0BF2 TAMIL NUMBER ONE THOUSAND
0BF3 TAMIL DAY SIGN
0BF4 TAMIL MONTH SIGN
0BF5 TAMIL YEAR SIGN
0BF6 TAMIL DEBIT SIGN
0BF7 TAMIL CREDIT SIGN
0BF8 TAMIL AS ABOVE SIGN
0BF9 TAMIL RUPEE SIGN
0BFA TAMIL NUMBER SIGN
0C00 TELUGU SIGN COMBINING CANDRABINDU ABOVE
0C01 TELUGU SIGN CANDRABINDU
0C02 TELUGU SIGN ANUSVARA
0C03 TELUGU SIGN VISARGA
0C05 TELUGU LETTER A
0C06 TELUGU LETTER AA
0C07 TELUGU LETTER I
0C08 TELUGU LETTER II
0C09 TELUGU LETTER U
0C0A TELUGU LETTER UU
0C0B TELUGU LETTER VOCALIC R
0C0C TELUGU LETTER VOCALIC L
0C0E TELUGU LETTER E
0C0F TELUGU LETTER EE
0C10 TELUGU LETTER AI
0C12 TELUGU LETTER O
0C13 TELUGU LETTER OO
0C14 TELUGU LETTER AU
0C15 TELUGU LETTER KA
0C16 TELUGU LETTER KHA
0C17 TELUGU LETTER GA
0C18 TELUGU LETTER GHA
0C19 TELUGU LETTER NGA
0C1A TELUGU LETTER CA
0C1B TELUGU LETTER CHA
0C1C TELUGU LETTER JA
0C1D TELUGU LETTER JHA
0C1E TELUGU LETTER NYA
0C1F TELUGU LETTER TTA
0C20 TELUGU LETTER TTHA
0C21 TELUGU LETTER DDA
0C22 TELUGU LETTER DDHA
0C23 TELUGU LETTER NNA
0C24 TELUGU LETTER TA
0C25 TELUGU LETTER THA
0C26 TELUGU LETTER DA
0C27 TELUGU LETTER DHA
0C28 TELUGU LETTER NA
0C2A TELUGU LETTER PA
0C2B TELUGU LETTER PHA
0C2C TELUGU LETTER BA
0C2D TELUGU LETTER BHA
0C2E TELUGU LETTER MA
0C2F TELUGU LETTER YA
0C30 TELUGU LETTER RA
0C31 TELUGU LETTER RRA
0C32 TELUGU LETTER LA
0C33 TELUGU LETTER LLA
0C34 TELUGU LETTER LLLA
0C35 TELUGU LETTER VA
0C36 TELUGU LETTER SHA
0C37 TELUGU LETTER SSA
0C38 TELUGU LETTER SA
0C39 TELUGU LETTER HA
0C3D TELUGU SIGN AVAGRAHA
0C3E TELUGU VOWEL SIGN AA
0C3F TELUGU VOWEL SIGN I
0C40 TELUGU VOWEL SIGN II
0C41 TELUGU VOWEL SIGN U
0C42 TELUGU VOWEL SIGN UU
0C43 TELUGU VOWEL SIGN VOCALIC R
0C44 TELUGU VOWEL SIGN VOCALIC RR
0C46 TELUGU VOWEL SIGN E
0C47 TELUGU VOWEL SIGN EE
0C48 TELUGU VOWEL SIGN AI
0C4A TELUGU VOWEL SIGN O
0C4B TELUGU VOWEL SIGN OO
0C4C TELUGU VOWEL SIGN AU
0C4D TELUGU SIGN VIRAMA
0C55 TELUGU LENGTH MARK
0C56 TELUGU AI LENGTH MARK
0C58 TELUGU LETTER TSA
0C59 TELUGU LETTER DZA
0C5A TELUGU LETTER RRRA
0C60 TELUGU LETTER VOCALIC RR
0C61 TELUGU LETTER VOCALIC LL
0C62 TELUGU VOWEL SIGN VOCALIC L
0C63 TELUGU VOWEL SIGN VOCALIC LL
0C66 TELUGU DIGIT ZERO
0C67 TELUGU DIGIT ONE
0C68 TELUGU DIGIT TWO
0C69 TELUGU DIGIT THREE
0C6A TELUGU DIGIT FOUR
0C6B TELUGU DIGIT FIVE
0C6C TELUGU DIGIT SIX
0C6D TELUGU DIGIT SEVEN
0C6E TELUGU DIGIT EIGHT
0C6F TELUGU DIGIT NINE
0C78 TELUGU FRACTION DIGIT ZERO FOR ODD POWERS OF FOUR
0C79 TELUGU FRACTION DIGIT ONE FOR ODD POWERS OF FOUR
0C7A TELUGU FRACTION DIGIT TWO FOR ODD POWERS OF FOUR
0C7B TELUGU FRACTION DIGIT THREE FOR ODD POWERS OF FOUR
0C7C TELUGU FRACTION DIGIT ONE FOR EVEN POWERS OF FOUR
0C7D TELUGU FRACTION DIGIT TWO FOR EVEN POWERS OF FOUR
0C7E TELUGU FRACTION DIGIT THREE FOR EVEN POWERS OF FOUR
0C7F TELUGU SIGN TUUMU
0C80 KANNADA SIGN SPACING CANDRABINDU
0C81 KANNADA SIGN CANDRABINDU
0C82 KANNADA SIGN ANUSVARA
0C83 KANNADA SIGN VISARGA
0C85 KANNADA LETTER A
0C86 KANNADA LETTER AA
0C87 KANNADA LETTER I
0C88 KANNADA LETTER II
0C89 KANNADA LETTER U
0C8A KANNADA LETTER UU
0C8B KANNADA LETTER VOCALIC R
0C8C KANNADA LETTER VOCALIC L
0C8E KANNADA LETTER E
0C8F KANNADA LETTER EE
0C90 KANNADA LETTER AI
0C92 KANNADA LETTER O
0C93 KANNADA LETTER OO
0C94 KANNADA LETTER AU
0C95 KANNADA LETTER KA
0C96 KANNADA LETTER KHA
0C97 KANNADA LETTER GA
0C98 KANNADA LETTER GHA
0C99 KANNADA LETTER NGA
0C9A KANNADA LETTER CA
0C9B KANNADA LETTER CHA
0C9C KANNADA LETTER JA
0C9D KANNADA LETTER JHA
0C9E KANNADA LETTER NYA
0C9F KANNADA LETTER TTA
0CA0 KANNADA LETTER TTHA
0CA1 KANNADA LETTER DDA
0CA2 KANNADA LETTER DDHA
0CA3 KANNADA LETTER NNA
0CA4 KANNADA LETTER TA
0CA5 KANNADA LETTER THA
0CA6 KANNADA LETTER DA
0CA7 KANNADA LETTER DHA
0CA8 KANNADA LETTER NA
0CAA KANNADA LETTER PA
0CAB KANNADA LETTER PHA
0CAC KANNADA LETTER BA
0CAD KANNADA LETTER BHA
0CAE KANNADA LETTER MA
0CAF KANNADA LETTER YA
0CB0 KANNADA LETTER RA
0CB1 KANNADA LETTER RRA
0CB2 KANNADA LETTER LA
0CB3 KANNADA LETTER LLA
0CB5 KANNADA LETTER VA
0CB6 KANNADA LETTER SHA
0CB7 KANNADA LETTER SSA
0CB8 KANNADA LETTER SA
0CB9 KANNADA LETTER HA
0CBC KANNADA SIGN NUKTA
0CBD KANNADA SIGN AVAGRAHA
0CBE KANNADA VOWEL SIGN AA
0CBF KANNADA VOWEL SIGN I
0CC0 KANNADA VOWEL SIGN II
0CC1 KANNADA VOWEL SIGN U
0CC2 KANNADA VOWEL SIGN UU
0CC3 KANNADA VOWEL SIGN VOCALIC R
0CC4 KANNADA VOWEL SIGN VOCALIC RR
0CC6 KANNADA VOWEL SIGN E
0CC7 KANNADA VOWEL SIGN EE
0CC8 KANNADA VOWEL SIGN AI
0CCA KANNADA VOWEL SIGN O
0CCB KANNADA VOWEL SIGN OO
0CCC KANNADA VOWEL SIGN AU
0CCD KANNADA SIGN VIRAMA
0CD5 KANNADA LENGTH MARK
0CD6 KANNADA AI LENGTH MARK
0CDE KANNADA LETTER FA
0CE0 KANNADA LETTER VOCALIC RR
0CE1 KANNADA LETTER VOCALIC LL
0CE2 KANNADA VOWEL SIGN VOCALIC L
0CE3 KANNADA VOWEL SIGN VOCALIC LL
0CE6 KANNADA DIGIT ZERO
0CE7 KANNADA DIGIT ONE
0CE8 KANNADA DIGIT TWO
0CE9 KANNADA DIGIT THREE
0CEA KANNADA DIGIT FOUR
0CEB KANNADA DIGIT FIVE
0CEC KANNADA DIGIT SIX
0CED KANNADA DIGIT SEVEN
0CEE KANNADA DIGIT EIGHT
0CEF KANNADA DIGIT NINE
0CF1 KANNADA SIGN JIHVAMULIYA
0CF2 KANNADA SIGN UPADHMANIYA
0D00 MALAYALAM SIGN COMBINING ANUSVARA ABOVE
0D01 MALAYALAM SIGN CANDRABINDU
0D02 MALAYALAM SIGN ANUSVARA
0D03 MALAYALAM SIGN VISARGA
0D05 MALAYALAM LETTER A
0D06 MALAYALAM LETTER AA
0D07 MALAYALAM LETTER I
0D08 MALAYALAM LETTER II
0D09 MALAYALAM LETTER U
0D0A MALAYALAM LETTER UU
0D0B MALAYALAM LETTER VOCALIC R
0D0C MALAYALAM LETTER VOCALIC L
0D0E MALAYALAM LETTER E
0D0F MALAYALAM LETTER EE
0D10 MALAYALAM LETTER AI
0D12 MALAYALAM LETTER O
0D13 MALAYALAM LETTER OO
0D14 MALAYALAM LETTER AU
0D15 MALAYALAM LETTER KA
0D16 MALAYALAM LETTER KHA
0D17 MALAYALAM LETTER GA
0D18 MALAYALAM LETTER GHA
0D19 MALAYALAM LETTER NGA
0D1A MALAYALAM LETTER CA
0D1B MALAYALAM LETTER CHA
0D1C MALAYALAM LETTER JA
0D1D MALAYALAM LETTER JHA
0D1E MALAYALAM LETTER NYA
0D1F MALAYALAM LETTER TTA
0D20 MALAYALAM LETTER TTHA
0D21 MALAYALAM LETTER DDA
0D22 MALAYALAM LETTER DDHA
0D23 MALAYALAM LETTER NNA
0D24 MALAYALAM LETTER TA
0D25 MALAYALAM LETTER THA
0D26 MALAYALAM LETTER DA
0D27 MALAYALAM LETTER DHA
0D28 MALAYALAM LETTER NA
0D29 MALAYALAM LETTER NNNA
0D2A MALAYALAM LETTER PA
0D2B MALAYALAM LETTER PHA
0D2C MALAYALAM LETTER BA
0D2D MALAYALAM LETTER BHA
0D2E MALAYALAM LETTER MA
0D2F MALAYALAM LETTER YA
0D30 MALAYALAM LETTER RA
0D31 MALAYALAM LETTER RRA
0D32 MALAYALAM LETTER LA
0D33 MALAYALAM LETTER LLA
0D34 MALAYALAM LETTER LLLA
0D35 MALAYALAM LETTER VA
0D36 MALAYALAM LETTER SHA
0D37 MALAYALAM LETTER SSA
0D38 MALAYALAM LETTER SA
0D39 MALAYALAM LETTER HA
0D3A MALAYALAM LETTER TTTA
0D3B MALAYALAM SIGN VERTICAL BAR VIRAMA
0D3C MALAYALAM SIGN CIRCULAR VIRAMA
0D3D MALAYALAM SIGN AVAGRAHA
0D3E MALAYALAM VOWEL SIGN AA
0D3F MALAYALAM VOWEL SIGN I
0D40 MALAYALAM VOWEL SIGN II
0D41 MALAYALAM VOWEL SIGN U
0D42 MALAYALAM VOWEL SIGN UU
0D43 MALAYALAM VOWEL SIGN VOCALIC R
0D44 MALAYALAM VOWEL SIGN VOCALIC RR
0D46 MALAYALAM VOWEL SIGN E
0D47 MALAYALAM VOWEL SIGN EE
0D48 MALAYALAM VOWEL SIGN AI
0D4A MALAYALAM VOWEL SIGN O
0D4B MALAYALAM VOWEL SIGN OO
0D4C MALAYALAM VOWEL SIGN AU
0D4D MALAYALAM SIGN VIRAMA
0D4E MALAYALAM LETTER DOT REPH
0D4F MALAYALAM SIGN PARA
0D54 MALAYALAM LETTER CHILLU M
0D55 MALAYALAM LETTER CHILLU Y
0D56 MALAYALAM LETTER CHILLU LLL
0D57 MALAYALAM AU LENGTH MARK
0D58 MALAYALAM FRACTION ONE ONE-HUNDRED-AND-SIXTIETH
0D59 MALAYALAM FRACTION ONE FORTIETH
0D5A MALAYALAM FRACTION THREE EIGHTIETHS
0D5B MALAYALAM FRACTION ONE TWENTIETH
0D5C MALAYALAM FRACTION ONE TENTH
0D5D MALAYALAM FRACTION THREE TWENTIETHS
0D5E MALAYALAM FRACTION ONE FIFTH
0D5F MALAYALAM LETTER ARCHAIC II
0D60 MALAYALAM LETTER VOCALIC RR
0D61 MALAYALAM LETTER VOCALIC LL
0D62 MALAYALAM VOWEL SIGN VOCALIC L
0D63 MALAYALAM VOWEL SIGN VOCALIC LL
0D66 MALAYALAM DIGIT ZERO
0D67 MALAYALAM DIGIT ONE
0D68 MALAYALAM DIGIT TWO
0D69 MALAYALAM DIGIT THREE
0D6A MALAYALAM DIGIT FOUR
0D6B MALAYALAM DIGIT FIVE
0D6C MALAYALAM DIGIT SIX
0D6D MALAYALAM DIGIT SEVEN
0D6E MALAYALAM DIGIT EIGHT
0D6F MALAYALAM DIGIT NINE
0D70 MALAYALAM NUMBER TEN
0D71 MALAYALAM NUMBER ONE HUNDRED
0D72 MALAYALAM NUMBER ONE THOUSAND
0D73 MALAYALAM FRACTION ONE QUARTER
0D74 MALAYALAM FRACTION ONE HALF
0D75 MALAYALAM FRACTION THREE QUARTERS
0D76 MALAYALAM FRACTION ONE SIXTEENTH
0D77 MALAYALAM FRACTION ONE EIGHTH
0D78 MALAYALAM FRACTION THREE SIXTEENTHS
0D79 MALAYALAM DATE MARK
0D7A MALAYALAM LETTER CHILLU NN
0D7B MALAYALAM LETTER CHILLU N
0D7C MALAYALAM LETTER CHILLU RR
0D7D MALAYALAM LETTER CHILLU L
0D7E MALAYALAM LETTER CHILLU LL
0D7F MALAYALAM LETTER CHILLU K
0D82 SINHALA SIGN ANUSVARAYA
0D83 SINHALA SIGN VISARGAYA
0D85 SINHALA LETTER AYANNA
0D86 SINHALA LETTER AAYANNA
0D87 SINHALA LETTER AEYANNA
0D88 SINHALA LETTER AEEYANNA
0D89 SINHALA LETTER IYANNA
0D8A SINHALA LETTER IIYANNA
0D8B SINHALA LETTER UYANNA
0D8C SINHALA LETTER UUYANNA
0D8D SINHALA LETTER IRUYANNA
0D8E SINHALA LETTER IRUUYANNA
0D8F SINHALA LETTER ILUYANNA
0D90 SINHALA LETTER ILUUYANNA
0D91 SINHALA LETTER EYANNA
0D92 SINHALA LETTER EEYANNA
0D93 SINHALA LETTER AIYANNA
0D94 SINHALA LETTER OYANNA
0D95 SINHALA LETTER OOYANNA
0D96 SINHALA LETTER AUYANNA
0D9A SINHALA LETTER ALPAPRAANA KAYANNA
0D9B SINHALA LETTER MAHAAPRAANA KAYANNA
0D9C SINHALA LETTER ALPAPRAANA GAYANNA
0D9D SINHALA LETTER MAHAAPRAANA GAYANNA
0D9E SINHALA LETTER KANTAJA NAASIKYAYA
0D9F SINHALA LETTER SANYAKA GAYANNA
0DA0 SINHALA LETTER ALPAPRAANA CAYANNA
0DA1 SINHALA LETTER MAHAAPRAANA CAYANNA
0DA2 SINHALA LETTER ALPAPRAANA JAYANNA
0DA3 SINHALA LETTER MAHAAPRAANA JAYANNA
0DA4 SINHALA LETTER TAALUJA NAASIKYAYA
0DA5 SINHALA LETTER TAALUJA SANYOOGA NAAKSIKYAYA
0DA6 SINHALA LETTER SANYAKA JAYANNA
0DA7 SINHALA LETTER ALPAPRAANA TTAYANNA
0DA8 SINHALA LETTER MAHAAPRAANA TTAYANNA
0DA9 SINHALA LETTER ALPAPRAANA DDAYANNA
0DAA SINHALA LETTER MAHAAPRAANA DDAYANNA
0DAB SINHALA LETTER MUURDHAJA NAYANNA
0DAC SINHALA LETTER SANYAKA DDAYANNA
0DAD SINHALA LETTER ALPAPRAANA TAYANNA
0DAE SINHALA LETTER MAHAAPRAANA TAYANNA
0DAF SINHALA LETTER ALPAPRAANA DAYANNA
0DB0 SINHALA LETTER MAHAAPRAANA DAYANNA
0DB1 SINHALA LETTER DANTAJA NAYANNA
0DB3 SINHALA LETTER SANYAKA DAYANNA
0DB4 SINHALA LETTER ALPAPRAANA PAYANNA
0DB5 SINHALA LETTER MAHAAPRAANA PAYANNA
0DB6 SINHALA LETTER ALPAPRAANA BAYANNA
0DB7 SINHALA LETTER MAHAAPRAANA BAYANNA
0DB8 SINHALA LETTER MAYANNA
0DB9 SINHALA LETTER AMBA BAYANNA
0DBA SINHALA LETTER YAYANNA
0DBB SINHALA LETTER RAYANNA
0DBD SINHALA LETTER DANTAJA LAYANNA
0DC0 SINHALA LETTER VAYANNA
0DC1 SINHALA LETTER TAALUJA SAYANNA
0DC2 SINHALA LETTER MUURDHAJA SAYANNA
0DC3 SINHALA LETTER DANTAJA SAYANNA
0DC4 SINHALA LETTER HAYANNA
0DC5 SINHALA LETTER MUURDHAJA LAYANNA
0DC6 SINHALA LETTER FAYANNA
0DCA SINHALA SIGN AL-LAKUNA
0DCF SINHALA VOWEL SIGN AELA-PILLA
0DD0 SINHALA VOWEL SIGN KETTI AEDA-PILLA
0DD1 SINHALA VOWEL SIGN DIGA AEDA-PILLA
0DD2 SINHALA VOWEL SIGN KETTI IS-PILLA
0DD3 SINHALA VOWEL SIGN DIGA IS-PILLA
0DD4 SINHALA VOWEL SIGN KETTI PAA-PILLA
0DD6 SINHALA VOWEL SIGN DIGA PAA-PILLA
0DD8 SINHALA VOWEL SIGN GAETTA-PILLA
0DD9 SINHALA VOWEL SIGN KOMBUVA
0DDA SINHALA VOWEL SIGN DIGA KOMBUVA
0DDB SINHALA VOWEL SIGN KOMBU DEKA
0DDC SINHALA VOWEL SIGN KOMBUVA HAA AELA-PILLA
0DDD SINHALA VOWEL SIGN KOMBUVA HAA DIGA AELA-PILLA
0DDE SINHALA VOWEL SIGN KOMBUVA HAA GAYANUKITTA
0DDF SINHALA VOWEL SIGN GAYANUKITTA
0DE6 SINHALA LITH DIGIT ZERO
0DE7 SINHALA LITH DIGIT ONE
0DE8 SINHALA LITH DIGIT TWO
0DE9 SINHALA LITH DIGIT THREE
0DEA SINHALA LITH DIGIT FOUR
0DEB SINHALA LITH DIGIT FIVE
0DEC SINHALA LITH DIGIT SIX
0DED SINHALA LITH DIGIT SEVEN
0DEE SINHALA LITH DIGIT EIGHT
0DEF SINHALA LITH DIGIT NINE
0DF2 SINHALA VOWEL SIGN DIGA GAETTA-PILLA
0DF3 SINHALA VOWEL SIGN DIGA GAYANUKITTA
0DF4 SINHALA PUNCTUATION KUNDDALIYA
0E01 THAI CHARACTER KO KAI
0E02 THAI CHARACTER KHO KHAI
0E03 THAI CHARACTER KHO KHUAT
0E04 THAI CHARACTER KHO KHWAI
0E05 THAI CHARACTER KHO KHON
0E06 THAI CHARACTER KHO RAKHANG
0E07 THAI CHARACTER NGO NGU
0E08 THAI CHARACTER CHO CHAN
0E09 THAI CHARACTER CHO CHING
0E0A THAI CHARACTER CHO CHANG
0E0B THAI CHARACTER SO SO
0E0C THAI CHARACTER CHO CHOE
0E0D THAI CHARACTER YO YING
0E0E THAI CHARACTER DO CHADA
0E0F THAI CHARACTER TO PATAK
0E10 THAI CHARACTER THO THAN
0E11 THAI CHARACTER THO NANGMONTHO
0E12 THAI CHARACTER THO PHUTHAO
0E13 THAI CHARACTER NO NEN
0E14 THAI CHARACTER DO DEK
0E15 THAI CHARACTER TO TAO
0E16 THAI CHARACTER THO THUNG
0E17 THAI CHARACTER THO THAHAN
0E18 THAI CHARACTER THO THONG
0E19 THAI CHARACTER NO NU
0E1A THAI CHARACTER BO BAIMAI
0E1B THAI CHARACTER PO PLA
0E1C THAI CHARACTER PHO PHUNG
0E1D THAI CHARACTER FO FA
0E1E THAI CHARACTER PHO PHAN
0E1F THAI CHARACTER FO FAN
0E20 THAI CHARACTER PHO SAMPHAO
0E21 THAI CHARACTER MO MA
0E22 THAI CHARACTER YO YAK
0E23 THAI CHARACTER RO RUA
0E24 THAI CHARACTER RU
0E25 THAI CHARACTER LO LING
0E26 THAI CHARACTER LU
0E27 THAI CHARACTER WO WAEN
0E28 THAI CHARACTER SO SALA
0E29 THAI CHARACTER SO RUSI
0E2A THAI CHARACTER SO SUA
0E2B THAI CHARACTER HO HIP
0E2C THAI CHARACTER LO CHULA
0E2D THAI CHARACTER O ANG
0E2E THAI CHARACTER HO NOKHUK
0E2F THAI CHARACTER PAIYANNOI
0E30 THAI CHARACTER SARA A
0E31 THAI CHARACTER MAI HAN-AKAT
0E32 THAI CHARACTER SARA AA
0E33 THAI CHARACTER SARA AM
0E34 THAI CHARACTER SARA I
0E35 THAI CHARACTER SARA II
0E36 THAI CHARACTER SARA UE
0E37 THAI CHARACTER SARA UEE
0E38 THAI CHARACTER SARA U
0E39 THAI CHARACTER SARA UU
0E3A THAI CHARACTER PHINTHU
0E3F THAI CURRENCY SYMBOL BAHT
0E40 THAI CHARACTER SARA E
0E41 THAI CHARACTER SARA AE
0E42 THAI CHARACTER SARA O
0E43 THAI CHARACTER SARA AI MAIMUAN
0E44 THAI CHARACTER SARA AI MAIMALAI
0E45 THAI CHARACTER LAKKHANGYAO
0E46 THAI CHARACTER MAIYAMOK
0E47 THAI CHARACTER MAITAIKHU
0E48 THAI CHARACTER MAI EK
0E49 THAI CHARACTER MAI THO
0E4A THAI CHARACTER MAI TRI
0E4B THAI CHARACTER MAI CHATTAWA
0E4C THAI CHARACTER THANTHAKHAT
0E4D THAI CHARACTER NIKHAHIT
0E4E THAI CHARACTER YAMAKKAN
0E4F THAI CHARACTER FONGMAN
0E50 THAI DIGIT ZERO
0E51 THAI DIGIT ONE
0E52 THAI DIGIT TWO
0E53 THAI DIGIT THREE
0E54 THAI DIGIT FOUR
0E55 THAI DIGIT FIVE
0E56 THAI DIGIT SIX
0E57 THAI DIGIT SEVEN
0E58 THAI DIGIT EIGHT
0E59 THAI DIGIT NINE
0E5A THAI CHARACTER ANGKHANKHU
0E5B THAI CHARACTER KHOMUT
0E81 LAO LETTER KO
0E82 LAO LETTER KHO SUNG
0E84 LAO LETTER KHO TAM
0E87 LAO LETTER NGO
0E88 LAO LETTER CO
0E8A LAO LETTER SO TAM
0E8D LAO LETTER NYO
0E94 LAO LETTER DO
0E95 LAO LETTER TO
0E96 LAO LETTER THO SUNG
0E97 LAO LETTER THO TAM
0E99 LAO LETTER NO
0E9A LAO LETTER BO
0E9B LAO LETTER PO
0E9C LAO LETTER PHO SUNG
0E9D LAO LETTER FO TAM
0E9E LAO LETTER PHO TAM
0E9F LAO LETTER FO SUNG
0EA1 LAO LETTER MO
0EA2 LAO LETTER YO
0EA3 LAO LETTER LO LING
0EA5 LAO LETTER LO LOOT
0EA7 LAO LETTER WO
0EAA LAO LETTER SO SUNG
0EAB LAO LETTER HO SUNG
0EAD LAO LETTER O
0EAE LAO LETTER HO TAM
0EAF LAO ELLIPSIS
0EB0 LAO VOWEL SIGN A
0EB1 LAO VOWEL SIGN MAI KAN
0EB2 LAO VOWEL SIGN AA
0EB3 LAO VOWEL SIGN AM
0EB4 LAO VOWEL SIGN I
0EB5 LAO VOWEL SIGN II
0EB6 LAO VOWEL SIGN Y
0EB7 LAO VOWEL SIGN YY
0EB8 LAO VOWEL SIGN U
0EB9 LAO VOWEL SIGN UU
0EBB LAO VOWEL SIGN MAI KON
0EBC LAO SEMIVOWEL SIGN LO
0EBD LAO SEMIVOWEL SIGN NYO
0EC0 LAO VOWEL SIGN E
0EC1 LAO VOWEL SIGN EI
0EC2 LAO VOWEL SIGN O
0EC3 LAO VOWEL SIGN AY
0EC4 LAO VOWEL SIGN AI
0EC6 LAO KO LA
0EC8 LAO TONE MAI EK
0EC9 LAO TONE MAI THO
0ECA LAO TONE MAI TI
0ECB LAO TONE MAI CATAWA
0ECC LAO CANCELLATION MARK
0ECD LAO NIGGAHITA
0ED0 LAO DIGIT ZERO
0ED1 LAO DIGIT ONE
0ED2 LAO DIGIT TWO
0ED3 LAO DIGIT THREE
0ED4 LAO DIGIT FOUR
0ED5 LAO DIGIT FIVE
0ED6 LAO DIGIT SIX
0ED7 LAO DIGIT SEVEN
0ED8 LAO DIGIT EIGHT
0ED9 LAO DIGIT NINE
0EDC LAO HO NO
0EDD LAO HO MO
0EDE LAO LETTER KHMU GO
0EDF LAO LETTER KHMU NYO
0F00 TIBETAN SYLLABLE OM
0F01 TIBETAN MARK GTER YIG MGO TRUNCATED A
0F02 TIBETAN MARK GTER YIG MGO -UM RNAM BCAD MA
0F03 TIBETAN MARK GTER YIG MGO -UM GTER TSHEG MA
0F04 TIBETAN MARK INITIAL YIG MGO MDUN MA
0F05 TIBETAN MARK CLOSING YIG MGO SGAB MA
0F06 TIBETAN MARK CARET YIG MGO PHUR SHAD MA
0F07 TIBETAN MARK YIG MGO TSHEG SHAD MA
0F08 TIBETAN MARK SBRUL SHAD
0F09 TIBETAN MARK BSKUR YIG MGO
0F0A TIBETAN MARK BKA- SHOG YIG MGO
0F0B TIBETAN MARK INTERSYLLABIC TSHEG
0F0C TIBETAN MARK DELIMITER TSHEG BSTAR
0F0D TIBETAN MARK SHAD
0F0E TIBETAN MARK NYIS SHAD
0F0F TIBETAN MARK TSHEG SHAD
0F10 TIBETAN MARK NYIS TSHEG SHAD
0F11 TIBETAN MARK RIN CHEN SPUNGS SHAD
0F12 TIBETAN MARK RGYA GRAM SHAD
0F13 TIBETAN MARK CARET -DZUD RTAGS ME LONG CAN
0F14 TIBETAN MARK GTER TSHEG
0F15 TIBETAN LOGOTYPE SIGN CHAD RTAGS
0F16 TIBETAN LOGOTYPE SIGN LHAG RTAGS
0F17 TIBETAN ASTROLOGICAL SIGN SGRA GCAN -CHAR RTAGS
0F18 TIBETAN ASTROLOGICAL SIGN -KHYUD PA
0F19 TIBETAN ASTROLOGICAL SIGN SDONG TSHUGS
0F1A TIBETAN SIGN RDEL DKAR GCIG
0F1B TIBETAN SIGN RDEL DKAR GNYIS
0F1C TIBETAN SIGN RDEL DKAR GSUM
0F1D TIBETAN SIGN RDEL NAG GCIG
0F1E TIBETAN SIGN RDEL NAG GNYIS
0F1F TIBETAN SIGN RDEL DKAR RDEL NAG
0F20 TIBETAN DIGIT ZERO
0F21 TIBETAN DIGIT ONE
0F22 TIBETAN DIGIT TWO
0F23 TIBETAN DIGIT THREE
0F24 TIBETAN DIGIT FOUR
0F25 TIBETAN DIGIT FIVE
0F26 TIBETAN DIGIT SIX
0F27 TIBETAN DIGIT SEVEN
0F28 TIBETAN DIGIT EIGHT
0F29 TIBETAN DIGIT NINE
0F2A TIBETAN DIGIT HALF ONE
0F2B TIBETAN DIGIT HALF TWO
0F2C TIBETAN DIGIT HALF THREE
0F2D TIBETAN DIGIT HALF FOUR
0F2E TIBETAN DIGIT HALF FIVE
0F2F TIBETAN DIGIT HALF SIX
0F30 TIBETAN DIGIT HALF SEVEN
0F31 TIBETAN DIGIT HALF EIGHT
0F32 TIBETAN DIGIT HALF NINE
0F33 TIBETAN DIGIT HALF ZERO
0F34 TIBETAN MARK BSDUS RTAGS
0F35 TIBETAN MARK NGAS BZUNG NYI ZLA
0F36 TIBETAN MARK CARET -DZUD RTAGS BZHI MIG CAN
0F37 TIBETAN MARK NGAS BZUNG SGOR RTAGS
0F38 TIBETAN MARK CHE MGO
0F39 TIBETAN MARK TSA -PHRU
0F3A TIBETAN MARK GUG RTAGS GYON
0F3B TIBETAN MARK GUG RTAGS GYAS
0F3C TIBETAN MARK ANG KHANG GYON
0F3D TIBETAN MARK ANG KHANG GYAS
0F3E TIBETAN SIGN YAR TSHES
0F3F TIBETAN SIGN MAR TSHES
0F40 TIBETAN LETTER KA
0F41 TIBETAN LETTER KHA
0F42 TIBETAN LETTER GA
0F43 TIBETAN LETTER GHA
0F44 TIBETAN LETTER NGA
0F45 TIBETAN LETTER CA
0F46 TIBETAN LETTER CHA
0F47 TIBETAN LETTER JA
0F49 TIBETAN LETTER NYA
0F4A TIBETAN LETTER TTA
0F4B TIBETAN LETTER TTHA
0F4C TIBETAN LETTER DDA
0F4D TIBETAN LETTER DDHA
0F4E TIBETAN LETTER NNA
0F4F TIBETAN LETTER TA
0F50 TIBETAN LETTER THA
0F51 TIBETAN LETTER DA
0F52 TIBETAN LETTER DHA
0F53 TIBETAN LETTER NA
0F54 TIBETAN LETTER PA
0F55 TIBETAN LETTER PHA
0F56 TIBETAN LETTER BA
0F57 TIBETAN LETTER BHA
0F58 TIBETAN LETTER MA
0F59 TIBETAN LETTER TSA
0F5A TIBETAN LETTER TSHA
0F5B TIBETAN LETTER DZA
0F5C TIBETAN LETTER DZHA
0F5D TIBETAN LETTER WA
0F5E TIBETAN LETTER ZHA
0F5F TIBETAN LETTER ZA
0F60 TIBETAN LETTER -A
0F61 TIBETAN LETTER YA
0F62 TIBETAN LETTER RA
0F63 TIBETAN LETTER LA
0F64 TIBETAN LETTER SHA
0F65 TIBETAN LETTER SSA
0F66 TIBETAN LETTER SA
0F67 TIBETAN LETTER HA
0F68 TIBETAN LETTER A
0F69 TIBETAN LETTER KSSA
0F6A TIBETAN LETTER FIXED-FORM RA
0F6B TIBETAN LETTER KKA
0F6C TIBETAN LETTER RRA
0F71 TIBETAN VOWEL SIGN AA
0F72 TIBETAN VOWEL SIGN I
0F73 TIBETAN VOWEL SIGN II
0F74 TIBETAN VOWEL SIGN U
0F75 TIBETAN VOWEL SIGN UU
0F76 TIBETAN VOWEL SIGN VOCALIC R
0F77 TIBETAN VOWEL SIGN VOCALIC RR
0F78 TIBETAN VOWEL SIGN VOCALIC L
0F79 TIBETAN VOWEL SIGN VOCALIC LL
0F7A TIBETAN VOWEL SIGN E
0F7B TIBETAN VOWEL SIGN EE
0F7C TIBETAN VOWEL SIGN O
0F7D TIBETAN VOWEL SIGN OO
0F7E TIBETAN SIGN RJES SU NGA RO
0F7F TIBETAN SIGN RNAM BCAD
0F80 TIBETAN VOWEL SIGN REVERSED I
0F81 TIBETAN VOWEL SIGN REVERSED II
0F82 TIBETAN SIGN NYI ZLA NAA DA
0F83 TIBETAN SIGN SNA LDAN
0F84 TIBETAN MARK HALANTA
0F85 TIBETAN MARK PALUTA
0F86 TIBETAN SIGN LCI RTAGS
0F87 TIBETAN SIGN YANG RTAGS
0F88 TIBETAN SIGN LCE TSA CAN
0F89 TIBETAN SIGN MCHU CAN
0F8A TIBETAN SIGN GRU CAN RGYINGS
0F8B TIBETAN SIGN GRU MED RGYINGS
0F8C TIBETAN SIGN INVERTED MCHU CAN
0F8D TIBETAN SUBJOINED SIGN LCE TSA CAN
0F8E TIBETAN SUBJOINED SIGN MCHU CAN
0F8F TIBETAN SUBJOINED SIGN INVERTED MCHU CAN
0F90 TIBETAN SUBJOINED LETTER KA
0F91 TIBETAN SUBJOINED LETTER KHA
0F92 TIBETAN SUBJOINED LETTER GA
0F93 TIBETAN SUBJOINED LETTER GHA
0F94 TIBETAN SUBJOINED LETTER NGA
0F95 TIBETAN SUBJOINED LETTER CA
0F96 TIBETAN SUBJOINED LETTER CHA
0F97 TIBETAN SUBJOINED LETTER JA
0F99 TIBETAN SUBJOINED LETTER NYA
0F9A TIBETAN SUBJOINED LETTER TTA
0F9B TIBETAN SUBJOINED LETTER TTHA
0F9C TIBETAN SUBJOINED LETTER DDA
0F9D TIBETAN SUBJOINED LETTER DDHA
0F9E TIBETAN SUBJOINED LETTER NNA
0F9F TIBETAN SUBJOINED LETTER TA
0FA0 TIBETAN SUBJOINED LETTER THA
0FA1 TIBETAN SUBJOINED LETTER DA
0FA2 TIBETAN SUBJOINED LETTER DHA
0FA3 TIBETAN SUBJOINED LETTER NA
0FA4 TIBETAN SUBJOINED LETTER PA
0FA5 TIBETAN SUBJOINED LETTER PHA
0FA6 TIBETAN SUBJOINED LETTER BA
0FA7 TIBETAN SUBJOINED LETTER BHA
0FA8 TIBETAN SUBJOINED LETTER MA
0FA9 TIBETAN SUBJOINED LETTER TSA
0FAA TIBETAN SUBJOINED LETTER TSHA
0FAB TIBETAN SUBJOINED LETTER DZA
0FAC TIBETAN SUBJOINED LETTER DZHA
0FAD TIBETAN SUBJOINED LETTER WA
0FAE TIBETAN SUBJOINED LETTER ZHA
0FAF TIBETAN SUBJOINED LETTER ZA
0FB0 TIBETAN SUBJOINED LETTER -A
0FB1 TIBETAN SUBJOINED LETTER YA
0FB2 TIBETAN SUBJOINED LETTER RA
0FB3 TIBETAN SUBJOINED LETTER LA
0FB4 TIBETAN SUBJOINED LETTER SHA
0FB5 TIBETAN SUBJOINED LETTER SSA
0FB6 TIBETAN SUBJOINED LETTER SA
0FB7 TIBETAN SUBJOINED LETTER HA
0FB8 TIBETAN SUBJOINED LETTER A
0FB9 TIBETAN SUBJOINED LETTER KSSA
0FBA TIBETAN SUBJOINED LETTER FIXED-FORM WA
0FBB TIBETAN SUBJOINED LETTER FIXED-FORM YA
0FBC TIBETAN SUBJOINED LETTER FIXED-FORM RA
0FBE TIBETAN KU RU KHA
0FBF TIBETAN KU RU KHA BZHI MIG CAN
0FC0 TIBETAN CANTILLATION SIGN HEAVY BEAT
0FC1 TIBETAN CANTILLATION SIGN LIGHT BEAT
0FC2 TIBETAN CANTILLATION SIGN CANG TE-U
0FC3 TIBETAN CANTILLATION SIGN SBUB -CHAL
0FC4 TIBETAN SYMBOL DRIL BU
0FC5 TIBETAN SYMBOL RDO RJE
0FC6 TIBETAN SYMBOL PADMA GDAN
0FC7 TIBETAN SYMBOL RDO RJE RGYA GRAM
0FC8 TIBETAN SYMBOL PHUR PA
0FC9 TIBETAN SYMBOL NOR BU
0FCA TIBETAN SYMBOL NOR BU NYIS -KHYIL
0FCB TIBETAN SYMBOL NOR BU GSUM -KHYIL
0FCC TIBETAN SYMBOL NOR BU BZHI -KHYIL
0FCE TIBETAN SIGN RDEL NAG RDEL DKAR
0FCF TIBETAN SIGN RDEL NAG GSUM
0FD0 TIBETAN MARK BSKA- SHOG GI MGO RGYAN
0FD1 TIBETAN MARK MNYAM YIG GI MGO RGYAN
0FD2 TIBETAN MARK NYIS TSHEG
0FD3 TIBETAN MARK INITIAL BRDA RNYING YIG MGO MDUN MA
0FD4 TIBETAN MARK CLOSING BRDA RNYING YIG MGO SGAB MA
0FD5 RIGHT-FACING SVASTI SIGN
0FD6 LEFT-FACING SVASTI SIGN
0FD7 RIGHT-FACING SVASTI SIGN WITH DOTS
0FD8 LEFT-FACING SVASTI SIGN WITH DOTS
0FD9 TIBETAN MARK LEADING MCHAN RTAGS
0FDA TIBETAN MARK TRAILING MCHAN RTAGS
1000 MYANMAR LETTER KA
1001 MYANMAR LETTER KHA
1002 MYANMAR LETTER GA
1003 MYANMAR LETTER GHA
1004 MYANMAR LETTER NGA
1005 MYANMAR LETTER CA
1006 MYANMAR LETTER CHA
1007 MYANMAR LETTER JA
1008 MYANMAR LETTER JHA
1009 MYANMAR LETTER NYA
100A MYANMAR LETTER NNYA
100B MYANMAR LETTER TTA
100C MYANMAR LETTER TTHA
100D MYANMAR LETTER DDA
100E MYANMAR LETTER DDHA
100F MYANMAR LETTER NNA
1010 MYANMAR LETTER TA
1011 MYANMAR LETTER THA
1012 MYANMAR LETTER DA
1013 MYANMAR LETTER DHA
1014 MYANMAR LETTER NA
1015 MYANMAR LETTER PA
1016 MYANMAR LETTER PHA
1017 MYANMAR LETTER BA
1018 MYANMAR LETTER BHA
1019 MYANMAR LETTER MA
101A MYANMAR LETTER YA
101B MYANMAR LETTER RA
101C MYANMAR LETTER LA
101D MYANMAR LETTER WA
101E MYANMAR LETTER SA
101F MYANMAR LETTER HA
1020 MYANMAR LETTER LLA
1021 MYANMAR LETTER A
1022 MYANMAR LETTER SHAN A
1023 MYANMAR LETTER I
1024 MYANMAR LETTER II
1025 MYANMAR LETTER U
1026 MYANMAR LETTER UU
1027 MYANMAR LETTER E
1028 MYANMAR LETTER MON E
1029 MYANMAR LETTER O
102A MYANMAR LETTER AU
102B MYANMAR VOWEL SIGN TALL AA
102C MYANMAR VOWEL SIGN AA
102D MYANMAR VOWEL SIGN I
102E MYANMAR VOWEL SIGN II
102F MYANMAR VOWEL SIGN U
1030 MYANMAR VOWEL SIGN UU
1031 MYANMAR VOWEL SIGN E
1032 MYANMAR VOWEL SIGN AI
1033 MYANMAR VOWEL SIGN MON II
1034 MYANMAR VOWEL SIGN MON O
1035 MYANMAR VOWEL SIGN E ABOVE
1036 MYANMAR SIGN ANUSVARA
1037 MYANMAR SIGN DOT BELOW
1038 MYANMAR SIGN VISARGA
1039 MYANMAR SIGN VIRAMA
103A MYANMAR SIGN ASAT
103B MYANMAR CONSONANT SIGN MEDIAL YA
103C MYANMAR CONSONANT SIGN MEDIAL RA
103D MYANMAR CONSONANT SIGN MEDIAL WA
103E MYANMAR CONSONANT SIGN MEDIAL HA
103F MYANMAR LETTER GREAT SA
1040 MYANMAR DIGIT ZERO
1041 MYANMAR DIGIT ONE
1042 MYANMAR DIGIT TWO
1043 MYANMAR DIGIT THREE
1044 MYANMAR DIGIT FOUR
1045 MYANMAR DIGIT FIVE
1046 MYANMAR DIGIT SIX
1047 MYANMAR DIGIT SEVEN
1048 MYANMAR DIGIT EIGHT
1049 MYANMAR DIGIT NINE
104A MYANMAR SIGN LITTLE SECTION
104B MYANMAR SIGN SECTION
104C MYANMAR SYMBOL LOCATIVE
104D MYANMAR SYMBOL COMPLETED
104E MYANMAR SYMBOL AFOREMENTIONED
104F MYANMAR SYMBOL GENITIVE
1050 MYANMAR LETTER SHA
1051 MYANMAR LETTER SSA
1052 MYANMAR LETTER VOCALIC R
1053 MYANMAR LETTER VOCALIC RR
1054 MYANMAR LETTER VOCALIC L
1055 MYANMAR LETTER VOCALIC LL
1056 MYANMAR VOWEL SIGN VOCALIC R
1057 MYANMAR VOWEL SIGN VOCALIC RR
1058 MYANMAR VOWEL SIGN VOCALIC L
1059 MYANMAR VOWEL SIGN VOCALIC LL
105A MYANMAR LETTER MON NGA
105B MYANMAR LETTER MON JHA
105C MYANMAR LETTER MON BBA
105D MYANMAR LETTER MON BBE
105E MYANMAR CONSONANT SIGN MON MEDIAL NA
105F MYANMAR CONSONANT SIGN MON MEDIAL MA
1060 MYANMAR CONSONANT SIGN MON MEDIAL LA
1061 MYANMAR LETTER SGAW KAREN SHA
1062 MYANMAR VOWEL SIGN SGAW KAREN EU
1063 MYANMAR TONE MARK SGAW KAREN HATHI
1064 MYANMAR TONE MARK SGAW KAREN KE PHO
1065 MYANMAR LETTER WESTERN PWO KAREN THA
1066 MYANMAR LETTER WESTERN PWO KAREN PWA
1067 MYANMAR VOWEL SIGN WESTERN PWO KAREN EU
1068 MYANMAR VOWEL SIGN WESTERN PWO KAREN UE
1069 MYANMAR SIGN WESTERN PWO KAREN TONE-1
106A MYANMAR SIGN WESTERN PWO KAREN TONE-2
106B MYANMAR SIGN WESTERN PWO KAREN TONE-3
106C MYANMAR SIGN WESTERN PWO KAREN TONE-4
106D MYANMAR SIGN WESTERN PWO KAREN TONE-5
106E MYANMAR LETTER EASTERN PWO KAREN NNA
106F MYANMAR LETTER EASTERN PWO KAREN YWA
1070 MYANMAR LETTER EASTERN PWO KAREN GHWA
1071 MYANMAR VOWEL SIGN GEBA KAREN I
1072 MYANMAR VOWEL SIGN KAYAH OE
1073 MYANMAR VOWEL SIGN KAYAH U
1074 MYANMAR VOWEL SIGN KAYAH EE
1075 MYANMAR LETTER SHAN KA
1076 MYANMAR LETTER SHAN KHA
1077 MYANMAR LETTER SHAN GA
1078 MYANMAR LETTER SHAN CA
1079 MYANMAR LETTER SHAN ZA
107A MYANMAR LETTER SHAN NYA
107B MYANMAR LETTER SHAN DA
107C MYANMAR LETTER SHAN NA
107D MYANMAR LETTER SHAN PHA
107E MYANMAR LETTER SHAN FA
107F MYANMAR LETTER SHAN BA
1080 MYANMAR LETTER SHAN THA
1081 MYANMAR LETTER SHAN HA
1082 MYANMAR CONSONANT SIGN SHAN MEDIAL WA
1083 MYANMAR VOWEL SIGN SHAN AA
1084 MYANMAR VOWEL SIGN SHAN E
1085 MYANMAR VOWEL SIGN SHAN E ABOVE
1086 MYANMAR VOWEL SIGN SHAN FINAL Y
1087 MYANMAR SIGN SHAN TONE-2
1088 MYANMAR SIGN SHAN TONE-3
1089 MYANMAR SIGN SHAN TONE-5
108A MYANMAR SIGN SHAN TONE-6
108B MYANMAR SIGN SHAN COUNCIL TONE-2
108C MYANMAR SIGN SHAN COUNCIL TONE-3
108D MYANMAR SIGN SHAN COUNCIL EMPHATIC TONE
108E MYANMAR LETTER RUMAI PALAUNG FA
108F MYANMAR SIGN RUMAI PALAUNG TONE-5
1090 MYANMAR SHAN DIGIT ZERO
1091 MYANMAR SHAN DIGIT ONE
1092 MYANMAR SHAN DIGIT TWO
1093 MYANMAR SHAN DIGIT THREE
1094 MYANMAR SHAN DIGIT FOUR
1095 MYANMAR SHAN DIGIT FIVE
1096 MYANMAR SHAN DIGIT SIX
1097 MYANMAR SHAN DIGIT SEVEN
1098 MYANMAR SHAN DIGIT EIGHT
1099 MYANMAR SHAN DIGIT NINE
109A MYANMAR SIGN KHAMTI TONE-1
109B MYANMAR SIGN KHAMTI TONE-3
109C MYANMAR VOWEL SIGN AITON A
109D MYANMAR VOWEL SIGN AITON AI
109E MYANMAR SYMBOL SHAN ONE
109F MYANMAR SYMBOL SHAN EXCLAMATION
10A0 GEORGIAN CAPITAL LETTER AN
10A1 GEORGIAN CAPITAL LETTER BAN
10A2 GEORGIAN CAPITAL LETTER GAN
10A3 GEORGIAN CAPITAL LETTER DON
10A4 GEORGIAN CAPITAL LETTER EN
10A5 GEORGIAN CAPITAL LETTER VIN
10A6 GEORGIAN CAPITAL LETTER ZEN
10A7 GEORGIAN CAPITAL LETTER TAN
10A8 GEORGIAN CAPITAL LETTER IN
10A9 GEORGIAN CAPITAL LETTER KAN
10AA GEORGIAN CAPITAL LETTER LAS
10AB GEORGIAN CAPITAL LETTER MAN
10AC GEORGIAN CAPITAL LETTER NAR
10AD GEORGIAN CAPITAL LETTER ON
10AE GEORGIAN CAPITAL LETTER PAR
10AF GEORGIAN CAPITAL LETTER ZHAR
10B0 GEORGIAN CAPITAL LETTER RAE
10B1 GEORGIAN CAPITAL LETTER SAN
10B2 GEORGIAN CAPITAL LETTER TAR
10B3 GEORGIAN CAPITAL LETTER UN
10B4 GEORGIAN CAPITAL LETTER PHAR
10B5 GEORGIAN CAPITAL LETTER KHAR
10B6 GEORGIAN CAPITAL LETTER GHAN
10B7 GEORGIAN CAPITAL LETTER QAR
10B8 GEORGIAN CAPITAL LETTER SHIN
10B9 GEORGIAN CAPITAL LETTER CHIN
10BA GEORGIAN CAPITAL LETTER CAN
10BB GEORGIAN CAPITAL LETTER JIL
10BC GEORGIAN CAPITAL LETTER CIL
10BD GEORGIAN CAPITAL LETTER CHAR
10BE GEORGIAN CAPITAL LETTER XAN
10BF GEORGIAN CAPITAL LETTER JHAN
10C0 GEORGIAN CAPITAL LETTER HAE
10C1 GEORGIAN CAPITAL LETTER HE
10C2 GEORGIAN CAPITAL LETTER HIE
10C3 GEORGIAN CAPITAL LETTER WE
10C4 GEORGIAN CAPITAL LETTER HAR
10C5 GEORGIAN CAPITAL LETTER HOE
10C7 GEORGIAN CAPITAL LETTER YN
10CD GEORGIAN CAPITAL LETTER AEN
10D0 GEORGIAN LETTER AN
10D1 GEORGIAN LETTER BAN
10D2 GEORGIAN LETTER GAN
10D3 GEORGIAN LETTER DON
10D4 GEORGIAN LETTER EN
10D5 GEORGIAN LETTER VIN
10D6 GEORGIAN LETTER ZEN
10D7 GEORGIAN LETTER TAN
10D8 GEORGIAN LETTER IN
10D9 GEORGIAN LETTER KAN
10DA GEORGIAN LETTER LAS
10DB GEORGIAN LETTER MAN
10DC GEORGIAN LETTER NAR
10DD GEORGIAN LETTER ON
10DE GEORGIAN LETTER PAR
10DF GEORGIAN LETTER ZHAR
10E0 GEORGIAN LETTER RAE
10E1 GEORGIAN LETTER SAN
10E2 GEORGIAN LETTER TAR
10E3 GEORGIAN LETTER UN
10E4 GEORGIAN LETTER PHAR
10E5 GEORGIAN LETTER KHAR
10E6 GEORGIAN LETTER GHAN
10E7 GEORGIAN LETTER QAR
10E8 GEORGIAN LETTER SHIN
10E9 GEORGIAN LETTER CHIN
10EA GEORGIAN LETTER CAN
10EB GEORGIAN LETTER JIL
10EC GEORGIAN LETTER CIL
10ED GEORGIAN LETTER CHAR
10EE GEORGIAN LETTER XAN
10EF GEORGIAN LETTER JHAN
10F0 GEORGIAN LETTER HAE
10F1 GEORGIAN LETTER HE
10F2 GEORGIAN LETTER HIE
10F3 GEORGIAN LETTER WE
10F4 GEORGIAN LETTER HAR
10F5 GEORGIAN LETTER HOE
10F6 GEORGIAN LETTER FI
10F7 GEORGIAN LETTER YN
10F8 GEORGIAN LETTER ELIFI
10F9 GEORGIAN LETTER TURNED GAN
10FA GEORGIAN LETTER AIN
10FB GEORGIAN PARAGRAPH SEPARATOR
10FC MODIFIER LETTER GEORGIAN NAR
10FD GEORGIAN LETTER AEN
10FE GEORGIAN LETTER HARD SIGN
10FF GEORGIAN LETTER LABIAL SIGN
1100 HANGUL CHOSEONG KIYEOK
1101 HANGUL CHOSEONG SSANGKIYEOK
1102 HANGUL CHOSEONG NIEUN
1103 HANGUL CHOSEONG TIKEUT
1104 HANGUL CHOSEONG SSANGTIKEUT
1105 HANGUL CHOSEONG RIEUL
1106 HANGUL CHOSEONG MIEUM
1107 HANGUL CHOSEONG PIEUP
1108 HANGUL CHOSEONG SSANGPIEUP
1109 HANGUL CHOSEONG SIOS
110A HANGUL CHOSEONG SSANGSIOS
110B HANGUL CHOSEONG IEUNG
110C HANGUL CHOSEONG CIEUC
110D HANGUL CHOSEONG SSANGCIEUC
110E HANGUL CHOSEONG CHIEUCH
110F HANGUL CHOSEONG KHIEUKH
1110 HANGUL CHOSEONG THIEUTH
1111 HANGUL CHOSEONG PHIEUPH
1112 HANGUL CHOSEONG HIEUH
1113 HANGUL CHOSEONG NIEUN-KIYEOK
1114 HANGUL CHOSEONG SSANGNIEUN
1115 HANGUL CHOSEONG NIEUN-TIKEUT
1116 HANGUL CHOSEONG NIEUN-PIEUP
1117 HANGUL CHOSEONG TIKEUT-KIYEOK
1118 HANGUL CHOSEONG RIEUL-NIEUN
1119 HANGUL CHOSEONG SSANGRIEUL
111A HANGUL CHOSEONG RIEUL-HIEUH
111B HANGUL CHOSEONG KAPYEOUNRIEUL
111C HANGUL CHOSEONG MIEUM-PIEUP
111D HANGUL CHOSEONG KAPYEOUNMIEUM
111E HANGUL CHOSEONG PIEUP-KIYEOK
111F HANGUL CHOSEONG PIEUP-NIEUN
1120 HANGUL CHOSEONG PIEUP-TIKEUT
1121 HANGUL CHOSEONG PIEUP-SIOS
1122 HANGUL CHOSEONG PIEUP-SIOS-KIYEOK
1123 HANGUL CHOSEONG PIEUP-SIOS-TIKEUT
1124 HANGUL CHOSEONG PIEUP-SIOS-PIEUP
1125 HANGUL CHOSEONG PIEUP-SSANGSIOS
1126 HANGUL CHOSEONG PIEUP-SIOS-CIEUC
1127 HANGUL CHOSEONG PIEUP-CIEUC
1128 HANGUL CHOSEONG PIEUP-CHIEUCH
1129 HANGUL CHOSEONG PIEUP-THIEUTH
112A HANGUL CHOSEONG PIEUP-PHIEUPH
112B HANGUL CHOSEONG KAPYEOUNPIEUP
112C HANGUL CHOSEONG KAPYEOUNSSANGPIEUP
112D HANGUL CHOSEONG SIOS-KIYEOK
112E HANGUL CHOSEONG SIOS-NIEUN
112F HANGUL CHOSEONG SIOS-TIKEUT
1130 HANGUL CHOSEONG SIOS-RIEUL
1131 HANGUL CHOSEONG SIOS-MIEUM
1132 HANGUL CHOSEONG SIOS-PIEUP
1133 HANGUL CHOSEONG SIOS-PIEUP-KIYEOK
1134 HANGUL CHOSEONG SIOS-SSANGSIOS
1135 HANGUL CHOSEONG SIOS-IEUNG
1136 HANGUL CHOSEONG SIOS-CIEUC
1137 HANGUL CHOSEONG SIOS-CHIEUCH
1138 HANGUL CHOSEONG SIOS-KHIEUKH
1139 HANGUL CHOSEONG SIOS-THIEUTH
113A HANGUL CHOSEONG SIOS-PHIEUPH
113B HANGUL CHOSEONG SIOS-HIEUH
113C HANGUL CHOSEONG CHITUEUMSIOS
113D HANGUL CHOSEONG CHITUEUMSSANGSIOS
113E HANGUL CHOSEONG CEONGCHIEUMSIOS
113F HANGUL CHOSEONG CEONGCHIEUMSSANGSIOS
1140 HANGUL CHOSEONG PANSIOS
1141 HANGUL CHOSEONG IEUNG-KIYEOK
1142 HANGUL CHOSEONG IEUNG-TIKEUT
1143 HANGUL CHOSEONG IEUNG-MIEUM
1144 HANGUL CHOSEONG IEUNG-PIEUP
1145 HANGUL CHOSEONG IEUNG-SIOS
1146 HANGUL CHOSEONG IEUNG-PANSIOS
1147 HANGUL CHOSEONG SSANGIEUNG
1148 HANGUL CHOSEONG IEUNG-CIEUC
1149 HANGUL CHOSEONG IEUNG-CHIEUCH
114A HANGUL CHOSEONG IEUNG-THIEUTH
114B HANGUL CHOSEONG IEUNG-PHIEUPH
114C HANGUL CHOSEONG YESIEUNG
114D HANGUL CHOSEONG CIEUC-IEUNG
114E HANGUL CHOSEONG CHITUEUMCIEUC
114F HANGUL CHOSEONG CHITUEUMSSANGCIEUC
1150 HANGUL CHOSEONG CEONGCHIEUMCIEUC
1151 HANGUL CHOSEONG CEONGCHIEUMSSANGCIEUC
1152 HANGUL CHOSEONG CHIEUCH-KHIEUKH
1153 HANGUL CHOSEONG CHIEUCH-HIEUH
1154 HANGUL CHOSEONG CHITUEUMCHIEUCH
1155 HANGUL CHOSEONG CEONGCHIEUMCHIEUCH
1156 HANGUL CHOSEONG PHIEUPH-PIEUP
1157 HANGUL CHOSEONG KAPYEOUNPHIEUPH
1158 HANGUL CHOSEONG SSANGHIEUH
1159 HANGUL CHOSEONG YEORINHIEUH
115A HANGUL CHOSEONG KIYEOK-TIKEUT
115B HANGUL CHOSEONG NIEUN-SIOS
115C HANGUL CHOSEONG NIEUN-CIEUC
115D HANGUL CHOSEONG NIEUN-HIEUH
115E HANGUL CHOSEONG TIKEUT-RIEUL
115F HANGUL CHOSEONG FILLER
1160 HANGUL JUNGSEONG FILLER
1161 HANGUL JUNGSEONG A
1162 HANGUL JUNGSEONG AE
1163 HANGUL JUNGSEONG YA
1164 HANGUL JUNGSEONG YAE
1165 HANGUL JUNGSEONG EO
1166 HANGUL JUNGSEONG E
1167 HANGUL JUNGSEONG YEO
1168 HANGUL JUNGSEONG YE
1169 HANGUL JUNGSEONG O
116A HANGUL JUNGSEONG WA
116B HANGUL JUNGSEONG WAE
116C HANGUL JUNGSEONG OE
116D HANGUL JUNGSEONG YO
116E HANGUL JUNGSEONG U
116F HANGUL JUNGSEONG WEO
1170 HANGUL JUNGSEONG WE
1171 HANGUL JUNGSEONG WI
1172 HANGUL JUNGSEONG YU
1173 HANGUL JUNGSEONG EU
1174 HANGUL JUNGSEONG YI
1175 HANGUL JUNGSEONG I
1176 HANGUL JUNGSEONG A-O
1177 HANGUL JUNGSEONG A-U
1178 HANGUL JUNGSEONG YA-O
1179 HANGUL JUNGSEONG YA-YO
117A HANGUL JUNGSEONG EO-O
117B HANGUL JUNGSEONG EO-U
117C HANGUL JUNGSEONG EO-EU
117D HANGUL JUNGSEONG YEO-O
117E HANGUL JUNGSEONG YEO-U
117F HANGUL JUNGSEONG O-EO
1180 HANGUL JUNGSEONG O-E
1181 HANGUL JUNGSEONG O-YE
1182 HANGUL JUNGSEONG O-O
1183 HANGUL JUNGSEONG O-U
1184 HANGUL JUNGSEONG YO-YA
1185 HANGUL JUNGSEONG YO-YAE
1186 HANGUL JUNGSEONG YO-YEO
1187 HANGUL JUNGSEONG YO-O
1188 HANGUL JUNGSEONG YO-I
1189 HANGUL JUNGSEONG U-A
118A HANGUL JUNGSEONG U-AE
118B HANGUL JUNGSEONG U-EO-EU
118C HANGUL JUNGSEONG U-YE
118D HANGUL JUNGSEONG U-U
118E HANGUL JUNGSEONG YU-A
118F HANGUL JUNGSEONG YU-EO
1190 HANGUL JUNGSEONG YU-E
1191 HANGUL JUNGSEONG YU-YEO
1192 HANGUL JUNGSEONG YU-YE
1193 HANGUL JUNGSEONG YU-U
1194 HANGUL JUNGSEONG YU-I
1195 HANGUL JUNGSEONG EU-U
1196 HANGUL JUNGSEONG EU-EU
1197 HANGUL JUNGSEONG YI-U
1198 HANGUL JUNGSEONG I-A
1199 HANGUL JUNGSEONG I-YA
119A HANGUL JUNGSEONG I-O
119B HANGUL JUNGSEONG I-U
119C HANGUL JUNGSEONG I-EU
119D HANGUL JUNGSEONG I-ARAEA
119E HANGUL JUNGSEONG ARAEA
119F HANGUL JUNGSEONG ARAEA-EO
11A0 HANGUL JUNGSEONG ARAEA-U
11A1 HANGUL JUNGSEONG ARAEA-I
11A2 HANGUL JUNGSEONG SSANGARAEA
11A3 HANGUL JUNGSEONG A-EU
11A4 HANGUL JUNGSEONG YA-U
11A5 HANGUL JUNGSEONG YEO-YA
11A6 HANGUL JUNGSEONG O-YA
11A7 HANGUL JUNGSEONG O-YAE
11A8 HANGUL JONGSEONG KIYEOK
11A9 HANGUL JONGSEONG SSANGKIYEOK
11AA HANGUL JONGSEONG KIYEOK-SIOS
11AB HANGUL JONGSEONG NIEUN
11AC HANGUL JONGSEONG NIEUN-CIEUC
11AD HANGUL JONGSEONG NIEUN-HIEUH
11AE HANGUL JONGSEONG TIKEUT
11AF HANGUL JONGSEONG RIEUL
11B0 HANGUL JONGSEONG RIEUL-KIYEOK
11B1 HANGUL JONGSEONG RIEUL-MIEUM
11B2 HANGUL JONGSEONG RIEUL-PIEUP
11B3 HANGUL JONGSEONG RIEUL-SIOS
11B4 HANGUL JONGSEONG RIEUL-THIEUTH
11B5 HANGUL JONGSEONG RIEUL-PHIEUPH
11B6 HANGUL JONGSEONG RIEUL-HIEUH
11B7 HANGUL JONGSEONG MIEUM
11B8 HANGUL JONGSEONG PIEUP
11B9 HANGUL JONGSEONG PIEUP-SIOS
11BA HANGUL JONGSEONG SIOS
11BB HANGUL JONGSEONG SSANGSIOS
11BC HANGUL JONGSEONG IEUNG
11BD HANGUL JONGSEONG CIEUC
11BE HANGUL JONGSEONG CHIEUCH
11BF HANGUL JONGSEONG KHIEUKH
11C0 HANGUL JONGSEONG THIEUTH
11C1 HANGUL JONGSEONG PHIEUPH
11C2 HANGUL JONGSEONG HIEUH
11C3 HANGUL JONGSEONG KIYEOK-RIEUL
11C4 HANGUL JONGSEONG KIYEOK-SIOS-KIYEOK
11C5 HANGUL JONGSEONG NIEUN-KIYEOK
11C6 HANGUL JONGSEONG NIEUN-TIKEUT
11C7 HANGUL JONGSEONG NIEUN-SIOS
11C8 HANGUL JONGSEONG NIEUN-PANSIOS
11C9 HANGUL JONGSEONG NIEUN-THIEUTH
11CA HANGUL JONGSEONG TIKEUT-KIYEOK
11CB HANGUL JONGSEONG TIKEUT-RIEUL
11CC HANGUL JONGSEONG RIEUL-KIYEOK-SIOS
11CD HANGUL JONGSEONG RIEUL-NIEUN
11CE HANGUL JONGSEONG RIEUL-TIKEUT
11CF HANGUL JONGSEONG RIEUL-TIKEUT-HIEUH
11D0 HANGUL JONGSEONG SSANGRIEUL
11D1 HANGUL JONGSEONG RIEUL-MIEUM-KIYEOK
11D2 HANGUL JONGSEONG RIEUL-MIEUM-SIOS
11D3 HANGUL JONGSEONG RIEUL-PIEUP-SIOS
11D4 HANGUL JONGSEONG RIEUL-PIEUP-HIEUH
11D5 HANGUL JONGSEONG RIEUL-KAPYEOUNPIEUP
11D6 HANGUL JONGSEONG RIEUL-SSANGSIOS
11D7 HANGUL JONGSEONG RIEUL-PANSIOS
11D8 HANGUL JONGSEONG RIEUL-KHIEUKH
11D9 HANGUL JONGSEONG RIEUL-YEORINHIEUH
11DA HANGUL JONGSEONG MIEUM-KIYEOK
11DB HANGUL JONGSEONG MIEUM-RIEUL
11DC HANGUL JONGSEONG MIEUM-PIEUP
11DD HANGUL JONGSEONG MIEUM-SIOS
11DE HANGUL JONGSEONG MIEUM-SSANGSIOS
11DF HANGUL JONGSEONG MIEUM-PANSIOS
11E0 HANGUL JONGSEONG MIEUM-CHIEUCH
11E1 HANGUL JONGSEONG MIEUM-HIEUH
11E2 HANGUL JONGSEONG KAPYEOUNMIEUM
11E3 HANGUL JONGSEONG PIEUP-RIEUL
11E4 HANGUL JONGSEONG PIEUP-PHIEUPH
11E5 HANGUL JONGSEONG PIEUP-HIEUH
11E6 HANGUL JONGSEONG KAPYEOUNPIEUP
11E7 HANGUL JONGSEONG SIOS-KIYEOK
11E8 HANGUL JONGSEONG SIOS-TIKEUT
11E9 HANGUL JONGSEONG SIOS-RIEUL
11EA HANGUL JONGSEONG SIOS-PIEUP
11EB HANGUL JONGSEONG PANSIOS
11EC HANGUL JONGSEONG IEUNG-KIYEOK
11ED HANGUL JONGSEONG IEUNG-SSANGKIYEOK
11EE HANGUL JONGSEONG SSANGIEUNG
11EF HANGUL JONGSEONG IEUNG-KHIEUKH
11F0 HANGUL JONGSEONG YESIEUNG
11F1 HANGUL JONGSEONG YESIEUNG-SIOS
11F2 HANGUL JONGSEONG YESIEUNG-PANSIOS
11F3 HANGUL JONGSEONG PHIEUPH-PIEUP
11F4 HANGUL JONGSEONG KAPYEOUNPHIEUPH
11F5 HANGUL JONGSEONG HIEUH-NIEUN
11F6 HANGUL JONGSEONG HIEUH-RIEUL
11F7 HANGUL JONGSEONG HIEUH-MIEUM
11F8 HANGUL JONGSEONG HIEUH-PIEUP
11F9 HANGUL JONGSEONG YEORINHIEUH
11FA HANGUL JONGSEONG KIYEOK-NIEUN
11FB HANGUL JONGSEONG KIYEOK-PIEUP
11FC HANGUL JONGSEONG KIYEOK-CHIEUCH
11FD HANGUL JONGSEONG KIYEOK-KHIEUKH
11FE HANGUL JONGSEONG KIYEOK-HIEUH
11FF HANGUL JONGSEONG SSANGNIEUN
1200 ETHIOPIC SYLLABLE HA
1201 ETHIOPIC SYLLABLE HU
1202 ETHIOPIC SYLLABLE HI
1203 ETHIOPIC SYLLABLE HAA
1204 ETHIOPIC SYLLABLE HEE
1205 ETHIOPIC SYLLABLE HE
1206 ETHIOPIC SYLLABLE HO
1207 ETHIOPIC SYLLABLE HOA
1208 ETHIOPIC SYLLABLE LA
1209 ETHIOPIC SYLLABLE LU
120A ETHIOPIC SYLLABLE LI
120B ETHIOPIC SYLLABLE LAA
120C ETHIOPIC SYLLABLE LEE
120D ETHIOPIC SYLLABLE LE
120E ETHIOPIC SYLLABLE LO
120F ETHIOPIC SYLLABLE LWA
1210 ETHIOPIC SYLLABLE HHA
1211 ETHIOPIC SYLLABLE HHU
1212 ETHIOPIC SYLLABLE HHI
1213 ETHIOPIC SYLLABLE HHAA
1214 ETHIOPIC SYLLABLE HHEE
1215 ETHIOPIC SYLLABLE HHE
1216 ETHIOPIC SYLLABLE HHO
1217 ETHIOPIC SYLLABLE HHWA
1218 ETHIOPIC SYLLABLE MA
1219 ETHIOPIC SYLLABLE MU
121A ETHIOPIC SYLLABLE MI
121B ETHIOPIC SYLLABLE MAA
121C ETHIOPIC SYLLABLE MEE
121D ETHIOPIC SYLLABLE ME
121E ETHIOPIC SYLLABLE MO
121F ETHIOPIC SYLLABLE MWA
1220 ETHIOPIC SYLLABLE SZA
1221 ETHIOPIC SYLLABLE SZU
1222 ETHIOPIC SYLLABLE SZI
1223 ETHIOPIC SYLLABLE SZAA
1224 ETHIOPIC SYLLABLE SZEE
1225 ETHIOPIC SYLLABLE SZE
1226 ETHIOPIC SYLLABLE SZO
1227 ETHIOPIC SYLLABLE SZWA
1228 ETHIOPIC SYLLABLE RA
1229 ETHIOPIC SYLLABLE RU
122A ETHIOPIC SYLLABLE RI
122B ETHIOPIC SYLLABLE RAA
122C ETHIOPIC SYLLABLE REE
122D ETHIOPIC SYLLABLE RE
122E ETHIOPIC SYLLABLE RO
122F ETHIOPIC SYLLABLE RWA
1230 ETHIOPIC SYLLABLE SA
1231 ETHIOPIC SYLLABLE SU
1232 ETHIOPIC SYLLABLE SI
1233 ETHIOPIC SYLLABLE SAA
1234 ETHIOPIC SYLLABLE SEE
1235 ETHIOPIC SYLLABLE SE
1236 ETHIOPIC SYLLABLE SO
1237 ETHIOPIC SYLLABLE SWA
1238 ETHIOPIC SYLLABLE SHA
1239 ETHIOPIC SYLLABLE SHU
123A ETHIOPIC SYLLABLE SHI
123B ETHIOPIC SYLLABLE SHAA
123C ETHIOPIC SYLLABLE SHEE
123D ETHIOPIC SYLLABLE SHE
123E ETHIOPIC SYLLABLE SHO
123F ETHIOPIC SYLLABLE SHWA
1240 ETHIOPIC SYLLABLE QA
1241 ETHIOPIC SYLLABLE QU
1242 ETHIOPIC SYLLABLE QI
1243 ETHIOPIC SYLLABLE QAA
1244 ETHIOPIC SYLLABLE QEE
1245 ETHIOPIC SYLLABLE QE
1246 ETHIOPIC SYLLABLE QO
1247 ETHIOPIC SYLLABLE QOA
1248 ETHIOPIC SYLLABLE QWA
124A ETHIOPIC SYLLABLE QWI
124B ETHIOPIC SYLLABLE QWAA
124C ETHIOPIC SYLLABLE QWEE
124D ETHIOPIC SYLLABLE QWE
1250 ETHIOPIC SYLLABLE QHA
1251 ETHIOPIC SYLLABLE QHU
1252 ETHIOPIC SYLLABLE QHI
1253 ETHIOPIC SYLLABLE QHAA
1254 ETHIOPIC SYLLABLE QHEE
1255 ETHIOPIC SYLLABLE QHE
1256 ETHIOPIC SYLLABLE QHO
1258 ETHIOPIC SYLLABLE QHWA
125A ETHIOPIC SYLLABLE QHWI
125B ETHIOPIC SYLLABLE QHWAA
125C ETHIOPIC SYLLABLE QHWEE
125D ETHIOPIC SYLLABLE QHWE
1260 ETHIOPIC SYLLABLE BA
1261 ETHIOPIC SYLLABLE BU
1262 ETHIOPIC SYLLABLE BI
1263 ETHIOPIC SYLLABLE BAA
1264 ETHIOPIC SYLLABLE BEE
1265 ETHIOPIC SYLLABLE BE
1266 ETHIOPIC SYLLABLE BO
1267 ETHIOPIC SYLLABLE BWA
1268 ETHIOPIC SYLLABLE VA
1269 ETHIOPIC SYLLABLE VU
126A ETHIOPIC SYLLABLE VI
126B ETHIOPIC SYLLABLE VAA
126C ETHIOPIC SYLLABLE VEE
126D ETHIOPIC SYLLABLE VE
126E ETHIOPIC SYLLABLE VO
126F ETHIOPIC SYLLABLE VWA
1270 ETHIOPIC SYLLABLE TA
1271 ETHIOPIC SYLLABLE TU
1272 ETHIOPIC SYLLABLE TI
1273 ETHIOPIC SYLLABLE TAA
1274 ETHIOPIC SYLLABLE TEE
1275 ETHIOPIC SYLLABLE TE
1276 ETHIOPIC SYLLABLE TO
1277 ETHIOPIC SYLLABLE TWA
1278 ETHIOPIC SYLLABLE CA
1279 ETHIOPIC SYLLABLE CU
127A ETHIOPIC SYLLABLE CI
127B ETHIOPIC SYLLABLE CAA
127C ETHIOPIC SYLLABLE CEE
127D ETHIOPIC SYLLABLE CE
127E ETHIOPIC SYLLABLE CO
127F ETHIOPIC SYLLABLE CWA
1280 ETHIOPIC SYLLABLE XA
1281 ETHIOPIC SYLLABLE XU
1282 ETHIOPIC SYLLABLE XI
1283 ETHIOPIC SYLLABLE XAA
1284 ETHIOPIC SYLLABLE XEE
1285 ETHIOPIC SYLLABLE XE
1286 ETHIOPIC SYLLABLE XO
1287 ETHIOPIC SYLLABLE XOA
1288 ETHIOPIC SYLLABLE XWA
128A ETHIOPIC SYLLABLE XWI
128B ETHIOPIC SYLLABLE XWAA
128C ETHIOPIC SYLLABLE XWEE
128D ETHIOPIC SYLLABLE XWE
1290 ETHIOPIC SYLLABLE NA
1291 ETHIOPIC SYLLABLE NU
1292 ETHIOPIC SYLLABLE NI
1293 ETHIOPIC SYLLABLE NAA
1294 ETHIOPIC SYLLABLE NEE
1295 ETHIOPIC SYLLABLE NE
1296 ETHIOPIC SYLLABLE NO
1297 ETHIOPIC SYLLABLE NWA
1298 ETHIOPIC SYLLABLE NYA
1299 ETHIOPIC SYLLABLE NYU
129A ETHIOPIC SYLLABLE NYI
129B ETHIOPIC SYLLABLE NYAA
129C ETHIOPIC SYLLABLE NYEE
129D ETHIOPIC SYLLABLE NYE
129E ETHIOPIC SYLLABLE NYO
129F ETHIOPIC SYLLABLE NYWA
12A0 ETHIOPIC SYLLABLE GLOTTAL A
12A1 ETHIOPIC SYLLABLE GLOTTAL U
12A2 ETHIOPIC SYLLABLE GLOTTAL I
12A3 ETHIOPIC SYLLABLE GLOTTAL AA
12A4 ETHIOPIC SYLLABLE GLOTTAL EE
12A5 ETHIOPIC SYLLABLE GLOTTAL E
12A6 ETHIOPIC SYLLABLE GLOTTAL O
12A7 ETHIOPIC SYLLABLE GLOTTAL WA
12A8 ETHIOPIC SYLLABLE KA
12A9 ETHIOPIC SYLLABLE KU
12AA ETHIOPIC SYLLABLE KI
12AB ETHIOPIC SYLLABLE KAA
12AC ETHIOPIC SYLLABLE KEE
12AD ETHIOPIC SYLLABLE KE
12AE ETHIOPIC SYLLABLE KO
12AF ETHIOPIC SYLLABLE KOA
12B0 ETHIOPIC SYLLABLE KWA
12B2 ETHIOPIC SYLLABLE KWI
12B3 ETHIOPIC SYLLABLE KWAA
12B4 ETHIOPIC SYLLABLE KWEE
12B5 ETHIOPIC SYLLABLE KWE
12B8 ETHIOPIC SYLLABLE KXA
12B9 ETHIOPIC SYLLABLE KXU
12BA ETHIOPIC SYLLABLE KXI
12BB ETHIOPIC SYLLABLE KXAA
12BC ETHIOPIC SYLLABLE KXEE
12BD ETHIOPIC SYLLABLE KXE
12BE ETHIOPIC SYLLABLE KXO
12C0 ETHIOPIC SYLLABLE KXWA
12C2 ETHIOPIC SYLLABLE KXWI
12C3 ETHIOPIC SYLLABLE KXWAA
12C4 ETHIOPIC SYLLABLE KXWEE
12C5 ETHIOPIC SYLLABLE KXWE
12C8 ETHIOPIC SYLLABLE WA
12C9 ETHIOPIC SYLLABLE WU
12CA ETHIOPIC SYLLABLE WI
12CB ETHIOPIC SYLLABLE WAA
12CC ETHIOPIC SYLLABLE WEE
12CD ETHIOPIC SYLLABLE WE
12CE ETHIOPIC SYLLABLE WO
12CF ETHIOPIC SYLLABLE WOA
12D0 ETHIOPIC SYLLABLE PHARYNGEAL A
12D1 ETHIOPIC SYLLABLE PHARYNGEAL U
12D2 ETHIOPIC SYLLABLE PHARYNGEAL I
12D3 ETHIOPIC SYLLABLE PHARYNGEAL AA
12D4 ETHIOPIC SYLLABLE PHARYNGEAL EE
12D5 ETHIOPIC SYLLABLE PHARYNGEAL E
12D6 ETHIOPIC SYLLABLE PHARYNGEAL O
12D8 ETHIOPIC SYLLABLE ZA
12D9 ETHIOPIC SYLLABLE ZU
12DA ETHIOPIC SYLLABLE ZI
12DB ETHIOPIC SYLLABLE ZAA
12DC ETHIOPIC SYLLABLE ZEE
12DD ETHIOPIC SYLLABLE ZE
12DE ETHIOPIC SYLLABLE ZO
12DF ETHIOPIC SYLLABLE ZWA
12E0 ETHIOPIC SYLLABLE ZHA
12E1 ETHIOPIC SYLLABLE ZHU
12E2 ETHIOPIC SYLLABLE ZHI
12E3 ETHIOPIC SYLLABLE ZHAA
12E4 ETHIOPIC SYLLABLE ZHEE
12E5 ETHIOPIC SYLLABLE ZHE
12E6 ETHIOPIC SYLLABLE ZHO
12E7 ETHIOPIC SYLLABLE ZHWA
12E8 ETHIOPIC SYLLABLE YA
12E9 ETHIOPIC SYLLABLE YU
12EA ETHIOPIC SYLLABLE YI
12EB ETHIOPIC SYLLABLE YAA
12EC ETHIOPIC SYLLABLE YEE
12ED ETHIOPIC SYLLABLE YE
12EE ETHIOPIC SYLLABLE YO
12EF ETHIOPIC SYLLABLE YOA
12F0 ETHIOPIC SYLLABLE DA
12F1 ETHIOPIC SYLLABLE DU
12F2 ETHIOPIC SYLLABLE DI
12F3 ETHIOPIC SYLLABLE DAA
12F4 ETHIOPIC SYLLABLE DEE
12F5 ETHIOPIC SYLLABLE DE
12F6 ETHIOPIC SYLLABLE DO
12F7 ETHIOPIC SYLLABLE DWA
12F8 ETHIOPIC SYLLABLE DDA
12F9 ETHIOPIC SYLLABLE DDU
12FA ETHIOPIC SYLLABLE DDI
12FB ETHIOPIC SYLLABLE DDAA
12FC ETHIOPIC SYLLABLE DDEE
12FD ETHIOPIC SYLLABLE DDE
12FE ETHIOPIC SYLLABLE DDO
12FF ETHIOPIC SYLLABLE DDWA
1300 ETHIOPIC SYLLABLE JA
1301 ETHIOPIC SYLLABLE JU
1302 ETHIOPIC SYLLABLE JI
1303 ETHIOPIC SYLLABLE JAA
1304 ETHIOPIC SYLLABLE JEE
1305 ETHIOPIC SYLLABLE JE
1306 ETHIOPIC SYLLABLE JO
1307 ETHIOPIC SYLLABLE JWA
1308 ETHIOPIC SYLLABLE GA
1309 ETHIOPIC SYLLABLE GU
130A ETHIOPIC SYLLABLE GI
130B ETHIOPIC SYLLABLE GAA
130C ETHIOPIC SYLLABLE GEE
130D ETHIOPIC SYLLABLE GE
130E ETHIOPIC SYLLABLE GO
130F ETHIOPIC SYLLABLE GOA
1310 ETHIOPIC SYLLABLE GWA
1312 ETHIOPIC SYLLABLE GWI
1313 ETHIOPIC SYLLABLE GWAA
1314 ETHIOPIC SYLLABLE GWEE
1315 ETHIOPIC SYLLABLE GWE
1318 ETHIOPIC SYLLABLE GGA
1319 ETHIOPIC SYLLABLE GGU
131A ETHIOPIC SYLLABLE GGI
131B ETHIOPIC SYLLABLE GGAA
131C ETHIOPIC SYLLABLE GGEE
131D ETHIOPIC SYLLABLE GGE
131E ETHIOPIC SYLLABLE GGO
131F ETHIOPIC SYLLABLE GGWAA
1320 ETHIOPIC SYLLABLE THA
1321 ETHIOPIC SYLLABLE THU
1322 ETHIOPIC SYLLABLE THI
1323 ETHIOPIC SYLLABLE THAA
1324 ETHIOPIC SYLLABLE THEE
1325 ETHIOPIC SYLLABLE THE
1326 ETHIOPIC SYLLABLE THO
1327 ETHIOPIC SYLLABLE THWA
1328 ETHIOPIC SYLLABLE CHA
1329 ETHIOPIC SYLLABLE CHU
132A ETHIOPIC SYLLABLE CHI
132B ETHIOPIC SYLLABLE CHAA
132C ETHIOPIC SYLLABLE CHEE
132D ETHIOPIC SYLLABLE CHE
132E ETHIOPIC SYLLABLE CHO
132F ETHIOPIC SYLLABLE CHWA
1330 ETHIOPIC SYLLABLE PHA
1331 ETHIOPIC SYLLABLE PHU
1332 ETHIOPIC SYLLABLE PHI
1333 ETHIOPIC SYLLABLE PHAA
1334 ETHIOPIC SYLLABLE PHEE
1335 ETHIOPIC SYLLABLE PHE
1336 ETHIOPIC SYLLABLE PHO
1337 ETHIOPIC SYLLABLE PHWA
1338 ETHIOPIC SYLLABLE TSA
1339 ETHIOPIC SYLLABLE TSU
133A ETHIOPIC SYLLABLE TSI
133B ETHIOPIC SYLLABLE TSAA
133C ETHIOPIC SYLLABLE TSEE
133D ETHIOPIC SYLLABLE TSE
133E ETHIOPIC SYLLABLE TSO
133F ETHIOPIC SYLLABLE TSWA
1340 ETHIOPIC SYLLABLE TZA
1341 ETHIOPIC SYLLABLE TZU
1342 ETHIOPIC SYLLABLE TZI
1343 ETHIOPIC SYLLABLE TZAA
1344 ETHIOPIC SYLLABLE TZEE
1345 ETHIOPIC SYLLABLE TZE
1346 ETHIOPIC SYLLABLE TZO
1347 ETHIOPIC SYLLABLE TZOA
1348 ETHIOPIC SYLLABLE FA
1349 ETHIOPIC SYLLABLE FU
134A ETHIOPIC SYLLABLE FI
134B ETHIOPIC SYLLABLE FAA
134C ETHIOPIC SYLLABLE FEE
134D ETHIOPIC SYLLABLE FE
134E ETHIOPIC SYLLABLE FO
134F ETHIOPIC SYLLABLE FWA
1350 ETHIOPIC SYLLABLE PA
1351 ETHIOPIC SYLLABLE PU
1352 ETHIOPIC SYLLABLE PI
1353 ETHIOPIC SYLLABLE PAA
1354 ETHIOPIC SYLLABLE PEE
1355 ETHIOPIC SYLLABLE PE
1356 ETHIOPIC SYLLABLE PO
1357 ETHIOPIC SYLLABLE PWA
1358 ETHIOPIC SYLLABLE RYA
1359 ETHIOPIC SYLLABLE MYA
135A ETHIOPIC SYLLABLE FYA
135D ETHIOPIC COMBINING GEMINATION AND VOWEL LENGTH MARK
135E ETHIOPIC COMBINING VOWEL LENGTH MARK
135F ETHIOPIC COMBINING GEMINATION MARK
1360 ETHIOPIC SECTION MARK
1361 ETHIOPIC WORDSPACE
1362 ETHIOPIC FULL STOP
1363 ETHIOPIC COMMA
1364 ETHIOPIC SEMICOLON
1365 ETHIOPIC COLON
1366 ETHIOPIC PREFACE COLON
1367 ETHIOPIC QUESTION MARK
1368 ETHIOPIC PARAGRAPH SEPARATOR
1369 ETHIOPIC DIGIT ONE
136A ETHIOPIC DIGIT TWO
136B ETHIOPIC DIGIT THREE
136C ETHIOPIC DIGIT FOUR
136D ETHIOPIC DIGIT FIVE
136E ETHIOPIC DIGIT SIX
136F ETHIOPIC DIGIT SEVEN
1370 ETHIOPIC DIGIT EIGHT
1371 ETHIOPIC DIGIT NINE
1372 ETHIOPIC NUMBER TEN
1373 ETHIOPIC NUMBER TWENTY
1374 ETHIOPIC NUMBER THIRTY
1375 ETHIOPIC NUMBER FORTY
1376 ETHIOPIC NUMBER FIFTY
1377 ETHIOPIC NUMBER SIXTY
1378 ETHIOPIC NUMBER SEVENTY
1379 ETHIOPIC NUMBER EIGHTY
137A ETHIOPIC NUMBER NINETY
137B ETHIOPIC NUMBER HUNDRED
137C ETHIOPIC NUMBER TEN THOUSAND
1380 ETHIOPIC SYLLABLE SEBATBEIT MWA
1381 ETHIOPIC SYLLABLE MWI
1382 ETHIOPIC SYLLABLE MWEE
1383 ETHIOPIC SYLLABLE MWE
1384 ETHIOPIC SYLLABLE SEBATBEIT BWA
1385 ETHIOPIC SYLLABLE BWI
1386 ETHIOPIC SYLLABLE BWEE
1387 ETHIOPIC SYLLABLE BWE
1388 ETHIOPIC SYLLABLE SEBATBEIT FWA
1389 ETHIOPIC SYLLABLE FWI
138A ETHIOPIC SYLLABLE FWEE
138B ETHIOPIC SYLLABLE FWE
138C ETHIOPIC SYLLABLE SEBATBEIT PWA
138D ETHIOPIC SYLLABLE PWI
138E ETHIOPIC SYLLABLE PWEE
138F ETHIOPIC SYLLABLE PWE
1390 ETHIOPIC TONAL MARK YIZET
1391 ETHIOPIC TONAL MARK DERET
1392 ETHIOPIC TONAL MARK RIKRIK
1393 ETHIOPIC TONAL MARK SHORT RIKRIK
1394 ETHIOPIC TONAL MARK DIFAT
1395 ETHIOPIC TONAL MARK KENAT
1396 ETHIOPIC TONAL MARK CHIRET
1397 ETHIOPIC TONAL MARK HIDET
1398 ETHIOPIC TONAL MARK DERET-HIDET
1399 ETHIOPIC TONAL MARK KURT
13A0 CHEROKEE LETTER A
13A1 CHEROKEE LETTER E
13A2 CHEROKEE LETTER I
13A3 CHEROKEE LETTER O
13A4 CHEROKEE LETTER U
13A5 CHEROKEE LETTER V
13A6 CHEROKEE LETTER GA
13A7 CHEROKEE LETTER KA
13A8 CHEROKEE LETTER GE
13A9 CHEROKEE LETTER GI
13AA CHEROKEE LETTER GO
13AB CHEROKEE LETTER GU
13AC CHEROKEE LETTER GV
13AD CHEROKEE LETTER HA
13AE CHEROKEE LETTER HE
13AF CHEROKEE LETTER HI
13B0 CHEROKEE LETTER HO
13B1 CHEROKEE LETTER HU
13B2 CHEROKEE LETTER HV
13B3 CHEROKEE LETTER LA
13B4 CHEROKEE LETTER LE
13B5 CHEROKEE LETTER LI
13B6 CHEROKEE LETTER LO
13B7 CHEROKEE LETTER LU
13B8 CHEROKEE LETTER LV
13B9 CHEROKEE LETTER MA
13BA CHEROKEE LETTER ME
13BB CHEROKEE LETTER MI
13BC CHEROKEE LETTER MO
13BD CHEROKEE LETTER MU
13BE CHEROKEE LETTER NA
13BF CHEROKEE LETTER HNA
13C0 CHEROKEE LETTER NAH
13C1 CHEROKEE LETTER NE
13C2 CHEROKEE LETTER NI
13C3 CHEROKEE LETTER NO
13C4 CHEROKEE LETTER NU
13C5 CHEROKEE LETTER NV
13C6 CHEROKEE LETTER QUA
13C7 CHEROKEE LETTER QUE
13C8 CHEROKEE LETTER QUI
13C9 CHEROKEE LETTER QUO
13CA CHEROKEE LETTER QUU
13CB CHEROKEE LETTER QUV
13CC CHEROKEE LETTER SA
13CD CHEROKEE LETTER S
13CE CHEROKEE LETTER SE
13CF CHEROKEE LETTER SI
13D0 CHEROKEE LETTER SO
13D1 CHEROKEE LETTER SU
13D2 CHEROKEE LETTER SV
13D3 CHEROKEE LETTER DA
13D4 CHEROKEE LETTER TA
13D5 CHEROKEE LETTER DE
13D6 CHEROKEE LETTER TE
13D7 CHEROKEE LETTER DI
13D8 CHEROKEE LETTER TI
13D9 CHEROKEE LETTER DO
13DA CHEROKEE LETTER DU
13DB CHEROKEE LETTER DV
13DC CHEROKEE LETTER DLA
13DD CHEROKEE LETTER TLA
13DE CHEROKEE LETTER TLE
13DF CHEROKEE LETTER TLI
13E0 CHEROKEE LETTER TLO
13E1 CHEROKEE LETTER TLU
13E2 CHEROKEE LETTER TLV
13E3 CHEROKEE LETTER TSA
13E4 CHEROKEE LETTER TSE
13E5 CHEROKEE LETTER TSI
13E6 CHEROKEE LETTER TSO
13E7 CHEROKEE LETTER TSU
13E8 CHEROKEE LETTER TSV
13E9 CHEROKEE LETTER WA
13EA CHEROKEE LETTER WE
13EB CHEROKEE LETTER WI
13EC CHEROKEE LETTER WO
13ED CHEROKEE LETTER WU
13EE CHEROKEE LETTER WV
13EF CHEROKEE LETTER YA
13F0 CHEROKEE LETTER YE
13F1 CHEROKEE LETTER YI
13F2 CHEROKEE LETTER YO
13F3 CHEROKEE LETTER YU
13F4 CHEROKEE LETTER YV
13F5 CHEROKEE LETTER MV
13F8 CHEROKEE SMALL LETTER YE
13F9 CHEROKEE SMALL LETTER YI
13FA CHEROKEE SMALL LETTER YO
13FB CHEROKEE SMALL LETTER YU
13FC CHEROKEE SMALL LETTER YV
13FD CHEROKEE SMALL LETTER MV
1400 CANADIAN SYLLABICS HYPHEN
1401 CANADIAN SYLLABICS E
1402 CANADIAN SYLLABICS AAI
1403 CANADIAN SYLLABICS I
1404 CANADIAN SYLLABICS II
1405 CANADIAN SYLLABICS O
1406 CANADIAN SYLLABICS OO
1407 CANADIAN SYLLABICS Y-CREE OO
1408 CANADIAN SYLLABICS CARRIER EE
1409 CANADIAN SYLLABICS CARRIER I
140A CANADIAN SYLLABICS A
140B CANADIAN SYLLABICS AA
140C CANADIAN SYLLABICS WE
140D CANADIAN SYLLABICS WEST-CREE WE
140E CANADIAN SYLLABICS WI
140F CANADIAN SYLLABICS WEST-CREE WI
1410 CANADIAN SYLLABICS WII
1411 CANADIAN SYLLABICS WEST-CREE WII
1412 CANADIAN SYLLABICS WO
1413 CANADIAN SYLLABICS WEST-CREE WO
1414 CANADIAN SYLLABICS WOO
1415 CANADIAN SYLLABICS WEST-CREE WOO
1416 CANADIAN SYLLABICS NASKAPI WOO
1417 CANADIAN SYLLABICS WA
1418 CANADIAN SYLLABICS WEST-CREE WA
1419 CANADIAN SYLLABICS WAA
141A CANADIAN SYLLABICS WEST-CREE WAA
141B CANADIAN SYLLABICS NASKAPI WAA
141C CANADIAN SYLLABICS AI
141D CANADIAN SYLLABICS Y-CREE W
141E CANADIAN SYLLABICS GLOTTAL STOP
141F CANADIAN SYLLABICS FINAL ACUTE
1420 CANADIAN SYLLABICS FINAL GRAVE
1421 CANADIAN SYLLABICS FINAL BOTTOM HALF RING
1422 CANADIAN SYLLABICS FINAL TOP HALF RING
1423 CANADIAN SYLLABICS FINAL RIGHT HALF RING
1424 CANADIAN SYLLABICS FINAL RING
1425 CANADIAN SYLLABICS FINAL DOUBLE ACUTE
1426 CANADIAN SYLLABICS FINAL DOUBLE SHORT VERTICAL STROKES
1427 CANADIAN SYLLABICS FINAL MIDDLE DOT
1428 CANADIAN SYLLABICS FINAL SHORT HORIZONTAL STROKE
1429 CANADIAN SYLLABICS FINAL PLUS
142A CANADIAN SYLLABICS FINAL DOWN TACK
142B CANADIAN SYLLABICS EN
142C CANADIAN SYLLABICS IN
142D CANADIAN SYLLABICS ON
142E CANADIAN SYLLABICS AN
142F CANADIAN SYLLABICS PE
1430 CANADIAN SYLLABICS PAAI
1431 CANADIAN SYLLABICS PI
1432 CANADIAN SYLLABICS PII
1433 CANADIAN SYLLABICS PO
1434 CANADIAN SYLLABICS POO
1435 CANADIAN SYLLABICS Y-CREE POO
1436 CANADIAN SYLLABICS CARRIER HEE
1437 CANADIAN SYLLABICS CARRIER HI
1438 CANADIAN SYLLABICS PA
1439 CANADIAN SYLLABICS PAA
143A CANADIAN SYLLABICS PWE
143B CANADIAN SYLLABICS WEST-CREE PWE
143C CANADIAN SYLLABICS PWI
143D CANADIAN SYLLABICS WEST-CREE PWI
143E CANADIAN SYLLABICS PWII
143F CANADIAN SYLLABICS WEST-CREE PWII
1440 CANADIAN SYLLABICS PWO
1441 CANADIAN SYLLABICS WEST-CREE PWO
1442 CANADIAN SYLLABICS PWOO
1443 CANADIAN SYLLABICS WEST-CREE PWOO
1444 CANADIAN SYLLABICS PWA
1445 CANADIAN SYLLABICS WEST-CREE PWA
1446 CANADIAN SYLLABICS PWAA
1447 CANADIAN SYLLABICS WEST-CREE PWAA
1448 CANADIAN SYLLABICS Y-CREE PWAA
1449 CANADIAN SYLLABICS P
144A CANADIAN SYLLABICS WEST-CREE P
144B CANADIAN SYLLABICS CARRIER H
144C CANADIAN SYLLABICS TE
144D CANADIAN SYLLABICS TAAI
144E CANADIAN SYLLABICS TI
144F CANADIAN SYLLABICS TII
1450 CANADIAN SYLLABICS TO
1451 CANADIAN SYLLABICS TOO
1452 CANADIAN SYLLABICS Y-CREE TOO
1453 CANADIAN SYLLABICS CARRIER DEE
1454 CANADIAN SYLLABICS CARRIER DI
1455 CANADIAN SYLLABICS TA
1456 CANADIAN SYLLABICS TAA
1457 CANADIAN SYLLABICS TWE
1458 CANADIAN SYLLABICS WEST-CREE TWE
1459 CANADIAN SYLLABICS TWI
145A CANADIAN SYLLABICS WEST-CREE TWI
145B CANADIAN SYLLABICS TWII
145C CANADIAN SYLLABICS WEST-CREE TWII
145D CANADIAN SYLLABICS TWO
145E CANADIAN SYLLABICS WEST-CREE TWO
145F CANADIAN SYLLABICS TWOO
1460 CANADIAN SYLLABICS WEST-CREE TWOO
1461 CANADIAN SYLLABICS TWA
1462 CANADIAN SYLLABICS WEST-CREE TWA
1463 CANADIAN SYLLABICS TWAA
1464 CANADIAN SYLLABICS WEST-CREE TWAA
1465 CANADIAN SYLLABICS NASKAPI TWAA
1466 CANADIAN SYLLABICS T
1467 CANADIAN SYLLABICS TTE
1468 CANADIAN SYLLABICS TTI
1469 CANADIAN SYLLABICS TTO
146A CANADIAN SYLLABICS TTA
146B CANADIAN SYLLABICS KE
146C CANADIAN SYLLABICS KAAI
146D CANADIAN SYLLABICS KI
146E CANADIAN SYLLABICS KII
146F CANADIAN SYLLABICS KO
1470 CANADIAN SYLLABICS KOO
1471 CANADIAN SYLLABICS Y-CREE KOO
1472 CANADIAN SYLLABICS KA
1473 CANADIAN SYLLABICS KAA
1474 CANADIAN SYLLABICS KWE
1475 CANADIAN SYLLABICS WEST-CREE KWE
1476 CANADIAN SYLLABICS KWI
1477 CANADIAN SYLLABICS WEST-CREE KWI
1478 CANADIAN SYLLABICS KWII
1479 CANADIAN SYLLABICS WEST-CREE KWII
147A CANADIAN SYLLABICS KWO
147B CANADIAN SYLLABICS WEST-CREE KWO
147C CANADIAN SYLLABICS KWOO
147D CANADIAN SYLLABICS WEST-CREE KWOO
147E CANADIAN SYLLABICS KWA
147F CANADIAN SYLLABICS WEST-CREE KWA
1480 CANADIAN SYLLABICS KWAA
1481 CANADIAN SYLLABICS WEST-CREE KWAA
1482 CANADIAN SYLLABICS NASKAPI KWAA
1483 CANADIAN SYLLABICS K
1484 CANADIAN SYLLABICS KW
1485 CANADIAN SYLLABICS SOUTH-SLAVEY KEH
1486 CANADIAN SYLLABICS SOUTH-SLAVEY KIH
1487 CANADIAN SYLLABICS SOUTH-SLAVEY KOH
1488 CANADIAN SYLLABICS SOUTH-SLAVEY KAH
1489 CANADIAN SYLLABICS CE
148A CANADIAN SYLLABICS CAAI
148B CANADIAN SYLLABICS CI
148C CANADIAN SYLLABICS CII
148D CANADIAN SYLLABICS CO
148E CANADIAN SYLLABICS COO
148F CANADIAN SYLLABICS Y-CREE COO
1490 CANADIAN SYLLABICS CA
1491 CANADIAN SYLLABICS CAA
1492 CANADIAN SYLLABICS CWE
1493 CANADIAN SYLLABICS WEST-CREE CWE
1494 CANADIAN SYLLABICS CWI
1495 CANADIAN SYLLABICS WEST-CREE CWI
1496 CANADIAN SYLLABICS CWII
1497 CANADIAN SYLLABICS WEST-CREE CWII
1498 CANADIAN SYLLABICS CWO
1499 CANADIAN SYLLABICS WEST-CREE CWO
149A CANADIAN SYLLABICS CWOO
149B CANADIAN SYLLABICS WEST-CREE CWOO
149C CANADIAN SYLLABICS CWA
149D CANADIAN SYLLABICS WEST-CREE CWA
149E CANADIAN SYLLABICS CWAA
149F CANADIAN SYLLABICS WEST-CREE CWAA
14A0 CANADIAN SYLLABICS NASKAPI CWAA
14A1 CANADIAN SYLLABICS C
14A2 CANADIAN SYLLABICS SAYISI TH
14A3 CANADIAN SYLLABICS ME
14A4 CANADIAN SYLLABICS MAAI
14A5 CANADIAN SYLLABICS MI
14A6 CANADIAN SYLLABICS MII
14A7 CANADIAN SYLLABICS MO
14A8 CANADIAN SYLLABICS MOO
14A9 CANADIAN SYLLABICS Y-CREE MOO
14AA CANADIAN SYLLABICS MA
14AB CANADIAN SYLLABICS MAA
14AC CANADIAN SYLLABICS MWE
14AD CANADIAN SYLLABICS WEST-CREE MWE
14AE CANADIAN SYLLABICS MWI
14AF CANADIAN SYLLABICS WEST-CREE MWI
14B0 CANADIAN SYLLABICS MWII
14B1 CANADIAN SYLLABICS WEST-CREE MWII
14B2 CANADIAN SYLLABICS MWO
14B3 CANADIAN SYLLABICS WEST-CREE MWO
14B4 CANADIAN SYLLABICS MWOO
14B5 CANADIAN SYLLABICS WEST-CREE MWOO
14B6 CANADIAN SYLLABICS MWA
14B7 CANADIAN SYLLABICS WEST-CREE MWA
14B8 CANADIAN SYLLABICS MWAA
14B9 CANADIAN SYLLABICS WEST-CREE MWAA
14BA CANADIAN SYLLABICS NASKAPI MWAA
14BB CANADIAN SYLLABICS M
14BC CANADIAN SYLLABICS WEST-CREE M
14BD CANADIAN SYLLABICS MH
14BE CANADIAN SYLLABICS ATHAPASCAN M
14BF CANADIAN SYLLABICS SAYISI M
14C0 CANADIAN SYLLABICS NE
14C1 CANADIAN SYLLABICS NAAI
14C2 CANADIAN SYLLABICS NI
14C3 CANADIAN SYLLABICS NII
14C4 CANADIAN SYLLABICS NO
14C5 CANADIAN SYLLABICS NOO
14C6 CANADIAN SYLLABICS Y-CREE NOO
14C7 CANADIAN SYLLABICS NA
14C8 CANADIAN SYLLABICS NAA
14C9 CANADIAN SYLLABICS NWE
14CA CANADIAN SYLLABICS WEST-CREE NWE
14CB CANADIAN SYLLABICS NWA
14CC CANADIAN SYLLABICS WEST-CREE NWA
14CD CANADIAN SYLLABICS NWAA
14CE CANADIAN SYLLABICS WEST-CREE NWAA
14CF CANADIAN SYLLABICS NASKAPI NWAA
14D0 CANADIAN SYLLABICS N
14D1 CANADIAN SYLLABICS CARRIER NG
14D2 CANADIAN SYLLABICS NH
14D3 CANADIAN SYLLABICS LE
14D4 CANADIAN SYLLABICS LAAI
14D5 CANADIAN SYLLABICS LI
14D6 CANADIAN SYLLABICS LII
14D7 CANADIAN SYLLABICS LO
14D8 CANADIAN SYLLABICS LOO
14D9 CANADIAN SYLLABICS Y-CREE LOO
14DA CANADIAN SYLLABICS LA
14DB CANADIAN SYLLABICS LAA
14DC CANADIAN SYLLABICS LWE
14DD CANADIAN SYLLABICS WEST-CREE LWE
14DE CANADIAN SYLLABICS LWI
14DF CANADIAN SYLLABICS WEST-CREE LWI
14E0 CANADIAN SYLLABICS LWII
14E1 CANADIAN SYLLABICS WEST-CREE LWII
14E2 CANADIAN SYLLABICS LWO
14E3 CANADIAN SYLLABICS WEST-CREE LWO
14E4 CANADIAN SYLLABICS LWOO
14E5 CANADIAN SYLLABICS WEST-CREE LWOO
14E6 CANADIAN SYLLABICS LWA
14E7 CANADIAN SYLLABICS WEST-CREE LWA
14E8 CANADIAN SYLLABICS LWAA
14E9 CANADIAN SYLLABICS WEST-CREE LWAA
14EA CANADIAN SYLLABICS L
14EB CANADIAN SYLLABICS WEST-CREE L
14EC CANADIAN SYLLABICS MEDIAL L
14ED CANADIAN SYLLABICS SE
14EE CANADIAN SYLLABICS SAAI
14EF CANADIAN SYLLABICS SI
14F0 CANADIAN SYLLABICS SII
14F1 CANADIAN SYLLABICS SO
14F2 CANADIAN SYLLABICS SOO
14F3 CANADIAN SYLLABICS Y-CREE SOO
14F4 CANADIAN SYLLABICS SA
14F5 CANADIAN SYLLABICS SAA
14F6 CANADIAN SYLLABICS SWE
14F7 CANADIAN SYLLABICS WEST-CREE SWE
14F8 CANADIAN SYLLABICS SWI
14F9 CANADIAN SYLLABICS WEST-CREE SWI
14FA CANADIAN SYLLABICS SWII
14FB CANADIAN SYLLABICS WEST-CREE SWII
14FC CANADIAN SYLLABICS SWO
14FD CANADIAN SYLLABICS WEST-CREE SWO
14FE CANADIAN SYLLABICS SWOO
14FF CANADIAN SYLLABICS WEST-CREE SWOO
1500 CANADIAN SYLLABICS SWA
1501 CANADIAN SYLLABICS WEST-CREE SWA
1502 CANADIAN SYLLABICS SWAA
1503 CANADIAN SYLLABICS WEST-CREE SWAA
1504 CANADIAN SYLLABICS NASKAPI SWAA
1505 CANADIAN SYLLABICS S
1506 CANADIAN SYLLABICS ATHAPASCAN S
1507 CANADIAN SYLLABICS SW
1508 CANADIAN SYLLABICS BLACKFOOT S
1509 CANADIAN SYLLABICS MOOSE-CREE SK
150A CANADIAN SYLLABICS NASKAPI SKW
150B CANADIAN SYLLABICS NASKAPI S-W
150C CANADIAN SYLLABICS NASKAPI SPWA
150D CANADIAN SYLLABICS NASKAPI STWA
150E CANADIAN SYLLABICS NASKAPI SKWA
150F CANADIAN SYLLABICS NASKAPI SCWA
1510 CANADIAN SYLLABICS SHE
1511 CANADIAN SYLLABICS SHI
1512 CANADIAN SYLLABICS SHII
1513 CANADIAN SYLLABICS SHO
1514 CANADIAN SYLLABICS SHOO
1515 CANADIAN SYLLABICS SHA
1516 CANADIAN SYLLABICS SHAA
1517 CANADIAN SYLLABICS SHWE
1518 CANADIAN SYLLABICS WEST-CREE SHWE
1519 CANADIAN SYLLABICS SHWI
151A CANADIAN SYLLABICS WEST-CREE SHWI
151B CANADIAN SYLLABICS SHWII
151C CANADIAN SYLLABICS WEST-CREE SHWII
151D CANADIAN SYLLABICS SHWO
151E CANADIAN SYLLABICS WEST-CREE SHWO
151F CANADIAN SYLLABICS SHWOO
1520 CANADIAN SYLLABICS WEST-CREE SHWOO
1521 CANADIAN SYLLABICS SHWA
1522 CANADIAN SYLLABICS WEST-CREE SHWA
1523 CANADIAN SYLLABICS SHWAA
1524 CANADIAN SYLLABICS WEST-CREE SHWAA
1525 CANADIAN SYLLABICS SH
1526 CANADIAN SYLLABICS YE
1527 CANADIAN SYLLABICS YAAI
1528 CANADIAN SYLLABICS YI
1529 CANADIAN SYLLABICS YII
152A CANADIAN SYLLABICS YO
152B CANADIAN SYLLABICS YOO
152C CANADIAN SYLLABICS Y-CREE YOO
152D CANADIAN SYLLABICS YA
152E CANADIAN SYLLABICS YAA
152F CANADIAN SYLLABICS YWE
1530 CANADIAN SYLLABICS WEST-CREE YWE
1531 CANADIAN SYLLABICS YWI
1532 CANADIAN SYLLABICS WEST-CREE YWI
1533 CANADIAN SYLLABICS YWII
1534 CANADIAN SYLLABICS WEST-CREE YWII
1535 CANADIAN SYLLABICS YWO
1536 CANADIAN SYLLABICS WEST-CREE YWO
1537 CANADIAN SYLLABICS YWOO
1538 CANADIAN SYLLABICS WEST-CREE YWOO
1539 CANADIAN SYLLABICS YWA
153A CANADIAN SYLLABICS WEST-CREE YWA
153B CANADIAN SYLLABICS YWAA
153C CANADIAN SYLLABICS WEST-CREE YWAA
153D CANADIAN SYLLABICS NASKAPI YWAA
153E CANADIAN SYLLABICS Y
153F CANADIAN SYLLABICS BIBLE-CREE Y
1540 CANADIAN SYLLABICS WEST-CREE Y
1541 CANADIAN SYLLABICS SAYISI YI
1542 CANADIAN SYLLABICS RE
1543 CANADIAN SYLLABICS R-CREE RE
1544 CANADIAN SYLLABICS WEST-CREE LE
1545 CANADIAN SYLLABICS RAAI
1546 CANADIAN SYLLABICS RI
1547 CANADIAN SYLLABICS RII
1548 CANADIAN SYLLABICS RO
1549 CANADIAN SYLLABICS ROO
154A CANADIAN SYLLABICS WEST-CREE LO
154B CANADIAN SYLLABICS RA
154C CANADIAN SYLLABICS RAA
154D CANADIAN SYLLABICS WEST-CREE LA
154E CANADIAN SYLLABICS RWAA
154F CANADIAN SYLLABICS WEST-CREE RWAA
1550 CANADIAN SYLLABICS R
1551 CANADIAN SYLLABICS WEST-CREE R
1552 CANADIAN SYLLABICS MEDIAL R
1553 CANADIAN SYLLABICS FE
1554 CANADIAN SYLLABICS FAAI
1555 CANADIAN SYLLABICS FI
1556 CANADIAN SYLLABICS FII
1557 CANADIAN SYLLABICS FO
1558 CANADIAN SYLLABICS FOO
1559 CANADIAN SYLLABICS FA
155A CANADIAN SYLLABICS FAA
155B CANADIAN SYLLABICS FWAA
155C CANADIAN SYLLABICS WEST-CREE FWAA
155D CANADIAN SYLLABICS F
155E CANADIAN SYLLABICS THE
155F CANADIAN SYLLABICS N-CREE THE
1560 CANADIAN SYLLABICS THI
1561 CANADIAN SYLLABICS N-CREE THI
1562 CANADIAN SYLLABICS THII
1563 CANADIAN SYLLABICS N-CREE THII
1564 CANADIAN SYLLABICS THO
1565 CANADIAN SYLLABICS THOO
1566 CANADIAN SYLLABICS THA
1567 CANADIAN SYLLABICS THAA
1568 CANADIAN SYLLABICS THWAA
1569 CANADIAN SYLLABICS WEST-CREE THWAA
156A CANADIAN SYLLABICS TH
156B CANADIAN SYLLABICS TTHE
156C CANADIAN SYLLABICS TTHI
156D CANADIAN SYLLABICS TTHO
156E CANADIAN SYLLABICS TTHA
156F CANADIAN SYLLABICS TTH
1570 CANADIAN SYLLABICS TYE
1571 CANADIAN SYLLABICS TYI
1572 CANADIAN SYLLABICS TYO
1573 CANADIAN SYLLABICS TYA
1574 CANADIAN SYLLABICS NUNAVIK HE
1575 CANADIAN SYLLABICS NUNAVIK HI
1576 CANADIAN SYLLABICS NUNAVIK HII
1577 CANADIAN SYLLABICS NUNAVIK HO
1578 CANADIAN SYLLABICS NUNAVIK HOO
1579 CANADIAN SYLLABICS NUNAVIK HA
157A CANADIAN SYLLABICS NUNAVIK HAA
157B CANADIAN SYLLABICS NUNAVIK H
157C CANADIAN SYLLABICS NUNAVUT H
157D CANADIAN SYLLABICS HK
157E CANADIAN SYLLABICS QAAI
157F CANADIAN SYLLABICS QI
1580 CANADIAN SYLLABICS QII
1581 CANADIAN SYLLABICS QO
1582 CANADIAN SYLLABICS QOO
1583 CANADIAN SYLLABICS QA
1584 CANADIAN SYLLABICS QAA
1585 CANADIAN SYLLABICS Q
1586 CANADIAN SYLLABICS TLHE
1587 CANADIAN SYLLABICS TLHI
1588 CANADIAN SYLLABICS TLHO
1589 CANADIAN SYLLABICS TLHA
158A CANADIAN SYLLABICS WEST-CREE RE
158B CANADIAN SYLLABICS WEST-CREE RI
158C CANADIAN SYLLABICS WEST-CREE RO
158D CANADIAN SYLLABICS WEST-CREE RA
158E CANADIAN SYLLABICS NGAAI
158F CANADIAN SYLLABICS NGI
1590 CANADIAN SYLLABICS NGII
1591 CANADIAN SYLLABICS NGO
1592 CANADIAN SYLLABICS NGOO
1593 CANADIAN SYLLABICS NGA
1594 CANADIAN SYLLABICS NGAA
1595 CANADIAN SYLLABICS NG
1596 CANADIAN SYLLABICS NNG
1597 CANADIAN SYLLABICS SAYISI SHE
1598 CANADIAN SYLLABICS SAYISI SHI
1599 CANADIAN SYLLABICS SAYISI SHO
159A CANADIAN SYLLABICS SAYISI SHA
159B CANADIAN SYLLABICS WOODS-CREE THE
159C CANADIAN SYLLABICS WOODS-CREE THI
159D CANADIAN SYLLABICS WOODS-CREE THO
159E CANADIAN SYLLABICS WOODS-CREE THA
159F CANADIAN SYLLABICS WOODS-CREE TH
15A0 CANADIAN SYLLABICS LHI
15A1 CANADIAN SYLLABICS LHII
15A2 CANADIAN SYLLABICS LHO
15A3 CANADIAN SYLLABICS LHOO
15A4 CANADIAN SYLLABICS LHA
15A5 CANADIAN SYLLABICS LHAA
15A6 CANADIAN SYLLABICS LH
15A7 CANADIAN SYLLABICS TH-CREE THE
15A8 CANADIAN SYLLABICS TH-CREE THI
15A9 CANADIAN SYLLABICS TH-CREE THII
15AA CANADIAN SYLLABICS TH-CREE THO
15AB CANADIAN SYLLABICS TH-CREE THOO
15AC CANADIAN SYLLABICS TH-CREE THA
15AD CANADIAN SYLLABICS TH-CREE THAA
15AE CANADIAN SYLLABICS TH-CREE TH
15AF CANADIAN SYLLABICS AIVILIK B
15B0 CANADIAN SYLLABICS BLACKFOOT E
15B1 CANADIAN SYLLABICS BLACKFOOT I
15B2 CANADIAN SYLLABICS BLACKFOOT O
15B3 CANADIAN SYLLABICS BLACKFOOT A
15B4 CANADIAN SYLLABICS BLACKFOOT WE
15B5 CANADIAN SYLLABICS BLACKFOOT WI
15B6 CANADIAN SYLLABICS BLACKFOOT WO
15B7 CANADIAN SYLLABICS BLACKFOOT WA
15B8 CANADIAN SYLLABICS BLACKFOOT NE
15B9 CANADIAN SYLLABICS BLACKFOOT NI
15BA CANADIAN SYLLABICS BLACKFOOT NO
15BB CANADIAN SYLLABICS BLACKFOOT NA
15BC CANADIAN SYLLABICS BLACKFOOT KE
15BD CANADIAN SYLLABICS BLACKFOOT KI
15BE CANADIAN SYLLABICS BLACKFOOT KO
15BF CANADIAN SYLLABICS BLACKFOOT KA
15C0 CANADIAN SYLLABICS SAYISI HE
15C1 CANADIAN SYLLABICS SAYISI HI
15C2 CANADIAN SYLLABICS SAYISI HO
15C3 CANADIAN SYLLABICS SAYISI HA
15C4 CANADIAN SYLLABICS CARRIER GHU
15C5 CANADIAN SYLLABICS CARRIER GHO
15C6 CANADIAN SYLLABICS CARRIER GHE
15C7 CANADIAN SYLLABICS CARRIER GHEE
15C8 CANADIAN SYLLABICS CARRIER GHI
15C9 CANADIAN SYLLABICS CARRIER GHA
15CA CANADIAN SYLLABICS CARRIER RU
15CB CANADIAN SYLLABICS CARRIER RO
15CC CANADIAN SYLLABICS CARRIER RE
15CD CANADIAN SYLLABICS CARRIER REE
15CE CANADIAN SYLLABICS CARRIER RI
15CF CANADIAN SYLLABICS CARRIER RA
15D0 CANADIAN SYLLABICS CARRIER WU
15D1 CANADIAN SYLLABICS CARRIER WO
15D2 CANADIAN SYLLABICS CARRIER WE
15D3 CANADIAN SYLLABICS CARRIER WEE
15D4 CANADIAN SYLLABICS CARRIER WI
15D5 CANADIAN SYLLABICS CARRIER WA
15D6 CANADIAN SYLLABICS CARRIER HWU
15D7 CANADIAN SYLLABICS CARRIER HWO
15D8 CANADIAN SYLLABICS CARRIER HWE
15D9 CANADIAN SYLLABICS CARRIER HWEE
15DA CANADIAN SYLLABICS CARRIER HWI
15DB CANADIAN SYLLABICS CARRIER HWA
15DC CANADIAN SYLLABICS CARRIER THU
15DD CANADIAN SYLLABICS CARRIER THO
15DE CANADIAN SYLLABICS CARRIER THE
15DF CANADIAN SYLLABICS CARRIER THEE
15E0 CANADIAN SYLLABICS CARRIER THI
15E1 CANADIAN SYLLABICS CARRIER THA
15E2 CANADIAN SYLLABICS CARRIER TTU
15E3 CANADIAN SYLLABICS CARRIER TTO
15E4 CANADIAN SYLLABICS CARRIER TTE
15E5 CANADIAN SYLLABICS CARRIER TTEE
15E6 CANADIAN SYLLABICS CARRIER TTI
15E7 CANADIAN SYLLABICS CARRIER TTA
15E8 CANADIAN SYLLABICS CARRIER PU
15E9 CANADIAN SYLLABICS CARRIER PO
15EA CANADIAN SYLLABICS CARRIER PE
15EB CANADIAN SYLLABICS CARRIER PEE
15EC CANADIAN SYLLABICS CARRIER PI
15ED CANADIAN SYLLABICS CARRIER PA
15EE CANADIAN SYLLABICS CARRIER P
15EF CANADIAN SYLLABICS CARRIER GU
15F0 CANADIAN SYLLABICS CARRIER GO
15F1 CANADIAN SYLLABICS CARRIER GE
15F2 CANADIAN SYLLABICS CARRIER GEE
15F3 CANADIAN SYLLABICS CARRIER GI
15F4 CANADIAN SYLLABICS CARRIER GA
15F5 CANADIAN SYLLABICS CARRIER KHU
15F6 CANADIAN SYLLABICS CARRIER KHO
15F7 CANADIAN SYLLABICS CARRIER KHE
15F8 CANADIAN SYLLABICS CARRIER KHEE
15F9 CANADIAN SYLLABICS CARRIER KHI
15FA CANADIAN SYLLABICS CARRIER KHA
15FB CANADIAN SYLLABICS CARRIER KKU
15FC CANADIAN SYLLABICS CARRIER KKO
15FD CANADIAN SYLLABICS CARRIER KKE
15FE CANADIAN SYLLABICS CARRIER KKEE
15FF CANADIAN SYLLABICS CARRIER KKI
1600 CANADIAN SYLLABICS CARRIER KKA
1601 CANADIAN SYLLABICS CARRIER KK
1602 CANADIAN SYLLABICS CARRIER NU
1603 CANADIAN SYLLABICS CARRIER NO
1604 CANADIAN SYLLABICS CARRIER NE
1605 CANADIAN SYLLABICS CARRIER NEE
1606 CANADIAN SYLLABICS CARRIER NI
1607 CANADIAN SYLLABICS CARRIER NA
1608 CANADIAN SYLLABICS CARRIER MU
1609 CANADIAN SYLLABICS CARRIER MO
160A CANADIAN SYLLABICS CARRIER ME
160B CANADIAN SYLLABICS CARRIER MEE
160C CANADIAN SYLLABICS CARRIER MI
160D CANADIAN SYLLABICS CARRIER MA
160E CANADIAN SYLLABICS CARRIER YU
160F CANADIAN SYLLABICS CARRIER YO
1610 CANADIAN SYLLABICS CARRIER YE
1611 CANADIAN SYLLABICS CARRIER YEE
1612 CANADIAN SYLLABICS CARRIER YI
1613 CANADIAN SYLLABICS CARRIER YA
1614 CANADIAN SYLLABICS CARRIER JU
1615 CANADIAN SYLLABICS SAYISI JU
1616 CANADIAN SYLLABICS CARRIER JO
1617 CANADIAN SYLLABICS CARRIER JE
1618 CANADIAN SYLLABICS CARRIER JEE
1619 CANADIAN SYLLABICS CARRIER JI
161A CANADIAN SYLLABICS SAYISI JI
161B CANADIAN SYLLABICS CARRIER JA
161C CANADIAN SYLLABICS CARRIER JJU
161D CANADIAN SYLLABICS CARRIER JJO
161E CANADIAN SYLLABICS CARRIER JJE
161F CANADIAN SYLLABICS CARRIER JJEE
1620 CANADIAN SYLLABICS CARRIER JJI
1621 CANADIAN SYLLABICS CARRIER JJA
1622 CANADIAN SYLLABICS CARRIER LU
1623 CANADIAN SYLLABICS CARRIER LO
1624 CANADIAN SYLLABICS CARRIER LE
1625 CANADIAN SYLLABICS CARRIER LEE
1626 CANADIAN SYLLABICS CARRIER LI
1627 CANADIAN SYLLABICS CARRIER LA
1628 CANADIAN SYLLABICS CARRIER DLU
1629 CANADIAN SYLLABICS CARRIER DLO
162A CANADIAN SYLLABICS CARRIER DLE
162B CANADIAN SYLLABICS CARRIER DLEE
162C CANADIAN SYLLABICS CARRIER DLI
162D CANADIAN SYLLABICS CARRIER DLA
162E CANADIAN SYLLABICS CARRIER LHU
162F CANADIAN SYLLABICS CARRIER LHO
1630 CANADIAN SYLLABICS CARRIER LHE
1631 CANADIAN SYLLABICS CARRIER LHEE
1632 CANADIAN SYLLABICS CARRIER LHI
1633 CANADIAN SYLLABICS CARRIER LHA
1634 CANADIAN SYLLABICS CARRIER TLHU
1635 CANADIAN SYLLABICS CARRIER TLHO
1636 CANADIAN SYLLABICS CARRIER TLHE
1637 CANADIAN SYLLABICS CARRIER TLHEE
1638 CANADIAN SYLLABICS CARRIER TLHI
1639 CANADIAN SYLLABICS CARRIER TLHA
163A CANADIAN SYLLABICS CARRIER TLU
163B CANADIAN SYLLABICS CARRIER TLO
163C CANADIAN SYLLABICS CARRIER TLE
163D CANADIAN SYLLABICS CARRIER TLEE
163E CANADIAN SYLLABICS CARRIER TLI
163F CANADIAN SYLLABICS CARRIER TLA
1640 CANADIAN SYLLABICS CARRIER ZU
1641 CANADIAN SYLLABICS CARRIER ZO
1642 CANADIAN SYLLABICS CARRIER ZE
1643 CANADIAN SYLLABICS CARRIER ZEE
1644 CANADIAN SYLLABICS CARRIER ZI
1645 CANADIAN SYLLABICS CARRIER ZA
1646 CANADIAN SYLLABICS CARRIER Z
1647 CANADIAN SYLLABICS CARRIER INITIAL Z
1648 CANADIAN SYLLABICS CARRIER DZU
1649 CANADIAN SYLLABICS CARRIER DZO
164A CANADIAN SYLLABICS CARRIER DZE
164B CANADIAN SYLLABICS CARRIER DZEE
164C CANADIAN SYLLABICS CARRIER DZI
164D CANADIAN SYLLABICS CARRIER DZA
164E CANADIAN SYLLABICS CARRIER SU
164F CANADIAN SYLLABICS CARRIER SO
1650 CANADIAN SYLLABICS CARRIER SE
1651 CANADIAN SYLLABICS CARRIER SEE
1652 CANADIAN SYLLABICS CARRIER SI
1653 CANADIAN SYLLABICS CARRIER SA
1654 CANADIAN SYLLABICS CARRIER SHU
1655 CANADIAN SYLLABICS CARRIER SHO
1656 CANADIAN SYLLABICS CARRIER SHE
1657 CANADIAN SYLLABICS CARRIER SHEE
1658 CANADIAN SYLLABICS CARRIER SHI
1659 CANADIAN SYLLABICS CARRIER SHA
165A CANADIAN SYLLABICS CARRIER SH
165B CANADIAN SYLLABICS CARRIER TSU
165C CANADIAN SYLLABICS CARRIER TSO
165D CANADIAN SYLLABICS CARRIER TSE
165E CANADIAN SYLLABICS CARRIER TSEE
165F CANADIAN SYLLABICS CARRIER TSI
1660 CANADIAN SYLLABICS CARRIER TSA
1661 CANADIAN SYLLABICS CARRIER CHU
1662 CANADIAN SYLLABICS CARRIER CHO
1663 CANADIAN SYLLABICS CARRIER CHE
1664 CANADIAN SYLLABICS CARRIER CHEE
1665 CANADIAN SYLLABICS CARRIER CHI
1666 CANADIAN SYLLABICS CARRIER CHA
1667 CANADIAN SYLLABICS CARRIER TTSU
1668 CANADIAN SYLLABICS CARRIER TTSO
1669 CANADIAN SYLLABICS CARRIER TTSE
166A CANADIAN SYLLABICS CARRIER TTSEE
166B CANADIAN SYLLABICS CARRIER TTSI
166C CANADIAN SYLLABICS CARRIER TTSA
166D CANADIAN SYLLABICS CHI SIGN
166E CANADIAN SYLLABICS FULL STOP
166F CANADIAN SYLLABICS QAI
1670 CANADIAN SYLLABICS NGAI
1671 CANADIAN SYLLABICS NNGI
1672 CANADIAN SYLLABICS NNGII
1673 CANADIAN SYLLABICS NNGO
1674 CANADIAN SYLLABICS NNGOO
1675 CANADIAN SYLLABICS NNGA
1676 CANADIAN SYLLABICS NNGAA
1677 CANADIAN SYLLABICS WOODS-CREE THWEE
1678 CANADIAN SYLLABICS WOODS-CREE THWI
1679 CANADIAN SYLLABICS WOODS-CREE THWII
167A CANADIAN SYLLABICS WOODS-CREE THWO
167B CANADIAN SYLLABICS WOODS-CREE THWOO
167C CANADIAN SYLLABICS WOODS-CREE THWA
167D CANADIAN SYLLABICS WOODS-CREE THWAA
167E CANADIAN SYLLABICS WOODS-CREE FINAL TH
167F CANADIAN SYLLABICS BLACKFOOT W
1680 OGHAM SPACE MARK
1681 OGHAM LETTER BEITH
1682 OGHAM LETTER LUIS
1683 OGHAM LETTER FEARN
1684 OGHAM LETTER SAIL
1685 OGHAM LETTER NION
1686 OGHAM LETTER UATH
1687 OGHAM LETTER DAIR
1688 OGHAM LETTER TINNE
1689 OGHAM LETTER COLL
168A OGHAM LETTER CEIRT
168B OGHAM LETTER MUIN
168C OGHAM LETTER GORT
168D OGHAM LETTER NGEADAL
168E OGHAM LETTER STRAIF
168F OGHAM LETTER RUIS
1690 OGHAM LETTER AILM
1691 OGHAM LETTER ONN
1692 OGHAM LETTER UR
1693 OGHAM LETTER EADHADH
1694 OGHAM LETTER IODHADH
1695 OGHAM LETTER EABHADH
1696 OGHAM LETTER OR
1697 OGHAM LETTER UILLEANN
1698 OGHAM LETTER IFIN
1699 OGHAM LETTER EAMHANCHOLL
169A OGHAM LETTER PEITH
169B OGHAM FEATHER MARK
169C OGHAM REVERSED FEATHER MARK
16A0 RUNIC LETTER FEHU FEOH FE F
16A1 RUNIC LETTER V
16A2 RUNIC LETTER URUZ UR U
16A3 RUNIC LETTER YR
16A4 RUNIC LETTER Y
16A5 RUNIC LETTER W
16A6 RUNIC LETTER THURISAZ THURS THORN
16A7 RUNIC LETTER ETH
16A8 RUNIC LETTER ANSUZ A
16A9 RUNIC LETTER OS O
16AA RUNIC LETTER AC A
16AB RUNIC LETTER AESC
16AC RUNIC LETTER LONG-BRANCH-OSS O
16AD RUNIC LETTER SHORT-TWIG-OSS O
16AE RUNIC LETTER O
16AF RUNIC LETTER OE
16B0 RUNIC LETTER ON
16B1 RUNIC LETTER RAIDO RAD REID R
16B2 RUNIC LETTER KAUNA
16B3 RUNIC LETTER CEN
16B4 RUNIC LETTER KAUN K
16B5 RUNIC LETTER G
16B6 RUNIC LETTER ENG
16B7 RUNIC LETTER GEBO GYFU G
16B8 RUNIC LETTER GAR
16B9 RUNIC LETTER WUNJO WYNN W
16BA RUNIC LETTER HAGLAZ H
16BB RUNIC LETTER HAEGL H
16BC RUNIC LETTER LONG-BRANCH-HAGALL H
16BD RUNIC LETTER SHORT-TWIG-HAGALL H
16BE RUNIC LETTER NAUDIZ NYD NAUD N
16BF RUNIC LETTER SHORT-TWIG-NAUD N
16C0 RUNIC LETTER DOTTED-N
16C1 RUNIC LETTER ISAZ IS ISS I
16C2 RUNIC LETTER E
16C3 RUNIC LETTER JERAN J
16C4 RUNIC LETTER GER
16C5 RUNIC LETTER LONG-BRANCH-AR AE
16C6 RUNIC LETTER SHORT-TWIG-AR A
16C7 RUNIC LETTER IWAZ EOH
16C8 RUNIC LETTER PERTHO PEORTH P
16C9 RUNIC LETTER ALGIZ EOLHX
16CA RUNIC LETTER SOWILO S
16CB RUNIC LETTER SIGEL LONG-BRANCH-SOL S
16CC RUNIC LETTER SHORT-TWIG-SOL S
16CD RUNIC LETTER C
16CE RUNIC LETTER Z
16CF RUNIC LETTER TIWAZ TIR TYR T
16D0 RUNIC LETTER SHORT-TWIG-TYR T
16D1 RUNIC LETTER D
16D2 RUNIC LETTER BERKANAN BEORC BJARKAN B
16D3 RUNIC LETTER SHORT-TWIG-BJARKAN B
16D4 RUNIC LETTER DOTTED-P
16D5 RUNIC LETTER OPEN-P
16D6 RUNIC LETTER EHWAZ EH E
16D7 RUNIC LETTER MANNAZ MAN M
16D8 RUNIC LETTER LONG-BRANCH-MADR M
16D9 RUNIC LETTER SHORT-TWIG-MADR M
16DA RUNIC LETTER LAUKAZ LAGU LOGR L
16DB RUNIC LETTER DOTTED-L
16DC RUNIC LETTER INGWAZ
16DD RUNIC LETTER ING
16DE RUNIC LETTER DAGAZ DAEG D
16DF RUNIC LETTER OTHALAN ETHEL O
16E0 RUNIC LETTER EAR
16E1 RUNIC LETTER IOR
16E2 RUNIC LETTER CWEORTH
16E3 RUNIC LETTER CALC
16E4 RUNIC LETTER CEALC
16E5 RUNIC LETTER STAN
16E6 RUNIC LETTER LONG-BRANCH-YR
16E7 RUNIC LETTER SHORT-TWIG-YR
16E8 RUNIC LETTER ICELANDIC-YR
16E9 RUNIC LETTER Q
16EA RUNIC LETTER X
16EB RUNIC SINGLE PUNCTUATION
16EC RUNIC MULTIPLE PUNCTUATION
16ED RUNIC CROSS PUNCTUATION
16EE RUNIC ARLAUG SYMBOL
16EF RUNIC TVIMADUR SYMBOL
16F0 RUNIC BELGTHOR SYMBOL
16F1 RUNIC LETTER K
16F2 RUNIC LETTER SH
16F3 RUNIC LETTER OO
16F4 RUNIC LETTER FRANKS CASKET OS
16F5 RUNIC LETTER FRANKS CASKET IS
16F6 RUNIC LETTER FRANKS CASKET EH
16F7 RUNIC LETTER FRANKS CASKET AC
16F8 RUNIC LETTER FRANKS CASKET AESC
1700 TAGALOG LETTER A
1701 TAGALOG LETTER I
1702 TAGALOG LETTER U
1703 TAGALOG LETTER KA
1704 TAGALOG LETTER GA
1705 TAGALOG LETTER NGA
1706 TAGALOG LETTER TA
1707 TAGALOG LETTER DA
1708 TAGALOG LETTER NA
1709 TAGALOG LETTER PA
170A TAGALOG LETTER BA
170B TAGALOG LETTER MA
170C TAGALOG LETTER YA
170E TAGALOG LETTER LA
170F TAGALOG LETTER WA
1710 TAGALOG LETTER SA
1711 TAGALOG LETTER HA
1712 TAGALOG VOWEL SIGN I
1713 TAGALOG VOWEL SIGN U
1714 TAGALOG SIGN VIRAMA
1720 HANUNOO LETTER A
1721 HANUNOO LETTER I
1722 HANUNOO LETTER U
1723 HANUNOO LETTER KA
1724 HANUNOO LETTER GA
1725 HANUNOO LETTER NGA
1726 HANUNOO LETTER TA
1727 HANUNOO LETTER DA
1728 HANUNOO LETTER NA
1729 HANUNOO LETTER PA
172A HANUNOO LETTER BA
172B HANUNOO LETTER MA
172C HANUNOO LETTER YA
172D HANUNOO LETTER RA
172E HANUNOO LETTER LA
172F HANUNOO LETTER WA
1730 HANUNOO LETTER SA
1731 HANUNOO LETTER HA
1732 HANUNOO VOWEL SIGN I
1733 HANUNOO VOWEL SIGN U
1734 HANUNOO SIGN PAMUDPOD
1735 PHILIPPINE SINGLE PUNCTUATION
1736 PHILIPPINE DOUBLE PUNCTUATION
1740 BUHID LETTER A
1741 BUHID LETTER I
1742 BUHID LETTER U
1743 BUHID LETTER KA
1744 BUHID LETTER GA
1745 BUHID LETTER NGA
1746 BUHID LETTER TA
1747 BUHID LETTER DA
1748 BUHID LETTER NA
1749 BUHID LETTER PA
174A BUHID LETTER BA
174B BUHID LETTER MA
174C BUHID LETTER YA
174D BUHID LETTER RA
174E BUHID LETTER LA
174F BUHID LETTER WA
1750 BUHID LETTER SA
1751 BUHID LETTER HA
1752 BUHID VOWEL SIGN I
1753 BUHID VOWEL SIGN U
1760 TAGBANWA LETTER A
1761 TAGBANWA LETTER I
1762 TAGBANWA LETTER U
1763 TAGBANWA LETTER KA
1764 TAGBANWA LETTER GA
1765 TAGBANWA LETTER NGA
1766 TAGBANWA LETTER TA
1767 TAGBANWA LETTER DA
1768 TAGBANWA LETTER NA
1769 TAGBANWA LETTER PA
176A TAGBANWA LETTER BA
176B TAGBANWA LETTER MA
176C TAGBANWA LETTER YA
176E TAGBANWA LETTER LA
176F TAGBANWA LETTER WA
1770 TAGBANWA LETTER SA
1772 TAGBANWA VOWEL SIGN I
1773 TAGBANWA VOWEL SIGN U
1780 KHMER LETTER KA
1781 KHMER LETTER KHA
1782 KHMER LETTER KO
1783 KHMER LETTER KHO
1784 KHMER LETTER NGO
1785 KHMER LETTER CA
1786 KHMER LETTER CHA
1787 KHMER LETTER CO
1788 KHMER LETTER CHO
1789 KHMER LETTER NYO
178A KHMER LETTER DA
178B KHMER LETTER TTHA
178C KHMER LETTER DO
178D KHMER LETTER TTHO
178E KHMER LETTER NNO
178F KHMER LETTER TA
1790 KHMER LETTER THA
1791 KHMER LETTER TO
1792 KHMER LETTER THO
1793 KHMER LETTER NO
1794 KHMER LETTER BA
1795 KHMER LETTER PHA
1796 KHMER LETTER PO
1797 KHMER LETTER PHO
1798 KHMER LETTER MO
1799 KHMER LETTER YO
179A KHMER LETTER RO
179B KHMER LETTER LO
179C KHMER LETTER VO
179D KHMER LETTER SHA
179E KHMER LETTER SSO
179F KHMER LETTER SA
17A0 KHMER LETTER HA
17A1 KHMER LETTER LA
17A2 KHMER LETTER QA
17A3 KHMER INDEPENDENT VOWEL QAQ
17A4 KHMER INDEPENDENT VOWEL QAA
17A5 KHMER INDEPENDENT VOWEL QI
17A6 KHMER INDEPENDENT VOWEL QII
17A7 KHMER INDEPENDENT VOWEL QU
17A8 KHMER INDEPENDENT VOWEL QUK
17A9 KHMER INDEPENDENT VOWEL QUU
17AA KHMER INDEPENDENT VOWEL QUUV
17AB KHMER INDEPENDENT VOWEL RY
17AC KHMER INDEPENDENT VOWEL RYY
17AD KHMER INDEPENDENT VOWEL LY
17AE KHMER INDEPENDENT VOWEL LYY
17AF KHMER INDEPENDENT VOWEL QE
17B0 KHMER INDEPENDENT VOWEL QAI
17B1 KHMER INDEPENDENT VOWEL QOO TYPE ONE
17B2 KHMER INDEPENDENT VOWEL QOO TYPE TWO
17B3 KHMER INDEPENDENT VOWEL QAU
17B4 KHMER VOWEL INHERENT AQ
17B5 KHMER VOWEL INHERENT AA
17B6 KHMER VOWEL SIGN AA
17B7 KHMER VOWEL SIGN I
17B8 KHMER VOWEL SIGN II
17B9 KHMER VOWEL SIGN Y
17BA KHMER VOWEL SIGN YY
17BB KHMER VOWEL SIGN U
17BC KHMER VOWEL SIGN UU
17BD KHMER VOWEL SIGN UA
17BE KHMER VOWEL SIGN OE
17BF KHMER VOWEL SIGN YA
17C0 KHMER VOWEL SIGN IE
17C1 KHMER VOWEL SIGN E
17C2 KHMER VOWEL SIGN AE
17C3 KHMER VOWEL SIGN AI
17C4 KHMER VOWEL SIGN OO
17C5 KHMER VOWEL SIGN AU
17C6 KHMER SIGN NIKAHIT
17C7 KHMER SIGN REAHMUK
17C8 KHMER SIGN YUUKALEAPINTU
17C9 KHMER SIGN MUUSIKATOAN
17CA KHMER SIGN TRIISAP
17CB KHMER SIGN BANTOC
17CC KHMER SIGN ROBAT
17CD KHMER SIGN TOANDAKHIAT
17CE KHMER SIGN KAKABAT
17CF KHMER SIGN AHSDA
17D0 KHMER SIGN SAMYOK SANNYA
17D1 KHMER SIGN VIRIAM
17D2 KHMER SIGN COENG
17D3 KHMER SIGN BATHAMASAT
17D4 KHMER SIGN KHAN
17D5 KHMER SIGN BARIYOOSAN
17D6 KHMER SIGN CAMNUC PII KUUH
17D7 KHMER SIGN LEK TOO
17D8 KHMER SIGN BEYYAL
17D9 KHMER SIGN PHNAEK MUAN
17DA KHMER SIGN KOOMUUT
17DB KHMER CURRENCY SYMBOL RIEL
17DC KHMER SIGN AVAKRAHASANYA
17DD KHMER SIGN ATTHACAN
17E0 KHMER DIGIT ZERO
17E1 KHMER DIGIT ONE
17E2 KHMER DIGIT TWO
17E3 KHMER DIGIT THREE
17E4 KHMER DIGIT FOUR
17E5 KHMER DIGIT FIVE
17E6 KHMER DIGIT SIX
17E7 KHMER DIGIT SEVEN
17E8 KHMER DIGIT EIGHT
17E9 KHMER DIGIT NINE
17F0 KHMER SYMBOL LEK ATTAK SON
17F1 KHMER SYMBOL LEK ATTAK MUOY
17F2 KHMER SYMBOL LEK ATTAK PII
17F3 KHMER SYMBOL LEK ATTAK BEI
17F4 KHMER SYMBOL LEK ATTAK BUON
17F5 KHMER SYMBOL LEK ATTAK PRAM
17F6 KHMER SYMBOL LEK ATTAK PRAM-MUOY
17F7 KHMER SYMBOL LEK ATTAK PRAM-PII
17F8 KHMER SYMBOL LEK ATTAK PRAM-BEI
17F9 KHMER SYMBOL LEK ATTAK PRAM-BUON
1800 MONGOLIAN BIRGA
1801 MONGOLIAN ELLIPSIS
1802 MONGOLIAN COMMA
1803 MONGOLIAN FULL STOP
1804 MONGOLIAN COLON
1805 MONGOLIAN FOUR DOTS
1806 MONGOLIAN TODO SOFT HYPHEN
1807 MONGOLIAN SIBE SYLLABLE BOUNDARY MARKER
1808 MONGOLIAN MANCHU COMMA
1809 MONGOLIAN MANCHU FULL STOP
180A MONGOLIAN NIRUGU
180B MONGOLIAN FREE VARIATION SELECTOR ONE, FVS1
180C MONGOLIAN FREE VARIATION SELECTOR TWO, FVS2
180D MONGOLIAN FREE VARIATION SELECTOR THREE, FVS3
180E MONGOLIAN VOWEL SEPARATOR, MVS
1810 MONGOLIAN DIGIT ZERO
1811 MONGOLIAN DIGIT ONE
1812 MONGOLIAN DIGIT TWO
1813 MONGOLIAN DIGIT THREE
1814 MONGOLIAN DIGIT FOUR
1815 MONGOLIAN DIGIT FIVE
1816 MONGOLIAN DIGIT SIX
1817 MONGOLIAN DIGIT SEVEN
1818 MONGOLIAN DIGIT EIGHT
1819 MONGOLIAN DIGIT NINE
1820 MONGOLIAN LETTER A
1821 MONGOLIAN LETTER E
1822 MONGOLIAN LETTER I
1823 MONGOLIAN LETTER O
1824 MONGOLIAN LETTER U
1825 MONGOLIAN LETTER OE
1826 MONGOLIAN LETTER UE
1827 MONGOLIAN LETTER EE
1828 MONGOLIAN LETTER NA
1829 MONGOLIAN LETTER ANG
182A MONGOLIAN LETTER BA
182B MONGOLIAN LETTER PA
182C MONGOLIAN LETTER QA
182D MONGOLIAN LETTER GA
182E MONGOLIAN LETTER MA
182F MONGOLIAN LETTER LA
1830 MONGOLIAN LETTER SA
1831 MONGOLIAN LETTER SHA
1832 MONGOLIAN LETTER TA
1833 MONGOLIAN LETTER DA
1834 MONGOLIAN LETTER CHA
1835 MONGOLIAN LETTER JA
1836 MONGOLIAN LETTER YA
1837 MONGOLIAN LETTER RA
1838 MONGOLIAN LETTER WA
1839 MONGOLIAN LETTER FA
183A MONGOLIAN LETTER KA
183B MONGOLIAN LETTER KHA
183C MONGOLIAN LETTER TSA
183D MONGOLIAN LETTER ZA
183E MONGOLIAN LETTER HAA
183F MONGOLIAN LETTER ZRA
1840 MONGOLIAN LETTER LHA
1841 MONGOLIAN LETTER ZHI
1842 MONGOLIAN LETTER CHI
1843 MONGOLIAN LETTER TODO LONG VOWEL SIGN
1844 MONGOLIAN LETTER TODO E
1845 MONGOLIAN LETTER TODO I
1846 MONGOLIAN LETTER TODO O
1847 MONGOLIAN LETTER TODO U
1848 MONGOLIAN LETTER TODO OE
1849 MONGOLIAN LETTER TODO UE
184A MONGOLIAN LETTER TODO ANG
184B MONGOLIAN LETTER TODO BA
184C MONGOLIAN LETTER TODO PA
184D MONGOLIAN LETTER TODO QA
184E MONGOLIAN LETTER TODO GA
184F MONGOLIAN LETTER TODO MA
1850 MONGOLIAN LETTER TODO TA
1851 MONGOLIAN LETTER TODO DA
1852 MONGOLIAN LETTER TODO CHA
1853 MONGOLIAN LETTER TODO JA
1854 MONGOLIAN LETTER TODO TSA
1855 MONGOLIAN LETTER TODO YA
1856 MONGOLIAN LETTER TODO WA
1857 MONGOLIAN LETTER TODO KA
1858 MONGOLIAN LETTER TODO GAA
1859 MONGOLIAN LETTER TODO HAA
185A MONGOLIAN LETTER TODO JIA
185B MONGOLIAN LETTER TODO NIA
185C MONGOLIAN LETTER TODO DZA
185D MONGOLIAN LETTER SIBE E
185E MONGOLIAN LETTER SIBE I
185F MONGOLIAN LETTER SIBE IY
1860 MONGOLIAN LETTER SIBE UE
1861 MONGOLIAN LETTER SIBE U
1862 MONGOLIAN LETTER SIBE ANG
1863 MONGOLIAN LETTER SIBE KA
1864 MONGOLIAN LETTER SIBE GA
1865 MONGOLIAN LETTER SIBE HA
1866 MONGOLIAN LETTER SIBE PA
1867 MONGOLIAN LETTER SIBE SHA
1868 MONGOLIAN LETTER SIBE TA
1869 MONGOLIAN LETTER SIBE DA
186A MONGOLIAN LETTER SIBE JA
186B MONGOLIAN LETTER SIBE FA
186C MONGOLIAN LETTER SIBE GAA
186D MONGOLIAN LETTER SIBE HAA
186E MONGOLIAN LETTER SIBE TSA
186F MONGOLIAN LETTER SIBE ZA
1870 MONGOLIAN LETTER SIBE RAA
1871 MONGOLIAN LETTER SIBE CHA
1872 MONGOLIAN LETTER SIBE ZHA
1873 MONGOLIAN LETTER MANCHU I
1874 MONGOLIAN LETTER MANCHU KA
1875 MONGOLIAN LETTER MANCHU RA
1876 MONGOLIAN LETTER MANCHU FA
1877 MONGOLIAN LETTER MANCHU ZHA
1880 MONGOLIAN LETTER ALI GALI ANUSVARA ONE
1881 MONGOLIAN LETTER ALI GALI VISARGA ONE
1882 MONGOLIAN LETTER ALI GALI DAMARU
1883 MONGOLIAN LETTER ALI GALI UBADAMA
1884 MONGOLIAN LETTER ALI GALI INVERTED UBADAMA
1885 MONGOLIAN LETTER ALI GALI BALUDA
1886 MONGOLIAN LETTER ALI GALI THREE BALUDA
1887 MONGOLIAN LETTER ALI GALI A
1888 MONGOLIAN LETTER ALI GALI I
1889 MONGOLIAN LETTER ALI GALI KA
188A MONGOLIAN LETTER ALI GALI NGA
188B MONGOLIAN LETTER ALI GALI CA
188C MONGOLIAN LETTER ALI GALI TTA
188D MONGOLIAN LETTER ALI GALI TTHA
188E MONGOLIAN LETTER ALI GALI DDA
188F MONGOLIAN LETTER ALI GALI NNA
1890 MONGOLIAN LETTER ALI GALI TA
1891 MONGOLIAN LETTER ALI GALI DA
1892 MONGOLIAN LETTER ALI GALI PA
1893 MONGOLIAN LETTER ALI GALI PHA
1894 MONGOLIAN LETTER ALI GALI SSA
1895 MONGOLIAN LETTER ALI GALI ZHA
1896 MONGOLIAN LETTER ALI GALI ZA
1897 MONGOLIAN LETTER ALI GALI AH
1898 MONGOLIAN LETTER TODO ALI GALI TA
1899 MONGOLIAN LETTER TODO ALI GALI ZHA
189A MONGOLIAN LETTER MANCHU ALI GALI GHA
189B MONGOLIAN LETTER MANCHU ALI GALI NGA
189C MONGOLIAN LETTER MANCHU ALI GALI CA
189D MONGOLIAN LETTER MANCHU ALI GALI JHA
189E MONGOLIAN LETTER MANCHU ALI GALI TTA
189F MONGOLIAN LETTER MANCHU ALI GALI DDHA
18A0 MONGOLIAN LETTER MANCHU ALI GALI TA
18A1 MONGOLIAN LETTER MANCHU ALI GALI DHA
18A2 MONGOLIAN LETTER MANCHU ALI GALI SSA
18A3 MONGOLIAN LETTER MANCHU ALI GALI CYA
18A4 MONGOLIAN LETTER MANCHU ALI GALI ZHA
18A5 MONGOLIAN LETTER MANCHU ALI GALI ZA
18A6 MONGOLIAN LETTER ALI GALI HALF U
18A7 MONGOLIAN LETTER ALI GALI HALF YA
18A8 MONGOLIAN LETTER MANCHU ALI GALI BHA
18A9 MONGOLIAN LETTER ALI GALI DAGALGA
18AA MONGOLIAN LETTER MANCHU ALI GALI LHA
18B0 CANADIAN SYLLABICS OY
18B1 CANADIAN SYLLABICS AY
18B2 CANADIAN SYLLABICS AAY
18B3 CANADIAN SYLLABICS WAY
18B4 CANADIAN SYLLABICS POY
18B5 CANADIAN SYLLABICS PAY
18B6 CANADIAN SYLLABICS PWOY
18B7 CANADIAN SYLLABICS TAY
18B8 CANADIAN SYLLABICS KAY
18B9 CANADIAN SYLLABICS KWAY
18BA CANADIAN SYLLABICS MAY
18BB CANADIAN SYLLABICS NOY
18BC CANADIAN SYLLABICS NAY
18BD CANADIAN SYLLABICS LAY
18BE CANADIAN SYLLABICS SOY
18BF CANADIAN SYLLABICS SAY
18C0 CANADIAN SYLLABICS SHOY
18C1 CANADIAN SYLLABICS SHAY
18C2 CANADIAN SYLLABICS SHWOY
18C3 CANADIAN SYLLABICS YOY
18C4 CANADIAN SYLLABICS YAY
18C5 CANADIAN SYLLABICS RAY
18C6 CANADIAN SYLLABICS NWI
18C7 CANADIAN SYLLABICS OJIBWAY NWI
18C8 CANADIAN SYLLABICS NWII
18C9 CANADIAN SYLLABICS OJIBWAY NWII
18CA CANADIAN SYLLABICS NWO
18CB CANADIAN SYLLABICS OJIBWAY NWO
18CC CANADIAN SYLLABICS NWOO
18CD CANADIAN SYLLABICS OJIBWAY NWOO
18CE CANADIAN SYLLABICS RWEE
18CF CANADIAN SYLLABICS RWI
18D0 CANADIAN SYLLABICS RWII
18D1 CANADIAN SYLLABICS RWO
18D2 CANADIAN SYLLABICS RWOO
18D3 CANADIAN SYLLABICS RWA
18D4 CANADIAN SYLLABICS OJIBWAY P
18D5 CANADIAN SYLLABICS OJIBWAY T
18D6 CANADIAN SYLLABICS OJIBWAY K
18D7 CANADIAN SYLLABICS OJIBWAY C
18D8 CANADIAN SYLLABICS OJIBWAY M
18D9 CANADIAN SYLLABICS OJIBWAY N
18DA CANADIAN SYLLABICS OJIBWAY S
18DB CANADIAN SYLLABICS OJIBWAY SH
18DC CANADIAN SYLLABICS EASTERN W
18DD CANADIAN SYLLABICS WESTERN W
18DE CANADIAN SYLLABICS FINAL SMALL RING
18DF CANADIAN SYLLABICS FINAL RAISED DOT
18E0 CANADIAN SYLLABICS R-CREE RWE
18E1 CANADIAN SYLLABICS WEST-CREE LOO
18E2 CANADIAN SYLLABICS WEST-CREE LAA
18E3 CANADIAN SYLLABICS THWE
18E4 CANADIAN SYLLABICS THWA
18E5 CANADIAN SYLLABICS TTHWE
18E6 CANADIAN SYLLABICS TTHOO
18E7 CANADIAN SYLLABICS TTHAA
18E8 CANADIAN SYLLABICS TLHWE
18E9 CANADIAN SYLLABICS TLHOO
18EA CANADIAN SYLLABICS SAYISI SHWE
18EB CANADIAN SYLLABICS SAYISI SHOO
18EC CANADIAN SYLLABICS SAYISI HOO
18ED CANADIAN SYLLABICS CARRIER GWU
18EE CANADIAN SYLLABICS CARRIER DENE GEE
18EF CANADIAN SYLLABICS CARRIER GAA
18F0 CANADIAN SYLLABICS CARRIER GWA
18F1 CANADIAN SYLLABICS SAYISI JUU
18F2 CANADIAN SYLLABICS CARRIER JWA
18F3 CANADIAN SYLLABICS BEAVER DENE L
18F4 CANADIAN SYLLABICS BEAVER DENE R
18F5 CANADIAN SYLLABICS CARRIER DENTAL S
1900 LIMBU VOWEL-CARRIER LETTER
1901 LIMBU LETTER KA
1902 LIMBU LETTER KHA
1903 LIMBU LETTER GA
1904 LIMBU LETTER GHA
1905 LIMBU LETTER NGA
1906 LIMBU LETTER CA
1907 LIMBU LETTER CHA
1908 LIMBU LETTER JA
1909 LIMBU LETTER JHA
190A LIMBU LETTER YAN
190B LIMBU LETTER TA
190C LIMBU LETTER THA
190D LIMBU LETTER DA
190E LIMBU LETTER DHA
190F LIMBU LETTER NA
1910 LIMBU LETTER PA
1911 LIMBU LETTER PHA
1912 LIMBU LETTER BA
1913 LIMBU LETTER BHA
1914 LIMBU LETTER MA
1915 LIMBU LETTER YA
1916 LIMBU LETTER RA
1917 LIMBU LETTER LA
1918 LIMBU LETTER WA
1919 LIMBU LETTER SHA
191A LIMBU LETTER SSA
191B LIMBU LETTER SA
191C LIMBU LETTER HA
191D LIMBU LETTER GYAN
191E LIMBU LETTER TRA
1920 LIMBU VOWEL SIGN A
1921 LIMBU VOWEL SIGN I
1922 LIMBU VOWEL SIGN U
1923 LIMBU VOWEL SIGN EE
1924 LIMBU VOWEL SIGN AI
1925 LIMBU VOWEL SIGN OO
1926 LIMBU VOWEL SIGN AU
1927 LIMBU VOWEL SIGN E
1928 LIMBU VOWEL SIGN O
1929 LIMBU SUBJOINED LETTER YA
192A LIMBU SUBJOINED LETTER RA
192B LIMBU SUBJOINED LETTER WA
1930 LIMBU SMALL LETTER KA
1931 LIMBU SMALL LETTER NGA
1932 LIMBU SMALL LETTER ANUSVARA
1933 LIMBU SMALL LETTER TA
1934 LIMBU SMALL LETTER NA
1935 LIMBU SMALL LETTER PA
1936 LIMBU SMALL LETTER MA
1937 LIMBU SMALL LETTER RA
1938 LIMBU SMALL LETTER LA
1939 LIMBU SIGN MUKPHRENG
193A LIMBU SIGN KEMPHRENG
193B LIMBU SIGN SA-I
1940 LIMBU SIGN LOO
1944 LIMBU EXCLAMATION MARK
1945 LIMBU QUESTION MARK
1946 LIMBU DIGIT ZERO
1947 LIMBU DIGIT ONE
1948 LIMBU DIGIT TWO
1949 LIMBU DIGIT THREE
194A LIMBU DIGIT FOUR
194B LIMBU DIGIT FIVE
194C LIMBU DIGIT SIX
194D LIMBU DIGIT SEVEN
194E LIMBU DIGIT EIGHT
194F LIMBU DIGIT NINE
1950 TAI LE LETTER KA
1951 TAI LE LETTER XA
1952 TAI LE LETTER NGA
1953 TAI LE LETTER TSA
1954 TAI LE LETTER SA
1955 TAI LE LETTER YA
1956 TAI LE LETTER TA
1957 TAI LE LETTER THA
1958 TAI LE LETTER LA
1959 TAI LE LETTER PA
195A TAI LE LETTER PHA
195B TAI LE LETTER MA
195C TAI LE LETTER FA
195D TAI LE LETTER VA
195E TAI LE LETTER HA
195F TAI LE LETTER QA
1960 TAI LE LETTER KHA
1961 TAI LE LETTER TSHA
1962 TAI LE LETTER NA
1963 TAI LE LETTER A
1964 TAI LE LETTER I
1965 TAI LE LETTER EE
1966 TAI LE LETTER EH
1967 TAI LE LETTER U
1968 TAI LE LETTER OO
1969 TAI LE LETTER O
196A TAI LE LETTER UE
196B TAI LE LETTER E
196C TAI LE LETTER AUE
196D TAI LE LETTER AI
1970 TAI LE LETTER TONE-2
1971 TAI LE LETTER TONE-3
1972 TAI LE LETTER TONE-4
1973 TAI LE LETTER TONE-5
1974 TAI LE LETTER TONE-6
1980 NEW TAI LUE LETTER HIGH QA
1981 NEW TAI LUE LETTER LOW QA
1982 NEW TAI LUE LETTER HIGH KA
1983 NEW TAI LUE LETTER HIGH XA
1984 NEW TAI LUE LETTER HIGH NGA
1985 NEW TAI LUE LETTER LOW KA
1986 NEW TAI LUE LETTER LOW XA
1987 NEW TAI LUE LETTER LOW NGA
1988 NEW TAI LUE LETTER HIGH TSA
1989 NEW TAI LUE LETTER HIGH SA
198A NEW TAI LUE LETTER HIGH YA
198B NEW TAI LUE LETTER LOW TSA
198C NEW TAI LUE LETTER LOW SA
198D NEW TAI LUE LETTER LOW YA
198E NEW TAI LUE LETTER HIGH TA
198F NEW TAI LUE LETTER HIGH THA
1990 NEW TAI LUE LETTER HIGH NA
1991 NEW TAI LUE LETTER LOW TA
1992 NEW TAI LUE LETTER LOW THA
1993 NEW TAI LUE LETTER LOW NA
1994 NEW TAI LUE LETTER HIGH PA
1995 NEW TAI LUE LETTER HIGH PHA
1996 NEW TAI LUE LETTER HIGH MA
1997 NEW TAI LUE LETTER LOW PA
1998 NEW TAI LUE LETTER LOW PHA
1999 NEW TAI LUE LETTER LOW MA
199A NEW TAI LUE LETTER HIGH FA
199B NEW TAI LUE LETTER HIGH VA
199C NEW TAI LUE LETTER HIGH LA
199D NEW TAI LUE LETTER LOW FA
199E NEW TAI LUE LETTER LOW VA
199F NEW TAI LUE LETTER LOW LA
19A0 NEW TAI LUE LETTER HIGH HA
19A1 NEW TAI LUE LETTER HIGH DA
19A2 NEW TAI LUE LETTER HIGH BA
19A3 NEW TAI LUE LETTER LOW HA
19A4 NEW TAI LUE LETTER LOW DA
19A5 NEW TAI LUE LETTER LOW BA
19A6 NEW TAI LUE LETTER HIGH KVA
19A7 NEW TAI LUE LETTER HIGH XVA
19A8 NEW TAI LUE LETTER LOW KVA
19A9 NEW TAI LUE LETTER LOW XVA
19AA NEW TAI LUE LETTER HIGH SUA
19AB NEW TAI LUE LETTER LOW SUA
19B0 NEW TAI LUE VOWEL SIGN VOWEL SHORTENER
19B1 NEW TAI LUE VOWEL SIGN AA
19B2 NEW TAI LUE VOWEL SIGN II
19B3 NEW TAI LUE VOWEL SIGN U
19B4 NEW TAI LUE VOWEL SIGN UU
19B5 NEW TAI LUE VOWEL SIGN E
19B6 NEW TAI LUE VOWEL SIGN AE
19B7 NEW TAI LUE VOWEL SIGN O
19B8 NEW TAI LUE VOWEL SIGN OA
19B9 NEW TAI LUE VOWEL SIGN UE
19BA NEW TAI LUE VOWEL SIGN AY
19BB NEW TAI LUE VOWEL SIGN AAY
19BC NEW TAI LUE VOWEL SIGN UY
19BD NEW TAI LUE VOWEL SIGN OY
19BE NEW TAI LUE VOWEL SIGN OAY
19BF NEW TAI LUE VOWEL SIGN UEY
19C0 NEW TAI LUE VOWEL SIGN IY
19C1 NEW TAI LUE LETTER FINAL V
19C2 NEW TAI LUE LETTER FINAL NG
19C3 NEW TAI LUE LETTER FINAL N
19C4 NEW TAI LUE LETTER FINAL M
19C5 NEW TAI LUE LETTER FINAL K
19C6 NEW TAI LUE LETTER FINAL D
19C7 NEW TAI LUE LETTER FINAL B
19C8 NEW TAI LUE TONE MARK-1
19C9 NEW TAI LUE TONE MARK-2
19D0 NEW TAI LUE DIGIT ZERO
19D1 NEW TAI LUE DIGIT ONE
19D2 NEW TAI LUE DIGIT TWO
19D3 NEW TAI LUE DIGIT THREE
19D4 NEW TAI LUE DIGIT FOUR
19D5 NEW TAI LUE DIGIT FIVE
19D6 NEW TAI LUE DIGIT SIX
19D7 NEW TAI LUE DIGIT SEVEN
19D8 NEW TAI LUE DIGIT EIGHT
19D9 NEW TAI LUE DIGIT NINE
19DA NEW TAI LUE THAM DIGIT ONE
19DE NEW TAI LUE SIGN LAE
19DF NEW TAI LUE SIGN LAEV
19E0 KHMER SYMBOL PATHAMASAT
19E1 KHMER SYMBOL MUOY KOET
19E2 KHMER SYMBOL PII KOET
19E3 KHMER SYMBOL BEI KOET
19E4 KHMER SYMBOL BUON KOET
19E5 KHMER SYMBOL PRAM KOET
19E6 KHMER SYMBOL PRAM-MUOY KOET
19E7 KHMER SYMBOL PRAM-PII KOET
19E8 KHMER SYMBOL PRAM-BEI KOET
19E9 KHMER SYMBOL PRAM-BUON KOET
19EA KHMER SYMBOL DAP KOET
19EB KHMER SYMBOL DAP-MUOY KOET
19EC KHMER SYMBOL DAP-PII KOET
19ED KHMER SYMBOL DAP-BEI KOET
19EE KHMER SYMBOL DAP-BUON KOET
19EF KHMER SYMBOL DAP-PRAM KOET
19F0 KHMER SYMBOL TUTEYASAT
19F1 KHMER SYMBOL MUOY ROC
19F2 KHMER SYMBOL PII ROC
19F3 KHMER SYMBOL BEI ROC
19F4 KHMER SYMBOL BUON ROC
19F5 KHMER SYMBOL PRAM ROC
19F6 KHMER SYMBOL PRAM-MUOY ROC
19F7 KHMER SYMBOL PRAM-PII ROC
19F8 KHMER SYMBOL PRAM-BEI ROC
19F9 KHMER SYMBOL PRAM-BUON ROC
19FA KHMER SYMBOL DAP ROC
19FB KHMER SYMBOL DAP-MUOY ROC
19FC KHMER SYMBOL DAP-PII ROC
19FD KHMER SYMBOL DAP-BEI ROC
19FE KHMER SYMBOL DAP-BUON ROC
19FF KHMER SYMBOL DAP-PRAM ROC
1A00 BUGINESE LETTER KA
1A01 BUGINESE LETTER GA
1A02 BUGINESE LETTER NGA
1A03 BUGINESE LETTER NGKA
1A04 BUGINESE LETTER PA
1A05 BUGINESE LETTER BA
1A06 BUGINESE LETTER MA
1A07 BUGINESE LETTER MPA
1A08 BUGINESE LETTER TA
1A09 BUGINESE LETTER DA
1A0A BUGINESE LETTER NA
1A0B BUGINESE LETTER NRA
1A0C BUGINESE LETTER CA
1A0D BUGINESE LETTER JA
1A0E BUGINESE LETTER NYA
1A0F BUGINESE LETTER NYCA
1A10 BUGINESE LETTER YA
1A11 BUGINESE LETTER RA
1A12 BUGINESE LETTER LA
1A13 BUGINESE LETTER VA
1A14 BUGINESE LETTER SA
1A15 BUGINESE LETTER A
1A16 BUGINESE LETTER HA
1A17 BUGINESE VOWEL SIGN I
1A18 BUGINESE VOWEL SIGN U
1A19 BUGINESE VOWEL SIGN E
1A1A BUGINESE VOWEL SIGN O
1A1B BUGINESE VOWEL SIGN AE
1A1E BUGINESE PALLAWA
1A1F BUGINESE END OF SECTION
1A20 TAI THAM LETTER HIGH KA
1A21 TAI THAM LETTER HIGH KHA
1A22 TAI THAM LETTER HIGH KXA
1A23 TAI THAM LETTER LOW KA
1A24 TAI THAM LETTER LOW KXA
1A25 TAI THAM LETTER LOW KHA
1A26 TAI THAM LETTER NGA
1A27 TAI THAM LETTER HIGH CA
1A28 TAI THAM LETTER HIGH CHA
1A29 TAI THAM LETTER LOW CA
1A2A TAI THAM LETTER LOW SA
1A2B TAI THAM LETTER LOW CHA
1A2C TAI THAM LETTER NYA
1A2D TAI THAM LETTER RATA
1A2E TAI THAM LETTER HIGH RATHA
1A2F TAI THAM LETTER DA
1A30 TAI THAM LETTER LOW RATHA
1A31 TAI THAM LETTER RANA
1A32 TAI THAM LETTER HIGH TA
1A33 TAI THAM LETTER HIGH THA
1A34 TAI THAM LETTER LOW TA
1A35 TAI THAM LETTER LOW THA
1A36 TAI THAM LETTER NA
1A37 TAI THAM LETTER BA
1A38 TAI THAM LETTER HIGH PA
1A39 TAI THAM LETTER HIGH PHA
1A3A TAI THAM LETTER HIGH FA
1A3B TAI THAM LETTER LOW PA
1A3C TAI THAM LETTER LOW FA
1A3D TAI THAM LETTER LOW PHA
1A3E TAI THAM LETTER MA
1A3F TAI THAM LETTER LOW YA
1A40 TAI THAM LETTER HIGH YA
1A41 TAI THAM LETTER RA
1A42 TAI THAM LETTER RUE
1A43 TAI THAM LETTER LA
1A44 TAI THAM LETTER LUE
1A45 TAI THAM LETTER WA
1A46 TAI THAM LETTER HIGH SHA
1A47 TAI THAM LETTER HIGH SSA
1A48 TAI THAM LETTER HIGH SA
1A49 TAI THAM LETTER HIGH HA
1A4A TAI THAM LETTER LLA
1A4B TAI THAM LETTER A
1A4C TAI THAM LETTER LOW HA
1A4D TAI THAM LETTER I
1A4E TAI THAM LETTER II
1A4F TAI THAM LETTER U
1A50 TAI THAM LETTER UU
1A51 TAI THAM LETTER EE
1A52 TAI THAM LETTER OO
1A53 TAI THAM LETTER LAE
1A54 TAI THAM LETTER GREAT SA
1A55 TAI THAM CONSONANT SIGN MEDIAL RA
1A56 TAI THAM CONSONANT SIGN MEDIAL LA
1A57 TAI THAM CONSONANT SIGN LA TANG LAI
1A58 TAI THAM SIGN MAI KANG LAI
1A59 TAI THAM CONSONANT SIGN FINAL NGA
1A5A TAI THAM CONSONANT SIGN LOW PA
1A5B TAI THAM CONSONANT SIGN HIGH RATHA OR LOW PA
1A5C TAI THAM CONSONANT SIGN MA
1A5D TAI THAM CONSONANT SIGN BA
1A5E TAI THAM CONSONANT SIGN SA
1A60 TAI THAM SIGN SAKOT
1A61 TAI THAM VOWEL SIGN A
1A62 TAI THAM VOWEL SIGN MAI SAT
1A63 TAI THAM VOWEL SIGN AA
1A64 TAI THAM VOWEL SIGN TALL AA
1A65 TAI THAM VOWEL SIGN I
1A66 TAI THAM VOWEL SIGN II
1A67 TAI THAM VOWEL SIGN UE
1A68 TAI THAM VOWEL SIGN UUE
1A69 TAI THAM VOWEL SIGN U
1A6A TAI THAM VOWEL SIGN UU
1A6B TAI THAM VOWEL SIGN O
1A6C TAI THAM VOWEL SIGN OA BELOW
1A6D TAI THAM VOWEL SIGN OY
1A6E TAI THAM VOWEL SIGN E
1A6F TAI THAM VOWEL SIGN AE
1A70 TAI THAM VOWEL SIGN OO
1A71 TAI THAM VOWEL SIGN AI
1A72 TAI THAM VOWEL SIGN THAM AI
1A73 TAI THAM VOWEL SIGN OA ABOVE
1A74 TAI THAM SIGN MAI KANG
1A75 TAI THAM SIGN TONE-1
1A76 TAI THAM SIGN TONE-2
1A77 TAI THAM SIGN KHUEN TONE-3
1A78 TAI THAM SIGN KHUEN TONE-4
1A79 TAI THAM SIGN KHUEN TONE-5
1A7A TAI THAM SIGN RA HAAM
1A7B TAI THAM SIGN MAI SAM
1A7C TAI THAM SIGN KHUEN-LUE KARAN
1A7F TAI THAM COMBINING CRYPTOGRAMMIC DOT
1A80 TAI THAM HORA DIGIT ZERO
1A81 TAI THAM HORA DIGIT ONE
1A82 TAI THAM HORA DIGIT TWO
1A83 TAI THAM HORA DIGIT THREE
1A84 TAI THAM HORA DIGIT FOUR
1A85 TAI THAM HORA DIGIT FIVE
1A86 TAI THAM HORA DIGIT SIX
1A87 TAI THAM HORA DIGIT SEVEN
1A88 TAI THAM HORA DIGIT EIGHT
1A89 TAI THAM HORA DIGIT NINE
1A90 TAI THAM THAM DIGIT ZERO
1A91 TAI THAM THAM DIGIT ONE
1A92 TAI THAM THAM DIGIT TWO
1A93 TAI THAM THAM DIGIT THREE
1A94 TAI THAM THAM DIGIT FOUR
1A95 TAI THAM THAM DIGIT FIVE
1A96 TAI THAM THAM DIGIT SIX
1A97 TAI THAM THAM DIGIT SEVEN
1A98 TAI THAM THAM DIGIT EIGHT
1A99 TAI THAM THAM DIGIT NINE
1AA0 TAI THAM SIGN WIANG
1AA1 TAI THAM SIGN WIANGWAAK
1AA2 TAI THAM SIGN SAWAN
1AA3 TAI THAM SIGN KEOW
1AA4 TAI THAM SIGN HOY
1AA5 TAI THAM SIGN DOKMAI
1AA6 TAI THAM SIGN REVERSED ROTATED RANA
1AA7 TAI THAM SIGN MAI YAMOK
1AA8 TAI THAM SIGN KAAN
1AA9 TAI THAM SIGN KAANKUU
1AAA TAI THAM SIGN SATKAAN
1AAB TAI THAM SIGN SATKAANKUU
1AAC TAI THAM SIGN HANG
1AAD TAI THAM SIGN CAANG
1AB0 COMBINING DOUBLED CIRCUMFLEX ACCENT
1AB1 COMBINING DIAERESIS-RING
1AB2 COMBINING INFINITY
1AB3 COMBINING DOWNWARDS ARROW
1AB4 COMBINING TRIPLE DOT
1AB5 COMBINING X-X BELOW
1AB6 COMBINING WIGGLY LINE BELOW
1AB7 COMBINING OPEN MARK BELOW
1AB8 COMBINING DOUBLE OPEN MARK BELOW
1AB9 COMBINING LIGHT CENTRALIZATION STROKE BELOW
1ABA COMBINING STRONG CENTRALIZATION STROKE BELOW
1ABB COMBINING PARENTHESES ABOVE
1ABC COMBINING DOUBLE PARENTHESES ABOVE
1ABD COMBINING PARENTHESES BELOW
1ABE COMBINING PARENTHESES OVERLAY
1B00 BALINESE SIGN ULU RICEM
1B01 BALINESE SIGN ULU CANDRA
1B02 BALINESE SIGN CECEK
1B03 BALINESE SIGN SURANG
1B04 BALINESE SIGN BISAH
1B05 BALINESE LETTER AKARA
1B06 BALINESE LETTER AKARA TEDUNG
1B07 BALINESE LETTER IKARA
1B08 BALINESE LETTER IKARA TEDUNG
1B09 BALINESE LETTER UKARA
1B0A BALINESE LETTER UKARA TEDUNG
1B0B BALINESE LETTER RA REPA
1B0C BALINESE LETTER RA REPA TEDUNG
1B0D BALINESE LETTER LA LENGA
1B0E BALINESE LETTER LA LENGA TEDUNG
1B0F BALINESE LETTER EKARA
1B10 BALINESE LETTER AIKARA
1B11 BALINESE LETTER OKARA
1B12 BALINESE LETTER OKARA TEDUNG
1B13 BALINESE LETTER KA
1B14 BALINESE LETTER KA MAHAPRANA
1B15 BALINESE LETTER GA
1B16 BALINESE LETTER GA GORA
1B17 BALINESE LETTER NGA
1B18 BALINESE LETTER CA
1B19 BALINESE LETTER CA LACA
1B1A BALINESE LETTER JA
1B1B BALINESE LETTER JA JERA
1B1C BALINESE LETTER NYA
1B1D BALINESE LETTER TA LATIK
1B1E BALINESE LETTER TA MURDA MAHAPRANA
1B1F BALINESE LETTER DA MURDA ALPAPRANA
1B20 BALINESE LETTER DA MURDA MAHAPRANA
1B21 BALINESE LETTER NA RAMBAT
1B22 BALINESE LETTER TA
1B23 BALINESE LETTER TA TAWA
1B24 BALINESE LETTER DA
1B25 BALINESE LETTER DA MADU
1B26 BALINESE LETTER NA
1B27 BALINESE LETTER PA
1B28 BALINESE LETTER PA KAPAL
1B29 BALINESE LETTER BA
1B2A BALINESE LETTER BA KEMBANG
1B2B BALINESE LETTER MA
1B2C BALINESE LETTER YA
1B2D BALINESE LETTER RA
1B2E BALINESE LETTER LA
1B2F BALINESE LETTER WA
1B30 BALINESE LETTER SA SAGA
1B31 BALINESE LETTER SA SAPA
1B32 BALINESE LETTER SA
1B33 BALINESE LETTER HA
1B34 BALINESE SIGN REREKAN
1B35 BALINESE VOWEL SIGN TEDUNG
1B36 BALINESE VOWEL SIGN ULU
1B37 BALINESE VOWEL SIGN ULU SARI
1B38 BALINESE VOWEL SIGN SUKU
1B39 BALINESE VOWEL SIGN SUKU ILUT
1B3A BALINESE VOWEL SIGN RA REPA
1B3B BALINESE VOWEL SIGN RA REPA TEDUNG
1B3C BALINESE VOWEL SIGN LA LENGA
1B3D BALINESE VOWEL SIGN LA LENGA TEDUNG
1B3E BALINESE VOWEL SIGN TALING
1B3F BALINESE VOWEL SIGN TALING REPA
1B40 BALINESE VOWEL SIGN TALING TEDUNG
1B41 BALINESE VOWEL SIGN TALING REPA TEDUNG
1B42 BALINESE VOWEL SIGN PEPET
1B43 BALINESE VOWEL SIGN PEPET TEDUNG
1B44 BALINESE ADEG ADEG
1B45 BALINESE LETTER KAF SASAK
1B46 BALINESE LETTER KHOT SASAK
1B47 BALINESE LETTER TZIR SASAK
1B48 BALINESE LETTER EF SASAK
1B49 BALINESE LETTER VE SASAK
1B4A BALINESE LETTER ZAL SASAK
1B4B BALINESE LETTER ASYURA SASAK
1B50 BALINESE DIGIT ZERO
1B51 BALINESE DIGIT ONE
1B52 BALINESE DIGIT TWO
1B53 BALINESE DIGIT THREE
1B54 BALINESE DIGIT FOUR
1B55 BALINESE DIGIT FIVE
1B56 BALINESE DIGIT SIX
1B57 BALINESE DIGIT SEVEN
1B58 BALINESE DIGIT EIGHT
1B59 BALINESE DIGIT NINE
1B5A BALINESE PANTI
1B5B BALINESE PAMADA
1B5C BALINESE WINDU
1B5D BALINESE CARIK PAMUNGKAH
1B5E BALINESE CARIK SIKI
1B5F BALINESE CARIK PAREREN
1B60 BALINESE PAMENENG
1B61 BALINESE MUSICAL SYMBOL DONG
1B62 BALINESE MUSICAL SYMBOL DENG
1B63 BALINESE MUSICAL SYMBOL DUNG
1B64 BALINESE MUSICAL SYMBOL DANG
1B65 BALINESE MUSICAL SYMBOL DANG SURANG
1B66 BALINESE MUSICAL SYMBOL DING
1B67 BALINESE MUSICAL SYMBOL DAENG
1B68 BALINESE MUSICAL SYMBOL DEUNG
1B69 BALINESE MUSICAL SYMBOL DAING
1B6A BALINESE MUSICAL SYMBOL DANG GEDE
1B6B BALINESE MUSICAL SYMBOL COMBINING TEGEH
1B6C BALINESE MUSICAL SYMBOL COMBINING ENDEP
1B6D BALINESE MUSICAL SYMBOL COMBINING KEMPUL
1B6E BALINESE MUSICAL SYMBOL COMBINING KEMPLI
1B6F BALINESE MUSICAL SYMBOL COMBINING JEGOGAN
1B70 BALINESE MUSICAL SYMBOL COMBINING KEMPUL WITH JEGOGAN
1B71 BALINESE MUSICAL SYMBOL COMBINING KEMPLI WITH JEGOGAN
1B72 BALINESE MUSICAL SYMBOL COMBINING BENDE
1B73 BALINESE MUSICAL SYMBOL COMBINING GONG
1B74 BALINESE MUSICAL SYMBOL RIGHT-HAND OPEN DUG
1B75 BALINESE MUSICAL SYMBOL RIGHT-HAND OPEN DAG
1B76 BALINESE MUSICAL SYMBOL RIGHT-HAND CLOSED TUK
1B77 BALINESE MUSICAL SYMBOL RIGHT-HAND CLOSED TAK
1B78 BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PANG
1B79 BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PUNG
1B7A BALINESE MUSICAL SYMBOL LEFT-HAND CLOSED PLAK
1B7B BALINESE MUSICAL SYMBOL LEFT-HAND CLOSED PLUK
1B7C BALINESE MUSICAL SYMBOL LEFT-HAND OPEN PING
1B80 SUNDANESE SIGN PANYECEK
1B81 SUNDANESE SIGN PANGLAYAR
1B82 SUNDANESE SIGN PANGWISAD
1B83 SUNDANESE LETTER A
1B84 SUNDANESE LETTER I
1B85 SUNDANESE LETTER U
1B86 SUNDANESE LETTER AE
1B87 SUNDANESE LETTER O
1B88 SUNDANESE LETTER E
1B89 SUNDANESE LETTER EU
1B8A SUNDANESE LETTER KA
1B8B SUNDANESE LETTER QA
1B8C SUNDANESE LETTER GA
1B8D SUNDANESE LETTER NGA
1B8E SUNDANESE LETTER CA
1B8F SUNDANESE LETTER JA
1B90 SUNDANESE LETTER ZA
1B91 SUNDANESE LETTER NYA
1B92 SUNDANESE LETTER TA
1B93 SUNDANESE LETTER DA
1B94 SUNDANESE LETTER NA
1B95 SUNDANESE LETTER PA
1B96 SUNDANESE LETTER FA
1B97 SUNDANESE LETTER VA
1B98 SUNDANESE LETTER BA
1B99 SUNDANESE LETTER MA
1B9A SUNDANESE LETTER YA
1B9B SUNDANESE LETTER RA
1B9C SUNDANESE LETTER LA
1B9D SUNDANESE LETTER WA
1B9E SUNDANESE LETTER SA
1B9F SUNDANESE LETTER XA
1BA0 SUNDANESE LETTER HA
1BA1 SUNDANESE CONSONANT SIGN PAMINGKAL
1BA2 SUNDANESE CONSONANT SIGN PANYAKRA
1BA3 SUNDANESE CONSONANT SIGN PANYIKU
1BA4 SUNDANESE VOWEL SIGN PANGHULU
1BA5 SUNDANESE VOWEL SIGN PANYUKU
1BA6 SUNDANESE VOWEL SIGN PANAELAENG
1BA7 SUNDANESE VOWEL SIGN PANOLONG
1BA8 SUNDANESE VOWEL SIGN PAMEPET
1BA9 SUNDANESE VOWEL SIGN PANEULEUNG
1BAA SUNDANESE SIGN PAMAAEH
1BAB SUNDANESE SIGN VIRAMA
1BAC SUNDANESE CONSONANT SIGN PASANGAN MA
1BAD SUNDANESE CONSONANT SIGN PASANGAN WA
1BAE SUNDANESE LETTER KHA
1BAF SUNDANESE LETTER SYA
1BB0 SUNDANESE DIGIT ZERO
1BB1 SUNDANESE DIGIT ONE
1BB2 SUNDANESE DIGIT TWO
1BB3 SUNDANESE DIGIT THREE
1BB4 SUNDANESE DIGIT FOUR
1BB5 SUNDANESE DIGIT FIVE
1BB6 SUNDANESE DIGIT SIX
1BB7 SUNDANESE DIGIT SEVEN
1BB8 SUNDANESE DIGIT EIGHT
1BB9 SUNDANESE DIGIT NINE
1BBA SUNDANESE AVAGRAHA
1BBB SUNDANESE LETTER REU
1BBC SUNDANESE LETTER LEU
1BBD SUNDANESE LETTER BHA
1BBE SUNDANESE LETTER FINAL K
1BBF SUNDANESE LETTER FINAL M
1BC0 BATAK LETTER A
1BC1 BATAK LETTER SIMALUNGUN A
1BC2 BATAK LETTER HA
1BC3 BATAK LETTER SIMALUNGUN HA
1BC4 BATAK LETTER MANDAILING HA
1BC5 BATAK LETTER BA
1BC6 BATAK LETTER KARO BA
1BC7 BATAK LETTER PA
1BC8 BATAK LETTER SIMALUNGUN PA
1BC9 BATAK LETTER NA
1BCA BATAK LETTER MANDAILING NA
1BCB BATAK LETTER WA
1BCC BATAK LETTER SIMALUNGUN WA
1BCD BATAK LETTER PAKPAK WA
1BCE BATAK LETTER GA
1BCF BATAK LETTER SIMALUNGUN GA
1BD0 BATAK LETTER JA
1BD1 BATAK LETTER DA
1BD2 BATAK LETTER RA
1BD3 BATAK LETTER SIMALUNGUN RA
1BD4 BATAK LETTER MA
1BD5 BATAK LETTER SIMALUNGUN MA
1BD6 BATAK LETTER SOUTHERN TA
1BD7 BATAK LETTER NORTHERN TA
1BD8 BATAK LETTER SA
1BD9 BATAK LETTER SIMALUNGUN SA
1BDA BATAK LETTER MANDAILING SA
1BDB BATAK LETTER YA
1BDC BATAK LETTER SIMALUNGUN YA
1BDD BATAK LETTER NGA
1BDE BATAK LETTER LA
1BDF BATAK LETTER SIMALUNGUN LA
1BE0 BATAK LETTER NYA
1BE1 BATAK LETTER CA
1BE2 BATAK LETTER NDA
1BE3 BATAK LETTER MBA
1BE4 BATAK LETTER I
1BE5 BATAK LETTER U
1BE6 BATAK SIGN TOMPI
1BE7 BATAK VOWEL SIGN E
1BE8 BATAK VOWEL SIGN PAKPAK E
1BE9 BATAK VOWEL SIGN EE
1BEA BATAK VOWEL SIGN I
1BEB BATAK VOWEL SIGN KARO I
1BEC BATAK VOWEL SIGN O
1BED BATAK VOWEL SIGN KARO O
1BEE BATAK VOWEL SIGN U
1BEF BATAK VOWEL SIGN U FOR SIMALUNGUN SA
1BF0 BATAK CONSONANT SIGN NG
1BF1 BATAK CONSONANT SIGN H
1BF2 BATAK PANGOLAT
1BF3 BATAK PANONGONAN
1BFC BATAK SYMBOL BINDU NA METEK
1BFD BATAK SYMBOL BINDU PINARBORAS
1BFE BATAK SYMBOL BINDU JUDUL
1BFF BATAK SYMBOL BINDU PANGOLAT
1C00 LEPCHA LETTER KA
1C01 LEPCHA LETTER KLA
1C02 LEPCHA LETTER KHA
1C03 LEPCHA LETTER GA
1C04 LEPCHA LETTER GLA
1C05 LEPCHA LETTER NGA
1C06 LEPCHA LETTER CA
1C07 LEPCHA LETTER CHA
1C08 LEPCHA LETTER JA
1C09 LEPCHA LETTER NYA
1C0A LEPCHA LETTER TA
1C0B LEPCHA LETTER THA
1C0C LEPCHA LETTER DA
1C0D LEPCHA LETTER NA
1C0E LEPCHA LETTER PA
1C0F LEPCHA LETTER PLA
1C10 LEPCHA LETTER PHA
1C11 LEPCHA LETTER FA
1C12 LEPCHA LETTER FLA
1C13 LEPCHA LETTER BA
1C14 LEPCHA LETTER BLA
1C15 LEPCHA LETTER MA
1C16 LEPCHA LETTER MLA
1C17 LEPCHA LETTER TSA
1C18 LEPCHA LETTER TSHA
1C19 LEPCHA LETTER DZA
1C1A LEPCHA LETTER YA
1C1B LEPCHA LETTER RA
1C1C LEPCHA LETTER LA
1C1D LEPCHA LETTER HA
1C1E LEPCHA LETTER HLA
1C1F LEPCHA LETTER VA
1C20 LEPCHA LETTER SA
1C21 LEPCHA LETTER SHA
1C22 LEPCHA LETTER WA
1C23 LEPCHA LETTER A
1C24 LEPCHA SUBJOINED LETTER YA
1C25 LEPCHA SUBJOINED LETTER RA
1C26 LEPCHA VOWEL SIGN AA
1C27 LEPCHA VOWEL SIGN I
1C28 LEPCHA VOWEL SIGN O
1C29 LEPCHA VOWEL SIGN OO
1C2A LEPCHA VOWEL SIGN U
1C2B LEPCHA VOWEL SIGN UU
1C2C LEPCHA VOWEL SIGN E
1C2D LEPCHA CONSONANT SIGN K
1C2E LEPCHA CONSONANT SIGN M
1C2F LEPCHA CONSONANT SIGN L
1C30 LEPCHA CONSONANT SIGN N
1C31 LEPCHA CONSONANT SIGN P
1C32 LEPCHA CONSONANT SIGN R
1C33 LEPCHA CONSONANT SIGN T
1C34 LEPCHA CONSONANT SIGN NYIN-DO
1C35 LEPCHA CONSONANT SIGN KANG
1C36 LEPCHA SIGN RAN
1C37 LEPCHA SIGN NUKTA
1C3B LEPCHA PUNCTUATION TA-ROL
1C3C LEPCHA PUNCTUATION NYET THYOOM TA-ROL
1C3D LEPCHA PUNCTUATION CER-WA
1C3E LEPCHA PUNCTUATION TSHOOK CER-WA
1C3F LEPCHA PUNCTUATION TSHOOK
1C40 LEPCHA DIGIT ZERO
1C41 LEPCHA DIGIT ONE
1C42 LEPCHA DIGIT TWO
1C43 LEPCHA DIGIT THREE
1C44 LEPCHA DIGIT FOUR
1C45 LEPCHA DIGIT FIVE
1C46 LEPCHA DIGIT SIX
1C47 LEPCHA DIGIT SEVEN
1C48 LEPCHA DIGIT EIGHT
1C49 LEPCHA DIGIT NINE
1C4D LEPCHA LETTER TTA
1C4E LEPCHA LETTER TTHA
1C4F LEPCHA LETTER DDA
1C50 OL CHIKI DIGIT ZERO
1C51 OL CHIKI DIGIT ONE
1C52 OL CHIKI DIGIT TWO
1C53 OL CHIKI DIGIT THREE
1C54 OL CHIKI DIGIT FOUR
1C55 OL CHIKI DIGIT FIVE
1C56 OL CHIKI DIGIT SIX
1C57 OL CHIKI DIGIT SEVEN
1C58 OL CHIKI DIGIT EIGHT
1C59 OL CHIKI DIGIT NINE
1C5A OL CHIKI LETTER LA
1C5B OL CHIKI LETTER AT
1C5C OL CHIKI LETTER AG
1C5D OL CHIKI LETTER ANG
1C5E OL CHIKI LETTER AL
1C5F OL CHIKI LETTER LAA
1C60 OL CHIKI LETTER AAK
1C61 OL CHIKI LETTER AAJ
1C62 OL CHIKI LETTER AAM
1C63 OL CHIKI LETTER AAW
1C64 OL CHIKI LETTER LI
1C65 OL CHIKI LETTER IS
1C66 OL CHIKI LETTER IH
1C67 OL CHIKI LETTER INY
1C68 OL CHIKI LETTER IR
1C69 OL CHIKI LETTER LU
1C6A OL CHIKI LETTER UC
1C6B OL CHIKI LETTER UD
1C6C OL CHIKI LETTER UNN
1C6D OL CHIKI LETTER UY
1C6E OL CHIKI LETTER LE
1C6F OL CHIKI LETTER EP
1C70 OL CHIKI LETTER EDD
1C71 OL CHIKI LETTER EN
1C72 OL CHIKI LETTER ERR
1C73 OL CHIKI LETTER LO
1C74 OL CHIKI LETTER OTT
1C75 OL CHIKI LETTER OB
1C76 OL CHIKI LETTER OV
1C77 OL CHIKI LETTER OH
1C78 OL CHIKI MU TTUDDAG
1C79 OL CHIKI GAAHLAA TTUDDAAG
1C7A OL CHIKI MU-GAAHLAA TTUDDAAG
1C7B OL CHIKI RELAA
1C7C OL CHIKI PHAARKAA
1C7D OL CHIKI AHAD
1C7E OL CHIKI PUNCTUATION MUCAAD
1C7F OL CHIKI PUNCTUATION DOUBLE MUCAAD
1C80 CYRILLIC SMALL LETTER ROUNDED VE
1C81 CYRILLIC SMALL LETTER LONG-LEGGED DE
1C82 CYRILLIC SMALL LETTER NARROW O
1C83 CYRILLIC SMALL LETTER WIDE ES
1C84 CYRILLIC SMALL LETTER TALL TE
1C85 CYRILLIC SMALL LETTER THREE-LEGGED TE
1C86 CYRILLIC SMALL LETTER TALL HARD SIGN
1C87 CYRILLIC SMALL LETTER TALL YAT
1C88 CYRILLIC SMALL LETTER UNBLENDED UK
1CC0 SUNDANESE PUNCTUATION BINDU SURYA
1CC1 SUNDANESE PUNCTUATION BINDU PANGLONG
1CC2 SUNDANESE PUNCTUATION BINDU PURNAMA
1CC3 SUNDANESE PUNCTUATION BINDU CAKRA
1CC4 SUNDANESE PUNCTUATION BINDU LEU SATANGA
1CC5 SUNDANESE PUNCTUATION BINDU KA SATANGA
1CC6 SUNDANESE PUNCTUATION BINDU DA SATANGA
1CC7 SUNDANESE PUNCTUATION BINDU BA SATANGA
1CD0 VEDIC TONE KARSHANA
1CD1 VEDIC TONE SHARA
1CD2 VEDIC TONE PRENKHA
1CD3 VEDIC SIGN NIHSHVASA
1CD4 VEDIC SIGN YAJURVEDIC MIDLINE SVARITA
1CD5 VEDIC TONE YAJURVEDIC AGGRAVATED INDEPENDENT SVARITA
1CD6 VEDIC TONE YAJURVEDIC INDEPENDENT SVARITA
1CD7 VEDIC TONE YAJURVEDIC KATHAKA INDEPENDENT SVARITA
1CD8 VEDIC TONE CANDRA BELOW
1CD9 VEDIC TONE YAJURVEDIC KATHAKA INDEPENDENT SVARITA SCHROEDER
1CDA VEDIC TONE DOUBLE SVARITA
1CDB VEDIC TONE TRIPLE SVARITA
1CDC VEDIC TONE KATHAKA ANUDATTA
1CDD VEDIC TONE DOT BELOW
1CDE VEDIC TONE TWO DOTS BELOW
1CDF VEDIC TONE THREE DOTS BELOW
1CE0 VEDIC TONE RIGVEDIC KASHMIRI INDEPENDENT SVARITA
1CE1 VEDIC TONE ATHARVAVEDIC INDEPENDENT SVARITA
1CE2 VEDIC SIGN VISARGA SVARITA
1CE3 VEDIC SIGN VISARGA UDATTA
1CE4 VEDIC SIGN REVERSED VISARGA UDATTA
1CE5 VEDIC SIGN VISARGA ANUDATTA
1CE6 VEDIC SIGN REVERSED VISARGA ANUDATTA
1CE7 VEDIC SIGN VISARGA UDATTA WITH TAIL
1CE8 VEDIC SIGN VISARGA ANUDATTA WITH TAIL
1CE9 VEDIC SIGN ANUSVARA ANTARGOMUKHA
1CEA VEDIC SIGN ANUSVARA BAHIRGOMUKHA
1CEB VEDIC SIGN ANUSVARA VAMAGOMUKHA
1CEC VEDIC SIGN ANUSVARA VAMAGOMUKHA WITH TAIL
1CED VEDIC SIGN TIRYAK
1CEE VEDIC SIGN HEXIFORM LONG ANUSVARA
1CEF VEDIC SIGN LONG ANUSVARA
1CF0 VEDIC SIGN RTHANG LONG ANUSVARA
1CF1 VEDIC SIGN ANUSVARA UBHAYATO MUKHA
1CF2 VEDIC SIGN ARDHAVISARGA
1CF3 VEDIC SIGN ROTATED ARDHAVISARGA
1CF4 VEDIC TONE CANDRA ABOVE
1CF5 VEDIC SIGN JIHVAMULIYA
1CF6 VEDIC SIGN UPADHMANIYA
1CF7 VEDIC SIGN ATIKRAMA
1CF8 VEDIC TONE RING ABOVE
1CF9 VEDIC TONE DOUBLE RING ABOVE
1D00 LATIN LETTER SMALL CAPITAL A
1D01 LATIN LETTER SMALL CAPITAL AE
1D02 LATIN SMALL LETTER TURNED AE
1D03 LATIN LETTER SMALL CAPITAL BARRED B
1D04 LATIN LETTER SMALL CAPITAL C
1D05 LATIN LETTER SMALL CAPITAL D
1D06 LATIN LETTER SMALL CAPITAL ETH
1D07 LATIN LETTER SMALL CAPITAL E
1D08 LATIN SMALL LETTER TURNED OPEN E
1D09 LATIN SMALL LETTER TURNED I
1D0A LATIN LETTER SMALL CAPITAL J
1D0B LATIN LETTER SMALL CAPITAL K
1D0C LATIN LETTER SMALL CAPITAL L WITH STROKE
1D0D LATIN LETTER SMALL CAPITAL M
1D0E LATIN LETTER SMALL CAPITAL REVERSED N
1D0F LATIN LETTER SMALL CAPITAL O
1D10 LATIN LETTER SMALL CAPITAL OPEN O
1D11 LATIN SMALL LETTER SIDEWAYS O
1D12 LATIN SMALL LETTER SIDEWAYS OPEN O
1D13 LATIN SMALL LETTER SIDEWAYS O WITH STROKE
1D14 LATIN SMALL LETTER TURNED OE
1D15 LATIN LETTER SMALL CAPITAL OU
1D16 LATIN SMALL LETTER TOP HALF O
1D17 LATIN SMALL LETTER BOTTOM HALF O
1D18 LATIN LETTER SMALL CAPITAL P
1D19 LATIN LETTER SMALL CAPITAL REVERSED R
1D1A LATIN LETTER SMALL CAPITAL TURNED R
1D1B LATIN LETTER SMALL CAPITAL T
1D1C LATIN LETTER SMALL CAPITAL U
1D1D LATIN SMALL LETTER SIDEWAYS U
1D1E LATIN SMALL LETTER SIDEWAYS DIAERESIZED U
1D1F LATIN SMALL LETTER SIDEWAYS TURNED M
1D20 LATIN LETTER SMALL CAPITAL V
1D21 LATIN LETTER SMALL CAPITAL W
1D22 LATIN LETTER SMALL CAPITAL Z
1D23 LATIN LETTER SMALL CAPITAL EZH
1D24 LATIN LETTER VOICED LARYNGEAL SPIRANT
1D25 LATIN LETTER AIN
1D26 GREEK LETTER SMALL CAPITAL GAMMA
1D27 GREEK LETTER SMALL CAPITAL LAMDA
1D28 GREEK LETTER SMALL CAPITAL PI
1D29 GREEK LETTER SMALL CAPITAL RHO
1D2A GREEK LETTER SMALL CAPITAL PSI
1D2B CYRILLIC LETTER SMALL CAPITAL EL
1D2C MODIFIER LETTER CAPITAL A
1D2D MODIFIER LETTER CAPITAL AE
1D2E MODIFIER LETTER CAPITAL B
1D2F MODIFIER LETTER CAPITAL BARRED B
1D30 MODIFIER LETTER CAPITAL D
1D31 MODIFIER LETTER CAPITAL E
1D32 MODIFIER LETTER CAPITAL REVERSED E
1D33 MODIFIER LETTER CAPITAL G
1D34 MODIFIER LETTER CAPITAL H
1D35 MODIFIER LETTER CAPITAL I
1D36 MODIFIER LETTER CAPITAL J
1D37 MODIFIER LETTER CAPITAL K
1D38 MODIFIER LETTER CAPITAL L
1D39 MODIFIER LETTER CAPITAL M
1D3A MODIFIER LETTER CAPITAL N
1D3B MODIFIER LETTER CAPITAL REVERSED N
1D3C MODIFIER LETTER CAPITAL O
1D3D MODIFIER LETTER CAPITAL OU
1D3E MODIFIER LETTER CAPITAL P
1D3F MODIFIER LETTER CAPITAL R
1D40 MODIFIER LETTER CAPITAL T
1D41 MODIFIER LETTER CAPITAL U
1D42 MODIFIER LETTER CAPITAL W
1D43 MODIFIER LETTER SMALL A
1D44 MODIFIER LETTER SMALL TURNED A
1D45 MODIFIER LETTER SMALL ALPHA
1D46 MODIFIER LETTER SMALL TURNED AE
1D47 MODIFIER LETTER SMALL B
1D48 MODIFIER LETTER SMALL D
1D49 MODIFIER LETTER SMALL E
1D4A MODIFIER LETTER SMALL SCHWA
1D4B MODIFIER LETTER SMALL OPEN E
1D4C MODIFIER LETTER SMALL TURNED OPEN E
1D4D MODIFIER LETTER SMALL G
1D4E MODIFIER LETTER SMALL TURNED I
1D4F MODIFIER LETTER SMALL K
1D50 MODIFIER LETTER SMALL M
1D51 MODIFIER LETTER SMALL ENG
1D52 MODIFIER LETTER SMALL O
1D53 MODIFIER LETTER SMALL OPEN O
1D54 MODIFIER LETTER SMALL TOP HALF O
1D55 MODIFIER LETTER SMALL BOTTOM HALF O
1D56 MODIFIER LETTER SMALL P
1D57 MODIFIER LETTER SMALL T
1D58 MODIFIER LETTER SMALL U
1D59 MODIFIER LETTER SMALL SIDEWAYS U
1D5A MODIFIER LETTER SMALL TURNED M
1D5B MODIFIER LETTER SMALL V
1D5C MODIFIER LETTER SMALL AIN
1D5D MODIFIER LETTER SMALL BETA
1D5E MODIFIER LETTER SMALL GREEK GAMMA
1D5F MODIFIER LETTER SMALL DELTA
1D60 MODIFIER LETTER SMALL GREEK PHI
1D61 MODIFIER LETTER SMALL CHI
1D62 LATIN SUBSCRIPT SMALL LETTER I
1D63 LATIN SUBSCRIPT SMALL LETTER R
1D64 LATIN SUBSCRIPT SMALL LETTER U
1D65 LATIN SUBSCRIPT SMALL LETTER V
1D66 GREEK SUBSCRIPT SMALL LETTER BETA
1D67 GREEK SUBSCRIPT SMALL LETTER GAMMA
1D68 GREEK SUBSCRIPT SMALL LETTER RHO
1D69 GREEK SUBSCRIPT SMALL LETTER PHI
1D6A GREEK SUBSCRIPT SMALL LETTER CHI
1D6B LATIN SMALL LETTER UE
1D6C LATIN SMALL LETTER B WITH MIDDLE TILDE
1D6D LATIN SMALL LETTER D WITH MIDDLE TILDE
1D6E LATIN SMALL LETTER F WITH MIDDLE TILDE
1D6F LATIN SMALL LETTER M WITH MIDDLE TILDE
1D70 LATIN SMALL LETTER N WITH MIDDLE TILDE
1D71 LATIN SMALL LETTER P WITH MIDDLE TILDE
1D72 LATIN SMALL LETTER R WITH MIDDLE TILDE
1D73 LATIN SMALL LETTER R WITH FISHHOOK AND MIDDLE TILDE
1D74 LATIN SMALL LETTER S WITH MIDDLE TILDE
1D75 LATIN SMALL LETTER T WITH MIDDLE TILDE
1D76 LATIN SMALL LETTER Z WITH MIDDLE TILDE
1D77 LATIN SMALL LETTER TURNED G
1D78 MODIFIER LETTER CYRILLIC EN
1D79 LATIN SMALL LETTER INSULAR G
1D7A LATIN SMALL LETTER TH WITH STRIKETHROUGH
1D7B LATIN SMALL CAPITAL LETTER I WITH STROKE
1D7C LATIN SMALL LETTER IOTA WITH STROKE
1D7D LATIN SMALL LETTER P WITH STROKE
1D7E LATIN SMALL CAPITAL LETTER U WITH STROKE
1D7F LATIN SMALL LETTER UPSILON WITH STROKE
1D80 LATIN SMALL LETTER B WITH PALATAL HOOK
1D81 LATIN SMALL LETTER D WITH PALATAL HOOK
1D82 LATIN SMALL LETTER F WITH PALATAL HOOK
1D83 LATIN SMALL LETTER G WITH PALATAL HOOK
1D84 LATIN SMALL LETTER K WITH PALATAL HOOK
1D85 LATIN SMALL LETTER L WITH PALATAL HOOK
1D86 LATIN SMALL LETTER M WITH PALATAL HOOK
1D87 LATIN SMALL LETTER N WITH PALATAL HOOK
1D88 LATIN SMALL LETTER P WITH PALATAL HOOK
1D89 LATIN SMALL LETTER R WITH PALATAL HOOK
1D8A LATIN SMALL LETTER S WITH PALATAL HOOK
1D8B LATIN SMALL LETTER ESH WITH PALATAL HOOK
1D8C LATIN SMALL LETTER V WITH PALATAL HOOK
1D8D LATIN SMALL LETTER X WITH PALATAL HOOK
1D8E LATIN SMALL LETTER Z WITH PALATAL HOOK
1D8F LATIN SMALL LETTER A WITH RETROFLEX HOOK
1D90 LATIN SMALL LETTER ALPHA WITH RETROFLEX HOOK
1D91 LATIN SMALL LETTER D WITH HOOK AND TAIL
1D92 LATIN SMALL LETTER E WITH RETROFLEX HOOK
1D93 LATIN SMALL LETTER OPEN E WITH RETROFLEX HOOK
1D94 LATIN SMALL LETTER REVERSED OPEN E WITH RETROFLEX HOOK
1D95 LATIN SMALL LETTER SCHWA WITH RETROFLEX HOOK
1D96 LATIN SMALL LETTER I WITH RETROFLEX HOOK
1D97 LATIN SMALL LETTER OPEN O WITH RETROFLEX HOOK
1D98 LATIN SMALL LETTER ESH WITH RETROFLEX HOOK
1D99 LATIN SMALL LETTER U WITH RETROFLEX HOOK
1D9A LATIN SMALL LETTER EZH WITH RETROFLEX HOOK
1D9B MODIFIER LETTER SMALL TURNED ALPHA
1D9C MODIFIER LETTER SMALL C
1D9D MODIFIER LETTER SMALL C WITH CURL
1D9E MODIFIER LETTER SMALL ETH
1D9F MODIFIER LETTER SMALL REVERSED OPEN E
1DA0 MODIFIER LETTER SMALL F
1DA1 MODIFIER LETTER SMALL DOTLESS J WITH STROKE
1DA2 MODIFIER LETTER SMALL SCRIPT G
1DA3 MODIFIER LETTER SMALL TURNED H
1DA4 MODIFIER LETTER SMALL I WITH STROKE
1DA5 MODIFIER LETTER SMALL IOTA
1DA6 MODIFIER LETTER SMALL CAPITAL I
1DA7 MODIFIER LETTER SMALL CAPITAL I WITH STROKE
1DA8 MODIFIER LETTER SMALL J WITH CROSSED-TAIL
1DA9 MODIFIER LETTER SMALL L WITH RETROFLEX HOOK
1DAA MODIFIER LETTER SMALL L WITH PALATAL HOOK
1DAB MODIFIER LETTER SMALL CAPITAL L
1DAC MODIFIER LETTER SMALL M WITH HOOK
1DAD MODIFIER LETTER SMALL TURNED M WITH LONG LEG
1DAE MODIFIER LETTER SMALL N WITH LEFT HOOK
1DAF MODIFIER LETTER SMALL N WITH RETROFLEX HOOK
1DB0 MODIFIER LETTER SMALL CAPITAL N
1DB1 MODIFIER LETTER SMALL BARRED O
1DB2 MODIFIER LETTER SMALL PHI
1DB3 MODIFIER LETTER SMALL S WITH HOOK
1DB4 MODIFIER LETTER SMALL ESH
1DB5 MODIFIER LETTER SMALL T WITH PALATAL HOOK
1DB6 MODIFIER LETTER SMALL U BAR
1DB7 MODIFIER LETTER SMALL UPSILON
1DB8 MODIFIER LETTER SMALL CAPITAL U
1DB9 MODIFIER LETTER SMALL V WITH HOOK
1DBA MODIFIER LETTER SMALL TURNED V
1DBB MODIFIER LETTER SMALL Z
1DBC MODIFIER LETTER SMALL Z WITH RETROFLEX HOOK
1DBD MODIFIER LETTER SMALL Z WITH CURL
1DBE MODIFIER LETTER SMALL EZH
1DBF MODIFIER LETTER SMALL THETA
1DC0 COMBINING DOTTED GRAVE ACCENT
1DC1 COMBINING DOTTED ACUTE ACCENT
1DC2 COMBINING SNAKE BELOW
1DC3 COMBINING SUSPENSION MARK
1DC4 COMBINING MACRON-ACUTE
1DC5 COMBINING GRAVE-MACRON
1DC6 COMBINING MACRON-GRAVE
1DC7 COMBINING ACUTE-MACRON
1DC8 COMBINING GRAVE-ACUTE-GRAVE
1DC9 COMBINING ACUTE-GRAVE-ACUTE
1DCA COMBINING LATIN SMALL LETTER R BELOW
1DCB COMBINING BREVE-MACRON
1DCC COMBINING MACRON-BREVE
1DCD COMBINING DOUBLE CIRCUMFLEX ABOVE
1DCE COMBINING OGONEK ABOVE
1DCF COMBINING ZIGZAG BELOW
1DD0 COMBINING IS BELOW
1DD1 COMBINING UR ABOVE
1DD2 COMBINING US ABOVE
1DD3 COMBINING LATIN SMALL LETTER FLATTENED OPEN A ABOVE
1DD4 COMBINING LATIN SMALL LETTER AE
1DD5 COMBINING LATIN SMALL LETTER AO
1DD6 COMBINING LATIN SMALL LETTER AV
1DD7 COMBINING LATIN SMALL LETTER C CEDILLA
1DD8 COMBINING LATIN SMALL LETTER INSULAR D
1DD9 COMBINING LATIN SMALL LETTER ETH
1DDA COMBINING LATIN SMALL LETTER G
1DDB COMBINING LATIN LETTER SMALL CAPITAL G
1DDC COMBINING LATIN SMALL LETTER K
1DDD COMBINING LATIN SMALL LETTER L
1DDE COMBINING LATIN LETTER SMALL CAPITAL L
1DDF COMBINING LATIN LETTER SMALL CAPITAL M
1DE0 COMBINING LATIN SMALL LETTER N
1DE1 COMBINING LATIN LETTER SMALL CAPITAL N
1DE2 COMBINING LATIN LETTER SMALL CAPITAL R
1DE3 COMBINING LATIN SMALL LETTER R ROTUNDA
1DE4 COMBINING LATIN SMALL LETTER S
1DE5 COMBINING LATIN SMALL LETTER LONG S
1DE6 COMBINING LATIN SMALL LETTER Z
1DE7 COMBINING LATIN SMALL LETTER ALPHA
1DE8 COMBINING LATIN SMALL LETTER B
1DE9 COMBINING LATIN SMALL LETTER BETA
1DEA COMBINING LATIN SMALL LETTER SCHWA
1DEB COMBINING LATIN SMALL LETTER F
1DEC COMBINING LATIN SMALL LETTER L WITH DOUBLE MIDDLE TILDE
1DED COMBINING LATIN SMALL LETTER O WITH LIGHT CENTRALIZATION STROKE
1DEE COMBINING LATIN SMALL LETTER P
1DEF COMBINING LATIN SMALL LETTER ESH
1DF0 COMBINING LATIN SMALL LETTER U WITH LIGHT CENTRALIZATION STROKE
1DF1 COMBINING LATIN SMALL LETTER W
1DF2 COMBINING LATIN SMALL LETTER A WITH DIAERESIS
1DF3 COMBINING LATIN SMALL LETTER O WITH DIAERESIS
1DF4 COMBINING LATIN SMALL LETTER U WITH DIAERESIS
1DF5 COMBINING UP TACK ABOVE
1DF6 COMBINING KAVYKA ABOVE RIGHT
1DF7 COMBINING KAVYKA ABOVE LEFT
1DF8 COMBINING DOT ABOVE LEFT
1DF9 COMBINING WIDE INVERTED BRIDGE BELOW
1DFB COMBINING DELETION MARK
1DFC COMBINING DOUBLE INVERTED BREVE BELOW
1DFD COMBINING ALMOST EQUAL TO BELOW
1DFE COMBINING LEFT ARROWHEAD ABOVE
1DFF COMBINING RIGHT ARROWHEAD AND DOWN ARROWHEAD BELOW
1E00 LATIN CAPITAL LETTER A WITH RING BELOW
1E01 LATIN SMALL LETTER A WITH RING BELOW
1E02 LATIN CAPITAL LETTER B WITH DOT ABOVE
1E03 LATIN SMALL LETTER B WITH DOT ABOVE
1E04 LATIN CAPITAL LETTER B WITH DOT BELOW
1E05 LATIN SMALL LETTER B WITH DOT BELOW
1E06 LATIN CAPITAL LETTER B WITH LINE BELOW
1E07 LATIN SMALL LETTER B WITH LINE BELOW
1E08 LATIN CAPITAL LETTER C WITH CEDILLA AND ACUTE
1E09 LATIN SMALL LETTER C WITH CEDILLA AND ACUTE
1E0A LATIN CAPITAL LETTER D WITH DOT ABOVE
1E0B LATIN SMALL LETTER D WITH DOT ABOVE
1E0C LATIN CAPITAL LETTER D WITH DOT BELOW
1E0D LATIN SMALL LETTER D WITH DOT BELOW
1E0E LATIN CAPITAL LETTER D WITH LINE BELOW
1E0F LATIN SMALL LETTER D WITH LINE BELOW
1E10 LATIN CAPITAL LETTER D WITH CEDILLA
1E11 LATIN SMALL LETTER D WITH CEDILLA
1E12 LATIN CAPITAL LETTER D WITH CIRCUMFLEX BELOW
1E13 LATIN SMALL LETTER D WITH CIRCUMFLEX BELOW
1E14 LATIN CAPITAL LETTER E WITH MACRON AND GRAVE
1E15 LATIN SMALL LETTER E WITH MACRON AND GRAVE
1E16 LATIN CAPITAL LETTER E WITH MACRON AND ACUTE
1E17 LATIN SMALL LETTER E WITH MACRON AND ACUTE
1E18 LATIN CAPITAL LETTER E WITH CIRCUMFLEX BELOW
1E19 LATIN SMALL LETTER E WITH CIRCUMFLEX BELOW
1E1A LATIN CAPITAL LETTER E WITH TILDE BELOW
1E1B LATIN SMALL LETTER E WITH TILDE BELOW
1E1C LATIN CAPITAL LETTER E WITH CEDILLA AND BREVE
1E1D LATIN SMALL LETTER E WITH CEDILLA AND BREVE
1E1E LATIN CAPITAL LETTER F WITH DOT ABOVE
1E1F LATIN SMALL LETTER F WITH DOT ABOVE
1E20 LATIN CAPITAL LETTER G WITH MACRON
1E21 LATIN SMALL LETTER G WITH MACRON
1E22 LATIN CAPITAL LETTER H WITH DOT ABOVE
1E23 LATIN SMALL LETTER H WITH DOT ABOVE
1E24 LATIN CAPITAL LETTER H WITH DOT BELOW
1E25 LATIN SMALL LETTER H WITH DOT BELOW
1E26 LATIN CAPITAL LETTER H WITH DIAERESIS
1E27 LATIN SMALL LETTER H WITH DIAERESIS
1E28 LATIN CAPITAL LETTER H WITH CEDILLA
1E29 LATIN SMALL LETTER H WITH CEDILLA
1E2A LATIN CAPITAL LETTER H WITH BREVE BELOW
1E2B LATIN SMALL LETTER H WITH BREVE BELOW
1E2C LATIN CAPITAL LETTER I WITH TILDE BELOW
1E2D LATIN SMALL LETTER I WITH TILDE BELOW
1E2E LATIN CAPITAL LETTER I WITH DIAERESIS AND ACUTE
1E2F LATIN SMALL LETTER I WITH DIAERESIS AND ACUTE
1E30 LATIN CAPITAL LETTER K WITH ACUTE
1E31 LATIN SMALL LETTER K WITH ACUTE
1E32 LATIN CAPITAL LETTER K WITH DOT BELOW
1E33 LATIN SMALL LETTER K WITH DOT BELOW
1E34 LATIN CAPITAL LETTER K WITH LINE BELOW
1E35 LATIN SMALL LETTER K WITH LINE BELOW
1E36 LATIN CAPITAL LETTER L WITH DOT BELOW
1E37 LATIN SMALL LETTER L WITH DOT BELOW
1E38 LATIN CAPITAL LETTER L WITH DOT BELOW AND MACRON
1E39 LATIN SMALL LETTER L WITH DOT BELOW AND MACRON
1E3A LATIN CAPITAL LETTER L WITH LINE BELOW
1E3B LATIN SMALL LETTER L WITH LINE BELOW
1E3C LATIN CAPITAL LETTER L WITH CIRCUMFLEX BELOW
1E3D LATIN SMALL LETTER L WITH CIRCUMFLEX BELOW
1E3E LATIN CAPITAL LETTER M WITH ACUTE
1E3F LATIN SMALL LETTER M WITH ACUTE
1E40 LATIN CAPITAL LETTER M WITH DOT ABOVE
1E41 LATIN SMALL LETTER M WITH DOT ABOVE
1E42 LATIN CAPITAL LETTER M WITH DOT BELOW
1E43 LATIN SMALL LETTER M WITH DOT BELOW
1E44 LATIN CAPITAL LETTER N WITH DOT ABOVE
1E45 LATIN SMALL LETTER N WITH DOT ABOVE
1E46 LATIN CAPITAL LETTER N WITH DOT BELOW
1E47 LATIN SMALL LETTER N WITH DOT BELOW
1E48 LATIN CAPITAL LETTER N WITH LINE BELOW
1E49 LATIN SMALL LETTER N WITH LINE BELOW
1E4A LATIN CAPITAL LETTER N WITH CIRCUMFLEX BELOW
1E4B LATIN SMALL LETTER N WITH CIRCUMFLEX BELOW
1E4C LATIN CAPITAL LETTER O WITH TILDE AND ACUTE
1E4D LATIN SMALL LETTER O WITH TILDE AND ACUTE
1E4E LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS
1E4F LATIN SMALL LETTER O WITH TILDE AND DIAERESIS
1E50 LATIN CAPITAL LETTER O WITH MACRON AND GRAVE
1E51 LATIN SMALL LETTER O WITH MACRON AND GRAVE
1E52 LATIN CAPITAL LETTER O WITH MACRON AND ACUTE
1E53 LATIN SMALL LETTER O WITH MACRON AND ACUTE
1E54 LATIN CAPITAL LETTER P WITH ACUTE
1E55 LATIN SMALL LETTER P WITH ACUTE
1E56 LATIN CAPITAL LETTER P WITH DOT ABOVE
1E57 LATIN SMALL LETTER P WITH DOT ABOVE
1E58 LATIN CAPITAL LETTER R WITH DOT ABOVE
1E59 LATIN SMALL LETTER R WITH DOT ABOVE
1E5A LATIN CAPITAL LETTER R WITH DOT BELOW
1E5B LATIN SMALL LETTER R WITH DOT BELOW
1E5C LATIN CAPITAL LETTER R WITH DOT BELOW AND MACRON
1E5D LATIN SMALL LETTER R WITH DOT BELOW AND MACRON
1E5E LATIN CAPITAL LETTER R WITH LINE BELOW
1E5F LATIN SMALL LETTER R WITH LINE BELOW
1E60 LATIN CAPITAL LETTER S WITH DOT ABOVE
1E61 LATIN SMALL LETTER S WITH DOT ABOVE
1E62 LATIN CAPITAL LETTER S WITH DOT BELOW
1E63 LATIN SMALL LETTER S WITH DOT BELOW
1E64 LATIN CAPITAL LETTER S WITH ACUTE AND DOT ABOVE
1E65 LATIN SMALL LETTER S WITH ACUTE AND DOT ABOVE
1E66 LATIN CAPITAL LETTER S WITH CARON AND DOT ABOVE
1E67 LATIN SMALL LETTER S WITH CARON AND DOT ABOVE
1E68 LATIN CAPITAL LETTER S WITH DOT BELOW AND DOT ABOVE
1E69 LATIN SMALL LETTER S WITH DOT BELOW AND DOT ABOVE
1E6A LATIN CAPITAL LETTER T WITH DOT ABOVE
1E6B LATIN SMALL LETTER T WITH DOT ABOVE
1E6C LATIN CAPITAL LETTER T WITH DOT BELOW
1E6D LATIN SMALL LETTER T WITH DOT BELOW
1E6E LATIN CAPITAL LETTER T WITH LINE BELOW
1E6F LATIN SMALL LETTER T WITH LINE BELOW
1E70 LATIN CAPITAL LETTER T WITH CIRCUMFLEX BELOW
1E71 LATIN SMALL LETTER T WITH CIRCUMFLEX BELOW
1E72 LATIN CAPITAL LETTER U WITH DIAERESIS BELOW
1E73 LATIN SMALL LETTER U WITH DIAERESIS BELOW
1E74 LATIN CAPITAL LETTER U WITH TILDE BELOW
1E75 LATIN SMALL LETTER U WITH TILDE BELOW
1E76 LATIN CAPITAL LETTER U WITH CIRCUMFLEX BELOW
1E77 LATIN SMALL LETTER U WITH CIRCUMFLEX BELOW
1E78 LATIN CAPITAL LETTER U WITH TILDE AND ACUTE
1E79 LATIN SMALL LETTER U WITH TILDE AND ACUTE
1E7A LATIN CAPITAL LETTER U WITH MACRON AND DIAERESIS
1E7B LATIN SMALL LETTER U WITH MACRON AND DIAERESIS
1E7C LATIN CAPITAL LETTER V WITH TILDE
1E7D LATIN SMALL LETTER V WITH TILDE
1E7E LATIN CAPITAL LETTER V WITH DOT BELOW
1E7F LATIN SMALL LETTER V WITH DOT BELOW
1E80 LATIN CAPITAL LETTER W WITH GRAVE
1E81 LATIN SMALL LETTER W WITH GRAVE
1E82 LATIN CAPITAL LETTER W WITH ACUTE
1E83 LATIN SMALL LETTER W WITH ACUTE
1E84 LATIN CAPITAL LETTER W WITH DIAERESIS
1E85 LATIN SMALL LETTER W WITH DIAERESIS
1E86 LATIN CAPITAL LETTER W WITH DOT ABOVE
1E87 LATIN SMALL LETTER W WITH DOT ABOVE
1E88 LATIN CAPITAL LETTER W WITH DOT BELOW
1E89 LATIN SMALL LETTER W WITH DOT BELOW
1E8A LATIN CAPITAL LETTER X WITH DOT ABOVE
1E8B LATIN SMALL LETTER X WITH DOT ABOVE
1E8C LATIN CAPITAL LETTER X WITH DIAERESIS
1E8D LATIN SMALL LETTER X WITH DIAERESIS
1E8E LATIN CAPITAL LETTER Y WITH DOT ABOVE
1E8F LATIN SMALL LETTER Y WITH DOT ABOVE
1E90 LATIN CAPITAL LETTER Z WITH CIRCUMFLEX
1E91 LATIN SMALL LETTER Z WITH CIRCUMFLEX
1E92 LATIN CAPITAL LETTER Z WITH DOT BELOW
1E93 LATIN SMALL LETTER Z WITH DOT BELOW
1E94 LATIN CAPITAL LETTER Z WITH LINE BELOW
1E95 LATIN SMALL LETTER Z WITH LINE BELOW
1E96 LATIN SMALL LETTER H WITH LINE BELOW
1E97 LATIN SMALL LETTER T WITH DIAERESIS
1E98 LATIN SMALL LETTER W WITH RING ABOVE
1E99 LATIN SMALL LETTER Y WITH RING ABOVE
1E9A LATIN SMALL LETTER A WITH RIGHT HALF RING
1E9B LATIN SMALL LETTER LONG S WITH DOT ABOVE
1E9C LATIN SMALL LETTER LONG S WITH DIAGONAL STROKE
1E9D LATIN SMALL LETTER LONG S WITH HIGH STROKE
1E9E LATIN CAPITAL LETTER SHARP S
1E9F LATIN SMALL LETTER DELTA
1EA0 LATIN CAPITAL LETTER A WITH DOT BELOW
1EA1 LATIN SMALL LETTER A WITH DOT BELOW
1EA2 LATIN CAPITAL LETTER A WITH HOOK ABOVE
1EA3 LATIN SMALL LETTER A WITH HOOK ABOVE
1EA4 LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE
1EA5 LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE
1EA6 LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE
1EA7 LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE
1EA8 LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
1EA9 LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
1EAA LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE
1EAB LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE
1EAC LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW
1EAD LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW
1EAE LATIN CAPITAL LETTER A WITH BREVE AND ACUTE
1EAF LATIN SMALL LETTER A WITH BREVE AND ACUTE
1EB0 LATIN CAPITAL LETTER A WITH BREVE AND GRAVE
1EB1 LATIN SMALL LETTER A WITH BREVE AND GRAVE
1EB2 LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE
1EB3 LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE
1EB4 LATIN CAPITAL LETTER A WITH BREVE AND TILDE
1EB5 LATIN SMALL LETTER A WITH BREVE AND TILDE
1EB6 LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW
1EB7 LATIN SMALL LETTER A WITH BREVE AND DOT BELOW
1EB8 LATIN CAPITAL LETTER E WITH DOT BELOW
1EB9 LATIN SMALL LETTER E WITH DOT BELOW
1EBA LATIN CAPITAL LETTER E WITH HOOK ABOVE
1EBB LATIN SMALL LETTER E WITH HOOK ABOVE
1EBC LATIN CAPITAL LETTER E WITH TILDE
1EBD LATIN SMALL LETTER E WITH TILDE
1EBE LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
1EBF LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
1EC0 LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
1EC1 LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
1EC2 LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
1EC3 LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
1EC4 LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
1EC5 LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
1EC6 LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
1EC7 LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
1EC8 LATIN CAPITAL LETTER I WITH HOOK ABOVE
1EC9 LATIN SMALL LETTER I WITH HOOK ABOVE
1ECA LATIN CAPITAL LETTER I WITH DOT BELOW
1ECB LATIN SMALL LETTER I WITH DOT BELOW
1ECC LATIN CAPITAL LETTER O WITH DOT BELOW
1ECD LATIN SMALL LETTER O WITH DOT BELOW
1ECE LATIN CAPITAL LETTER O WITH HOOK ABOVE
1ECF LATIN SMALL LETTER O WITH HOOK ABOVE
1ED0 LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE
1ED1 LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE
1ED2 LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE
1ED3 LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE
1ED4 LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
1ED5 LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
1ED6 LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE
1ED7 LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE
1ED8 LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW
1ED9 LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW
1EDA LATIN CAPITAL LETTER O WITH HORN AND ACUTE
1EDB LATIN SMALL LETTER O WITH HORN AND ACUTE
1EDC LATIN CAPITAL LETTER O WITH HORN AND GRAVE
1EDD LATIN SMALL LETTER O WITH HORN AND GRAVE
1EDE LATIN CAPITAL LETTER O WITH HORN AND HOOK ABOVE
1EDF LATIN SMALL LETTER O WITH HORN AND HOOK ABOVE
1EE0 LATIN CAPITAL LETTER O WITH HORN AND TILDE
1EE1 LATIN SMALL LETTER O WITH HORN AND TILDE
1EE2 LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW
1EE3 LATIN SMALL LETTER O WITH HORN AND DOT BELOW
1EE4 LATIN CAPITAL LETTER U WITH DOT BELOW
1EE5 LATIN SMALL LETTER U WITH DOT BELOW
1EE6 LATIN CAPITAL LETTER U WITH HOOK ABOVE
1EE7 LATIN SMALL LETTER U WITH HOOK ABOVE
1EE8 LATIN CAPITAL LETTER U WITH HORN AND ACUTE
1EE9 LATIN SMALL LETTER U WITH HORN AND ACUTE
1EEA LATIN CAPITAL LETTER U WITH HORN AND GRAVE
1EEB LATIN SMALL LETTER U WITH HORN AND GRAVE
1EEC LATIN CAPITAL LETTER U WITH HORN AND HOOK ABOVE
1EED LATIN SMALL LETTER U WITH HORN AND HOOK ABOVE
1EEE LATIN CAPITAL LETTER U WITH HORN AND TILDE
1EEF LATIN SMALL LETTER U WITH HORN AND TILDE
1EF0 LATIN CAPITAL LETTER U WITH HORN AND DOT BELOW
1EF1 LATIN SMALL LETTER U WITH HORN AND DOT BELOW
1EF2 LATIN CAPITAL LETTER Y WITH GRAVE
1EF3 LATIN SMALL LETTER Y WITH GRAVE
1EF4 LATIN CAPITAL LETTER Y WITH DOT BELOW
1EF5 LATIN SMALL LETTER Y WITH DOT BELOW
1EF6 LATIN CAPITAL LETTER Y WITH HOOK ABOVE
1EF7 LATIN SMALL LETTER Y WITH HOOK ABOVE
1EF8 LATIN CAPITAL LETTER Y WITH TILDE
1EF9 LATIN SMALL LETTER Y WITH TILDE
1EFA LATIN CAPITAL LETTER MIDDLE-WELSH LL
1EFB LATIN SMALL LETTER MIDDLE-WELSH LL
1EFC LATIN CAPITAL LETTER MIDDLE-WELSH V
1EFD LATIN SMALL LETTER MIDDLE-WELSH V
1EFE LATIN CAPITAL LETTER Y WITH LOOP
1EFF LATIN SMALL LETTER Y WITH LOOP
1F00 GREEK SMALL LETTER ALPHA WITH PSILI
1F01 GREEK SMALL LETTER ALPHA WITH DASIA
1F02 GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA
1F03 GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA
1F04 GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA
1F05 GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA
1F06 GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI
1F07 GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI
1F08 GREEK CAPITAL LETTER ALPHA WITH PSILI
1F09 GREEK CAPITAL LETTER ALPHA WITH DASIA
1F0A GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA
1F0B GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA
1F0C GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA
1F0D GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA
1F0E GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI
1F0F GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI
1F10 GREEK SMALL LETTER EPSILON WITH PSILI
1F11 GREEK SMALL LETTER EPSILON WITH DASIA
1F12 GREEK SMALL LETTER EPSILON WITH PSILI AND VARIA
1F13 GREEK SMALL LETTER EPSILON WITH DASIA AND VARIA
1F14 GREEK SMALL LETTER EPSILON WITH PSILI AND OXIA
1F15 GREEK SMALL LETTER EPSILON WITH DASIA AND OXIA
1F18 GREEK CAPITAL LETTER EPSILON WITH PSILI
1F19 GREEK CAPITAL LETTER EPSILON WITH DASIA
1F1A GREEK CAPITAL LETTER EPSILON WITH PSILI AND VARIA
1F1B GREEK CAPITAL LETTER EPSILON WITH DASIA AND VARIA
1F1C GREEK CAPITAL LETTER EPSILON WITH PSILI AND OXIA
1F1D GREEK CAPITAL LETTER EPSILON WITH DASIA AND OXIA
1F20 GREEK SMALL LETTER ETA WITH PSILI
1F21 GREEK SMALL LETTER ETA WITH DASIA
1F22 GREEK SMALL LETTER ETA WITH PSILI AND VARIA
1F23 GREEK SMALL LETTER ETA WITH DASIA AND VARIA
1F24 GREEK SMALL LETTER ETA WITH PSILI AND OXIA
1F25 GREEK SMALL LETTER ETA WITH DASIA AND OXIA
1F26 GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI
1F27 GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI
1F28 GREEK CAPITAL LETTER ETA WITH PSILI
1F29 GREEK CAPITAL LETTER ETA WITH DASIA
1F2A GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA
1F2B GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA
1F2C GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA
1F2D GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA
1F2E GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI
1F2F GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI
1F30 GREEK SMALL LETTER IOTA WITH PSILI
1F31 GREEK SMALL LETTER IOTA WITH DASIA
1F32 GREEK SMALL LETTER IOTA WITH PSILI AND VARIA
1F33 GREEK SMALL LETTER IOTA WITH DASIA AND VARIA
1F34 GREEK SMALL LETTER IOTA WITH PSILI AND OXIA
1F35 GREEK SMALL LETTER IOTA WITH DASIA AND OXIA
1F36 GREEK SMALL LETTER IOTA WITH PSILI AND PERISPOMENI
1F37 GREEK SMALL LETTER IOTA WITH DASIA AND PERISPOMENI
1F38 GREEK CAPITAL LETTER IOTA WITH PSILI
1F39 GREEK CAPITAL LETTER IOTA WITH DASIA
1F3A GREEK CAPITAL LETTER IOTA WITH PSILI AND VARIA
1F3B GREEK CAPITAL LETTER IOTA WITH DASIA AND VARIA
1F3C GREEK CAPITAL LETTER IOTA WITH PSILI AND OXIA
1F3D GREEK CAPITAL LETTER IOTA WITH DASIA AND OXIA
1F3E GREEK CAPITAL LETTER IOTA WITH PSILI AND PERISPOMENI
1F3F GREEK CAPITAL LETTER IOTA WITH DASIA AND PERISPOMENI
1F40 GREEK SMALL LETTER OMICRON WITH PSILI
1F41 GREEK SMALL LETTER OMICRON WITH DASIA
1F42 GREEK SMALL LETTER OMICRON WITH PSILI AND VARIA
1F43 GREEK SMALL LETTER OMICRON WITH DASIA AND VARIA
1F44 GREEK SMALL LETTER OMICRON WITH PSILI AND OXIA
1F45 GREEK SMALL LETTER OMICRON WITH DASIA AND OXIA
1F48 GREEK CAPITAL LETTER OMICRON WITH PSILI
1F49 GREEK CAPITAL LETTER OMICRON WITH DASIA
1F4A GREEK CAPITAL LETTER OMICRON WITH PSILI AND VARIA
1F4B GREEK CAPITAL LETTER OMICRON WITH DASIA AND VARIA
1F4C GREEK CAPITAL LETTER OMICRON WITH PSILI AND OXIA
1F4D GREEK CAPITAL LETTER OMICRON WITH DASIA AND OXIA
1F50 GREEK SMALL LETTER UPSILON WITH PSILI
1F51 GREEK SMALL LETTER UPSILON WITH DASIA
1F52 GREEK SMALL LETTER UPSILON WITH PSILI AND VARIA
1F53 GREEK SMALL LETTER UPSILON WITH DASIA AND VARIA
1F54 GREEK SMALL LETTER UPSILON WITH PSILI AND OXIA
1F55 GREEK SMALL LETTER UPSILON WITH DASIA AND OXIA
1F56 GREEK SMALL LETTER UPSILON WITH PSILI AND PERISPOMENI
1F57 GREEK SMALL LETTER UPSILON WITH DASIA AND PERISPOMENI
1F59 GREEK CAPITAL LETTER UPSILON WITH DASIA
1F5B GREEK CAPITAL LETTER UPSILON WITH DASIA AND VARIA
1F5D GREEK CAPITAL LETTER UPSILON WITH DASIA AND OXIA
1F5F GREEK CAPITAL LETTER UPSILON WITH DASIA AND PERISPOMENI
1F60 GREEK SMALL LETTER OMEGA WITH PSILI
1F61 GREEK SMALL LETTER OMEGA WITH DASIA
1F62 GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA
1F63 GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA
1F64 GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA
1F65 GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA
1F66 GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI
1F67 GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI
1F68 GREEK CAPITAL LETTER OMEGA WITH PSILI
1F69 GREEK CAPITAL LETTER OMEGA WITH DASIA
1F6A GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA
1F6B GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA
1F6C GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA
1F6D GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA
1F6E GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI
1F6F GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI
1F70 GREEK SMALL LETTER ALPHA WITH VARIA
1F71 GREEK SMALL LETTER ALPHA WITH OXIA
1F72 GREEK SMALL LETTER EPSILON WITH VARIA
1F73 GREEK SMALL LETTER EPSILON WITH OXIA
1F74 GREEK SMALL LETTER ETA WITH VARIA
1F75 GREEK SMALL LETTER ETA WITH OXIA
1F76 GREEK SMALL LETTER IOTA WITH VARIA
1F77 GREEK SMALL LETTER IOTA WITH OXIA
1F78 GREEK SMALL LETTER OMICRON WITH VARIA
1F79 GREEK SMALL LETTER OMICRON WITH OXIA
1F7A GREEK SMALL LETTER UPSILON WITH VARIA
1F7B GREEK SMALL LETTER UPSILON WITH OXIA
1F7C GREEK SMALL LETTER OMEGA WITH VARIA
1F7D GREEK SMALL LETTER OMEGA WITH OXIA
1F80 GREEK SMALL LETTER ALPHA WITH PSILI AND YPOGEGRAMMENI
1F81 GREEK SMALL LETTER ALPHA WITH DASIA AND YPOGEGRAMMENI
1F82 GREEK SMALL LETTER ALPHA WITH PSILI AND VARIA AND YPOGEGRAMMENI
1F83 GREEK SMALL LETTER ALPHA WITH DASIA AND VARIA AND YPOGEGRAMMENI
1F84 GREEK SMALL LETTER ALPHA WITH PSILI AND OXIA AND YPOGEGRAMMENI
1F85 GREEK SMALL LETTER ALPHA WITH DASIA AND OXIA AND YPOGEGRAMMENI
1F86 GREEK SMALL LETTER ALPHA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI
1F87 GREEK SMALL LETTER ALPHA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI
1F88 GREEK CAPITAL LETTER ALPHA WITH PSILI AND PROSGEGRAMMENI
1F89 GREEK CAPITAL LETTER ALPHA WITH DASIA AND PROSGEGRAMMENI
1F8A GREEK CAPITAL LETTER ALPHA WITH PSILI AND VARIA AND PROSGEGRAMMENI
1F8B GREEK CAPITAL LETTER ALPHA WITH DASIA AND VARIA AND PROSGEGRAMMENI
1F8C GREEK CAPITAL LETTER ALPHA WITH PSILI AND OXIA AND PROSGEGRAMMENI
1F8D GREEK CAPITAL LETTER ALPHA WITH DASIA AND OXIA AND PROSGEGRAMMENI
1F8E GREEK CAPITAL LETTER ALPHA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI
1F8F GREEK CAPITAL LETTER ALPHA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI
1F90 GREEK SMALL LETTER ETA WITH PSILI AND YPOGEGRAMMENI
1F91 GREEK SMALL LETTER ETA WITH DASIA AND YPOGEGRAMMENI
1F92 GREEK SMALL LETTER ETA WITH PSILI AND VARIA AND YPOGEGRAMMENI
1F93 GREEK SMALL LETTER ETA WITH DASIA AND VARIA AND YPOGEGRAMMENI
1F94 GREEK SMALL LETTER ETA WITH PSILI AND OXIA AND YPOGEGRAMMENI
1F95 GREEK SMALL LETTER ETA WITH DASIA AND OXIA AND YPOGEGRAMMENI
1F96 GREEK SMALL LETTER ETA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI
1F97 GREEK SMALL LETTER ETA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI
1F98 GREEK CAPITAL LETTER ETA WITH PSILI AND PROSGEGRAMMENI
1F99 GREEK CAPITAL LETTER ETA WITH DASIA AND PROSGEGRAMMENI
1F9A GREEK CAPITAL LETTER ETA WITH PSILI AND VARIA AND PROSGEGRAMMENI
1F9B GREEK CAPITAL LETTER ETA WITH DASIA AND VARIA AND PROSGEGRAMMENI
1F9C GREEK CAPITAL LETTER ETA WITH PSILI AND OXIA AND PROSGEGRAMMENI
1F9D GREEK CAPITAL LETTER ETA WITH DASIA AND OXIA AND PROSGEGRAMMENI
1F9E GREEK CAPITAL LETTER ETA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI
1F9F GREEK CAPITAL LETTER ETA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI
1FA0 GREEK SMALL LETTER OMEGA WITH PSILI AND YPOGEGRAMMENI
1FA1 GREEK SMALL LETTER OMEGA WITH DASIA AND YPOGEGRAMMENI
1FA2 GREEK SMALL LETTER OMEGA WITH PSILI AND VARIA AND YPOGEGRAMMENI
1FA3 GREEK SMALL LETTER OMEGA WITH DASIA AND VARIA AND YPOGEGRAMMENI
1FA4 GREEK SMALL LETTER OMEGA WITH PSILI AND OXIA AND YPOGEGRAMMENI
1FA5 GREEK SMALL LETTER OMEGA WITH DASIA AND OXIA AND YPOGEGRAMMENI
1FA6 GREEK SMALL LETTER OMEGA WITH PSILI AND PERISPOMENI AND YPOGEGRAMMENI
1FA7 GREEK SMALL LETTER OMEGA WITH DASIA AND PERISPOMENI AND YPOGEGRAMMENI
1FA8 GREEK CAPITAL LETTER OMEGA WITH PSILI AND PROSGEGRAMMENI
1FA9 GREEK CAPITAL LETTER OMEGA WITH DASIA AND PROSGEGRAMMENI
1FAA GREEK CAPITAL LETTER OMEGA WITH PSILI AND VARIA AND PROSGEGRAMMENI
1FAB GREEK CAPITAL LETTER OMEGA WITH DASIA AND VARIA AND PROSGEGRAMMENI
1FAC GREEK CAPITAL LETTER OMEGA WITH PSILI AND OXIA AND PROSGEGRAMMENI
1FAD GREEK CAPITAL LETTER OMEGA WITH DASIA AND OXIA AND PROSGEGRAMMENI
1FAE GREEK CAPITAL LETTER OMEGA WITH PSILI AND PERISPOMENI AND PROSGEGRAMMENI
1FAF GREEK CAPITAL LETTER OMEGA WITH DASIA AND PERISPOMENI AND PROSGEGRAMMENI
1FB0 GREEK SMALL LETTER ALPHA WITH VRACHY
1FB1 GREEK SMALL LETTER ALPHA WITH MACRON
1FB2 GREEK SMALL LETTER ALPHA WITH VARIA AND YPOGEGRAMMENI
1FB3 GREEK SMALL LETTER ALPHA WITH YPOGEGRAMMENI
1FB4 GREEK SMALL LETTER ALPHA WITH OXIA AND YPOGEGRAMMENI
1FB6 GREEK SMALL LETTER ALPHA WITH PERISPOMENI
1FB7 GREEK SMALL LETTER ALPHA WITH PERISPOMENI AND YPOGEGRAMMENI
1FB8 GREEK CAPITAL LETTER ALPHA WITH VRACHY
1FB9 GREEK CAPITAL LETTER ALPHA WITH MACRON
1FBA GREEK CAPITAL LETTER ALPHA WITH VARIA
1FBB GREEK CAPITAL LETTER ALPHA WITH OXIA
1FBC GREEK CAPITAL LETTER ALPHA WITH PROSGEGRAMMENI
1FBD GREEK KORONIS
1FBE GREEK PROSGEGRAMMENI
1FBF GREEK PSILI
1FC0 GREEK PERISPOMENI
1FC1 GREEK DIALYTIKA AND PERISPOMENI
1FC2 GREEK SMALL LETTER ETA WITH VARIA AND YPOGEGRAMMENI
1FC3 GREEK SMALL LETTER ETA WITH YPOGEGRAMMENI
1FC4 GREEK SMALL LETTER ETA WITH OXIA AND YPOGEGRAMMENI
1FC6 GREEK SMALL LETTER ETA WITH PERISPOMENI
1FC7 GREEK SMALL LETTER ETA WITH PERISPOMENI AND YPOGEGRAMMENI
1FC8 GREEK CAPITAL LETTER EPSILON WITH VARIA
1FC9 GREEK CAPITAL LETTER EPSILON WITH OXIA
1FCA GREEK CAPITAL LETTER ETA WITH VARIA
1FCB GREEK CAPITAL LETTER ETA WITH OXIA
1FCC GREEK CAPITAL LETTER ETA WITH PROSGEGRAMMENI
1FCD GREEK PSILI AND VARIA
1FCE GREEK PSILI AND OXIA
1FCF GREEK PSILI AND PERISPOMENI
1FD0 GREEK SMALL LETTER IOTA WITH VRACHY
1FD1 GREEK SMALL LETTER IOTA WITH MACRON
1FD2 GREEK SMALL LETTER IOTA WITH DIALYTIKA AND VARIA
1FD3 GREEK SMALL LETTER IOTA WITH DIALYTIKA AND OXIA
1FD6 GREEK SMALL LETTER IOTA WITH PERISPOMENI
1FD7 GREEK SMALL LETTER IOTA WITH DIALYTIKA AND PERISPOMENI
1FD8 GREEK CAPITAL LETTER IOTA WITH VRACHY
1FD9 GREEK CAPITAL LETTER IOTA WITH MACRON
1FDA GREEK CAPITAL LETTER IOTA WITH VARIA
1FDB GREEK CAPITAL LETTER IOTA WITH OXIA
1FDD GREEK DASIA AND VARIA
1FDE GREEK DASIA AND OXIA
1FDF GREEK DASIA AND PERISPOMENI
1FE0 GREEK SMALL LETTER UPSILON WITH VRACHY
1FE1 GREEK SMALL LETTER UPSILON WITH MACRON
1FE2 GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND VARIA
1FE3 GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND OXIA
1FE4 GREEK SMALL LETTER RHO WITH PSILI
1FE5 GREEK SMALL LETTER RHO WITH DASIA
1FE6 GREEK SMALL LETTER UPSILON WITH PERISPOMENI
1FE7 GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND PERISPOMENI
1FE8 GREEK CAPITAL LETTER UPSILON WITH VRACHY
1FE9 GREEK CAPITAL LETTER UPSILON WITH MACRON
1FEA GREEK CAPITAL LETTER UPSILON WITH VARIA
1FEB GREEK CAPITAL LETTER UPSILON WITH OXIA
1FEC GREEK CAPITAL LETTER RHO WITH DASIA
1FED GREEK DIALYTIKA AND VARIA
1FEE GREEK DIALYTIKA AND OXIA
1FEF GREEK VARIA
1FF2 GREEK SMALL LETTER OMEGA WITH VARIA AND YPOGEGRAMMENI
1FF3 GREEK SMALL LETTER OMEGA WITH YPOGEGRAMMENI
1FF4 GREEK SMALL LETTER OMEGA WITH OXIA AND YPOGEGRAMMENI
1FF6 GREEK SMALL LETTER OMEGA WITH PERISPOMENI
1FF7 GREEK SMALL LETTER OMEGA WITH PERISPOMENI AND YPOGEGRAMMENI
1FF8 GREEK CAPITAL LETTER OMICRON WITH VARIA
1FF9 GREEK CAPITAL LETTER OMICRON WITH OXIA
1FFA GREEK CAPITAL LETTER OMEGA WITH VARIA
1FFB GREEK CAPITAL LETTER OMEGA WITH OXIA
1FFC GREEK CAPITAL LETTER OMEGA WITH PROSGEGRAMMENI
1FFD GREEK OXIA
1FFE GREEK DASIA
2000 EN QUAD
2001 EM QUAD
2002 EN SPACE
2003 EM SPACE
2004 THREE-PER-EM SPACE
2005 FOUR-PER-EM SPACE
2006 SIX-PER-EM SPACE
2007 FIGURE SPACE
2008 PUNCTUATION SPACE
2009 THIN SPACE
200A HAIR SPACE
200B ZERO WIDTH SPACE, ZWSP
200C ZERO WIDTH NON-JOINER, ZWNJ
200D ZERO WIDTH JOINER, ZWJ
200E LEFT-TO-RIGHT MARK, LRM
200F RIGHT-TO-LEFT MARK, RLM
2010 HYPHEN
2011 NON-BREAKING HYPHEN
2012 FIGURE DASH
2013 EN DASH
2014 EM DASH
2015 HORIZONTAL BAR
2016 DOUBLE VERTICAL LINE
2017 DOUBLE LOW LINE
2018 LEFT SINGLE QUOTATION MARK
2019 RIGHT SINGLE QUOTATION MARK
201A SINGLE LOW-9 QUOTATION MARK
201B SINGLE HIGH-REVERSED-9 QUOTATION MARK
201C LEFT DOUBLE QUOTATION MARK
201D RIGHT DOUBLE QUOTATION MARK
201E DOUBLE LOW-9 QUOTATION MARK
201F DOUBLE HIGH-REVERSED-9 QUOTATION MARK
2020 DAGGER
2021 DOUBLE DAGGER
2022 BULLET
2023 TRIANGULAR BULLET
2024 ONE DOT LEADER
2025 TWO DOT LEADER
2026 HORIZONTAL ELLIPSIS
2027 HYPHENATION POINT
2028 LINE SEPARATOR
2029 PARAGRAPH SEPARATOR
202A LEFT-TO-RIGHT EMBEDDING, LRE
202B RIGHT-TO-LEFT EMBEDDING, RLE
202C POP DIRECTIONAL FORMATTING, PDF
202D LEFT-TO-RIGHT OVERRIDE, LRO
202E RIGHT-TO-LEFT OVERRIDE, RLO
202F NARROW NO-BREAK SPACE, NNBSP
2030 PER MILLE SIGN
2031 PER TEN THOUSAND SIGN
2032 PRIME
2033 DOUBLE PRIME
2034 TRIPLE PRIME
2035 REVERSED PRIME
2036 REVERSED DOUBLE PRIME
2037 REVERSED TRIPLE PRIME
2038 CARET
2039 SINGLE LEFT-POINTING ANGLE QUOTATION MARK
203A SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
203B REFERENCE MARK
203C DOUBLE EXCLAMATION MARK
203D INTERROBANG
203E OVERLINE
203F UNDERTIE
2040 CHARACTER TIE
2041 CARET INSERTION POINT
2042 ASTERISM
2043 HYPHEN BULLET
2044 FRACTION SLASH
2045 LEFT SQUARE BRACKET WITH QUILL
2046 RIGHT SQUARE BRACKET WITH QUILL
2047 DOUBLE QUESTION MARK
2048 QUESTION EXCLAMATION MARK
2049 EXCLAMATION QUESTION MARK
204A TIRONIAN SIGN ET
204B REVERSED PILCROW SIGN
204C BLACK LEFTWARDS BULLET
204D BLACK RIGHTWARDS BULLET
204E LOW ASTERISK
204F REVERSED SEMICOLON
2050 CLOSE UP
2051 TWO ASTERISKS ALIGNED VERTICALLY
2052 COMMERCIAL MINUS SIGN
2053 SWUNG DASH
2054 INVERTED UNDERTIE
2055 FLOWER PUNCTUATION MARK
2056 THREE DOT PUNCTUATION
2057 QUADRUPLE PRIME
2058 FOUR DOT PUNCTUATION
2059 FIVE DOT PUNCTUATION
205A TWO DOT PUNCTUATION
205B FOUR DOT MARK
205C DOTTED CROSS
205D TRICOLON
205E VERTICAL FOUR DOTS
205F MEDIUM MATHEMATICAL SPACE, MMSP
2060 WORD JOINER, WJ
2061 FUNCTION APPLICATION
2062 INVISIBLE TIMES
2063 INVISIBLE SEPARATOR
2064 INVISIBLE PLUS
2066 LEFT-TO-RIGHT ISOLATE, LRI
2067 RIGHT-TO-LEFT ISOLATE, RLI
2068 FIRST STRONG ISOLATE, FSI
2069 POP DIRECTIONAL ISOLATE, PDI
206A INHIBIT SYMMETRIC SWAPPING
206B ACTIVATE SYMMETRIC SWAPPING
206C INHIBIT ARABIC FORM SHAPING
206D ACTIVATE ARABIC FORM SHAPING
206E NATIONAL DIGIT SHAPES
206F NOMINAL DIGIT SHAPES
2070 SUPERSCRIPT ZERO
2071 SUPERSCRIPT LATIN SMALL LETTER I
2074 SUPERSCRIPT FOUR
2075 SUPERSCRIPT FIVE
2076 SUPERSCRIPT SIX
2077 SUPERSCRIPT SEVEN
2078 SUPERSCRIPT EIGHT
2079 SUPERSCRIPT NINE
207A SUPERSCRIPT PLUS SIGN
207B SUPERSCRIPT MINUS
207C SUPERSCRIPT EQUALS SIGN
207D SUPERSCRIPT LEFT PARENTHESIS
207E SUPERSCRIPT RIGHT PARENTHESIS
207F SUPERSCRIPT LATIN SMALL LETTER N
2080 SUBSCRIPT ZERO
2081 SUBSCRIPT ONE
2082 SUBSCRIPT TWO
2083 SUBSCRIPT THREE
2084 SUBSCRIPT FOUR
2085 SUBSCRIPT FIVE
2086 SUBSCRIPT SIX
2087 SUBSCRIPT SEVEN
2088 SUBSCRIPT EIGHT
2089 SUBSCRIPT NINE
208A SUBSCRIPT PLUS SIGN
208B SUBSCRIPT MINUS
208C SUBSCRIPT EQUALS SIGN
208D SUBSCRIPT LEFT PARENTHESIS
208E SUBSCRIPT RIGHT PARENTHESIS
2090 LATIN SUBSCRIPT SMALL LETTER A
2091 LATIN SUBSCRIPT SMALL LETTER E
2092 LATIN SUBSCRIPT SMALL LETTER O
2093 LATIN SUBSCRIPT SMALL LETTER X
2094 LATIN SUBSCRIPT SMALL LETTER SCHWA
2095 LATIN SUBSCRIPT SMALL LETTER H
2096 LATIN SUBSCRIPT SMALL LETTER K
2097 LATIN SUBSCRIPT SMALL LETTER L
2098 LATIN SUBSCRIPT SMALL LETTER M
2099 LATIN SUBSCRIPT SMALL LETTER N
209A LATIN SUBSCRIPT SMALL LETTER P
209B LATIN SUBSCRIPT SMALL LETTER S
209C LATIN SUBSCRIPT SMALL LETTER T
20A0 EURO-CURRENCY SIGN
20A1 COLON SIGN
20A2 CRUZEIRO SIGN
20A3 FRENCH FRANC SIGN
20A4 LIRA SIGN
20A5 MILL SIGN
20A6 NAIRA SIGN
20A7 PESETA SIGN
20A8 RUPEE SIGN
20A9 WON SIGN
20AA NEW SHEQEL SIGN
20AB DONG SIGN
20AC EURO SIGN
20AD KIP SIGN
20AE TUGRIK SIGN
20AF DRACHMA SIGN
20B0 GERMAN PENNY SIGN
20B1 PESO SIGN
20B2 GUARANI SIGN
20B3 AUSTRAL SIGN
20B4 HRYVNIA SIGN
20B5 CEDI SIGN
20B6 LIVRE TOURNOIS SIGN
20B7 SPESMILO SIGN
20B8 TENGE SIGN
20B9 INDIAN RUPEE SIGN
20BA TURKISH LIRA SIGN
20BB NORDIC MARK SIGN
20BC MANAT SIGN
20BD RUBLE SIGN
20BE LARI SIGN
20BF BITCOIN SIGN
20D0 COMBINING LEFT HARPOON ABOVE
20D1 COMBINING RIGHT HARPOON ABOVE
20D2 COMBINING LONG VERTICAL LINE OVERLAY
20D3 COMBINING SHORT VERTICAL LINE OVERLAY
20D4 COMBINING ANTICLOCKWISE ARROW ABOVE
20D5 COMBINING CLOCKWISE ARROW ABOVE
20D6 COMBINING LEFT ARROW ABOVE
20D7 COMBINING RIGHT ARROW ABOVE
20D8 COMBINING RING OVERLAY
20D9 COMBINING CLOCKWISE RING OVERLAY
20DA COMBINING ANTICLOCKWISE RING OVERLAY
20DB COMBINING THREE DOTS ABOVE
20DC COMBINING FOUR DOTS ABOVE
20DD COMBINING ENCLOSING CIRCLE
20DE COMBINING ENCLOSING SQUARE
20DF COMBINING ENCLOSING DIAMOND
20E0 COMBINING ENCLOSING CIRCLE BACKSLASH
20E1 COMBINING LEFT RIGHT ARROW ABOVE
20E2 COMBINING ENCLOSING SCREEN
20E3 COMBINING ENCLOSING KEYCAP
20E4 COMBINING ENCLOSING UPWARD POINTING TRIANGLE
20E5 COMBINING REVERSE SOLIDUS OVERLAY
20E6 COMBINING DOUBLE VERTICAL STROKE OVERLAY
20E7 COMBINING ANNUITY SYMBOL
20E8 COMBINING TRIPLE UNDERDOT
20E9 COMBINING WIDE BRIDGE ABOVE
20EA COMBINING LEFTWARDS ARROW OVERLAY
20EB COMBINING LONG DOUBLE SOLIDUS OVERLAY
20EC COMBINING RIGHTWARDS HARPOON WITH BARB DOWNWARDS
20ED COMBINING LEFTWARDS HARPOON WITH BARB DOWNWARDS
20EE COMBINING LEFT ARROW BELOW
20EF COMBINING RIGHT ARROW BELOW
20F0 COMBINING ASTERISK ABOVE
2100 ACCOUNT OF
2101 ADDRESSED TO THE SUBJECT
2102 DOUBLE-STRUCK CAPITAL C
2103 DEGREE CELSIUS
2104 CENTRE LINE SYMBOL
2105 CARE OF
2106 CADA UNA
2107 EULER CONSTANT
2108 SCRUPLE
2109 DEGREE FAHRENHEIT
210A SCRIPT SMALL G
210B SCRIPT CAPITAL H
210C BLACK-LETTER CAPITAL H
210D DOUBLE-STRUCK CAPITAL H
210E PLANCK CONSTANT
210F PLANCK CONSTANT OVER TWO PI
2110 SCRIPT CAPITAL I
2111 BLACK-LETTER CAPITAL I
2112 SCRIPT CAPITAL L
2113 SCRIPT SMALL L
2114 L B BAR SYMBOL
2115 DOUBLE-STRUCK CAPITAL N
2116 NUMERO SIGN
2117 SOUND RECORDING COPYRIGHT
2118 SCRIPT CAPITAL P
2119 DOUBLE-STRUCK CAPITAL P
211A DOUBLE-STRUCK CAPITAL Q
211B SCRIPT CAPITAL R
211C BLACK-LETTER CAPITAL R
211D DOUBLE-STRUCK CAPITAL R
211E PRESCRIPTION TAKE
211F RESPONSE
2120 SERVICE MARK
2121 TELEPHONE SIGN
2122 TRADE MARK SIGN
2123 VERSICLE
2124 DOUBLE-STRUCK CAPITAL Z
2125 OUNCE SIGN
2126 OHM SIGN
2127 INVERTED OHM SIGN
2128 BLACK-LETTER CAPITAL Z
2129 TURNED GREEK SMALL LETTER IOTA
212A KELVIN SIGN
212B ANGSTROM SIGN
212C SCRIPT CAPITAL B
212D BLACK-LETTER CAPITAL C
212E ESTIMATED SYMBOL
212F SCRIPT SMALL E
2130 SCRIPT CAPITAL E
2131 SCRIPT CAPITAL F
2132 TURNED CAPITAL F
2133 SCRIPT CAPITAL M
2134 SCRIPT SMALL O
2135 ALEF SYMBOL
2136 BET SYMBOL
2137 GIMEL SYMBOL
2138 DALET SYMBOL
2139 INFORMATION SOURCE
213A ROTATED CAPITAL Q
213B FACSIMILE SIGN
213C DOUBLE-STRUCK SMALL PI
213D DOUBLE-STRUCK SMALL GAMMA
213E DOUBLE-STRUCK CAPITAL GAMMA
213F DOUBLE-STRUCK CAPITAL PI
2140 DOUBLE-STRUCK N-ARY SUMMATION
2141 TURNED SANS-SERIF CAPITAL G
2142 TURNED SANS-SERIF CAPITAL L
2143 REVERSED SANS-SERIF CAPITAL L
2144 TURNED SANS-SERIF CAPITAL Y
2145 DOUBLE-STRUCK ITALIC CAPITAL D
2146 DOUBLE-STRUCK ITALIC SMALL D
2147 DOUBLE-STRUCK ITALIC SMALL E
2148 DOUBLE-STRUCK ITALIC SMALL I
2149 DOUBLE-STRUCK ITALIC SMALL J
214A PROPERTY LINE
214B TURNED AMPERSAND
214C PER SIGN
214D AKTIESELSKAB
214E TURNED SMALL F
214F SYMBOL FOR SAMARITAN SOURCE
2150 VULGAR FRACTION ONE SEVENTH
2151 VULGAR FRACTION ONE NINTH
2152 VULGAR FRACTION ONE TENTH
2153 VULGAR FRACTION ONE THIRD
2154 VULGAR FRACTION TWO THIRDS
2155 VULGAR FRACTION ONE FIFTH
2156 VULGAR FRACTION TWO FIFTHS
2157 VULGAR FRACTION THREE FIFTHS
2158 VULGAR FRACTION FOUR FIFTHS
2159 VULGAR FRACTION ONE SIXTH
215A VULGAR FRACTION FIVE SIXTHS
215B VULGAR FRACTION ONE EIGHTH
215C VULGAR FRACTION THREE EIGHTHS
215D VULGAR FRACTION FIVE EIGHTHS
215E VULGAR FRACTION SEVEN EIGHTHS
215F FRACTION NUMERATOR ONE
2160 ROMAN NUMERAL ONE
2161 ROMAN NUMERAL TWO
2162 ROMAN NUMERAL THREE
2163 ROMAN NUMERAL FOUR
2164 ROMAN NUMERAL FIVE
2165 ROMAN NUMERAL SIX
2166 ROMAN NUMERAL SEVEN
2167 ROMAN NUMERAL EIGHT
2168 ROMAN NUMERAL NINE
2169 ROMAN NUMERAL TEN
216A ROMAN NUMERAL ELEVEN
216B ROMAN NUMERAL TWELVE
216C ROMAN NUMERAL FIFTY
216D ROMAN NUMERAL ONE HUNDRED
216E ROMAN NUMERAL FIVE HUNDRED
216F ROMAN NUMERAL ONE THOUSAND
2170 SMALL ROMAN NUMERAL ONE
2171 SMALL ROMAN NUMERAL TWO
2172 SMALL ROMAN NUMERAL THREE
2173 SMALL ROMAN NUMERAL FOUR
2174 SMALL ROMAN NUMERAL FIVE
2175 SMALL ROMAN NUMERAL SIX
2176 SMALL ROMAN NUMERAL SEVEN
2177 SMALL ROMAN NUMERAL EIGHT
2178 SMALL ROMAN NUMERAL NINE
2179 SMALL ROMAN NUMERAL TEN
217A SMALL ROMAN NUMERAL ELEVEN
217B SMALL ROMAN NUMERAL TWELVE
217C SMALL ROMAN NUMERAL FIFTY
217D SMALL ROMAN NUMERAL ONE HUNDRED
217E SMALL ROMAN NUMERAL FIVE HUNDRED
217F SMALL ROMAN NUMERAL ONE THOUSAND
2180 ROMAN NUMERAL ONE THOUSAND C D
2181 ROMAN NUMERAL FIVE THOUSAND
2182 ROMAN NUMERAL TEN THOUSAND
2183 ROMAN NUMERAL REVERSED ONE HUNDRED
2184 LATIN SMALL LETTER REVERSED C
2185 ROMAN NUMERAL SIX LATE FORM
2186 ROMAN NUMERAL FIFTY EARLY FORM
2187 ROMAN NUMERAL FIFTY THOUSAND
2188 ROMAN NUMERAL ONE HUNDRED THOUSAND
2189 VULGAR FRACTION ZERO THIRDS
218A TURNED DIGIT TWO
218B TURNED DIGIT THREE
2190 LEFTWARDS ARROW
2191 UPWARDS ARROW
2192 RIGHTWARDS ARROW
2193 DOWNWARDS ARROW
2194 LEFT RIGHT ARROW
2195 UP DOWN ARROW
2196 NORTH WEST ARROW
2197 NORTH EAST ARROW
2198 SOUTH EAST ARROW
2199 SOUTH WEST ARROW
219A LEFTWARDS ARROW WITH STROKE
219B RIGHTWARDS ARROW WITH STROKE
219C LEFTWARDS WAVE ARROW
219D RIGHTWARDS WAVE ARROW
219E LEFTWARDS TWO HEADED ARROW
219F UPWARDS TWO HEADED ARROW
21A0 RIGHTWARDS TWO HEADED ARROW
21A1 DOWNWARDS TWO HEADED ARROW
21A2 LEFTWARDS ARROW WITH TAIL
21A3 RIGHTWARDS ARROW WITH TAIL
21A4 LEFTWARDS ARROW FROM BAR
21A5 UPWARDS ARROW FROM BAR
21A6 RIGHTWARDS ARROW FROM BAR
21A7 DOWNWARDS ARROW FROM BAR
21A8 UP DOWN ARROW WITH BASE
21A9 LEFTWARDS ARROW WITH HOOK
21AA RIGHTWARDS ARROW WITH HOOK
21AB LEFTWARDS ARROW WITH LOOP
21AC RIGHTWARDS ARROW WITH LOOP
21AD LEFT RIGHT WAVE ARROW
21AE LEFT RIGHT ARROW WITH STROKE
21AF DOWNWARDS ZIGZAG ARROW
21B0 UPWARDS ARROW WITH TIP LEFTWARDS
21B1 UPWARDS ARROW WITH TIP RIGHTWARDS
21B2 DOWNWARDS ARROW WITH TIP LEFTWARDS
21B3 DOWNWARDS ARROW WITH TIP RIGHTWARDS
21B4 RIGHTWARDS ARROW WITH CORNER DOWNWARDS
21B5 DOWNWARDS ARROW WITH CORNER LEFTWARDS
21B6 ANTICLOCKWISE TOP SEMICIRCLE ARROW
21B7 CLOCKWISE TOP SEMICIRCLE ARROW
21B8 NORTH WEST ARROW TO LONG BAR
21B9 LEFTWARDS ARROW TO BAR OVER RIGHTWARDS ARROW TO BAR
21BA ANTICLOCKWISE OPEN CIRCLE ARROW
21BB CLOCKWISE OPEN CIRCLE ARROW
21BC LEFTWARDS HARPOON WITH BARB UPWARDS
21BD LEFTWARDS HARPOON WITH BARB DOWNWARDS
21BE UPWARDS HARPOON WITH BARB RIGHTWARDS
21BF UPWARDS HARPOON WITH BARB LEFTWARDS
21C0 RIGHTWARDS HARPOON WITH BARB UPWARDS
21C1 RIGHTWARDS HARPOON WITH BARB DOWNWARDS
21C2 DOWNWARDS HARPOON WITH BARB RIGHTWARDS
21C3 DOWNWARDS HARPOON WITH BARB LEFTWARDS
21C4 RIGHTWARDS ARROW OVER LEFTWARDS ARROW
21C5 UPWARDS ARROW LEFTWARDS OF DOWNWARDS ARROW
21C6 LEFTWARDS ARROW OVER RIGHTWARDS ARROW
21C7 LEFTWARDS PAIRED ARROWS
21C8 UPWARDS PAIRED ARROWS
21C9 RIGHTWARDS PAIRED ARROWS
21CA DOWNWARDS PAIRED ARROWS
21CB LEFTWARDS HARPOON OVER RIGHTWARDS HARPOON
21CC RIGHTWARDS HARPOON OVER LEFTWARDS HARPOON
21CD LEFTWARDS DOUBLE ARROW WITH STROKE
21CE LEFT RIGHT DOUBLE ARROW WITH STROKE
21CF RIGHTWARDS DOUBLE ARROW WITH STROKE
21D0 LEFTWARDS DOUBLE ARROW
21D1 UPWARDS DOUBLE ARROW
21D2 RIGHTWARDS DOUBLE ARROW
21D3 DOWNWARDS DOUBLE ARROW
21D4 LEFT RIGHT DOUBLE ARROW
21D5 UP DOWN DOUBLE ARROW
21D6 NORTH WEST DOUBLE ARROW
21D7 NORTH EAST DOUBLE ARROW
21D8 SOUTH EAST DOUBLE ARROW
21D9 SOUTH WEST DOUBLE ARROW
21DA LEFTWARDS TRIPLE ARROW
21DB RIGHTWARDS TRIPLE ARROW
21DC LEFTWARDS SQUIGGLE ARROW
21DD RIGHTWARDS SQUIGGLE ARROW
21DE UPWARDS ARROW WITH DOUBLE STROKE
21DF DOWNWARDS ARROW WITH DOUBLE STROKE
21E0 LEFTWARDS DASHED ARROW
21E1 UPWARDS DASHED ARROW
21E2 RIGHTWARDS DASHED ARROW
21E3 DOWNWARDS DASHED ARROW
21E4 LEFTWARDS ARROW TO BAR
21E5 RIGHTWARDS ARROW TO BAR
21E6 LEFTWARDS WHITE ARROW
21E7 UPWARDS WHITE ARROW
21E8 RIGHTWARDS WHITE ARROW
21E9 DOWNWARDS WHITE ARROW
21EA UPWARDS WHITE ARROW FROM BAR
21EB UPWARDS WHITE ARROW ON PEDESTAL
21EC UPWARDS WHITE ARROW ON PEDESTAL WITH HORIZONTAL BAR
21ED UPWARDS WHITE ARROW ON PEDESTAL WITH VERTICAL BAR
21EE UPWARDS WHITE DOUBLE ARROW
21EF UPWARDS WHITE DOUBLE ARROW ON PEDESTAL
21F0 RIGHTWARDS WHITE ARROW FROM WALL
21F1 NORTH WEST ARROW TO CORNER
21F2 SOUTH EAST ARROW TO CORNER
21F3 UP DOWN WHITE ARROW
21F4 RIGHT ARROW WITH SMALL CIRCLE
21F5 DOWNWARDS ARROW LEFTWARDS OF UPWARDS ARROW
21F6 THREE RIGHTWARDS ARROWS
21F7 LEFTWARDS ARROW WITH VERTICAL STROKE
21F8 RIGHTWARDS ARROW WITH VERTICAL STROKE
21F9 LEFT RIGHT ARROW WITH VERTICAL STROKE
21FA LEFTWARDS ARROW WITH DOUBLE VERTICAL STROKE
21FB RIGHTWARDS ARROW WITH DOUBLE VERTICAL STROKE
21FC LEFT RIGHT ARROW WITH DOUBLE VERTICAL STROKE
21FD LEFTWARDS OPEN-HEADED ARROW
21FE RIGHTWARDS OPEN-HEADED ARROW
21FF LEFT RIGHT OPEN-HEADED ARROW
2200 FOR ALL
2201 COMPLEMENT
2202 PARTIAL DIFFERENTIAL
2203 THERE EXISTS
2204 THERE DOES NOT EXIST
2205 EMPTY SET
2206 INCREMENT
2207 NABLA
2208 ELEMENT OF
2209 NOT AN ELEMENT OF
220A SMALL ELEMENT OF
220B CONTAINS AS MEMBER
220C DOES NOT CONTAIN AS MEMBER
220D SMALL CONTAINS AS MEMBER
220E END OF PROOF
220F N-ARY PRODUCT
2210 N-ARY COPRODUCT
2211 N-ARY SUMMATION
2212 MINUS SIGN
2213 MINUS-OR-PLUS SIGN
2214 DOT PLUS
2215 DIVISION SLASH
2216 SET MINUS
2217 ASTERISK OPERATOR
2218 RING OPERATOR
2219 BULLET OPERATOR
221A SQUARE ROOT
221B CUBE ROOT
221C FOURTH ROOT
221D PROPORTIONAL TO
221E INFINITY
221F RIGHT ANGLE
2220 ANGLE
2221 MEASURED ANGLE
2222 SPHERICAL ANGLE
2223 DIVIDES
2224 DOES NOT DIVIDE
2225 PARALLEL TO
2226 NOT PARALLEL TO
2227 LOGICAL AND
2228 LOGICAL OR
2229 INTERSECTION
222A UNION
222B INTEGRAL
222C DOUBLE INTEGRAL
222D TRIPLE INTEGRAL
222E CONTOUR INTEGRAL
222F SURFACE INTEGRAL
2230 VOLUME INTEGRAL
2231 CLOCKWISE INTEGRAL
2232 CLOCKWISE CONTOUR INTEGRAL
2233 ANTICLOCKWISE CONTOUR INTEGRAL
2234 THEREFORE
2235 BECAUSE
2236 RATIO
2237 PROPORTION
2238 DOT MINUS
2239 EXCESS
223A GEOMETRIC PROPORTION
223B HOMOTHETIC
223C TILDE OPERATOR
223D REVERSED TILDE
223E INVERTED LAZY S
223F SINE WAVE
2240 WREATH PRODUCT
2241 NOT TILDE
2242 MINUS TILDE
2243 ASYMPTOTICALLY EQUAL TO
2244 NOT ASYMPTOTICALLY EQUAL TO
2245 APPROXIMATELY EQUAL TO
2246 APPROXIMATELY BUT NOT ACTUALLY EQUAL TO
2247 NEITHER APPROXIMATELY NOR ACTUALLY EQUAL TO
2248 ALMOST EQUAL TO
2249 NOT ALMOST EQUAL TO
224A ALMOST EQUAL OR EQUAL TO
224B TRIPLE TILDE
224C ALL EQUAL TO
224D EQUIVALENT TO
224E GEOMETRICALLY EQUIVALENT TO
224F DIFFERENCE BETWEEN
2250 APPROACHES THE LIMIT
2251 GEOMETRICALLY EQUAL TO
2252 APPROXIMATELY EQUAL TO OR THE IMAGE OF
2253 IMAGE OF OR APPROXIMATELY EQUAL TO
2254 COLON EQUALS
2255 EQUALS COLON
2256 RING IN EQUAL TO
2257 RING EQUAL TO
2258 CORRESPONDS TO
2259 ESTIMATES
225A EQUIANGULAR TO
225B STAR EQUALS
225C DELTA EQUAL TO
225D EQUAL TO BY DEFINITION
225E MEASURED BY
225F QUESTIONED EQUAL TO
2260 NOT EQUAL TO
2261 IDENTICAL TO
2262 NOT IDENTICAL TO
2263 STRICTLY EQUIVALENT TO
2264 LESS-THAN OR EQUAL TO
2265 GREATER-THAN OR EQUAL TO
2266 LESS-THAN OVER EQUAL TO
2267 GREATER-THAN OVER EQUAL TO
2268 LESS-THAN BUT NOT EQUAL TO
2269 GREATER-THAN BUT NOT EQUAL TO
226A MUCH LESS-THAN
226B MUCH GREATER-THAN
226C BETWEEN
226D NOT EQUIVALENT TO
226E NOT LESS-THAN
226F NOT GREATER-THAN
2270 NEITHER LESS-THAN NOR EQUAL TO
2271 NEITHER GREATER-THAN NOR EQUAL TO
2272 LESS-THAN OR EQUIVALENT TO
2273 GREATER-THAN OR EQUIVALENT TO
2274 NEITHER LESS-THAN NOR EQUIVALENT TO
2275 NEITHER GREATER-THAN NOR EQUIVALENT TO
2276 LESS-THAN OR GREATER-THAN
2277 GREATER-THAN OR LESS-THAN
2278 NEITHER LESS-THAN NOR GREATER-THAN
2279 NEITHER GREATER-THAN NOR LESS-THAN
227A PRECEDES
227B SUCCEEDS
227C PRECEDES OR EQUAL TO
227D SUCCEEDS OR EQUAL TO
227E PRECEDES OR EQUIVALENT TO
227F SUCCEEDS OR EQUIVALENT TO
2280 DOES NOT PRECEDE
2281 DOES NOT SUCCEED
2282 SUBSET OF
2283 SUPERSET OF
2284 NOT A SUBSET OF
2285 NOT A SUPERSET OF
2286 SUBSET OF OR EQUAL TO
2287 SUPERSET OF OR EQUAL TO
2288 NEITHER A SUBSET OF NOR EQUAL TO
2289 NEITHER A SUPERSET OF NOR EQUAL TO
228A SUBSET OF WITH NOT EQUAL TO
228B SUPERSET OF WITH NOT EQUAL TO
228C MULTISET
228D MULTISET MULTIPLICATION
228E MULTISET UNION
228F SQUARE IMAGE OF
2290 SQUARE ORIGINAL OF
2291 SQUARE IMAGE OF OR EQUAL TO
2292 SQUARE ORIGINAL OF OR EQUAL TO
2293 SQUARE CAP
2294 SQUARE CUP
2295 CIRCLED PLUS
2296 CIRCLED MINUS
2297 CIRCLED TIMES
2298 CIRCLED DIVISION SLASH
2299 CIRCLED DOT OPERATOR
229A CIRCLED RING OPERATOR
229B CIRCLED ASTERISK OPERATOR
229C CIRCLED EQUALS
229D CIRCLED DASH
229E SQUARED PLUS
229F SQUARED MINUS
22A0 SQUARED TIMES
22A1 SQUARED DOT OPERATOR
22A2 RIGHT TACK
22A3 LEFT TACK
22A4 DOWN TACK
22A5 UP TACK
22A6 ASSERTION
22A7 MODELS
22A8 TRUE
22A9 FORCES
22AA TRIPLE VERTICAL BAR RIGHT TURNSTILE
22AB DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE
22AC DOES NOT PROVE
22AD NOT TRUE
22AE DOES NOT FORCE
22AF NEGATED DOUBLE VERTICAL BAR DOUBLE RIGHT TURNSTILE
22B0 PRECEDES UNDER RELATION
22B1 SUCCEEDS UNDER RELATION
22B2 NORMAL SUBGROUP OF
22B3 CONTAINS AS NORMAL SUBGROUP
22B4 NORMAL SUBGROUP OF OR EQUAL TO
22B5 CONTAINS AS NORMAL SUBGROUP OR EQUAL TO
22B6 ORIGINAL OF
22B7 IMAGE OF
22B8 MULTIMAP
22B9 HERMITIAN CONJUGATE MATRIX
22BA INTERCALATE
22BB XOR
22BC NAND
22BD NOR
22BE RIGHT ANGLE WITH ARC
22BF RIGHT TRIANGLE
22C0 N-ARY LOGICAL AND
22C1 N-ARY LOGICAL OR
22C2 N-ARY INTERSECTION
22C3 N-ARY UNION
22C4 DIAMOND OPERATOR
22C5 DOT OPERATOR
22C6 STAR OPERATOR
22C7 DIVISION TIMES
22C8 BOWTIE
22C9 LEFT NORMAL FACTOR SEMIDIRECT PRODUCT
22CA RIGHT NORMAL FACTOR SEMIDIRECT PRODUCT
22CB LEFT SEMIDIRECT PRODUCT
22CC RIGHT SEMIDIRECT PRODUCT
22CD REVERSED TILDE EQUALS
22CE CURLY LOGICAL OR
22CF CURLY LOGICAL AND
22D0 DOUBLE SUBSET
22D1 DOUBLE SUPERSET
22D2 DOUBLE INTERSECTION
22D3 DOUBLE UNION
22D4 PITCHFORK
22D5 EQUAL AND PARALLEL TO
22D6 LESS-THAN WITH DOT
22D7 GREATER-THAN WITH DOT
22D8 VERY MUCH LESS-THAN
22D9 VERY MUCH GREATER-THAN
22DA LESS-THAN EQUAL TO OR GREATER-THAN
22DB GREATER-THAN EQUAL TO OR LESS-THAN
22DC EQUAL TO OR LESS-THAN
22DD EQUAL TO OR GREATER-THAN
22DE EQUAL TO OR PRECEDES
22DF EQUAL TO OR SUCCEEDS
22E0 DOES NOT PRECEDE OR EQUAL
22E1 DOES NOT SUCCEED OR EQUAL
22E2 NOT SQUARE IMAGE OF OR EQUAL TO
22E3 NOT SQUARE ORIGINAL OF OR EQUAL TO
22E4 SQUARE IMAGE OF OR NOT EQUAL TO
22E5 SQUARE ORIGINAL OF OR NOT EQUAL TO
22E6 LESS-THAN BUT NOT EQUIVALENT TO
22E7 GREATER-THAN BUT NOT EQUIVALENT TO
22E8 PRECEDES BUT NOT EQUIVALENT TO
22E9 SUCCEEDS BUT NOT EQUIVALENT TO
22EA NOT NORMAL SUBGROUP OF
22EB DOES NOT CONTAIN AS NORMAL SUBGROUP
22EC NOT NORMAL SUBGROUP OF OR EQUAL TO
22ED DOES NOT CONTAIN AS NORMAL SUBGROUP OR EQUAL
22EE VERTICAL ELLIPSIS
22EF MIDLINE HORIZONTAL ELLIPSIS
22F0 UP RIGHT DIAGONAL ELLIPSIS
22F1 DOWN RIGHT DIAGONAL ELLIPSIS
22F2 ELEMENT OF WITH LONG HORIZONTAL STROKE
22F3 ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE
22F4 SMALL ELEMENT OF WITH VERTICAL BAR AT END OF HORIZONTAL STROKE
22F5 ELEMENT OF WITH DOT ABOVE
22F6 ELEMENT OF WITH OVERBAR
22F7 SMALL ELEMENT OF WITH OVERBAR
22F8 ELEMENT OF WITH UNDERBAR
22F9 ELEMENT OF WITH TWO HORIZONTAL STROKES
22FA CONTAINS WITH LONG HORIZONTAL STROKE
22FB CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE
22FC SMALL CONTAINS WITH VERTICAL BAR AT END OF HORIZONTAL STROKE
22FD CONTAINS WITH OVERBAR
22FE SMALL CONTAINS WITH OVERBAR
22FF Z NOTATION BAG MEMBERSHIP
2300 DIAMETER SIGN
2301 ELECTRIC ARROW
2302 HOUSE
2303 UP ARROWHEAD
2304 DOWN ARROWHEAD
2305 PROJECTIVE
2306 PERSPECTIVE
2307 WAVY LINE
2308 LEFT CEILING
2309 RIGHT CEILING
230A LEFT FLOOR
230B RIGHT FLOOR
230C BOTTOM RIGHT CROP
230D BOTTOM LEFT CROP
230E TOP RIGHT CROP
230F TOP LEFT CROP
2310 REVERSED NOT SIGN
2311 SQUARE LOZENGE
2312 ARC
2313 SEGMENT
2314 SECTOR
2315 TELEPHONE RECORDER
2316 POSITION INDICATOR
2317 VIEWDATA SQUARE
2318 PLACE OF INTEREST SIGN
2319 TURNED NOT SIGN
231A WATCH
231B HOURGLASS
231C TOP LEFT CORNER
231D TOP RIGHT CORNER
231E BOTTOM LEFT CORNER
231F BOTTOM RIGHT CORNER
2320 TOP HALF INTEGRAL
2321 BOTTOM HALF INTEGRAL
2322 FROWN
2323 SMILE
2324 UP ARROWHEAD BETWEEN TWO HORIZONTAL BARS
2325 OPTION KEY
2326 ERASE TO THE RIGHT
2327 X IN A RECTANGLE BOX
2328 KEYBOARD
2329 LEFT-POINTING ANGLE BRACKET
232A RIGHT-POINTING ANGLE BRACKET
232B ERASE TO THE LEFT
232C BENZENE RING
232D CYLINDRICITY
232E ALL AROUND-PROFILE
232F SYMMETRY
2330 TOTAL RUNOUT
2331 DIMENSION ORIGIN
2332 CONICAL TAPER
2333 SLOPE
2334 COUNTERBORE
2335 COUNTERSINK
2336 APL FUNCTIONAL SYMBOL I-BEAM
2337 APL FUNCTIONAL SYMBOL SQUISH QUAD
2338 APL FUNCTIONAL SYMBOL QUAD EQUAL
2339 APL FUNCTIONAL SYMBOL QUAD DIVIDE
233A APL FUNCTIONAL SYMBOL QUAD DIAMOND
233B APL FUNCTIONAL SYMBOL QUAD JOT
233C APL FUNCTIONAL SYMBOL QUAD CIRCLE
233D APL FUNCTIONAL SYMBOL CIRCLE STILE
233E APL FUNCTIONAL SYMBOL CIRCLE JOT
233F APL FUNCTIONAL SYMBOL SLASH BAR
2340 APL FUNCTIONAL SYMBOL BACKSLASH BAR
2341 APL FUNCTIONAL SYMBOL QUAD SLASH
2342 APL FUNCTIONAL SYMBOL QUAD BACKSLASH
2343 APL FUNCTIONAL SYMBOL QUAD LESS-THAN
2344 APL FUNCTIONAL SYMBOL QUAD GREATER-THAN
2345 APL FUNCTIONAL SYMBOL LEFTWARDS VANE
2346 APL FUNCTIONAL SYMBOL RIGHTWARDS VANE
2347 APL FUNCTIONAL SYMBOL QUAD LEFTWARDS ARROW
2348 APL FUNCTIONAL SYMBOL QUAD RIGHTWARDS ARROW
2349 APL FUNCTIONAL SYMBOL CIRCLE BACKSLASH
234A APL FUNCTIONAL SYMBOL DOWN TACK UNDERBAR
234B APL FUNCTIONAL SYMBOL DELTA STILE
234C APL FUNCTIONAL SYMBOL QUAD DOWN CARET
234D APL FUNCTIONAL SYMBOL QUAD DELTA
234E APL FUNCTIONAL SYMBOL DOWN TACK JOT
234F APL FUNCTIONAL SYMBOL UPWARDS VANE
2350 APL FUNCTIONAL SYMBOL QUAD UPWARDS ARROW
2351 APL FUNCTIONAL SYMBOL UP TACK OVERBAR
2352 APL FUNCTIONAL SYMBOL DEL STILE
2353 APL FUNCTIONAL SYMBOL QUAD UP CARET
2354 APL FUNCTIONAL SYMBOL QUAD DEL
2355 APL FUNCTIONAL SYMBOL UP TACK JOT
2356 APL FUNCTIONAL SYMBOL DOWNWARDS VANE
2357 APL FUNCTIONAL SYMBOL QUAD DOWNWARDS ARROW
2358 APL FUNCTIONAL SYMBOL QUOTE UNDERBAR
2359 APL FUNCTIONAL SYMBOL DELTA UNDERBAR
235A APL FUNCTIONAL SYMBOL DIAMOND UNDERBAR
235B APL FUNCTIONAL SYMBOL JOT UNDERBAR
235C APL FUNCTIONAL SYMBOL CIRCLE UNDERBAR
235D APL FUNCTIONAL SYMBOL UP SHOE JOT
235E APL FUNCTIONAL SYMBOL QUOTE QUAD
235F APL FUNCTIONAL SYMBOL CIRCLE STAR
2360 APL FUNCTIONAL SYMBOL QUAD COLON
2361 APL FUNCTIONAL SYMBOL UP TACK DIAERESIS
2362 APL FUNCTIONAL SYMBOL DEL DIAERESIS
2363 APL FUNCTIONAL SYMBOL STAR DIAERESIS
2364 APL FUNCTIONAL SYMBOL JOT DIAERESIS
2365 APL FUNCTIONAL SYMBOL CIRCLE DIAERESIS
2366 APL FUNCTIONAL SYMBOL DOWN SHOE STILE
2367 APL FUNCTIONAL SYMBOL LEFT SHOE STILE
2368 APL FUNCTIONAL SYMBOL TILDE DIAERESIS
2369 APL FUNCTIONAL SYMBOL GREATER-THAN DIAERESIS
236A APL FUNCTIONAL SYMBOL COMMA BAR
236B APL FUNCTIONAL SYMBOL DEL TILDE
236C APL FUNCTIONAL SYMBOL ZILDE
236D APL FUNCTIONAL SYMBOL STILE TILDE
236E APL FUNCTIONAL SYMBOL SEMICOLON UNDERBAR
236F APL FUNCTIONAL SYMBOL QUAD NOT EQUAL
2370 APL FUNCTIONAL SYMBOL QUAD QUESTION
2371 APL FUNCTIONAL SYMBOL DOWN CARET TILDE
2372 APL FUNCTIONAL SYMBOL UP CARET TILDE
2373 APL FUNCTIONAL SYMBOL IOTA
2374 APL FUNCTIONAL SYMBOL RHO
2375 APL FUNCTIONAL SYMBOL OMEGA
2376 APL FUNCTIONAL SYMBOL ALPHA UNDERBAR
2377 APL FUNCTIONAL SYMBOL EPSILON UNDERBAR
2378 APL FUNCTIONAL SYMBOL IOTA UNDERBAR
2379 APL FUNCTIONAL SYMBOL OMEGA UNDERBAR
237A APL FUNCTIONAL SYMBOL ALPHA
237B NOT CHECK MARK
237C RIGHT ANGLE WITH DOWNWARDS ZIGZAG ARROW
237D SHOULDERED OPEN BOX
237E BELL SYMBOL
237F VERTICAL LINE WITH MIDDLE DOT
2380 INSERTION SYMBOL
2381 CONTINUOUS UNDERLINE SYMBOL
2382 DISCONTINUOUS UNDERLINE SYMBOL
2383 EMPHASIS SYMBOL
2384 COMPOSITION SYMBOL
2385 WHITE SQUARE WITH CENTRE VERTICAL LINE
2386 ENTER SYMBOL
2387 ALTERNATIVE KEY SYMBOL
2388 HELM SYMBOL
2389 CIRCLED HORIZONTAL BAR WITH NOTCH
238A CIRCLED TRIANGLE DOWN
238B BROKEN CIRCLE WITH NORTHWEST ARROW
238C UNDO SYMBOL
238D MONOSTABLE SYMBOL
238E HYSTERESIS SYMBOL
238F OPEN-CIRCUIT-OUTPUT H-TYPE SYMBOL
2390 OPEN-CIRCUIT-OUTPUT L-TYPE SYMBOL
2391 PASSIVE-PULL-DOWN-OUTPUT SYMBOL
2392 PASSIVE-PULL-UP-OUTPUT SYMBOL
2393 DIRECT CURRENT SYMBOL FORM TWO
2394 SOFTWARE-FUNCTION SYMBOL
2395 APL FUNCTIONAL SYMBOL QUAD
2396 DECIMAL SEPARATOR KEY SYMBOL
2397 PREVIOUS PAGE
2398 NEXT PAGE
2399 PRINT SCREEN SYMBOL
239A CLEAR SCREEN SYMBOL
239B LEFT PARENTHESIS UPPER HOOK
239C LEFT PARENTHESIS EXTENSION
239D LEFT PARENTHESIS LOWER HOOK
239E RIGHT PARENTHESIS UPPER HOOK
239F RIGHT PARENTHESIS EXTENSION
23A0 RIGHT PARENTHESIS LOWER HOOK
23A1 LEFT SQUARE BRACKET UPPER CORNER
23A2 LEFT SQUARE BRACKET EXTENSION
23A3 LEFT SQUARE BRACKET LOWER CORNER
23A4 RIGHT SQUARE BRACKET UPPER CORNER
23A5 RIGHT SQUARE BRACKET EXTENSION
23A6 RIGHT SQUARE BRACKET LOWER CORNER
23A7 LEFT CURLY BRACKET UPPER HOOK
23A8 LEFT CURLY BRACKET MIDDLE PIECE
23A9 LEFT CURLY BRACKET LOWER HOOK
23AA CURLY BRACKET EXTENSION
23AB RIGHT CURLY BRACKET UPPER HOOK
23AC RIGHT CURLY BRACKET MIDDLE PIECE
23AD RIGHT CURLY BRACKET LOWER HOOK
23AE INTEGRAL EXTENSION
23AF HORIZONTAL LINE EXTENSION
23B0 UPPER LEFT OR LOWER RIGHT CURLY BRACKET SECTION
23B1 UPPER RIGHT OR LOWER LEFT CURLY BRACKET SECTION
23B2 SUMMATION TOP
23B3 SUMMATION BOTTOM
23B4 TOP SQUARE BRACKET
23B5 BOTTOM SQUARE BRACKET
23B6 BOTTOM SQUARE BRACKET OVER TOP SQUARE BRACKET
23B7 RADICAL SYMBOL BOTTOM
23B8 LEFT VERTICAL BOX LINE
23B9 RIGHT VERTICAL BOX LINE
23BA HORIZONTAL SCAN LINE-1
23BB HORIZONTAL SCAN LINE-3
23BC HORIZONTAL SCAN LINE-7
23BD HORIZONTAL SCAN LINE-9
23BE DENTISTRY SYMBOL LIGHT VERTICAL AND TOP RIGHT
23BF DENTISTRY SYMBOL LIGHT VERTICAL AND BOTTOM RIGHT
23C0 DENTISTRY SYMBOL LIGHT VERTICAL WITH CIRCLE
23C1 DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH CIRCLE
23C2 DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH CIRCLE
23C3 DENTISTRY SYMBOL LIGHT VERTICAL WITH TRIANGLE
23C4 DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH TRIANGLE
23C5 DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH TRIANGLE
23C6 DENTISTRY SYMBOL LIGHT VERTICAL AND WAVE
23C7 DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL WITH WAVE
23C8 DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL WITH WAVE
23C9 DENTISTRY SYMBOL LIGHT DOWN AND HORIZONTAL
23CA DENTISTRY SYMBOL LIGHT UP AND HORIZONTAL
23CB DENTISTRY SYMBOL LIGHT VERTICAL AND TOP LEFT
23CC DENTISTRY SYMBOL LIGHT VERTICAL AND BOTTOM LEFT
23CD SQUARE FOOT
23CE RETURN SYMBOL
23CF EJECT SYMBOL
23D0 VERTICAL LINE EXTENSION
23D1 METRICAL BREVE
23D2 METRICAL LONG OVER SHORT
23D3 METRICAL SHORT OVER LONG
23D4 METRICAL LONG OVER TWO SHORTS
23D5 METRICAL TWO SHORTS OVER LONG
23D6 METRICAL TWO SHORTS JOINED
23D7 METRICAL TRISEME
23D8 METRICAL TETRASEME
23D9 METRICAL PENTASEME
23DA EARTH GROUND
23DB FUSE
23DC TOP PARENTHESIS
23DD BOTTOM PARENTHESIS
23DE TOP CURLY BRACKET
23DF BOTTOM CURLY BRACKET
23E0 TOP TORTOISE SHELL BRACKET
23E1 BOTTOM TORTOISE SHELL BRACKET
23E2 WHITE TRAPEZIUM
23E3 BENZENE RING WITH CIRCLE
23E4 STRAIGHTNESS
23E5 FLATNESS
23E6 AC CURRENT
23E7 ELECTRICAL INTERSECTION
23E8 DECIMAL EXPONENT SYMBOL
23E9 BLACK RIGHT-POINTING DOUBLE TRIANGLE
23EA BLACK LEFT-POINTING DOUBLE TRIANGLE
23EB BLACK UP-POINTING DOUBLE TRIANGLE
23EC BLACK DOWN-POINTING DOUBLE TRIANGLE
23ED BLACK RIGHT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR
23EE BLACK LEFT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR
23EF BLACK RIGHT-POINTING TRIANGLE WITH DOUBLE VERTICAL BAR
23F0 ALARM CLOCK
23F1 STOPWATCH
23F2 TIMER CLOCK
23F3 HOURGLASS WITH FLOWING SAND
23F4 BLACK MEDIUM LEFT-POINTING TRIANGLE
23F5 BLACK MEDIUM RIGHT-POINTING TRIANGLE
23F6 BLACK MEDIUM UP-POINTING TRIANGLE
23F7 BLACK MEDIUM DOWN-POINTING TRIANGLE
23F8 DOUBLE VERTICAL BAR
23F9 BLACK SQUARE FOR STOP
23FA BLACK CIRCLE FOR RECORD
23FB POWER SYMBOL
23FC POWER ON-OFF SYMBOL
23FD POWER ON SYMBOL
23FE POWER SLEEP SYMBOL
23FF OBSERVER EYE SYMBOL
2400 SYMBOL FOR NULL
2401 SYMBOL FOR START OF HEADING
2402 SYMBOL FOR START OF TEXT
2403 SYMBOL FOR END OF TEXT
2404 SYMBOL FOR END OF TRANSMISSION
2405 SYMBOL FOR ENQUIRY
2406 SYMBOL FOR ACKNOWLEDGE
2407 SYMBOL FOR BELL
2408 SYMBOL FOR BACKSPACE
2409 SYMBOL FOR HORIZONTAL TABULATION
240A SYMBOL FOR LINE FEED
240B SYMBOL FOR VERTICAL TABULATION
240C SYMBOL FOR FORM FEED
240D SYMBOL FOR CARRIAGE RETURN
240E SYMBOL FOR SHIFT OUT
240F SYMBOL FOR SHIFT IN
2410 SYMBOL FOR DATA LINK ESCAPE
2411 SYMBOL FOR DEVICE CONTROL ONE
2412 SYMBOL FOR DEVICE CONTROL TWO
2413 SYMBOL FOR DEVICE CONTROL THREE
2414 SYMBOL FOR DEVICE CONTROL FOUR
2415 SYMBOL FOR NEGATIVE ACKNOWLEDGE
2416 SYMBOL FOR SYNCHRONOUS IDLE
2417 SYMBOL FOR END OF TRANSMISSION BLOCK
2418 SYMBOL FOR CANCEL
2419 SYMBOL FOR END OF MEDIUM
241A SYMBOL FOR SUBSTITUTE
241B SYMBOL FOR ESCAPE
241C SYMBOL FOR FILE SEPARATOR
241D SYMBOL FOR GROUP SEPARATOR
241E SYMBOL FOR RECORD SEPARATOR
241F SYMBOL FOR UNIT SEPARATOR
2420 SYMBOL FOR SPACE
2421 SYMBOL FOR DELETE
2422 BLANK SYMBOL
2423 OPEN BOX
2424 SYMBOL FOR NEWLINE
2425 SYMBOL FOR DELETE FORM TWO
2426 SYMBOL FOR SUBSTITUTE FORM TWO
2440 OCR HOOK
2441 OCR CHAIR
2442 OCR FORK
2443 OCR INVERTED FORK
2444 OCR BELT BUCKLE
2445 OCR BOW TIE
2446 OCR BRANCH BANK IDENTIFICATION
2447 OCR AMOUNT OF CHECK
2448 OCR DASH
2449 OCR CUSTOMER ACCOUNT NUMBER
244A OCR DOUBLE BACKSLASH
2460 CIRCLED DIGIT ONE
2461 CIRCLED DIGIT TWO
2462 CIRCLED DIGIT THREE
2463 CIRCLED DIGIT FOUR
2464 CIRCLED DIGIT FIVE
2465 CIRCLED DIGIT SIX
2466 CIRCLED DIGIT SEVEN
2467 CIRCLED DIGIT EIGHT
2468 CIRCLED DIGIT NINE
2469 CIRCLED NUMBER TEN
246A CIRCLED NUMBER ELEVEN
246B CIRCLED NUMBER TWELVE
246C CIRCLED NUMBER THIRTEEN
246D CIRCLED NUMBER FOURTEEN
246E CIRCLED NUMBER FIFTEEN
246F CIRCLED NUMBER SIXTEEN
2470 CIRCLED NUMBER SEVENTEEN
2471 CIRCLED NUMBER EIGHTEEN
2472 CIRCLED NUMBER NINETEEN
2473 CIRCLED NUMBER TWENTY
2474 PARENTHESIZED DIGIT ONE
2475 PARENTHESIZED DIGIT TWO
2476 PARENTHESIZED DIGIT THREE
2477 PARENTHESIZED DIGIT FOUR
2478 PARENTHESIZED DIGIT FIVE
2479 PARENTHESIZED DIGIT SIX
247A PARENTHESIZED DIGIT SEVEN
247B PARENTHESIZED DIGIT EIGHT
247C PARENTHESIZED DIGIT NINE
247D PARENTHESIZED NUMBER TEN
247E PARENTHESIZED NUMBER ELEVEN
247F PARENTHESIZED NUMBER TWELVE
2480 PARENTHESIZED NUMBER THIRTEEN
2481 PARENTHESIZED NUMBER FOURTEEN
2482 PARENTHESIZED NUMBER FIFTEEN
2483 PARENTHESIZED NUMBER SIXTEEN
2484 PARENTHESIZED NUMBER SEVENTEEN
2485 PARENTHESIZED NUMBER EIGHTEEN
2486 PARENTHESIZED NUMBER NINETEEN
2487 PARENTHESIZED NUMBER TWENTY
2488 DIGIT ONE FULL STOP
2489 DIGIT TWO FULL STOP
248A DIGIT THREE FULL STOP
248B DIGIT FOUR FULL STOP
248C DIGIT FIVE FULL STOP
248D DIGIT SIX FULL STOP
248E DIGIT SEVEN FULL STOP
248F DIGIT EIGHT FULL STOP
2490 DIGIT NINE FULL STOP
2491 NUMBER TEN FULL STOP
2492 NUMBER ELEVEN FULL STOP
2493 NUMBER TWELVE FULL STOP
2494 NUMBER THIRTEEN FULL STOP
2495 NUMBER FOURTEEN FULL STOP
2496 NUMBER FIFTEEN FULL STOP
2497 NUMBER SIXTEEN FULL STOP
2498 NUMBER SEVENTEEN FULL STOP
2499 NUMBER EIGHTEEN FULL STOP
249A NUMBER NINETEEN FULL STOP
249B NUMBER TWENTY FULL STOP
249C PARENTHESIZED LATIN SMALL LETTER A
249D PARENTHESIZED LATIN SMALL LETTER B
249E PARENTHESIZED LATIN SMALL LETTER C
249F PARENTHESIZED LATIN SMALL LETTER D
24A0 PARENTHESIZED LATIN SMALL LETTER E
24A1 PARENTHESIZED LATIN SMALL LETTER F
24A2 PARENTHESIZED LATIN SMALL LETTER G
24A3 PARENTHESIZED LATIN SMALL LETTER H
24A4 PARENTHESIZED LATIN SMALL LETTER I
24A5 PARENTHESIZED LATIN SMALL LETTER J
24A6 PARENTHESIZED LATIN SMALL LETTER K
24A7 PARENTHESIZED LATIN SMALL LETTER L
24A8 PARENTHESIZED LATIN SMALL LETTER M
24A9 PARENTHESIZED LATIN SMALL LETTER N
24AA PARENTHESIZED LATIN SMALL LETTER O
24AB PARENTHESIZED LATIN SMALL LETTER P
24AC PARENTHESIZED LATIN SMALL LETTER Q
24AD PARENTHESIZED LATIN SMALL LETTER R
24AE PARENTHESIZED LATIN SMALL LETTER S
24AF PARENTHESIZED LATIN SMALL LETTER T
24B0 PARENTHESIZED LATIN SMALL LETTER U
24B1 PARENTHESIZED LATIN SMALL LETTER V
24B2 PARENTHESIZED LATIN SMALL LETTER W
24B3 PARENTHESIZED LATIN SMALL LETTER X
24B4 PARENTHESIZED LATIN SMALL LETTER Y
24B5 PARENTHESIZED LATIN SMALL LETTER Z
24B6 CIRCLED LATIN CAPITAL LETTER A
24B7 CIRCLED LATIN CAPITAL LETTER B
24B8 CIRCLED LATIN CAPITAL LETTER C
24B9 CIRCLED LATIN CAPITAL LETTER D
24BA CIRCLED LATIN CAPITAL LETTER E
24BB CIRCLED LATIN CAPITAL LETTER F
24BC CIRCLED LATIN CAPITAL LETTER G
24BD CIRCLED LATIN CAPITAL LETTER H
24BE CIRCLED LATIN CAPITAL LETTER I
24BF CIRCLED LATIN CAPITAL LETTER J
24C0 CIRCLED LATIN CAPITAL LETTER K
24C1 CIRCLED LATIN CAPITAL LETTER L
24C2 CIRCLED LATIN CAPITAL LETTER M
24C3 CIRCLED LATIN CAPITAL LETTER N
24C4 CIRCLED LATIN CAPITAL LETTER O
24C5 CIRCLED LATIN CAPITAL LETTER P
24C6 CIRCLED LATIN CAPITAL LETTER Q
24C7 CIRCLED LATIN CAPITAL LETTER R
24C8 CIRCLED LATIN CAPITAL LETTER S
24C9 CIRCLED LATIN CAPITAL LETTER T
24CA CIRCLED LATIN CAPITAL LETTER U
24CB CIRCLED LATIN CAPITAL LETTER V
24CC CIRCLED LATIN CAPITAL LETTER W
24CD CIRCLED LATIN CAPITAL LETTER X
24CE CIRCLED LATIN CAPITAL LETTER Y
24CF CIRCLED LATIN CAPITAL LETTER Z
24D0 CIRCLED LATIN SMALL LETTER A
24D1 CIRCLED LATIN SMALL LETTER B
24D2 CIRCLED LATIN SMALL LETTER C
24D3 CIRCLED LATIN SMALL LETTER D
24D4 CIRCLED LATIN SMALL LETTER E
24D5 CIRCLED LATIN SMALL LETTER F
24D6 CIRCLED LATIN SMALL LETTER G
24D7 CIRCLED LATIN SMALL LETTER H
24D8 CIRCLED LATIN SMALL LETTER I
24D9 CIRCLED LATIN SMALL LETTER J
24DA CIRCLED LATIN SMALL LETTER K
24DB CIRCLED LATIN SMALL LETTER L
24DC CIRCLED LATIN SMALL LETTER M
24DD CIRCLED LATIN SMALL LETTER N
24DE CIRCLED LATIN SMALL LETTER O
24DF CIRCLED LATIN SMALL LETTER P
24E0 CIRCLED LATIN SMALL LETTER Q
24E1 CIRCLED LATIN SMALL LETTER R
24E2 CIRCLED LATIN SMALL LETTER S
24E3 CIRCLED LATIN SMALL LETTER T
24E4 CIRCLED LATIN SMALL LETTER U
24E5 CIRCLED LATIN SMALL LETTER V
24E6 CIRCLED LATIN SMALL LETTER W
24E7 CIRCLED LATIN SMALL LETTER X
24E8 CIRCLED LATIN SMALL LETTER Y
24E9 CIRCLED LATIN SMALL LETTER Z
24EA CIRCLED DIGIT ZERO
24EB NEGATIVE CIRCLED NUMBER ELEVEN
24EC NEGATIVE CIRCLED NUMBER TWELVE
24ED NEGATIVE CIRCLED NUMBER THIRTEEN
24EE NEGATIVE CIRCLED NUMBER FOURTEEN
24EF NEGATIVE CIRCLED NUMBER FIFTEEN
24F0 NEGATIVE CIRCLED NUMBER SIXTEEN
24F1 NEGATIVE CIRCLED NUMBER SEVENTEEN
24F2 NEGATIVE CIRCLED NUMBER EIGHTEEN
24F3 NEGATIVE CIRCLED NUMBER NINETEEN
24F4 NEGATIVE CIRCLED NUMBER TWENTY
24F5 DOUBLE CIRCLED DIGIT ONE
24F6 DOUBLE CIRCLED DIGIT TWO
24F7 DOUBLE CIRCLED DIGIT THREE
24F8 DOUBLE CIRCLED DIGIT FOUR
24F9 DOUBLE CIRCLED DIGIT FIVE
24FA DOUBLE CIRCLED DIGIT SIX
24FB DOUBLE CIRCLED DIGIT SEVEN
24FC DOUBLE CIRCLED DIGIT EIGHT
24FD DOUBLE CIRCLED DIGIT NINE
24FE DOUBLE CIRCLED NUMBER TEN
24FF NEGATIVE CIRCLED DIGIT ZERO
2500 BOX DRAWINGS LIGHT HORIZONTAL
2501 BOX DRAWINGS HEAVY HORIZONTAL
2502 BOX DRAWINGS LIGHT VERTICAL
2503 BOX DRAWINGS HEAVY VERTICAL
2504 BOX DRAWINGS LIGHT TRIPLE DASH HORIZONTAL
2505 BOX DRAWINGS HEAVY TRIPLE DASH HORIZONTAL
2506 BOX DRAWINGS LIGHT TRIPLE DASH VERTICAL
2507 BOX DRAWINGS HEAVY TRIPLE DASH VERTICAL
2508 BOX DRAWINGS LIGHT QUADRUPLE DASH HORIZONTAL
2509 BOX DRAWINGS HEAVY QUADRUPLE DASH HORIZONTAL
250A BOX DRAWINGS LIGHT QUADRUPLE DASH VERTICAL
250B BOX DRAWINGS HEAVY QUADRUPLE DASH VERTICAL
250C BOX DRAWINGS LIGHT DOWN AND RIGHT
250D BOX DRAWINGS DOWN LIGHT AND RIGHT HEAVY
250E BOX DRAWINGS DOWN HEAVY AND RIGHT LIGHT
250F BOX DRAWINGS HEAVY DOWN AND RIGHT
2510 BOX DRAWINGS LIGHT DOWN AND LEFT
2511 BOX DRAWINGS DOWN LIGHT AND LEFT HEAVY
2512 BOX DRAWINGS DOWN HEAVY AND LEFT LIGHT
2513 BOX DRAWINGS HEAVY DOWN AND LEFT
2514 BOX DRAWINGS LIGHT UP AND RIGHT
2515 BOX DRAWINGS UP LIGHT AND RIGHT HEAVY
2516 BOX DRAWINGS UP HEAVY AND RIGHT LIGHT
2517 BOX DRAWINGS HEAVY UP AND RIGHT
2518 BOX DRAWINGS LIGHT UP AND LEFT
2519 BOX DRAWINGS UP LIGHT AND LEFT HEAVY
251A BOX DRAWINGS UP HEAVY AND LEFT LIGHT
251B BOX DRAWINGS HEAVY UP AND LEFT
251C BOX DRAWINGS LIGHT VERTICAL AND RIGHT
251D BOX DRAWINGS VERTICAL LIGHT AND RIGHT HEAVY
251E BOX DRAWINGS UP HEAVY AND RIGHT DOWN LIGHT
251F BOX DRAWINGS DOWN HEAVY AND RIGHT UP LIGHT
2520 BOX DRAWINGS VERTICAL HEAVY AND RIGHT LIGHT
2521 BOX DRAWINGS DOWN LIGHT AND RIGHT UP HEAVY
2522 BOX DRAWINGS UP LIGHT AND RIGHT DOWN HEAVY
2523 BOX DRAWINGS HEAVY VERTICAL AND RIGHT
2524 BOX DRAWINGS LIGHT VERTICAL AND LEFT
2525 BOX DRAWINGS VERTICAL LIGHT AND LEFT HEAVY
2526 BOX DRAWINGS UP HEAVY AND LEFT DOWN LIGHT
2527 BOX DRAWINGS DOWN HEAVY AND LEFT UP LIGHT
2528 BOX DRAWINGS VERTICAL HEAVY AND LEFT LIGHT
2529 BOX DRAWINGS DOWN LIGHT AND LEFT UP HEAVY
252A BOX DRAWINGS UP LIGHT AND LEFT DOWN HEAVY
252B BOX DRAWINGS HEAVY VERTICAL AND LEFT
252C BOX DRAWINGS LIGHT DOWN AND HORIZONTAL
252D BOX DRAWINGS LEFT HEAVY AND RIGHT DOWN LIGHT
252E BOX DRAWINGS RIGHT HEAVY AND LEFT DOWN LIGHT
252F BOX DRAWINGS DOWN LIGHT AND HORIZONTAL HEAVY
2530 BOX DRAWINGS DOWN HEAVY AND HORIZONTAL LIGHT
2531 BOX DRAWINGS RIGHT LIGHT AND LEFT DOWN HEAVY
2532 BOX DRAWINGS LEFT LIGHT AND RIGHT DOWN HEAVY
2533 BOX DRAWINGS HEAVY DOWN AND HORIZONTAL
2534 BOX DRAWINGS LIGHT UP AND HORIZONTAL
2535 BOX DRAWINGS LEFT HEAVY AND RIGHT UP LIGHT
2536 BOX DRAWINGS RIGHT HEAVY AND LEFT UP LIGHT
2537 BOX DRAWINGS UP LIGHT AND HORIZONTAL HEAVY
2538 BOX DRAWINGS UP HEAVY AND HORIZONTAL LIGHT
2539 BOX DRAWINGS RIGHT LIGHT AND LEFT UP HEAVY
253A BOX DRAWINGS LEFT LIGHT AND RIGHT UP HEAVY
253B BOX DRAWINGS HEAVY UP AND HORIZONTAL
253C BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL
253D BOX DRAWINGS LEFT HEAVY AND RIGHT VERTICAL LIGHT
253E BOX DRAWINGS RIGHT HEAVY AND LEFT VERTICAL LIGHT
253F BOX DRAWINGS VERTICAL LIGHT AND HORIZONTAL HEAVY
2540 BOX DRAWINGS UP HEAVY AND DOWN HORIZONTAL LIGHT
2541 BOX DRAWINGS DOWN HEAVY AND UP HORIZONTAL LIGHT
2542 BOX DRAWINGS VERTICAL HEAVY AND HORIZONTAL LIGHT
2543 BOX DRAWINGS LEFT UP HEAVY AND RIGHT DOWN LIGHT
2544 BOX DRAWINGS RIGHT UP HEAVY AND LEFT DOWN LIGHT
2545 BOX DRAWINGS LEFT DOWN HEAVY AND RIGHT UP LIGHT
2546 BOX DRAWINGS RIGHT DOWN HEAVY AND LEFT UP LIGHT
2547 BOX DRAWINGS DOWN LIGHT AND UP HORIZONTAL HEAVY
2548 BOX DRAWINGS UP LIGHT AND DOWN HORIZONTAL HEAVY
2549 BOX DRAWINGS RIGHT LIGHT AND LEFT VERTICAL HEAVY
254A BOX DRAWINGS LEFT LIGHT AND RIGHT VERTICAL HEAVY
254B BOX DRAWINGS HEAVY VERTICAL AND HORIZONTAL
254C BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL
254D BOX DRAWINGS HEAVY DOUBLE DASH HORIZONTAL
254E BOX DRAWINGS LIGHT DOUBLE DASH VERTICAL
254F BOX DRAWINGS HEAVY DOUBLE DASH VERTICAL
2550 BOX DRAWINGS DOUBLE HORIZONTAL
2551 BOX DRAWINGS DOUBLE VERTICAL
2552 BOX DRAWINGS DOWN SINGLE AND RIGHT DOUBLE
2553 BOX DRAWINGS DOWN DOUBLE AND RIGHT SINGLE
2554 BOX DRAWINGS DOUBLE DOWN AND RIGHT
2555 BOX DRAWINGS DOWN SINGLE AND LEFT DOUBLE
2556 BOX DRAWINGS DOWN DOUBLE AND LEFT SINGLE
2557 BOX DRAWINGS DOUBLE DOWN AND LEFT
2558 BOX DRAWINGS UP SINGLE AND RIGHT DOUBLE
2559 BOX DRAWINGS UP DOUBLE AND RIGHT SINGLE
255A BOX DRAWINGS DOUBLE UP AND RIGHT
255B BOX DRAWINGS UP SINGLE AND LEFT DOUBLE
255C BOX DRAWINGS UP DOUBLE AND LEFT SINGLE
255D BOX DRAWINGS DOUBLE UP AND LEFT
255E BOX DRAWINGS VERTICAL SINGLE AND RIGHT DOUBLE
255F BOX DRAWINGS VERTICAL DOUBLE AND RIGHT SINGLE
2560 BOX DRAWINGS DOUBLE VERTICAL AND RIGHT
2561 BOX DRAWINGS VERTICAL SINGLE AND LEFT DOUBLE
2562 BOX DRAWINGS VERTICAL DOUBLE AND LEFT SINGLE
2563 BOX DRAWINGS DOUBLE VERTICAL AND LEFT
2564 BOX DRAWINGS DOWN SINGLE AND HORIZONTAL DOUBLE
2565 BOX DRAWINGS DOWN DOUBLE AND HORIZONTAL SINGLE
2566 BOX DRAWINGS DOUBLE DOWN AND HORIZONTAL
2567 BOX DRAWINGS UP SINGLE AND HORIZONTAL DOUBLE
2568 BOX DRAWINGS UP DOUBLE AND HORIZONTAL SINGLE
2569 BOX DRAWINGS DOUBLE UP AND HORIZONTAL
256A BOX DRAWINGS VERTICAL SINGLE AND HORIZONTAL DOUBLE
256B BOX DRAWINGS VERTICAL DOUBLE AND HORIZONTAL SINGLE
256C BOX DRAWINGS DOUBLE VERTICAL AND HORIZONTAL
256D BOX DRAWINGS LIGHT ARC DOWN AND RIGHT
256E BOX DRAWINGS LIGHT ARC DOWN AND LEFT
256F BOX DRAWINGS LIGHT ARC UP AND LEFT
2570 BOX DRAWINGS LIGHT ARC UP AND RIGHT
2571 BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO LOWER LEFT
2572 BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER RIGHT
2573 BOX DRAWINGS LIGHT DIAGONAL CROSS
2574 BOX DRAWINGS LIGHT LEFT
2575 BOX DRAWINGS LIGHT UP
2576 BOX DRAWINGS LIGHT RIGHT
2577 BOX DRAWINGS LIGHT DOWN
2578 BOX DRAWINGS HEAVY LEFT
2579 BOX DRAWINGS HEAVY UP
257A BOX DRAWINGS HEAVY RIGHT
257B BOX DRAWINGS HEAVY DOWN
257C BOX DRAWINGS LIGHT LEFT AND HEAVY RIGHT
257D BOX DRAWINGS LIGHT UP AND HEAVY DOWN
257E BOX DRAWINGS HEAVY LEFT AND LIGHT RIGHT
257F BOX DRAWINGS HEAVY UP AND LIGHT DOWN
2580 UPPER HALF BLOCK
2581 LOWER ONE EIGHTH BLOCK
2582 LOWER ONE QUARTER BLOCK
2583 LOWER THREE EIGHTHS BLOCK
2584 LOWER HALF BLOCK
2585 LOWER FIVE EIGHTHS BLOCK
2586 LOWER THREE QUARTERS BLOCK
2587 LOWER SEVEN EIGHTHS BLOCK
2588 FULL BLOCK
2589 LEFT SEVEN EIGHTHS BLOCK
258A LEFT THREE QUARTERS BLOCK
258B LEFT FIVE EIGHTHS BLOCK
258C LEFT HALF BLOCK
258D LEFT THREE EIGHTHS BLOCK
258E LEFT ONE QUARTER BLOCK
258F LEFT ONE EIGHTH BLOCK
2590 RIGHT HALF BLOCK
2591 LIGHT SHADE
2592 MEDIUM SHADE
2593 DARK SHADE
2594 UPPER ONE EIGHTH BLOCK
2595 RIGHT ONE EIGHTH BLOCK
2596 QUADRANT LOWER LEFT
2597 QUADRANT LOWER RIGHT
2598 QUADRANT UPPER LEFT
2599 QUADRANT UPPER LEFT AND LOWER LEFT AND LOWER RIGHT
259A QUADRANT UPPER LEFT AND LOWER RIGHT
259B QUADRANT UPPER LEFT AND UPPER RIGHT AND LOWER LEFT
259C QUADRANT UPPER LEFT AND UPPER RIGHT AND LOWER RIGHT
259D QUADRANT UPPER RIGHT
259E QUADRANT UPPER RIGHT AND LOWER LEFT
259F QUADRANT UPPER RIGHT AND LOWER LEFT AND LOWER RIGHT
25A0 BLACK SQUARE
25A1 WHITE SQUARE
25A2 WHITE SQUARE WITH ROUNDED CORNERS
25A3 WHITE SQUARE CONTAINING BLACK SMALL SQUARE
25A4 SQUARE WITH HORIZONTAL FILL
25A5 SQUARE WITH VERTICAL FILL
25A6 SQUARE WITH ORTHOGONAL CROSSHATCH FILL
25A7 SQUARE WITH UPPER LEFT TO LOWER RIGHT FILL
25A8 SQUARE WITH UPPER RIGHT TO LOWER LEFT FILL
25A9 SQUARE WITH DIAGONAL CROSSHATCH FILL
25AA BLACK SMALL SQUARE
25AB WHITE SMALL SQUARE
25AC BLACK RECTANGLE
25AD WHITE RECTANGLE
25AE BLACK VERTICAL RECTANGLE
25AF WHITE VERTICAL RECTANGLE
25B0 BLACK PARALLELOGRAM
25B1 WHITE PARALLELOGRAM
25B2 BLACK UP-POINTING TRIANGLE
25B3 WHITE UP-POINTING TRIANGLE
25B4 BLACK UP-POINTING SMALL TRIANGLE
25B5 WHITE UP-POINTING SMALL TRIANGLE
25B6 BLACK RIGHT-POINTING TRIANGLE
25B7 WHITE RIGHT-POINTING TRIANGLE
25B8 BLACK RIGHT-POINTING SMALL TRIANGLE
25B9 WHITE RIGHT-POINTING SMALL TRIANGLE
25BA BLACK RIGHT-POINTING POINTER
25BB WHITE RIGHT-POINTING POINTER
25BC BLACK DOWN-POINTING TRIANGLE
25BD WHITE DOWN-POINTING TRIANGLE
25BE BLACK DOWN-POINTING SMALL TRIANGLE
25BF WHITE DOWN-POINTING SMALL TRIANGLE
25C0 BLACK LEFT-POINTING TRIANGLE
25C1 WHITE LEFT-POINTING TRIANGLE
25C2 BLACK LEFT-POINTING SMALL TRIANGLE
25C3 WHITE LEFT-POINTING SMALL TRIANGLE
25C4 BLACK LEFT-POINTING POINTER
25C5 WHITE LEFT-POINTING POINTER
25C6 BLACK DIAMOND
25C7 WHITE DIAMOND
25C8 WHITE DIAMOND CONTAINING BLACK SMALL DIAMOND
25C9 FISHEYE
25CA LOZENGE
25CB WHITE CIRCLE
25CC DOTTED CIRCLE
25CD CIRCLE WITH VERTICAL FILL
25CE BULLSEYE
25CF BLACK CIRCLE
25D0 CIRCLE WITH LEFT HALF BLACK
25D1 CIRCLE WITH RIGHT HALF BLACK
25D2 CIRCLE WITH LOWER HALF BLACK
25D3 CIRCLE WITH UPPER HALF BLACK
25D4 CIRCLE WITH UPPER RIGHT QUADRANT BLACK
25D5 CIRCLE WITH ALL BUT UPPER LEFT QUADRANT BLACK
25D6 LEFT HALF BLACK CIRCLE
25D7 RIGHT HALF BLACK CIRCLE
25D8 INVERSE BULLET
25D9 INVERSE WHITE CIRCLE
25DA UPPER HALF INVERSE WHITE CIRCLE
25DB LOWER HALF INVERSE WHITE CIRCLE
25DC UPPER LEFT QUADRANT CIRCULAR ARC
25DD UPPER RIGHT QUADRANT CIRCULAR ARC
25DE LOWER RIGHT QUADRANT CIRCULAR ARC
25DF LOWER LEFT QUADRANT CIRCULAR ARC
25E0 UPPER HALF CIRCLE
25E1 LOWER HALF CIRCLE
25E2 BLACK LOWER RIGHT TRIANGLE
25E3 BLACK LOWER LEFT TRIANGLE
25E4 BLACK UPPER LEFT TRIANGLE
25E5 BLACK UPPER RIGHT TRIANGLE
25E6 WHITE BULLET
25E7 SQUARE WITH LEFT HALF BLACK
25E8 SQUARE WITH RIGHT HALF BLACK
25E9 SQUARE WITH UPPER LEFT DIAGONAL HALF BLACK
25EA SQUARE WITH LOWER RIGHT DIAGONAL HALF BLACK
25EB WHITE SQUARE WITH VERTICAL BISECTING LINE
25EC WHITE UP-POINTING TRIANGLE WITH DOT
25ED UP-POINTING TRIANGLE WITH LEFT HALF BLACK
25EE UP-POINTING TRIANGLE WITH RIGHT HALF BLACK
25EF LARGE CIRCLE
25F0 WHITE SQUARE WITH UPPER LEFT QUADRANT
25F1 WHITE SQUARE WITH LOWER LEFT QUADRANT
25F2 WHITE SQUARE WITH LOWER RIGHT QUADRANT
25F3 WHITE SQUARE WITH UPPER RIGHT QUADRANT
25F4 WHITE CIRCLE WITH UPPER LEFT QUADRANT
25F5 WHITE CIRCLE WITH LOWER LEFT QUADRANT
25F6 WHITE CIRCLE WITH LOWER RIGHT QUADRANT
25F7 WHITE CIRCLE WITH UPPER RIGHT QUADRANT
25F8 UPPER LEFT TRIANGLE
25F9 UPPER RIGHT TRIANGLE
25FA LOWER LEFT TRIANGLE
25FB WHITE MEDIUM SQUARE
25FC BLACK MEDIUM SQUARE
25FD WHITE MEDIUM SMALL SQUARE
25FE BLACK MEDIUM SMALL SQUARE
25FF LOWER RIGHT TRIANGLE
2600 BLACK SUN WITH RAYS
2601 CLOUD
2602 UMBRELLA
2603 SNOWMAN
2604 COMET
2605 BLACK STAR
2606 WHITE STAR
2607 LIGHTNING
2608 THUNDERSTORM
2609 SUN
260A ASCENDING NODE
260B DESCENDING NODE
260C CONJUNCTION
260D OPPOSITION
260E BLACK TELEPHONE
260F WHITE TELEPHONE
2610 BALLOT BOX
2611 BALLOT BOX WITH CHECK
2612 BALLOT BOX WITH X
2613 SALTIRE
2614 UMBRELLA WITH RAIN DROPS
2615 HOT BEVERAGE
2616 WHITE SHOGI PIECE
2617 BLACK SHOGI PIECE
2618 SHAMROCK
2619 REVERSED ROTATED FLORAL HEART BULLET
261A BLACK LEFT POINTING INDEX
261B BLACK RIGHT POINTING INDEX
261C WHITE LEFT POINTING INDEX
261D WHITE UP POINTING INDEX
261E WHITE RIGHT POINTING INDEX
261F WHITE DOWN POINTING INDEX
2620 SKULL AND CROSSBONES
2621 CAUTION SIGN
2622 RADIOACTIVE SIGN
2623 BIOHAZARD SIGN
2624 CADUCEUS
2625 ANKH
2626 ORTHODOX CROSS
2627 CHI RHO
2628 CROSS OF LORRAINE
2629 CROSS OF JERUSALEM
262A STAR AND CRESCENT
262B FARSI SYMBOL
262C ADI SHAKTI
262D HAMMER AND SICKLE
262E PEACE SYMBOL
262F YIN YANG
2630 TRIGRAM FOR HEAVEN
2631 TRIGRAM FOR LAKE
2632 TRIGRAM FOR FIRE
2633 TRIGRAM FOR THUNDER
2634 TRIGRAM FOR WIND
2635 TRIGRAM FOR WATER
2636 TRIGRAM FOR MOUNTAIN
2637 TRIGRAM FOR EARTH
2638 WHEEL OF DHARMA
2639 WHITE FROWNING FACE
263A WHITE SMILING FACE
263B BLACK SMILING FACE
263C WHITE SUN WITH RAYS
263D FIRST QUARTER MOON
263E LAST QUARTER MOON
263F MERCURY
2640 FEMALE SIGN
2641 EARTH
2642 MALE SIGN
2643 JUPITER
2644 SATURN
2645 URANUS
2646 NEPTUNE
2647 PLUTO
2648 ARIES
2649 TAURUS
264A GEMINI
264B CANCER
264C LEO
264D VIRGO
264E LIBRA
264F SCORPIUS
2650 SAGITTARIUS
2651 CAPRICORN
2652 AQUARIUS
2653 PISCES
2654 WHITE CHESS KING
2655 WHITE CHESS QUEEN
2656 WHITE CHESS ROOK
2657 WHITE CHESS BISHOP
2658 WHITE CHESS KNIGHT
2659 WHITE CHESS PAWN
265A BLACK CHESS KING
265B BLACK CHESS QUEEN
265C BLACK CHESS ROOK
265D BLACK CHESS BISHOP
265E BLACK CHESS KNIGHT
265F BLACK CHESS PAWN
2660 BLACK SPADE SUIT
2661 WHITE HEART SUIT
2662 WHITE DIAMOND SUIT
2663 BLACK CLUB SUIT
2664 WHITE SPADE SUIT
2665 BLACK HEART SUIT
2666 BLACK DIAMOND SUIT
2667 WHITE CLUB SUIT
2668 HOT SPRINGS
2669 QUARTER NOTE
266A EIGHTH NOTE
266B BEAMED EIGHTH NOTES
266C BEAMED SIXTEENTH NOTES
266D MUSIC FLAT SIGN
266E MUSIC NATURAL SIGN
266F MUSIC SHARP SIGN
2670 WEST SYRIAC CROSS
2671 EAST SYRIAC CROSS
2672 UNIVERSAL RECYCLING SYMBOL
2673 RECYCLING SYMBOL FOR TYPE-1 PLASTICS
2674 RECYCLING SYMBOL FOR TYPE-2 PLASTICS
2675 RECYCLING SYMBOL FOR TYPE-3 PLASTICS
2676 RECYCLING SYMBOL FOR TYPE-4 PLASTICS
2677 RECYCLING SYMBOL FOR TYPE-5 PLASTICS
2678 RECYCLING SYMBOL FOR TYPE-6 PLASTICS
2679 RECYCLING SYMBOL FOR TYPE-7 PLASTICS
267A RECYCLING SYMBOL FOR GENERIC MATERIALS
267B BLACK UNIVERSAL RECYCLING SYMBOL
267C RECYCLED PAPER SYMBOL
267D PARTIALLY-RECYCLED PAPER SYMBOL
267E PERMANENT PAPER SIGN
267F WHEELCHAIR SYMBOL
2680 DIE FACE-1
2681 DIE FACE-2
2682 DIE FACE-3
2683 DIE FACE-4
2684 DIE FACE-5
2685 DIE FACE-6
2686 WHITE CIRCLE WITH DOT RIGHT
2687 WHITE CIRCLE WITH TWO DOTS
2688 BLACK CIRCLE WITH WHITE DOT RIGHT
2689 BLACK CIRCLE WITH TWO WHITE DOTS
268A MONOGRAM FOR YANG
268B MONOGRAM FOR YIN
268C DIGRAM FOR GREATER YANG
268D DIGRAM FOR LESSER YIN
268E DIGRAM FOR LESSER YANG
268F DIGRAM FOR GREATER YIN
2690 WHITE FLAG
2691 BLACK FLAG
2692 HAMMER AND PICK
2693 ANCHOR
2694 CROSSED SWORDS
2695 STAFF OF AESCULAPIUS
2696 SCALES
2697 ALEMBIC
2698 FLOWER
2699 GEAR
269A STAFF OF HERMES
269B ATOM SYMBOL
269C FLEUR-DE-LIS
269D OUTLINED WHITE STAR
269E THREE LINES CONVERGING RIGHT
269F THREE LINES CONVERGING LEFT
26A0 WARNING SIGN
26A1 HIGH VOLTAGE SIGN
26A2 DOUBLED FEMALE SIGN
26A3 DOUBLED MALE SIGN
26A4 INTERLOCKED FEMALE AND MALE SIGN
26A5 MALE AND FEMALE SIGN
26A6 MALE WITH STROKE SIGN
26A7 MALE WITH STROKE AND MALE AND FEMALE SIGN
26A8 VERTICAL MALE WITH STROKE SIGN
26A9 HORIZONTAL MALE WITH STROKE SIGN
26AA MEDIUM WHITE CIRCLE
26AB MEDIUM BLACK CIRCLE
26AC MEDIUM SMALL WHITE CIRCLE
26AD MARRIAGE SYMBOL
26AE DIVORCE SYMBOL
26AF UNMARRIED PARTNERSHIP SYMBOL
26B0 COFFIN
26B1 FUNERAL URN
26B2 NEUTER
26B3 CERES
26B4 PALLAS
26B5 JUNO
26B6 VESTA
26B7 CHIRON
26B8 BLACK MOON LILITH
26B9 SEXTILE
26BA SEMISEXTILE
26BB QUINCUNX
26BC SESQUIQUADRATE
26BD SOCCER BALL
26BE BASEBALL
26BF SQUARED KEY
26C0 WHITE DRAUGHTS MAN
26C1 WHITE DRAUGHTS KING
26C2 BLACK DRAUGHTS MAN
26C3 BLACK DRAUGHTS KING
26C4 SNOWMAN WITHOUT SNOW
26C5 SUN BEHIND CLOUD
26C6 RAIN
26C7 BLACK SNOWMAN
26C8 THUNDER CLOUD AND RAIN
26C9 TURNED WHITE SHOGI PIECE
26CA TURNED BLACK SHOGI PIECE
26CB WHITE DIAMOND IN SQUARE
26CC CROSSING LANES
26CD DISABLED CAR
26CE OPHIUCHUS
26CF PICK
26D0 CAR SLIDING
26D1 HELMET WITH WHITE CROSS
26D2 CIRCLED CROSSING LANES
26D3 CHAINS
26D4 NO ENTRY
26D5 ALTERNATE ONE-WAY LEFT WAY TRAFFIC
26D6 BLACK TWO-WAY LEFT WAY TRAFFIC
26D7 WHITE TWO-WAY LEFT WAY TRAFFIC
26D8 BLACK LEFT LANE MERGE
26D9 WHITE LEFT LANE MERGE
26DA DRIVE SLOW SIGN
26DB HEAVY WHITE DOWN-POINTING TRIANGLE
26DC LEFT CLOSED ENTRY
26DD SQUARED SALTIRE
26DE FALLING DIAGONAL IN WHITE CIRCLE IN BLACK SQUARE
26DF BLACK TRUCK
26E0 RESTRICTED LEFT ENTRY-1
26E1 RESTRICTED LEFT ENTRY-2
26E2 ASTRONOMICAL SYMBOL FOR URANUS
26E3 HEAVY CIRCLE WITH STROKE AND TWO DOTS ABOVE
26E4 PENTAGRAM
26E5 RIGHT-HANDED INTERLACED PENTAGRAM
26E6 LEFT-HANDED INTERLACED PENTAGRAM
26E7 INVERTED PENTAGRAM
26E8 BLACK CROSS ON SHIELD
26E9 SHINTO SHRINE
26EA CHURCH
26EB CASTLE
26EC HISTORIC SITE
26ED GEAR WITHOUT HUB
26EE GEAR WITH HANDLES
26EF MAP SYMBOL FOR LIGHTHOUSE
26F0 MOUNTAIN
26F1 UMBRELLA ON GROUND
26F2 FOUNTAIN
26F3 FLAG IN HOLE
26F4 FERRY
26F5 SAILBOAT
26F6 SQUARE FOUR CORNERS
26F7 SKIER
26F8 ICE SKATE
26F9 PERSON WITH BALL
26FA TENT
26FB JAPANESE BANK SYMBOL
26FC HEADSTONE GRAVEYARD SYMBOL
26FD FUEL PUMP
26FE CUP ON BLACK SQUARE
26FF WHITE FLAG WITH HORIZONTAL MIDDLE BLACK STRIPE
2700 BLACK SAFETY SCISSORS
2701 UPPER BLADE SCISSORS
2702 BLACK SCISSORS
2703 LOWER BLADE SCISSORS
2704 WHITE SCISSORS
2705 WHITE HEAVY CHECK MARK
2706 TELEPHONE LOCATION SIGN
2707 TAPE DRIVE
2708 AIRPLANE
2709 ENVELOPE
270A RAISED FIST
270B RAISED HAND
270C VICTORY HAND
270D WRITING HAND
270E LOWER RIGHT PENCIL
270F PENCIL
2710 UPPER RIGHT PENCIL
2711 WHITE NIB
2712 BLACK NIB
2713 CHECK MARK
2714 HEAVY CHECK MARK
2715 MULTIPLICATION X
2716 HEAVY MULTIPLICATION X
2717 BALLOT X
2718 HEAVY BALLOT X
2719 OUTLINED GREEK CROSS
271A HEAVY GREEK CROSS
271B OPEN CENTRE CROSS
271C HEAVY OPEN CENTRE CROSS
271D LATIN CROSS
271E SHADOWED WHITE LATIN CROSS
271F OUTLINED LATIN CROSS
2720 MALTESE CROSS
2721 STAR OF DAVID
2722 FOUR TEARDROP-SPOKED ASTERISK
2723 FOUR BALLOON-SPOKED ASTERISK
2724 HEAVY FOUR BALLOON-SPOKED ASTERISK
2725 FOUR CLUB-SPOKED ASTERISK
2726 BLACK FOUR POINTED STAR
2727 WHITE FOUR POINTED STAR
2728 SPARKLES
2729 STRESS OUTLINED WHITE STAR
272A CIRCLED WHITE STAR
272B OPEN CENTRE BLACK STAR
272C BLACK CENTRE WHITE STAR
272D OUTLINED BLACK STAR
272E HEAVY OUTLINED BLACK STAR
272F PINWHEEL STAR
2730 SHADOWED WHITE STAR
2731 HEAVY ASTERISK
2732 OPEN CENTRE ASTERISK
2733 EIGHT SPOKED ASTERISK
2734 EIGHT POINTED BLACK STAR
2735 EIGHT POINTED PINWHEEL STAR
2736 SIX POINTED BLACK STAR
2737 EIGHT POINTED RECTILINEAR BLACK STAR
2738 HEAVY EIGHT POINTED RECTILINEAR BLACK STAR
2739 TWELVE POINTED BLACK STAR
273A SIXTEEN POINTED ASTERISK
273B TEARDROP-SPOKED ASTERISK
273C OPEN CENTRE TEARDROP-SPOKED ASTERISK
273D HEAVY TEARDROP-SPOKED ASTERISK
273E SIX PETALLED BLACK AND WHITE FLORETTE
273F BLACK FLORETTE
2740 WHITE FLORETTE
2741 EIGHT PETALLED OUTLINED BLACK FLORETTE
2742 CIRCLED OPEN CENTRE EIGHT POINTED STAR
2743 HEAVY TEARDROP-SPOKED PINWHEEL ASTERISK
2744 SNOWFLAKE
2745 TIGHT TRIFOLIATE SNOWFLAKE
2746 HEAVY CHEVRON SNOWFLAKE
2747 SPARKLE
2748 HEAVY SPARKLE
2749 BALLOON-SPOKED ASTERISK
274A EIGHT TEARDROP-SPOKED PROPELLER ASTERISK
274B HEAVY EIGHT TEARDROP-SPOKED PROPELLER ASTERISK
274C CROSS MARK
274D SHADOWED WHITE CIRCLE
274E NEGATIVE SQUARED CROSS MARK
274F LOWER RIGHT DROP-SHADOWED WHITE SQUARE
2750 UPPER RIGHT DROP-SHADOWED WHITE SQUARE
2751 LOWER RIGHT SHADOWED WHITE SQUARE
2752 UPPER RIGHT SHADOWED WHITE SQUARE
2753 BLACK QUESTION MARK ORNAMENT
2754 WHITE QUESTION MARK ORNAMENT
2755 WHITE EXCLAMATION MARK ORNAMENT
2756 BLACK DIAMOND MINUS WHITE X
2757 HEAVY EXCLAMATION MARK SYMBOL
2758 LIGHT VERTICAL BAR
2759 MEDIUM VERTICAL BAR
275A HEAVY VERTICAL BAR
275B HEAVY SINGLE TURNED COMMA QUOTATION MARK ORNAMENT
275C HEAVY SINGLE COMMA QUOTATION MARK ORNAMENT
275D HEAVY DOUBLE TURNED COMMA QUOTATION MARK ORNAMENT
275E HEAVY DOUBLE COMMA QUOTATION MARK ORNAMENT
275F HEAVY LOW SINGLE COMMA QUOTATION MARK ORNAMENT
2760 HEAVY LOW DOUBLE COMMA QUOTATION MARK ORNAMENT
2761 CURVED STEM PARAGRAPH SIGN ORNAMENT
2762 HEAVY EXCLAMATION MARK ORNAMENT
2763 HEAVY HEART EXCLAMATION MARK ORNAMENT
2764 HEAVY BLACK HEART
2765 ROTATED HEAVY BLACK HEART BULLET
2766 FLORAL HEART
2767 ROTATED FLORAL HEART BULLET
2768 MEDIUM LEFT PARENTHESIS ORNAMENT
2769 MEDIUM RIGHT PARENTHESIS ORNAMENT
276A MEDIUM FLATTENED LEFT PARENTHESIS ORNAMENT
276B MEDIUM FLATTENED RIGHT PARENTHESIS ORNAMENT
276C MEDIUM LEFT-POINTING ANGLE BRACKET ORNAMENT
276D MEDIUM RIGHT-POINTING ANGLE BRACKET ORNAMENT
276E HEAVY LEFT-POINTING ANGLE QUOTATION MARK ORNAMENT
276F HEAVY RIGHT-POINTING ANGLE QUOTATION MARK ORNAMENT
2770 HEAVY LEFT-POINTING ANGLE BRACKET ORNAMENT
2771 HEAVY RIGHT-POINTING ANGLE BRACKET ORNAMENT
2772 LIGHT LEFT TORTOISE SHELL BRACKET ORNAMENT
2773 LIGHT RIGHT TORTOISE SHELL BRACKET ORNAMENT
2774 MEDIUM LEFT CURLY BRACKET ORNAMENT
2775 MEDIUM RIGHT CURLY BRACKET ORNAMENT
2776 DINGBAT NEGATIVE CIRCLED DIGIT ONE
2777 DINGBAT NEGATIVE CIRCLED DIGIT TWO
2778 DINGBAT NEGATIVE CIRCLED DIGIT THREE
2779 DINGBAT NEGATIVE CIRCLED DIGIT FOUR
277A DINGBAT NEGATIVE CIRCLED DIGIT FIVE
277B DINGBAT NEGATIVE CIRCLED DIGIT SIX
277C DINGBAT NEGATIVE CIRCLED DIGIT SEVEN
277D DINGBAT NEGATIVE CIRCLED DIGIT EIGHT
277E DINGBAT NEGATIVE CIRCLED DIGIT NINE
277F DINGBAT NEGATIVE CIRCLED NUMBER TEN
2780 DINGBAT CIRCLED SANS-SERIF DIGIT ONE
2781 DINGBAT CIRCLED SANS-SERIF DIGIT TWO
2782 DINGBAT CIRCLED SANS-SERIF DIGIT THREE
2783 DINGBAT CIRCLED SANS-SERIF DIGIT FOUR
2784 DINGBAT CIRCLED SANS-SERIF DIGIT FIVE
2785 DINGBAT CIRCLED SANS-SERIF DIGIT SIX
2786 DINGBAT CIRCLED SANS-SERIF DIGIT SEVEN
2787 DINGBAT CIRCLED SANS-SERIF DIGIT EIGHT
2788 DINGBAT CIRCLED SANS-SERIF DIGIT NINE
2789 DINGBAT CIRCLED SANS-SERIF NUMBER TEN
278A DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT ONE
278B DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT TWO
278C DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT THREE
278D DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FOUR
278E DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT FIVE
278F DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SIX
2790 DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT SEVEN
2791 DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT EIGHT
2792 DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT NINE
2793 DINGBAT NEGATIVE CIRCLED SANS-SERIF NUMBER TEN
2794 HEAVY WIDE-HEADED RIGHTWARDS ARROW
2795 HEAVY PLUS SIGN
2796 HEAVY MINUS SIGN
2797 HEAVY DIVISION SIGN
2798 HEAVY SOUTH EAST ARROW
2799 HEAVY RIGHTWARDS ARROW
279A HEAVY NORTH EAST ARROW
279B DRAFTING POINT RIGHTWARDS ARROW
279C HEAVY ROUND-TIPPED RIGHTWARDS ARROW
279D TRIANGLE-HEADED RIGHTWARDS ARROW
279E HEAVY TRIANGLE-HEADED RIGHTWARDS ARROW
279F DASHED TRIANGLE-HEADED RIGHTWARDS ARROW
27A0 HEAVY DASHED TRIANGLE-HEADED RIGHTWARDS ARROW
27A1 BLACK RIGHTWARDS ARROW
27A2 THREE-D TOP-LIGHTED RIGHTWARDS ARROWHEAD
27A3 THREE-D BOTTOM-LIGHTED RIGHTWARDS ARROWHEAD
27A4 BLACK RIGHTWARDS ARROWHEAD
27A5 HEAVY BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW
27A6 HEAVY BLACK CURVED UPWARDS AND RIGHTWARDS ARROW
27A7 SQUAT BLACK RIGHTWARDS ARROW
27A8 HEAVY CONCAVE-POINTED BLACK RIGHTWARDS ARROW
27A9 RIGHT-SHADED WHITE RIGHTWARDS ARROW
27AA LEFT-SHADED WHITE RIGHTWARDS ARROW
27AB BACK-TILTED SHADOWED WHITE RIGHTWARDS ARROW
27AC FRONT-TILTED SHADOWED WHITE RIGHTWARDS ARROW
27AD HEAVY LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW
27AE HEAVY UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW
27AF NOTCHED LOWER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW
27B0 CURLY LOOP
27B1 NOTCHED UPPER RIGHT-SHADOWED WHITE RIGHTWARDS ARROW
27B2 CIRCLED HEAVY WHITE RIGHTWARDS ARROW
27B3 WHITE-FEATHERED RIGHTWARDS ARROW
27B4 BLACK-FEATHERED SOUTH EAST ARROW
27B5 BLACK-FEATHERED RIGHTWARDS ARROW
27B6 BLACK-FEATHERED NORTH EAST ARROW
27B7 HEAVY BLACK-FEATHERED SOUTH EAST ARROW
27B8 HEAVY BLACK-FEATHERED RIGHTWARDS ARROW
27B9 HEAVY BLACK-FEATHERED NORTH EAST ARROW
27BA TEARDROP-BARBED RIGHTWARDS ARROW
27BB HEAVY TEARDROP-SHANKED RIGHTWARDS ARROW
27BC WEDGE-TAILED RIGHTWARDS ARROW
27BD HEAVY WEDGE-TAILED RIGHTWARDS ARROW
27BE OPEN-OUTLINED RIGHTWARDS ARROW
27BF DOUBLE CURLY LOOP
27C0 THREE DIMENSIONAL ANGLE
27C1 WHITE TRIANGLE CONTAINING SMALL WHITE TRIANGLE
27C2 PERPENDICULAR
27C3 OPEN SUBSET
27C4 OPEN SUPERSET
27C5 LEFT S-SHAPED BAG DELIMITER
27C6 RIGHT S-SHAPED BAG DELIMITER
27C7 OR WITH DOT INSIDE
27C8 REVERSE SOLIDUS PRECEDING SUBSET
27C9 SUPERSET PRECEDING SOLIDUS
27CA VERTICAL BAR WITH HORIZONTAL STROKE
27CB MATHEMATICAL RISING DIAGONAL
27CC LONG DIVISION
27CD MATHEMATICAL FALLING DIAGONAL
27CE SQUARED LOGICAL AND
27CF SQUARED LOGICAL OR
27D0 WHITE DIAMOND WITH CENTRED DOT
27D1 AND WITH DOT
27D2 ELEMENT OF OPENING UPWARDS
27D3 LOWER RIGHT CORNER WITH DOT
27D4 UPPER LEFT CORNER WITH DOT
27D5 LEFT OUTER JOIN
27D6 RIGHT OUTER JOIN
27D7 FULL OUTER JOIN
27D8 LARGE UP TACK
27D9 LARGE DOWN TACK
27DA LEFT AND RIGHT DOUBLE TURNSTILE
27DB LEFT AND RIGHT TACK
27DC LEFT MULTIMAP
27DD LONG RIGHT TACK
27DE LONG LEFT TACK
27DF UP TACK WITH CIRCLE ABOVE
27E0 LOZENGE DIVIDED BY HORIZONTAL RULE
27E1 WHITE CONCAVE-SIDED DIAMOND
27E2 WHITE CONCAVE-SIDED DIAMOND WITH LEFTWARDS TICK
27E3 WHITE CONCAVE-SIDED DIAMOND WITH RIGHTWARDS TICK
27E4 WHITE SQUARE WITH LEFTWARDS TICK
27E5 WHITE SQUARE WITH RIGHTWARDS TICK
27E6 MATHEMATICAL LEFT WHITE SQUARE BRACKET
27E7 MATHEMATICAL RIGHT WHITE SQUARE BRACKET
27E8 MATHEMATICAL LEFT ANGLE BRACKET
27E9 MATHEMATICAL RIGHT ANGLE BRACKET
27EA MATHEMATICAL LEFT DOUBLE ANGLE BRACKET
27EB MATHEMATICAL RIGHT DOUBLE ANGLE BRACKET
27EC MATHEMATICAL LEFT WHITE TORTOISE SHELL BRACKET
27ED MATHEMATICAL RIGHT WHITE TORTOISE SHELL BRACKET
27EE MATHEMATICAL LEFT FLATTENED PARENTHESIS
27EF MATHEMATICAL RIGHT FLATTENED PARENTHESIS
27F0 UPWARDS QUADRUPLE ARROW
27F1 DOWNWARDS QUADRUPLE ARROW
27F2 ANTICLOCKWISE GAPPED CIRCLE ARROW
27F3 CLOCKWISE GAPPED CIRCLE ARROW
27F4 RIGHT ARROW WITH CIRCLED PLUS
27F5 LONG LEFTWARDS ARROW
27F6 LONG RIGHTWARDS ARROW
27F7 LONG LEFT RIGHT ARROW
27F8 LONG LEFTWARDS DOUBLE ARROW
27F9 LONG RIGHTWARDS DOUBLE ARROW
27FA LONG LEFT RIGHT DOUBLE ARROW
27FB LONG LEFTWARDS ARROW FROM BAR
27FC LONG RIGHTWARDS ARROW FROM BAR
27FD LONG LEFTWARDS DOUBLE ARROW FROM BAR
27FE LONG RIGHTWARDS DOUBLE ARROW FROM BAR
27FF LONG RIGHTWARDS SQUIGGLE ARROW
2800 BRAILLE PATTERN BLANK
2801 BRAILLE PATTERN DOTS-1
2802 BRAILLE PATTERN DOTS-2
2803 BRAILLE PATTERN DOTS-12
2804 BRAILLE PATTERN DOTS-3
2805 BRAILLE PATTERN DOTS-13
2806 BRAILLE PATTERN DOTS-23
2807 BRAILLE PATTERN DOTS-123
2808 BRAILLE PATTERN DOTS-4
2809 BRAILLE PATTERN DOTS-14
280A BRAILLE PATTERN DOTS-24
280B BRAILLE PATTERN DOTS-124
280C BRAILLE PATTERN DOTS-34
280D BRAILLE PATTERN DOTS-134
280E BRAILLE PATTERN DOTS-234
280F BRAILLE PATTERN DOTS-1234
2810 BRAILLE PATTERN DOTS-5
2811 BRAILLE PATTERN DOTS-15
2812 BRAILLE PATTERN DOTS-25
2813 BRAILLE PATTERN DOTS-125
2814 BRAILLE PATTERN DOTS-35
2815 BRAILLE PATTERN DOTS-135
2816 BRAILLE PATTERN DOTS-235
2817 BRAILLE PATTERN DOTS-1235
2818 BRAILLE PATTERN DOTS-45
2819 BRAILLE PATTERN DOTS-145
281A BRAILLE PATTERN DOTS-245
281B BRAILLE PATTERN DOTS-1245
281C BRAILLE PATTERN DOTS-345
281D BRAILLE PATTERN DOTS-1345
281E BRAILLE PATTERN DOTS-2345
281F BRAILLE PATTERN DOTS-12345
2820 BRAILLE PATTERN DOTS-6
2821 BRAILLE PATTERN DOTS-16
2822 BRAILLE PATTERN DOTS-26
2823 BRAILLE PATTERN DOTS-126
2824 BRAILLE PATTERN DOTS-36
2825 BRAILLE PATTERN DOTS-136
2826 BRAILLE PATTERN DOTS-236
2827 BRAILLE PATTERN DOTS-1236
2828 BRAILLE PATTERN DOTS-46
2829 BRAILLE PATTERN DOTS-146
282A BRAILLE PATTERN DOTS-246
282B BRAILLE PATTERN DOTS-1246
282C BRAILLE PATTERN DOTS-346
282D BRAILLE PATTERN DOTS-1346
282E BRAILLE PATTERN DOTS-2346
282F BRAILLE PATTERN DOTS-12346
2830 BRAILLE PATTERN DOTS-56
2831 BRAILLE PATTERN DOTS-156
2832 BRAILLE PATTERN DOTS-256
2833 BRAILLE PATTERN DOTS-1256
2834 BRAILLE PATTERN DOTS-356
2835 BRAILLE PATTERN DOTS-1356
2836 BRAILLE PATTERN DOTS-2356
2837 BRAILLE PATTERN DOTS-12356
2838 BRAILLE PATTERN DOTS-456
2839 BRAILLE PATTERN DOTS-1456
283A BRAILLE PATTERN DOTS-2456
283B BRAILLE PATTERN DOTS-12456
283C BRAILLE PATTERN DOTS-3456
283D BRAILLE PATTERN DOTS-13456
283E BRAILLE PATTERN DOTS-23456
283F BRAILLE PATTERN DOTS-123456
2840 BRAILLE PATTERN DOTS-7
2841 BRAILLE PATTERN DOTS-17
2842 BRAILLE PATTERN DOTS-27
2843 BRAILLE PATTERN DOTS-127
2844 BRAILLE PATTERN DOTS-37
2845 BRAILLE PATTERN DOTS-137
2846 BRAILLE PATTERN DOTS-237
2847 BRAILLE PATTERN DOTS-1237
2848 BRAILLE PATTERN DOTS-47
2849 BRAILLE PATTERN DOTS-147
284A BRAILLE PATTERN DOTS-247
284B BRAILLE PATTERN DOTS-1247
284C BRAILLE PATTERN DOTS-347
284D BRAILLE PATTERN DOTS-1347
284E BRAILLE PATTERN DOTS-2347
284F BRAILLE PATTERN DOTS-12347
2850 BRAILLE PATTERN DOTS-57
2851 BRAILLE PATTERN DOTS-157
2852 BRAILLE PATTERN DOTS-257
2853 BRAILLE PATTERN DOTS-1257
2854 BRAILLE PATTERN DOTS-357
2855 BRAILLE PATTERN DOTS-1357
2856 BRAILLE PATTERN DOTS-2357
2857 BRAILLE PATTERN DOTS-12357
2858 BRAILLE PATTERN DOTS-457
2859 BRAILLE PATTERN DOTS-1457
285A BRAILLE PATTERN DOTS-2457
285B BRAILLE PATTERN DOTS-12457
285C BRAILLE PATTERN DOTS-3457
285D BRAILLE PATTERN DOTS-13457
285E BRAILLE PATTERN DOTS-23457
285F BRAILLE PATTERN DOTS-123457
2860 BRAILLE PATTERN DOTS-67
2861 BRAILLE PATTERN DOTS-167
2862 BRAILLE PATTERN DOTS-267
2863 BRAILLE PATTERN DOTS-1267
2864 BRAILLE PATTERN DOTS-367
2865 BRAILLE PATTERN DOTS-1367
2866 BRAILLE PATTERN DOTS-2367
2867 BRAILLE PATTERN DOTS-12367
2868 BRAILLE PATTERN DOTS-467
2869 BRAILLE PATTERN DOTS-1467
286A BRAILLE PATTERN DOTS-2467
286B BRAILLE PATTERN DOTS-12467
286C BRAILLE PATTERN DOTS-3467
286D BRAILLE PATTERN DOTS-13467
286E BRAILLE PATTERN DOTS-23467
286F BRAILLE PATTERN DOTS-123467
2870 BRAILLE PATTERN DOTS-567
2871 BRAILLE PATTERN DOTS-1567
2872 BRAILLE PATTERN DOTS-2567
2873 BRAILLE PATTERN DOTS-12567
2874 BRAILLE PATTERN DOTS-3567
2875 BRAILLE PATTERN DOTS-13567
2876 BRAILLE PATTERN DOTS-23567
2877 BRAILLE PATTERN DOTS-123567
2878 BRAILLE PATTERN DOTS-4567
2879 BRAILLE PATTERN DOTS-14567
287A BRAILLE PATTERN DOTS-24567
287B BRAILLE PATTERN DOTS-124567
287C BRAILLE PATTERN DOTS-34567
287D BRAILLE PATTERN DOTS-134567
287E BRAILLE PATTERN DOTS-234567
287F BRAILLE PATTERN DOTS-1234567
2880 BRAILLE PATTERN DOTS-8
2881 BRAILLE PATTERN DOTS-18
2882 BRAILLE PATTERN DOTS-28
2883 BRAILLE PATTERN DOTS-128
2884 BRAILLE PATTERN DOTS-38
2885 BRAILLE PATTERN DOTS-138
2886 BRAILLE PATTERN DOTS-238
2887 BRAILLE PATTERN DOTS-1238
2888 BRAILLE PATTERN DOTS-48
2889 BRAILLE PATTERN DOTS-148
288A BRAILLE PATTERN DOTS-248
288B BRAILLE PATTERN DOTS-1248
288C BRAILLE PATTERN DOTS-348
288D BRAILLE PATTERN DOTS-1348
288E BRAILLE PATTERN DOTS-2348
288F BRAILLE PATTERN DOTS-12348
2890 BRAILLE PATTERN DOTS-58
2891 BRAILLE PATTERN DOTS-158
2892 BRAILLE PATTERN DOTS-258
2893 BRAILLE PATTERN DOTS-1258
2894 BRAILLE PATTERN DOTS-358
2895 BRAILLE PATTERN DOTS-1358
2896 BRAILLE PATTERN DOTS-2358
2897 BRAILLE PATTERN DOTS-12358
2898 BRAILLE PATTERN DOTS-458
2899 BRAILLE PATTERN DOTS-1458
289A BRAILLE PATTERN DOTS-2458
289B BRAILLE PATTERN DOTS-12458
289C BRAILLE PATTERN DOTS-3458
289D BRAILLE PATTERN DOTS-13458
289E BRAILLE PATTERN DOTS-23458
289F BRAILLE PATTERN DOTS-123458
28A0 BRAILLE PATTERN DOTS-68
28A1 BRAILLE PATTERN DOTS-168
28A2 BRAILLE PATTERN DOTS-268
28A3 BRAILLE PATTERN DOTS-1268
28A4 BRAILLE PATTERN DOTS-368
28A5 BRAILLE PATTERN DOTS-1368
28A6 BRAILLE PATTERN DOTS-2368
28A7 BRAILLE PATTERN DOTS-12368
28A8 BRAILLE PATTERN DOTS-468
28A9 BRAILLE PATTERN DOTS-1468
28AA BRAILLE PATTERN DOTS-2468
28AB BRAILLE PATTERN DOTS-12468
28AC BRAILLE PATTERN DOTS-3468
28AD BRAILLE PATTERN DOTS-13468
28AE BRAILLE PATTERN DOTS-23468
28AF BRAILLE PATTERN DOTS-123468
28B0 BRAILLE PATTERN DOTS-568
28B1 BRAILLE PATTERN DOTS-1568
28B2 BRAILLE PATTERN DOTS-2568
28B3 BRAILLE PATTERN DOTS-12568
28B4 BRAILLE PATTERN DOTS-3568
28B5 BRAILLE PATTERN DOTS-13568
28B6 BRAILLE PATTERN DOTS-23568
28B7 BRAILLE PATTERN DOTS-123568
28B8 BRAILLE PATTERN DOTS-4568
28B9 BRAILLE PATTERN DOTS-14568
28BA BRAILLE PATTERN DOTS-24568
28BB BRAILLE PATTERN DOTS-124568
28BC BRAILLE PATTERN DOTS-34568
28BD BRAILLE PATTERN DOTS-134568
28BE BRAILLE PATTERN DOTS-234568
28BF BRAILLE PATTERN DOTS-1234568
28C0 BRAILLE PATTERN DOTS-78
28C1 BRAILLE PATTERN DOTS-178
28C2 BRAILLE PATTERN DOTS-278
28C3 BRAILLE PATTERN DOTS-1278
28C4 BRAILLE PATTERN DOTS-378
28C5 BRAILLE PATTERN DOTS-1378
28C6 BRAILLE PATTERN DOTS-2378
28C7 BRAILLE PATTERN DOTS-12378
28C8 BRAILLE PATTERN DOTS-478
28C9 BRAILLE PATTERN DOTS-1478
28CA BRAILLE PATTERN DOTS-2478
28CB BRAILLE PATTERN DOTS-12478
28CC BRAILLE PATTERN DOTS-3478
28CD BRAILLE PATTERN DOTS-13478
28CE BRAILLE PATTERN DOTS-23478
28CF BRAILLE PATTERN DOTS-123478
28D0 BRAILLE PATTERN DOTS-578
28D1 BRAILLE PATTERN DOTS-1578
28D2 BRAILLE PATTERN DOTS-2578
28D3 BRAILLE PATTERN DOTS-12578
28D4 BRAILLE PATTERN DOTS-3578
28D5 BRAILLE PATTERN DOTS-13578
28D6 BRAILLE PATTERN DOTS-23578
28D7 BRAILLE PATTERN DOTS-123578
28D8 BRAILLE PATTERN DOTS-4578
28D9 BRAILLE PATTERN DOTS-14578
28DA BRAILLE PATTERN DOTS-24578
28DB BRAILLE PATTERN DOTS-124578
28DC BRAILLE PATTERN DOTS-34578
28DD BRAILLE PATTERN DOTS-134578
28DE BRAILLE PATTERN DOTS-234578
28DF BRAILLE PATTERN DOTS-1234578
28E0 BRAILLE PATTERN DOTS-678
28E1 BRAILLE PATTERN DOTS-1678
28E2 BRAILLE PATTERN DOTS-2678
28E3 BRAILLE PATTERN DOTS-12678
28E4 BRAILLE PATTERN DOTS-3678
28E5 BRAILLE PATTERN DOTS-13678
28E6 BRAILLE PATTERN DOTS-23678
28E7 BRAILLE PATTERN DOTS-123678
28E8 BRAILLE PATTERN DOTS-4678
28E9 BRAILLE PATTERN DOTS-14678
28EA BRAILLE PATTERN DOTS-24678
28EB BRAILLE PATTERN DOTS-124678
28EC BRAILLE PATTERN DOTS-34678
28ED BRAILLE PATTERN DOTS-134678
28EE BRAILLE PATTERN DOTS-234678
28EF BRAILLE PATTERN DOTS-1234678
28F0 BRAILLE PATTERN DOTS-5678
28F1 BRAILLE PATTERN DOTS-15678
28F2 BRAILLE PATTERN DOTS-25678
28F3 BRAILLE PATTERN DOTS-125678
28F4 BRAILLE PATTERN DOTS-35678
28F5 BRAILLE PATTERN DOTS-135678
28F6 BRAILLE PATTERN DOTS-235678
28F7 BRAILLE PATTERN DOTS-1235678
28F8 BRAILLE PATTERN DOTS-45678
28F9 BRAILLE PATTERN DOTS-145678
28FA BRAILLE PATTERN DOTS-245678
28FB BRAILLE PATTERN DOTS-1245678
28FC BRAILLE PATTERN DOTS-345678
28FD BRAILLE PATTERN DOTS-1345678
28FE BRAILLE PATTERN DOTS-2345678
28FF BRAILLE PATTERN DOTS-12345678
2900 RIGHTWARDS TWO-HEADED ARROW WITH VERTICAL STROKE
2901 RIGHTWARDS TWO-HEADED ARROW WITH DOUBLE VERTICAL STROKE
2902 LEFTWARDS DOUBLE ARROW WITH VERTICAL STROKE
2903 RIGHTWARDS DOUBLE ARROW WITH VERTICAL STROKE
2904 LEFT RIGHT DOUBLE ARROW WITH VERTICAL STROKE
2905 RIGHTWARDS TWO-HEADED ARROW FROM BAR
2906 LEFTWARDS DOUBLE ARROW FROM BAR
2907 RIGHTWARDS DOUBLE ARROW FROM BAR
2908 DOWNWARDS ARROW WITH HORIZONTAL STROKE
2909 UPWARDS ARROW WITH HORIZONTAL STROKE
290A UPWARDS TRIPLE ARROW
290B DOWNWARDS TRIPLE ARROW
290C LEFTWARDS DOUBLE DASH ARROW
290D RIGHTWARDS DOUBLE DASH ARROW
290E LEFTWARDS TRIPLE DASH ARROW
290F RIGHTWARDS TRIPLE DASH ARROW
2910 RIGHTWARDS TWO-HEADED TRIPLE DASH ARROW
2911 RIGHTWARDS ARROW WITH DOTTED STEM
2912 UPWARDS ARROW TO BAR
2913 DOWNWARDS ARROW TO BAR
2914 RIGHTWARDS ARROW WITH TAIL WITH VERTICAL STROKE
2915 RIGHTWARDS ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE
2916 RIGHTWARDS TWO-HEADED ARROW WITH TAIL
2917 RIGHTWARDS TWO-HEADED ARROW WITH TAIL WITH VERTICAL STROKE
2918 RIGHTWARDS TWO-HEADED ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE
2919 LEFTWARDS ARROW-TAIL
291A RIGHTWARDS ARROW-TAIL
291B LEFTWARDS DOUBLE ARROW-TAIL
291C RIGHTWARDS DOUBLE ARROW-TAIL
291D LEFTWARDS ARROW TO BLACK DIAMOND
291E RIGHTWARDS ARROW TO BLACK DIAMOND
291F LEFTWARDS ARROW FROM BAR TO BLACK DIAMOND
2920 RIGHTWARDS ARROW FROM BAR TO BLACK DIAMOND
2921 NORTH WEST AND SOUTH EAST ARROW
2922 NORTH EAST AND SOUTH WEST ARROW
2923 NORTH WEST ARROW WITH HOOK
2924 NORTH EAST ARROW WITH HOOK
2925 SOUTH EAST ARROW WITH HOOK
2926 SOUTH WEST ARROW WITH HOOK
2927 NORTH WEST ARROW AND NORTH EAST ARROW
2928 NORTH EAST ARROW AND SOUTH EAST ARROW
2929 SOUTH EAST ARROW AND SOUTH WEST ARROW
292A SOUTH WEST ARROW AND NORTH WEST ARROW
292B RISING DIAGONAL CROSSING FALLING DIAGONAL
292C FALLING DIAGONAL CROSSING RISING DIAGONAL
292D SOUTH EAST ARROW CROSSING NORTH EAST ARROW
292E NORTH EAST ARROW CROSSING SOUTH EAST ARROW
292F FALLING DIAGONAL CROSSING NORTH EAST ARROW
2930 RISING DIAGONAL CROSSING SOUTH EAST ARROW
2931 NORTH EAST ARROW CROSSING NORTH WEST ARROW
2932 NORTH WEST ARROW CROSSING NORTH EAST ARROW
2933 WAVE ARROW POINTING DIRECTLY RIGHT
2934 ARROW POINTING RIGHTWARDS THEN CURVING UPWARDS
2935 ARROW POINTING RIGHTWARDS THEN CURVING DOWNWARDS
2936 ARROW POINTING DOWNWARDS THEN CURVING LEFTWARDS
2937 ARROW POINTING DOWNWARDS THEN CURVING RIGHTWARDS
2938 RIGHT-SIDE ARC CLOCKWISE ARROW
2939 LEFT-SIDE ARC ANTICLOCKWISE ARROW
293A TOP ARC ANTICLOCKWISE ARROW
293B BOTTOM ARC ANTICLOCKWISE ARROW
293C TOP ARC CLOCKWISE ARROW WITH MINUS
293D TOP ARC ANTICLOCKWISE ARROW WITH PLUS
293E LOWER RIGHT SEMICIRCULAR CLOCKWISE ARROW
293F LOWER LEFT SEMICIRCULAR ANTICLOCKWISE ARROW
2940 ANTICLOCKWISE CLOSED CIRCLE ARROW
2941 CLOCKWISE CLOSED CIRCLE ARROW
2942 RIGHTWARDS ARROW ABOVE SHORT LEFTWARDS ARROW
2943 LEFTWARDS ARROW ABOVE SHORT RIGHTWARDS ARROW
2944 SHORT RIGHTWARDS ARROW ABOVE LEFTWARDS ARROW
2945 RIGHTWARDS ARROW WITH PLUS BELOW
2946 LEFTWARDS ARROW WITH PLUS BELOW
2947 RIGHTWARDS ARROW THROUGH X
2948 LEFT RIGHT ARROW THROUGH SMALL CIRCLE
2949 UPWARDS TWO-HEADED ARROW FROM SMALL CIRCLE
294A LEFT BARB UP RIGHT BARB DOWN HARPOON
294B LEFT BARB DOWN RIGHT BARB UP HARPOON
294C UP BARB RIGHT DOWN BARB LEFT HARPOON
294D UP BARB LEFT DOWN BARB RIGHT HARPOON
294E LEFT BARB UP RIGHT BARB UP HARPOON
294F UP BARB RIGHT DOWN BARB RIGHT HARPOON
2950 LEFT BARB DOWN RIGHT BARB DOWN HARPOON
2951 UP BARB LEFT DOWN BARB LEFT HARPOON
2952 LEFTWARDS HARPOON WITH BARB UP TO BAR
2953 RIGHTWARDS HARPOON WITH BARB UP TO BAR
2954 UPWARDS HARPOON WITH BARB RIGHT TO BAR
2955 DOWNWARDS HARPOON WITH BARB RIGHT TO BAR
2956 LEFTWARDS HARPOON WITH BARB DOWN TO BAR
2957 RIGHTWARDS HARPOON WITH BARB DOWN TO BAR
2958 UPWARDS HARPOON WITH BARB LEFT TO BAR
2959 DOWNWARDS HARPOON WITH BARB LEFT TO BAR
295A LEFTWARDS HARPOON WITH BARB UP FROM BAR
295B RIGHTWARDS HARPOON WITH BARB UP FROM BAR
295C UPWARDS HARPOON WITH BARB RIGHT FROM BAR
295D DOWNWARDS HARPOON WITH BARB RIGHT FROM BAR
295E LEFTWARDS HARPOON WITH BARB DOWN FROM BAR
295F RIGHTWARDS HARPOON WITH BARB DOWN FROM BAR
2960 UPWARDS HARPOON WITH BARB LEFT FROM BAR
2961 DOWNWARDS HARPOON WITH BARB LEFT FROM BAR
2962 LEFTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB DOWN
2963 UPWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT
2964 RIGHTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB DOWN
2965 DOWNWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT
2966 LEFTWARDS HARPOON WITH BARB UP ABOVE RIGHTWARDS HARPOON WITH BARB UP
2967 LEFTWARDS HARPOON WITH BARB DOWN ABOVE RIGHTWARDS HARPOON WITH BARB DOWN
2968 RIGHTWARDS HARPOON WITH BARB UP ABOVE LEFTWARDS HARPOON WITH BARB UP
2969 RIGHTWARDS HARPOON WITH BARB DOWN ABOVE LEFTWARDS HARPOON WITH BARB DOWN
296A LEFTWARDS HARPOON WITH BARB UP ABOVE LONG DASH
296B LEFTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH
296C RIGHTWARDS HARPOON WITH BARB UP ABOVE LONG DASH
296D RIGHTWARDS HARPOON WITH BARB DOWN BELOW LONG DASH
296E UPWARDS HARPOON WITH BARB LEFT BESIDE DOWNWARDS HARPOON WITH BARB RIGHT
296F DOWNWARDS HARPOON WITH BARB LEFT BESIDE UPWARDS HARPOON WITH BARB RIGHT
2970 RIGHT DOUBLE ARROW WITH ROUNDED HEAD
2971 EQUALS SIGN ABOVE RIGHTWARDS ARROW
2972 TILDE OPERATOR ABOVE RIGHTWARDS ARROW
2973 LEFTWARDS ARROW ABOVE TILDE OPERATOR
2974 RIGHTWARDS ARROW ABOVE TILDE OPERATOR
2975 RIGHTWARDS ARROW ABOVE ALMOST EQUAL TO
2976 LESS-THAN ABOVE LEFTWARDS ARROW
2977 LEFTWARDS ARROW THROUGH LESS-THAN
2978 GREATER-THAN ABOVE RIGHTWARDS ARROW
2979 SUBSET ABOVE RIGHTWARDS ARROW
297A LEFTWARDS ARROW THROUGH SUBSET
297B SUPERSET ABOVE LEFTWARDS ARROW
297C LEFT FISH TAIL
297D RIGHT FISH TAIL
297E UP FISH TAIL
297F DOWN FISH TAIL
2980 TRIPLE VERTICAL BAR DELIMITER
2981 Z NOTATION SPOT
2982 Z NOTATION TYPE COLON
2983 LEFT WHITE CURLY BRACKET
2984 RIGHT WHITE CURLY BRACKET
2985 LEFT WHITE PARENTHESIS
2986 RIGHT WHITE PARENTHESIS
2987 Z NOTATION LEFT IMAGE BRACKET
2988 Z NOTATION RIGHT IMAGE BRACKET
2989 Z NOTATION LEFT BINDING BRACKET
298A Z NOTATION RIGHT BINDING BRACKET
298B LEFT SQUARE BRACKET WITH UNDERBAR
298C RIGHT SQUARE BRACKET WITH UNDERBAR
298D LEFT SQUARE BRACKET WITH TICK IN TOP CORNER
298E RIGHT SQUARE BRACKET WITH TICK IN BOTTOM CORNER
298F LEFT SQUARE BRACKET WITH TICK IN BOTTOM CORNER
2990 RIGHT SQUARE BRACKET WITH TICK IN TOP CORNER
2991 LEFT ANGLE BRACKET WITH DOT
2992 RIGHT ANGLE BRACKET WITH DOT
2993 LEFT ARC LESS-THAN BRACKET
2994 RIGHT ARC GREATER-THAN BRACKET
2995 DOUBLE LEFT ARC GREATER-THAN BRACKET
2996 DOUBLE RIGHT ARC LESS-THAN BRACKET
2997 LEFT BLACK TORTOISE SHELL BRACKET
2998 RIGHT BLACK TORTOISE SHELL BRACKET
2999 DOTTED FENCE
299A VERTICAL ZIGZAG LINE
299B MEASURED ANGLE OPENING LEFT
299C RIGHT ANGLE VARIANT WITH SQUARE
299D MEASURED RIGHT ANGLE WITH DOT
299E ANGLE WITH S INSIDE
299F ACUTE ANGLE
29A0 SPHERICAL ANGLE OPENING LEFT
29A1 SPHERICAL ANGLE OPENING UP
29A2 TURNED ANGLE
29A3 REVERSED ANGLE
29A4 ANGLE WITH UNDERBAR
29A5 REVERSED ANGLE WITH UNDERBAR
29A6 OBLIQUE ANGLE OPENING UP
29A7 OBLIQUE ANGLE OPENING DOWN
29A8 MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND RIGHT
29A9 MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING UP AND LEFT
29AA MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND RIGHT
29AB MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING DOWN AND LEFT
29AC MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND UP
29AD MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND UP
29AE MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING RIGHT AND DOWN
29AF MEASURED ANGLE WITH OPEN ARM ENDING IN ARROW POINTING LEFT AND DOWN
29B0 REVERSED EMPTY SET
29B1 EMPTY SET WITH OVERBAR
29B2 EMPTY SET WITH SMALL CIRCLE ABOVE
29B3 EMPTY SET WITH RIGHT ARROW ABOVE
29B4 EMPTY SET WITH LEFT ARROW ABOVE
29B5 CIRCLE WITH HORIZONTAL BAR
29B6 CIRCLED VERTICAL BAR
29B7 CIRCLED PARALLEL
29B8 CIRCLED REVERSE SOLIDUS
29B9 CIRCLED PERPENDICULAR
29BA CIRCLE DIVIDED BY HORIZONTAL BAR AND TOP HALF DIVIDED BY VERTICAL BAR
29BB CIRCLE WITH SUPERIMPOSED X
29BC CIRCLED ANTICLOCKWISE-ROTATED DIVISION SIGN
29BD UP ARROW THROUGH CIRCLE
29BE CIRCLED WHITE BULLET
29BF CIRCLED BULLET
29C0 CIRCLED LESS-THAN
29C1 CIRCLED GREATER-THAN
29C2 CIRCLE WITH SMALL CIRCLE TO THE RIGHT
29C3 CIRCLE WITH TWO HORIZONTAL STROKES TO THE RIGHT
29C4 SQUARED RISING DIAGONAL SLASH
29C5 SQUARED FALLING DIAGONAL SLASH
29C6 SQUARED ASTERISK
29C7 SQUARED SMALL CIRCLE
29C8 SQUARED SQUARE
29C9 TWO JOINED SQUARES
29CA TRIANGLE WITH DOT ABOVE
29CB TRIANGLE WITH UNDERBAR
29CC S IN TRIANGLE
29CD TRIANGLE WITH SERIFS AT BOTTOM
29CE RIGHT TRIANGLE ABOVE LEFT TRIANGLE
29CF LEFT TRIANGLE BESIDE VERTICAL BAR
29D0 VERTICAL BAR BESIDE RIGHT TRIANGLE
29D1 BOWTIE WITH LEFT HALF BLACK
29D2 BOWTIE WITH RIGHT HALF BLACK
29D3 BLACK BOWTIE
29D4 TIMES WITH LEFT HALF BLACK
29D5 TIMES WITH RIGHT HALF BLACK
29D6 WHITE HOURGLASS
29D7 BLACK HOURGLASS
29D8 LEFT WIGGLY FENCE
29D9 RIGHT WIGGLY FENCE
29DA LEFT DOUBLE WIGGLY FENCE
29DB RIGHT DOUBLE WIGGLY FENCE
29DC INCOMPLETE INFINITY
29DD TIE OVER INFINITY
29DE INFINITY NEGATED WITH VERTICAL BAR
29DF DOUBLE-ENDED MULTIMAP
29E0 SQUARE WITH CONTOURED OUTLINE
29E1 INCREASES AS
29E2 SHUFFLE PRODUCT
29E3 EQUALS SIGN AND SLANTED PARALLEL
29E4 EQUALS SIGN AND SLANTED PARALLEL WITH TILDE ABOVE
29E5 IDENTICAL TO AND SLANTED PARALLEL
29E6 GLEICH STARK
29E7 THERMODYNAMIC
29E8 DOWN-POINTING TRIANGLE WITH LEFT HALF BLACK
29E9 DOWN-POINTING TRIANGLE WITH RIGHT HALF BLACK
29EA BLACK DIAMOND WITH DOWN ARROW
29EB BLACK LOZENGE
29EC WHITE CIRCLE WITH DOWN ARROW
29ED BLACK CIRCLE WITH DOWN ARROW
29EE ERROR-BARRED WHITE SQUARE
29EF ERROR-BARRED BLACK SQUARE
29F0 ERROR-BARRED WHITE DIAMOND
29F1 ERROR-BARRED BLACK DIAMOND
29F2 ERROR-BARRED WHITE CIRCLE
29F3 ERROR-BARRED BLACK CIRCLE
29F4 RULE-DELAYED
29F5 REVERSE SOLIDUS OPERATOR
29F6 SOLIDUS WITH OVERBAR
29F7 REVERSE SOLIDUS WITH HORIZONTAL STROKE
29F8 BIG SOLIDUS
29F9 BIG REVERSE SOLIDUS
29FA DOUBLE PLUS
29FB TRIPLE PLUS
29FC LEFT-POINTING CURVED ANGLE BRACKET
29FD RIGHT-POINTING CURVED ANGLE BRACKET
29FE TINY
29FF MINY
2A00 N-ARY CIRCLED DOT OPERATOR
2A01 N-ARY CIRCLED PLUS OPERATOR
2A02 N-ARY CIRCLED TIMES OPERATOR
2A03 N-ARY UNION OPERATOR WITH DOT
2A04 N-ARY UNION OPERATOR WITH PLUS
2A05 N-ARY SQUARE INTERSECTION OPERATOR
2A06 N-ARY SQUARE UNION OPERATOR
2A07 TWO LOGICAL AND OPERATOR
2A08 TWO LOGICAL OR OPERATOR
2A09 N-ARY TIMES OPERATOR
2A0A MODULO TWO SUM
2A0B SUMMATION WITH INTEGRAL
2A0C QUADRUPLE INTEGRAL OPERATOR
2A0D FINITE PART INTEGRAL
2A0E INTEGRAL WITH DOUBLE STROKE
2A0F INTEGRAL AVERAGE WITH SLASH
2A10 CIRCULATION FUNCTION
2A11 ANTICLOCKWISE INTEGRATION
2A12 LINE INTEGRATION WITH RECTANGULAR PATH AROUND POLE
2A13 LINE INTEGRATION WITH SEMICIRCULAR PATH AROUND POLE
2A14 LINE INTEGRATION NOT INCLUDING THE POLE
2A15 INTEGRAL AROUND A POINT OPERATOR
2A16 QUATERNION INTEGRAL OPERATOR
2A17 INTEGRAL WITH LEFTWARDS ARROW WITH HOOK
2A18 INTEGRAL WITH TIMES SIGN
2A19 INTEGRAL WITH INTERSECTION
2A1A INTEGRAL WITH UNION
2A1B INTEGRAL WITH OVERBAR
2A1C INTEGRAL WITH UNDERBAR
2A1D JOIN
2A1E LARGE LEFT TRIANGLE OPERATOR
2A1F Z NOTATION SCHEMA COMPOSITION
2A20 Z NOTATION SCHEMA PIPING
2A21 Z NOTATION SCHEMA PROJECTION
2A22 PLUS SIGN WITH SMALL CIRCLE ABOVE
2A23 PLUS SIGN WITH CIRCUMFLEX ACCENT ABOVE
2A24 PLUS SIGN WITH TILDE ABOVE
2A25 PLUS SIGN WITH DOT BELOW
2A26 PLUS SIGN WITH TILDE BELOW
2A27 PLUS SIGN WITH SUBSCRIPT TWO
2A28 PLUS SIGN WITH BLACK TRIANGLE
2A29 MINUS SIGN WITH COMMA ABOVE
2A2A MINUS SIGN WITH DOT BELOW
2A2B MINUS SIGN WITH FALLING DOTS
2A2C MINUS SIGN WITH RISING DOTS
2A2D PLUS SIGN IN LEFT HALF CIRCLE
2A2E PLUS SIGN IN RIGHT HALF CIRCLE
2A2F VECTOR OR CROSS PRODUCT
2A30 MULTIPLICATION SIGN WITH DOT ABOVE
2A31 MULTIPLICATION SIGN WITH UNDERBAR
2A32 SEMIDIRECT PRODUCT WITH BOTTOM CLOSED
2A33 SMASH PRODUCT
2A34 MULTIPLICATION SIGN IN LEFT HALF CIRCLE
2A35 MULTIPLICATION SIGN IN RIGHT HALF CIRCLE
2A36 CIRCLED MULTIPLICATION SIGN WITH CIRCUMFLEX ACCENT
2A37 MULTIPLICATION SIGN IN DOUBLE CIRCLE
2A38 CIRCLED DIVISION SIGN
2A39 PLUS SIGN IN TRIANGLE
2A3A MINUS SIGN IN TRIANGLE
2A3B MULTIPLICATION SIGN IN TRIANGLE
2A3C INTERIOR PRODUCT
2A3D RIGHTHAND INTERIOR PRODUCT
2A3E Z NOTATION RELATIONAL COMPOSITION
2A3F AMALGAMATION OR COPRODUCT
2A40 INTERSECTION WITH DOT
2A41 UNION WITH MINUS SIGN
2A42 UNION WITH OVERBAR
2A43 INTERSECTION WITH OVERBAR
2A44 INTERSECTION WITH LOGICAL AND
2A45 UNION WITH LOGICAL OR
2A46 UNION ABOVE INTERSECTION
2A47 INTERSECTION ABOVE UNION
2A48 UNION ABOVE BAR ABOVE INTERSECTION
2A49 INTERSECTION ABOVE BAR ABOVE UNION
2A4A UNION BESIDE AND JOINED WITH UNION
2A4B INTERSECTION BESIDE AND JOINED WITH INTERSECTION
2A4C CLOSED UNION WITH SERIFS
2A4D CLOSED INTERSECTION WITH SERIFS
2A4E DOUBLE SQUARE INTERSECTION
2A4F DOUBLE SQUARE UNION
2A50 CLOSED UNION WITH SERIFS AND SMASH PRODUCT
2A51 LOGICAL AND WITH DOT ABOVE
2A52 LOGICAL OR WITH DOT ABOVE
2A53 DOUBLE LOGICAL AND
2A54 DOUBLE LOGICAL OR
2A55 TWO INTERSECTING LOGICAL AND
2A56 TWO INTERSECTING LOGICAL OR
2A57 SLOPING LARGE OR
2A58 SLOPING LARGE AND
2A59 LOGICAL OR OVERLAPPING LOGICAL AND
2A5A LOGICAL AND WITH MIDDLE STEM
2A5B LOGICAL OR WITH MIDDLE STEM
2A5C LOGICAL AND WITH HORIZONTAL DASH
2A5D LOGICAL OR WITH HORIZONTAL DASH
2A5E LOGICAL AND WITH DOUBLE OVERBAR
2A5F LOGICAL AND WITH UNDERBAR
2A60 LOGICAL AND WITH DOUBLE UNDERBAR
2A61 SMALL VEE WITH UNDERBAR
2A62 LOGICAL OR WITH DOUBLE OVERBAR
2A63 LOGICAL OR WITH DOUBLE UNDERBAR
2A64 Z NOTATION DOMAIN ANTIRESTRICTION
2A65 Z NOTATION RANGE ANTIRESTRICTION
2A66 EQUALS SIGN WITH DOT BELOW
2A67 IDENTICAL WITH DOT ABOVE
2A68 TRIPLE HORIZONTAL BAR WITH DOUBLE VERTICAL STROKE
2A69 TRIPLE HORIZONTAL BAR WITH TRIPLE VERTICAL STROKE
2A6A TILDE OPERATOR WITH DOT ABOVE
2A6B TILDE OPERATOR WITH RISING DOTS
2A6C SIMILAR MINUS SIMILAR
2A6D CONGRUENT WITH DOT ABOVE
2A6E EQUALS WITH ASTERISK
2A6F ALMOST EQUAL TO WITH CIRCUMFLEX ACCENT
2A70 APPROXIMATELY EQUAL OR EQUAL TO
2A71 EQUALS SIGN ABOVE PLUS SIGN
2A72 PLUS SIGN ABOVE EQUALS SIGN
2A73 EQUALS SIGN ABOVE TILDE OPERATOR
2A74 DOUBLE COLON EQUAL
2A75 TWO CONSECUTIVE EQUALS SIGNS
2A76 THREE CONSECUTIVE EQUALS SIGNS
2A77 EQUALS SIGN WITH TWO DOTS ABOVE AND TWO DOTS BELOW
2A78 EQUIVALENT WITH FOUR DOTS ABOVE
2A79 LESS-THAN WITH CIRCLE INSIDE
2A7A GREATER-THAN WITH CIRCLE INSIDE
2A7B LESS-THAN WITH QUESTION MARK ABOVE
2A7C GREATER-THAN WITH QUESTION MARK ABOVE
2A7D LESS-THAN OR SLANTED EQUAL TO
2A7E GREATER-THAN OR SLANTED EQUAL TO
2A7F LESS-THAN OR SLANTED EQUAL TO WITH DOT INSIDE
2A80 GREATER-THAN OR SLANTED EQUAL TO WITH DOT INSIDE
2A81 LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE
2A82 GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE
2A83 LESS-THAN OR SLANTED EQUAL TO WITH DOT ABOVE RIGHT
2A84 GREATER-THAN OR SLANTED EQUAL TO WITH DOT ABOVE LEFT
2A85 LESS-THAN OR APPROXIMATE
2A86 GREATER-THAN OR APPROXIMATE
2A87 LESS-THAN AND SINGLE-LINE NOT EQUAL TO
2A88 GREATER-THAN AND SINGLE-LINE NOT EQUAL TO
2A89 LESS-THAN AND NOT APPROXIMATE
2A8A GREATER-THAN AND NOT APPROXIMATE
2A8B LESS-THAN ABOVE DOUBLE-LINE EQUAL ABOVE GREATER-THAN
2A8C GREATER-THAN ABOVE DOUBLE-LINE EQUAL ABOVE LESS-THAN
2A8D LESS-THAN ABOVE SIMILAR OR EQUAL
2A8E GREATER-THAN ABOVE SIMILAR OR EQUAL
2A8F LESS-THAN ABOVE SIMILAR ABOVE GREATER-THAN
2A90 GREATER-THAN ABOVE SIMILAR ABOVE LESS-THAN
2A91 LESS-THAN ABOVE GREATER-THAN ABOVE DOUBLE-LINE EQUAL
2A92 GREATER-THAN ABOVE LESS-THAN ABOVE DOUBLE-LINE EQUAL
2A93 LESS-THAN ABOVE SLANTED EQUAL ABOVE GREATER-THAN ABOVE SLANTED EQUAL
2A94 GREATER-THAN ABOVE SLANTED EQUAL ABOVE LESS-THAN ABOVE SLANTED EQUAL
2A95 SLANTED EQUAL TO OR LESS-THAN
2A96 SLANTED EQUAL TO OR GREATER-THAN
2A97 SLANTED EQUAL TO OR LESS-THAN WITH DOT INSIDE
2A98 SLANTED EQUAL TO OR GREATER-THAN WITH DOT INSIDE
2A99 DOUBLE-LINE EQUAL TO OR LESS-THAN
2A9A DOUBLE-LINE EQUAL TO OR GREATER-THAN
2A9B DOUBLE-LINE SLANTED EQUAL TO OR LESS-THAN
2A9C DOUBLE-LINE SLANTED EQUAL TO OR GREATER-THAN
2A9D SIMILAR OR LESS-THAN
2A9E SIMILAR OR GREATER-THAN
2A9F SIMILAR ABOVE LESS-THAN ABOVE EQUALS SIGN
2AA0 SIMILAR ABOVE GREATER-THAN ABOVE EQUALS SIGN
2AA1 DOUBLE NESTED LESS-THAN
2AA2 DOUBLE NESTED GREATER-THAN
2AA3 DOUBLE NESTED LESS-THAN WITH UNDERBAR
2AA4 GREATER-THAN OVERLAPPING LESS-THAN
2AA5 GREATER-THAN BESIDE LESS-THAN
2AA6 LESS-THAN CLOSED BY CURVE
2AA7 GREATER-THAN CLOSED BY CURVE
2AA8 LESS-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL
2AA9 GREATER-THAN CLOSED BY CURVE ABOVE SLANTED EQUAL
2AAA SMALLER THAN
2AAB LARGER THAN
2AAC SMALLER THAN OR EQUAL TO
2AAD LARGER THAN OR EQUAL TO
2AAE EQUALS SIGN WITH BUMPY ABOVE
2AAF PRECEDES ABOVE SINGLE-LINE EQUALS SIGN
2AB0 SUCCEEDS ABOVE SINGLE-LINE EQUALS SIGN
2AB1 PRECEDES ABOVE SINGLE-LINE NOT EQUAL TO
2AB2 SUCCEEDS ABOVE SINGLE-LINE NOT EQUAL TO
2AB3 PRECEDES ABOVE EQUALS SIGN
2AB4 SUCCEEDS ABOVE EQUALS SIGN
2AB5 PRECEDES ABOVE NOT EQUAL TO
2AB6 SUCCEEDS ABOVE NOT EQUAL TO
2AB7 PRECEDES ABOVE ALMOST EQUAL TO
2AB8 SUCCEEDS ABOVE ALMOST EQUAL TO
2AB9 PRECEDES ABOVE NOT ALMOST EQUAL TO
2ABA SUCCEEDS ABOVE NOT ALMOST EQUAL TO
2ABB DOUBLE PRECEDES
2ABC DOUBLE SUCCEEDS
2ABD SUBSET WITH DOT
2ABE SUPERSET WITH DOT
2ABF SUBSET WITH PLUS SIGN BELOW
2AC0 SUPERSET WITH PLUS SIGN BELOW
2AC1 SUBSET WITH MULTIPLICATION SIGN BELOW
2AC2 SUPERSET WITH MULTIPLICATION SIGN BELOW
2AC3 SUBSET OF OR EQUAL TO WITH DOT ABOVE
2AC4 SUPERSET OF OR EQUAL TO WITH DOT ABOVE
2AC5 SUBSET OF ABOVE EQUALS SIGN
2AC6 SUPERSET OF ABOVE EQUALS SIGN
2AC7 SUBSET OF ABOVE TILDE OPERATOR
2AC8 SUPERSET OF ABOVE TILDE OPERATOR
2AC9 SUBSET OF ABOVE ALMOST EQUAL TO
2ACA SUPERSET OF ABOVE ALMOST EQUAL TO
2ACB SUBSET OF ABOVE NOT EQUAL TO
2ACC SUPERSET OF ABOVE NOT EQUAL TO
2ACD SQUARE LEFT OPEN BOX OPERATOR
2ACE SQUARE RIGHT OPEN BOX OPERATOR
2ACF CLOSED SUBSET
2AD0 CLOSED SUPERSET
2AD1 CLOSED SUBSET OR EQUAL TO
2AD2 CLOSED SUPERSET OR EQUAL TO
2AD3 SUBSET ABOVE SUPERSET
2AD4 SUPERSET ABOVE SUBSET
2AD5 SUBSET ABOVE SUBSET
2AD6 SUPERSET ABOVE SUPERSET
2AD7 SUPERSET BESIDE SUBSET
2AD8 SUPERSET BESIDE AND JOINED BY DASH WITH SUBSET
2AD9 ELEMENT OF OPENING DOWNWARDS
2ADA PITCHFORK WITH TEE TOP
2ADB TRANSVERSAL INTERSECTION
2ADC FORKING
2ADD NONFORKING
2ADE SHORT LEFT TACK
2ADF SHORT DOWN TACK
2AE0 SHORT UP TACK
2AE1 PERPENDICULAR WITH S
2AE2 VERTICAL BAR TRIPLE RIGHT TURNSTILE
2AE3 DOUBLE VERTICAL BAR LEFT TURNSTILE
2AE4 VERTICAL BAR DOUBLE LEFT TURNSTILE
2AE5 DOUBLE VERTICAL BAR DOUBLE LEFT TURNSTILE
2AE6 LONG DASH FROM LEFT MEMBER OF DOUBLE VERTICAL
2AE7 SHORT DOWN TACK WITH OVERBAR
2AE8 SHORT UP TACK WITH UNDERBAR
2AE9 SHORT UP TACK ABOVE SHORT DOWN TACK
2AEA DOUBLE DOWN TACK
2AEB DOUBLE UP TACK
2AEC DOUBLE STROKE NOT SIGN
2AED REVERSED DOUBLE STROKE NOT SIGN
2AEE DOES NOT DIVIDE WITH REVERSED NEGATION SLASH
2AEF VERTICAL LINE WITH CIRCLE ABOVE
2AF0 VERTICAL LINE WITH CIRCLE BELOW
2AF1 DOWN TACK WITH CIRCLE BELOW
2AF2 PARALLEL WITH HORIZONTAL STROKE
2AF3 PARALLEL WITH TILDE OPERATOR
2AF4 TRIPLE VERTICAL BAR BINARY RELATION
2AF5 TRIPLE VERTICAL BAR WITH HORIZONTAL STROKE
2AF6 TRIPLE COLON OPERATOR
2AF7 TRIPLE NESTED LESS-THAN
2AF8 TRIPLE NESTED GREATER-THAN
2AF9 DOUBLE-LINE SLANTED LESS-THAN OR EQUAL TO
2AFA DOUBLE-LINE SLANTED GREATER-THAN OR EQUAL TO
2AFB TRIPLE SOLIDUS BINARY RELATION
2AFC LARGE TRIPLE VERTICAL BAR OPERATOR
2AFD DOUBLE SOLIDUS OPERATOR
2AFE WHITE VERTICAL BAR
2AFF N-ARY WHITE VERTICAL BAR
2B00 NORTH EAST WHITE ARROW
2B01 NORTH WEST WHITE ARROW
2B02 SOUTH EAST WHITE ARROW
2B03 SOUTH WEST WHITE ARROW
2B04 LEFT RIGHT WHITE ARROW
2B05 LEFTWARDS BLACK ARROW
2B06 UPWARDS BLACK ARROW
2B07 DOWNWARDS BLACK ARROW
2B08 NORTH EAST BLACK ARROW
2B09 NORTH WEST BLACK ARROW
2B0A SOUTH EAST BLACK ARROW
2B0B SOUTH WEST BLACK ARROW
2B0C LEFT RIGHT BLACK ARROW
2B0D UP DOWN BLACK ARROW
2B0E RIGHTWARDS ARROW WITH TIP DOWNWARDS
2B0F RIGHTWARDS ARROW WITH TIP UPWARDS
2B10 LEFTWARDS ARROW WITH TIP DOWNWARDS
2B11 LEFTWARDS ARROW WITH TIP UPWARDS
2B12 SQUARE WITH TOP HALF BLACK
2B13 SQUARE WITH BOTTOM HALF BLACK
2B14 SQUARE WITH UPPER RIGHT DIAGONAL HALF BLACK
2B15 SQUARE WITH LOWER LEFT DIAGONAL HALF BLACK
2B16 DIAMOND WITH LEFT HALF BLACK
2B17 DIAMOND WITH RIGHT HALF BLACK
2B18 DIAMOND WITH TOP HALF BLACK
2B19 DIAMOND WITH BOTTOM HALF BLACK
2B1A DOTTED SQUARE
2B1B BLACK LARGE SQUARE
2B1C WHITE LARGE SQUARE
2B1D BLACK VERY SMALL SQUARE
2B1E WHITE VERY SMALL SQUARE
2B1F BLACK PENTAGON
2B20 WHITE PENTAGON
2B21 WHITE HEXAGON
2B22 BLACK HEXAGON
2B23 HORIZONTAL BLACK HEXAGON
2B24 BLACK LARGE CIRCLE
2B25 BLACK MEDIUM DIAMOND
2B26 WHITE MEDIUM DIAMOND
2B27 BLACK MEDIUM LOZENGE
2B28 WHITE MEDIUM LOZENGE
2B29 BLACK SMALL DIAMOND
2B2A BLACK SMALL LOZENGE
2B2B WHITE SMALL LOZENGE
2B2C BLACK HORIZONTAL ELLIPSE
2B2D WHITE HORIZONTAL ELLIPSE
2B2E BLACK VERTICAL ELLIPSE
2B2F WHITE VERTICAL ELLIPSE
2B30 LEFT ARROW WITH SMALL CIRCLE
2B31 THREE LEFTWARDS ARROWS
2B32 LEFT ARROW WITH CIRCLED PLUS
2B33 LONG LEFTWARDS SQUIGGLE ARROW
2B34 LEFTWARDS TWO-HEADED ARROW WITH VERTICAL STROKE
2B35 LEFTWARDS TWO-HEADED ARROW WITH DOUBLE VERTICAL STROKE
2B36 LEFTWARDS TWO-HEADED ARROW FROM BAR
2B37 LEFTWARDS TWO-HEADED TRIPLE DASH ARROW
2B38 LEFTWARDS ARROW WITH DOTTED STEM
2B39 LEFTWARDS ARROW WITH TAIL WITH VERTICAL STROKE
2B3A LEFTWARDS ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE
2B3B LEFTWARDS TWO-HEADED ARROW WITH TAIL
2B3C LEFTWARDS TWO-HEADED ARROW WITH TAIL WITH VERTICAL STROKE
2B3D LEFTWARDS TWO-HEADED ARROW WITH TAIL WITH DOUBLE VERTICAL STROKE
2B3E LEFTWARDS ARROW THROUGH X
2B3F WAVE ARROW POINTING DIRECTLY LEFT
2B40 EQUALS SIGN ABOVE LEFTWARDS ARROW
2B41 REVERSE TILDE OPERATOR ABOVE LEFTWARDS ARROW
2B42 LEFTWARDS ARROW ABOVE REVERSE ALMOST EQUAL TO
2B43 RIGHTWARDS ARROW THROUGH GREATER-THAN
2B44 RIGHTWARDS ARROW THROUGH SUPERSET
2B45 LEFTWARDS QUADRUPLE ARROW
2B46 RIGHTWARDS QUADRUPLE ARROW
2B47 REVERSE TILDE OPERATOR ABOVE RIGHTWARDS ARROW
2B48 RIGHTWARDS ARROW ABOVE REVERSE ALMOST EQUAL TO
2B49 TILDE OPERATOR ABOVE LEFTWARDS ARROW
2B4A LEFTWARDS ARROW ABOVE ALMOST EQUAL TO
2B4B LEFTWARDS ARROW ABOVE REVERSE TILDE OPERATOR
2B4C RIGHTWARDS ARROW ABOVE REVERSE TILDE OPERATOR
2B4D DOWNWARDS TRIANGLE-HEADED ZIGZAG ARROW
2B4E SHORT SLANTED NORTH ARROW
2B4F SHORT BACKSLANTED SOUTH ARROW
2B50 WHITE MEDIUM STAR
2B51 BLACK SMALL STAR
2B52 WHITE SMALL STAR
2B53 BLACK RIGHT-POINTING PENTAGON
2B54 WHITE RIGHT-POINTING PENTAGON
2B55 HEAVY LARGE CIRCLE
2B56 HEAVY OVAL WITH OVAL INSIDE
2B57 HEAVY CIRCLE WITH CIRCLE INSIDE
2B58 HEAVY CIRCLE
2B59 HEAVY CIRCLED SALTIRE
2B5A SLANTED NORTH ARROW WITH HOOKED HEAD
2B5B BACKSLANTED SOUTH ARROW WITH HOOKED TAIL
2B5C SLANTED NORTH ARROW WITH HORIZONTAL TAIL
2B5D BACKSLANTED SOUTH ARROW WITH HORIZONTAL TAIL
2B5E BENT ARROW POINTING DOWNWARDS THEN NORTH EAST
2B5F SHORT BENT ARROW POINTING DOWNWARDS THEN NORTH EAST
2B60 LEFTWARDS TRIANGLE-HEADED ARROW
2B61 UPWARDS TRIANGLE-HEADED ARROW
2B62 RIGHTWARDS TRIANGLE-HEADED ARROW
2B63 DOWNWARDS TRIANGLE-HEADED ARROW
2B64 LEFT RIGHT TRIANGLE-HEADED ARROW
2B65 UP DOWN TRIANGLE-HEADED ARROW
2B66 NORTH WEST TRIANGLE-HEADED ARROW
2B67 NORTH EAST TRIANGLE-HEADED ARROW
2B68 SOUTH EAST TRIANGLE-HEADED ARROW
2B69 SOUTH WEST TRIANGLE-HEADED ARROW
2B6A LEFTWARDS TRIANGLE-HEADED DASHED ARROW
2B6B UPWARDS TRIANGLE-HEADED DASHED ARROW
2B6C RIGHTWARDS TRIANGLE-HEADED DASHED ARROW
2B6D DOWNWARDS TRIANGLE-HEADED DASHED ARROW
2B6E CLOCKWISE TRIANGLE-HEADED OPEN CIRCLE ARROW
2B6F ANTICLOCKWISE TRIANGLE-HEADED OPEN CIRCLE ARROW
2B70 LEFTWARDS TRIANGLE-HEADED ARROW TO BAR
2B71 UPWARDS TRIANGLE-HEADED ARROW TO BAR
2B72 RIGHTWARDS TRIANGLE-HEADED ARROW TO BAR
2B73 DOWNWARDS TRIANGLE-HEADED ARROW TO BAR
2B76 NORTH WEST TRIANGLE-HEADED ARROW TO BAR
2B77 NORTH EAST TRIANGLE-HEADED ARROW TO BAR
2B78 SOUTH EAST TRIANGLE-HEADED ARROW TO BAR
2B79 SOUTH WEST TRIANGLE-HEADED ARROW TO BAR
2B7A LEFTWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE
2B7B UPWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE
2B7C RIGHTWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE
2B7D DOWNWARDS TRIANGLE-HEADED ARROW WITH DOUBLE HORIZONTAL STROKE
2B7E HORIZONTAL TAB KEY
2B7F VERTICAL TAB KEY
2B80 LEFTWARDS TRIANGLE-HEADED ARROW OVER RIGHTWARDS TRIANGLE-HEADED ARROW
2B81 UPWARDS TRIANGLE-HEADED ARROW LEFTWARDS OF DOWNWARDS TRIANGLE-HEADED ARROW
2B82 RIGHTWARDS TRIANGLE-HEADED ARROW OVER LEFTWARDS TRIANGLE-HEADED ARROW
2B83 DOWNWARDS TRIANGLE-HEADED ARROW LEFTWARDS OF UPWARDS TRIANGLE-HEADED ARROW
2B84 LEFTWARDS TRIANGLE-HEADED PAIRED ARROWS
2B85 UPWARDS TRIANGLE-HEADED PAIRED ARROWS
2B86 RIGHTWARDS TRIANGLE-HEADED PAIRED ARROWS
2B87 DOWNWARDS TRIANGLE-HEADED PAIRED ARROWS
2B88 LEFTWARDS BLACK CIRCLED WHITE ARROW
2B89 UPWARDS BLACK CIRCLED WHITE ARROW
2B8A RIGHTWARDS BLACK CIRCLED WHITE ARROW
2B8B DOWNWARDS BLACK CIRCLED WHITE ARROW
2B8C ANTICLOCKWISE TRIANGLE-HEADED RIGHT U-SHAPED ARROW
2B8D ANTICLOCKWISE TRIANGLE-HEADED BOTTOM U-SHAPED ARROW
2B8E ANTICLOCKWISE TRIANGLE-HEADED LEFT U-SHAPED ARROW
2B8F ANTICLOCKWISE TRIANGLE-HEADED TOP U-SHAPED ARROW
2B90 RETURN LEFT
2B91 RETURN RIGHT
2B92 NEWLINE LEFT
2B93 NEWLINE RIGHT
2B94 FOUR CORNER ARROWS CIRCLING ANTICLOCKWISE
2B95 RIGHTWARDS BLACK ARROW
2B98 THREE-D TOP-LIGHTED LEFTWARDS EQUILATERAL ARROWHEAD
2B99 THREE-D RIGHT-LIGHTED UPWARDS EQUILATERAL ARROWHEAD
2B9A THREE-D TOP-LIGHTED RIGHTWARDS EQUILATERAL ARROWHEAD
2B9B THREE-D LEFT-LIGHTED DOWNWARDS EQUILATERAL ARROWHEAD
2B9C BLACK LEFTWARDS EQUILATERAL ARROWHEAD
2B9D BLACK UPWARDS EQUILATERAL ARROWHEAD
2B9E BLACK RIGHTWARDS EQUILATERAL ARROWHEAD
2B9F BLACK DOWNWARDS EQUILATERAL ARROWHEAD
2BA0 DOWNWARDS TRIANGLE-HEADED ARROW WITH LONG TIP LEFTWARDS
2BA1 DOWNWARDS TRIANGLE-HEADED ARROW WITH LONG TIP RIGHTWARDS
2BA2 UPWARDS TRIANGLE-HEADED ARROW WITH LONG TIP LEFTWARDS
2BA3 UPWARDS TRIANGLE-HEADED ARROW WITH LONG TIP RIGHTWARDS
2BA4 LEFTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP UPWARDS
2BA5 RIGHTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP UPWARDS
2BA6 LEFTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP DOWNWARDS
2BA7 RIGHTWARDS TRIANGLE-HEADED ARROW WITH LONG TIP DOWNWARDS
2BA8 BLACK CURVED DOWNWARDS AND LEFTWARDS ARROW
2BA9 BLACK CURVED DOWNWARDS AND RIGHTWARDS ARROW
2BAA BLACK CURVED UPWARDS AND LEFTWARDS ARROW
2BAB BLACK CURVED UPWARDS AND RIGHTWARDS ARROW
2BAC BLACK CURVED LEFTWARDS AND UPWARDS ARROW
2BAD BLACK CURVED RIGHTWARDS AND UPWARDS ARROW
2BAE BLACK CURVED LEFTWARDS AND DOWNWARDS ARROW
2BAF BLACK CURVED RIGHTWARDS AND DOWNWARDS ARROW
2BB0 RIBBON ARROW DOWN LEFT
2BB1 RIBBON ARROW DOWN RIGHT
2BB2 RIBBON ARROW UP LEFT
2BB3 RIBBON ARROW UP RIGHT
2BB4 RIBBON ARROW LEFT UP
2BB5 RIBBON ARROW RIGHT UP
2BB6 RIBBON ARROW LEFT DOWN
2BB7 RIBBON ARROW RIGHT DOWN
2BB8 UPWARDS WHITE ARROW FROM BAR WITH HORIZONTAL BAR
2BB9 UP ARROWHEAD IN A RECTANGLE BOX
2BBD BALLOT BOX WITH LIGHT X
2BBE CIRCLED X
2BBF CIRCLED BOLD X
2BC0 BLACK SQUARE CENTRED
2BC1 BLACK DIAMOND CENTRED
2BC2 TURNED BLACK PENTAGON
2BC3 HORIZONTAL BLACK OCTAGON
2BC4 BLACK OCTAGON
2BC5 BLACK MEDIUM UP-POINTING TRIANGLE CENTRED
2BC6 BLACK MEDIUM DOWN-POINTING TRIANGLE CENTRED
2BC7 BLACK MEDIUM LEFT-POINTING TRIANGLE CENTRED
2BC8 BLACK MEDIUM RIGHT-POINTING TRIANGLE CENTRED
2BCA TOP HALF BLACK CIRCLE
2BCB BOTTOM HALF BLACK CIRCLE
2BCC LIGHT FOUR POINTED BLACK CUSP
2BCD ROTATED LIGHT FOUR POINTED BLACK CUSP
2BCE WHITE FOUR POINTED CUSP
2BCF ROTATED WHITE FOUR POINTED CUSP
2BD0 SQUARE POSITION INDICATOR
2BD1 UNCERTAINTY SIGN
2BD2 GROUP MARK
2BEC LEFTWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS
2BED UPWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS
2BEE RIGHTWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS
2BEF DOWNWARDS TWO-HEADED ARROW WITH TRIANGLE ARROWHEADS
2C00 GLAGOLITIC CAPITAL LETTER AZU
2C01 GLAGOLITIC CAPITAL LETTER BUKY
2C02 GLAGOLITIC CAPITAL LETTER VEDE
2C03 GLAGOLITIC CAPITAL LETTER GLAGOLI
2C04 GLAGOLITIC CAPITAL LETTER DOBRO
2C05 GLAGOLITIC CAPITAL LETTER YESTU
2C06 GLAGOLITIC CAPITAL LETTER ZHIVETE
2C07 GLAGOLITIC CAPITAL LETTER DZELO
2C08 GLAGOLITIC CAPITAL LETTER ZEMLJA
2C09 GLAGOLITIC CAPITAL LETTER IZHE
2C0A GLAGOLITIC CAPITAL LETTER INITIAL IZHE
2C0B GLAGOLITIC CAPITAL LETTER I
2C0C GLAGOLITIC CAPITAL LETTER DJERVI
2C0D GLAGOLITIC CAPITAL LETTER KAKO
2C0E GLAGOLITIC CAPITAL LETTER LJUDIJE
2C0F GLAGOLITIC CAPITAL LETTER MYSLITE
2C10 GLAGOLITIC CAPITAL LETTER NASHI
2C11 GLAGOLITIC CAPITAL LETTER ONU
2C12 GLAGOLITIC CAPITAL LETTER POKOJI
2C13 GLAGOLITIC CAPITAL LETTER RITSI
2C14 GLAGOLITIC CAPITAL LETTER SLOVO
2C15 GLAGOLITIC CAPITAL LETTER TVRIDO
2C16 GLAGOLITIC CAPITAL LETTER UKU
2C17 GLAGOLITIC CAPITAL LETTER FRITU
2C18 GLAGOLITIC CAPITAL LETTER HERU
2C19 GLAGOLITIC CAPITAL LETTER OTU
2C1A GLAGOLITIC CAPITAL LETTER PE
2C1B GLAGOLITIC CAPITAL LETTER SHTA
2C1C GLAGOLITIC CAPITAL LETTER TSI
2C1D GLAGOLITIC CAPITAL LETTER CHRIVI
2C1E GLAGOLITIC CAPITAL LETTER SHA
2C1F GLAGOLITIC CAPITAL LETTER YERU
2C20 GLAGOLITIC CAPITAL LETTER YERI
2C21 GLAGOLITIC CAPITAL LETTER YATI
2C22 GLAGOLITIC CAPITAL LETTER SPIDERY HA
2C23 GLAGOLITIC CAPITAL LETTER YU
2C24 GLAGOLITIC CAPITAL LETTER SMALL YUS
2C25 GLAGOLITIC CAPITAL LETTER SMALL YUS WITH TAIL
2C26 GLAGOLITIC CAPITAL LETTER YO
2C27 GLAGOLITIC CAPITAL LETTER IOTATED SMALL YUS
2C28 GLAGOLITIC CAPITAL LETTER BIG YUS
2C29 GLAGOLITIC CAPITAL LETTER IOTATED BIG YUS
2C2A GLAGOLITIC CAPITAL LETTER FITA
2C2B GLAGOLITIC CAPITAL LETTER IZHITSA
2C2C GLAGOLITIC CAPITAL LETTER SHTAPIC
2C2D GLAGOLITIC CAPITAL LETTER TROKUTASTI A
2C2E GLAGOLITIC CAPITAL LETTER LATINATE MYSLITE
2C30 GLAGOLITIC SMALL LETTER AZU
2C31 GLAGOLITIC SMALL LETTER BUKY
2C32 GLAGOLITIC SMALL LETTER VEDE
2C33 GLAGOLITIC SMALL LETTER GLAGOLI
2C34 GLAGOLITIC SMALL LETTER DOBRO
2C35 GLAGOLITIC SMALL LETTER YESTU
2C36 GLAGOLITIC SMALL LETTER ZHIVETE
2C37 GLAGOLITIC SMALL LETTER DZELO
2C38 GLAGOLITIC SMALL LETTER ZEMLJA
2C39 GLAGOLITIC SMALL LETTER IZHE
2C3A GLAGOLITIC SMALL LETTER INITIAL IZHE
2C3B GLAGOLITIC SMALL LETTER I
2C3C GLAGOLITIC SMALL LETTER DJERVI
2C3D GLAGOLITIC SMALL LETTER KAKO
2C3E GLAGOLITIC SMALL LETTER LJUDIJE
2C3F GLAGOLITIC SMALL LETTER MYSLITE
2C40 GLAGOLITIC SMALL LETTER NASHI
2C41 GLAGOLITIC SMALL LETTER ONU
2C42 GLAGOLITIC SMALL LETTER POKOJI
2C43 GLAGOLITIC SMALL LETTER RITSI
2C44 GLAGOLITIC SMALL LETTER SLOVO
2C45 GLAGOLITIC SMALL LETTER TVRIDO
2C46 GLAGOLITIC SMALL LETTER UKU
2C47 GLAGOLITIC SMALL LETTER FRITU
2C48 GLAGOLITIC SMALL LETTER HERU
2C49 GLAGOLITIC SMALL LETTER OTU
2C4A GLAGOLITIC SMALL LETTER PE
2C4B GLAGOLITIC SMALL LETTER SHTA
2C4C GLAGOLITIC SMALL LETTER TSI
2C4D GLAGOLITIC SMALL LETTER CHRIVI
2C4E GLAGOLITIC SMALL LETTER SHA
2C4F GLAGOLITIC SMALL LETTER YERU
2C50 GLAGOLITIC SMALL LETTER YERI
2C51 GLAGOLITIC SMALL LETTER YATI
2C52 GLAGOLITIC SMALL LETTER SPIDERY HA
2C53 GLAGOLITIC SMALL LETTER YU
2C54 GLAGOLITIC SMALL LETTER SMALL YUS
2C55 GLAGOLITIC SMALL LETTER SMALL YUS WITH TAIL
2C56 GLAGOLITIC SMALL LETTER YO
2C57 GLAGOLITIC SMALL LETTER IOTATED SMALL YUS
2C58 GLAGOLITIC SMALL LETTER BIG YUS
2C59 GLAGOLITIC SMALL LETTER IOTATED BIG YUS
2C5A GLAGOLITIC SMALL LETTER FITA
2C5B GLAGOLITIC SMALL LETTER IZHITSA
2C5C GLAGOLITIC SMALL LETTER SHTAPIC
2C5D GLAGOLITIC SMALL LETTER TROKUTASTI A
2C5E GLAGOLITIC SMALL LETTER LATINATE MYSLITE
2C60 LATIN CAPITAL LETTER L WITH DOUBLE BAR
2C61 LATIN SMALL LETTER L WITH DOUBLE BAR
2C62 LATIN CAPITAL LETTER L WITH MIDDLE TILDE
2C63 LATIN CAPITAL LETTER P WITH STROKE
2C64 LATIN CAPITAL LETTER R WITH TAIL
2C65 LATIN SMALL LETTER A WITH STROKE
2C66 LATIN SMALL LETTER T WITH DIAGONAL STROKE
2C67 LATIN CAPITAL LETTER H WITH DESCENDER
2C68 LATIN SMALL LETTER H WITH DESCENDER
2C69 LATIN CAPITAL LETTER K WITH DESCENDER
2C6A LATIN SMALL LETTER K WITH DESCENDER
2C6B LATIN CAPITAL LETTER Z WITH DESCENDER
2C6C LATIN SMALL LETTER Z WITH DESCENDER
2C6D LATIN CAPITAL LETTER ALPHA
2C6E LATIN CAPITAL LETTER M WITH HOOK
2C6F LATIN CAPITAL LETTER TURNED A
2C70 LATIN CAPITAL LETTER TURNED ALPHA
2C71 LATIN SMALL LETTER V WITH RIGHT HOOK
2C72 LATIN CAPITAL LETTER W WITH HOOK
2C73 LATIN SMALL LETTER W WITH HOOK
2C74 LATIN SMALL LETTER V WITH CURL
2C75 LATIN CAPITAL LETTER HALF H
2C76 LATIN SMALL LETTER HALF H
2C77 LATIN SMALL LETTER TAILLESS PHI
2C78 LATIN SMALL LETTER E WITH NOTCH
2C79 LATIN SMALL LETTER TURNED R WITH TAIL
2C7A LATIN SMALL LETTER O WITH LOW RING INSIDE
2C7B LATIN LETTER SMALL CAPITAL TURNED E
2C7C LATIN SUBSCRIPT SMALL LETTER J
2C7D MODIFIER LETTER CAPITAL V
2C7E LATIN CAPITAL LETTER S WITH SWASH TAIL
2C7F LATIN CAPITAL LETTER Z WITH SWASH TAIL
2C80 COPTIC CAPITAL LETTER ALFA
2C81 COPTIC SMALL LETTER ALFA
2C82 COPTIC CAPITAL LETTER VIDA
2C83 COPTIC SMALL LETTER VIDA
2C84 COPTIC CAPITAL LETTER GAMMA
2C85 COPTIC SMALL LETTER GAMMA
2C86 COPTIC CAPITAL LETTER DALDA
2C87 COPTIC SMALL LETTER DALDA
2C88 COPTIC CAPITAL LETTER EIE
2C89 COPTIC SMALL LETTER EIE
2C8A COPTIC CAPITAL LETTER SOU
2C8B COPTIC SMALL LETTER SOU
2C8C COPTIC CAPITAL LETTER ZATA
2C8D COPTIC SMALL LETTER ZATA
2C8E COPTIC CAPITAL LETTER HATE
2C8F COPTIC SMALL LETTER HATE
2C90 COPTIC CAPITAL LETTER THETHE
2C91 COPTIC SMALL LETTER THETHE
2C92 COPTIC CAPITAL LETTER IAUDA
2C93 COPTIC SMALL LETTER IAUDA
2C94 COPTIC CAPITAL LETTER KAPA
2C95 COPTIC SMALL LETTER KAPA
2C96 COPTIC CAPITAL LETTER LAULA
2C97 COPTIC SMALL LETTER LAULA
2C98 COPTIC CAPITAL LETTER MI
2C99 COPTIC SMALL LETTER MI
2C9A COPTIC CAPITAL LETTER NI
2C9B COPTIC SMALL LETTER NI
2C9C COPTIC CAPITAL LETTER KSI
2C9D COPTIC SMALL LETTER KSI
2C9E COPTIC CAPITAL LETTER O
2C9F COPTIC SMALL LETTER O
2CA0 COPTIC CAPITAL LETTER PI
2CA1 COPTIC SMALL LETTER PI
2CA2 COPTIC CAPITAL LETTER RO
2CA3 COPTIC SMALL LETTER RO
2CA4 COPTIC CAPITAL LETTER SIMA
2CA5 COPTIC SMALL LETTER SIMA
2CA6 COPTIC CAPITAL LETTER TAU
2CA7 COPTIC SMALL LETTER TAU
2CA8 COPTIC CAPITAL LETTER UA
2CA9 COPTIC SMALL LETTER UA
2CAA COPTIC CAPITAL LETTER FI
2CAB COPTIC SMALL LETTER FI
2CAC COPTIC CAPITAL LETTER KHI
2CAD COPTIC SMALL LETTER KHI
2CAE COPTIC CAPITAL LETTER PSI
2CAF COPTIC SMALL LETTER PSI
2CB0 COPTIC CAPITAL LETTER OOU
2CB1 COPTIC SMALL LETTER OOU
2CB2 COPTIC CAPITAL LETTER DIALECT-P ALEF
2CB3 COPTIC SMALL LETTER DIALECT-P ALEF
2CB4 COPTIC CAPITAL LETTER OLD COPTIC AIN
2CB5 COPTIC SMALL LETTER OLD COPTIC AIN
2CB6 COPTIC CAPITAL LETTER CRYPTOGRAMMIC EIE
2CB7 COPTIC SMALL LETTER CRYPTOGRAMMIC EIE
2CB8 COPTIC CAPITAL LETTER DIALECT-P KAPA
2CB9 COPTIC SMALL LETTER DIALECT-P KAPA
2CBA COPTIC CAPITAL LETTER DIALECT-P NI
2CBB COPTIC SMALL LETTER DIALECT-P NI
2CBC COPTIC CAPITAL LETTER CRYPTOGRAMMIC NI
2CBD COPTIC SMALL LETTER CRYPTOGRAMMIC NI
2CBE COPTIC CAPITAL LETTER OLD COPTIC OOU
2CBF COPTIC SMALL LETTER OLD COPTIC OOU
2CC0 COPTIC CAPITAL LETTER SAMPI
2CC1 COPTIC SMALL LETTER SAMPI
2CC2 COPTIC CAPITAL LETTER CROSSED SHEI
2CC3 COPTIC SMALL LETTER CROSSED SHEI
2CC4 COPTIC CAPITAL LETTER OLD COPTIC SHEI
2CC5 COPTIC SMALL LETTER OLD COPTIC SHEI
2CC6 COPTIC CAPITAL LETTER OLD COPTIC ESH
2CC7 COPTIC SMALL LETTER OLD COPTIC ESH
2CC8 COPTIC CAPITAL LETTER AKHMIMIC KHEI
2CC9 COPTIC SMALL LETTER AKHMIMIC KHEI
2CCA COPTIC CAPITAL LETTER DIALECT-P HORI
2CCB COPTIC SMALL LETTER DIALECT-P HORI
2CCC COPTIC CAPITAL LETTER OLD COPTIC HORI
2CCD COPTIC SMALL LETTER OLD COPTIC HORI
2CCE COPTIC CAPITAL LETTER OLD COPTIC HA
2CCF COPTIC SMALL LETTER OLD COPTIC HA
2CD0 COPTIC CAPITAL LETTER L-SHAPED HA
2CD1 COPTIC SMALL LETTER L-SHAPED HA
2CD2 COPTIC CAPITAL LETTER OLD COPTIC HEI
2CD3 COPTIC SMALL LETTER OLD COPTIC HEI
2CD4 COPTIC CAPITAL LETTER OLD COPTIC HAT
2CD5 COPTIC SMALL LETTER OLD COPTIC HAT
2CD6 COPTIC CAPITAL LETTER OLD COPTIC GANGIA
2CD7 COPTIC SMALL LETTER OLD COPTIC GANGIA
2CD8 COPTIC CAPITAL LETTER OLD COPTIC DJA
2CD9 COPTIC SMALL LETTER OLD COPTIC DJA
2CDA COPTIC CAPITAL LETTER OLD COPTIC SHIMA
2CDB COPTIC SMALL LETTER OLD COPTIC SHIMA
2CDC COPTIC CAPITAL LETTER OLD NUBIAN SHIMA
2CDD COPTIC SMALL LETTER OLD NUBIAN SHIMA
2CDE COPTIC CAPITAL LETTER OLD NUBIAN NGI
2CDF COPTIC SMALL LETTER OLD NUBIAN NGI
2CE0 COPTIC CAPITAL LETTER OLD NUBIAN NYI
2CE1 COPTIC SMALL LETTER OLD NUBIAN NYI
2CE2 COPTIC CAPITAL LETTER OLD NUBIAN WAU
2CE3 COPTIC SMALL LETTER OLD NUBIAN WAU
2CE4 COPTIC SYMBOL KAI
2CE5 COPTIC SYMBOL MI RO
2CE6 COPTIC SYMBOL PI RO
2CE7 COPTIC SYMBOL STAUROS
2CE8 COPTIC SYMBOL TAU RO
2CE9 COPTIC SYMBOL KHI RO
2CEA COPTIC SYMBOL SHIMA SIMA
2CEB COPTIC CAPITAL LETTER CRYPTOGRAMMIC SHEI
2CEC COPTIC SMALL LETTER CRYPTOGRAMMIC SHEI
2CED COPTIC CAPITAL LETTER CRYPTOGRAMMIC GANGIA
2CEE COPTIC SMALL LETTER CRYPTOGRAMMIC GANGIA
2CEF COPTIC COMBINING NI ABOVE
2CF0 COPTIC COMBINING SPIRITUS ASPER
2CF1 COPTIC COMBINING SPIRITUS LENIS
2CF2 COPTIC CAPITAL LETTER BOHAIRIC KHEI
2CF3 COPTIC SMALL LETTER BOHAIRIC KHEI
2CF9 COPTIC OLD NUBIAN FULL STOP
2CFA COPTIC OLD NUBIAN DIRECT QUESTION MARK
2CFB COPTIC OLD NUBIAN INDIRECT QUESTION MARK
2CFC COPTIC OLD NUBIAN VERSE DIVIDER
2CFD COPTIC FRACTION ONE HALF
2CFE COPTIC FULL STOP
2CFF COPTIC MORPHOLOGICAL DIVIDER
2D00 GEORGIAN SMALL LETTER AN
2D01 GEORGIAN SMALL LETTER BAN
2D02 GEORGIAN SMALL LETTER GAN
2D03 GEORGIAN SMALL LETTER DON
2D04 GEORGIAN SMALL LETTER EN
2D05 GEORGIAN SMALL LETTER VIN
2D06 GEORGIAN SMALL LETTER ZEN
2D07 GEORGIAN SMALL LETTER TAN
2D08 GEORGIAN SMALL LETTER IN
2D09 GEORGIAN SMALL LETTER KAN
2D0A GEORGIAN SMALL LETTER LAS
2D0B GEORGIAN SMALL LETTER MAN
2D0C GEORGIAN SMALL LETTER NAR
2D0D GEORGIAN SMALL LETTER ON
2D0E GEORGIAN SMALL LETTER PAR
2D0F GEORGIAN SMALL LETTER ZHAR
2D10 GEORGIAN SMALL LETTER RAE
2D11 GEORGIAN SMALL LETTER SAN
2D12 GEORGIAN SMALL LETTER TAR
2D13 GEORGIAN SMALL LETTER UN
2D14 GEORGIAN SMALL LETTER PHAR
2D15 GEORGIAN SMALL LETTER KHAR
2D16 GEORGIAN SMALL LETTER GHAN
2D17 GEORGIAN SMALL LETTER QAR
2D18 GEORGIAN SMALL LETTER SHIN
2D19 GEORGIAN SMALL LETTER CHIN
2D1A GEORGIAN SMALL LETTER CAN
2D1B GEORGIAN SMALL LETTER JIL
2D1C GEORGIAN SMALL LETTER CIL
2D1D GEORGIAN SMALL LETTER CHAR
2D1E GEORGIAN SMALL LETTER XAN
2D1F GEORGIAN SMALL LETTER JHAN
2D20 GEORGIAN SMALL LETTER HAE
2D21 GEORGIAN SMALL LETTER HE
2D22 GEORGIAN SMALL LETTER HIE
2D23 GEORGIAN SMALL LETTER WE
2D24 GEORGIAN SMALL LETTER HAR
2D25 GEORGIAN SMALL LETTER HOE
2D27 GEORGIAN SMALL LETTER YN
2D2D GEORGIAN SMALL LETTER AEN
2D30 TIFINAGH LETTER YA
2D31 TIFINAGH LETTER YAB
2D32 TIFINAGH LETTER YABH
2D33 TIFINAGH LETTER YAG
2D34 TIFINAGH LETTER YAGHH
2D35 TIFINAGH LETTER BERBER ACADEMY YAJ
2D36 TIFINAGH LETTER YAJ
2D37 TIFINAGH LETTER YAD
2D38 TIFINAGH LETTER YADH
2D39 TIFINAGH LETTER YADD
2D3A TIFINAGH LETTER YADDH
2D3B TIFINAGH LETTER YEY
2D3C TIFINAGH LETTER YAF
2D3D TIFINAGH LETTER YAK
2D3E TIFINAGH LETTER TUAREG YAK
2D3F TIFINAGH LETTER YAKHH
2D40 TIFINAGH LETTER YAH
2D41 TIFINAGH LETTER BERBER ACADEMY YAH
2D42 TIFINAGH LETTER TUAREG YAH
2D43 TIFINAGH LETTER YAHH
2D44 TIFINAGH LETTER YAA
2D45 TIFINAGH LETTER YAKH
2D46 TIFINAGH LETTER TUAREG YAKH
2D47 TIFINAGH LETTER YAQ
2D48 TIFINAGH LETTER TUAREG YAQ
2D49 TIFINAGH LETTER YI
2D4A TIFINAGH LETTER YAZH
2D4B TIFINAGH LETTER AHAGGAR YAZH
2D4C TIFINAGH LETTER TUAREG YAZH
2D4D TIFINAGH LETTER YAL
2D4E TIFINAGH LETTER YAM
2D4F TIFINAGH LETTER YAN
2D50 TIFINAGH LETTER TUAREG YAGN
2D51 TIFINAGH LETTER TUAREG YANG
2D52 TIFINAGH LETTER YAP
2D53 TIFINAGH LETTER YU
2D54 TIFINAGH LETTER YAR
2D55 TIFINAGH LETTER YARR
2D56 TIFINAGH LETTER YAGH
2D57 TIFINAGH LETTER TUAREG YAGH
2D58 TIFINAGH LETTER AYER YAGH
2D59 TIFINAGH LETTER YAS
2D5A TIFINAGH LETTER YASS
2D5B TIFINAGH LETTER YASH
2D5C TIFINAGH LETTER YAT
2D5D TIFINAGH LETTER YATH
2D5E TIFINAGH LETTER YACH
2D5F TIFINAGH LETTER YATT
2D60 TIFINAGH LETTER YAV
2D61 TIFINAGH LETTER YAW
2D62 TIFINAGH LETTER YAY
2D63 TIFINAGH LETTER YAZ
2D64 TIFINAGH LETTER TAWELLEMET YAZ
2D65 TIFINAGH LETTER YAZZ
2D66 TIFINAGH LETTER YE
2D67 TIFINAGH LETTER YO
2D6F TIFINAGH MODIFIER LETTER LABIALIZATION MARK
2D70 TIFINAGH SEPARATOR MARK
2D7F TIFINAGH CONSONANT JOINER
2D80 ETHIOPIC SYLLABLE LOA
2D81 ETHIOPIC SYLLABLE MOA
2D82 ETHIOPIC SYLLABLE ROA
2D83 ETHIOPIC SYLLABLE SOA
2D84 ETHIOPIC SYLLABLE SHOA
2D85 ETHIOPIC SYLLABLE BOA
2D86 ETHIOPIC SYLLABLE TOA
2D87 ETHIOPIC SYLLABLE COA
2D88 ETHIOPIC SYLLABLE NOA
2D89 ETHIOPIC SYLLABLE NYOA
2D8A ETHIOPIC SYLLABLE GLOTTAL OA
2D8B ETHIOPIC SYLLABLE ZOA
2D8C ETHIOPIC SYLLABLE DOA
2D8D ETHIOPIC SYLLABLE DDOA
2D8E ETHIOPIC SYLLABLE JOA
2D8F ETHIOPIC SYLLABLE THOA
2D90 ETHIOPIC SYLLABLE CHOA
2D91 ETHIOPIC SYLLABLE PHOA
2D92 ETHIOPIC SYLLABLE POA
2D93 ETHIOPIC SYLLABLE GGWA
2D94 ETHIOPIC SYLLABLE GGWI
2D95 ETHIOPIC SYLLABLE GGWEE
2D96 ETHIOPIC SYLLABLE GGWE
2DA0 ETHIOPIC SYLLABLE SSA
2DA1 ETHIOPIC SYLLABLE SSU
2DA2 ETHIOPIC SYLLABLE SSI
2DA3 ETHIOPIC SYLLABLE SSAA
2DA4 ETHIOPIC SYLLABLE SSEE
2DA5 ETHIOPIC SYLLABLE SSE
2DA6 ETHIOPIC SYLLABLE SSO
2DA8 ETHIOPIC SYLLABLE CCA
2DA9 ETHIOPIC SYLLABLE CCU
2DAA ETHIOPIC SYLLABLE CCI
2DAB ETHIOPIC SYLLABLE CCAA
2DAC ETHIOPIC SYLLABLE CCEE
2DAD ETHIOPIC SYLLABLE CCE
2DAE ETHIOPIC SYLLABLE CCO
2DB0 ETHIOPIC SYLLABLE ZZA
2DB1 ETHIOPIC SYLLABLE ZZU
2DB2 ETHIOPIC SYLLABLE ZZI
2DB3 ETHIOPIC SYLLABLE ZZAA
2DB4 ETHIOPIC SYLLABLE ZZEE
2DB5 ETHIOPIC SYLLABLE ZZE
2DB6 ETHIOPIC SYLLABLE ZZO
2DB8 ETHIOPIC SYLLABLE CCHA
2DB9 ETHIOPIC SYLLABLE CCHU
2DBA ETHIOPIC SYLLABLE CCHI
2DBB ETHIOPIC SYLLABLE CCHAA
2DBC ETHIOPIC SYLLABLE CCHEE
2DBD ETHIOPIC SYLLABLE CCHE
2DBE ETHIOPIC SYLLABLE CCHO
2DC0 ETHIOPIC SYLLABLE QYA
2DC1 ETHIOPIC SYLLABLE QYU
2DC2 ETHIOPIC SYLLABLE QYI
2DC3 ETHIOPIC SYLLABLE QYAA
2DC4 ETHIOPIC SYLLABLE QYEE
2DC5 ETHIOPIC SYLLABLE QYE
2DC6 ETHIOPIC SYLLABLE QYO
2DC8 ETHIOPIC SYLLABLE KYA
2DC9 ETHIOPIC SYLLABLE KYU
2DCA ETHIOPIC SYLLABLE KYI
2DCB ETHIOPIC SYLLABLE KYAA
2DCC ETHIOPIC SYLLABLE KYEE
2DCD ETHIOPIC SYLLABLE KYE
2DCE ETHIOPIC SYLLABLE KYO
2DD0 ETHIOPIC SYLLABLE XYA
2DD1 ETHIOPIC SYLLABLE XYU
2DD2 ETHIOPIC SYLLABLE XYI
2DD3 ETHIOPIC SYLLABLE XYAA
2DD4 ETHIOPIC SYLLABLE XYEE
2DD5 ETHIOPIC SYLLABLE XYE
2DD6 ETHIOPIC SYLLABLE XYO
2DD8 ETHIOPIC SYLLABLE GYA
2DD9 ETHIOPIC SYLLABLE GYU
2DDA ETHIOPIC SYLLABLE GYI
2DDB ETHIOPIC SYLLABLE GYAA
2DDC ETHIOPIC SYLLABLE GYEE
2DDD ETHIOPIC SYLLABLE GYE
2DDE ETHIOPIC SYLLABLE GYO
2DE0 COMBINING CYRILLIC LETTER BE
2DE1 COMBINING CYRILLIC LETTER VE
2DE2 COMBINING CYRILLIC LETTER GHE
2DE3 COMBINING CYRILLIC LETTER DE
2DE4 COMBINING CYRILLIC LETTER ZHE
2DE5 COMBINING CYRILLIC LETTER ZE
2DE6 COMBINING CYRILLIC LETTER KA
2DE7 COMBINING CYRILLIC LETTER EL
2DE8 COMBINING CYRILLIC LETTER EM
2DE9 COMBINING CYRILLIC LETTER EN
2DEA COMBINING CYRILLIC LETTER O
2DEB COMBINING CYRILLIC LETTER PE
2DEC COMBINING CYRILLIC LETTER ER
2DED COMBINING CYRILLIC LETTER ES
2DEE COMBINING CYRILLIC LETTER TE
2DEF COMBINING CYRILLIC LETTER HA
2DF0 COMBINING CYRILLIC LETTER TSE
2DF1 COMBINING CYRILLIC LETTER CHE
2DF2 COMBINING CYRILLIC LETTER SHA
2DF3 COMBINING CYRILLIC LETTER SHCHA
2DF4 COMBINING CYRILLIC LETTER FITA
2DF5 COMBINING CYRILLIC LETTER ES-TE
2DF6 COMBINING CYRILLIC LETTER A
2DF7 COMBINING CYRILLIC LETTER IE
2DF8 COMBINING CYRILLIC LETTER DJERV
2DF9 COMBINING CYRILLIC LETTER MONOGRAPH UK
2DFA COMBINING CYRILLIC LETTER YAT
2DFB COMBINING CYRILLIC LETTER YU
2DFC COMBINING CYRILLIC LETTER IOTIFIED A
2DFD COMBINING CYRILLIC LETTER LITTLE YUS
2DFE COMBINING CYRILLIC LETTER BIG YUS
2DFF COMBINING CYRILLIC LETTER IOTIFIED BIG YUS
2E00 RIGHT ANGLE SUBSTITUTION MARKER
2E01 RIGHT ANGLE DOTTED SUBSTITUTION MARKER
2E02 LEFT SUBSTITUTION BRACKET
2E03 RIGHT SUBSTITUTION BRACKET
2E04 LEFT DOTTED SUBSTITUTION BRACKET
2E05 RIGHT DOTTED SUBSTITUTION BRACKET
2E06 RAISED INTERPOLATION MARKER
2E07 RAISED DOTTED INTERPOLATION MARKER
2E08 DOTTED TRANSPOSITION MARKER
2E09 LEFT TRANSPOSITION BRACKET
2E0A RIGHT TRANSPOSITION BRACKET
2E0B RAISED SQUARE
2E0C LEFT RAISED OMISSION BRACKET
2E0D RIGHT RAISED OMISSION BRACKET
2E0E EDITORIAL CORONIS
2E0F PARAGRAPHOS
2E10 FORKED PARAGRAPHOS
2E11 REVERSED FORKED PARAGRAPHOS
2E12 HYPODIASTOLE
2E13 DOTTED OBELOS
2E14 DOWNWARDS ANCORA
2E15 UPWARDS ANCORA
2E16 DOTTED RIGHT-POINTING ANGLE
2E17 DOUBLE OBLIQUE HYPHEN
2E18 INVERTED INTERROBANG
2E19 PALM BRANCH
2E1A HYPHEN WITH DIAERESIS
2E1B TILDE WITH RING ABOVE
2E1C LEFT LOW PARAPHRASE BRACKET
2E1D RIGHT LOW PARAPHRASE BRACKET
2E1E TILDE WITH DOT ABOVE
2E1F TILDE WITH DOT BELOW
2E20 LEFT VERTICAL BAR WITH QUILL
2E21 RIGHT VERTICAL BAR WITH QUILL
2E22 TOP LEFT HALF BRACKET
2E23 TOP RIGHT HALF BRACKET
2E24 BOTTOM LEFT HALF BRACKET
2E25 BOTTOM RIGHT HALF BRACKET
2E26 LEFT SIDEWAYS U BRACKET
2E27 RIGHT SIDEWAYS U BRACKET
2E28 LEFT DOUBLE PARENTHESIS
2E29 RIGHT DOUBLE PARENTHESIS
2E2A TWO DOTS OVER ONE DOT PUNCTUATION
2E2B ONE DOT OVER TWO DOTS PUNCTUATION
2E2C SQUARED FOUR DOT PUNCTUATION
2E2D FIVE DOT MARK
2E2E REVERSED QUESTION MARK
2E2F VERTICAL TILDE
2E30 RING POINT
2E31 WORD SEPARATOR MIDDLE DOT
2E32 TURNED COMMA
2E33 RAISED DOT
2E34 RAISED COMMA
2E35 TURNED SEMICOLON
2E36 DAGGER WITH LEFT GUARD
2E37 DAGGER WITH RIGHT GUARD
2E38 TURNED DAGGER
2E39 TOP HALF SECTION SIGN
2E3A TWO-EM DASH
2E3B THREE-EM DASH
2E3C STENOGRAPHIC FULL STOP
2E3D VERTICAL SIX DOTS
2E3E WIGGLY VERTICAL LINE
2E3F CAPITULUM
2E40 DOUBLE HYPHEN
2E41 REVERSED COMMA
2E42 DOUBLE LOW-REVERSED-9 QUOTATION MARK
2E43 DASH WITH LEFT UPTURN
2E44 DOUBLE SUSPENSION MARK
2E45 INVERTED LOW KAVYKA
2E46 INVERTED LOW KAVYKA WITH KAVYKA ABOVE
2E47 LOW KAVYKA
2E48 LOW KAVYKA WITH DOT
2E49 DOUBLE STACKED COMMA
2E80 CJK RADICAL REPEAT
2E81 CJK RADICAL CLIFF
2E82 CJK RADICAL SECOND ONE
2E83 CJK RADICAL SECOND TWO
2E84 CJK RADICAL SECOND THREE
2E85 CJK RADICAL PERSON
2E86 CJK RADICAL BOX
2E87 CJK RADICAL TABLE
2E88 CJK RADICAL KNIFE ONE
2E89 CJK RADICAL KNIFE TWO
2E8A CJK RADICAL DIVINATION
2E8B CJK RADICAL SEAL
2E8C CJK RADICAL SMALL ONE
2E8D CJK RADICAL SMALL TWO
2E8E CJK RADICAL LAME ONE
2E8F CJK RADICAL LAME TWO
2E90 CJK RADICAL LAME THREE
2E91 CJK RADICAL LAME FOUR
2E92 CJK RADICAL SNAKE
2E93 CJK RADICAL THREAD
2E94 CJK RADICAL SNOUT ONE
2E95 CJK RADICAL SNOUT TWO
2E96 CJK RADICAL HEART ONE
2E97 CJK RADICAL HEART TWO
2E98 CJK RADICAL HAND
2E99 CJK RADICAL RAP
2E9B CJK RADICAL CHOKE
2E9C CJK RADICAL SUN
2E9D CJK RADICAL MOON
2E9E CJK RADICAL DEATH
2E9F CJK RADICAL MOTHER
2EA0 CJK RADICAL CIVILIAN
2EA1 CJK RADICAL WATER ONE
2EA2 CJK RADICAL WATER TWO
2EA3 CJK RADICAL FIRE
2EA4 CJK RADICAL PAW ONE
2EA5 CJK RADICAL PAW TWO
2EA6 CJK RADICAL SIMPLIFIED HALF TREE TRUNK
2EA7 CJK RADICAL COW
2EA8 CJK RADICAL DOG
2EA9 CJK RADICAL JADE
2EAA CJK RADICAL BOLT OF CLOTH
2EAB CJK RADICAL EYE
2EAC CJK RADICAL SPIRIT ONE
2EAD CJK RADICAL SPIRIT TWO
2EAE CJK RADICAL BAMBOO
2EAF CJK RADICAL SILK
2EB0 CJK RADICAL C-SIMPLIFIED SILK
2EB1 CJK RADICAL NET ONE
2EB2 CJK RADICAL NET TWO
2EB3 CJK RADICAL NET THREE
2EB4 CJK RADICAL NET FOUR
2EB5 CJK RADICAL MESH
2EB6 CJK RADICAL SHEEP
2EB7 CJK RADICAL RAM
2EB8 CJK RADICAL EWE
2EB9 CJK RADICAL OLD
2EBA CJK RADICAL BRUSH ONE
2EBB CJK RADICAL BRUSH TWO
2EBC CJK RADICAL MEAT
2EBD CJK RADICAL MORTAR
2EBE CJK RADICAL GRASS ONE
2EBF CJK RADICAL GRASS TWO
2EC0 CJK RADICAL GRASS THREE
2EC1 CJK RADICAL TIGER
2EC2 CJK RADICAL CLOTHES
2EC3 CJK RADICAL WEST ONE
2EC4 CJK RADICAL WEST TWO
2EC5 CJK RADICAL C-SIMPLIFIED SEE
2EC6 CJK RADICAL SIMPLIFIED HORN
2EC7 CJK RADICAL HORN
2EC8 CJK RADICAL C-SIMPLIFIED SPEECH
2EC9 CJK RADICAL C-SIMPLIFIED SHELL
2ECA CJK RADICAL FOOT
2ECB CJK RADICAL C-SIMPLIFIED CART
2ECC CJK RADICAL SIMPLIFIED WALK
2ECD CJK RADICAL WALK ONE
2ECE CJK RADICAL WALK TWO
2ECF CJK RADICAL CITY
2ED0 CJK RADICAL C-SIMPLIFIED GOLD
2ED1 CJK RADICAL LONG ONE
2ED2 CJK RADICAL LONG TWO
2ED3 CJK RADICAL C-SIMPLIFIED LONG
2ED4 CJK RADICAL C-SIMPLIFIED GATE
2ED5 CJK RADICAL MOUND ONE
2ED6 CJK RADICAL MOUND TWO
2ED7 CJK RADICAL RAIN
2ED8 CJK RADICAL BLUE
2ED9 CJK RADICAL C-SIMPLIFIED TANNED LEATHER
2EDA CJK RADICAL C-SIMPLIFIED LEAF
2EDB CJK RADICAL C-SIMPLIFIED WIND
2EDC CJK RADICAL C-SIMPLIFIED FLY
2EDD CJK RADICAL EAT ONE
2EDE CJK RADICAL EAT TWO
2EDF CJK RADICAL EAT THREE
2EE0 CJK RADICAL C-SIMPLIFIED EAT
2EE1 CJK RADICAL HEAD
2EE2 CJK RADICAL C-SIMPLIFIED HORSE
2EE3 CJK RADICAL BONE
2EE4 CJK RADICAL GHOST
2EE5 CJK RADICAL C-SIMPLIFIED FISH
2EE6 CJK RADICAL C-SIMPLIFIED BIRD
2EE7 CJK RADICAL C-SIMPLIFIED SALT
2EE8 CJK RADICAL SIMPLIFIED WHEAT
2EE9 CJK RADICAL SIMPLIFIED YELLOW
2EEA CJK RADICAL C-SIMPLIFIED FROG
2EEB CJK RADICAL J-SIMPLIFIED EVEN
2EEC CJK RADICAL C-SIMPLIFIED EVEN
2EED CJK RADICAL J-SIMPLIFIED TOOTH
2EEE CJK RADICAL C-SIMPLIFIED TOOTH
2EEF CJK RADICAL J-SIMPLIFIED DRAGON
2EF0 CJK RADICAL C-SIMPLIFIED DRAGON
2EF1 CJK RADICAL TURTLE
2EF2 CJK RADICAL J-SIMPLIFIED TURTLE
2EF3 CJK RADICAL C-SIMPLIFIED TURTLE
2F00 KANGXI RADICAL ONE
2F01 KANGXI RADICAL LINE
2F02 KANGXI RADICAL DOT
2F03 KANGXI RADICAL SLASH
2F04 KANGXI RADICAL SECOND
2F05 KANGXI RADICAL HOOK
2F06 KANGXI RADICAL TWO
2F07 KANGXI RADICAL LID
2F08 KANGXI RADICAL MAN
2F09 KANGXI RADICAL LEGS
2F0A KANGXI RADICAL ENTER
2F0B KANGXI RADICAL EIGHT
2F0C KANGXI RADICAL DOWN BOX
2F0D KANGXI RADICAL COVER
2F0E KANGXI RADICAL ICE
2F0F KANGXI RADICAL TABLE
2F10 KANGXI RADICAL OPEN BOX
2F11 KANGXI RADICAL KNIFE
2F12 KANGXI RADICAL POWER
2F13 KANGXI RADICAL WRAP
2F14 KANGXI RADICAL SPOON
2F15 KANGXI RADICAL RIGHT OPEN BOX
2F16 KANGXI RADICAL HIDING ENCLOSURE
2F17 KANGXI RADICAL TEN
2F18 KANGXI RADICAL DIVINATION
2F19 KANGXI RADICAL SEAL
2F1A KANGXI RADICAL CLIFF
2F1B KANGXI RADICAL PRIVATE
2F1C KANGXI RADICAL AGAIN
2F1D KANGXI RADICAL MOUTH
2F1E KANGXI RADICAL ENCLOSURE
2F1F KANGXI RADICAL EARTH
2F20 KANGXI RADICAL SCHOLAR
2F21 KANGXI RADICAL GO
2F22 KANGXI RADICAL GO SLOWLY
2F23 KANGXI RADICAL EVENING
2F24 KANGXI RADICAL BIG
2F25 KANGXI RADICAL WOMAN
2F26 KANGXI RADICAL CHILD
2F27 KANGXI RADICAL ROOF
2F28 KANGXI RADICAL INCH
2F29 KANGXI RADICAL SMALL
2F2A KANGXI RADICAL LAME
2F2B KANGXI RADICAL CORPSE
2F2C KANGXI RADICAL SPROUT
2F2D KANGXI RADICAL MOUNTAIN
2F2E KANGXI RADICAL RIVER
2F2F KANGXI RADICAL WORK
2F30 KANGXI RADICAL ONESELF
2F31 KANGXI RADICAL TURBAN
2F32 KANGXI RADICAL DRY
2F33 KANGXI RADICAL SHORT THREAD
2F34 KANGXI RADICAL DOTTED CLIFF
2F35 KANGXI RADICAL LONG STRIDE
2F36 KANGXI RADICAL TWO HANDS
2F37 KANGXI RADICAL SHOOT
2F38 KANGXI RADICAL BOW
2F39 KANGXI RADICAL SNOUT
2F3A KANGXI RADICAL BRISTLE
2F3B KANGXI RADICAL STEP
2F3C KANGXI RADICAL HEART
2F3D KANGXI RADICAL HALBERD
2F3E KANGXI RADICAL DOOR
2F3F KANGXI RADICAL HAND
2F40 KANGXI RADICAL BRANCH
2F41 KANGXI RADICAL RAP
2F42 KANGXI RADICAL SCRIPT
2F43 KANGXI RADICAL DIPPER
2F44 KANGXI RADICAL AXE
2F45 KANGXI RADICAL SQUARE
2F46 KANGXI RADICAL NOT
2F47 KANGXI RADICAL SUN
2F48 KANGXI RADICAL SAY
2F49 KANGXI RADICAL MOON
2F4A KANGXI RADICAL TREE
2F4B KANGXI RADICAL LACK
2F4C KANGXI RADICAL STOP
2F4D KANGXI RADICAL DEATH
2F4E KANGXI RADICAL WEAPON
2F4F KANGXI RADICAL DO NOT
2F50 KANGXI RADICAL COMPARE
2F51 KANGXI RADICAL FUR
2F52 KANGXI RADICAL CLAN
2F53 KANGXI RADICAL STEAM
2F54 KANGXI RADICAL WATER
2F55 KANGXI RADICAL FIRE
2F56 KANGXI RADICAL CLAW
2F57 KANGXI RADICAL FATHER
2F58 KANGXI RADICAL DOUBLE X
2F59 KANGXI RADICAL HALF TREE TRUNK
2F5A KANGXI RADICAL SLICE
2F5B KANGXI RADICAL FANG
2F5C KANGXI RADICAL COW
2F5D KANGXI RADICAL DOG
2F5E KANGXI RADICAL PROFOUND
2F5F KANGXI RADICAL JADE
2F60 KANGXI RADICAL MELON
2F61 KANGXI RADICAL TILE
2F62 KANGXI RADICAL SWEET
2F63 KANGXI RADICAL LIFE
2F64 KANGXI RADICAL USE
2F65 KANGXI RADICAL FIELD
2F66 KANGXI RADICAL BOLT OF CLOTH
2F67 KANGXI RADICAL SICKNESS
2F68 KANGXI RADICAL DOTTED TENT
2F69 KANGXI RADICAL WHITE
2F6A KANGXI RADICAL SKIN
2F6B KANGXI RADICAL DISH
2F6C KANGXI RADICAL EYE
2F6D KANGXI RADICAL SPEAR
2F6E KANGXI RADICAL ARROW
2F6F KANGXI RADICAL STONE
2F70 KANGXI RADICAL SPIRIT
2F71 KANGXI RADICAL TRACK
2F72 KANGXI RADICAL GRAIN
2F73 KANGXI RADICAL CAVE
2F74 KANGXI RADICAL STAND
2F75 KANGXI RADICAL BAMBOO
2F76 KANGXI RADICAL RICE
2F77 KANGXI RADICAL SILK
2F78 KANGXI RADICAL JAR
2F79 KANGXI RADICAL NET
2F7A KANGXI RADICAL SHEEP
2F7B KANGXI RADICAL FEATHER
2F7C KANGXI RADICAL OLD
2F7D KANGXI RADICAL AND
2F7E KANGXI RADICAL PLOW
2F7F KANGXI RADICAL EAR
2F80 KANGXI RADICAL BRUSH
2F81 KANGXI RADICAL MEAT
2F82 KANGXI RADICAL MINISTER
2F83 KANGXI RADICAL SELF
2F84 KANGXI RADICAL ARRIVE
2F85 KANGXI RADICAL MORTAR
2F86 KANGXI RADICAL TONGUE
2F87 KANGXI RADICAL OPPOSE
2F88 KANGXI RADICAL BOAT
2F89 KANGXI RADICAL STOPPING
2F8A KANGXI RADICAL COLOR
2F8B KANGXI RADICAL GRASS
2F8C KANGXI RADICAL TIGER
2F8D KANGXI RADICAL INSECT
2F8E KANGXI RADICAL BLOOD
2F8F KANGXI RADICAL WALK ENCLOSURE
2F90 KANGXI RADICAL CLOTHES
2F91 KANGXI RADICAL WEST
2F92 KANGXI RADICAL SEE
2F93 KANGXI RADICAL HORN
2F94 KANGXI RADICAL SPEECH
2F95 KANGXI RADICAL VALLEY
2F96 KANGXI RADICAL BEAN
2F97 KANGXI RADICAL PIG
2F98 KANGXI RADICAL BADGER
2F99 KANGXI RADICAL SHELL
2F9A KANGXI RADICAL RED
2F9B KANGXI RADICAL RUN
2F9C KANGXI RADICAL FOOT
2F9D KANGXI RADICAL BODY
2F9E KANGXI RADICAL CART
2F9F KANGXI RADICAL BITTER
2FA0 KANGXI RADICAL MORNING
2FA1 KANGXI RADICAL WALK
2FA2 KANGXI RADICAL CITY
2FA3 KANGXI RADICAL WINE
2FA4 KANGXI RADICAL DISTINGUISH
2FA5 KANGXI RADICAL VILLAGE
2FA6 KANGXI RADICAL GOLD
2FA7 KANGXI RADICAL LONG
2FA8 KANGXI RADICAL GATE
2FA9 KANGXI RADICAL MOUND
2FAA KANGXI RADICAL SLAVE
2FAB KANGXI RADICAL SHORT TAILED BIRD
2FAC KANGXI RADICAL RAIN
2FAD KANGXI RADICAL BLUE
2FAE KANGXI RADICAL WRONG
2FAF KANGXI RADICAL FACE
2FB0 KANGXI RADICAL LEATHER
2FB1 KANGXI RADICAL TANNED LEATHER
2FB2 KANGXI RADICAL LEEK
2FB3 KANGXI RADICAL SOUND
2FB4 KANGXI RADICAL LEAF
2FB5 KANGXI RADICAL WIND
2FB6 KANGXI RADICAL FLY
2FB7 KANGXI RADICAL EAT
2FB8 KANGXI RADICAL HEAD
2FB9 KANGXI RADICAL FRAGRANT
2FBA KANGXI RADICAL HORSE
2FBB KANGXI RADICAL BONE
2FBC KANGXI RADICAL TALL
2FBD KANGXI RADICAL HAIR
2FBE KANGXI RADICAL FIGHT
2FBF KANGXI RADICAL SACRIFICIAL WINE
2FC0 KANGXI RADICAL CAULDRON
2FC1 KANGXI RADICAL GHOST
2FC2 KANGXI RADICAL FISH
2FC3 KANGXI RADICAL BIRD
2FC4 KANGXI RADICAL SALT
2FC5 KANGXI RADICAL DEER
2FC6 KANGXI RADICAL WHEAT
2FC7 KANGXI RADICAL HEMP
2FC8 KANGXI RADICAL YELLOW
2FC9 KANGXI RADICAL MILLET
2FCA KANGXI RADICAL BLACK
2FCB KANGXI RADICAL EMBROIDERY
2FCC KANGXI RADICAL FROG
2FCD KANGXI RADICAL TRIPOD
2FCE KANGXI RADICAL DRUM
2FCF KANGXI RADICAL RAT
2FD0 KANGXI RADICAL NOSE
2FD1 KANGXI RADICAL EVEN
2FD2 KANGXI RADICAL TOOTH
2FD3 KANGXI RADICAL DRAGON
2FD4 KANGXI RADICAL TURTLE
2FD5 KANGXI RADICAL FLUTE
2FF0 IDEOGRAPHIC DESCRIPTION CHARACTER LEFT TO RIGHT
2FF1 IDEOGRAPHIC DESCRIPTION CHARACTER ABOVE TO BELOW
2FF2 IDEOGRAPHIC DESCRIPTION CHARACTER LEFT TO MIDDLE AND RIGHT
2FF3 IDEOGRAPHIC DESCRIPTION CHARACTER ABOVE TO MIDDLE AND BELOW
2FF4 IDEOGRAPHIC DESCRIPTION CHARACTER FULL SURROUND
2FF5 IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM ABOVE
2FF6 IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM BELOW
2FF7 IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM LEFT
2FF8 IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM UPPER LEFT
2FF9 IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM UPPER RIGHT
2FFA IDEOGRAPHIC DESCRIPTION CHARACTER SURROUND FROM LOWER LEFT
2FFB IDEOGRAPHIC DESCRIPTION CHARACTER OVERLAID
3000 IDEOGRAPHIC SPACE
3001 IDEOGRAPHIC COMMA
3002 IDEOGRAPHIC FULL STOP
3003 DITTO MARK
3004 JAPANESE INDUSTRIAL STANDARD SYMBOL
3005 IDEOGRAPHIC ITERATION MARK
3006 IDEOGRAPHIC CLOSING MARK
3007 IDEOGRAPHIC NUMBER ZERO
3008 LEFT ANGLE BRACKET
3009 RIGHT ANGLE BRACKET
300A LEFT DOUBLE ANGLE BRACKET
300B RIGHT DOUBLE ANGLE BRACKET
300C LEFT CORNER BRACKET
300D RIGHT CORNER BRACKET
300E LEFT WHITE CORNER BRACKET
300F RIGHT WHITE CORNER BRACKET
3010 LEFT BLACK LENTICULAR BRACKET
3011 RIGHT BLACK LENTICULAR BRACKET
3012 POSTAL MARK
3013 GETA MARK
3014 LEFT TORTOISE SHELL BRACKET
3015 RIGHT TORTOISE SHELL BRACKET
3016 LEFT WHITE LENTICULAR BRACKET
3017 RIGHT WHITE LENTICULAR BRACKET
3018 LEFT WHITE TORTOISE SHELL BRACKET
3019 RIGHT WHITE TORTOISE SHELL BRACKET
301A LEFT WHITE SQUARE BRACKET
301B RIGHT WHITE SQUARE BRACKET
301C WAVE DASH
301D REVERSED DOUBLE PRIME QUOTATION MARK
301E DOUBLE PRIME QUOTATION MARK
301F LOW DOUBLE PRIME QUOTATION MARK
3020 POSTAL MARK FACE
3021 HANGZHOU NUMERAL ONE
3022 HANGZHOU NUMERAL TWO
3023 HANGZHOU NUMERAL THREE
3024 HANGZHOU NUMERAL FOUR
3025 HANGZHOU NUMERAL FIVE
3026 HANGZHOU NUMERAL SIX
3027 HANGZHOU NUMERAL SEVEN
3028 HANGZHOU NUMERAL EIGHT
3029 HANGZHOU NUMERAL NINE
302A IDEOGRAPHIC LEVEL TONE MARK
302B IDEOGRAPHIC RISING TONE MARK
302C IDEOGRAPHIC DEPARTING TONE MARK
302D IDEOGRAPHIC ENTERING TONE MARK
302E HANGUL SINGLE DOT TONE MARK
302F HANGUL DOUBLE DOT TONE MARK
3030 WAVY DASH
3031 VERTICAL KANA REPEAT MARK
3032 VERTICAL KANA REPEAT WITH VOICED SOUND MARK
3033 VERTICAL KANA REPEAT MARK UPPER HALF
3034 VERTICAL KANA REPEAT WITH VOICED SOUND MARK UPPER HALF
3035 VERTICAL KANA REPEAT MARK LOWER HALF
3036 CIRCLED POSTAL MARK
3037 IDEOGRAPHIC TELEGRAPH LINE FEED SEPARATOR SYMBOL
3038 HANGZHOU NUMERAL TEN
3039 HANGZHOU NUMERAL TWENTY
303A HANGZHOU NUMERAL THIRTY
303B VERTICAL IDEOGRAPHIC ITERATION MARK
303C MASU MARK
303D PART ALTERNATION MARK
303E IDEOGRAPHIC VARIATION INDICATOR
303F IDEOGRAPHIC HALF FILL SPACE
3041 HIRAGANA LETTER SMALL A
3042 HIRAGANA LETTER A
3043 HIRAGANA LETTER SMALL I
3044 HIRAGANA LETTER I
3045 HIRAGANA LETTER SMALL U
3046 HIRAGANA LETTER U
3047 HIRAGANA LETTER SMALL E
3048 HIRAGANA LETTER E
3049 HIRAGANA LETTER SMALL O
304A HIRAGANA LETTER O
304B HIRAGANA LETTER KA
304C HIRAGANA LETTER GA
304D HIRAGANA LETTER KI
304E HIRAGANA LETTER GI
304F HIRAGANA LETTER KU
3050 HIRAGANA LETTER GU
3051 HIRAGANA LETTER KE
3052 HIRAGANA LETTER GE
3053 HIRAGANA LETTER KO
3054 HIRAGANA LETTER GO
3055 HIRAGANA LETTER SA
3056 HIRAGANA LETTER ZA
3057 HIRAGANA LETTER SI
3058 HIRAGANA LETTER ZI
3059 HIRAGANA LETTER SU
305A HIRAGANA LETTER ZU
305B HIRAGANA LETTER SE
305C HIRAGANA LETTER ZE
305D HIRAGANA LETTER SO
305E HIRAGANA LETTER ZO
305F HIRAGANA LETTER TA
3060 HIRAGANA LETTER DA
3061 HIRAGANA LETTER TI
3062 HIRAGANA LETTER DI
3063 HIRAGANA LETTER SMALL TU
3064 HIRAGANA LETTER TU
3065 HIRAGANA LETTER DU
3066 HIRAGANA LETTER TE
3067 HIRAGANA LETTER DE
3068 HIRAGANA LETTER TO
3069 HIRAGANA LETTER DO
306A HIRAGANA LETTER NA
306B HIRAGANA LETTER NI
306C HIRAGANA LETTER NU
306D HIRAGANA LETTER NE
306E HIRAGANA LETTER NO
306F HIRAGANA LETTER HA
3070 HIRAGANA LETTER BA
3071 HIRAGANA LETTER PA
3072 HIRAGANA LETTER HI
3073 HIRAGANA LETTER BI
3074 HIRAGANA LETTER PI
3075 HIRAGANA LETTER HU
3076 HIRAGANA LETTER BU
3077 HIRAGANA LETTER PU
3078 HIRAGANA LETTER HE
3079 HIRAGANA LETTER BE
307A HIRAGANA LETTER PE
307B HIRAGANA LETTER HO
307C HIRAGANA LETTER BO
307D HIRAGANA LETTER PO
307E HIRAGANA LETTER MA
307F HIRAGANA LETTER MI
3080 HIRAGANA LETTER MU
3081 HIRAGANA LETTER ME
3082 HIRAGANA LETTER MO
3083 HIRAGANA LETTER SMALL YA
3084 HIRAGANA LETTER YA
3085 HIRAGANA LETTER SMALL YU
3086 HIRAGANA LETTER YU
3087 HIRAGANA LETTER SMALL YO
3088 HIRAGANA LETTER YO
3089 HIRAGANA LETTER RA
308A HIRAGANA LETTER RI
308B HIRAGANA LETTER RU
308C HIRAGANA LETTER RE
308D HIRAGANA LETTER RO
308E HIRAGANA LETTER SMALL WA
308F HIRAGANA LETTER WA
3090 HIRAGANA LETTER WI
3091 HIRAGANA LETTER WE
3092 HIRAGANA LETTER WO
3093 HIRAGANA LETTER N
3094 HIRAGANA LETTER VU
3095 HIRAGANA LETTER SMALL KA
3096 HIRAGANA LETTER SMALL KE
3099 COMBINING KATAKANA-HIRAGANA VOICED SOUND MARK
309A COMBINING KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK
309B KATAKANA-HIRAGANA VOICED SOUND MARK
309C KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK
309D HIRAGANA ITERATION MARK
309E HIRAGANA VOICED ITERATION MARK
309F HIRAGANA DIGRAPH YORI
30A0 KATAKANA-HIRAGANA DOUBLE HYPHEN
30A1 KATAKANA LETTER SMALL A
30A2 KATAKANA LETTER A
30A3 KATAKANA LETTER SMALL I
30A4 KATAKANA LETTER I
30A5 KATAKANA LETTER SMALL U
30A6 KATAKANA LETTER U
30A7 KATAKANA LETTER SMALL E
30A8 KATAKANA LETTER E
30A9 KATAKANA LETTER SMALL O
30AA KATAKANA LETTER O
30AB KATAKANA LETTER KA
30AC KATAKANA LETTER GA
30AD KATAKANA LETTER KI
30AE KATAKANA LETTER GI
30AF KATAKANA LETTER KU
30B0 KATAKANA LETTER GU
30B1 KATAKANA LETTER KE
30B2 KATAKANA LETTER GE
30B3 KATAKANA LETTER KO
30B4 KATAKANA LETTER GO
30B5 KATAKANA LETTER SA
30B6 KATAKANA LETTER ZA
30B7 KATAKANA LETTER SI
30B8 KATAKANA LETTER ZI
30B9 KATAKANA LETTER SU
30BA KATAKANA LETTER ZU
30BB KATAKANA LETTER SE
30BC KATAKANA LETTER ZE
30BD KATAKANA LETTER SO
30BE KATAKANA LETTER ZO
30BF KATAKANA LETTER TA
30C0 KATAKANA LETTER DA
30C1 KATAKANA LETTER TI
30C2 KATAKANA LETTER DI
30C3 KATAKANA LETTER SMALL TU
30C4 KATAKANA LETTER TU
30C5 KATAKANA LETTER DU
30C6 KATAKANA LETTER TE
30C7 KATAKANA LETTER DE
30C8 KATAKANA LETTER TO
30C9 KATAKANA LETTER DO
30CA KATAKANA LETTER NA
30CB KATAKANA LETTER NI
30CC KATAKANA LETTER NU
30CD KATAKANA LETTER NE
30CE KATAKANA LETTER NO
30CF KATAKANA LETTER HA
30D0 KATAKANA LETTER BA
30D1 KATAKANA LETTER PA
30D2 KATAKANA LETTER HI
30D3 KATAKANA LETTER BI
30D4 KATAKANA LETTER PI
30D5 KATAKANA LETTER HU
30D6 KATAKANA LETTER BU
30D7 KATAKANA LETTER PU
30D8 KATAKANA LETTER HE
30D9 KATAKANA LETTER BE
30DA KATAKANA LETTER PE
30DB KATAKANA LETTER HO
30DC KATAKANA LETTER BO
30DD KATAKANA LETTER PO
30DE KATAKANA LETTER MA
30DF KATAKANA LETTER MI
30E0 KATAKANA LETTER MU
30E1 KATAKANA LETTER ME
30E2 KATAKANA LETTER MO
30E3 KATAKANA LETTER SMALL YA
30E4 KATAKANA LETTER YA
30E5 KATAKANA LETTER SMALL YU
30E6 KATAKANA LETTER YU
30E7 KATAKANA LETTER SMALL YO
30E8 KATAKANA LETTER YO
30E9 KATAKANA LETTER RA
30EA KATAKANA LETTER RI
30EB KATAKANA LETTER RU
30EC KATAKANA LETTER RE
30ED KATAKANA LETTER RO
30EE KATAKANA LETTER SMALL WA
30EF KATAKANA LETTER WA
30F0 KATAKANA LETTER WI
30F1 KATAKANA LETTER WE
30F2 KATAKANA LETTER WO
30F3 KATAKANA LETTER N
30F4 KATAKANA LETTER VU
30F5 KATAKANA LETTER SMALL KA
30F6 KATAKANA LETTER SMALL KE
30F7 KATAKANA LETTER VA
30F8 KATAKANA LETTER VI
30F9 KATAKANA LETTER VE
30FA KATAKANA LETTER VO
30FB KATAKANA MIDDLE DOT
30FC KATAKANA-HIRAGANA PROLONGED SOUND MARK
30FD KATAKANA ITERATION MARK
30FE KATAKANA VOICED ITERATION MARK
30FF KATAKANA DIGRAPH KOTO
3105 BOPOMOFO LETTER B
3106 BOPOMOFO LETTER P
3107 BOPOMOFO LETTER M
3108 BOPOMOFO LETTER F
3109 BOPOMOFO LETTER D
310A BOPOMOFO LETTER T
310B BOPOMOFO LETTER N
310C BOPOMOFO LETTER L
310D BOPOMOFO LETTER G
310E BOPOMOFO LETTER K
310F BOPOMOFO LETTER H
3110 BOPOMOFO LETTER J
3111 BOPOMOFO LETTER Q
3112 BOPOMOFO LETTER X
3113 BOPOMOFO LETTER ZH
3114 BOPOMOFO LETTER CH
3115 BOPOMOFO LETTER SH
3116 BOPOMOFO LETTER R
3117 BOPOMOFO LETTER Z
3118 BOPOMOFO LETTER C
3119 BOPOMOFO LETTER S
311A BOPOMOFO LETTER A
311B BOPOMOFO LETTER O
311C BOPOMOFO LETTER E
311D BOPOMOFO LETTER EH
311E BOPOMOFO LETTER AI
311F BOPOMOFO LETTER EI
3120 BOPOMOFO LETTER AU
3121 BOPOMOFO LETTER OU
3122 BOPOMOFO LETTER AN
3123 BOPOMOFO LETTER EN
3124 BOPOMOFO LETTER ANG
3125 BOPOMOFO LETTER ENG
3126 BOPOMOFO LETTER ER
3127 BOPOMOFO LETTER I
3128 BOPOMOFO LETTER U
3129 BOPOMOFO LETTER IU
312A BOPOMOFO LETTER V
312B BOPOMOFO LETTER NG
312C BOPOMOFO LETTER GN
312D BOPOMOFO LETTER IH
312E BOPOMOFO LETTER O WITH DOT ABOVE
3131 HANGUL LETTER KIYEOK
3132 HANGUL LETTER SSANGKIYEOK
3133 HANGUL LETTER KIYEOK-SIOS
3134 HANGUL LETTER NIEUN
3135 HANGUL LETTER NIEUN-CIEUC
3136 HANGUL LETTER NIEUN-HIEUH
3137 HANGUL LETTER TIKEUT
3138 HANGUL LETTER SSANGTIKEUT
3139 HANGUL LETTER RIEUL
313A HANGUL LETTER RIEUL-KIYEOK
313B HANGUL LETTER RIEUL-MIEUM
313C HANGUL LETTER RIEUL-PIEUP
313D HANGUL LETTER RIEUL-SIOS
313E HANGUL LETTER RIEUL-THIEUTH
313F HANGUL LETTER RIEUL-PHIEUPH
3140 HANGUL LETTER RIEUL-HIEUH
3141 HANGUL LETTER MIEUM
3142 HANGUL LETTER PIEUP
3143 HANGUL LETTER SSANGPIEUP
3144 HANGUL LETTER PIEUP-SIOS
3145 HANGUL LETTER SIOS
3146 HANGUL LETTER SSANGSIOS
3147 HANGUL LETTER IEUNG
3148 HANGUL LETTER CIEUC
3149 HANGUL LETTER SSANGCIEUC
314A HANGUL LETTER CHIEUCH
314B HANGUL LETTER KHIEUKH
314C HANGUL LETTER THIEUTH
314D HANGUL LETTER PHIEUPH
314E HANGUL LETTER HIEUH
314F HANGUL LETTER A
3150 HANGUL LETTER AE
3151 HANGUL LETTER YA
3152 HANGUL LETTER YAE
3153 HANGUL LETTER EO
3154 HANGUL LETTER E
3155 HANGUL LETTER YEO
3156 HANGUL LETTER YE
3157 HANGUL LETTER O
3158 HANGUL LETTER WA
3159 HANGUL LETTER WAE
315A HANGUL LETTER OE
315B HANGUL LETTER YO
315C HANGUL LETTER U
315D HANGUL LETTER WEO
315E HANGUL LETTER WE
315F HANGUL LETTER WI
3160 HANGUL LETTER YU
3161 HANGUL LETTER EU
3162 HANGUL LETTER YI
3163 HANGUL LETTER I
3164 HANGUL FILLER
3165 HANGUL LETTER SSANGNIEUN
3166 HANGUL LETTER NIEUN-TIKEUT
3167 HANGUL LETTER NIEUN-SIOS
3168 HANGUL LETTER NIEUN-PANSIOS
3169 HANGUL LETTER RIEUL-KIYEOK-SIOS
316A HANGUL LETTER RIEUL-TIKEUT
316B HANGUL LETTER RIEUL-PIEUP-SIOS
316C HANGUL LETTER RIEUL-PANSIOS
316D HANGUL LETTER RIEUL-YEORINHIEUH
316E HANGUL LETTER MIEUM-PIEUP
316F HANGUL LETTER MIEUM-SIOS
3170 HANGUL LETTER MIEUM-PANSIOS
3171 HANGUL LETTER KAPYEOUNMIEUM
3172 HANGUL LETTER PIEUP-KIYEOK
3173 HANGUL LETTER PIEUP-TIKEUT
3174 HANGUL LETTER PIEUP-SIOS-KIYEOK
3175 HANGUL LETTER PIEUP-SIOS-TIKEUT
3176 HANGUL LETTER PIEUP-CIEUC
3177 HANGUL LETTER PIEUP-THIEUTH
3178 HANGUL LETTER KAPYEOUNPIEUP
3179 HANGUL LETTER KAPYEOUNSSANGPIEUP
317A HANGUL LETTER SIOS-KIYEOK
317B HANGUL LETTER SIOS-NIEUN
317C HANGUL LETTER SIOS-TIKEUT
317D HANGUL LETTER SIOS-PIEUP
317E HANGUL LETTER SIOS-CIEUC
317F HANGUL LETTER PANSIOS
3180 HANGUL LETTER SSANGIEUNG
3181 HANGUL LETTER YESIEUNG
3182 HANGUL LETTER YESIEUNG-SIOS
3183 HANGUL LETTER YESIEUNG-PANSIOS
3184 HANGUL LETTER KAPYEOUNPHIEUPH
3185 HANGUL LETTER SSANGHIEUH
3186 HANGUL LETTER YEORINHIEUH
3187 HANGUL LETTER YO-YA
3188 HANGUL LETTER YO-YAE
3189 HANGUL LETTER YO-I
318A HANGUL LETTER YU-YEO
318B HANGUL LETTER YU-YE
318C HANGUL LETTER YU-I
318D HANGUL LETTER ARAEA
318E HANGUL LETTER ARAEAE
3190 IDEOGRAPHIC ANNOTATION LINKING MARK
3191 IDEOGRAPHIC ANNOTATION REVERSE MARK
3192 IDEOGRAPHIC ANNOTATION ONE MARK
3193 IDEOGRAPHIC ANNOTATION TWO MARK
3194 IDEOGRAPHIC ANNOTATION THREE MARK
3195 IDEOGRAPHIC ANNOTATION FOUR MARK
3196 IDEOGRAPHIC ANNOTATION TOP MARK
3197 IDEOGRAPHIC ANNOTATION MIDDLE MARK
3198 IDEOGRAPHIC ANNOTATION BOTTOM MARK
3199 IDEOGRAPHIC ANNOTATION FIRST MARK
319A IDEOGRAPHIC ANNOTATION SECOND MARK
319B IDEOGRAPHIC ANNOTATION THIRD MARK
319C IDEOGRAPHIC ANNOTATION FOURTH MARK
319D IDEOGRAPHIC ANNOTATION HEAVEN MARK
319E IDEOGRAPHIC ANNOTATION EARTH MARK
319F IDEOGRAPHIC ANNOTATION MAN MARK
31A0 BOPOMOFO LETTER BU
31A1 BOPOMOFO LETTER ZI
31A2 BOPOMOFO LETTER JI
31A3 BOPOMOFO LETTER GU
31A4 BOPOMOFO LETTER EE
31A5 BOPOMOFO LETTER ENN
31A6 BOPOMOFO LETTER OO
31A7 BOPOMOFO LETTER ONN
31A8 BOPOMOFO LETTER IR
31A9 BOPOMOFO LETTER ANN
31AA BOPOMOFO LETTER INN
31AB BOPOMOFO LETTER UNN
31AC BOPOMOFO LETTER IM
31AD BOPOMOFO LETTER NGG
31AE BOPOMOFO LETTER AINN
31AF BOPOMOFO LETTER AUNN
31B0 BOPOMOFO LETTER AM
31B1 BOPOMOFO LETTER OM
31B2 BOPOMOFO LETTER ONG
31B3 BOPOMOFO LETTER INNN
31B4 BOPOMOFO FINAL LETTER P
31B5 BOPOMOFO FINAL LETTER T
31B6 BOPOMOFO FINAL LETTER K
31B7 BOPOMOFO FINAL LETTER H
31B8 BOPOMOFO LETTER GH
31B9 BOPOMOFO LETTER LH
31BA BOPOMOFO LETTER ZY
31C0 CJK STROKE T
31C1 CJK STROKE WG
31C2 CJK STROKE XG
31C3 CJK STROKE BXG
31C4 CJK STROKE SW
31C5 CJK STROKE HZZ
31C6 CJK STROKE HZG
31C7 CJK STROKE HP
31C8 CJK STROKE HZWG
31C9 CJK STROKE SZWG
31CA CJK STROKE HZT
31CB CJK STROKE HZZP
31CC CJK STROKE HPWG
31CD CJK STROKE HZW
31CE CJK STROKE HZZZ
31CF CJK STROKE N
31D0 CJK STROKE H
31D1 CJK STROKE S
31D2 CJK STROKE P
31D3 CJK STROKE SP
31D4 CJK STROKE D
31D5 CJK STROKE HZ
31D6 CJK STROKE HG
31D7 CJK STROKE SZ
31D8 CJK STROKE SWZ
31D9 CJK STROKE ST
31DA CJK STROKE SG
31DB CJK STROKE PD
31DC CJK STROKE PZ
31DD CJK STROKE TN
31DE CJK STROKE SZZ
31DF CJK STROKE SWG
31E0 CJK STROKE HXWG
31E1 CJK STROKE HZZZG
31E2 CJK STROKE PG
31E3 CJK STROKE Q
31F0 KATAKANA LETTER SMALL KU
31F1 KATAKANA LETTER SMALL SI
31F2 KATAKANA LETTER SMALL SU
31F3 KATAKANA LETTER SMALL TO
31F4 KATAKANA LETTER SMALL NU
31F5 KATAKANA LETTER SMALL HA
31F6 KATAKANA LETTER SMALL HI
31F7 KATAKANA LETTER SMALL HU
31F8 KATAKANA LETTER SMALL HE
31F9 KATAKANA LETTER SMALL HO
31FA KATAKANA LETTER SMALL MU
31FB KATAKANA LETTER SMALL RA
31FC KATAKANA LETTER SMALL RI
31FD KATAKANA LETTER SMALL RU
31FE KATAKANA LETTER SMALL RE
31FF KATAKANA LETTER SMALL RO
3200 PARENTHESIZED HANGUL KIYEOK
3201 PARENTHESIZED HANGUL NIEUN
3202 PARENTHESIZED HANGUL TIKEUT
3203 PARENTHESIZED HANGUL RIEUL
3204 PARENTHESIZED HANGUL MIEUM
3205 PARENTHESIZED HANGUL PIEUP
3206 PARENTHESIZED HANGUL SIOS
3207 PARENTHESIZED HANGUL IEUNG
3208 PARENTHESIZED HANGUL CIEUC
3209 PARENTHESIZED HANGUL CHIEUCH
320A PARENTHESIZED HANGUL KHIEUKH
320B PARENTHESIZED HANGUL THIEUTH
320C PARENTHESIZED HANGUL PHIEUPH
320D PARENTHESIZED HANGUL HIEUH
320E PARENTHESIZED HANGUL KIYEOK A
320F PARENTHESIZED HANGUL NIEUN A
3210 PARENTHESIZED HANGUL TIKEUT A
3211 PARENTHESIZED HANGUL RIEUL A
3212 PARENTHESIZED HANGUL MIEUM A
3213 PARENTHESIZED HANGUL PIEUP A
3214 PARENTHESIZED HANGUL SIOS A
3215 PARENTHESIZED HANGUL IEUNG A
3216 PARENTHESIZED HANGUL CIEUC A
3217 PARENTHESIZED HANGUL CHIEUCH A
3218 PARENTHESIZED HANGUL KHIEUKH A
3219 PARENTHESIZED HANGUL THIEUTH A
321A PARENTHESIZED HANGUL PHIEUPH A
321B PARENTHESIZED HANGUL HIEUH A
321C PARENTHESIZED HANGUL CIEUC U
321D PARENTHESIZED KOREAN CHARACTER OJEON
321E PARENTHESIZED KOREAN CHARACTER O HU
3220 PARENTHESIZED IDEOGRAPH ONE
3221 PARENTHESIZED IDEOGRAPH TWO
3222 PARENTHESIZED IDEOGRAPH THREE
3223 PARENTHESIZED IDEOGRAPH FOUR
3224 PARENTHESIZED IDEOGRAPH FIVE
3225 PARENTHESIZED IDEOGRAPH SIX
3226 PARENTHESIZED IDEOGRAPH SEVEN
3227 PARENTHESIZED IDEOGRAPH EIGHT
3228 PARENTHESIZED IDEOGRAPH NINE
3229 PARENTHESIZED IDEOGRAPH TEN
322A PARENTHESIZED IDEOGRAPH MOON
322B PARENTHESIZED IDEOGRAPH FIRE
322C PARENTHESIZED IDEOGRAPH WATER
322D PARENTHESIZED IDEOGRAPH WOOD
322E PARENTHESIZED IDEOGRAPH METAL
322F PARENTHESIZED IDEOGRAPH EARTH
3230 PARENTHESIZED IDEOGRAPH SUN
3231 PARENTHESIZED IDEOGRAPH STOCK
3232 PARENTHESIZED IDEOGRAPH HAVE
3233 PARENTHESIZED IDEOGRAPH SOCIETY
3234 PARENTHESIZED IDEOGRAPH NAME
3235 PARENTHESIZED IDEOGRAPH SPECIAL
3236 PARENTHESIZED IDEOGRAPH FINANCIAL
3237 PARENTHESIZED IDEOGRAPH CONGRATULATION
3238 PARENTHESIZED IDEOGRAPH LABOR
3239 PARENTHESIZED IDEOGRAPH REPRESENT
323A PARENTHESIZED IDEOGRAPH CALL
323B PARENTHESIZED IDEOGRAPH STUDY
323C PARENTHESIZED IDEOGRAPH SUPERVISE
323D PARENTHESIZED IDEOGRAPH ENTERPRISE
323E PARENTHESIZED IDEOGRAPH RESOURCE
323F PARENTHESIZED IDEOGRAPH ALLIANCE
3240 PARENTHESIZED IDEOGRAPH FESTIVAL
3241 PARENTHESIZED IDEOGRAPH REST
3242 PARENTHESIZED IDEOGRAPH SELF
3243 PARENTHESIZED IDEOGRAPH REACH
3244 CIRCLED IDEOGRAPH QUESTION
3245 CIRCLED IDEOGRAPH KINDERGARTEN
3246 CIRCLED IDEOGRAPH SCHOOL
3247 CIRCLED IDEOGRAPH KOTO
3248 CIRCLED NUMBER TEN ON BLACK SQUARE
3249 CIRCLED NUMBER TWENTY ON BLACK SQUARE
324A CIRCLED NUMBER THIRTY ON BLACK SQUARE
324B CIRCLED NUMBER FORTY ON BLACK SQUARE
324C CIRCLED NUMBER FIFTY ON BLACK SQUARE
324D CIRCLED NUMBER SIXTY ON BLACK SQUARE
324E CIRCLED NUMBER SEVENTY ON BLACK SQUARE
324F CIRCLED NUMBER EIGHTY ON BLACK SQUARE
3250 PARTNERSHIP SIGN
3251 CIRCLED NUMBER TWENTY ONE
3252 CIRCLED NUMBER TWENTY TWO
3253 CIRCLED NUMBER TWENTY THREE
3254 CIRCLED NUMBER TWENTY FOUR
3255 CIRCLED NUMBER TWENTY FIVE
3256 CIRCLED NUMBER TWENTY SIX
3257 CIRCLED NUMBER TWENTY SEVEN
3258 CIRCLED NUMBER TWENTY EIGHT
3259 CIRCLED NUMBER TWENTY NINE
325A CIRCLED NUMBER THIRTY
325B CIRCLED NUMBER THIRTY ONE
325C CIRCLED NUMBER THIRTY TWO
325D CIRCLED NUMBER THIRTY THREE
325E CIRCLED NUMBER THIRTY FOUR
325F CIRCLED NUMBER THIRTY FIVE
3260 CIRCLED HANGUL KIYEOK
3261 CIRCLED HANGUL NIEUN
3262 CIRCLED HANGUL TIKEUT
3263 CIRCLED HANGUL RIEUL
3264 CIRCLED HANGUL MIEUM
3265 CIRCLED HANGUL PIEUP
3266 CIRCLED HANGUL SIOS
3267 CIRCLED HANGUL IEUNG
3268 CIRCLED HANGUL CIEUC
3269 CIRCLED HANGUL CHIEUCH
326A CIRCLED HANGUL KHIEUKH
326B CIRCLED HANGUL THIEUTH
326C CIRCLED HANGUL PHIEUPH
326D CIRCLED HANGUL HIEUH
326E CIRCLED HANGUL KIYEOK A
326F CIRCLED HANGUL NIEUN A
3270 CIRCLED HANGUL TIKEUT A
3271 CIRCLED HANGUL RIEUL A
3272 CIRCLED HANGUL MIEUM A
3273 CIRCLED HANGUL PIEUP A
3274 CIRCLED HANGUL SIOS A
3275 CIRCLED HANGUL IEUNG A
3276 CIRCLED HANGUL CIEUC A
3277 CIRCLED HANGUL CHIEUCH A
3278 CIRCLED HANGUL KHIEUKH A
3279 CIRCLED HANGUL THIEUTH A
327A CIRCLED HANGUL PHIEUPH A
327B CIRCLED HANGUL HIEUH A
327C CIRCLED KOREAN CHARACTER CHAMKO
327D CIRCLED KOREAN CHARACTER JUEUI
327E CIRCLED HANGUL IEUNG U
327F KOREAN STANDARD SYMBOL
3280 CIRCLED IDEOGRAPH ONE
3281 CIRCLED IDEOGRAPH TWO
3282 CIRCLED IDEOGRAPH THREE
3283 CIRCLED IDEOGRAPH FOUR
3284 CIRCLED IDEOGRAPH FIVE
3285 CIRCLED IDEOGRAPH SIX
3286 CIRCLED IDEOGRAPH SEVEN
3287 CIRCLED IDEOGRAPH EIGHT
3288 CIRCLED IDEOGRAPH NINE
3289 CIRCLED IDEOGRAPH TEN
328A CIRCLED IDEOGRAPH MOON
328B CIRCLED IDEOGRAPH FIRE
328C CIRCLED IDEOGRAPH WATER
328D CIRCLED IDEOGRAPH WOOD
328E CIRCLED IDEOGRAPH METAL
328F CIRCLED IDEOGRAPH EARTH
3290 CIRCLED IDEOGRAPH SUN
3291 CIRCLED IDEOGRAPH STOCK
3292 CIRCLED IDEOGRAPH HAVE
3293 CIRCLED IDEOGRAPH SOCIETY
3294 CIRCLED IDEOGRAPH NAME
3295 CIRCLED IDEOGRAPH SPECIAL
3296 CIRCLED IDEOGRAPH FINANCIAL
3297 CIRCLED IDEOGRAPH CONGRATULATION
3298 CIRCLED IDEOGRAPH LABOR
3299 CIRCLED IDEOGRAPH SECRET
329A CIRCLED IDEOGRAPH MALE
329B CIRCLED IDEOGRAPH FEMALE
329C CIRCLED IDEOGRAPH SUITABLE
329D CIRCLED IDEOGRAPH EXCELLENT
329E CIRCLED IDEOGRAPH PRINT
329F CIRCLED IDEOGRAPH ATTENTION
32A0 CIRCLED IDEOGRAPH ITEM
32A1 CIRCLED IDEOGRAPH REST
32A2 CIRCLED IDEOGRAPH COPY
32A3 CIRCLED IDEOGRAPH CORRECT
32A4 CIRCLED IDEOGRAPH HIGH
32A5 CIRCLED IDEOGRAPH CENTRE
32A6 CIRCLED IDEOGRAPH LOW
32A7 CIRCLED IDEOGRAPH LEFT
32A8 CIRCLED IDEOGRAPH RIGHT
32A9 CIRCLED IDEOGRAPH MEDICINE
32AA CIRCLED IDEOGRAPH RELIGION
32AB CIRCLED IDEOGRAPH STUDY
32AC CIRCLED IDEOGRAPH SUPERVISE
32AD CIRCLED IDEOGRAPH ENTERPRISE
32AE CIRCLED IDEOGRAPH RESOURCE
32AF CIRCLED IDEOGRAPH ALLIANCE
32B0 CIRCLED IDEOGRAPH NIGHT
32B1 CIRCLED NUMBER THIRTY SIX
32B2 CIRCLED NUMBER THIRTY SEVEN
32B3 CIRCLED NUMBER THIRTY EIGHT
32B4 CIRCLED NUMBER THIRTY NINE
32B5 CIRCLED NUMBER FORTY
32B6 CIRCLED NUMBER FORTY ONE
32B7 CIRCLED NUMBER FORTY TWO
32B8 CIRCLED NUMBER FORTY THREE
32B9 CIRCLED NUMBER FORTY FOUR
32BA CIRCLED NUMBER FORTY FIVE
32BB CIRCLED NUMBER FORTY SIX
32BC CIRCLED NUMBER FORTY SEVEN
32BD CIRCLED NUMBER FORTY EIGHT
32BE CIRCLED NUMBER FORTY NINE
32BF CIRCLED NUMBER FIFTY
32C0 IDEOGRAPHIC TELEGRAPH SYMBOL FOR JANUARY
32C1 IDEOGRAPHIC TELEGRAPH SYMBOL FOR FEBRUARY
32C2 IDEOGRAPHIC TELEGRAPH SYMBOL FOR MARCH
32C3 IDEOGRAPHIC TELEGRAPH SYMBOL FOR APRIL
32C4 IDEOGRAPHIC TELEGRAPH SYMBOL FOR MAY
32C5 IDEOGRAPHIC TELEGRAPH SYMBOL FOR JUNE
32C6 IDEOGRAPHIC TELEGRAPH SYMBOL FOR JULY
32C7 IDEOGRAPHIC TELEGRAPH SYMBOL FOR AUGUST
32C8 IDEOGRAPHIC TELEGRAPH SYMBOL FOR SEPTEMBER
32C9 IDEOGRAPHIC TELEGRAPH SYMBOL FOR OCTOBER
32CA IDEOGRAPHIC TELEGRAPH SYMBOL FOR NOVEMBER
32CB IDEOGRAPHIC TELEGRAPH SYMBOL FOR DECEMBER
32CC SQUARE HG
32CD SQUARE ERG
32CE SQUARE EV
32CF LIMITED LIABILITY SIGN
32D0 CIRCLED KATAKANA A
32D1 CIRCLED KATAKANA I
32D2 CIRCLED KATAKANA U
32D3 CIRCLED KATAKANA E
32D4 CIRCLED KATAKANA O
32D5 CIRCLED KATAKANA KA
32D6 CIRCLED KATAKANA KI
32D7 CIRCLED KATAKANA KU
32D8 CIRCLED KATAKANA KE
32D9 CIRCLED KATAKANA KO
32DA CIRCLED KATAKANA SA
32DB CIRCLED KATAKANA SI
32DC CIRCLED KATAKANA SU
32DD CIRCLED KATAKANA SE
32DE CIRCLED KATAKANA SO
32DF CIRCLED KATAKANA TA
32E0 CIRCLED KATAKANA TI
32E1 CIRCLED KATAKANA TU
32E2 CIRCLED KATAKANA TE
32E3 CIRCLED KATAKANA TO
32E4 CIRCLED KATAKANA NA
32E5 CIRCLED KATAKANA NI
32E6 CIRCLED KATAKANA NU
32E7 CIRCLED KATAKANA NE
32E8 CIRCLED KATAKANA NO
32E9 CIRCLED KATAKANA HA
32EA CIRCLED KATAKANA HI
32EB CIRCLED KATAKANA HU
32EC CIRCLED KATAKANA HE
32ED CIRCLED KATAKANA HO
32EE CIRCLED KATAKANA MA
32EF CIRCLED KATAKANA MI
32F0 CIRCLED KATAKANA MU
32F1 CIRCLED KATAKANA ME
32F2 CIRCLED KATAKANA MO
32F3 CIRCLED KATAKANA YA
32F4 CIRCLED KATAKANA YU
32F5 CIRCLED KATAKANA YO
32F6 CIRCLED KATAKANA RA
32F7 CIRCLED KATAKANA RI
32F8 CIRCLED KATAKANA RU
32F9 CIRCLED KATAKANA RE
32FA CIRCLED KATAKANA RO
32FB CIRCLED KATAKANA WA
32FC CIRCLED KATAKANA WI
32FD CIRCLED KATAKANA WE
32FE CIRCLED KATAKANA WO
3300 SQUARE APAATO
3301 SQUARE ARUHUA
3302 SQUARE ANPEA
3303 SQUARE AARU
3304 SQUARE ININGU
3305 SQUARE INTI
3306 SQUARE UON
3307 SQUARE ESUKUUDO
3308 SQUARE EEKAA
3309 SQUARE ONSU
330A SQUARE OOMU
330B SQUARE KAIRI
330C SQUARE KARATTO
330D SQUARE KARORII
330E SQUARE GARON
330F SQUARE GANMA
3310 SQUARE GIGA
3311 SQUARE GINII
3312 SQUARE KYURII
3313 SQUARE GIRUDAA
3314 SQUARE KIRO
3315 SQUARE KIROGURAMU
3316 SQUARE KIROMEETORU
3317 SQUARE KIROWATTO
3318 SQUARE GURAMU
3319 SQUARE GURAMUTON
331A SQUARE KURUZEIRO
331B SQUARE KUROONE
331C SQUARE KEESU
331D SQUARE KORUNA
331E SQUARE KOOPO
331F SQUARE SAIKURU
3320 SQUARE SANTIIMU
3321 SQUARE SIRINGU
3322 SQUARE SENTI
3323 SQUARE SENTO
3324 SQUARE DAASU
3325 SQUARE DESI
3326 SQUARE DORU
3327 SQUARE TON
3328 SQUARE NANO
3329 SQUARE NOTTO
332A SQUARE HAITU
332B SQUARE PAASENTO
332C SQUARE PAATU
332D SQUARE BAARERU
332E SQUARE PIASUTORU
332F SQUARE PIKURU
3330 SQUARE PIKO
3331 SQUARE BIRU
3332 SQUARE HUARADDO
3333 SQUARE HUIITO
3334 SQUARE BUSSYERU
3335 SQUARE HURAN
3336 SQUARE HEKUTAARU
3337 SQUARE PESO
3338 SQUARE PENIHI
3339 SQUARE HERUTU
333A SQUARE PENSU
333B SQUARE PEEZI
333C SQUARE BEETA
333D SQUARE POINTO
333E SQUARE BORUTO
333F SQUARE HON
3340 SQUARE PONDO
3341 SQUARE HOORU
3342 SQUARE HOON
3343 SQUARE MAIKURO
3344 SQUARE MAIRU
3345 SQUARE MAHHA
3346 SQUARE MARUKU
3347 SQUARE MANSYON
3348 SQUARE MIKURON
3349 SQUARE MIRI
334A SQUARE MIRIBAARU
334B SQUARE MEGA
334C SQUARE MEGATON
334D SQUARE MEETORU
334E SQUARE YAADO
334F SQUARE YAARU
3350 SQUARE YUAN
3351 SQUARE RITTORU
3352 SQUARE RIRA
3353 SQUARE RUPII
3354 SQUARE RUUBURU
3355 SQUARE REMU
3356 SQUARE RENTOGEN
3357 SQUARE WATTO
3358 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ZERO
3359 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ONE
335A IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWO
335B IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THREE
335C IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOUR
335D IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIVE
335E IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIX
335F IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVEN
3360 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHT
3361 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINE
3362 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TEN
3363 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR ELEVEN
3364 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWELVE
3365 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR THIRTEEN
3366 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FOURTEEN
3367 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR FIFTEEN
3368 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SIXTEEN
3369 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR SEVENTEEN
336A IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR EIGHTEEN
336B IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR NINETEEN
336C IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY
336D IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-ONE
336E IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-TWO
336F IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-THREE
3370 IDEOGRAPHIC TELEGRAPH SYMBOL FOR HOUR TWENTY-FOUR
3371 SQUARE HPA
3372 SQUARE DA
3373 SQUARE AU
3374 SQUARE BAR
3375 SQUARE OV
3376 SQUARE PC
3377 SQUARE DM
3378 SQUARE DM SQUARED
3379 SQUARE DM CUBED
337A SQUARE IU
337B SQUARE ERA NAME HEISEI
337C SQUARE ERA NAME SYOUWA
337D SQUARE ERA NAME TAISYOU
337E SQUARE ERA NAME MEIZI
337F SQUARE CORPORATION
3380 SQUARE PA AMPS
3381 SQUARE NA
3382 SQUARE MU A
3383 SQUARE MA
3384 SQUARE KA
3385 SQUARE KB
3386 SQUARE MB
3387 SQUARE GB
3388 SQUARE CAL
3389 SQUARE KCAL
338A SQUARE PF
338B SQUARE NF
338C SQUARE MU F
338D SQUARE MU G
338E SQUARE MG
338F SQUARE KG
3390 SQUARE HZ
3391 SQUARE KHZ
3392 SQUARE MHZ
3393 SQUARE GHZ
3394 SQUARE THZ
3395 SQUARE MU L
3396 SQUARE ML
3397 SQUARE DL
3398 SQUARE KL
3399 SQUARE FM
339A SQUARE NM
339B SQUARE MU M
339C SQUARE MM
339D SQUARE CM
339E SQUARE KM
339F SQUARE MM SQUARED
33A0 SQUARE CM SQUARED
33A1 SQUARE M SQUARED
33A2 SQUARE KM SQUARED
33A3 SQUARE MM CUBED
33A4 SQUARE CM CUBED
33A5 SQUARE M CUBED
33A6 SQUARE KM CUBED
33A7 SQUARE M OVER S
33A8 SQUARE M OVER S SQUARED
33A9 SQUARE PA
33AA SQUARE KPA
33AB SQUARE MPA
33AC SQUARE GPA
33AD SQUARE RAD
33AE SQUARE RAD OVER S
33AF SQUARE RAD OVER S SQUARED
33B0 SQUARE PS
33B1 SQUARE NS
33B2 SQUARE MU S
33B3 SQUARE MS
33B4 SQUARE PV
33B5 SQUARE NV
33B6 SQUARE MU V
33B7 SQUARE MV
33B8 SQUARE KV
33B9 SQUARE MV MEGA
33BA SQUARE PW
33BB SQUARE NW
33BC SQUARE MU W
33BD SQUARE MW
33BE SQUARE KW
33BF SQUARE MW MEGA
33C0 SQUARE K OHM
33C1 SQUARE M OHM
33C2 SQUARE AM
33C3 SQUARE BQ
33C4 SQUARE CC
33C5 SQUARE CD
33C6 SQUARE C OVER KG
33C7 SQUARE CO
33C8 SQUARE DB
33C9 SQUARE GY
33CA SQUARE HA
33CB SQUARE HP
33CC SQUARE IN
33CD SQUARE KK
33CE SQUARE KM CAPITAL
33CF SQUARE KT
33D0 SQUARE LM
33D1 SQUARE LN
33D2 SQUARE LOG
33D3 SQUARE LX
33D4 SQUARE MB SMALL
33D5 SQUARE MIL
33D6 SQUARE MOL
33D7 SQUARE PH
33D8 SQUARE PM
33D9 SQUARE PPM
33DA SQUARE PR
33DB SQUARE SR
33DC SQUARE SV
33DD SQUARE WB
33DE SQUARE V OVER M
33DF SQUARE A OVER M
33E0 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ONE
33E1 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWO
33E2 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THREE
33E3 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOUR
33E4 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIVE
33E5 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIX
33E6 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVEN
33E7 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHT
33E8 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINE
33E9 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TEN
33EA IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY ELEVEN
33EB IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWELVE
33EC IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTEEN
33ED IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FOURTEEN
33EE IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY FIFTEEN
33EF IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SIXTEEN
33F0 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY SEVENTEEN
33F1 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY EIGHTEEN
33F2 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY NINETEEN
33F3 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY
33F4 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-ONE
33F5 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-TWO
33F6 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-THREE
33F7 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FOUR
33F8 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-FIVE
33F9 IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SIX
33FA IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-SEVEN
33FB IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-EIGHT
33FC IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY TWENTY-NINE
33FD IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY
33FE IDEOGRAPHIC TELEGRAPH SYMBOL FOR DAY THIRTY-ONE
33FF SQUARE GAL
3400 CJK UNIFIED IDEOGRAPH-#3400, IRGKangXi=0078.010, Def{(same as U+4E18 丘) hillock or mound}
3401 CJK UNIFIED IDEOGRAPH-#3401, IRGKangXi=0078.030, Def{to lick; to taste, a mat, bamboo bark}
3402 CJK UNIFIED IDEOGRAPH-#3402, IRGKangXi=0078.101, Def{(J) non-standard form of U+559C 喜, to like, love, enjoy; a joyful thing}
3403 CJK UNIFIED IDEOGRAPH-#3403, IRGKangXi=0079.021
3404 CJK UNIFIED IDEOGRAPH-#3404, IRGKangXi=0079.020
3405 CJK UNIFIED IDEOGRAPH-#3405, IRGKangXi=0081.180, Def{(an ancient form of U+4E94 五) five}
3406 CJK UNIFIED IDEOGRAPH-#3406, IRGKangXi=0083.011, Def{(corrupted form) to follow, to trust to; to put confidence in; to depend on, to turn around; to turn the body, (interchangeable 隱)}
3407 CJK UNIFIED IDEOGRAPH-#3407, IRGKangXi=0084.051
3408 CJK UNIFIED IDEOGRAPH-#3408, IRGKangXi=0084.051
3409 CJK UNIFIED IDEOGRAPH-#3409, IRGKangXi=0084.051
340A CJK UNIFIED IDEOGRAPH-#340A, IRGKangXi=0084.071
340B CJK UNIFIED IDEOGRAPH-#340B, IRGKangXi=0084.071
340C CJK UNIFIED IDEOGRAPH-#340C, IRGKangXi=0084.080, Def{a tribe of savages in South China}
340D CJK UNIFIED IDEOGRAPH-#340D, IRGKangXi=0084.101
340E CJK UNIFIED IDEOGRAPH-#340E, IRGKangXi=0084.101
340F CJK UNIFIED IDEOGRAPH-#340F, IRGKangXi=0084.101
3410 CJK UNIFIED IDEOGRAPH-#3410, IRGKangXi=0084.141
3411 CJK UNIFIED IDEOGRAPH-#3411, IRGKangXi=0084.141
3412 CJK UNIFIED IDEOGRAPH-#3412, IRGKangXi=0084.141
3413 CJK UNIFIED IDEOGRAPH-#3413, IRGKangXi=0084.141
3414 CJK UNIFIED IDEOGRAPH-#3414, IRGKangXi=0084.141
3415 CJK UNIFIED IDEOGRAPH-#3415, IRGKangXi=0084.141
3416 CJK UNIFIED IDEOGRAPH-#3416, IRGKangXi=0084.160, Def{㐖毒, an old name for India}
3417 CJK UNIFIED IDEOGRAPH-#3417, IRGKangXi=0084.161
3418 CJK UNIFIED IDEOGRAPH-#3418, IRGKangXi=0084.161
3419 CJK UNIFIED IDEOGRAPH-#3419, IRGKangXi=0084.201
341A CJK UNIFIED IDEOGRAPH-#341A, IRGKangXi=0084.201
341B CJK UNIFIED IDEOGRAPH-#341B, IRGKangXi=0084.201
341C CJK UNIFIED IDEOGRAPH-#341C, IRGKangXi=0084.220, Def{(same as 仇) an enemy, enmity, hatred, to hate, a rival, a match}
341D CJK UNIFIED IDEOGRAPH-#341D, IRGKangXi=0084.241
341E CJK UNIFIED IDEOGRAPH-#341E, IRGKangXi=0084.241
341F CJK UNIFIED IDEOGRAPH-#341F, IRGKangXi=0084.241
3420 CJK UNIFIED IDEOGRAPH-#3420, IRGKangXi=0084.241
3421 CJK UNIFIED IDEOGRAPH-#3421, IRGKangXi=0084.310, Def{(same as 懦) weak; timid; imbecile}
3422 CJK UNIFIED IDEOGRAPH-#3422, IRGKangXi=0084.321
3423 CJK UNIFIED IDEOGRAPH-#3423, IRGKangXi=0084.321
3424 CJK UNIFIED IDEOGRAPH-#3424, IRGKangXi=0084.321, Def{to implore; to beseech, to seek after, to beg; to pray}
3425 CJK UNIFIED IDEOGRAPH-#3425, IRGKangXi=0085.061
3426 CJK UNIFIED IDEOGRAPH-#3426, IRGKangXi=0085.071
3427 CJK UNIFIED IDEOGRAPH-#3427, IRGKangXi=0085.191, Def{(J) non-standard form of 第 U+7B2C, sequence, number; grade, degree}
3428 CJK UNIFIED IDEOGRAPH-#3428, IRGKangXi=0085.230, Def{a kind of fish in legend (a record in old books)}
3429 CJK UNIFIED IDEOGRAPH-#3429, IRGKangXi=0087.141, Def{wine cups}
342A CJK UNIFIED IDEOGRAPH-#342A, IRGKangXi=0088.111
342B CJK UNIFIED IDEOGRAPH-#342B, IRGKangXi=0088.111, Def{(same as 凶) cruel, unfortunate, sad}
342C CJK UNIFIED IDEOGRAPH-#342C, IRGKangXi=0088.150, Def{(same as U+65D2 旒, a corrupted form of U+8352 荒) a cup with pendants, a pennant, wild, barren, uncultivated}
342D CJK UNIFIED IDEOGRAPH-#342D, IRGKangXi=0089.010, Def{(same as 廩) a granary, to supply (foodstuff), to stockpile}
342E CJK UNIFIED IDEOGRAPH-#342E, IRGKangXi=0089.201, Def{(same as 襄) to help; to assist, to achieve, to rise; to raise}
342F CJK UNIFIED IDEOGRAPH-#342F, IRGKangXi=0089.241, Def{(ancient form of 庸) to employ; to use, to manifest}
3430 CJK UNIFIED IDEOGRAPH-#3430, IRGKangXi=0092.080, Def{(ancient form of 信) to believe in; to trust, truth, sincerity, confidence, a pledge or token}
3431 CJK UNIFIED IDEOGRAPH-#3431, IRGKangXi=0092.110, Def{(same as 鬒) bushy, black hair}
3432 CJK UNIFIED IDEOGRAPH-#3432, IRGKangXi=0093.080, Def{name of an island}
3433 CJK UNIFIED IDEOGRAPH-#3433, IRGKangXi=0094.030, Def{high and level on the top}
3434 CJK UNIFIED IDEOGRAPH-#3434, IRGKangXi=0094.050, Def{(non-classical of 攀) to drag down; to seize, to pull, to hold to}
3435 CJK UNIFIED IDEOGRAPH-#3435, IRGKangXi=0094.051, Def{Confucianism; scholar}
3436 CJK UNIFIED IDEOGRAPH-#3436, IRGKangXi=0094.051
3437 CJK UNIFIED IDEOGRAPH-#3437, IRGKangXi=0094.051, Def{a kind of punishment in Han Dynasty, name of chessmen in Chinese chess game (simplified form, a variant 罵) to curse; to revile; to abuse, to scold}
3438 CJK UNIFIED IDEOGRAPH-#3438, IRGKangXi=0094.100, Def{(non-classical form of 欠) to owe money, deficient, to yawn, last name}
3439 CJK UNIFIED IDEOGRAPH-#3439, IRGKangXi=0094.140, Def{(standard form of 仡) strong; valiant, a minority ethnic group in China}
343A CJK UNIFIED IDEOGRAPH-#343A, IRGKangXi=0095.220, Def{(standard form of 眾) all; the whole of; a multitude, a crowd (three or more)}
343B CJK UNIFIED IDEOGRAPH-#343B, IRGKangXi=0096.090, Def{name of a person}
343C CJK UNIFIED IDEOGRAPH-#343C, IRGKangXi=0096.110, Def{(corrupted form of 拯) to save; to lift up}
343D CJK UNIFIED IDEOGRAPH-#343D, IRGKangXi=0096.121, Def{(simplified form of 偑) name of a place, last name}
343E CJK UNIFIED IDEOGRAPH-#343E, IRGKangXi=0096.121
343F CJK UNIFIED IDEOGRAPH-#343F, IRGKangXi=0096.121
3440 CJK UNIFIED IDEOGRAPH-#3440, IRGKangXi=0096.121
3441 CJK UNIFIED IDEOGRAPH-#3441, IRGKangXi=0096.150, Def{(same as U+20B74 𠭴) short; of short stature}
3442 CJK UNIFIED IDEOGRAPH-#3442, IRGKangXi=0096.190, Def{(same as 仿) to imitate, like; resembling, according to}
3443 CJK UNIFIED IDEOGRAPH-#3443, IRGKangXi=0097.050, Def{(same as 拗) to pull; to drag, to break off, to pluck, as a flower}
3444 CJK UNIFIED IDEOGRAPH-#3444, IRGKangXi=0098.020, Def{(ancient form of 侮) to insult, to ridicule}
3445 CJK UNIFIED IDEOGRAPH-#3445, IRGKangXi=0100.021, Def{(same as 作) to make; to do; to act, to write; to compose; to rise, work}
3446 CJK UNIFIED IDEOGRAPH-#3446, IRGKangXi=0100.021
3447 CJK UNIFIED IDEOGRAPH-#3447, IRGKangXi=0100.021, Def{(a simplified form) clever; ingenious; cute; pretty}
3448 CJK UNIFIED IDEOGRAPH-#3448, IRGKangXi=0100.021, Def{(simplified form) rude; barbarous, stupid; dull, last name}
3449 CJK UNIFIED IDEOGRAPH-#3449, IRGKangXi=0100.050, Def{cannot straighten up}
344A CJK UNIFIED IDEOGRAPH-#344A, IRGKangXi=0100.200, Def{a kind of disease}
344B CJK UNIFIED IDEOGRAPH-#344B, IRGKangXi=0100.260, Def{small, poor, submit to the dominion of; slow; late}
344C CJK UNIFIED IDEOGRAPH-#344C, IRGKangXi=0101.210, Def{(same as 尪) weak; a rickety person; emaciated}
344D CJK UNIFIED IDEOGRAPH-#344D, IRGKangXi=0102.110, Def{inferior; secondary, ugly}
344E CJK UNIFIED IDEOGRAPH-#344E, IRGKangXi=0102.190, Def{last name}
344F CJK UNIFIED IDEOGRAPH-#344F, IRGKangXi=0102.230, Def{(corrupted form of U+4F47 佇) to stand and wait; to hope for}
3450 CJK UNIFIED IDEOGRAPH-#3450, IRGKangXi=0102.291, Def{to move; to start; to shake, name of a person}
3451 CJK UNIFIED IDEOGRAPH-#3451, IRGKangXi=0102.291
3452 CJK UNIFIED IDEOGRAPH-#3452, IRGKangXi=0102.291
3453 CJK UNIFIED IDEOGRAPH-#3453, IRGKangXi=0102.291
3454 CJK UNIFIED IDEOGRAPH-#3454, IRGKangXi=0102.291, Def{(a simplified form) (corrupted form of 偦) all together, mutually, last name}
3455 CJK UNIFIED IDEOGRAPH-#3455, IRGKangXi=0102.291
3456 CJK UNIFIED IDEOGRAPH-#3456, IRGKangXi=0102.291
3457 CJK UNIFIED IDEOGRAPH-#3457, IRGKangXi=0103.050, Def{a god, pregnant}
3458 CJK UNIFIED IDEOGRAPH-#3458, IRGKangXi=0103.120, Def{(same as 价) a servant, a middle-man, good, great; (a simplified form) price; value}
3459 CJK UNIFIED IDEOGRAPH-#3459, IRGKangXi=0103.240, Def{frivolous; flippant; capricious; playful}
345A CJK UNIFIED IDEOGRAPH-#345A, IRGKangXi=0103.290, Def{(non-classical form of 那) that, there}
345B CJK UNIFIED IDEOGRAPH-#345B, IRGKangXi=0104.120, Def{to shake one's head}
345C CJK UNIFIED IDEOGRAPH-#345C, IRGKangXi=0105.010, Def{(a dialect) to engrave}
345D CJK UNIFIED IDEOGRAPH-#345D, IRGKangXi=0105.060, Def{to make a fool of; idiotic, simple, stupid}
345E CJK UNIFIED IDEOGRAPH-#345E, IRGKangXi=0105.070, Def{(same as 媵) (in old time) a maid who accompanies a bride to her new home; to escort, a concubine}
345F CJK UNIFIED IDEOGRAPH-#345F, IRGKangXi=0105.220, Def{insincere and cunning person; a pretentious person}
3460 CJK UNIFIED IDEOGRAPH-#3460, IRGKangXi=0106.041
3461 CJK UNIFIED IDEOGRAPH-#3461, IRGKangXi=0106.041
3462 CJK UNIFIED IDEOGRAPH-#3462, IRGKangXi=0106.041
3463 CJK UNIFIED IDEOGRAPH-#3463, IRGKangXi=0106.130, Def{stupid; loutish, without ability; unable; lacking power}
3464 CJK UNIFIED IDEOGRAPH-#3464, IRGKangXi=0106.150, Def{(same as 媌) good looking, a prostitute}
3465 CJK UNIFIED IDEOGRAPH-#3465, IRGKangXi=0106.160, Def{disrespectful; irreverent, to make light of; to neglect; careless; rush, to exchange, (said of one's personality) easy to get along with}
3466 CJK UNIFIED IDEOGRAPH-#3466, IRGKangXi=0107.240, Def{anger; rage; angry, (same as 戾) recalcitrant; stubbornly persisting in doing something wrong; cruel; despotic}
3467 CJK UNIFIED IDEOGRAPH-#3467, IRGKangXi=0109.171, Def{(corrupted form of 悸) perturbed, to throb, palpitation of the heart}
3468 CJK UNIFIED IDEOGRAPH-#3468, IRGKangXi=0109.171, Def{great; big; tall; vast, noble; high in rank, very; much}
3469 CJK UNIFIED IDEOGRAPH-#3469, IRGKangXi=0109.171, Def{(simplified form of U+5138 儸) smart; clever}
346A CJK UNIFIED IDEOGRAPH-#346A, IRGKangXi=0109.171, Def{(non-classical form of 儕) a generation, a class; a series; a kind}
346B CJK UNIFIED IDEOGRAPH-#346B, IRGKangXi=0109.171
346C CJK UNIFIED IDEOGRAPH-#346C, IRGKangXi=0109.171
346D CJK UNIFIED IDEOGRAPH-#346D, IRGKangXi=0109.171
346E CJK UNIFIED IDEOGRAPH-#346E, IRGKangXi=0110.100, Def{last name, girl's name}
346F CJK UNIFIED IDEOGRAPH-#346F, IRGKangXi=0111.130, Def{last name, all; together; mutually, a low rank officer to take charge of the bandits in ancient time}
3470 CJK UNIFIED IDEOGRAPH-#3470, IRGKangXi=0111.160, Def{(a corrupted form) distress; very difficulty; anxiety; very tired}
3471 CJK UNIFIED IDEOGRAPH-#3471, IRGKangXi=0112.071, Def{a kind of monkey, fingering for an ancient string instrument}
3472 CJK UNIFIED IDEOGRAPH-#3472, IRGKangXi=0112.071
3473 CJK UNIFIED IDEOGRAPH-#3473, IRGKangXi=0112.100, Def{(same as 媰) pregnant (妊娠, 妊身); cruel; pretty, cute, clever, ingenious, smart; to be hired; (used for 謅) to jest, to chaff, to bawl, mean person (as opposed to real gentleman)}
3474 CJK UNIFIED IDEOGRAPH-#3474, IRGKangXi=0112.120, Def{(standard form of 侵) to usurp, to encroach upon, to raid}
3475 CJK UNIFIED IDEOGRAPH-#3475, IRGKangXi=0113.030, Def{(same as 嫉) envy; jealousy, to hate}
3476 CJK UNIFIED IDEOGRAPH-#3476, IRGKangXi=0113.040, Def{(non-classical form of 愾) anger; passion; rage, to sigh; to groan}
3477 CJK UNIFIED IDEOGRAPH-#3477, IRGKangXi=0113.060, Def{(same as 態) manner, bearing, behaviour, policy, attitude}
3478 CJK UNIFIED IDEOGRAPH-#3478, IRGKangXi=0114.051
3479 CJK UNIFIED IDEOGRAPH-#3479, IRGKangXi=0114.051, Def{(non-classical of 會) to meet; to assemble, to co-operate, a society; a guild; an association}
347A CJK UNIFIED IDEOGRAPH-#347A, IRGKangXi=0114.051, Def{(a variant of 俊) superior, handsome, refined, eminent}
347B CJK UNIFIED IDEOGRAPH-#347B, IRGKangXi=0114.130, Def{strong, robust, vigorous}
347C CJK UNIFIED IDEOGRAPH-#347C, IRGKangXi=0114.210, Def{name of a god}
347D CJK UNIFIED IDEOGRAPH-#347D, IRGKangXi=0114.270, Def{(same as 傏) to ward off; to parry; to keep out, as wind, rain, or cold}
347E CJK UNIFIED IDEOGRAPH-#347E, IRGKangXi=0114.290, Def{(interchangeable 繇) joy, delight, gratification}
347F CJK UNIFIED IDEOGRAPH-#347F, IRGKangXi=0115.130, Def{long, of space or time, profitable, excelling}
3480 CJK UNIFIED IDEOGRAPH-#3480, IRGKangXi=0115.150, Def{do not fear to}
3481 CJK UNIFIED IDEOGRAPH-#3481, IRGKangXi=0115.220, Def{(same as 俁) of great stature; stalwart, to injure, to grieve}
3482 CJK UNIFIED IDEOGRAPH-#3482, IRGKangXi=0118.230, Def{to bestow; to grant, to act; to do, quiet; still, peace; tranquility}
3483 CJK UNIFIED IDEOGRAPH-#3483, IRGKangXi=0116.090, Def{(same as 貳) capital form of two, a second job, to harbour doubts; to hesitate, to revolt}
3484 CJK UNIFIED IDEOGRAPH-#3484, IRGKangXi=0116.240, Def{brittle and friable, fear; dread; fright; scare}
3485 CJK UNIFIED IDEOGRAPH-#3485, IRGKangXi=0117.060, Def{to unbind the collar}
3486 CJK UNIFIED IDEOGRAPH-#3486, IRGKangXi=0117.110, Def{(same as 歙) to gather the harvest; to gather together}
3487 CJK UNIFIED IDEOGRAPH-#3487, IRGKangXi=0117.130, Def{(same as 憮) to skip about; to dance for joy; to soothe, slow, disappointed}
3488 CJK UNIFIED IDEOGRAPH-#3488, IRGKangXi=0117.150, Def{dangerous; lofty; steep; high and dangerous}
3489 CJK UNIFIED IDEOGRAPH-#3489, IRGKangXi=0117.220, Def{(same as 惝) alarmed; agitated}
348A CJK UNIFIED IDEOGRAPH-#348A, IRGKangXi=0117.250, Def{loquacious}
348B CJK UNIFIED IDEOGRAPH-#348B, IRGKangXi=0117.280, Def{(same as U+5EDD 廝) a servant; a menial, a woodcutter}
348C CJK UNIFIED IDEOGRAPH-#348C, IRGKangXi=0118.030, Def{(ancient form of 煢) along; desolate; orphaned}
348D CJK UNIFIED IDEOGRAPH-#348D, IRGKangXi=0118.051, Def{(interchangeable U+50AB 儽) utterly weary in body and spirits; negligent; lax}
348E CJK UNIFIED IDEOGRAPH-#348E, IRGKangXi=0118.051, Def{evil, wicked, wrong, foul}
348F CJK UNIFIED IDEOGRAPH-#348F, IRGKangXi=0118.051
3490 CJK UNIFIED IDEOGRAPH-#3490, IRGKangXi=0118.051
3491 CJK UNIFIED IDEOGRAPH-#3491, IRGKangXi=0118.120, Def{grow up, commodity prices}
3492 CJK UNIFIED IDEOGRAPH-#3492, IRGKangXi=0118.220, Def{(same as 僕) a slave; a servant, used conventionally for oneself, a charioteer}
3493 CJK UNIFIED IDEOGRAPH-#3493, IRGKangXi=0119.010, Def{to escape; to abscond; to flee, (interchangeable 達)}
3494 CJK UNIFIED IDEOGRAPH-#3494, IRGKangXi=0119.070, Def{to shake one's head, ugly, not in peace}
3495 CJK UNIFIED IDEOGRAPH-#3495, IRGKangXi=0119.140, Def{unyield}
3496 CJK UNIFIED IDEOGRAPH-#3496, IRGKangXi=0119.231, Def{(same as 藕) the root-stock of the lotus; arrowroot}
3497 CJK UNIFIED IDEOGRAPH-#3497, IRGKangXi=0119.231, Def{(a variant of 儓) a servant}
3498 CJK UNIFIED IDEOGRAPH-#3498, IRGKangXi=0119.231
3499 CJK UNIFIED IDEOGRAPH-#3499, IRGKangXi=0119.250, Def{to hand or bow the head; to droop; to lower, low; beneath}
349A CJK UNIFIED IDEOGRAPH-#349A, IRGKangXi=0119.320, Def{(same as U+7A69 穩) firm; stable; secure, dependent upon others}
349B CJK UNIFIED IDEOGRAPH-#349B, IRGKangXi=0119.360, Def{to stand alone; independent}
349C CJK UNIFIED IDEOGRAPH-#349C, IRGKangXi=0120.040, Def{respectful; attentive, carefully; cautious; to heed; to be watchful, to rely on; to trust to; to lean towards}
349D CJK UNIFIED IDEOGRAPH-#349D, IRGKangXi=0120.150, Def{to deceive; artful; false}
349E CJK UNIFIED IDEOGRAPH-#349E, IRGKangXi=0120.190, Def{valiant; brave, eminent}
349F CJK UNIFIED IDEOGRAPH-#349F, IRGKangXi=0121.070, Def{(same as 褭) with a charming; slim carriage (of a woman), pretty}
34A0 CJK UNIFIED IDEOGRAPH-#34A0, IRGKangXi=0121.140, Def{narrow; contracted, quickly; fast; hasty; soon; promptly}
34A1 CJK UNIFIED IDEOGRAPH-#34A1, IRGKangXi=0121.291, Def{name of a person}
34A2 CJK UNIFIED IDEOGRAPH-#34A2, IRGKangXi=0119.231
34A3 CJK UNIFIED IDEOGRAPH-#34A3, IRGKangXi=0121.291
34A4 CJK UNIFIED IDEOGRAPH-#34A4, IRGKangXi=0121.310, Def{to have one's heart won; to submit, admire, etc. sincerely and willingly, (interchangeable 懾) to fear; to dread; to be scared of}
34A5 CJK UNIFIED IDEOGRAPH-#34A5, IRGKangXi=0121.330, Def{an immortal}
34A6 CJK UNIFIED IDEOGRAPH-#34A6, IRGKangXi=0121.340, Def{(same as 儡) puppets, very tired; fatigued; weary and weak}
34A7 CJK UNIFIED IDEOGRAPH-#34A7, IRGKangXi=0121.370, Def{(same as 儷) a pair; a couple, luxuriant; lush; exuberant}
34A8 CJK UNIFIED IDEOGRAPH-#34A8, IRGKangXi=0122.061, Def{(ancient form of 仙) an immortal; a fairy; a genie}
34A9 CJK UNIFIED IDEOGRAPH-#34A9, IRGKangXi=0122.100, Def{(same as 梴 裸) naked, to strip; to unclothe}
34AA CJK UNIFIED IDEOGRAPH-#34AA, IRGKangXi=0122.120, Def{(ancient form of 錫) tin; pewter}
34AB CJK UNIFIED IDEOGRAPH-#34AB, IRGKangXi=0124.140, Def{(ancient form of 旡) choked and unable to breath}
34AC CJK UNIFIED IDEOGRAPH-#34AC, IRGKangXi=0125.131
34AD CJK UNIFIED IDEOGRAPH-#34AD, IRGKangXi=0125.190, Def{(same as 昆) an elder brother}
34AE CJK UNIFIED IDEOGRAPH-#34AE, IRGKangXi=0125.201
34AF CJK UNIFIED IDEOGRAPH-#34AF, IRGKangXi=0125.291
34B0 CJK UNIFIED IDEOGRAPH-#34B0, IRGKangXi=0126.030, Def{(a variant, seal type of U+5168 全) perfect, complete, absolute}
34B1 CJK UNIFIED IDEOGRAPH-#34B1, IRGKangXi=0126.041
34B2 CJK UNIFIED IDEOGRAPH-#34B2, IRGKangXi=0126.080, Def{(a variant of 財) wealth; property; valuables, bribes}
34B3 CJK UNIFIED IDEOGRAPH-#34B3, IRGKangXi=0126.100, Def{(ancient form of 兩) two, a pair; a couple; both}
34B4 CJK UNIFIED IDEOGRAPH-#34B4, IRGKangXi=0126.120, Def{to come; to go out}
34B5 CJK UNIFIED IDEOGRAPH-#34B5, IRGKangXi=0127.160, Def{(same as 貌) manner; appearance; form; face; bearing}
34B6 CJK UNIFIED IDEOGRAPH-#34B6, IRGKangXi=0127.170, Def{(ancient form of 公) public; open to all}
34B7 CJK UNIFIED IDEOGRAPH-#34B7, IRGKangXi=0127.171, Def{(simple form of U+8208 興) to prosper, to begin, to increase; to rise; to raise, flourishing}
34B8 CJK UNIFIED IDEOGRAPH-#34B8, IRGKangXi=0128.050, Def{(same as U+9042 遂) to obey; to comply with; to follow the wishes of another, (an ancient form of U+6B72 歲) a year, age, the harvest}
34B9 CJK UNIFIED IDEOGRAPH-#34B9, IRGKangXi=0128.280, Def{(non-classical of 顛) to upset; to turn over, to fall, upside down}
34BA CJK UNIFIED IDEOGRAPH-#34BA, IRGKangXi=0129.191
34BB CJK UNIFIED IDEOGRAPH-#34BB, IRGKangXi=0129.290, Def{(same as 冒) to go forward with eyes covered, to risk, to rush upon, to put forth, to issue forth}
34BC CJK UNIFIED IDEOGRAPH-#34BC, IRGKangXi=0129.320, Def{average; equivalent; corresponding, to cover something carefully and tightly without a break; (Cant.) blocked}
34BD CJK UNIFIED IDEOGRAPH-#34BD, IRGKangXi=0129.350, Def{a kind of cap for children}
34BE CJK UNIFIED IDEOGRAPH-#34BE, IRGKangXi=0130.020, Def{a kind of wrapper used to cover over the face and head}
34BF CJK UNIFIED IDEOGRAPH-#34BF, IRGKangXi=0130.100, Def{a kind of turban used in ancient time}
34C0 CJK UNIFIED IDEOGRAPH-#34C0, IRGKangXi=0130.151
34C1 CJK UNIFIED IDEOGRAPH-#34C1, IRGKangXi=0130.151, Def{a net; net-like, radical 122}
34C2 CJK UNIFIED IDEOGRAPH-#34C2, IRGKangXi=0130.231, Def{(a variant of 寇) tyrannical; cruel, to rob; to plunder, banditti; thieves; highwaymen}
34C3 CJK UNIFIED IDEOGRAPH-#34C3, IRGKangXi=0131.040, Def{(standard form of U+8A6B 詫) to sacrifice by pouring out a libation of wine}
34C4 CJK UNIFIED IDEOGRAPH-#34C4, IRGKangXi=0131.080, Def{to plough; to till, black color}
34C5 CJK UNIFIED IDEOGRAPH-#34C5, IRGKangXi=0131.160, Def{frozen; cold}
34C6 CJK UNIFIED IDEOGRAPH-#34C6, IRGKangXi=0131.291
34C7 CJK UNIFIED IDEOGRAPH-#34C7, IRGKangXi=0131.291
34C8 CJK UNIFIED IDEOGRAPH-#34C8, IRGKangXi=0132.040, Def{sound of flying or speeding}
34C9 CJK UNIFIED IDEOGRAPH-#34C9, IRGKangXi=0132.080, Def{ice; icicles, cold; frost, crystallized}
34CA CJK UNIFIED IDEOGRAPH-#34CA, IRGKangXi=0132.090, Def{cold, indifferent}
34CB CJK UNIFIED IDEOGRAPH-#34CB, IRGKangXi=0132.130, Def{to freeze; to congeal; to curdle}
34CC CJK UNIFIED IDEOGRAPH-#34CC, IRGKangXi=0132.190, Def{bitterly cold}
34CD CJK UNIFIED IDEOGRAPH-#34CD, IRGKangXi=0132.201
34CE CJK UNIFIED IDEOGRAPH-#34CE, IRGKangXi=0132.220, Def{cold, cold air, bitterly cold}
34CF CJK UNIFIED IDEOGRAPH-#34CF, IRGKangXi=0132.290, Def{bitterly cold}
34D0 CJK UNIFIED IDEOGRAPH-#34D0, IRGKangXi=0132.340, Def{to rain, cold; wintry}
34D1 CJK UNIFIED IDEOGRAPH-#34D1, IRGKangXi=0132.360, Def{cold}
34D2 CJK UNIFIED IDEOGRAPH-#34D2, IRGKangXi=0133.011
34D3 CJK UNIFIED IDEOGRAPH-#34D3, IRGKangXi=0133.070, Def{thin ice}
34D4 CJK UNIFIED IDEOGRAPH-#34D4, IRGKangXi=0133.120, Def{(same as 謝) faded and fallen -- as blossoms; withered}
34D5 CJK UNIFIED IDEOGRAPH-#34D5, IRGKangXi=0133.211
34D6 CJK UNIFIED IDEOGRAPH-#34D6, IRGKangXi=0133.280, Def{bitterly cold, cold wind; the north wind}
34D7 CJK UNIFIED IDEOGRAPH-#34D7, IRGKangXi=0133.330, Def{(non-classical of 潔) clean; pure; clear}
34D8 CJK UNIFIED IDEOGRAPH-#34D8, IRGKangXi=0134.301, Def{(same as U+738A 玊) jade with some defects, a lapidary, to polish gems; a surname}
34D9 CJK UNIFIED IDEOGRAPH-#34D9, IRGKangXi=0135.151, Def{(non-classical of 凶) cruel, unfortunate, sad}
34DA CJK UNIFIED IDEOGRAPH-#34DA, IRGKangXi=0136.150, Def{a sickle, a reaping-hook, to gather in the harvest, to pare; to scrape}
34DB CJK UNIFIED IDEOGRAPH-#34DB, IRGKangXi=0137.021, Def{(incorrect form of 功) merit; achievement; meritorious, efficacy; good results}
34DC CJK UNIFIED IDEOGRAPH-#34DC, IRGKangXi=0342.041, Def{(corrupted form of 幼) young; immature; weak; delicate}
34DD CJK UNIFIED IDEOGRAPH-#34DD, IRGKangXi=0137.120, Def{(same as 刑) a law, to punish; punishment}
34DE CJK UNIFIED IDEOGRAPH-#34DE, IRGKangXi=0137.150, Def{to engrave, (interchangeable with U+5951 契) a written contract or agreement}
34DF CJK UNIFIED IDEOGRAPH-#34DF, IRGKangXi=0137.360, Def{to peel, to pare, to trim, to split, (non-classical form) to open; to unroll; to spread out}
34E0 CJK UNIFIED IDEOGRAPH-#34E0, IRGKangXi=0138.180, Def{(same as 玷) a flaw; a defect, to cut with a sword; to chop}
34E1 CJK UNIFIED IDEOGRAPH-#34E1, IRGKangXi=0138.380, Def{(same as 弣) the middle part of a bow; the handle of a bow, try to dig and get something with a knife}
34E2 CJK UNIFIED IDEOGRAPH-#34E2, IRGKangXi=0138.450, Def{to cut the flesh from the bones; to scrape off; to pick out; to get rid of}
34E3 CJK UNIFIED IDEOGRAPH-#34E3, IRGKangXi=0139.080, Def{to sink into; to pierce, (ancient form of 割) to cut; to hack; to reap}
34E4 CJK UNIFIED IDEOGRAPH-#34E4, IRGKangXi=0139.180, Def{to strip the skin of the face; an imminent calamity, to engrave; (Cant.) to pierce}
34E5 CJK UNIFIED IDEOGRAPH-#34E5, IRGKangXi=0139.251, Def{(dial.) to kill; to slaughter}
34E6 CJK UNIFIED IDEOGRAPH-#34E6, IRGKangXi=0139.251, Def{to deliberate and plan; to arrange}
34E7 CJK UNIFIED IDEOGRAPH-#34E7, IRGKangXi=0140.200, Def{agricultural implements}
34E8 CJK UNIFIED IDEOGRAPH-#34E8, IRGKangXi=0140.210, Def{(same as 刺) to pierce; to stab; to irritate; to hurt}
34E9 CJK UNIFIED IDEOGRAPH-#34E9, IRGKangXi=0140.220, Def{horned hair}
34EA CJK UNIFIED IDEOGRAPH-#34EA, IRGKangXi=0140.290, Def{(same as 朗) bright, clear, intelligent, light, brilliant, to understand, to illustrate, to cleanse}
34EB CJK UNIFIED IDEOGRAPH-#34EB, IRGKangXi=0140.291
34EC CJK UNIFIED IDEOGRAPH-#34EC, IRGKangXi=0141.150, Def{(same as 刳) to cut open; to rip up; to cut out}
34ED CJK UNIFIED IDEOGRAPH-#34ED, IRGKangXi=0141.240, Def{(same as U+97A8 鞨) to make ready the leather for shoes}
34EE CJK UNIFIED IDEOGRAPH-#34EE, IRGKangXi=0141.330, Def{(same as 雕) to engrave; to carve; to tattoo}
34EF CJK UNIFIED IDEOGRAPH-#34EF, IRGKangXi=0141.340, Def{(same as 劙) to divide, to partition, to cut; to hack; to reap}
34F0 CJK UNIFIED IDEOGRAPH-#34F0, IRGKangXi=0141.411, Def{(a variant of 劃) to rive; to divide; to mark; to cut}
34F1 CJK UNIFIED IDEOGRAPH-#34F1, IRGKangXi=0142.050, Def{to cut; to cut out; to pick out; to scoop out, (same as 鄃) name of a county in today's Shandong province}
34F2 CJK UNIFIED IDEOGRAPH-#34F2, IRGKangXi=0142.090, Def{to pare; to cut into slices}
34F3 CJK UNIFIED IDEOGRAPH-#34F3, IRGKangXi=0142.100, Def{use knife to split something}
34F4 CJK UNIFIED IDEOGRAPH-#34F4, IRGKangXi=0142.120, Def{to cut in two, to slash}
34F5 CJK UNIFIED IDEOGRAPH-#34F5, IRGKangXi=0142.210, Def{(same as 鍔) swords; a double-edged sword}
34F6 CJK UNIFIED IDEOGRAPH-#34F6, IRGKangXi=0142.220, Def{(same as 鍥) to carve; to engrave; to cut; to oppress, a sickle}
34F7 CJK UNIFIED IDEOGRAPH-#34F7, IRGKangXi=0142.290, Def{(same as 劓) to cut off the nose; cut off}
34F8 CJK UNIFIED IDEOGRAPH-#34F8, IRGKangXi=0142.370, Def{(same as 斲) to cut to pieces; to hack; to chop or hew, to carve for ornaments}
34F9 CJK UNIFIED IDEOGRAPH-#34F9, IRGKangXi=0142.390, Def{(same as 銳) a sharp-pointed weapon, acute; zealous; valiant, wound, minor injury}
34FA CJK UNIFIED IDEOGRAPH-#34FA, IRGKangXi=0142.410, Def{castration, to pare; to scrape; to sharpen to a point}
34FB CJK UNIFIED IDEOGRAPH-#34FB, IRGKangXi=0142.470, Def{(same as 剛) tough; unyielding; inflexible; hard}
34FC CJK UNIFIED IDEOGRAPH-#34FC, IRGKangXi=0143.160, Def{an incised wound; cuts}
34FD CJK UNIFIED IDEOGRAPH-#34FD, IRGKangXi=0143.220, Def{a kind of farm tool; iron spade; spade}
34FE CJK UNIFIED IDEOGRAPH-#34FE, IRGKangXi=0143.300, Def{to wound the skin; to cut open; to open out, ripped}
34FF CJK UNIFIED IDEOGRAPH-#34FF, IRGKangXi=0143.381
3500 CJK UNIFIED IDEOGRAPH-#3500, IRGKangXi=0143.400, Def{(non-classical form) to brand criminals on the face, to rob; to plunder}
3501 CJK UNIFIED IDEOGRAPH-#3501, IRGKangXi=0143.410, Def{a kind of tool; a hook; a barb; a sickle}
3502 CJK UNIFIED IDEOGRAPH-#3502, IRGKangXi=0143.420, Def{to pare; to pare away; to scrape; to sharpen to a point; to shave; to brush away}
3503 CJK UNIFIED IDEOGRAPH-#3503, IRGKangXi=0143.430, Def{(same as 絕) to cut short; to break off; to interrupt, to drag; to pull}
3504 CJK UNIFIED IDEOGRAPH-#3504, IRGKangXi=0143.440, Def{thin, small cut}
3505 CJK UNIFIED IDEOGRAPH-#3505, IRGKangXi=0143.470, Def{to cut; to hack; to reap, minced meat mixed up with ginger and cassia}
3506 CJK UNIFIED IDEOGRAPH-#3506, IRGKangXi=0144.030, Def{to cut; to hack; to reap; to trim or clip, to stab; to pierce; to brand}
3507 CJK UNIFIED IDEOGRAPH-#3507, IRGKangXi=0144.050, Def{(same as U+93FA 鏺) a kind of farm tool; a reaping-hook; used to cut grass}
3508 CJK UNIFIED IDEOGRAPH-#3508, IRGKangXi=0144.261
3509 CJK UNIFIED IDEOGRAPH-#3509, IRGKangXi=0144.261, Def{to dig; to excavate}
350A CJK UNIFIED IDEOGRAPH-#350A, IRGKangXi=0144.360, Def{to cut; to hack; to reap, to strike; to attack, to chastise rebels}
350B CJK UNIFIED IDEOGRAPH-#350B, IRGKangXi=0145.010, Def{cut into thin slices; to mince, sharp}
350C CJK UNIFIED IDEOGRAPH-#350C, IRGKangXi=0145.030, Def{to cut off; to mince, to cut up firewood}
350D CJK UNIFIED IDEOGRAPH-#350D, IRGKangXi=0145.040, Def{a hinged shear or long knife for cutting fodder; sheet-iron; etc., to cut up; to mince}
350E CJK UNIFIED IDEOGRAPH-#350E, IRGKangXi=0145.270, Def{to cut apart; to divide}
350F CJK UNIFIED IDEOGRAPH-#350F, IRGKangXi=0145.290, Def{(same as 剆) to cut open, to strike against; to clash together}
3510 CJK UNIFIED IDEOGRAPH-#3510, IRGKangXi=0145.310, Def{(corrupted form) to cut; to mince}
3511 CJK UNIFIED IDEOGRAPH-#3511, IRGKangXi=0145.350, Def{(same as U+34FC 㓼) an incised wound; cuts}
3512 CJK UNIFIED IDEOGRAPH-#3512, IRGKangXi=0145.400, Def{to cut; to cut out; to pick out; to scoop out, to cut short; to spare}
3513 CJK UNIFIED IDEOGRAPH-#3513, IRGKangXi=0146.140, Def{to stammer}
3514 CJK UNIFIED IDEOGRAPH-#3514, IRGKangXi=0146.241
3515 CJK UNIFIED IDEOGRAPH-#3515, IRGKangXi=0146.200, Def{with purpose; with ambition; with the determination and courage to get ahead}
3516 CJK UNIFIED IDEOGRAPH-#3516, IRGKangXi=0146.241
3517 CJK UNIFIED IDEOGRAPH-#3517, IRGKangXi=0146.250, Def{strong; healthy, to clasp under the arm, to persecute; to oppress, vigorous}
3518 CJK UNIFIED IDEOGRAPH-#3518, IRGKangXi=0147.071, Def{(same as 黜) to degrade; to dismiss, to reject; to dispel}
3519 CJK UNIFIED IDEOGRAPH-#3519, IRGKangXi=0147.150, Def{great strength; great power}
351A CJK UNIFIED IDEOGRAPH-#351A, IRGKangXi=0147.220, Def{to exert oneself; to make strenuous effort}
351B CJK UNIFIED IDEOGRAPH-#351B, IRGKangXi=0147.231
351C CJK UNIFIED IDEOGRAPH-#351C, IRGKangXi=0147.380, Def{(non-classical form of 勃) sudden; suddenly; quick; to change as the countenance}
351D CJK UNIFIED IDEOGRAPH-#351D, IRGKangXi=0147.450, Def{strong resistance; lazy, reluctant}
351E CJK UNIFIED IDEOGRAPH-#351E, IRGKangXi=0148.040, Def{vigorous; with great strength}
351F CJK UNIFIED IDEOGRAPH-#351F, IRGKangXi=0147.381
3520 CJK UNIFIED IDEOGRAPH-#3520, IRGKangXi=0148.090, Def{industry, sound of making strenuous efforts}
3521 CJK UNIFIED IDEOGRAPH-#3521, IRGKangXi=0148.280, Def{greatly; deeply, with great strength; vigorous}
3522 CJK UNIFIED IDEOGRAPH-#3522, IRGKangXi=0149.200, Def{to break something, to drag; to pull}
3523 CJK UNIFIED IDEOGRAPH-#3523, IRGKangXi=0149.410, Def{in ancient times to fight against the enemy by pushing down the big rocks from up high; to throw over, to urge; to exert oneself, to carry in the bosom}
3524 CJK UNIFIED IDEOGRAPH-#3524, IRGKangXi=0149.420, Def{to exert one's strength}
3525 CJK UNIFIED IDEOGRAPH-#3525, IRGKangXi=0149.430, Def{(non-classical form of 疲) full of anger; fierce anger, tired; weary; exhausted}
3526 CJK UNIFIED IDEOGRAPH-#3526, IRGKangXi=0150.020, Def{to encourage; to stimulate; to exhort to action; to encourage by rewards}
3527 CJK UNIFIED IDEOGRAPH-#3527, IRGKangXi=0150.070, Def{to incite; to urge, to aid; to help; to assist, to approve; to acquiesce}
3528 CJK UNIFIED IDEOGRAPH-#3528, IRGKangXi=0151.350, Def{name of a person}
3529 CJK UNIFIED IDEOGRAPH-#3529, IRGKangXi=0151.380, Def{hair ornaments used in old time}
352A CJK UNIFIED IDEOGRAPH-#352A, IRGKangXi=0152.030, Def{to crawl; to crawl on hands and knees}
352B CJK UNIFIED IDEOGRAPH-#352B, IRGKangXi=0152.241
352C CJK UNIFIED IDEOGRAPH-#352C, IRGKangXi=0152.310, Def{(ancient form of 卓) to establish, to surpass, eminent; lofty; profound}
352D CJK UNIFIED IDEOGRAPH-#352D, IRGKangXi=0153.060, Def{(same as 匙) a spoon, a key}
352E CJK UNIFIED IDEOGRAPH-#352E, IRGKangXi=0998.200, Def{a kind of animal which looks like a rat}
352F CJK UNIFIED IDEOGRAPH-#352F, IRGKangXi=0153.280, Def{(same as 匴) a large basket for holding cooked rice, a kind of tray made of bamboo used in ancient time}
3530 CJK UNIFIED IDEOGRAPH-#3530, IRGKangXi=0153.321, Def{(ancient form of 恆) constant; regular; continually; persevering}
3531 CJK UNIFIED IDEOGRAPH-#3531, IRGKangXi=0154.060, Def{(same as 庾) a stack of grain, a measure of 16 dǒu}
3532 CJK UNIFIED IDEOGRAPH-#3532, IRGKangXi=0154.161
3533 CJK UNIFIED IDEOGRAPH-#3533, IRGKangXi=0154.130, Def{(ancient form of 簋) a square basket of bamboo for holding grain used at sacrifices, feasts, etc.}
3534 CJK UNIFIED IDEOGRAPH-#3534, IRGKangXi=0154.140, Def{agricultural implement; farm tools, a big sacrificial vessel; a tripod of bronze with two ears; a caldron}
3535 CJK UNIFIED IDEOGRAPH-#3535, IRGKangXi=0154.180, Def{a kind of vessel}
3536 CJK UNIFIED IDEOGRAPH-#3536, IRGKangXi=0154.340, Def{a small cup, a box; a chest, a granary, cover of a vessel}
3537 CJK UNIFIED IDEOGRAPH-#3537, IRGKangXi=0155.030, Def{(ancient form of 陋) to secrete; to hide, a kind of basket}
3538 CJK UNIFIED IDEOGRAPH-#3538, IRGKangXi=0155.140, Def{(interchangeable 榹) a tray; a kind of dumbwaiter}
3539 CJK UNIFIED IDEOGRAPH-#3539, IRGKangXi=0155.210, Def{(standard form of 仂) a surplus or excess, a tithe, a great stock of merit}
353A CJK UNIFIED IDEOGRAPH-#353A, IRGKangXi=0156.090, Def{(ancient form of 世) an age, a generation of thirty years, from generation to generation}
353B CJK UNIFIED IDEOGRAPH-#353B, IRGKangXi=0156.110, Def{(same as 丕) great; distinguished}
353C CJK UNIFIED IDEOGRAPH-#353C, IRGKangXi=0157.140, Def{(non-classical form of 榫) to fit into, a tenon, connected}
353D CJK UNIFIED IDEOGRAPH-#353D, IRGKangXi=0158.190, Def{(non-classical form of 卣) a kind of wine pot or jar used in ancient time}
353E CJK UNIFIED IDEOGRAPH-#353E, IRGKangXi=0158.460, Def{(same as U+7B44 筄) last name; KangXi radical 26; a joint, a seal, (ancient form of 節)}
353F CJK UNIFIED IDEOGRAPH-#353F, IRGKangXi=0158.480, Def{a tally, like fitting the two halves of a tally, to petition the emperor that ..., to play music; to beat time}
3540 CJK UNIFIED IDEOGRAPH-#3540, IRGKangXi=0159.211
3541 CJK UNIFIED IDEOGRAPH-#3541, IRGKangXi=0159.260, Def{(non-classical form of 卻) still; but; yet; etc., to refuse to accept, to retreat; to withdraw}
3542 CJK UNIFIED IDEOGRAPH-#3542, IRGKangXi=0160.260, Def{(ancient form of 吟) to hum; to intone, to moan, to sigh, high ridges of cliffs, pebble ground}
3543 CJK UNIFIED IDEOGRAPH-#3543, IRGKangXi=0160.280, Def{to fall over; rolling on the ground}
3544 CJK UNIFIED IDEOGRAPH-#3544, IRGKangXi=0160.360, Def{(same as 厎 砥) to apply knowledge to final causes; to extend knowledge to the utmost, equally; average, smooth}
3545 CJK UNIFIED IDEOGRAPH-#3545, IRGKangXi=0160.390, Def{big; extremely; great; vast; extensive; tall}
3546 CJK UNIFIED IDEOGRAPH-#3546, IRGKangXi=0161.020, Def{fine stone; fine jade}
3547 CJK UNIFIED IDEOGRAPH-#3547, IRGKangXi=0161.030, Def{rocks collapsing (descriptive of sound), big pieces of rocks}
3548 CJK UNIFIED IDEOGRAPH-#3548, IRGKangXi=0161.090, Def{(interchangeable 庡) to linger; to walk to and from, to conceal; to cover up; to secrete; to hide; to cover over}
3549 CJK UNIFIED IDEOGRAPH-#3549, IRGKangXi=0161.140, Def{to dig a hole; to tuck in; to put the finger into}
354A CJK UNIFIED IDEOGRAPH-#354A, IRGKangXi=0161.240, Def{to slant; intricate; describe a writer's pen, lofty rocks; protruded rocks; resolute}
354B CJK UNIFIED IDEOGRAPH-#354B, IRGKangXi=0161.380, Def{rock land}
354C CJK UNIFIED IDEOGRAPH-#354C, IRGKangXi=0161.410, Def{to raise the curtain, a kind of rock}
354D CJK UNIFIED IDEOGRAPH-#354D, IRGKangXi=0162.020, Def{(same as 堆) to heap up; to pile, a heap; a pile; a mass; a crowd}
354E CJK UNIFIED IDEOGRAPH-#354E, IRGKangXi=0162.310, Def{caves; grottos on the mountain side, collapsed in ruins; destroyed; to clash; to bump against}
354F CJK UNIFIED IDEOGRAPH-#354F, IRGKangXi=0162.441, Def{(corrupted form of 廚) a kitchen, a sideboard with cupboard and drawers}
3550 CJK UNIFIED IDEOGRAPH-#3550, IRGKangXi=0162.500, Def{inclined; slanting, to upset; to be overthrown, to collapse, to fall flat}
3551 CJK UNIFIED IDEOGRAPH-#3551, IRGKangXi=0163.041, Def{(non-classical variant of U+53A8 厨) a kitchen, a sideboard with cupboard and drawers}
3552 CJK UNIFIED IDEOGRAPH-#3552, IRGKangXi=0163.050, Def{a lofty peak; a mountain peak}
3553 CJK UNIFIED IDEOGRAPH-#3553, IRGKangXi=0163.131
3554 CJK UNIFIED IDEOGRAPH-#3554, IRGKangXi=0163.171, Def{(non-classical form of 廳) a hall; a court; a lodge; a room}
3555 CJK UNIFIED IDEOGRAPH-#3555, IRGKangXi=0164.050, Def{(ancient form of 幻) deception; sleight of hand; magic}
3556 CJK UNIFIED IDEOGRAPH-#3556, IRGKangXi=0164.260, Def{(ancient form of 素) plain; unornamented, white, ordinary, simple}
3557 CJK UNIFIED IDEOGRAPH-#3557, IRGKangXi=0164.270, Def{(same as 誘) to induce; to entice; to mislead; to lead on}
3558 CJK UNIFIED IDEOGRAPH-#3558, IRGKangXi=0164.301, Def{(a variant of 參) to take part in; to visit; to counsel, one of the 28 lunar mansions; ginseng}
3559 CJK UNIFIED IDEOGRAPH-#3559, IRGKangXi=0164.390, Def{a wily rabbit; a cunning hare}
355A CJK UNIFIED IDEOGRAPH-#355A, IRGKangXi=0165.020, Def{(ancient form of 爪) claws of birds or animals, feet, to scratch, to claw, to grasp}
355B CJK UNIFIED IDEOGRAPH-#355B, IRGKangXi=0165.120, Def{(ancient form of 友) a friend; a companion; a associate, friendly, to make friends of, brotherly regard}
355C CJK UNIFIED IDEOGRAPH-#355C, IRGKangXi=0165.300, Def{(ancient form of 史) history; chronicles; annals}
355D CJK UNIFIED IDEOGRAPH-#355D, IRGKangXi=0165.391
355E CJK UNIFIED IDEOGRAPH-#355E, IRGKangXi=0166.020, Def{(same as U+5237 刷) a brush, to brush; to clean; to scrub, to print, especially from blocks}
355F CJK UNIFIED IDEOGRAPH-#355F, IRGKangXi=0166.080, Def{(same as 喟) to sign; to lament, to stop, to cut off; to sever; to interrupt}
3560 CJK UNIFIED IDEOGRAPH-#3560, IRGKangXi=0166.391, Def{(same as 雙) a pair; a couple, both, two, double, even}
3561 CJK UNIFIED IDEOGRAPH-#3561, IRGKangXi=0167.010, Def{(same as U+58D1 壑) the bed of a torrent; a gully, a pool}
3562 CJK UNIFIED IDEOGRAPH-#3562, IRGKangXi=1208.260, Def{profound significance, just now; then; in that case}
3563 CJK UNIFIED IDEOGRAPH-#3563, IRGKangXi=0172.090, Def{a marsh at the foot of the hills, (interchangeable 湢 沇) name of a river}
3564 CJK UNIFIED IDEOGRAPH-#3564, IRGKangXi=0173.080, Def{a proud temper, military equipment; a long spear}
3565 CJK UNIFIED IDEOGRAPH-#3565, IRGKangXi=0174.091
3566 CJK UNIFIED IDEOGRAPH-#3566, IRGKangXi=0175.010, Def{loud; clamour; hubbub, big mouth, to brag}
3567 CJK UNIFIED IDEOGRAPH-#3567, IRGKangXi=0175.080, Def{used to represent sound; to hum; to groan}
3568 CJK UNIFIED IDEOGRAPH-#3568, IRGKangXi=0177.021
3569 CJK UNIFIED IDEOGRAPH-#3569, IRGKangXi=0177.110, Def{(non-classical form) sound of tapping; sound of striking, opposing voices}
356A CJK UNIFIED IDEOGRAPH-#356A, IRGKangXi=0177.120, Def{birds' chirps; gabbling, sound in high pitch; to roar; aloud}
356B CJK UNIFIED IDEOGRAPH-#356B, IRGKangXi=0177.230, Def{(same as 仿 方) to imitate, like; resembling; according to, a measurement for sound effect}
356C CJK UNIFIED IDEOGRAPH-#356C, IRGKangXi=0178.100, Def{public opinion, (same as U+8A1F 訟) to go to law, to dispute, to demand justice; (Cant.) classifier for ears of corn}
356D CJK UNIFIED IDEOGRAPH-#356D, IRGKangXi=0178.230, Def{(same as 咬) to bark as a dog, obscene expressions, an interjection; implying surprise}
356E CJK UNIFIED IDEOGRAPH-#356E, IRGKangXi=0178.250, Def{to chew; to masticate, to dwell on, Chinese medicine term}
356F CJK UNIFIED IDEOGRAPH-#356F, IRGKangXi=0179.090, Def{slow-tongued; to stammer, to shout in triumph; the noise of shoting in battle}
3570 CJK UNIFIED IDEOGRAPH-#3570, IRGKangXi=0180.050, Def{sound angrily; roaring with rage, (same as 嘛) (a dialect) what; the tone implying to remind}
3571 CJK UNIFIED IDEOGRAPH-#3571, IRGKangXi=0181.070, Def{to bark (said of a dog)}
3572 CJK UNIFIED IDEOGRAPH-#3572, IRGKangXi=0181.130, Def{to gag or bribe; to satisfy one's appetite; name of an old book; (Cant.) to guess, reckon mentally; to bud}
3573 CJK UNIFIED IDEOGRAPH-#3573, IRGKangXi=0181.190, Def{(of a crowd) noisy; to brawl; to scold}
3574 CJK UNIFIED IDEOGRAPH-#3574, IRGKangXi=0181.191
3575 CJK UNIFIED IDEOGRAPH-#3575, IRGKangXi=0181.191
3576 CJK UNIFIED IDEOGRAPH-#3576, IRGKangXi=0181.191, Def{(Cant.) an expletive, exclamation}
3577 CJK UNIFIED IDEOGRAPH-#3577, IRGKangXi=0181.270, Def{(corrupted form 咟) to call, to yell, anxious, dazed, image sound, an exclamation expressing sound (such as clap hands; to fire a gun; to strike; sound of firecracker etc.)}
3578 CJK UNIFIED IDEOGRAPH-#3578, IRGKangXi=0181.310, Def{sound of rolling a boat}
3579 CJK UNIFIED IDEOGRAPH-#3579, IRGKangXi=0183.010, Def{a buckler; a shield}
357A CJK UNIFIED IDEOGRAPH-#357A, IRGKangXi=0183.100, Def{(corrupted form of 囂) looks big outside but empty inside, to yell; voice of anger, hubbub; clamour}
357B CJK UNIFIED IDEOGRAPH-#357B, IRGKangXi=0184.090, Def{to refuse, to repel}
357C CJK UNIFIED IDEOGRAPH-#357C, IRGKangXi=0185.080, Def{to brawl; to scold, noise from a crowd; hubbub; noisy; loud noise}
357D CJK UNIFIED IDEOGRAPH-#357D, IRGKangXi=0185.211, Def{a phonetic}
357E CJK UNIFIED IDEOGRAPH-#357E, IRGKangXi=0185.211
357F CJK UNIFIED IDEOGRAPH-#357F, IRGKangXi=0185.211
3580 CJK UNIFIED IDEOGRAPH-#3580, IRGKangXi=0186.100, Def{sound}
3581 CJK UNIFIED IDEOGRAPH-#3581, IRGKangXi=0186.120, Def{(non-classical form of 吝) stingy, sparing of; closefisted, to regret, to shame; to insult}
3582 CJK UNIFIED IDEOGRAPH-#3582, IRGKangXi=0187.010, Def{(same as 詍) loquacity; to talk incessantly and tediously, to laugh, joy}
3583 CJK UNIFIED IDEOGRAPH-#3583, IRGKangXi=0187.080, Def{(interchangeable 吼) to roar of animals, angry tones, (interchangeable 詬) a sense of shame; to shame, to vomit}
3584 CJK UNIFIED IDEOGRAPH-#3584, IRGKangXi=0187.220, Def{sound of calling chickens, to curse; to swear}
3585 CJK UNIFIED IDEOGRAPH-#3585, IRGKangXi=0188.160, Def{sound of a whistle, to blow}
3586 CJK UNIFIED IDEOGRAPH-#3586, IRGKangXi=0188.180, Def{to condemn; to sentence, to hold a hearing (on a legal case); to interrogate or question a prisoner, to whisper}
3587 CJK UNIFIED IDEOGRAPH-#3587, IRGKangXi=0189.130, Def{the lips; (Cant.) to sip}
3588 CJK UNIFIED IDEOGRAPH-#3588, IRGKangXi=0189.271
3589 CJK UNIFIED IDEOGRAPH-#3589, IRGKangXi=0189.271
358A CJK UNIFIED IDEOGRAPH-#358A, IRGKangXi=0189.271, Def{fathom}
358B CJK UNIFIED IDEOGRAPH-#358B, IRGKangXi=0189.271
358C CJK UNIFIED IDEOGRAPH-#358C, IRGKangXi=0189.271
358D CJK UNIFIED IDEOGRAPH-#358D, IRGKangXi=0189.271
358E CJK UNIFIED IDEOGRAPH-#358E, IRGKangXi=0189.271
358F CJK UNIFIED IDEOGRAPH-#358F, IRGKangXi=0189.290, Def{angry, to scold with loud voice, to slander; to defame}
3590 CJK UNIFIED IDEOGRAPH-#3590, IRGKangXi=0190.060, Def{sound of calling ducks}
3591 CJK UNIFIED IDEOGRAPH-#3591, IRGKangXi=0190.140, Def{to shout at, (same as 欸) to backbite, to dislike, sound of oars; the creaking or swishing sound of oars or sweeps in rowing}
3592 CJK UNIFIED IDEOGRAPH-#3592, IRGKangXi=0190.150, Def{(non-classical form of 啼) to cry; to mourn; to howl, to twitter; to crow, to sneeze; a running at the nose}
3593 CJK UNIFIED IDEOGRAPH-#3593, IRGKangXi=0191.120, Def{(corrupted form) to shout; to scold with loud voice, din; noise; a confused noise}
3594 CJK UNIFIED IDEOGRAPH-#3594, IRGKangXi=0191.180, Def{silly, foolish; doting; idiotic}
3595 CJK UNIFIED IDEOGRAPH-#3595, IRGKangXi=0191.210, Def{to spit out; to blame, name of an organic compounds}
3596 CJK UNIFIED IDEOGRAPH-#3596, IRGKangXi=0192.180, Def{(standard form) to spit out; to blame, name of an organic compounds}
3597 CJK UNIFIED IDEOGRAPH-#3597, IRGKangXi=0193.051, Def{(corrupted form) high ridges of cliffs}
3598 CJK UNIFIED IDEOGRAPH-#3598, IRGKangXi=0193.051, Def{(same as U+5507 唇) to startle, to alarm; afraid; scared, to be surprised; to be amazed}
3599 CJK UNIFIED IDEOGRAPH-#3599, IRGKangXi=0193.051
359A CJK UNIFIED IDEOGRAPH-#359A, IRGKangXi=0193.051
359B CJK UNIFIED IDEOGRAPH-#359B, IRGKangXi=0193.051
359C CJK UNIFIED IDEOGRAPH-#359C, IRGKangXi=0193.051
359D CJK UNIFIED IDEOGRAPH-#359D, IRGKangXi=0193.051
359E CJK UNIFIED IDEOGRAPH-#359E, IRGKangXi=0193.051, Def{(simplified form of 喎) a wry mouth}
359F CJK UNIFIED IDEOGRAPH-#359F, IRGKangXi=0193.080, Def{to deliver over to personally, to communicate orally with one's own mouth}
35A0 CJK UNIFIED IDEOGRAPH-#35A0, IRGKangXi=0193.130, Def{(same as 那 哪) an auxiliary (in grammar), that, there, a final particle.}
35A1 CJK UNIFIED IDEOGRAPH-#35A1, IRGKangXi=0194.040, Def{the birds singing during the night; (Cant.) interjection to indicate the speaker is thinking}
35A2 CJK UNIFIED IDEOGRAPH-#35A2, IRGKangXi=0194.050, Def{(same as 飺) to reject food}
35A3 CJK UNIFIED IDEOGRAPH-#35A3, IRGKangXi=0194.070, Def{(same as U+5485 咅) to spit out; (Cant.) the sound of spitting}
35A4 CJK UNIFIED IDEOGRAPH-#35A4, IRGKangXi=0194.130, Def{wrath; anger}
35A5 CJK UNIFIED IDEOGRAPH-#35A5, IRGKangXi=0194.210, Def{to spit; to vomit; (Cant.) to gnaw (on bones)}
35A6 CJK UNIFIED IDEOGRAPH-#35A6, IRGKangXi=0194.260, Def{loquacity}
35A7 CJK UNIFIED IDEOGRAPH-#35A7, IRGKangXi=0195.070, Def{can not see clear, (ancient form of 吻) lips}
35A8 CJK UNIFIED IDEOGRAPH-#35A8, IRGKangXi=0195.140, Def{Indistinct nasal utterance, laugh, sound of birds}
35A9 CJK UNIFIED IDEOGRAPH-#35A9, IRGKangXi=0196.140, Def{not pure, immodest, to urge, (same as 嗾) to set a dog on}
35AA CJK UNIFIED IDEOGRAPH-#35AA, IRGKangXi=0196.160, Def{sound of surprising, to laugh loudly, to flow off, loquacious, sound; voice; tone}
35AB CJK UNIFIED IDEOGRAPH-#35AB, IRGKangXi=0196.261, Def{(sound transcription) used in names for minority ethnic group in ancient China}
35AC CJK UNIFIED IDEOGRAPH-#35AC, IRGKangXi=0196.261
35AD CJK UNIFIED IDEOGRAPH-#35AD, IRGKangXi=0196.261, Def{(same as 舔) to lick; to taste; (Cant.) even; in addition}
35AE CJK UNIFIED IDEOGRAPH-#35AE, IRGKangXi=0196.261, Def{an interjection used in poems and songs}
35AF CJK UNIFIED IDEOGRAPH-#35AF, IRGKangXi=0196.261
35B0 CJK UNIFIED IDEOGRAPH-#35B0, IRGKangXi=0196.261
35B1 CJK UNIFIED IDEOGRAPH-#35B1, IRGKangXi=0196.261
35B2 CJK UNIFIED IDEOGRAPH-#35B2, IRGKangXi=0196.261
35B3 CJK UNIFIED IDEOGRAPH-#35B3, IRGKangXi=0196.261
35B4 CJK UNIFIED IDEOGRAPH-#35B4, IRGKangXi=0196.261
35B5 CJK UNIFIED IDEOGRAPH-#35B5, IRGKangXi=0196.261
35B6 CJK UNIFIED IDEOGRAPH-#35B6, IRGKangXi=0196.280, Def{(same as 捗) to swallow; to gulp, to be choked with food, (same as 諲) respectful; venerable}
35B7 CJK UNIFIED IDEOGRAPH-#35B7, IRGKangXi=0197.030, Def{bird singing, (same as 啼) to cry; to mourn; to howl, to twitter; to crow}
35B8 CJK UNIFIED IDEOGRAPH-#35B8, IRGKangXi=0197.090, Def{(same as 噱) to laugh heartily; to roar with laughter, (in Shanghai dialect) a promotional gimmick, tone (of one's speech)}
35B9 CJK UNIFIED IDEOGRAPH-#35B9, IRGKangXi=0197.150, Def{(non-classical form of噴) to spurt; to blow out; to puff out, to snort, sound of flowing water}
35BA CJK UNIFIED IDEOGRAPH-#35BA, IRGKangXi=0197.160, Def{to blow; to breath; to puff}
35BB CJK UNIFIED IDEOGRAPH-#35BB, IRGKangXi=0197.230, Def{whisper, bad language}
35BC CJK UNIFIED IDEOGRAPH-#35BC, IRGKangXi=0198.030, Def{(same as 謀) to scheme; to plot; to devise, a device}
35BD CJK UNIFIED IDEOGRAPH-#35BD, IRGKangXi=0198.060, Def{(corrupted form of 嘖) to call out; to make an uproar}
35BE CJK UNIFIED IDEOGRAPH-#35BE, IRGKangXi=0198.120, Def{(same as 咢) to beat a drum; to startle, to argue; to debate; to dispute, (interchangeable 愕) to be surprised; to be amazed; to marvel, (interchangeable 鍔) the blade or edge of a sword, beams of a house}
35BF CJK UNIFIED IDEOGRAPH-#35BF, IRGKangXi=0198.130, Def{a sound; a voice; a tone, an interjection; to hesitate; to harbour doubts}
35C0 CJK UNIFIED IDEOGRAPH-#35C0, IRGKangXi=0198.190, Def{(same as 呦 嚘) the bleating of the deer, sound of insects}
35C1 CJK UNIFIED IDEOGRAPH-#35C1, IRGKangXi=0198.310, Def{(same as 齶) the roof of the mouth, the palate}
35C2 CJK UNIFIED IDEOGRAPH-#35C2, IRGKangXi=0198.320, Def{to keep the mouth shut; to be careful how one speak, (non-classical form of U+7701 省) to examine; to watch; (Cant.) to scour}
35C3 CJK UNIFIED IDEOGRAPH-#35C3, IRGKangXi=0198.340, Def{(same as 吻) the lip, the tone of one's speech, to kiss; a kiss}
35C4 CJK UNIFIED IDEOGRAPH-#35C4, IRGKangXi=0199.040, Def{(non-classical form of 謾) to deceive; to insult}
35C5 CJK UNIFIED IDEOGRAPH-#35C5, IRGKangXi=0199.090, Def{(same as 胡) angry, the throat, what? how? why? which?}
35C6 CJK UNIFIED IDEOGRAPH-#35C6, IRGKangXi=0199.210, Def{sound of the ringed pheasant, cackling of fowls, (same as 嗝) to gag, to vomit, (a dialect) an auxiliary verb (almost same as 的)}
35C7 CJK UNIFIED IDEOGRAPH-#35C7, IRGKangXi=0199.230, Def{to swallow; to gulp, an auxiliary; usually at the end of a sentence to beg or request for something}
35C8 CJK UNIFIED IDEOGRAPH-#35C8, IRGKangXi=0199.240, Def{(same as 曼) long; extended, large}
35C9 CJK UNIFIED IDEOGRAPH-#35C9, IRGKangXi=0200.100, Def{incisive, (the large seal type 籀) to brand criminals on the face, to rob; to plunder, an edge, a two-edged weapon; a sword}
35CA CJK UNIFIED IDEOGRAPH-#35CA, IRGKangXi=0200.210, Def{public opinion; clamour; noise, (ancient form of 雷); thunder, an organic compound (porphin); (porphyrins)}
35CB CJK UNIFIED IDEOGRAPH-#35CB, IRGKangXi=0201.030, Def{(standard form of 喉) the throat; the gullet; guttural}
35CC CJK UNIFIED IDEOGRAPH-#35CC, IRGKangXi=0198.150, Def{(non-classical form) to scold with loud voice, to talk out of control; loquacious}
35CD CJK UNIFIED IDEOGRAPH-#35CD, IRGKangXi=0201.121, Def{(non-classical form) to gnaw; to bite; to masticate, sound of biting}
35CE CJK UNIFIED IDEOGRAPH-#35CE, IRGKangXi=0201.121, Def{(Cant.) final particle indicating emphasis or surprise; phonetic}
35CF CJK UNIFIED IDEOGRAPH-#35CF, IRGKangXi=0201.121
35D0 CJK UNIFIED IDEOGRAPH-#35D0, IRGKangXi=0201.121
35D1 CJK UNIFIED IDEOGRAPH-#35D1, IRGKangXi=0201.121
35D2 CJK UNIFIED IDEOGRAPH-#35D2, IRGKangXi=0201.121, Def{(in grammar) interjection; to express sadness; sorrow and emotional excitement}
35D3 CJK UNIFIED IDEOGRAPH-#35D3, IRGKangXi=0201.170, Def{mouthful}
35D4 CJK UNIFIED IDEOGRAPH-#35D4, IRGKangXi=0201.180, Def{(a dialect) joy; happiness}
35D5 CJK UNIFIED IDEOGRAPH-#35D5, IRGKangXi=0202.040, Def{(same as 雊) the crowing of a pheasant, loud and noise}
35D6 CJK UNIFIED IDEOGRAPH-#35D6, IRGKangXi=0202.160, Def{(non-classical form of 啗) to eat; to chew; to bite. to entice; to lure, to contain; to, comprise}
35D7 CJK UNIFIED IDEOGRAPH-#35D7, IRGKangXi=0202.380, Def{to separate; to part, to split; to crack, to rend; to rip open}
35D8 CJK UNIFIED IDEOGRAPH-#35D8, IRGKangXi=0203.020, Def{to bite the hard and solid food}
35D9 CJK UNIFIED IDEOGRAPH-#35D9, IRGKangXi=0203.030, Def{to shout or bawl, talking manner of a mean person, (same as 謅) to jest; to joke; to quip}
35DA CJK UNIFIED IDEOGRAPH-#35DA, IRGKangXi=0203.200, Def{vexingly verbose or wordy; prosy; complicated; annoying}
35DB CJK UNIFIED IDEOGRAPH-#35DB, IRGKangXi=0204.030, Def{(same as 笑) to laugh; to smile, to laugh at; to ridicule}
35DC CJK UNIFIED IDEOGRAPH-#35DC, IRGKangXi=0203.190, Def{(same as 嗅) to smell, to scent}
35DD CJK UNIFIED IDEOGRAPH-#35DD, IRGKangXi=0204.111
35DE CJK UNIFIED IDEOGRAPH-#35DE, IRGKangXi=0204.111
35DF CJK UNIFIED IDEOGRAPH-#35DF, IRGKangXi=0204.111
35E0 CJK UNIFIED IDEOGRAPH-#35E0, IRGKangXi=0204.111
35E1 CJK UNIFIED IDEOGRAPH-#35E1, IRGKangXi=0204.111
35E2 CJK UNIFIED IDEOGRAPH-#35E2, IRGKangXi=0204.180, Def{loquacious, the sound of singing, to sing in a loud voice, loud}
35E3 CJK UNIFIED IDEOGRAPH-#35E3, IRGKangXi=0204.330, Def{(same as 嚏) to sneeze; a running at the nose}
35E4 CJK UNIFIED IDEOGRAPH-#35E4, IRGKangXi=0204.360, Def{ashamed, restless; fidgeting; (a dialect) bashful, grievous; mournful; sad}
35E5 CJK UNIFIED IDEOGRAPH-#35E5, IRGKangXi=0205.040, Def{sound of striking, slow expiration of the breath, a deep sign}
35E6 CJK UNIFIED IDEOGRAPH-#35E6, IRGKangXi=0205.080, Def{a loud and confused noise}
35E7 CJK UNIFIED IDEOGRAPH-#35E7, IRGKangXi=0205.120, Def{to scold with loud voice, to talk out of control; loquacious}
35E8 CJK UNIFIED IDEOGRAPH-#35E8, IRGKangXi=0205.190, Def{to laugh; to smile, to laugh at; to ridicule, sound of laughter}
35E9 CJK UNIFIED IDEOGRAPH-#35E9, IRGKangXi=0205.220, Def{sound made when cold (brrr); to endure cold}
35EA CJK UNIFIED IDEOGRAPH-#35EA, IRGKangXi=0205.240, Def{(corrupted form) mouthful}
35EB CJK UNIFIED IDEOGRAPH-#35EB, IRGKangXi=0206.020, Def{to whisper; to talk in a soft and low voice}
35EC CJK UNIFIED IDEOGRAPH-#35EC, IRGKangXi=0206.110, Def{thick lips, to talk slowly}
35ED CJK UNIFIED IDEOGRAPH-#35ED, IRGKangXi=0206.190, Def{a sound; an echo}
35EE CJK UNIFIED IDEOGRAPH-#35EE, IRGKangXi=0206.201
35EF CJK UNIFIED IDEOGRAPH-#35EF, IRGKangXi=0206.201
35F0 CJK UNIFIED IDEOGRAPH-#35F0, IRGKangXi=0206.201, Def{used in transliteration; the traditional drama of Vietnam; (Cant.) all, entire, completely}
35F1 CJK UNIFIED IDEOGRAPH-#35F1, IRGKangXi=0206.300, Def{to suck; to chew, to smear the mouth with the blood of a victim when taking an oath}
35F2 CJK UNIFIED IDEOGRAPH-#35F2, IRGKangXi=0207.060, Def{to call; to summon; (Cant.) eloquent}
35F3 CJK UNIFIED IDEOGRAPH-#35F3, IRGKangXi=0207.170, Def{forgetful; having a bad memory, disgraced; shy; sensitive to shame; ashamed; (Cant.) to lower one's head}
35F4 CJK UNIFIED IDEOGRAPH-#35F4, IRGKangXi=0207.310, Def{dogs fighting, to go to law; an indictment}
35F5 CJK UNIFIED IDEOGRAPH-#35F5, IRGKangXi=0208.150, Def{breath, air, steam, not clear; not quite sure}
35F6 CJK UNIFIED IDEOGRAPH-#35F6, IRGKangXi=0208.260, Def{to expel the breath}
35F7 CJK UNIFIED IDEOGRAPH-#35F7, IRGKangXi=0209.151, Def{(simplified form) to eat; to bite; to gnaw, a dialect, usually used at the end of a sentence}
35F8 CJK UNIFIED IDEOGRAPH-#35F8, IRGKangXi=0209.151
35F9 CJK UNIFIED IDEOGRAPH-#35F9, IRGKangXi=0209.151
35FA CJK UNIFIED IDEOGRAPH-#35FA, IRGKangXi=0209.151
35FB CJK UNIFIED IDEOGRAPH-#35FB, IRGKangXi=0209.220, Def{baby's answering, (baby talk) eat; (Cant.) a particle implying doubt; slow, troublesome}
35FC CJK UNIFIED IDEOGRAPH-#35FC, IRGKangXi=0209.360, Def{eating or talking, moving of the mouth}
35FD CJK UNIFIED IDEOGRAPH-#35FD, IRGKangXi=0209.370, Def{(standard form 響) an echo; to answer; to consent, noise; sound, to make a noise}
35FE CJK UNIFIED IDEOGRAPH-#35FE, IRGKangXi=0210.130, Def{to give vent to the feelings; (Cant.) to hiss, boo, jeer}
35FF CJK UNIFIED IDEOGRAPH-#35FF, IRGKangXi=0210.230, Def{to laugh loudly, to blame; to reprimand, entrance to a cave or to a gorge}
3600 CJK UNIFIED IDEOGRAPH-#3600, IRGKangXi=0210.250, Def{to sound, a sound, the cry of a bird or animal}
3601 CJK UNIFIED IDEOGRAPH-#3601, IRGKangXi=0211.010, Def{to call; to scream; to whistle, name of a stream}
3602 CJK UNIFIED IDEOGRAPH-#3602, IRGKangXi=0211.020, Def{ashamed; bashful}
3603 CJK UNIFIED IDEOGRAPH-#3603, IRGKangXi=0211.121
3604 CJK UNIFIED IDEOGRAPH-#3604, IRGKangXi=0211.121
3605 CJK UNIFIED IDEOGRAPH-#3605, IRGKangXi=0211.270, Def{(same as U+929C 銜 U+5563 啣) to hold in the mouth}
3606 CJK UNIFIED IDEOGRAPH-#3606, IRGKangXi=0211.280, Def{to laugh at; to deride; to jeer at, to snore}
3607 CJK UNIFIED IDEOGRAPH-#3607, IRGKangXi=0211.380
3608 CJK UNIFIED IDEOGRAPH-#3608, IRGKangXi=0212.040, Def{able to take a correct view of things; to response correctly (said of small children), sound; echo}
3609 CJK UNIFIED IDEOGRAPH-#3609, IRGKangXi=0212.210, Def{to make sound; to speak; (Cant.) to tickle, squeeze}
360A CJK UNIFIED IDEOGRAPH-#360A, IRGKangXi=0212.280, Def{the abrupt and hasty sound of the crowd}
360B CJK UNIFIED IDEOGRAPH-#360B, IRGKangXi=0212.300, Def{sound; echo, difficult; troublesome}
360C CJK UNIFIED IDEOGRAPH-#360C, IRGKangXi=0212.330, Def{(non-classical form of 噱) to laugh without stopping, loud laughter}
360D CJK UNIFIED IDEOGRAPH-#360D, IRGKangXi=0212.360, Def{sound of rat; sound of insects}
360E CJK UNIFIED IDEOGRAPH-#360E, IRGKangXi=0213.171, Def{(simplified form) the roars of a tiger}
360F CJK UNIFIED IDEOGRAPH-#360F, IRGKangXi=0213.171
3610 CJK UNIFIED IDEOGRAPH-#3610, IRGKangXi=0213.200, Def{loud; to roar}
3611 CJK UNIFIED IDEOGRAPH-#3611, IRGKangXi=0213.220, Def{to curse, to swear and oath, incantations}
3612 CJK UNIFIED IDEOGRAPH-#3612, IRGKangXi=0213.471
3613 CJK UNIFIED IDEOGRAPH-#3613, IRGKangXi=0214.060, Def{prolix speech, (same as 讕) to make a false charge; to lay a false accusation}
3614 CJK UNIFIED IDEOGRAPH-#3614, IRGKangXi=0214.151, Def{eat, to bite, to gnaw, (a dialect) usually at the end of a sentence; tone (of one's speech)}
3615 CJK UNIFIED IDEOGRAPH-#3615, IRGKangXi=0214.190, Def{(non-classical form of 喊) (standard form of 婪) to call; to halloo, covetous; avaricious}
3616 CJK UNIFIED IDEOGRAPH-#3616, IRGKangXi=0214.250, Def{to make a disturbance; to quarrel; to wrangle}
3617 CJK UNIFIED IDEOGRAPH-#3617, IRGKangXi=0215.051, Def{whisper; to whistle}
3618 CJK UNIFIED IDEOGRAPH-#3618, IRGKangXi=0215.221
3619 CJK UNIFIED IDEOGRAPH-#3619, IRGKangXi=0215.230, Def{to groan; to moan}
361A CJK UNIFIED IDEOGRAPH-#361A, IRGKangXi=0215.271, Def{angry appearance; to look furious; the roaring of a tiger}
361B CJK UNIFIED IDEOGRAPH-#361B, IRGKangXi=0216.070, Def{(non-classical form of 嵌) a deep valley, piece of music in minority group}
361C CJK UNIFIED IDEOGRAPH-#361C, IRGKangXi=0216.110, Def{(non-classical form of 雔) a kind of silkworm, pair of birds; couple; companion; to match, corresponding, proper}
361D CJK UNIFIED IDEOGRAPH-#361D, IRGKangXi=0216.190, Def{to take in; to absorb, (non-classical form of 罱) a kind of spring fishing net; a kind of small net with a handle used to catch fishes or birds}
361E CJK UNIFIED IDEOGRAPH-#361E, IRGKangXi=0146.150, Def{sound of yelling while towing a boat; (Sanskrit) to call out}
361F CJK UNIFIED IDEOGRAPH-#361F, IRGKangXi=0217.061
3620 CJK UNIFIED IDEOGRAPH-#3620, IRGKangXi=0217.290, Def{to close; to stop up; to obstruct}
3621 CJK UNIFIED IDEOGRAPH-#3621, IRGKangXi=0217.310, Def{(same as 柙) a pen for wild beasts; a cage for prisoners}
3622 CJK UNIFIED IDEOGRAPH-#3622, IRGKangXi=0218.050, Def{a round cave; a round hole}
3623 CJK UNIFIED IDEOGRAPH-#3623, IRGKangXi=0218.170, Def{compasses, (same as U+5713 圓) round; circular}
3624 CJK UNIFIED IDEOGRAPH-#3624, IRGKangXi=0220.160, Def{circle of the moving water}
3625 CJK UNIFIED IDEOGRAPH-#3625, IRGKangXi=0221.160, Def{(same as 囮) to inveigle; to decoy, a decoy-bird; a go-between; a medium}
3626 CJK UNIFIED IDEOGRAPH-#3626, IRGKangXi=0223.080, Def{wall made of soil, used in name of places}
3627 CJK UNIFIED IDEOGRAPH-#3627, IRGKangXi=0225.020, Def{(same as 序) precedence, order, orderly, the east and west walls of the parlor}
3628 CJK UNIFIED IDEOGRAPH-#3628, IRGKangXi=0225.050, Def{deep; profound, empty; hollow, quite; peaceful}
3629 CJK UNIFIED IDEOGRAPH-#3629, IRGKangXi=0225.110, Def{to mate; to pair}
362A CJK UNIFIED IDEOGRAPH-#362A, IRGKangXi=0226.080, Def{(same as 耗) to waste, to destroy, to diminish; hence it came to mean, a rat, heedless; careless; inattentive; rough and coarse}
362B CJK UNIFIED IDEOGRAPH-#362B, IRGKangXi=0226.101, Def{(a variant of 阱) to fall into a well, a pit; a pitfall; a hole; a gully, to involve; to entrap}
362C CJK UNIFIED IDEOGRAPH-#362C, IRGKangXi=0226.101, Def{(same as 坳) a hollow in the ground; a cavity, (same as 物) matter; substance, all living creatures, things in general, the affairs of this world, things or matters outside oneself, others, goods, the Tibetan classical text means Buddha}
362D CJK UNIFIED IDEOGRAPH-#362D, IRGKangXi=0226.101, Def{(same as 坳) a hollow in the ground; a cavity, undulating}
362E CJK UNIFIED IDEOGRAPH-#362E, IRGKangXi=0226.101
362F CJK UNIFIED IDEOGRAPH-#362F, IRGKangXi=0226.101
3630 CJK UNIFIED IDEOGRAPH-#3630, IRGKangXi=0226.101, Def{(interchangeable 斟) name of a old country; used in name of a place}
3631 CJK UNIFIED IDEOGRAPH-#3631, IRGKangXi=0226.230, Def{(same as 坍) to fall into ruins; to collapse}
3632 CJK UNIFIED IDEOGRAPH-#3632, IRGKangXi=0226.360, Def{a cove; a bay, a bend or nook in the hills, the outside part of a curved bank; the curve of a bow}
3633 CJK UNIFIED IDEOGRAPH-#3633, IRGKangXi=0227.230, Def{(same as 丘) a hillock or mound}
3634 CJK UNIFIED IDEOGRAPH-#3634, IRGKangXi=0227.271, Def{(same as 坐) to sit, a seat}
3635 CJK UNIFIED IDEOGRAPH-#3635, IRGKangXi=0227.271, Def{name of a place; in Fujian Province}
3636 CJK UNIFIED IDEOGRAPH-#3636, IRGKangXi=0228.060, Def{(ancient form of 桀) a hen-roost, cruel, the last ruler of the Xia Dynasty}
3637 CJK UNIFIED IDEOGRAPH-#3637, IRGKangXi=0228.230, Def{(same as 艾) Mugwort, artemisia or any plant which produces moxa punk, general name for plants like mint}
3638 CJK UNIFIED IDEOGRAPH-#3638, IRGKangXi=0228.290, Def{(same as 葬) to bury, (ancient form of 坐) to sit, a seat}
3639 CJK UNIFIED IDEOGRAPH-#3639, IRGKangXi=0227.271, Def{(non-classical form of 垐) to spread soil on the road, pave the road with soil, (ancient form of 堲) sickness; illness; disease}
363A CJK UNIFIED IDEOGRAPH-#363A, IRGKangXi=0228.291, Def{cultivated land; to till lands, a clod of earth}
363B CJK UNIFIED IDEOGRAPH-#363B, IRGKangXi=0228.291, Def{to stop up; to close against; to restrain, to dam a stream and change its direction, to conceal a mound}
363C CJK UNIFIED IDEOGRAPH-#363C, IRGKangXi=0228.291
363D CJK UNIFIED IDEOGRAPH-#363D, IRGKangXi=0228.291
363E CJK UNIFIED IDEOGRAPH-#363E, IRGKangXi=0228.291
363F CJK UNIFIED IDEOGRAPH-#363F, IRGKangXi=0228.300, Def{(same as 涅) to fill up, as a hole, black mud; slime, to stop up; to block; to cork}
3640 CJK UNIFIED IDEOGRAPH-#3640, IRGKangXi=0229.020, Def{a vegetable-plot, to plough; to till lands, among dikes and fields}
3641 CJK UNIFIED IDEOGRAPH-#3641, IRGKangXi=0229.140, Def{dust; dirt; a smear, (same as 牧) name of a place in old times}
3642 CJK UNIFIED IDEOGRAPH-#3642, IRGKangXi=0230.100, Def{wall; fence, (interchangeable with 兑) a hole}
3643 CJK UNIFIED IDEOGRAPH-#3643, IRGKangXi=0230.110, Def{a cavity; hole of a mound or an altar of earth}
3644 CJK UNIFIED IDEOGRAPH-#3644, IRGKangXi=0230.121, Def{below; under; low, (same as 陛) the steps to the throne, to ascend steps}
3645 CJK UNIFIED IDEOGRAPH-#3645, IRGKangXi=0230.121, Def{(same as 堡) a walled village, an earth-work; a petty military station, subdivision of a township; a ward in a city}
3646 CJK UNIFIED IDEOGRAPH-#3646, IRGKangXi=0230.121
3647 CJK UNIFIED IDEOGRAPH-#3647, IRGKangXi=0230.210, Def{place trampled by cattle and horses}
3648 CJK UNIFIED IDEOGRAPH-#3648, IRGKangXi=0230.240, Def{name of a place in Shanxi province}
3649 CJK UNIFIED IDEOGRAPH-#3649, IRGKangXi=0230.270, Def{(same as 腆) prosperous; affluence, good; virtuous, to make strong -- as liquors}
364A CJK UNIFIED IDEOGRAPH-#364A, IRGKangXi=0231.010, Def{(same as 場) an area of level ground; an open space, a threshing floor, arena for drill, etc. a place, to pile a sand-hills}
364B CJK UNIFIED IDEOGRAPH-#364B, IRGKangXi=0232.181
364C CJK UNIFIED IDEOGRAPH-#364C, IRGKangXi=0232.181, Def{(a simplified form)}
364D CJK UNIFIED IDEOGRAPH-#364D, IRGKangXi=0232.181, Def{name of a place in today's Guangdong Province}
364E CJK UNIFIED IDEOGRAPH-#364E, IRGKangXi=0233.100, Def{breach of a tank; pond, (a dialect) to cover up; to conceal; to hide; to bury}
364F CJK UNIFIED IDEOGRAPH-#364F, IRGKangXi=0233.170, Def{caverns; a grotto, a cellar, a cave-dwelling, to make a cave -- for dwelling}
3650 CJK UNIFIED IDEOGRAPH-#3650, IRGKangXi=0233.230, Def{to move, to hang down; to let fall, (same as 垛) a target, a battlement, to add up; to pile up}
3651 CJK UNIFIED IDEOGRAPH-#3651, IRGKangXi=0234.130, Def{(same as 宇) the canopy of heaven; space, to cover; to shelter}
3652 CJK UNIFIED IDEOGRAPH-#3652, IRGKangXi=0234.200, Def{(same as 野) wild; uncultivated; a wilderness, rustic, savage}
3653 CJK UNIFIED IDEOGRAPH-#3653, IRGKangXi=0234.271, Def{earth; land; soil; ground; territory, opium}
3654 CJK UNIFIED IDEOGRAPH-#3654, IRGKangXi=0234.271, Def{(non-classical form of 韓) a fence, name of a star, a small feudal State, old name for Korea}
3655 CJK UNIFIED IDEOGRAPH-#3655, IRGKangXi=0234.271, Def{(same as 塊) a lump, a piece of, a fraction}
3656 CJK UNIFIED IDEOGRAPH-#3656, IRGKangXi=0234.271
3657 CJK UNIFIED IDEOGRAPH-#3657, IRGKangXi=0234.271, Def{(same as 塊) a lump of earth; a lump, rugged; uneven}
3658 CJK UNIFIED IDEOGRAPH-#3658, IRGKangXi=0234.271, Def{used in naming a place}
3659 CJK UNIFIED IDEOGRAPH-#3659, IRGKangXi=0234.290, Def{to smear; to daub, to erase; to blot out, mud, mire, to plaster a wall with mud}
365A CJK UNIFIED IDEOGRAPH-#365A, IRGKangXi=0235.030, Def{red colored hard and solid mud (soil; clay; earth)}
365B CJK UNIFIED IDEOGRAPH-#365B, IRGKangXi=0235.190, Def{a person's name in old times}
365C CJK UNIFIED IDEOGRAPH-#365C, IRGKangXi=0236.341, Def{(ancient and corrupted form of U+81FA 臺) a lookout, a tower, a terrace, a platform, a stage}
365D CJK UNIFIED IDEOGRAPH-#365D, IRGKangXi=0236.110, Def{a dike; a barrier; an embankment}
365E CJK UNIFIED IDEOGRAPH-#365E, IRGKangXi=0236.130, Def{a small mountain; a hill}
365F CJK UNIFIED IDEOGRAPH-#365F, IRGKangXi=0238.191, Def{(a dialect) low-lying (ground) on the side of a river or lake, (a variant 塱) name of a place in Guangdong}
3660 CJK UNIFIED IDEOGRAPH-#3660, IRGKangXi=0237.010, Def{dust; dirt; a smear, (same as 曀) the sun hidden by clouds, obscure}
3661 CJK UNIFIED IDEOGRAPH-#3661, IRGKangXi=0237.040, Def{a kind of eatable mushroom}
3662 CJK UNIFIED IDEOGRAPH-#3662, IRGKangXi=0237.070, Def{(same as 墁 鏝) a trowel; a plaster; a trowel for plastering}
3663 CJK UNIFIED IDEOGRAPH-#3663, IRGKangXi=0237.190, Def{to pile a sand-hills}
3664 CJK UNIFIED IDEOGRAPH-#3664, IRGKangXi=0237.230, Def{(same as 罅) a crack in earthenware, a split; rip or break apart; thus -- a grudge}
3665 CJK UNIFIED IDEOGRAPH-#3665, IRGKangXi=0238.190, Def{muddy}
3666 CJK UNIFIED IDEOGRAPH-#3666, IRGKangXi=0238.191
3667 CJK UNIFIED IDEOGRAPH-#3667, IRGKangXi=0238.210, Def{(same as 塯) earthenware; a kind of rice container}
3668 CJK UNIFIED IDEOGRAPH-#3668, IRGKangXi=0238.240, Def{(same as 畿) the royal domains set apart in ancient times for the emperor}
3669 CJK UNIFIED IDEOGRAPH-#3669, IRGKangXi=0238.270, Def{an enclosing wall}
366A CJK UNIFIED IDEOGRAPH-#366A, IRGKangXi=0238.300, Def{dark; the sun hidden by clouds, obscure}
366B CJK UNIFIED IDEOGRAPH-#366B, IRGKangXi=0239.090, Def{a fountain or spring out from the underground}
366C CJK UNIFIED IDEOGRAPH-#366C, IRGKangXi=0239.170, Def{(ancient form of 垠) a bank; a boundary}
366D CJK UNIFIED IDEOGRAPH-#366D, IRGKangXi=0239.241
366E CJK UNIFIED IDEOGRAPH-#366E, IRGKangXi=0239.241, Def{a tower, pagoda}
366F CJK UNIFIED IDEOGRAPH-#366F, IRGKangXi=0239.241, Def{(same as 藝) skill, ability in handicraft, a craft, an art, a calling, a trade, an accomplishment}
3670 CJK UNIFIED IDEOGRAPH-#3670, IRGKangXi=0240.070, Def{name of a place in ancient times}
3671 CJK UNIFIED IDEOGRAPH-#3671, IRGKangXi=0240.090, Def{earthenware used to bake cakes in Northern China}
3672 CJK UNIFIED IDEOGRAPH-#3672, IRGKangXi=0240.190, Def{(same as 壅) to stop up; to obstruct}
3673 CJK UNIFIED IDEOGRAPH-#3673, IRGKangXi=0240.200, Def{ruggedness of the road; difficulties of the way; bad luck, unable to reach one's aim}
3674 CJK UNIFIED IDEOGRAPH-#3674, IRGKangXi=0240.230, Def{to conceal; to hide, to shade; to darken}
3675 CJK UNIFIED IDEOGRAPH-#3675, IRGKangXi=0240.290, Def{(ancient form of 臺) a lookout, a tower, a terrace, a platform; a stage}
3676 CJK UNIFIED IDEOGRAPH-#3676, IRGKangXi=0240.300, Def{(large seal type of 堂) a hall; a reception room; a meeting-place, a court of justice}
3677 CJK UNIFIED IDEOGRAPH-#3677, IRGKangXi=0240.320, Def{low-lying area, to accumulate soil; to store up soil}
3678 CJK UNIFIED IDEOGRAPH-#3678, IRGKangXi=0241.020, Def{(non-classical form 墣) a clod of earth; a lump of earth; a lump}
3679 CJK UNIFIED IDEOGRAPH-#3679, IRGKangXi=0241.150, Def{a damp; a marsh, (interchangeable 夢)}
367A CJK UNIFIED IDEOGRAPH-#367A, IRGKangXi=0241.160, Def{(same as 逵 馗) cross-road; a thorough-fare; a center from which nine roads lead out, to accumulate soil, to store up soil}
367B CJK UNIFIED IDEOGRAPH-#367B, IRGKangXi=0241.220, Def{(non-classical form of 廛) living space for one family in ancient times, ground allotted to a retainer, a shop; a market place}
367C CJK UNIFIED IDEOGRAPH-#367C, IRGKangXi=0241.281, Def{(same as 壘) a military wall, a rampart, to pile up, a pile}
367D CJK UNIFIED IDEOGRAPH-#367D, IRGKangXi=0241.281
367E CJK UNIFIED IDEOGRAPH-#367E, IRGKangXi=0242.110, Def{(same as 嶨) hills with lots of big rocks}
367F CJK UNIFIED IDEOGRAPH-#367F, IRGKangXi=0242.141
3680 CJK UNIFIED IDEOGRAPH-#3680, IRGKangXi=0242.150, Def{lofty, dangerous; critical, (same as 虧) to destroy; to injure; to damage}
3681 CJK UNIFIED IDEOGRAPH-#3681, IRGKangXi=0242.350, Def{the long tail feathers which curl up; to elevate; to raise the head; warped, (interchangeable 翹) long tail feathers, to raise, outstanding}
3682 CJK UNIFIED IDEOGRAPH-#3682, IRGKangXi=0242.360, Def{dust; dirt, a cellar, a caverns}
3683 CJK UNIFIED IDEOGRAPH-#3683, IRGKangXi=0243.160, Def{to take a hint; a group of Chinese characters the construction of which suggests the meaning, the fate; good luck or bad are in the pot; don't expose; or leak out}
3684 CJK UNIFIED IDEOGRAPH-#3684, IRGKangXi=0244.111
3685 CJK UNIFIED IDEOGRAPH-#3685, IRGKangXi=0244.240, Def{to worship of God, to praise; many; much}
3686 CJK UNIFIED IDEOGRAPH-#3686, IRGKangXi=0245.080, Def{to do something in an old way; use the old method; to go to the old road}
3687 CJK UNIFIED IDEOGRAPH-#3687, IRGKangXi=0245.100, RSKangXi=35.6, Def{draw the feet up; to refuse to advance, to summarize; to gather; to collect, name of an old country, (same as U+9350 鍐) a headstall; ornament on a bridle; (Cant.) to jump up}
3688 CJK UNIFIED IDEOGRAPH-#3688, IRGKangXi=0246.061
3689 CJK UNIFIED IDEOGRAPH-#3689, IRGKangXi=0247.020, Def{(corrupted form) to make a profit on sell and buy; the profit in business, (interchangeable 嬴) a overplus; gain; profit; abundance}
368A CJK UNIFIED IDEOGRAPH-#368A, IRGKangXi=0247.140, Def{much; many; numerous, great; big; vast}
368B CJK UNIFIED IDEOGRAPH-#368B, IRGKangXi=0247.210, Def{much; many; numerous, great; big; vast}
368C CJK UNIFIED IDEOGRAPH-#368C, IRGKangXi=0247.230, Def{(same as 夥) a band; a company; a partner; an assistant}
368D CJK UNIFIED IDEOGRAPH-#368D, IRGKangXi=0247.260, Def{much; many; numerous, to get more profit, to estimate more}
368E CJK UNIFIED IDEOGRAPH-#368E, IRGKangXi=0249.111
368F CJK UNIFIED IDEOGRAPH-#368F, IRGKangXi=0249.120, Def{(corrupted form) to scatter; to disperse, to give the reins to; to allow to run wild; unstable; light; featherbrained}
3690 CJK UNIFIED IDEOGRAPH-#3690, IRGKangXi=0250.071, Def{(same as 套) a case; a wrapper; a covering; a snare, to encase; to slip over}
3691 CJK UNIFIED IDEOGRAPH-#3691, IRGKangXi=0250.071
3692 CJK UNIFIED IDEOGRAPH-#3692, IRGKangXi=0250.120, Def{concealed the stolen goods in one's dress}
3693 CJK UNIFIED IDEOGRAPH-#3693, IRGKangXi=0250.140, Def{tie-beams of a small boat}
3694 CJK UNIFIED IDEOGRAPH-#3694, IRGKangXi=0250.240, Def{instrument of torture used in ancient times, loud, an evil doer all the times, (same as 幸) to rejoice, fortunate; prosperous}
3695 CJK UNIFIED IDEOGRAPH-#3695, IRGKangXi=0250.250, Def{great; big; vast, (same as 弼) to aid; to assist; as in the government, (interchangeable 佛) Buddha}
3696 CJK UNIFIED IDEOGRAPH-#3696, IRGKangXi=0250.280, Def{(said of truth) to come out to the open; to be known by all, (ancient form 澤) glossy; shining}
3697 CJK UNIFIED IDEOGRAPH-#3697, IRGKangXi=0250.290, Def{with a big mouth, great; big; vast}
3698 CJK UNIFIED IDEOGRAPH-#3698, IRGKangXi=0250.300, Def{(interchangeable 伴) a partner; a companion, (same as 赫) bright; luminous, glorious (same as 扶) to support; to prop up; to help}
3699 CJK UNIFIED IDEOGRAPH-#3699, IRGKangXi=0251.091
369A CJK UNIFIED IDEOGRAPH-#369A, IRGKangXi=0251.140, Def{big; great; vast, very, liberal, bark (as a dog)}
369B CJK UNIFIED IDEOGRAPH-#369B, IRGKangXi=0252.051, Def{corpulent, abundant; flourishing; plenteous}
369C CJK UNIFIED IDEOGRAPH-#369C, IRGKangXi=0252.210, Def{with great power; vigorous; very strong; with great force, (same as 域) a frontier; a boundary; region, great; big; vast}
369D CJK UNIFIED IDEOGRAPH-#369D, IRGKangXi=0253.040, Def{(same as 奎) the stride made by a man, name of a star, a kind of tree}
369E CJK UNIFIED IDEOGRAPH-#369E, IRGKangXi=0253.041, Def{terror; horror; fear}
369F CJK UNIFIED IDEOGRAPH-#369F, IRGKangXi=0253.060, Def{(non-classical form) a kind of animal; with head looks like rabbit and feet deer, small rabbit}
36A0 CJK UNIFIED IDEOGRAPH-#36A0, IRGKangXi=0253.160, Def{full grown; fat; plump, fertile; rich, big and clumsy}
36A1 CJK UNIFIED IDEOGRAPH-#36A1, IRGKangXi=0254.151, Def{standing without a straight back}
36A2 CJK UNIFIED IDEOGRAPH-#36A2, IRGKangXi=0255.010, Def{(ancient form of 奴) a slave; a servant, term of depreciation, (ancient form of 侮) to insult; to ridicule}
36A3 CJK UNIFIED IDEOGRAPH-#36A3, IRGKangXi=0255.060, Def{(ancient form of U+59E3 姣 U+5B0C 嬌) handsome; pretty, cunning, meretricious allurements, to insult; to disgrace, licentious; profligate; lewd; (Cant.) amorous, in love with}
36A4 CJK UNIFIED IDEOGRAPH-#36A4, IRGKangXi=0255.100, Def{a lady officer of the monarch's palace in old times}
36A5 CJK UNIFIED IDEOGRAPH-#36A5, IRGKangXi=0255.200, Def{to become associated with each other in good manners and politeness}
36A6 CJK UNIFIED IDEOGRAPH-#36A6, IRGKangXi=0256.030, Def{(ancient form of U+59EC 姬) a charming girl, a charming concubine; a monarch's wife}
36A7 CJK UNIFIED IDEOGRAPH-#36A7, IRGKangXi=0256.040, Def{(same as 嬐) agile; adroit fast; quick; prompt, neat; tidy; orderly, to raise the head; to look up}
36A8 CJK UNIFIED IDEOGRAPH-#36A8, IRGKangXi=0256.041, Def{used in girl's name}
36A9 CJK UNIFIED IDEOGRAPH-#36A9, IRGKangXi=0256.110, Def{with a charming sprightly carriage (said of a woman)}
36AA CJK UNIFIED IDEOGRAPH-#36AA, IRGKangXi=0256.130, Def{to make a deceptive show of power, not really strict}
36AB CJK UNIFIED IDEOGRAPH-#36AB, IRGKangXi=0256.250, Def{used in girl's name, a woman's countenance; features}
36AC CJK UNIFIED IDEOGRAPH-#36AC, IRGKangXi=0257.050, Def{a lady start to doll up}
36AD CJK UNIFIED IDEOGRAPH-#36AD, IRGKangXi=0257.101, Def{used in girl's name}
36AE CJK UNIFIED IDEOGRAPH-#36AE, IRGKangXi=0257.101, Def{(non-classical form 妉,媅) happy; pleased, to laugh}
36AF CJK UNIFIED IDEOGRAPH-#36AF, IRGKangXi=0257.101, Def{(simplified form) last name}
36B0 CJK UNIFIED IDEOGRAPH-#36B0, IRGKangXi=0257.110, Def{(same as 胚) an embryo; a foetus a month old}
36B1 CJK UNIFIED IDEOGRAPH-#36B1, IRGKangXi=0257.260, Def{used in girl's name}
36B2 CJK UNIFIED IDEOGRAPH-#36B2, IRGKangXi=0257.380, Def{small and weak, used in girl's name, a woman's feature; lady's face}
36B3 CJK UNIFIED IDEOGRAPH-#36B3, IRGKangXi=0257.410, Def{a lady teacher to teach the proper rules of female behavior in ancient times}
36B4 CJK UNIFIED IDEOGRAPH-#36B4, IRGKangXi=0258.060, Def{a pretty girl; a beauty; a belle, handsome; female beauty}
36B5 CJK UNIFIED IDEOGRAPH-#36B5, IRGKangXi=0258.080, Def{used in girl's name}
36B6 CJK UNIFIED IDEOGRAPH-#36B6, IRGKangXi=0258.100, Def{(same as 姒) wife of one's husband's elder brother; (in ancient China) the elder of twins; a Chinese family name, (same as 姬) a handsome girl; a charming girl; a concubine; a Chinese family name}
36B7 CJK UNIFIED IDEOGRAPH-#36B7, IRGKangXi=0258.120, Def{(same as 嬭) the breasts of a woman; milk; a term of respect for women; grandma, one's elder sister or sisters, used for a girl's name}
36B8 CJK UNIFIED IDEOGRAPH-#36B8, IRGKangXi=0259.010, Def{used in girl's name}
36B9 CJK UNIFIED IDEOGRAPH-#36B9, IRGKangXi=0259.090, Def{(same as 媌) pretty; charming girl, (same as 懰) exquisite; fine}
36BA CJK UNIFIED IDEOGRAPH-#36BA, IRGKangXi=0259.110, Def{(non-classical form of 孕) to be pregnant; to conceive}
36BB CJK UNIFIED IDEOGRAPH-#36BB, IRGKangXi=0259.150, Def{sodomy; to bugger}
36BC CJK UNIFIED IDEOGRAPH-#36BC, IRGKangXi=0259.151, Def{(non-classical form of 妞) a girl; a little girl}
36BD CJK UNIFIED IDEOGRAPH-#36BD, IRGKangXi=0259.151, Def{used in girl's name}
36BE CJK UNIFIED IDEOGRAPH-#36BE, IRGKangXi=0259.151, Def{to have fun; to sport; to play; to frolic}
36BF CJK UNIFIED IDEOGRAPH-#36BF, IRGKangXi=0259.151, Def{a goddess's name in legend; the sister and successor of Fu Xi 伏羲, (interchangeable 庖), last name}
36C0 CJK UNIFIED IDEOGRAPH-#36C0, IRGKangXi=0259.151
36C1 CJK UNIFIED IDEOGRAPH-#36C1, IRGKangXi=0259.151, Def{quick; urgent; anxious, loyal sincere and respectful}
36C2 CJK UNIFIED IDEOGRAPH-#36C2, IRGKangXi=0260.030, Def{weak and small}
36C3 CJK UNIFIED IDEOGRAPH-#36C3, IRGKangXi=0260.140, Def{clean; pure; clear, usually used for names}
36C4 CJK UNIFIED IDEOGRAPH-#36C4, IRGKangXi=0260.160, Def{used in girl's name}
36C5 CJK UNIFIED IDEOGRAPH-#36C5, IRGKangXi=0261.050, Def{used in girl's name}
36C6 CJK UNIFIED IDEOGRAPH-#36C6, IRGKangXi=0261.270, Def{to speculate; to conjecture; to assume; to make an intelligent guess; to fathom, (of a woman) beautiful, used in girl's name}
36C7 CJK UNIFIED IDEOGRAPH-#36C7, IRGKangXi=0261.321
36C8 CJK UNIFIED IDEOGRAPH-#36C8, IRGKangXi=0261.321
36C9 CJK UNIFIED IDEOGRAPH-#36C9, IRGKangXi=0261.321
36CA CJK UNIFIED IDEOGRAPH-#36CA, IRGKangXi=0261.321, Def{to speculate; to conjecture; to assume; to make an intelligent guess; to fathom, (of a woman) beautiful, used in girl's name}
36CB CJK UNIFIED IDEOGRAPH-#36CB, IRGKangXi=0261.321
36CC CJK UNIFIED IDEOGRAPH-#36CC, IRGKangXi=0261.321
36CD CJK UNIFIED IDEOGRAPH-#36CD, IRGKangXi=0261.340, Def{to have one's ambition fulfilled; to be successful in one's career; (same as 愜) pleasing; satisfying; to gratify or be gratified, undignified; improper}
36CE CJK UNIFIED IDEOGRAPH-#36CE, IRGKangXi=0261.350, Def{an ugly woman}
36CF CJK UNIFIED IDEOGRAPH-#36CF, IRGKangXi=0261.390, Def{used in girl's name}
36D0 CJK UNIFIED IDEOGRAPH-#36D0, IRGKangXi=0262.050, Def{(non-classical form of 嫂) wife of one's elder's brother}
36D1 CJK UNIFIED IDEOGRAPH-#36D1, IRGKangXi=0262.110, Def{three women, beautiful things}
36D2 CJK UNIFIED IDEOGRAPH-#36D2, IRGKangXi=0262.120, Def{can not speak}
36D3 CJK UNIFIED IDEOGRAPH-#36D3, IRGKangXi=0262.200, Def{used in girl's name}
36D4 CJK UNIFIED IDEOGRAPH-#36D4, IRGKangXi=0262.220, Def{(same as 妦) exquisite; fine; (said of a woman's figure) very full and voluptuous; buxom, used in girl's name}
36D5 CJK UNIFIED IDEOGRAPH-#36D5, IRGKangXi=0262.240, Def{womanly, (same as 姶 ancient form) exquisite; fine, used in girl's name, clever; bright; nimble, cute; lovable}
36D6 CJK UNIFIED IDEOGRAPH-#36D6, IRGKangXi=0262.250, Def{used in girl's name}
36D7 CJK UNIFIED IDEOGRAPH-#36D7, IRGKangXi=0262.280, Def{frivolous; flippant; disrespectful; irreverent; to insult, young, used in girl's name}
36D8 CJK UNIFIED IDEOGRAPH-#36D8, IRGKangXi=0262.300, Def{used in girl's name, a fat woman}
36D9 CJK UNIFIED IDEOGRAPH-#36D9, IRGKangXi=0262.310, Def{used in girl's name, (same as 妾) a concubine, (in old China) a polite term used by a woman to refer to herself when speaking to her husband}
36DA CJK UNIFIED IDEOGRAPH-#36DA, IRGKangXi=0262.320, Def{equal; uniform, used in girl's name}
36DB CJK UNIFIED IDEOGRAPH-#36DB, IRGKangXi=0263.020, Def{(same as U+5A20 娠) pregnant, to let develop; to nourish; to foster; to nurture, slave girls}
36DC CJK UNIFIED IDEOGRAPH-#36DC, IRGKangXi=0263.030, Def{used in girl's name}
36DD CJK UNIFIED IDEOGRAPH-#36DD, IRGKangXi=0263.230, Def{used in girl's name}
36DE CJK UNIFIED IDEOGRAPH-#36DE, IRGKangXi=0263.251, Def{used in girl's name}
36DF CJK UNIFIED IDEOGRAPH-#36DF, IRGKangXi=0263.251
36E0 CJK UNIFIED IDEOGRAPH-#36E0, IRGKangXi=0263.251
36E1 CJK UNIFIED IDEOGRAPH-#36E1, IRGKangXi=0263.251
36E2 CJK UNIFIED IDEOGRAPH-#36E2, IRGKangXi=0263.251
36E3 CJK UNIFIED IDEOGRAPH-#36E3, IRGKangXi=0263.251
36E4 CJK UNIFIED IDEOGRAPH-#36E4, IRGKangXi=0263.251
36E5 CJK UNIFIED IDEOGRAPH-#36E5, IRGKangXi=0263.280, Def{to prostrate; to make obeisance, to concede or submit willingly}
36E6 CJK UNIFIED IDEOGRAPH-#36E6, IRGKangXi=0263.410, Def{good; nice; fine; excellent}
36E7 CJK UNIFIED IDEOGRAPH-#36E7, IRGKangXi=0263.420, Def{name of a county in today's Shanxi province}
36E8 CJK UNIFIED IDEOGRAPH-#36E8, IRGKangXi=0264.090, Def{(corrupted form) chaos; anarchy; distractions; confusion}
36E9 CJK UNIFIED IDEOGRAPH-#36E9, IRGKangXi=0264.100, Def{(same as 妯) sisters-in-law (a reference among wives of brothers)}
36EA CJK UNIFIED IDEOGRAPH-#36EA, IRGKangXi=0264.320, Def{to slander; to libel, a maidservant, used in girl's name, womanly}
36EB CJK UNIFIED IDEOGRAPH-#36EB, IRGKangXi=0265.210, Def{used in girl's name}
36EC CJK UNIFIED IDEOGRAPH-#36EC, IRGKangXi=0265.240, Def{used in girl's name}
36ED CJK UNIFIED IDEOGRAPH-#36ED, IRGKangXi=0265.280, Def{used in girl's name}
36EE CJK UNIFIED IDEOGRAPH-#36EE, IRGKangXi=0266.020, Def{(same as 嫂) wife of one's elder brother}
36EF CJK UNIFIED IDEOGRAPH-#36EF, IRGKangXi=0266.040, Def{(same as 嬔) to soar; to fly; to roam (same as 娩) complaisant; agreeable, a pair; a couple; persons or things that come in pairs}
36F0 CJK UNIFIED IDEOGRAPH-#36F0, IRGKangXi=0266.050, Def{(same as 婚) to marry a wife; a bride-groom}
36F1 CJK UNIFIED IDEOGRAPH-#36F1, IRGKangXi=0266.070, Def{exquisite; fine, used in girl's name}
36F2 CJK UNIFIED IDEOGRAPH-#36F2, IRGKangXi=0266.130, Def{(same as 髮) the hair on the human head, hairbreadth; hair's-breadth}
36F3 CJK UNIFIED IDEOGRAPH-#36F3, IRGKangXi=0266.150, Def{an abnomal unborn baby}
36F4 CJK UNIFIED IDEOGRAPH-#36F4, IRGKangXi=0266.190, Def{(same as 惱) to anger to annoy; to irritate}
36F5 CJK UNIFIED IDEOGRAPH-#36F5, IRGKangXi=0266.200, Def{used in girl's name}
36F6 CJK UNIFIED IDEOGRAPH-#36F6, IRGKangXi=0266.320, Def{do not care about appearance and deportment}
36F7 CJK UNIFIED IDEOGRAPH-#36F7, IRGKangXi=0266.420, Def{used in girl's name}
36F8 CJK UNIFIED IDEOGRAPH-#36F8, IRGKangXi=0266.430, Def{(corrupted form) used in girl's name}
36F9 CJK UNIFIED IDEOGRAPH-#36F9, IRGKangXi=0267.120, Def{pretty; exquisite; fine}
36FA CJK UNIFIED IDEOGRAPH-#36FA, IRGKangXi=0267.150, Def{not clean; impure}
36FB CJK UNIFIED IDEOGRAPH-#36FB, IRGKangXi=0267.180, Def{womanly; feminine}
36FC CJK UNIFIED IDEOGRAPH-#36FC, IRGKangXi=0267.260, Def{to interrupt; to put in a word, lacking in courage; cowardly, nervous; socially timid, womanly; feminine}
36FD CJK UNIFIED IDEOGRAPH-#36FD, IRGKangXi=0267.300, Def{(ancient form of 璈) to walk slowly like a woman, to ridicule; to laugh at}
36FE CJK UNIFIED IDEOGRAPH-#36FE, IRGKangXi=0267.361, Def{(said of a woman) not clean; impure}
36FF CJK UNIFIED IDEOGRAPH-#36FF, IRGKangXi=0267.361, Def{cunning; wicked, spoiled; coddled}
3700 CJK UNIFIED IDEOGRAPH-#3700, IRGKangXi=0267.361
3701 CJK UNIFIED IDEOGRAPH-#3701, IRGKangXi=0267.361
3702 CJK UNIFIED IDEOGRAPH-#3702, IRGKangXi=0267.361, Def{used in girl's name}
3703 CJK UNIFIED IDEOGRAPH-#3703, IRGKangXi=0267.361, Def{from; by; whence, to undertake; to manage, to follow}
3704 CJK UNIFIED IDEOGRAPH-#3704, IRGKangXi=0267.361, Def{last name (refer to 千家姓)}
3705 CJK UNIFIED IDEOGRAPH-#3705, IRGKangXi=0267.380, Def{to fawn on; to flatter, to love, attractive, jealous; envy; jealousy}
3706 CJK UNIFIED IDEOGRAPH-#3706, IRGKangXi=0268.010, Def{commonly known as mother in Wu}
3707 CJK UNIFIED IDEOGRAPH-#3707, IRGKangXi=0268.020, Def{unhappy, girlish}
3708 CJK UNIFIED IDEOGRAPH-#3708, IRGKangXi=0268.040, Def{a beautiful face (of a woman); pretty}
3709 CJK UNIFIED IDEOGRAPH-#3709, IRGKangXi=0268.130, Def{womanly, used in girl's name}
370A CJK UNIFIED IDEOGRAPH-#370A, IRGKangXi=0268.240, Def{exquisite; fine}
370B CJK UNIFIED IDEOGRAPH-#370B, IRGKangXi=0268.300, Def{used in girl's name}
370C CJK UNIFIED IDEOGRAPH-#370C, IRGKangXi=0269.030, Def{a different name for breasts, to breast-feed; to feed a baby with milk, stingy; niggardly; miserly}
370D CJK UNIFIED IDEOGRAPH-#370D, IRGKangXi=0269.070, Def{used in girl's name}
370E CJK UNIFIED IDEOGRAPH-#370E, IRGKangXi=0269.080, Def{slave girls, lacking in courage; nervous, a jealous woman}
370F CJK UNIFIED IDEOGRAPH-#370F, IRGKangXi=0269.100, Def{(the large seal type 妘) last name, used in girl's name}
3710 CJK UNIFIED IDEOGRAPH-#3710, IRGKangXi=0269.110, Def{used in girl's name}
3711 CJK UNIFIED IDEOGRAPH-#3711, IRGKangXi=0269.130, Def{(same as 婆) an older woman, mother of one's husband, one's grandmother}
3712 CJK UNIFIED IDEOGRAPH-#3712, IRGKangXi=0269.180, Def{maternal grandmother, a midwife, an old woman}
3713 CJK UNIFIED IDEOGRAPH-#3713, IRGKangXi=0269.181, Def{womanly}
3714 CJK UNIFIED IDEOGRAPH-#3714, IRGKangXi=0269.181
3715 CJK UNIFIED IDEOGRAPH-#3715, IRGKangXi=0270.311, Def{(same as 連) relatives through marriage}
3716 CJK UNIFIED IDEOGRAPH-#3716, IRGKangXi=0269.300, Def{exquisite; fine}
3717 CJK UNIFIED IDEOGRAPH-#3717, IRGKangXi=0269.350, Def{covetousness; greed; cupidity; avarice, licentious; obscene; to seduce}
3718 CJK UNIFIED IDEOGRAPH-#3718, IRGKangXi=0270.020, Def{delicate; lovely; beautiful, spoiled, jealous; to envy; jealousy, used in girl's name}
3719 CJK UNIFIED IDEOGRAPH-#3719, IRGKangXi=0270.120, Def{used in girl's name}
371A CJK UNIFIED IDEOGRAPH-#371A, IRGKangXi=0270.140, Def{a local government post in ancient times}
371B CJK UNIFIED IDEOGRAPH-#371B, IRGKangXi=0270.190, Def{(non-classical form of 媆) soft; gentle, attractive (same as 嫩) soft and tender, delicate, weak}
371C CJK UNIFIED IDEOGRAPH-#371C, IRGKangXi=0270.250, Def{(ancient form form of 傲) proud; haughty; overbearing rude}
371D CJK UNIFIED IDEOGRAPH-#371D, IRGKangXi=0270.260, Def{to cherish anger, hard to understand, pretty, dignified; solemn, to make sheep eyes or passes; to converse with eyes}
371E CJK UNIFIED IDEOGRAPH-#371E, IRGKangXi=0270.290, Def{beautiful; pretty, used in girl's name}
371F CJK UNIFIED IDEOGRAPH-#371F, IRGKangXi=0271.351
3720 CJK UNIFIED IDEOGRAPH-#3720, IRGKangXi=0270.311, Def{used in girl's name}
3721 CJK UNIFIED IDEOGRAPH-#3721, IRGKangXi=0270.311, Def{used in girl's name}
3722 CJK UNIFIED IDEOGRAPH-#3722, IRGKangXi=0270.311, Def{a bad term by which one addresses a woman}
3723 CJK UNIFIED IDEOGRAPH-#3723, IRGKangXi=0270.360, Def{a last name, carriage; deportment; bearing; poise (of a woman)}
3724 CJK UNIFIED IDEOGRAPH-#3724, IRGKangXi=0270.370, Def{fooling around, weak, (said of a woman's figure) slender; thin and long, used in girl's name}
3725 CJK UNIFIED IDEOGRAPH-#3725, IRGKangXi=0271.090, Def{crafty; artiful}
3726 CJK UNIFIED IDEOGRAPH-#3726, IRGKangXi=0271.230, Def{used in girl's name}
3727 CJK UNIFIED IDEOGRAPH-#3727, IRGKangXi=0271.351, Def{plump, womanly}
3728 CJK UNIFIED IDEOGRAPH-#3728, IRGKangXi=0271.351, Def{beautiful; pretty}
3729 CJK UNIFIED IDEOGRAPH-#3729, IRGKangXi=0271.370, Def{jealous; to envy; jealously}
372A CJK UNIFIED IDEOGRAPH-#372A, IRGKangXi=0272.160, Def{(same as 嫀) name of a family or a clan, name of country (in ancient times)}
372B CJK UNIFIED IDEOGRAPH-#372B, IRGKangXi=0272.251, Def{(same as 媄) pretty; beautiful}
372C CJK UNIFIED IDEOGRAPH-#372C, IRGKangXi=0272.251
372D CJK UNIFIED IDEOGRAPH-#372D, IRGKangXi=0272.251
372E CJK UNIFIED IDEOGRAPH-#372E, IRGKangXi=0272.450, Def{to go beyond normal limit; excessive; out of control, to covet; greedy, to be impolite, used in girl's name}
372F CJK UNIFIED IDEOGRAPH-#372F, IRGKangXi=0273.150, Def{a word to designate woman, a word of revile used to call a woman}
3730 CJK UNIFIED IDEOGRAPH-#3730, IRGKangXi=0273.220, Def{exquisite; fine}
3731 CJK UNIFIED IDEOGRAPH-#3731, IRGKangXi=0273.290, Def{used in girl's name, soft and tender}
3732 CJK UNIFIED IDEOGRAPH-#3732, IRGKangXi=0273.330, Def{(non-classical form of 嬴) to have surplus; full; an overplus, to open out; to produce, a family name}
3733 CJK UNIFIED IDEOGRAPH-#3733, IRGKangXi=0273.350, Def{peaceful; joyful}
3734 CJK UNIFIED IDEOGRAPH-#3734, IRGKangXi=0273.390, Def{(non-classical from of 瞢) dark and obscure, obscure; not bright, used in girl's name, good; fine}
3735 CJK UNIFIED IDEOGRAPH-#3735, IRGKangXi=0273.421, Def{(said of a woman) with a charming sprightly carriage; slim; delicate and beautiful}
3736 CJK UNIFIED IDEOGRAPH-#3736, IRGKangXi=0274.171, Def{a (married) couple}
3737 CJK UNIFIED IDEOGRAPH-#3737, IRGKangXi=0274.030, Def{milk, the breasts of a woman, to suckle, word of respect for women, (for Qi's people) mother, used in girl's name}
3738 CJK UNIFIED IDEOGRAPH-#3738, IRGKangXi=0274.060, Def{(non-classical form of 孽) sin; evil; retribution, the son of a concubine}
3739 CJK UNIFIED IDEOGRAPH-#3739, IRGKangXi=0274.150, Def{name of a folk song in ancient times, used in girl's name}
373A CJK UNIFIED IDEOGRAPH-#373A, IRGKangXi=0274.190, Def{white color; no respect; imprudent; (Cant.) interesting, good}
373B CJK UNIFIED IDEOGRAPH-#373B, IRGKangXi=0274.340, Def{(non-classical form of 孌) (interchangeable 戀) to admire; to remember (old days, etc.), exquisite; fine, to obey; obedient; to comply, (same as 奱) to bind; binding, used in girl's name}
373C CJK UNIFIED IDEOGRAPH-#373C, IRGKangXi=0274.350, Def{(same as 姪) children of one's brother -- nephews or nieces, I; me (when speaking to a family friend of father's generation)}
373D CJK UNIFIED IDEOGRAPH-#373D, IRGKangXi=0277.160, Def{(ancient form of 子) child, seed, 1st terrestrial branch}
373E CJK UNIFIED IDEOGRAPH-#373E, IRGKangXi=0278.130, Def{(same as 孩) a child; an infant, young; small}
373F CJK UNIFIED IDEOGRAPH-#373F, IRGKangXi=0278.150, Def{name of a fish in legend, spawn, or roe}
3740 CJK UNIFIED IDEOGRAPH-#3740, IRGKangXi=0279.121, Def{(same as 好) to like; to love; to be fond of}
3741 CJK UNIFIED IDEOGRAPH-#3741, IRGKangXi=0279.170, Def{(same as 嬛) lonely; solitary, exquisite; fine, to worship with reverence}
3742 CJK UNIFIED IDEOGRAPH-#3742, IRGKangXi=0279.220, Def{locust, larva of Chilo simplex; a kind of moth}
3743 CJK UNIFIED IDEOGRAPH-#3743, IRGKangXi=0279.240, Def{(same as U+5A29 娩) to bear a son; to give birth}
3744 CJK UNIFIED IDEOGRAPH-#3744, IRGKangXi=0280.100, Def{(ancient form of 純) pure, sincere; honest; faithful}
3745 CJK UNIFIED IDEOGRAPH-#3745, IRGKangXi=0280.190, Def{to give suck to, infant; baby, ignorant; stupid, prudent; cautious}
3746 CJK UNIFIED IDEOGRAPH-#3746, IRGKangXi=0280.261
3747 CJK UNIFIED IDEOGRAPH-#3747, IRGKangXi=0281.011, Def{(same as 鶉) quail}
3748 CJK UNIFIED IDEOGRAPH-#3748, IRGKangXi=0281.100, Def{(same as 孿) twin}
3749 CJK UNIFIED IDEOGRAPH-#3749, IRGKangXi=0281.111, Def{(same as 宁) space between the throne and the retiring room behind it, to store up; to save up, peaceful, used as a term of comparison}
374A CJK UNIFIED IDEOGRAPH-#374A, IRGKangXi=0281.190, Def{(same as 守) to guide; to watch, to wait, to keep}
374B CJK UNIFIED IDEOGRAPH-#374B, IRGKangXi=0281.191
374C CJK UNIFIED IDEOGRAPH-#374C, IRGKangXi=0281.230, Def{(same as 疚) prolonged illness, mental discomfort, to stay in one place for a long period}
374D CJK UNIFIED IDEOGRAPH-#374D, IRGKangXi=0282.101, Def{(simplified form of 寫) to write; to draw}
374E CJK UNIFIED IDEOGRAPH-#374E, IRGKangXi=0283.051, Def{(same as 定) to decide; to fix; to settle}
374F CJK UNIFIED IDEOGRAPH-#374F, IRGKangXi=0282.150, Def{(same as 介) alone; solitary, to live alone}
3750 CJK UNIFIED IDEOGRAPH-#3750, IRGKangXi=0282.160, Def{(ancient form of 容) face; expression, to contain; to hold; to pardon}
3751 CJK UNIFIED IDEOGRAPH-#3751, IRGKangXi=0282.210, Def{(ancient form of 旁) side, by the side of; nearby}
3752 CJK UNIFIED IDEOGRAPH-#3752, IRGKangXi=0284.070, Def{(ancient form of 居) to dwell; to occupy to inhabit, a Chinese family name}
3753 CJK UNIFIED IDEOGRAPH-#3753, IRGKangXi=0284.100, Def{corresponding; equivalent, considerable; to a great extent, appropriate, (same as 凹) a hollow, concave}
3754 CJK UNIFIED IDEOGRAPH-#3754, IRGKangXi=0284.190, Def{deep bottom; the southeast corner of a house}
3755 CJK UNIFIED IDEOGRAPH-#3755, IRGKangXi=0285.080, Def{(same as 寍 寧) peace; serenity, used as a term of comparison: -- rather; it is better, would that}
3756 CJK UNIFIED IDEOGRAPH-#3756, IRGKangXi=0285.100, Def{(corrupted form) right; fitting; proper; good, should; ought to; had better}
3757 CJK UNIFIED IDEOGRAPH-#3757, IRGKangXi=0285.130, Def{spaciously rooms, expansive; vast and boundless}
3758 CJK UNIFIED IDEOGRAPH-#3758, IRGKangXi=0286.030, Def{(non-classical form) harmonoy; peace, pleasant; agreeable; delightful}
3759 CJK UNIFIED IDEOGRAPH-#3759, IRGKangXi=0287.090, Def{(ancient form of 寅) the third of the twelve terrestrial branches, a fellow officer, horary sign (for period from 3 to 5 a.m.)}
375A CJK UNIFIED IDEOGRAPH-#375A, IRGKangXi=0287.101
375B CJK UNIFIED IDEOGRAPH-#375B, IRGKangXi=0287.160, Def{(ancient form of 宿) a halting place; to lodge for the night, to keep over night, to cherish, asleep and perching}
375C CJK UNIFIED IDEOGRAPH-#375C, IRGKangXi=0287.170, Def{night; dark; darkness, of death, to mourn, to lose; to deprived of}
375D CJK UNIFIED IDEOGRAPH-#375D, IRGKangXi=0288.120, Def{deep, profound, far, extremely}
375E CJK UNIFIED IDEOGRAPH-#375E, IRGKangXi=0288.130, Def{pretend to be delicate and beautiful, to hang or be hanged, to be in suspension; unfounded}
375F CJK UNIFIED IDEOGRAPH-#375F, IRGKangXi=0288.201, Def{(corrupted form) in contravention of; to offend (same as 冒) incautious, to risk, to put forth}
3760 CJK UNIFIED IDEOGRAPH-#3760, IRGKangXi=0288.201, Def{(same as 冥) dark; obscure; dim, stupidity, far and high, deep; profound, night}
3761 CJK UNIFIED IDEOGRAPH-#3761, IRGKangXi=0288.201, Def{(a variant of 最) very; exceedingly; most, superior}
3762 CJK UNIFIED IDEOGRAPH-#3762, IRGKangXi=0289.140, Def{(same as 宇) a house; a roof, look; appearance, space}
3763 CJK UNIFIED IDEOGRAPH-#3763, IRGKangXi=0289.070, Def{still; calm; silent, peaceful; harmonious; serene, quite}
3764 CJK UNIFIED IDEOGRAPH-#3764, IRGKangXi=0290.020, Def{night, the dark part of a room}
3765 CJK UNIFIED IDEOGRAPH-#3765, IRGKangXi=0290.040, Def{have a nightmare, sound sleep}
3766 CJK UNIFIED IDEOGRAPH-#3766, IRGKangXi=0290.090, Def{to accumulate; to amass; to store up, superior, handsome, refined, eminent}
3767 CJK UNIFIED IDEOGRAPH-#3767, IRGKangXi=0290.100, Def{(non-classical form of 穩) stable; steady; firm, sure; secure}
3768 CJK UNIFIED IDEOGRAPH-#3768, IRGKangXi=0290.121
3769 CJK UNIFIED IDEOGRAPH-#3769, IRGKangXi=0290.130, Def{spaciously rooms, emptiness}
376A CJK UNIFIED IDEOGRAPH-#376A, IRGKangXi=0290.140, Def{a slanting house, nightmare}
376B CJK UNIFIED IDEOGRAPH-#376B, IRGKangXi=0291.180, Def{shape of the sky}
376C CJK UNIFIED IDEOGRAPH-#376C, IRGKangXi=0291.181
376D CJK UNIFIED IDEOGRAPH-#376D, IRGKangXi=0291.200, Def{(non-classical form) to awake (from errors, illusions, etc. to come to one's sense, (interchangeable 惺) clever; wise, wavering; indecisive}
376E CJK UNIFIED IDEOGRAPH-#376E, IRGKangXi=0292.010, Def{to exile; to banish, beyond the borders}
376F CJK UNIFIED IDEOGRAPH-#376F, IRGKangXi=0292.020, Def{to sojourn; sojourn, a sojourner; a visitor}
3770 CJK UNIFIED IDEOGRAPH-#3770, IRGKangXi=0293.010, Def{unable to meet, empty room}
3771 CJK UNIFIED IDEOGRAPH-#3771, IRGKangXi=0293.190, Def{(standard form) a dream; to dream, visionary, stupid}
3772 CJK UNIFIED IDEOGRAPH-#3772, IRGKangXi=0293.290, Def{(same as 寢) to sleep; to rest, a tomb, a residence}
3773 CJK UNIFIED IDEOGRAPH-#3773, IRGKangXi=0293.321
3774 CJK UNIFIED IDEOGRAPH-#3774, IRGKangXi=0294.020, Def{(same as 刓) a round off; to trim}
3775 CJK UNIFIED IDEOGRAPH-#3775, IRGKangXi=0294.040, Def{(ancient form of U+5F97 得) to get, complacent, (same as U+7919 礙) to obstruct, to hinder, to stop progress, to injure, to offend, to concern, hindrance, restraint}
3776 CJK UNIFIED IDEOGRAPH-#3776, IRGKangXi=0294.150, Def{(ancient form of 得) to get, complacent}
3777 CJK UNIFIED IDEOGRAPH-#3777, IRGKangXi=0296.011
3778 CJK UNIFIED IDEOGRAPH-#3778, IRGKangXi=0297.160, Def{(same as 弁) a conical cap worn on ceremonious occasions in ancient times, low-ranking military officers, a Chinese family name}
3779 CJK UNIFIED IDEOGRAPH-#3779, IRGKangXi=0297.200, Def{(corrupted form) a hare, a small rabbit, a family name}
377A CJK UNIFIED IDEOGRAPH-#377A, IRGKangXi=0297.300, Def{small; little, humble, to owe, deficient; lacking}
377B CJK UNIFIED IDEOGRAPH-#377B, IRGKangXi=0297.320, Def{(same as U+50C5 僅) barely enough; scarcely; almost}
377C CJK UNIFIED IDEOGRAPH-#377C, IRGKangXi=0298.070, Def{crooked; winding, to circle; to hover around}
377D CJK UNIFIED IDEOGRAPH-#377D, IRGKangXi=0298.171, Def{short, small; little}
377E CJK UNIFIED IDEOGRAPH-#377E, IRGKangXi=0298.221, Def{can not walk normally}
377F CJK UNIFIED IDEOGRAPH-#377F, IRGKangXi=0298.210, Def{(non-classical form of 跛) lame; crippled}
3780 CJK UNIFIED IDEOGRAPH-#3780, IRGKangXi=0298.270, Def{to bump, to strike}
3781 CJK UNIFIED IDEOGRAPH-#3781, IRGKangXi=0298.280, Def{can not walk normally, swollen feet}
3782 CJK UNIFIED IDEOGRAPH-#3782, IRGKangXi=0298.300, Def{ulcers, swollen feet, a kind of disease}
3783 CJK UNIFIED IDEOGRAPH-#3783, IRGKangXi=0298.350, Def{tired; weary}
3784 CJK UNIFIED IDEOGRAPH-#3784, IRGKangXi=0298.360, Def{lame; crippled; feeble}
3785 CJK UNIFIED IDEOGRAPH-#3785, IRGKangXi=0298.380, Def{not straight, improper}
3786 CJK UNIFIED IDEOGRAPH-#3786, IRGKangXi=0298.410, Def{(same as 踦) one-legged, crippled; halt, a defect, tired, the shin}
3787 CJK UNIFIED IDEOGRAPH-#3787, IRGKangXi=0299.061, Def{ulcers, swollen feet, a kind of disease (abnormal in walking)}
3788 CJK UNIFIED IDEOGRAPH-#3788, IRGKangXi=0299.060, Def{big foot, walking}
3789 CJK UNIFIED IDEOGRAPH-#3789, IRGKangXi=0299.080, Def{big foot}
378A CJK UNIFIED IDEOGRAPH-#378A, IRGKangXi=0299.140, Def{unable to walk}
378B CJK UNIFIED IDEOGRAPH-#378B, IRGKangXi=0300.050, Def{soft and meek, weak, to arrange, to regulate}
378C CJK UNIFIED IDEOGRAPH-#378C, IRGKangXi=0300.120, Def{(same as 孕) to be pregnant; to conceive}
378D CJK UNIFIED IDEOGRAPH-#378D, IRGKangXi=0300.151
378E CJK UNIFIED IDEOGRAPH-#378E, IRGKangXi=0300.241, Def{(baby talk) body waste, (a dialect) weight measurement}
378F CJK UNIFIED IDEOGRAPH-#378F, IRGKangXi=0300.250, Def{small; to store up or pile in order, to follow; to trace, a short step}
3790 CJK UNIFIED IDEOGRAPH-#3790, IRGKangXi=0301.010, Def{(an ancient form of 居), to dwell; to remain, to be in (various states and conditions), to occupy, the course of one's life}
3791 CJK UNIFIED IDEOGRAPH-#3791, IRGKangXi=0301.130, Def{(standard form of 尾) the tail; the rear, last; final}
3792 CJK UNIFIED IDEOGRAPH-#3792, IRGKangXi=0301.180, Def{(standard form) lusty; strong; gigantic strength, heavy sleep with snoring}
3793 CJK UNIFIED IDEOGRAPH-#3793, IRGKangXi=0301.220, Def{the buttocks; the rump; the sacrum, to set sideways, the male organ; (Cant.) vulgar term for the female sex organ}
3794 CJK UNIFIED IDEOGRAPH-#3794, IRGKangXi=0301.260, Def{(corrupted form) the upright bar for fastening a door}
3795 CJK UNIFIED IDEOGRAPH-#3795, IRGKangXi=0301.300, Def{(same as 屑) chips; crumbs; bits trifles, to care; to mind}
3796 CJK UNIFIED IDEOGRAPH-#3796, IRGKangXi=0301.310, Def{this, here, if so; in this case, reluctant to go forward}
3797 CJK UNIFIED IDEOGRAPH-#3797, IRGKangXi=0302.070, Def{the male organ, obscene language; vulgar expression}
3798 CJK UNIFIED IDEOGRAPH-#3798, IRGKangXi=0302.230, Def{(non-classical form of U+8C5A 豚) a small pig; (Cant.) end, bottom, rump}
3799 CJK UNIFIED IDEOGRAPH-#3799, IRGKangXi=0302.321, Def{(same as 尿) urine; to urinate}
379A CJK UNIFIED IDEOGRAPH-#379A, IRGKangXi=0302.330, Def{to pile up layer by layer, wedge, gatepost}
379B CJK UNIFIED IDEOGRAPH-#379B, IRGKangXi=0303.110, Def{red slippers, (corrupted form of 履) shoes}
379C CJK UNIFIED IDEOGRAPH-#379C, IRGKangXi=0303.370, Def{hempen sandals, boots}
379D CJK UNIFIED IDEOGRAPH-#379D, IRGKangXi=0303.391
379E CJK UNIFIED IDEOGRAPH-#379E, IRGKangXi=0303.391, Def{semen}
379F CJK UNIFIED IDEOGRAPH-#379F, IRGKangXi=0303.450, Def{savings and (or) reserves; (same as U+5960 奠) to settle; to lay; (same as U+588A 墊) to advance (money), to cushion, to sink into; (said of manner) dignified; stately; graceful}
37A0 CJK UNIFIED IDEOGRAPH-#37A0, IRGKangXi=0303.461, Def{male organ}
37A1 CJK UNIFIED IDEOGRAPH-#37A1, IRGKangXi=0304.050, Def{(same as 展) to open, to stretch, to unfold, to expand}
37A2 CJK UNIFIED IDEOGRAPH-#37A2, IRGKangXi=0304.120, Def{(ancient form of 之) to arrive at; to go to}
37A3 CJK UNIFIED IDEOGRAPH-#37A3, IRGKangXi=0305.040, Def{(same as 芬) fragrance; aroma; sweet smell; perfume}
37A4 CJK UNIFIED IDEOGRAPH-#37A4, IRGKangXi=0307.030, Def{to help; to aid; to assist (ancient form of 岑) a relatively high, pointed hill, silent; still; quiet}
37A5 CJK UNIFIED IDEOGRAPH-#37A5, IRGKangXi=0307.050, Def{deep in the mountain}
37A6 CJK UNIFIED IDEOGRAPH-#37A6, IRGKangXi=0307.070, Def{name of a mountain}
37A7 CJK UNIFIED IDEOGRAPH-#37A7, IRGKangXi=0307.090, Def{(ancient form of 會) to meet, to gather, to be able, to understand}
37A8 CJK UNIFIED IDEOGRAPH-#37A8, IRGKangXi=0307.160, Def{(corrupted form) name of a mountain (the location is unknown)}
37A9 CJK UNIFIED IDEOGRAPH-#37A9, IRGKangXi=0307.180, Def{(same as 嵐) mountain vapor; mist}
37AA CJK UNIFIED IDEOGRAPH-#37AA, IRGKangXi=0307.200, Def{the appearance of the mountain is flat and smooth, (corrupted form of 峱) name of a mountain in Shandong province}
37AB CJK UNIFIED IDEOGRAPH-#37AB, IRGKangXi=0307.260, Def{(non-classical form of 走) to walk, to run, to leave}
37AC CJK UNIFIED IDEOGRAPH-#37AC, IRGKangXi=0307.271, Def{close or near}
37AD CJK UNIFIED IDEOGRAPH-#37AD, IRGKangXi=0307.271, Def{name of an island}
37AE CJK UNIFIED IDEOGRAPH-#37AE, IRGKangXi=0307.271, Def{variant of 出 U+51FA, to go out, send out; to stand; to produce}
37AF CJK UNIFIED IDEOGRAPH-#37AF, IRGKangXi=0307.271, Def{(same as 岊) the turning area of a mountain, mountain top; summit, a high mountain, a bare (of bald) mountain or hill}
37B0 CJK UNIFIED IDEOGRAPH-#37B0, IRGKangXi=0307.290, Def{name of a mountain}
37B1 CJK UNIFIED IDEOGRAPH-#37B1, IRGKangXi=0307.320, Def{dusk; twilight}
37B2 CJK UNIFIED IDEOGRAPH-#37B2, IRGKangXi=0308.020, Def{name of a mountain, the plain between mountains}
37B3 CJK UNIFIED IDEOGRAPH-#37B3, IRGKangXi=0308.050, Def{name of a mountain}
37B4 CJK UNIFIED IDEOGRAPH-#37B4, IRGKangXi=0308.160, Def{name of a mountain, (non-classical form of 岷) the Min River (in Sichuan), Mt. Min (in Sichuan), name of a county (in old China)}
37B5 CJK UNIFIED IDEOGRAPH-#37B5, IRGKangXi=0308.200, Def{(corrupted form) frivolous; flippant; capricious; playful; sportive, cunning}
37B6 CJK UNIFIED IDEOGRAPH-#37B6, IRGKangXi=0308.300, Def{(same as 岷) the Min River (in Sichuan), Mt. Min (in Sichuan), name of a county (in old China)}
37B7 CJK UNIFIED IDEOGRAPH-#37B7, IRGKangXi=0305.060, Def{luxuriant; lush; flourishing}
37B8 CJK UNIFIED IDEOGRAPH-#37B8, IRGKangXi=0308.331, Def{(same as 呡) (simplified form of 歲) a year; age (of a person), harvest}
37B9 CJK UNIFIED IDEOGRAPH-#37B9, IRGKangXi=0309.030, Def{(same as 岢) name of a mountain in Shanxi province}
37BA CJK UNIFIED IDEOGRAPH-#37BA, IRGKangXi=0309.060, Def{(ancient form of 族) a tribe; a clan; relatives, race (of people), a class; a family (of animals)}
37BB CJK UNIFIED IDEOGRAPH-#37BB, IRGKangXi=0309.080, Def{name of a mountain}
37BC CJK UNIFIED IDEOGRAPH-#37BC, IRGKangXi=0309.120, Def{(same as 丞) to respectfully receive, to flatter; to pay court to}
37BD CJK UNIFIED IDEOGRAPH-#37BD, IRGKangXi=0309.140, Def{mountain; hill}
37BE CJK UNIFIED IDEOGRAPH-#37BE, IRGKangXi=0309.360, Def{(same as 尼) a nun, the mountains after which Confucius was named}
37BF CJK UNIFIED IDEOGRAPH-#37BF, IRGKangXi=0310.071, Def{(same as 岐) name of a mountain in Shanxi province, name of a political district in ancient China, name of a river in Shanxi province, to diverge; to branch}
37C0 CJK UNIFIED IDEOGRAPH-#37C0, IRGKangXi=0310.071, Def{name of a mountain}
37C1 CJK UNIFIED IDEOGRAPH-#37C1, IRGKangXi=0310.071, Def{(a variant of 岸) shore; bank; beach; coast}
37C2 CJK UNIFIED IDEOGRAPH-#37C2, IRGKangXi=0310.071, Def{name of cape in Shandong Province}
37C3 CJK UNIFIED IDEOGRAPH-#37C3, IRGKangXi=0310.071, Def{(corrupted form of 司) to have charge of; to preside over, a (governmental) department}
37C4 CJK UNIFIED IDEOGRAPH-#37C4, IRGKangXi=0310.160, Def{name of a mountain}
37C5 CJK UNIFIED IDEOGRAPH-#37C5, IRGKangXi=0310.210, Def{lofty; high; steep}
37C6 CJK UNIFIED IDEOGRAPH-#37C6, IRGKangXi=0311.061, Def{name of a mountain}
37C7 CJK UNIFIED IDEOGRAPH-#37C7, IRGKangXi=0311.070, Def{a land-slide, name of mountain}
37C8 CJK UNIFIED IDEOGRAPH-#37C8, IRGKangXi=0311.220, Def{name of a mountain}
37C9 CJK UNIFIED IDEOGRAPH-#37C9, IRGKangXi=0311.250, Def{name of pavilion (garden) in ancient China, name of a mountain}
37CA CJK UNIFIED IDEOGRAPH-#37CA, IRGKangXi=0311.270, Def{name of a mountain}
37CB CJK UNIFIED IDEOGRAPH-#37CB, IRGKangXi=0311.290, Def{deep and level ground gully at the foot of a hill}
37CC CJK UNIFIED IDEOGRAPH-#37CC, IRGKangXi=0311.380, Def{a mountain in today's Sichuan Province}
37CD CJK UNIFIED IDEOGRAPH-#37CD, IRGKangXi=0312.010, Def{name of a mountain, a solitary peak}
37CE CJK UNIFIED IDEOGRAPH-#37CE, IRGKangXi=0312.080, Def{a long mountain ridge, steep; lofty mountain}
37CF CJK UNIFIED IDEOGRAPH-#37CF, IRGKangXi=0312.170, Def{steep and lofty, a big valley}
37D0 CJK UNIFIED IDEOGRAPH-#37D0, IRGKangXi=0312.220, Def{big and high; lofty; steep}
37D1 CJK UNIFIED IDEOGRAPH-#37D1, IRGKangXi=0312.260, Def{mountain; hill}
37D2 CJK UNIFIED IDEOGRAPH-#37D2, IRGKangXi=0312.301, Def{mountains adjoining, mountain chain; name of a mountain}
37D3 CJK UNIFIED IDEOGRAPH-#37D3, IRGKangXi=0311.320, Def{lofty and dangerous, rocks on the mountain side}
37D4 CJK UNIFIED IDEOGRAPH-#37D4, IRGKangXi=0312.301, Def{steep and lofty, a big valley}
37D5 CJK UNIFIED IDEOGRAPH-#37D5, IRGKangXi=0312.301
37D6 CJK UNIFIED IDEOGRAPH-#37D6, IRGKangXi=0312.301, Def{(loanword from Zhuang) the plain; level ground between rocky mountain, name of county}
37D7 CJK UNIFIED IDEOGRAPH-#37D7, IRGKangXi=0312.320, Def{name of a small principality in what is now Shanxi, the home of the founder of the Zhou dynasty}
37D8 CJK UNIFIED IDEOGRAPH-#37D8, IRGKangXi=0312.330, Def{name of a mountain}
37D9 CJK UNIFIED IDEOGRAPH-#37D9, IRGKangXi=0313.070, Def{shape of the mountain, a mountain in today's Shandong Province}
37DA CJK UNIFIED IDEOGRAPH-#37DA, IRGKangXi=0313.090, Def{(same as 岐) name of a mountain in Shanxi Province, name of a political district in ancient China, name of a river in Shanxi province, to diverge; to branch}
37DB CJK UNIFIED IDEOGRAPH-#37DB, IRGKangXi=0313.150, Def{high and steep; lofty}
37DC CJK UNIFIED IDEOGRAPH-#37DC, IRGKangXi=0314.190, Def{(non-classical and abbreviated form) shape of the mountain}
37DD CJK UNIFIED IDEOGRAPH-#37DD, IRGKangXi=0314.240, Def{(same as 培) to bank up with earth, to nourish; to strengthen; to cultivate}
37DE CJK UNIFIED IDEOGRAPH-#37DE, IRGKangXi=0315.080, Def{precipitous and lofty; very steep mountains}
37DF CJK UNIFIED IDEOGRAPH-#37DF, IRGKangXi=0315.100, Def{(same as 巷) a lane; an alley}
37E0 CJK UNIFIED IDEOGRAPH-#37E0, IRGKangXi=0315.140, Def{(same as 岡) ridge (of a hill or mountain)}
37E1 CJK UNIFIED IDEOGRAPH-#37E1, IRGKangXi=0315.151
37E2 CJK UNIFIED IDEOGRAPH-#37E2, IRGKangXi=0315.151, Def{the rocks on the hills are of different shapes; rugged and weird, character different from others}
37E3 CJK UNIFIED IDEOGRAPH-#37E3, IRGKangXi=0315.151
37E4 CJK UNIFIED IDEOGRAPH-#37E4, IRGKangXi=0315.151, Def{(loan-word from Zhuang) used in place-names in Guangxi for level ground, a plain between mountains}
37E5 CJK UNIFIED IDEOGRAPH-#37E5, IRGKangXi=0315.151, Def{(simplified form of 嵾) uneven; rolling; rough; rugged, name of a mountain (Wudangshan)}
37E6 CJK UNIFIED IDEOGRAPH-#37E6, IRGKangXi=0315.240, Def{name of a mountain}
37E7 CJK UNIFIED IDEOGRAPH-#37E7, IRGKangXi=0316.010, Def{a cliff; a precipice}
37E8 CJK UNIFIED IDEOGRAPH-#37E8, IRGKangXi=0316.110, Def{a fountain in the side of a hill, name of a mountain}
37E9 CJK UNIFIED IDEOGRAPH-#37E9, IRGKangXi=0316.260, Def{(same as 岷) the Min River (in Sichuan), Mt. Min (in Sichuan), name of a county (in old China)}
37EA CJK UNIFIED IDEOGRAPH-#37EA, IRGKangXi=0316.280, Def{name of a mountain, lofty and steep; high}
37EB CJK UNIFIED IDEOGRAPH-#37EB, IRGKangXi=0316.350, Def{(same as 泉) spring; fountain, money (archaic)}
37EC CJK UNIFIED IDEOGRAPH-#37EC, IRGKangXi=0317.521, Def{a mountain in today's Shandong Province southwest of Mengyin county}
37ED CJK UNIFIED IDEOGRAPH-#37ED, IRGKangXi=0316.381, Def{(same as 岷) the Min River (in Sichuan), Mt. Min (in Sichuan), name of a county (in old China)}
37EE CJK UNIFIED IDEOGRAPH-#37EE, IRGKangXi=0316.381, Def{lofty; high}
37EF CJK UNIFIED IDEOGRAPH-#37EF, IRGKangXi=0316.381
37F0 CJK UNIFIED IDEOGRAPH-#37F0, IRGKangXi=0317.050, Def{name of a mountain; lofty, steep}
37F1 CJK UNIFIED IDEOGRAPH-#37F1, IRGKangXi=0317.190, Def{shape of a mountain}
37F2 CJK UNIFIED IDEOGRAPH-#37F2, IRGKangXi=0317.210, Def{mountain peak; mountain top; summit}
37F3 CJK UNIFIED IDEOGRAPH-#37F3, IRGKangXi=0317.300, Def{name of a mountain}
37F4 CJK UNIFIED IDEOGRAPH-#37F4, IRGKangXi=0317.360, Def{lump on the hills, rugged; rough; rough, lofty; steep, the dejection one feels at heart}
37F5 CJK UNIFIED IDEOGRAPH-#37F5, IRGKangXi=0317.480, Def{(non-classical form of 岡) ridge (of a hill or mountain)}
37F6 CJK UNIFIED IDEOGRAPH-#37F6, IRGKangXi=0317.521, Def{mountain peak; mountain top; summit}
37F7 CJK UNIFIED IDEOGRAPH-#37F7, IRGKangXi=0317.521, Def{a wart; a pustule; a pimple, a round lump}
37F8 CJK UNIFIED IDEOGRAPH-#37F8, IRGKangXi=0317.521, Def{(non-classical form) name of pavilion (garden) in ancient China, name of a mountain}
37F9 CJK UNIFIED IDEOGRAPH-#37F9, IRGKangXi=0318.080, Def{the appearance of a mountain is lofty and steep and profound}
37FA CJK UNIFIED IDEOGRAPH-#37FA, IRGKangXi=0318.260, Def{mountain top; summit}
37FB CJK UNIFIED IDEOGRAPH-#37FB, IRGKangXi=0318.280, Def{(same as 塹) the moat around a city, a pit; a hole or cavity in the ground (same as 嶄) (of a mountain) high and pointed, novel; new}
37FC CJK UNIFIED IDEOGRAPH-#37FC, IRGKangXi=0318.320, Def{name of a place in Shandong Province, mountain with lots of small rocks}
37FD CJK UNIFIED IDEOGRAPH-#37FD, IRGKangXi=0318.330, Def{mountain top; summit, pointing mountain}
37FE CJK UNIFIED IDEOGRAPH-#37FE, IRGKangXi=0318.390, Def{name of a mountain in county Jian}
37FF CJK UNIFIED IDEOGRAPH-#37FF, IRGKangXi=0318.400, Def{high and steep, name of a mountain}
3800 CJK UNIFIED IDEOGRAPH-#3800, IRGKangXi=0319.070, Def{(same as 島) island; isle}
3801 CJK UNIFIED IDEOGRAPH-#3801, IRGKangXi=0319.090, Def{irregular outline of a range of hills}
3802 CJK UNIFIED IDEOGRAPH-#3802, IRGKangXi=0319.111, Def{name of a place, lofty; steep, mountain with lots of small rocks}
3803 CJK UNIFIED IDEOGRAPH-#3803, IRGKangXi=0319.111
3804 CJK UNIFIED IDEOGRAPH-#3804, IRGKangXi=0319.111, Def{name of a mountain in Yunnan Province}
3805 CJK UNIFIED IDEOGRAPH-#3805, IRGKangXi=0319.120, Def{to cover; to put a cover over something, name of a mountain}
3806 CJK UNIFIED IDEOGRAPH-#3806, IRGKangXi=0319.140, Def{name of a mountain}
3807 CJK UNIFIED IDEOGRAPH-#3807, IRGKangXi=0319.190, Def{name of a mountain ridge}
3808 CJK UNIFIED IDEOGRAPH-#3808, IRGKangXi=0319.250, Def{name of a place}
3809 CJK UNIFIED IDEOGRAPH-#3809, IRGKangXi=0319.260, Def{mountain; hill, bald hills, valley; ravine}
380A CJK UNIFIED IDEOGRAPH-#380A, IRGKangXi=0319.290, Def{(same as U+5D87 嶇) a rugged, steep mountain}
380B CJK UNIFIED IDEOGRAPH-#380B, IRGKangXi=0319.360, Def{(same as 崿) a lofty mountain peak}
380C CJK UNIFIED IDEOGRAPH-#380C, IRGKangXi=0319.380, Def{high; lofty; steep, (corrupted form of 嵌)}
380D CJK UNIFIED IDEOGRAPH-#380D, IRGKangXi=0319.400, Def{lofty; majestic, name of a mountain}
380E CJK UNIFIED IDEOGRAPH-#380E, IRGKangXi=0319.410, Def{(same as U+380D 㠍) a lofty mountain}
380F CJK UNIFIED IDEOGRAPH-#380F, IRGKangXi=0320.131, Def{name of a mountain}
3810 CJK UNIFIED IDEOGRAPH-#3810, IRGKangXi=0320.131, Def{high and pointed mountain, mountain paths (same as 嶠) lofty}
3811 CJK UNIFIED IDEOGRAPH-#3811, IRGKangXi=0320.250, Def{high mountain steep rugged and uneven}
3812 CJK UNIFIED IDEOGRAPH-#3812, IRGKangXi=0320.260, Def{(same as U+37FD 㟽) mountain top; summit, pointed mountain top}
3813 CJK UNIFIED IDEOGRAPH-#3813, IRGKangXi=0320.320, Def{name of a mountain}
3814 CJK UNIFIED IDEOGRAPH-#3814, IRGKangXi=0320.330, Def{shapes of the mountain, the strategic and dangious gorge, (a dialect) field in between of the valleys}
3815 CJK UNIFIED IDEOGRAPH-#3815, IRGKangXi=0320.390, Def{(same as 嵬) lofty, precipitous; high and dangerous mountain}
3816 CJK UNIFIED IDEOGRAPH-#3816, IRGKangXi=0321.070, Def{(same as 嶬) precipitous; nigh and dangerous, name of a mountain}
3817 CJK UNIFIED IDEOGRAPH-#3817, IRGKangXi=0321.081, Def{(same as 奧 嶴) deep in the mountain, name of a place in Zhejiang Province; at the hill side}
3818 CJK UNIFIED IDEOGRAPH-#3818, IRGKangXi=0321.361, Def{(same as 嶼) an island}
3819 CJK UNIFIED IDEOGRAPH-#3819, IRGKangXi=0321.100, Def{a mountain paths (same as 崤) name of a mountain}
381A CJK UNIFIED IDEOGRAPH-#381A, IRGKangXi=0321.230, Def{high and lofty}
381B CJK UNIFIED IDEOGRAPH-#381B, IRGKangXi=0321.270, Def{name a county}
381C CJK UNIFIED IDEOGRAPH-#381C, IRGKangXi=0321.361, Def{(same as 嶷) young kids smart and familiar with human affairs, range of mountains in Hunan Province}
381D CJK UNIFIED IDEOGRAPH-#381D, IRGKangXi=0321.370, Def{(non-classical 巑) lofty and steep mountains, to rise high}
381E CJK UNIFIED IDEOGRAPH-#381E, IRGKangXi=0322.061
381F CJK UNIFIED IDEOGRAPH-#381F, IRGKangXi=0322.061, Def{a mountain in ancient times; Lieshan in Guizhou province}
3820 CJK UNIFIED IDEOGRAPH-#3820, IRGKangXi=0322.080, Def{name of a mountain}
3821 CJK UNIFIED IDEOGRAPH-#3821, IRGKangXi=0322.140, Def{high and lofty}
3822 CJK UNIFIED IDEOGRAPH-#3822, IRGKangXi=0322.150, Def{rugged and uneven, to shrink; to recoil; to cringe}
3823 CJK UNIFIED IDEOGRAPH-#3823, IRGKangXi=0322.181, Def{a mountain in Jiangxi Province; southeast of Jingde county}
3824 CJK UNIFIED IDEOGRAPH-#3824, IRGKangXi=0322.291
3825 CJK UNIFIED IDEOGRAPH-#3825, IRGKangXi=0322.300, Def{rugged and uneven, high and lofty, to roll stones down hill, piles of stones}
3826 CJK UNIFIED IDEOGRAPH-#3826, IRGKangXi=0322.370, Def{name of a mountain}
3827 CJK UNIFIED IDEOGRAPH-#3827, IRGKangXi=0323.050, Def{a little slanted; smooth, name of a mountain}
3828 CJK UNIFIED IDEOGRAPH-#3828, IRGKangXi=0323.161, Def{misty mountain}
3829 CJK UNIFIED IDEOGRAPH-#3829, IRGKangXi=0324.061, Def{(same as 芒 荒) vast, to reach, dwell, to neglect; to leave completely unattended to}
382A CJK UNIFIED IDEOGRAPH-#382A, IRGKangXi=0325.060, Def{ancient form of 五 'five'}
382B CJK UNIFIED IDEOGRAPH-#382B, IRGKangXi=0326.031
382C CJK UNIFIED IDEOGRAPH-#382C, IRGKangXi=0326.031
382D CJK UNIFIED IDEOGRAPH-#382D, IRGKangXi=0326.050, Def{to open, to stretch; to extend, to unfold; to dilate; to prolong}
382E CJK UNIFIED IDEOGRAPH-#382E, IRGKangXi=0326.070, Def{to expand, to swell, (non-classical form of 肛) the anus}
382F CJK UNIFIED IDEOGRAPH-#382F, IRGKangXi=0327.030, Def{according to; to use; with, for}
3830 CJK UNIFIED IDEOGRAPH-#3830, IRGKangXi=0327.061
3831 CJK UNIFIED IDEOGRAPH-#3831, IRGKangXi=0327.110, Def{to set with the legs crossed (standard form of 踞); (ancient form of 箕) a winnowing basket, a dust basket, (same as 杞) a state in ancient times}
3832 CJK UNIFIED IDEOGRAPH-#3832, IRGKangXi=0328.050, Def{ripped; split}
3833 CJK UNIFIED IDEOGRAPH-#3833, IRGKangXi=0328.081
3834 CJK UNIFIED IDEOGRAPH-#3834, IRGKangXi=0328.090, Def{a pillow case}
3835 CJK UNIFIED IDEOGRAPH-#3835, IRGKangXi=0328.120, Def{a turban; headdress; a scarf, a piece of cloth (fabric) used to cover something}
3836 CJK UNIFIED IDEOGRAPH-#3836, IRGKangXi=0329.051, Def{(a variant of U+5E06 帆) a sail, to sail}
3837 CJK UNIFIED IDEOGRAPH-#3837, IRGKangXi=0329.060, Def{a vessel for rice, mats on carriage}
3838 CJK UNIFIED IDEOGRAPH-#3838, IRGKangXi=0329.120, Def{(same as 衭) the lapel or collar of a garment or robe, (Cant., same as 褲) drawers, trousers or pants}
3839 CJK UNIFIED IDEOGRAPH-#3839, IRGKangXi=0329.150, Def{a turban; a headdress a scarf}
383A CJK UNIFIED IDEOGRAPH-#383A, IRGKangXi=0329.220, Def{a fine thread, a net with small; tiny holes}
383B CJK UNIFIED IDEOGRAPH-#383B, IRGKangXi=0329.291, Def{(same as 希) rare, to hope; to expect}
383C CJK UNIFIED IDEOGRAPH-#383C, IRGKangXi=0329.291
383D CJK UNIFIED IDEOGRAPH-#383D, IRGKangXi=0329.300, Def{a dish-cloth; a mopper; a cleaning rag}
383E CJK UNIFIED IDEOGRAPH-#383E, IRGKangXi=0329.310, Def{a dish-cloth; a mopper; a cleaning rag, headdress; a scarf; turban}
383F CJK UNIFIED IDEOGRAPH-#383F, IRGKangXi=0329.410, Def{a kind of delicate and fine fabric, a napkin; kerchief or towel, headwear}
3840 CJK UNIFIED IDEOGRAPH-#3840, IRGKangXi=0330.050, Def{ragged clothing, ragged; old and wear out}
3841 CJK UNIFIED IDEOGRAPH-#3841, IRGKangXi=0330.170, Def{a robe; a long gown, a shirt; a short gown}
3842 CJK UNIFIED IDEOGRAPH-#3842, IRGKangXi=0330.210, Def{remains; remnants}
3843 CJK UNIFIED IDEOGRAPH-#3843, IRGKangXi=0331.010, Def{an artisan to soften raw silk by boiling and to dye the dressed silk}
3844 CJK UNIFIED IDEOGRAPH-#3844, IRGKangXi=0331.020, Def{collar}
3845 CJK UNIFIED IDEOGRAPH-#3845, IRGKangXi=0331.130, Def{storage room}
3846 CJK UNIFIED IDEOGRAPH-#3846, IRGKangXi=0331.191, Def{(same as U+3843 㡃) an artisan to soften raw silk by boiling and to dye the dressed silk}
3847 CJK UNIFIED IDEOGRAPH-#3847, IRGKangXi=0331.200, Def{collar, the front of a Chinese gown, lapel of a Chinese dress worn by the literati in former days}
3848 CJK UNIFIED IDEOGRAPH-#3848, IRGKangXi=0331.240, Def{the ropes attached to the bier and held by mourners, mourning garments, a ceremonial cap for high ministers in old China}
3849 CJK UNIFIED IDEOGRAPH-#3849, IRGKangXi=0332.220, Def{a kind of fabric, a county in today's Shandong Province; southwest of Huangxian}
384A CJK UNIFIED IDEOGRAPH-#384A, IRGKangXi=0333.010, Def{(same as 帢) a kind of cap worn by an officer in old China}
384B CJK UNIFIED IDEOGRAPH-#384B, IRGKangXi=0333.080, Def{a kind of headdress for man in old China, a bag used to feed the horses}
384C CJK UNIFIED IDEOGRAPH-#384C, IRGKangXi=0333.161, Def{(same as 帽) a hat, headwear, a cap (of fountain-pen, crew, etc.)}
384D CJK UNIFIED IDEOGRAPH-#384D, IRGKangXi=0333.161
384E CJK UNIFIED IDEOGRAPH-#384E, IRGKangXi=0333.161, Def{(simplified form of 幓) (same as 縿) the long bands or ribbons attrached to flags and banners (same as 襂) the feather decorected carriages or dresses; flapping and dangling, headdress used by man in ancient times}
384F CJK UNIFIED IDEOGRAPH-#384F, IRGKangXi=0333.170, Def{to cut a strip of cloth; a breadth of material, (same as 繻) fine gauze, frayed edges of silk, silk torn into two pieces, one of which was given as a credential and the other retained, a loose garment or cloak; fine clothes, the left over material after cutting; ragged fabric}
3850 CJK UNIFIED IDEOGRAPH-#3850, IRGKangXi=0333.210, Def{(non-classical form) flags, pennants, streamers, etc.}
3851 CJK UNIFIED IDEOGRAPH-#3851, IRGKangXi=0334.030, Def{ancient mourning turban worn by women, to hem, turban worn by men}
3852 CJK UNIFIED IDEOGRAPH-#3852, IRGKangXi=0334.090, Def{a calico sack for grain, etc.}
3853 CJK UNIFIED IDEOGRAPH-#3853, IRGKangXi=0334.130, Def{drawers; trousers or pants}
3854 CJK UNIFIED IDEOGRAPH-#3854, IRGKangXi=0334.140, Def{oiled calico, varnish-cloth used to cover the cross-bean in front of the shafts of a carriage}
3855 CJK UNIFIED IDEOGRAPH-#3855, IRGKangXi=0334.150, Def{(same as 央) sharp; distinct, bright-colored}
3856 CJK UNIFIED IDEOGRAPH-#3856, IRGKangXi=0334.170, Def{(same as 幢) to cover; a covering; a screen, a curtain for a carriage}
3857 CJK UNIFIED IDEOGRAPH-#3857, IRGKangXi=0334.350, Def{red paper, a small piece of thin paper, ropes; cords; cables}
3858 CJK UNIFIED IDEOGRAPH-#3858, IRGKangXi=0334.360, Def{screens; cloth partition; door curtain; door flap, (same as 縑) a kind of fine silk, downy, feathery; featheriness}
3859 CJK UNIFIED IDEOGRAPH-#3859, IRGKangXi=0335.070, Def{curtain for carriage}
385A CJK UNIFIED IDEOGRAPH-#385A, IRGKangXi=0335.080, Def{armour, unlined garments}
385B CJK UNIFIED IDEOGRAPH-#385B, IRGKangXi=0335.151, Def{name for a workman who applied color in painting (in ancient times)}
385C CJK UNIFIED IDEOGRAPH-#385C, IRGKangXi=0335.160, Def{ragged clothes, left over; remainder, the excess; the surplus, to cut out (of silk fabrics) as a design}
385D CJK UNIFIED IDEOGRAPH-#385D, IRGKangXi=0335.220, Def{a napkin, kerchief, a headgear; articles for dressing the hair, a calligrapher's or painter's signature, seal, dedicatory notes, etc. on a painting, etc.}
385E CJK UNIFIED IDEOGRAPH-#385E, IRGKangXi=0336.020, Def{a sack used to feed the horses, an old family name}
385F CJK UNIFIED IDEOGRAPH-#385F, IRGKangXi=0336.030, Def{bed-mats for baby}
3860 CJK UNIFIED IDEOGRAPH-#3860, IRGKangXi=0336.170, Def{a picture; one of a pair, as of scrolls, etc.}
3861 CJK UNIFIED IDEOGRAPH-#3861, IRGKangXi=0337.031, Def{(a variant of 幮 U+5E6E, 𢅥 U+22165) a screen used to make a temporary kitchen}
3862 CJK UNIFIED IDEOGRAPH-#3862, IRGKangXi=0337.130, Def{(a variant of 幔) a curtain, a screen}
3863 CJK UNIFIED IDEOGRAPH-#3863, IRGKangXi=0337.171, Def{(same as 龍) dragon, or the emperor; imperial, a Chinese family name}
3864 CJK UNIFIED IDEOGRAPH-#3864, IRGKangXi=0337.171
3865 CJK UNIFIED IDEOGRAPH-#3865, IRGKangXi=0337.180, Def{to curl up; to roll up, to wrap up; to bind}
3866 CJK UNIFIED IDEOGRAPH-#3866, IRGKangXi=0337.210, Def{mess; out of order, chaos; confusion, (of clothes) tattered; in rags}
3867 CJK UNIFIED IDEOGRAPH-#3867, IRGKangXi=0338.170, Def{to stretch open painting, (same as 幀) a picture (one of a pair as of scrolls, etc.)}
3868 CJK UNIFIED IDEOGRAPH-#3868, IRGKangXi=0338.180, Def{a label; a tag, to record, to make a note, to wipe; to scrub; to dust; to clean}
3869 CJK UNIFIED IDEOGRAPH-#3869, IRGKangXi=0338.220, Def{a girdle; a sash or scarf; a belt; a band; a ribbon; a string; a tie}
386A CJK UNIFIED IDEOGRAPH-#386A, IRGKangXi=0338.251, Def{the varnish on the floor, to erase; to obliterate, to scribble}
386B CJK UNIFIED IDEOGRAPH-#386B, IRGKangXi=0342.170, Def{anxious, unsuccessful man}
386C CJK UNIFIED IDEOGRAPH-#386C, IRGKangXi=0342.181
386D CJK UNIFIED IDEOGRAPH-#386D, IRGKangXi=0343.020, Def{(standard, ancient form of U+7E7C 繼) to continue; to carry on, to follow; to inherit; to succeed to}
386E CJK UNIFIED IDEOGRAPH-#386E, IRGKangXi=0343.040, Def{danger; precarious, to fear, lofty; high, just; honest, to grind, to cultivate; to polish}
386F CJK UNIFIED IDEOGRAPH-#386F, IRGKangXi=0343.090, Def{(ancient form of 宅) wall of a building, a house, to keep in the house, thriving; flourishing, blazing, (ancient form of 度) legal system; laws and institutions, to think; to consider; to ponder; to contemplate}
3870 CJK UNIFIED IDEOGRAPH-#3870, IRGKangXi=0343.130, Def{(large seal type 宇) a house; a roof, appearance, space; the canopy of heaven, to cover}
3871 CJK UNIFIED IDEOGRAPH-#3871, IRGKangXi=0343.150, Def{(same as 灸) (in Chinese medicine) to cauterize by burning moxa; moxa cautery; moxibustion}
3872 CJK UNIFIED IDEOGRAPH-#3872, IRGKangXi=0343.340, Def{tiles (laid upside down) on a roof, ropes, to hold fast}
3873 CJK UNIFIED IDEOGRAPH-#3873, IRGKangXi=0344.010, Def{mountain, (corrupted form of 底) underside; bottom; basis; foundation}
3874 CJK UNIFIED IDEOGRAPH-#3874, IRGKangXi=0344.070, Def{sound}
3875 CJK UNIFIED IDEOGRAPH-#3875, IRGKangXi=0344.080, Def{roof of the house connected}
3876 CJK UNIFIED IDEOGRAPH-#3876, IRGKangXi=0344.090, Def{dwell, to live in a depraved (crude; vulgar; inferior) place}
3877 CJK UNIFIED IDEOGRAPH-#3877, IRGKangXi=0344.120, Def{a family name}
3878 CJK UNIFIED IDEOGRAPH-#3878, IRGKangXi=0344.140, Def{a house; an unfinished house, uneven; irregular; unsuitable; ill-matched, tenon}
3879 CJK UNIFIED IDEOGRAPH-#3879, IRGKangXi=0344.230, Def{to rely upon each other}
387A CJK UNIFIED IDEOGRAPH-#387A, IRGKangXi=0344.240, Def{a cottage; a small house, a small cup}
387B CJK UNIFIED IDEOGRAPH-#387B, IRGKangXi=0345.030, Def{(non-classical form of 廖) name of a small ancient State, a Chinese family name}
387C CJK UNIFIED IDEOGRAPH-#387C, IRGKangXi=0345.120, Def{a granary, a cabin, as in the ship, a corridor; a hallway}
387D CJK UNIFIED IDEOGRAPH-#387D, IRGKangXi=0345.130, Def{depraved talking}
387E CJK UNIFIED IDEOGRAPH-#387E, IRGKangXi=0345.140, Def{a threshold; a door-sill}
387F CJK UNIFIED IDEOGRAPH-#387F, IRGKangXi=0345.190, Def{(standard form of 斥) to accuse; to blame, to expel; to drive off; to reject}
3880 CJK UNIFIED IDEOGRAPH-#3880, IRGKangXi=0345.220, Def{side room}
3881 CJK UNIFIED IDEOGRAPH-#3881, IRGKangXi=0345.250, Def{(same as U+388B 㢋) vast, to open up, enlarge or expand, the blot of a door; door latch, name of a person}
3882 CJK UNIFIED IDEOGRAPH-#3882, IRGKangXi=0346.010, Def{(terrains) of highly strategic; precipitous (hill, etc. a big mound; (same as 㢈) a collapsed house, to hit, to catch something}
3883 CJK UNIFIED IDEOGRAPH-#3883, IRGKangXi=0346.080, Def{high, magnanimity}
3884 CJK UNIFIED IDEOGRAPH-#3884, IRGKangXi=0346.120, Def{a kind of utensil; implement; tool, a place of worship; a place where to honor by a service or rite; a place to offer sacrifices; a kitchen}
3885 CJK UNIFIED IDEOGRAPH-#3885, IRGKangXi=0346.230, Def{a shield; a screen, a tall building; an edifice, (same as 弄) an alley; a lane}
3886 CJK UNIFIED IDEOGRAPH-#3886, IRGKangXi=0346.270, Def{(same as 廛) living space for one family in ancient times, a store; a shop, a hundred mu (equal to 733.50 square yards) cultivated land}
3887 CJK UNIFIED IDEOGRAPH-#3887, IRGKangXi=0346.291
3888 CJK UNIFIED IDEOGRAPH-#3888, IRGKangXi=0346.320, Def{a collapsed house; (same as U+5806 堆) to heap up; to pile}
3889 CJK UNIFIED IDEOGRAPH-#3889, IRGKangXi=0346.330, Def{a room with open space, an old county near today's Shandong Province Yunchengxian}
388A CJK UNIFIED IDEOGRAPH-#388A, IRGKangXi=0347.010, Def{to set side by side, to hide; to conceal, to store}
388B CJK UNIFIED IDEOGRAPH-#388B, IRGKangXi=0347.150, Def{vast, to open up, enlarge or expand}
388C CJK UNIFIED IDEOGRAPH-#388C, IRGKangXi=0348.081
388D CJK UNIFIED IDEOGRAPH-#388D, IRGKangXi=0348.200, Def{a long verandah; a long porch}
388E CJK UNIFIED IDEOGRAPH-#388E, IRGKangXi=0348.240, Def{hide; conceal, a house not so high}
388F CJK UNIFIED IDEOGRAPH-#388F, IRGKangXi=0348.270, Def{a cesspool; a manger, a trough; a flume; a chute, (same as 庾) a stack of grain, an ancient measure of capacity, a storage for water, (ancient form 逾) to pass over; to exceed}
3890 CJK UNIFIED IDEOGRAPH-#3890, IRGKangXi=0348.361
3891 CJK UNIFIED IDEOGRAPH-#3891, IRGKangXi=0348.370, Def{(corrupted form of U+3888 㢈) a collapsed house; (same as 堆) to heap up; to pile}
3892 CJK UNIFIED IDEOGRAPH-#3892, IRGKangXi=0349.240, Def{an almost collapsing house}
3893 CJK UNIFIED IDEOGRAPH-#3893, IRGKangXi=0349.280, Def{(same as 障) to separate; to screen, a screen, a veil, a dike, to defend; to guard}
3894 CJK UNIFIED IDEOGRAPH-#3894, IRGKangXi=0349.300, Def{many; numerous; a crowd; the masses, two houses connected each other}
3895 CJK UNIFIED IDEOGRAPH-#3895, IRGKangXi=0350.090, Def{(same as 廱) harmony; peace, peaceful; mild}
3896 CJK UNIFIED IDEOGRAPH-#3896, IRGKangXi=0350.150, Def{a store house, to store}
3897 CJK UNIFIED IDEOGRAPH-#3897, IRGKangXi=0351.040, Def{a high house; a high building}
3898 CJK UNIFIED IDEOGRAPH-#3898, IRGKangXi=0351.071, Def{(non-classical form) (a variant of 廉) pure, modest, incorrupt, not avaricious--thus: reasonable in price}
3899 CJK UNIFIED IDEOGRAPH-#3899, IRGKangXi=0351.100, Def{(same as 廑) a hut; cottage, careful; eager; concern}
389A CJK UNIFIED IDEOGRAPH-#389A, IRGKangXi=0351.120, Def{a corridor; a hallway; rooms around the hall (the middle room of a Chinese house), a nunnery; a convent, a cottage; a hut, a mansion}
389B CJK UNIFIED IDEOGRAPH-#389B, IRGKangXi=0351.190, Def{small, a cabinet; a cupboard}
389C CJK UNIFIED IDEOGRAPH-#389C, IRGKangXi=0351.231, Def{vast}
389D CJK UNIFIED IDEOGRAPH-#389D, IRGKangXi=0352.040, Def{cottage; a coarse house, house with flat roof}
389E CJK UNIFIED IDEOGRAPH-#389E, IRGKangXi=0352.110, Def{rooms connected, moveable house (a yurt, a portable, tentlike dwelling used by nomadic Mongols)}
389F CJK UNIFIED IDEOGRAPH-#389F, IRGKangXi=0352.290, Def{to walk slowly; to stroll; to ramble}
38A0 CJK UNIFIED IDEOGRAPH-#38A0, IRGKangXi=0353.031, Def{(same as 迥) far; distant; separated}
38A1 CJK UNIFIED IDEOGRAPH-#38A1, IRGKangXi=0354.300, Def{(same as 獎) to exhort; to encourage, to praise; to commend, to advise; to urge, to help}
38A2 CJK UNIFIED IDEOGRAPH-#38A2, IRGKangXi=0354.351
38A3 CJK UNIFIED IDEOGRAPH-#38A3, IRGKangXi=0354.370, Def{(same as 擎) to lift; to lift up; to support}
38A4 CJK UNIFIED IDEOGRAPH-#38A4, IRGKangXi=0355.101
38A5 CJK UNIFIED IDEOGRAPH-#38A5, IRGKangXi=0355.120, Def{a big piece of log to join the thick ropes; cable; used on a boat}
38A6 CJK UNIFIED IDEOGRAPH-#38A6, IRGKangXi=0355.150, Def{(corrupted form) wooden post or pile for tethering animals, small and sharp pile}
38A7 CJK UNIFIED IDEOGRAPH-#38A7, IRGKangXi=0356.120, Def{(same as 卷) a book or painting which can be easily folded or rolled up, a division of a book}
38A8 CJK UNIFIED IDEOGRAPH-#38A8, IRGKangXi=0357.010, Def{to defend; to ward off; to refuse; to reject; to oppose, a frontier pass (in Wuxian) in ancient times, a county in ancient times}
38A9 CJK UNIFIED IDEOGRAPH-#38A9, IRGKangXi=0357.040, Def{to shoot; to spurt, (same as 的) target for archery}
38AA CJK UNIFIED IDEOGRAPH-#38AA, IRGKangXi=0357.090, Def{to draw a full bow to aim at the target, to hold; to maintain; to uphold, to conduct}
38AB CJK UNIFIED IDEOGRAPH-#38AB, IRGKangXi=0357.101
38AC CJK UNIFIED IDEOGRAPH-#38AC, IRGKangXi=0357.120, Def{(same as U+5F4B 彋) a bow stretched to the full}
38AD CJK UNIFIED IDEOGRAPH-#38AD, IRGKangXi=0357.211, Def{(non-classical form of 弢) a bow-case; a scabbard, to sheathe, to conceal}
38AE CJK UNIFIED IDEOGRAPH-#38AE, IRGKangXi=0357.240, Def{(same as 弛) to unstring a bow; to relax; to neglect}
38AF CJK UNIFIED IDEOGRAPH-#38AF, IRGKangXi=0357.290, Def{(same as 弴) bows (with carved pattern) used by the son of heaven -- the emperor, flags; streamers; banners, a flag-staff made of bamboo}
38B0 CJK UNIFIED IDEOGRAPH-#38B0, IRGKangXi=0357.330, Def{to stretch a bow, the bow decorated with colorful silk and leather, bent; curved}
38B1 CJK UNIFIED IDEOGRAPH-#38B1, IRGKangXi=0358.031
38B2 CJK UNIFIED IDEOGRAPH-#38B2, IRGKangXi=0358.140, Def{(same as 巽) the 5th of the Eight Diagrams 八卦, South-east, Mild, bland, insinuating, peaceful words}
38B3 CJK UNIFIED IDEOGRAPH-#38B3, IRGKangXi=0358.150, Def{(same as 玈) black color, a black bow; bow in general}
38B4 CJK UNIFIED IDEOGRAPH-#38B4, IRGKangXi=0358.160, Def{(ancient form of 西) the west; western, European}
38B5 CJK UNIFIED IDEOGRAPH-#38B5, IRGKangXi=0358.170, Def{powerful and strong bow, (interchangeable 弽韘) archer's thumb ring of leather}
38B6 CJK UNIFIED IDEOGRAPH-#38B6, IRGKangXi=0358.191, Def{(non-classical form of 弼) device for regulating bows; bow regulator, to correct, to assist; to aid}
38B7 CJK UNIFIED IDEOGRAPH-#38B7, IRGKangXi=0358.191
38B8 CJK UNIFIED IDEOGRAPH-#38B8, IRGKangXi=0358.210, Def{(ancient form of 弼) device for regulating bows; bow regulator, to correct, to assist; to aid, to dust, to shake; to brush}
38B9 CJK UNIFIED IDEOGRAPH-#38B9, IRGKangXi=0359.061
38BA CJK UNIFIED IDEOGRAPH-#38BA, IRGKangXi=0359.080, Def{(non-classical form of 弦) string (of a bow, a musical instrument, etc.), chord of an arc, the first or last quarter of a lunar month}
38BB CJK UNIFIED IDEOGRAPH-#38BB, IRGKangXi=0359.130, Def{to draw a bow, bent}
38BC CJK UNIFIED IDEOGRAPH-#38BC, IRGKangXi=0360.010, Def{(same as 彆) awkward, unfavourable, unsuitable, not smooth}
38BD CJK UNIFIED IDEOGRAPH-#38BD, IRGKangXi=0360.160, Def{(same as 餌) a bait, cakes, food, to eat}
38BE CJK UNIFIED IDEOGRAPH-#38BE, IRGKangXi=0360.190, Def{the curved end of a bow}
38BF CJK UNIFIED IDEOGRAPH-#38BF, IRGKangXi=0360.221
38C0 CJK UNIFIED IDEOGRAPH-#38C0, IRGKangXi=0360.260, Def{to rebound, to impeach, to play}
38C1 CJK UNIFIED IDEOGRAPH-#38C1, IRGKangXi=0360.270, Def{to equip a bow with silk and muscular fibre}
38C2 CJK UNIFIED IDEOGRAPH-#38C2, IRGKangXi=0360.280, Def{to bind, to pack up the bows and the cover of the bows}
38C3 CJK UNIFIED IDEOGRAPH-#38C3, IRGKangXi=0360.350, Def{(same as 鬻) to sell; to buy, to nourish}
38C4 CJK UNIFIED IDEOGRAPH-#38C4, IRGKangXi=0360.400, Def{powerful; strong bows, the end of the bows}
38C5 CJK UNIFIED IDEOGRAPH-#38C5, IRGKangXi=0360.430, Def{bow-string; a chord; a straight road, to draw a bow, strong}
38C6 CJK UNIFIED IDEOGRAPH-#38C6, IRGKangXi=0361.250, Def{to loose the bow-string, a kind of jade, (same as 彌) full, great, boundless, to complete}
38C7 CJK UNIFIED IDEOGRAPH-#38C7, IRGKangXi=0362.080, Def{a kind of beast with long hair, other name for pig, fox, wild cat, raccoon}
38C8 CJK UNIFIED IDEOGRAPH-#38C8, IRGKangXi=0362.240, Def{a kind of animal, a kind of rat, (interchangeable 肆) extremely; excessively; reckless; without restraint, to exhaust}
38C9 CJK UNIFIED IDEOGRAPH-#38C9, IRGKangXi=0363.040, Def{(ancient form of 工) labor, work, fine; delicate, to be skilled in}
38CA CJK UNIFIED IDEOGRAPH-#38CA, IRGKangXi=0363.081
38CB CJK UNIFIED IDEOGRAPH-#38CB, IRGKangXi=0363.090, Def{(ancient form of 丹) cinnabar, red; scarlet, a pill, a sophisticated decoction}
38CC CJK UNIFIED IDEOGRAPH-#38CC, IRGKangXi=0363.110, Def{to join two things; contiguous; things connected end to end, sharp}
38CD CJK UNIFIED IDEOGRAPH-#38CD, IRGKangXi=0363.120, Def{(ancient form of 台) a raised platform, eminent; exalted, name of a star}
38CE CJK UNIFIED IDEOGRAPH-#38CE, IRGKangXi=0363.190, Def{fine (material, etc.) and delicate (workmanship, etc.) decorative design or pattern}
38CF CJK UNIFIED IDEOGRAPH-#38CF, IRGKangXi=0364.080, Def{(ancient form of 靜) still; quiet; calm; silent; peaceful}
38D0 CJK UNIFIED IDEOGRAPH-#38D0, IRGKangXi=0364.081, Def{(ancient form of 變) to change; to transform; to switch; to alter, rebellion}
38D1 CJK UNIFIED IDEOGRAPH-#38D1, IRGKangXi=0364.160, Def{double image, (non-classical form of 容) face; expression; countenance, to contain; to hold; to accept}
38D2 CJK UNIFIED IDEOGRAPH-#38D2, IRGKangXi=0364.210, Def{hair-raising, hairiness}
38D3 CJK UNIFIED IDEOGRAPH-#38D3, IRGKangXi=0364.240, Def{literary in taste; elegant; ornamental, beautiful and gorgeous}
38D4 CJK UNIFIED IDEOGRAPH-#38D4, IRGKangXi=0365.030, Def{to walk alone, to insist on one's ways in doing things}
38D5 CJK UNIFIED IDEOGRAPH-#38D5, IRGKangXi=0365.071
38D6 CJK UNIFIED IDEOGRAPH-#38D6, IRGKangXi=0365.211
38D7 CJK UNIFIED IDEOGRAPH-#38D7, IRGKangXi=0365.211
38D8 CJK UNIFIED IDEOGRAPH-#38D8, IRGKangXi=0365.240, Def{(same as 跔) spasms, cramps in the feet and legs, in cold day the joints of the feet and legs unable to stretch}
38D9 CJK UNIFIED IDEOGRAPH-#38D9, IRGKangXi=0365.310, Def{to walk in an easy and leisurely manner, (same as 宙) time--past, present and future, infinite time; time without beginning or end; eternity}
38DA CJK UNIFIED IDEOGRAPH-#38DA, IRGKangXi=0366.010, Def{to go straight forward, (same as 衕) a lane; an alley, (same as 侗) ignorant; rude; rustic; straight-forward; uninterrupted; no obstacle}
38DB CJK UNIFIED IDEOGRAPH-#38DB, IRGKangXi=0366.040, Def{walking, (ancient form form of 會) to meet, to gather, to be able, to realize}
38DC CJK UNIFIED IDEOGRAPH-#38DC, IRGKangXi=0366.060, Def{to walk; to go}
38DD CJK UNIFIED IDEOGRAPH-#38DD, IRGKangXi=0366.080, Def{a Chinese family name}
38DE CJK UNIFIED IDEOGRAPH-#38DE, IRGKangXi=0367.030, Def{to walki; to go}
38DF CJK UNIFIED IDEOGRAPH-#38DF, IRGKangXi=0367.040, Def{to go; to walk}
38E0 CJK UNIFIED IDEOGRAPH-#38E0, IRGKangXi=0367.051, Def{a rope decorated with bronze ornament (for leading cattle), a family name}
38E1 CJK UNIFIED IDEOGRAPH-#38E1, IRGKangXi=0367.051
38E2 CJK UNIFIED IDEOGRAPH-#38E2, IRGKangXi=0367.140, Def{to rest from work; to take a rest}
38E3 CJK UNIFIED IDEOGRAPH-#38E3, IRGKangXi=0367.170, Def{to walk in an unsteady way; to swing to and from, to doubt, to suspect}
38E4 CJK UNIFIED IDEOGRAPH-#38E4, IRGKangXi=0368.010, Def{(same as 踐) to tread upon; to trample, to carry out; to perform}
38E5 CJK UNIFIED IDEOGRAPH-#38E5, IRGKangXi=0369.010, Def{(same as 偫) to store up, savings and/or reserves, complete with every; having nothing short; all; the whole}
38E6 CJK UNIFIED IDEOGRAPH-#38E6, IRGKangXi=0369.020, Def{a winding path}
38E7 CJK UNIFIED IDEOGRAPH-#38E7, IRGKangXi=0369.081, Def{(same as 胤) the succession in a family; posterity; heirs, to inherit; to follow after}
38E8 CJK UNIFIED IDEOGRAPH-#38E8, IRGKangXi=0369.081
38E9 CJK UNIFIED IDEOGRAPH-#38E9, IRGKangXi=0369.081
38EA CJK UNIFIED IDEOGRAPH-#38EA, IRGKangXi=0369.100, Def{to walk with slow steps; proceed slowly}
38EB CJK UNIFIED IDEOGRAPH-#38EB, IRGKangXi=0369.110, Def{(same as 踵) the heel, to follow, to call personally at; to go personally to, (ancient form 動) to move; to start; to shake, to excite; to rouse; to take action}
38EC CJK UNIFIED IDEOGRAPH-#38EC, IRGKangXi=0369.210, Def{to walk}
38ED CJK UNIFIED IDEOGRAPH-#38ED, IRGKangXi=0369.250, Def{number, several; a few, a kind of caldron or kettle, to walk}
38EE CJK UNIFIED IDEOGRAPH-#38EE, IRGKangXi=0370.051
38EF CJK UNIFIED IDEOGRAPH-#38EF, IRGKangXi=0370.080, Def{the dresses toss and flying about in the wind, to shake; to toss, to wave, to scull; to row, to agitate}
38F0 CJK UNIFIED IDEOGRAPH-#38F0, IRGKangXi=0370.280, Def{to shake; to rattle}
38F1 CJK UNIFIED IDEOGRAPH-#38F1, IRGKangXi=0370.310, Def{common people; people in ordinary feature or countenance, to walk, to go in a hurry}
38F2 CJK UNIFIED IDEOGRAPH-#38F2, IRGKangXi=0370.320, Def{(non-classical form of 微) small, low, weak; feeble}
38F3 CJK UNIFIED IDEOGRAPH-#38F3, IRGKangXi=0371.191
38F4 CJK UNIFIED IDEOGRAPH-#38F4, IRGKangXi=0371.191
38F5 CJK UNIFIED IDEOGRAPH-#38F5, IRGKangXi=0371.220, Def{to run away; to flee; to escape; to evade, (interchangeable 達) to reach; to arrive at, to walk away without meeting each other}
38F6 CJK UNIFIED IDEOGRAPH-#38F6, IRGKangXi=0371.240, Def{to walk, to go, to hide; to conceal, very difficult to proceed}
38F7 CJK UNIFIED IDEOGRAPH-#38F7, IRGKangXi=0372.030, Def{walking}
38F8 CJK UNIFIED IDEOGRAPH-#38F8, IRGKangXi=0372.161
38F9 CJK UNIFIED IDEOGRAPH-#38F9, IRGKangXi=0372.201
38FA CJK UNIFIED IDEOGRAPH-#38FA, IRGKangXi=0375.011, Def{(variant of 心) the heart, the moral nature, the mind, the affections, intention, the radical on left side of the character}
38FB CJK UNIFIED IDEOGRAPH-#38FB, IRGKangXi=0375.070, Def{to remedy by punishment; to punish; to reprove; to warn, in great distress; suffering hardships; distress; trouble; worry}
38FC CJK UNIFIED IDEOGRAPH-#38FC, IRGKangXi=0376.050, Def{(same as 忍) to endure; to bear; to forbear; to repress}
38FD CJK UNIFIED IDEOGRAPH-#38FD, IRGKangXi=0376.180, Def{(ancient form of 恕) to forgive; to pardon, (ancient form 怒) anger; wrath; indignation; rage}
38FE CJK UNIFIED IDEOGRAPH-#38FE, IRGKangXi=0377.030, Def{do not care; unmindful of}
38FF CJK UNIFIED IDEOGRAPH-#38FF, IRGKangXi=0377.060, Def{painfully sad, scared; afraid; fearful, anger, melancholy; grievous; mournful; sad, to be concerned about}
3900 CJK UNIFIED IDEOGRAPH-#3900, IRGKangXi=0377.071
3901 CJK UNIFIED IDEOGRAPH-#3901, IRGKangXi=0377.090, Def{(standard form of 忝) to disgrace; to insult, to condescend}
3902 CJK UNIFIED IDEOGRAPH-#3902, IRGKangXi=0377.160, Def{(a variant of 急) anxious; hurried; urgent; hasty}
3903 CJK UNIFIED IDEOGRAPH-#3903, IRGKangXi=0377.230, Def{jealous; to envy, (same as 妨) to hinder; to obstruct, to harm; to damage}
3904 CJK UNIFIED IDEOGRAPH-#3904, IRGKangXi=0378.010, Def{raging animosity or hatred; full of anger and spite, unhappy; displeased}
3905 CJK UNIFIED IDEOGRAPH-#3905, IRGKangXi=0378.050, Def{to love, to be fond of, o like; love, affection, a breath, news, to stop; to end, (interchangeable 忌) jealous; to envy, (the small seal 愛) love}
3906 CJK UNIFIED IDEOGRAPH-#3906, IRGKangXi=0378.070, Def{nauseated; disgusted, (in medicine) an acute case, quick-tempered, to regret; to repent, small (piece of land); narrow (minded)}
3907 CJK UNIFIED IDEOGRAPH-#3907, IRGKangXi=0378.110, Def{terrified; scared; nervous, (same as 懊) regretful; remorseful; resentful}
3908 CJK UNIFIED IDEOGRAPH-#3908, IRGKangXi=0378.180, Def{sad; sorrowful}
3909 CJK UNIFIED IDEOGRAPH-#3909, IRGKangXi=0378.250, Def{fear; dread; fright; scare, crafty; low cunning}
390A CJK UNIFIED IDEOGRAPH-#390A, IRGKangXi=0378.330, Def{(same as 恔) cheerful and exuberant; spiritually elevated}
390B CJK UNIFIED IDEOGRAPH-#390B, IRGKangXi=0379.070, Def{confusion; confused or disorderly; chaotic}
390C CJK UNIFIED IDEOGRAPH-#390C, IRGKangXi=0379.080, Def{(same as 甘) to have one's heart own; to submit, admire, etc. sincerely and willingly}
390D CJK UNIFIED IDEOGRAPH-#390D, IRGKangXi=0380.020, Def{never reveal one's feeling or emotion, (same as 巧) false, artificial, illegal, clever; artful, pretty cute}
390E CJK UNIFIED IDEOGRAPH-#390E, IRGKangXi=0380.060, Def{a model or typical example; technique of standard handwriting, knowledge, to know; to feel; to understand}
390F CJK UNIFIED IDEOGRAPH-#390F, IRGKangXi=0380.170, Def{grievous; mournful; melancholy}
3910 CJK UNIFIED IDEOGRAPH-#3910, IRGKangXi=0380.200, Def{(said of music) disharmony; discord, quiet, to yield; to concede}
3911 CJK UNIFIED IDEOGRAPH-#3911, IRGKangXi=0380.240, Def{(non-classical 憂) palpitation or fluttering of the heart, to become interested in something (usually as a result of persuasion); to move the mind; to start thinking; agitated; nervous}
3912 CJK UNIFIED IDEOGRAPH-#3912, IRGKangXi=0381.120, Def{knowledge; to know; to be aware of, a bureau, state of affairs}
3913 CJK UNIFIED IDEOGRAPH-#3913, IRGKangXi=0381.130, Def{stupid; foolish; unwise; unintelligent}
3914 CJK UNIFIED IDEOGRAPH-#3914, IRGKangXi=0381.190, Def{to concede or submit willingly}
3915 CJK UNIFIED IDEOGRAPH-#3915, IRGKangXi=0381.230, Def{melancholy; grievous; mournful; sad, anxious and fearful, extremely sad}
3916 CJK UNIFIED IDEOGRAPH-#3916, IRGKangXi=0382.200, Def{to have wisdom; intelligent}
3917 CJK UNIFIED IDEOGRAPH-#3917, IRGKangXi=0383.111
3918 CJK UNIFIED IDEOGRAPH-#3918, IRGKangXi=0383.111, Def{(simplified form of U+396E 㥮) obstinate; stubborn; opinionated; obstinacy; stubbornness; intransigent, truculent; savage, ferocious; fierce}
3919 CJK UNIFIED IDEOGRAPH-#3919, IRGKangXi=0383.111, Def{(same as 恩) grace, favour, kindness, mercy}
391A CJK UNIFIED IDEOGRAPH-#391A, IRGKangXi=0383.130, Def{joy; delight; gratification}
391B CJK UNIFIED IDEOGRAPH-#391B, IRGKangXi=0383.170, Def{to remember (old days, friends, etc.); to recall, (a pronoun, a dialect) this; these; such, here, without restriction; at will, to trust; to show good faith, weak, (ancient form 飪) to cook, you, (dialect) so; that, than, that case, that (indicating degree)}
391C CJK UNIFIED IDEOGRAPH-#391C, IRGKangXi=0383.210, Def{(corrupted form of 怴) crazy; mad, anger; angry, idiotic; silly; stupid, ill-will; enmity; animus}
391D CJK UNIFIED IDEOGRAPH-#391D, IRGKangXi=0383.320, Def{palpitation or fluttering of the heart, to become interested in something (usually as a result of persuasion)}
391E CJK UNIFIED IDEOGRAPH-#391E, IRGKangXi=0383.370, Def{disappointed; to fail in attaining one's purpose; to be disappointed in attaining the ambitions, to be surprised; to be amazed; to marvel, to think; to consider; to ponder; to contemplate, to expect or hope with eagerness, a credit, straightforward; faithful and upright, to reprimand; to discipline; to punish}
391F CJK UNIFIED IDEOGRAPH-#391F, IRGKangXi=0383.410, Def{(same as 恐) fear; dread; fright; scare, (with reference to an unpleasant fact) probably; perhaps; maybe; possible; to threaten; to blackmail}
3920 CJK UNIFIED IDEOGRAPH-#3920, IRGKangXi=0384.010, Def{grieved; distressed}
3921 CJK UNIFIED IDEOGRAPH-#3921, IRGKangXi=0384.020, Def{to surprise; to amaze, afraid; scared; fearful; terrified, grieved; distressed; grieved; distressed}
3922 CJK UNIFIED IDEOGRAPH-#3922, IRGKangXi=0384.040, Def{to move the mind; agitated; nervous; to start thinking}
3923 CJK UNIFIED IDEOGRAPH-#3923, IRGKangXi=0384.070, Def{(same as 恲) noble; disinterested; generous; energetic; liberal, to divulge; to leak out, to feel dull and listless or depressed}
3924 CJK UNIFIED IDEOGRAPH-#3924, IRGKangXi=0384.100, Def{(non-classical form) mournful; melancholy; distressed; grieved; sad, to fear; fear; dread}
3925 CJK UNIFIED IDEOGRAPH-#3925, IRGKangXi=0384.340, Def{sorrowful, anxious}
3926 CJK UNIFIED IDEOGRAPH-#3926, IRGKangXi=0385.030, Def{mournful; melancholy; distressed; grieved; sad}
3927 CJK UNIFIED IDEOGRAPH-#3927, IRGKangXi=0385.170, Def{conciliation; to come to an amicable understanding; compromise}
3928 CJK UNIFIED IDEOGRAPH-#3928, IRGKangXi=0385.180, Def{scared; terrified, fear; dread; fright}
3929 CJK UNIFIED IDEOGRAPH-#3929, IRGKangXi=0386.050, Def{(same as 恪) to respect; to venerate, grave and stern; of ornament -- splendid, imposing}
392A CJK UNIFIED IDEOGRAPH-#392A, IRGKangXi=0386.100, Def{(same as 怨) to find fault with; to repine; to murmur against; to harbour resentment, hatred}
392B CJK UNIFIED IDEOGRAPH-#392B, IRGKangXi=0386.161, Def{(non-classical form)}
392C CJK UNIFIED IDEOGRAPH-#392C, IRGKangXi=0386.161, Def{(same as 恚) full of anger and vexation, rage; hatred; to hate; to bear a grudge against; animosity}
392D CJK UNIFIED IDEOGRAPH-#392D, IRGKangXi=0386.161, Def{(simplified form of 憍) (same as 驕) untamed; intractable; disobedient}
392E CJK UNIFIED IDEOGRAPH-#392E, IRGKangXi=0386.230, Def{an error; a blunder, to cheat; to swindle; to defraud, confused; deceit; to deceive}
392F CJK UNIFIED IDEOGRAPH-#392F, IRGKangXi=0386.390, Def{clever or smart in a small way, memory or recollection}
3930 CJK UNIFIED IDEOGRAPH-#3930, IRGKangXi=0386.400, Def{(same as 怍) to be ashamed; mortified; chagrined, to change color; to blush}
3931 CJK UNIFIED IDEOGRAPH-#3931, IRGKangXi=0387.040, Def{anger; passion; rage, to wait, to cheat; to swindle}
3932 CJK UNIFIED IDEOGRAPH-#3932, IRGKangXi=0387.070, Def{to think; to contemplate; to consider, to pant because of fear}
3933 CJK UNIFIED IDEOGRAPH-#3933, IRGKangXi=0387.210, Def{to depend on}
3934 CJK UNIFIED IDEOGRAPH-#3934, IRGKangXi=0387.260, Def{to move the mind; agitated; nervous; to start thinking, to rest; to cease, intelligent, strange; uncanny, light aspirations or ambitions for ...}
3935 CJK UNIFIED IDEOGRAPH-#3935, IRGKangXi=0387.270, Def{(non-classical form of 慈) compassion, mercy, kindness}
3936 CJK UNIFIED IDEOGRAPH-#3936, IRGKangXi=0387.280, Def{confuse, senile, stupid}
3937 CJK UNIFIED IDEOGRAPH-#3937, IRGKangXi=0387.330, Def{to debauch; to dissipate; to act uninhibitively or disrespectfully}
3938 CJK UNIFIED IDEOGRAPH-#3938, IRGKangXi=0388.090, Def{uneasy; disturbed; not feeling at peace}
3939 CJK UNIFIED IDEOGRAPH-#3939, IRGKangXi=0388.110, Def{hatred; grudge; enmity; animosity, (interchangeable 救) to save; to relieve; to rescue; to deliver; to aid}
393A CJK UNIFIED IDEOGRAPH-#393A, IRGKangXi=0386.060, Def{(corrupted form of 慌) blurred; dim, obscure; confused in mind}
393B CJK UNIFIED IDEOGRAPH-#393B, IRGKangXi=0388.341, Def{stupid; clumsy; (Cant.) to dirty, defile}
393C CJK UNIFIED IDEOGRAPH-#393C, IRGKangXi=0388.341
393D CJK UNIFIED IDEOGRAPH-#393D, IRGKangXi=0388.341, Def{(simplified form of 懤) grieved, pained}
393E CJK UNIFIED IDEOGRAPH-#393E, IRGKangXi=0388.380, Def{not doing well; disappointed; very discouraged; frustrate (same as 憛) worried; anxious; apprehensive, to lose head; to lose self-possession}
393F CJK UNIFIED IDEOGRAPH-#393F, IRGKangXi=0388.390, Def{to love; to be fond of, love; affection; kindness, willingly; willing, joyous; happy, to fail to remember; to forget}
3940 CJK UNIFIED IDEOGRAPH-#3940, IRGKangXi=0388.400, Def{exclusive; special (same as 德) morality; virtues, behavior; conduct}
3941 CJK UNIFIED IDEOGRAPH-#3941, IRGKangXi=0389.010, Def{(same as U+5FB7 德) morality; virtues, behavior; conduct}
3942 CJK UNIFIED IDEOGRAPH-#3942, IRGKangXi=0389.040, Def{quick; fast, sharp, to move the mind; agitated; nervous; to start thinking, to fear; to dread; to be scared of, to get; to obtain}
3943 CJK UNIFIED IDEOGRAPH-#3943, IRGKangXi=0389.060, Def{(a variant of 悶) mournful, sorrowful, melancholy; depressed, to stupefy}
3944 CJK UNIFIED IDEOGRAPH-#3944, IRGKangXi=0389.180, Def{to pity; to commiserate; to have sympathy or compassion for, scared; afraid; fearful}
3945 CJK UNIFIED IDEOGRAPH-#3945, IRGKangXi=0389.200, Def{used in a person's name, pensive}
3946 CJK UNIFIED IDEOGRAPH-#3946, IRGKangXi=0389.230, Def{indulgent and without restraint, to abandon oneself to carnal desire; to be dissolute; to debauched, to forget, slow; to delay}
3947 CJK UNIFIED IDEOGRAPH-#3947, IRGKangXi=0390.050, Def{to be perverse; to act contrary to, jealous; to envy; jealousy, obstinate; stubborn, fierce; truculent}
3948 CJK UNIFIED IDEOGRAPH-#3948, IRGKangXi=0390.080, Def{(interchangeable 惵) afraid; fearful; terrified, peaceful; quiet; calm; safe; secure; stable}
3949 CJK UNIFIED IDEOGRAPH-#3949, IRGKangXi=0390.120, Def{a little angry}
394A CJK UNIFIED IDEOGRAPH-#394A, IRGKangXi=0390.130, Def{angry, (same as 恲) generous; unselfish; liberal}
394B CJK UNIFIED IDEOGRAPH-#394B, IRGKangXi=0390.170, Def{sound of the anguish of sorrow; the pain of grief}
394C CJK UNIFIED IDEOGRAPH-#394C, IRGKangXi=0390.190, Def{prudent; cautious}
394D CJK UNIFIED IDEOGRAPH-#394D, IRGKangXi=0390.230, Def{(same as 惎) to bear jealous hatred for; to hate; to hold a grudge against, to injure atrociously; to murder}
394E CJK UNIFIED IDEOGRAPH-#394E, IRGKangXi=0390.360, Def{(abbreviated form) to resent; to hate, to neglect; negligent, joy; delight; gratification}
394F CJK UNIFIED IDEOGRAPH-#394F, IRGKangXi=0390.370, Def{bashful; shy; ashamed}
3950 CJK UNIFIED IDEOGRAPH-#3950, IRGKangXi=0390.410, Def{(ancient form of 怨) hatred; enmity; resentment, to complain; to blame; to impute}
3951 CJK UNIFIED IDEOGRAPH-#3951, IRGKangXi=0390.460, Def{(corrupted form) (standard form of 憂) sad; mournful; grieved; to worry about; concerned over; anxious; apprehensive}
3952 CJK UNIFIED IDEOGRAPH-#3952, IRGKangXi=0391.020, Def{corrupt; wicked, to hate; to dislike, (same as 猜) to be jealous and suspicious, cunning; crafty}
3953 CJK UNIFIED IDEOGRAPH-#3953, IRGKangXi=0391.040, Def{happy; contented; pleased, fragile, nearly; almost, cunning; crafty}
3954 CJK UNIFIED IDEOGRAPH-#3954, IRGKangXi=0391.100, Def{to move the mind; agitated; nervous; to start thinking}
3955 CJK UNIFIED IDEOGRAPH-#3955, IRGKangXi=0392.160, Def{(ancient form of 憐) to pity; to commiserate; to feel tender regard for}
3956 CJK UNIFIED IDEOGRAPH-#3956, IRGKangXi=0392.181, Def{red color}
3957 CJK UNIFIED IDEOGRAPH-#3957, IRGKangXi=0392.181
3958 CJK UNIFIED IDEOGRAPH-#3958, IRGKangXi=0392.181
3959 CJK UNIFIED IDEOGRAPH-#3959, IRGKangXi=0392.181
395A CJK UNIFIED IDEOGRAPH-#395A, IRGKangXi=0392.190, Def{melancholy; grievous; mournful; sad, to fear; to dread; to be scared of}
395B CJK UNIFIED IDEOGRAPH-#395B, IRGKangXi=0392.200, Def{with expedition; urgent; hasty, anxious; worried, respectfully serious; to take careful precautions; to do something in a serious manner, to love; to like; to be fond of; to be kind to}
395C CJK UNIFIED IDEOGRAPH-#395C, IRGKangXi=0392.280, Def{unsuccessful in one's career; to have not one's ambition fulfilled, generous; unselfish; liberal, uneasy; disturbed; not feeling at peace}
395D CJK UNIFIED IDEOGRAPH-#395D, IRGKangXi=0393.160, Def{to arouse to action; to encourage, to temper and grind; to train or discipline oneself (toward a goal); to sharpen (a knife); to forge to harden, (same as 弭) to stop; to end; to eliminate}
395E CJK UNIFIED IDEOGRAPH-#395E, IRGKangXi=0393.230, Def{to think deeply, to think far ahead, profound and abstruse thinking, careful deliberations; to think and contemplate thoroughly}
395F CJK UNIFIED IDEOGRAPH-#395F, IRGKangXi=0393.240, Def{enmity; animus; ill-will}
3960 CJK UNIFIED IDEOGRAPH-#3960, IRGKangXi=0394.020, Def{(same as 諝) intelligence; brilliance, shrewdness; cunning; quick-witted and full of tricks; tricky}
3961 CJK UNIFIED IDEOGRAPH-#3961, IRGKangXi=0394.090, Def{idle; shiftless}
3962 CJK UNIFIED IDEOGRAPH-#3962, IRGKangXi=0394.110, Def{bad; evil; wicked; vice, overbearing; haughty, melancholy; depressed; dejected; cheerless; despondent, considerations; contemplations; to think carefully; to turn over and over in the mind}
3963 CJK UNIFIED IDEOGRAPH-#3963, IRGKangXi=0394.150, Def{(ancient form of 惠) to benefit; to profit; to favor, kind; benevolent; gracious; gentle}
3964 CJK UNIFIED IDEOGRAPH-#3964, IRGKangXi=0394.340, Def{(non-classical form of 矜) to pity; to feel for, to have compassion on, sympathetic}
3965 CJK UNIFIED IDEOGRAPH-#3965, IRGKangXi=0395.110, Def{absent-minded; unconscious, happy; glad; joyous}
3966 CJK UNIFIED IDEOGRAPH-#3966, IRGKangXi=0395.170, Def{(a variant of 愜) satisfied; contented; cheerful, appropriate; fitting; apposite, to have one's heart won; to summit; admire, etc. sincerely and willingly}
3967 CJK UNIFIED IDEOGRAPH-#3967, IRGKangXi=0395.230, Def{(ancient form of 順) to follow; to obedient; agreeable; favorable, convenient; smooth}
3968 CJK UNIFIED IDEOGRAPH-#3968, IRGKangXi=0395.290, Def{unhappy displeased, anger; rage; angry; furious}
3969 CJK UNIFIED IDEOGRAPH-#3969, IRGKangXi=0396.020, Def{idle; lazy; slothful; inactive}
396A CJK UNIFIED IDEOGRAPH-#396A, IRGKangXi=0396.071, Def{(simplied form of 慺) diligent; industrious; sedulous, to encourage; to make efforts}
396B CJK UNIFIED IDEOGRAPH-#396B, IRGKangXi=0396.071, Def{(a variant of 惇) honest; sincere; kind; generous}
396C CJK UNIFIED IDEOGRAPH-#396C, IRGKangXi=0396.190, Def{fear; dread; fright; scare}
396D CJK UNIFIED IDEOGRAPH-#396D, IRGKangXi=0396.200, Def{luxury; waste; wasteful; prodigal; extravagant}
396E CJK UNIFIED IDEOGRAPH-#396E, IRGKangXi=0396.240, Def{obstinate; stubborn; opinionated; obstinacy; stubbornness; intransigent, truculent; savage, ferocious; fierce}
396F CJK UNIFIED IDEOGRAPH-#396F, IRGKangXi=0396.260, Def{careful; compassionate; to take an interest in; prudent; cautious, worried and grieved}
3970 CJK UNIFIED IDEOGRAPH-#3970, IRGKangXi=0396.290, Def{mournful; melancholy; distressed; grieved; sad}
3971 CJK UNIFIED IDEOGRAPH-#3971, IRGKangXi=0396.310, Def{(same as 悱) to be desirous of speaking; inarticulate; unable to give vent to one's emotion, sorrowful}
3972 CJK UNIFIED IDEOGRAPH-#3972, IRGKangXi=0397.010, Def{(same as 謓) anger; rage; angry; furious, (ancient form 慎) cautious; careful; scrupulous; prudent}
3973 CJK UNIFIED IDEOGRAPH-#3973, IRGKangXi=0397.070, Def{to survey; to measure; mensuration}
3974 CJK UNIFIED IDEOGRAPH-#3974, IRGKangXi=0397.090, Def{do not care about something; disregard, to be ashamed}
3975 CJK UNIFIED IDEOGRAPH-#3975, IRGKangXi=0397.120, Def{(a variant of 慁) to dishonour; to disgrace; to distress, grief; shame; to disobey, to be anxious; to be apprehensive; to worry, to disturb or to agitate; to harass, confused and disorderly}
3976 CJK UNIFIED IDEOGRAPH-#3976, IRGKangXi=0397.130, Def{(same as 塞) (same as 愆) to fill up; full of; filled with; rich in contents; abundance, a fault; a mistake, to exceed; to be more than, to surpass}
3977 CJK UNIFIED IDEOGRAPH-#3977, IRGKangXi=0398.010, Def{(same as 瘱) quiet; calm; still peaceful, gracefully quiet, clear and evident; obvious, deep and far; profound and abstruse, to conceal; to hide}
3978 CJK UNIFIED IDEOGRAPH-#3978, IRGKangXi=0398.060, Def{(ancient form of 愍) to sympathize with; to pity; to grieve; to commiserate}
3979 CJK UNIFIED IDEOGRAPH-#3979, IRGKangXi=0398.210, Def{to move}
397A CJK UNIFIED IDEOGRAPH-#397A, IRGKangXi=0398.261, Def{(same as 熆) to blow a fire}
397B CJK UNIFIED IDEOGRAPH-#397B, IRGKangXi=0398.261
397C CJK UNIFIED IDEOGRAPH-#397C, IRGKangXi=0398.360, Def{to be near to, close to, to recollect; to recall; to look back upon}
397D CJK UNIFIED IDEOGRAPH-#397D, IRGKangXi=0398.410, Def{feeling; emotion, fact, love; affection, nature; reason, (same as 責) one's duty, responsibility; obligation, etc., to demand; to punish, to upbraid}
397E CJK UNIFIED IDEOGRAPH-#397E, IRGKangXi=0399.050, Def{mortified; ashamed}
397F CJK UNIFIED IDEOGRAPH-#397F, IRGKangXi=0399.090, Def{(same as 慠) proud; haughty; over bearing rude}
3980 CJK UNIFIED IDEOGRAPH-#3980, IRGKangXi=0399.250, Def{joy; delight; gratification}
3981 CJK UNIFIED IDEOGRAPH-#3981, IRGKangXi=0399.260, Def{to sob; to weep, to pay attention, to be careful; to take care; to exercise caution}
3982 CJK UNIFIED IDEOGRAPH-#3982, IRGKangXi=0399.300, Def{(ancient form of 常) constantly, frequently, usually habitually, regular, common, a rule, a principle}
3983 CJK UNIFIED IDEOGRAPH-#3983, IRGKangXi=0400.090, Def{perfect personal character, many; much; plenty; lots of}
3984 CJK UNIFIED IDEOGRAPH-#3984, IRGKangXi=0400.100, Def{hard to say or predict, difficult to speak out (for fear of embarrassing or paining others, etc.) not easy to express with words}
3985 CJK UNIFIED IDEOGRAPH-#3985, IRGKangXi=0401.010, Def{(same as 慸) uneasy; feeling uneasy or uncomfortable; not feeling at peace}
3986 CJK UNIFIED IDEOGRAPH-#3986, IRGKangXi=0401.050, Def{to exaggerate; exaggeration, arrogant; showing wild imagination; preposterously fantastic, without ambition; discourage}
3987 CJK UNIFIED IDEOGRAPH-#3987, IRGKangXi=0401.160, Def{a peaceful or easy mood; calm at mind, to move; to turn the mind, conversion}
3988 CJK UNIFIED IDEOGRAPH-#3988, IRGKangXi=0401.391
3989 CJK UNIFIED IDEOGRAPH-#3989, IRGKangXi=0401.410, Def{(ancient form of 懿) virtuous, especially women, admirable; esteemed; excellent}
398A CJK UNIFIED IDEOGRAPH-#398A, IRGKangXi=0401.420, Def{lavish; luxurious, wasteful}
398B CJK UNIFIED IDEOGRAPH-#398B, IRGKangXi=0402.060, Def{absurd; wild; nonsensical; showing wild imagination; preposterously fantastic}
398C CJK UNIFIED IDEOGRAPH-#398C, IRGKangXi=0402.090, Def{keen or sharp; clever; simple and honest, sound sleep or slumber; a deep sleep, to wake up from sleep}
398D CJK UNIFIED IDEOGRAPH-#398D, IRGKangXi=0402.100, Def{(same as 愕) to be startled, alarmed, to speak out; to speak up, frank statement, an obstacle or hindrance; to obstruct; to impede; unwilling; disagreeable}
398E CJK UNIFIED IDEOGRAPH-#398E, IRGKangXi=0402.260, Def{cantankerous; perverse, stupid; dull, ignorant, to divide clearly; without ambiguity, gracefully quiet}
398F CJK UNIFIED IDEOGRAPH-#398F, IRGKangXi=0403.100, Def{weak; feeble, joy; delight; gratification}
3990 CJK UNIFIED IDEOGRAPH-#3990, IRGKangXi=0403.230, Def{a straightforward character, cannot make up one's mind; to hesitate}
3991 CJK UNIFIED IDEOGRAPH-#3991, IRGKangXi=0403.250, Def{anger; rage; angry; furious, silly; stupid; foolish}
3992 CJK UNIFIED IDEOGRAPH-#3992, IRGKangXi=0403.340, Def{to deceived, loquacious}
3993 CJK UNIFIED IDEOGRAPH-#3993, IRGKangXi=0403.350, Def{difficult intention, difficult idea or sentiment, weakened volition; dejected, fear; scare; fright}
3994 CJK UNIFIED IDEOGRAPH-#3994, IRGKangXi=0404.090, Def{(same as 懕) sickly, in poor health, undisturbed; composed; calm; quiet, to satisfy or be satisfied to gratify or be gratified; (same as 厭) content; gratification}
3995 CJK UNIFIED IDEOGRAPH-#3995, IRGKangXi=0404.160, Def{thought; idea; sentiment, intention, expectation, meaning}
3996 CJK UNIFIED IDEOGRAPH-#3996, IRGKangXi=0404.301, Def{(same as 懣) resentful; sullen; sulky; anger (especially at injustice) indignant, annoyed; depressed; bored}
3997 CJK UNIFIED IDEOGRAPH-#3997, IRGKangXi=0405.030, Def{diligent; sedulous; industrious, with a strong will power}
3998 CJK UNIFIED IDEOGRAPH-#3998, IRGKangXi=0405.070, Def{(same as 憿) swift; rapid; quick; fast, by luck or chance}
3999 CJK UNIFIED IDEOGRAPH-#3999, IRGKangXi=0406.141
399A CJK UNIFIED IDEOGRAPH-#399A, IRGKangXi=0406.200, Def{melancholy; grievous; mournful, urgent; pressing}
399B CJK UNIFIED IDEOGRAPH-#399B, IRGKangXi=0406.250, Def{to walk in a composed (comfortable) way, respectful; reverent}
399C CJK UNIFIED IDEOGRAPH-#399C, IRGKangXi=0406.280, Def{to move the mind; agitated; nervous; to start thinking, melancholy; grievous; mournful, (same as 驚) to surprise; to amaze, afraid; scared; terrified; fearful}
399D CJK UNIFIED IDEOGRAPH-#399D, IRGKangXi=0406.440, Def{beautiful; pretty, good; excellent, to usurp; to outrage, to draw; to sketch}
399E CJK UNIFIED IDEOGRAPH-#399E, IRGKangXi=0407.030, Def{(same as 懤) grieved; pained; in deep grief; to lament deeply}
399F CJK UNIFIED IDEOGRAPH-#399F, IRGKangXi=0407.050, Def{intelligent; astute; clever}
39A0 CJK UNIFIED IDEOGRAPH-#39A0, IRGKangXi=0407.161
39A1 CJK UNIFIED IDEOGRAPH-#39A1, IRGKangXi=0407.310, Def{(non-classical form of 樂) happy; glad, joyful, cheerful; elated; content; delighted; pleased; willing, enjoyable}
39A2 CJK UNIFIED IDEOGRAPH-#39A2, IRGKangXi=0407.470, Def{pure; virtuous; devotion; dedication, to have bearings; to have manners}
39A3 CJK UNIFIED IDEOGRAPH-#39A3, IRGKangXi=0407.560, Def{to talk in one's sleep}
39A4 CJK UNIFIED IDEOGRAPH-#39A4, IRGKangXi=0408.050, Def{virtuous, especially of women, admirable, esteemed, excellent}
39A5 CJK UNIFIED IDEOGRAPH-#39A5, IRGKangXi=0408.130, Def{(same as 愋) talented; intelligent; wise wisdom; knowledge, to resent; to hate, to regret}
39A6 CJK UNIFIED IDEOGRAPH-#39A6, IRGKangXi=0408.140, Def{apprehensive; fearful; afraid, ashamed, uneasy in mind; not feeling at peace; disturbed}
39A7 CJK UNIFIED IDEOGRAPH-#39A7, IRGKangXi=0408.291, Def{(same as U+61AF 憯 U+6158 慘) sad; sorrowful; grieved; miserable; tragic}
39A8 CJK UNIFIED IDEOGRAPH-#39A8, IRGKangXi=0408.310, Def{(same as 嬾) lazy; indolent; idle; inactive; reluctant; disinclined}
39A9 CJK UNIFIED IDEOGRAPH-#39A9, IRGKangXi=0408.350, Def{melancholy; grievous; mournful; to feel sorrow or grief; to grieve; to mourn; to be sad, prudent; cautious}
39AA CJK UNIFIED IDEOGRAPH-#39AA, IRGKangXi=0408.421, Def{complaint; grudge; unjust}
39AB CJK UNIFIED IDEOGRAPH-#39AB, IRGKangXi=0409.070, Def{lax and crude; idle and remiss}
39AC CJK UNIFIED IDEOGRAPH-#39AC, IRGKangXi=0409.130, Def{ashamed; abashed; mortified; humiliated, few; little scarce; rare}
39AD CJK UNIFIED IDEOGRAPH-#39AD, IRGKangXi=0409.300, Def{(same as 憐 怜) to pity; to have compassion on; to sympathize}
39AE CJK UNIFIED IDEOGRAPH-#39AE, IRGKangXi=0411.091, Def{(abbreviated form of 錢) money; cash, a unit of weight, a Chinese family name}
39AF CJK UNIFIED IDEOGRAPH-#39AF, IRGKangXi=0412.081, Def{(same as 或) a certain; some, perhaps; probably; maybe, or}
39B0 CJK UNIFIED IDEOGRAPH-#39B0, IRGKangXi=0412.110, Def{to break off (relations); to sever, to exterminate; to annihilate; to wipe out, to pierce; to stab; to irritate; to hurt, to hold weapons, agricultural implements; far tools, sharp will; eager intention; determination}
39B1 CJK UNIFIED IDEOGRAPH-#39B1, IRGKangXi=0412.221
39B2 CJK UNIFIED IDEOGRAPH-#39B2, IRGKangXi=0412.221, Def{(non-classical form of 哉) a particle expressing surprise, admiration, or grief, an expletive}
39B3 CJK UNIFIED IDEOGRAPH-#39B3, IRGKangXi=0412.291
39B4 CJK UNIFIED IDEOGRAPH-#39B4, IRGKangXi=0412.300, Def{to arrest; to catch; to seize, to brawl; a hand-to-hand fight; to struggle for; to fight for, to beat; to strike; to attack}
39B5 CJK UNIFIED IDEOGRAPH-#39B5, IRGKangXi=0412.310, Def{to kill; to put to death; to slaughter; to execute, to punish, to weed out; to exterminate, a kind of weapon}
39B6 CJK UNIFIED IDEOGRAPH-#39B6, IRGKangXi=0412.350, Def{repeatedly; frequently; to alternate, common; ordinary; normal, sharp, name of a state in ancient China, bold; brave; fierce; violent; severe; strict; stringent}
39B7 CJK UNIFIED IDEOGRAPH-#39B7, IRGKangXi=0413.020, Def{(ancient form of 勇) brave; courageous; bold; valiant; fearless; gallant; heroic}
39B8 CJK UNIFIED IDEOGRAPH-#39B8, IRGKangXi=0413.141, Def{a lance with two points, a halberd with a crescent -shaped blade; weapons used in ancient times, to stimulate; to provoke; to excite; to irritate, to point with the index finger and the middle finger; to describe angry or an awe-inspiring display of military force, etc., masculine; heroic; brave}
39B9 CJK UNIFIED IDEOGRAPH-#39B9, IRGKangXi=0413.190, Def{a spear; a lance; a javelin, a battle-axe; a halberd}
39BA CJK UNIFIED IDEOGRAPH-#39BA, IRGKangXi=0413.280, Def{a lance with two points, a halberd with a crescent-shaped blade; weapons used in ancient times, to stimulate; to provoke; to excite; to irritate, to point with the index finger and the middle finger; to describe angry or an awe-inspiring display of military force, etc., masculine; heroic; brave, (in general) sharp points and edges of weapons}
39BB CJK UNIFIED IDEOGRAPH-#39BB, IRGKangXi=0413.380, Def{(ancient form of 襲) to put on; to wear, repeated; double; to inherit; to attack or take by surprise, to accord with; to unite}
39BC CJK UNIFIED IDEOGRAPH-#39BC, IRGKangXi=0414.010, Def{a wooden piles used as a cable to make immovable of a boat}
39BD CJK UNIFIED IDEOGRAPH-#39BD, IRGKangXi=0414.210, Def{with elegant appearance, with beautiful or gorgeous color; refined, learned and accomplished}
39BE CJK UNIFIED IDEOGRAPH-#39BE, IRGKangXi=0415.050, Def{(same as U+6245 扊) the bolt of a door; door latch}
39BF CJK UNIFIED IDEOGRAPH-#39BF, IRGKangXi=0415.090, Def{a window, a small door, (ancient form 戶) a door, a household}
39C0 CJK UNIFIED IDEOGRAPH-#39C0, IRGKangXi=0415.140, Def{the bolt of a door; door latch}
39C1 CJK UNIFIED IDEOGRAPH-#39C1, IRGKangXi=0415.190, Def{to close, shut the door with a bang, to soar, (ancient form 闔) a Chinese family name}
39C2 CJK UNIFIED IDEOGRAPH-#39C2, IRGKangXi=0416.060, Def{(same as 屇) a cave a hold in the ground; a hole}
39C3 CJK UNIFIED IDEOGRAPH-#39C3, IRGKangXi=0417.040, Def{(ancient form of 收) to receive what is due; to gather together, to harvest, to collect; to put away, to close, to bind, to restrain, to bring to the end, (same as 摎) entwined -- as branches of a tree; to tangle; to involve, to collaborate; to band together}
39C4 CJK UNIFIED IDEOGRAPH-#39C4, IRGKangXi=0417.080, Def{to take; to receive; to fetch; to take hold of}
39C5 CJK UNIFIED IDEOGRAPH-#39C5, IRGKangXi=0417.131, Def{to turn upside down; to exert a great deal; to pull and drag, to implicate or involve}
39C6 CJK UNIFIED IDEOGRAPH-#39C6, IRGKangXi=0417.150, Def{to cover something with a piece of cloth, a kind of cloth used to cover something}
39C7 CJK UNIFIED IDEOGRAPH-#39C7, IRGKangXi=0417.190, Def{to hold; to grasp, to maintain; to support; to keep; to uphold, a tie or stalemate}
39C8 CJK UNIFIED IDEOGRAPH-#39C8, IRGKangXi=0418.090, Def{(same as 引) to pull; to attract, to guide, to introduce, to quote, to retire}
39C9 CJK UNIFIED IDEOGRAPH-#39C9, IRGKangXi=0418.180, Def{to rub; to grind; to polish; to wear, to take; to obtain; to select, to beat; to strike; to attack}
39CA CJK UNIFIED IDEOGRAPH-#39CA, IRGKangXi=0418.220, Def{to push; to expel, to shirk; to decline, to row, to wipe and clean, to strike; to beat, to be rampant in defiance of authority}
39CB CJK UNIFIED IDEOGRAPH-#39CB, IRGKangXi=0419.080, Def{to lengthen and extenuate -- as in making noodle; to drag out}
39CC CJK UNIFIED IDEOGRAPH-#39CC, IRGKangXi=0420.080, Def{(same as 毛 芼) to select; to choose; to pick out}
39CD CJK UNIFIED IDEOGRAPH-#39CD, IRGKangXi=0420.130, Def{(same as 仿) alike; similar, (same as 搒) to involve; to affect}
39CE CJK UNIFIED IDEOGRAPH-#39CE, IRGKangXi=0421.030, Def{forked branches, stone roller, to roll, to stop; to detain; to prohibit, to clutch; to grasp}
39CF CJK UNIFIED IDEOGRAPH-#39CF, IRGKangXi=0422.121, Def{(a simplified form of 掆) to carry on the shoulders of two or more men, to raise}
39D0 CJK UNIFIED IDEOGRAPH-#39D0, IRGKangXi=0422.121, Def{(simplified form of 㩳) to hold; to grasp, to detain, to uphold, to push, to stand upright}
39D1 CJK UNIFIED IDEOGRAPH-#39D1, IRGKangXi=0422.121, Def{(a simplified form 撝) to wave, to assist}
39D2 CJK UNIFIED IDEOGRAPH-#39D2, IRGKangXi=0423.030, Def{to beat; to strike, to throw; to pitch, to scoop out to dig out}
39D3 CJK UNIFIED IDEOGRAPH-#39D3, IRGKangXi=0423.070, Def{to lead; to guide, to entice, to introduce, to draw out; to stretch, to beat; to strike}
39D4 CJK UNIFIED IDEOGRAPH-#39D4, IRGKangXi=0424.110, Def{to disturbe; to agitate; to harass, to quarrel; to wrangle}
39D5 CJK UNIFIED IDEOGRAPH-#39D5, IRGKangXi=0424.150, Def{to feel or touch with hands; to hold, to lay the hand on, to cover}
39D6 CJK UNIFIED IDEOGRAPH-#39D6, IRGKangXi=0424.200, Def{to clutch; to grasp}
39D7 CJK UNIFIED IDEOGRAPH-#39D7, IRGKangXi=0425.040, Def{to catch, to grasp with the hand, to pinch, to kill, to attach from the sideway, to strike with the hand; (Cant.) to tear, rip}
39D8 CJK UNIFIED IDEOGRAPH-#39D8, IRGKangXi=0425.060, Def{to accumulate, to massage the cheeks}
39D9 CJK UNIFIED IDEOGRAPH-#39D9, IRGKangXi=0426.060, Def{to give a playful blow, to strike against, to wring; to wrench; to twist, to turn for the better}
39DA CJK UNIFIED IDEOGRAPH-#39DA, IRGKangXi=0427.161, Def{(a dialect character) cup the hand, (corrupted form of U+65CA 瓬) clay pottery; earthenware}
39DB CJK UNIFIED IDEOGRAPH-#39DB, IRGKangXi=0427.161, Def{(simplied form of 掔) thick; firm; substantial, to drag along; to pull, to lead}
39DC CJK UNIFIED IDEOGRAPH-#39DC, IRGKangXi=0427.161, Def{(same as U+64F8 擸) to hold, to grasp, to hold the hair; to pull at; (Cant.) to take at a glance}
39DD CJK UNIFIED IDEOGRAPH-#39DD, IRGKangXi=0427.161, Def{to take}
39DE CJK UNIFIED IDEOGRAPH-#39DE, IRGKangXi=0427.161
39DF CJK UNIFIED IDEOGRAPH-#39DF, IRGKangXi=0427.161, Def{(simplified form of 擓) to wipe; to scrub; to rub, to dust; to clean, (a dialect) to scratch with fingers lightly, (a dialect) to carry on the arm}
39E0 CJK UNIFIED IDEOGRAPH-#39E0, IRGKangXi=0427.161
39E1 CJK UNIFIED IDEOGRAPH-#39E1, IRGKangXi=0428.010, Def{to move; to shake; to rock; to excite, to decrease; to reduce; to diminish; to subtract; to deduct, to shoulder; to take upon on oneself}
39E2 CJK UNIFIED IDEOGRAPH-#39E2, IRGKangXi=0429.020, Def{to depend on; to lean to; to rely on; by means of, to follow the old or traditional (practices, customs, precedents, etc.), to receive and carry on; to continue; to succeed to}
39E3 CJK UNIFIED IDEOGRAPH-#39E3, IRGKangXi=0429.080, Def{to stop, to detain; to stay; to end; still; calm, only}
39E4 CJK UNIFIED IDEOGRAPH-#39E4, IRGKangXi=0429.120, Def{(non-classical form) to jump; to leap; to bounce; (in general) get angry and leave away, to bump; (Cant.) to poke, jab}
39E5 CJK UNIFIED IDEOGRAPH-#39E5, IRGKangXi=0429.130, Def{to nip with the fingers; to take a pinch; to take up as with tongs}
39E6 CJK UNIFIED IDEOGRAPH-#39E6, IRGKangXi=0429.190, Def{to strike; to beat; to attach, (same as 揈) to move; to shake; to wield}
39E7 CJK UNIFIED IDEOGRAPH-#39E7, IRGKangXi=0429.230, Def{(non-classical form of 梳) a comb; a coarse comb; to comb}
39E8 CJK UNIFIED IDEOGRAPH-#39E8, IRGKangXi=0429.240, Def{(ancient form of 扏) slow; gradual; tardy; leisurely, to delay; to put off; to defer}
39E9 CJK UNIFIED IDEOGRAPH-#39E9, IRGKangXi=0429.250, Def{to dispel, to move; to transfer, to issue; to set aside, to stir up, turning}
39EA CJK UNIFIED IDEOGRAPH-#39EA, IRGKangXi=0430.040, Def{to ruin; to destroy; to break down, to hang up; to suspend}
39EB CJK UNIFIED IDEOGRAPH-#39EB, IRGKangXi=0430.080, Def{to hold; to grasp, to maintain; to keep, a post, to lead on, (same as 擩) to rub, to crumble by hand, to massage; mixed-up; confused}
39EC CJK UNIFIED IDEOGRAPH-#39EC, IRGKangXi=0430.110, Def{to raise; to fold the hands on the breast, to bow, to salute, a method (to pile or to raise up) of painting; (Cant.) to push from behind}
39ED CJK UNIFIED IDEOGRAPH-#39ED, IRGKangXi=0431.020, Def{to get something with both raising hands}
39EE CJK UNIFIED IDEOGRAPH-#39EE, IRGKangXi=0431.120, Def{high; tall; lofty}
39EF CJK UNIFIED IDEOGRAPH-#39EF, IRGKangXi=0431.171, Def{a bucket made of willow, (a dialect) to lift (especially when only a single person is involved)}
39F0 CJK UNIFIED IDEOGRAPH-#39F0, IRGKangXi=0427.161, Def{(a simplified form) to strike; to tap, to shock}
39F1 CJK UNIFIED IDEOGRAPH-#39F1, IRGKangXi=0431.171, Def{(same as U+62FF 拿) to bring, to take, to apprehend, to grasp}
39F2 CJK UNIFIED IDEOGRAPH-#39F2, IRGKangXi=0431.230, Def{to shake; to rattle}
39F3 CJK UNIFIED IDEOGRAPH-#39F3, IRGKangXi=0431.270, Def{to mix; to blend, to display in neat rows; to place in order}
39F4 CJK UNIFIED IDEOGRAPH-#39F4, IRGKangXi=0431.350, Def{to rub hands; to rub between the hands; to twist between the hands}
39F5 CJK UNIFIED IDEOGRAPH-#39F5, IRGKangXi=0432.060, Def{(corrupted form of U+638A 掊) to exact, to get salt from sea-water, to break up; to injure, to hold something in both hands; to scoop up mud; (Cant.) to hit, strike, knock}
39F6 CJK UNIFIED IDEOGRAPH-#39F6, IRGKangXi=0432.110, Def{the jingling of metals, to strike, to lead; to guide}
39F7 CJK UNIFIED IDEOGRAPH-#39F7, IRGKangXi=0432.200, Def{to wipe tears, to bind}
39F8 CJK UNIFIED IDEOGRAPH-#39F8, IRGKangXi=0433.220, Def{to hit; to beat; to strike; (Cant.) to drive away, chase}
39F9 CJK UNIFIED IDEOGRAPH-#39F9, IRGKangXi=0434.250, Def{to strike with fists, to strike; to blow}
39FA CJK UNIFIED IDEOGRAPH-#39FA, IRGKangXi=0434.290, Def{a finger wrapper; a covering (used to protect the fingers from getting hurt)}
39FB CJK UNIFIED IDEOGRAPH-#39FB, IRGKangXi=0434.300, Def{a thorn, to select; to pick, to push, to find out, to cut out; to engrave, sound of striking}
39FC CJK UNIFIED IDEOGRAPH-#39FC, IRGKangXi=0434.310, Def{to distribute, to scatter; to disperse}
39FD CJK UNIFIED IDEOGRAPH-#39FD, IRGKangXi=0435.020, Def{name of a county in Han dynasty; today's Inner Mongolia Autonomous Region; southeast of Baotou county}
39FE CJK UNIFIED IDEOGRAPH-#39FE, IRGKangXi=0435.040, Def{to strike, to bale out; to clean up}
39FF CJK UNIFIED IDEOGRAPH-#39FF, IRGKangXi=0435.110, Def{to bump; to knock against; to strike accidentally; to collide}
3A00 CJK UNIFIED IDEOGRAPH-#3A00, IRGKangXi=0435.170, Def{(same as 抦) to hold in the hand}
3A01 CJK UNIFIED IDEOGRAPH-#3A01, IRGKangXi=0436.080, Def{to throw; to pitch, to send, to stay, a crutch; staff or stick}
3A02 CJK UNIFIED IDEOGRAPH-#3A02, IRGKangXi=0436.090, Def{to beat; to strike; to attack}
3A03 CJK UNIFIED IDEOGRAPH-#3A03, IRGKangXi=0436.110, Def{a row; a line, to push; to clear out, (same as 朾) to bump; to knock against; to strike accidentally; to collide; (Cant.) to poke, nudge, stab; to stretch out}
3A04 CJK UNIFIED IDEOGRAPH-#3A04, IRGKangXi=0437.150, Def{to pierce; to stab, (same as 挑) to stir; to disturb; to agitate, to place the hand on, to impeach, (a dialect) to lift something heavy from one side or from the end}
3A05 CJK UNIFIED IDEOGRAPH-#3A05, IRGKangXi=0438.090, Def{inside; within; inner, a family name, (corrupted form of 抐) to take from the top, to strip; to peel}
3A06 CJK UNIFIED IDEOGRAPH-#3A06, IRGKangXi=0438.130, Def{to kill, to slaughter, to beat; to strike; to hit; to attack; (Cant.) to pile, stack}
3A07 CJK UNIFIED IDEOGRAPH-#3A07, IRGKangXi=0440.040, Def{(same as 搫) to sweep clean; to clean away, to eliminate}
3A08 CJK UNIFIED IDEOGRAPH-#3A08, IRGKangXi=0440.181, Def{(abbreviated form of 擠) to crowd; to throng; to push; to squeeze}
3A09 CJK UNIFIED IDEOGRAPH-#3A09, IRGKangXi=0440.240, Def{(same as U+62BF 抿) to smooth, to stroke; to pucker, to contract, to wipe away}
3A0A CJK UNIFIED IDEOGRAPH-#3A0A, IRGKangXi=0441.060, Def{to discard; to reject; to abandon, to feel; to stroke, to sort out the divining stalks, to drop; to lose; to fall off, to weigh; to measure weight}
3A0B CJK UNIFIED IDEOGRAPH-#3A0B, IRGKangXi=0441.080, Def{to beat; to strike; to attach}
3A0C CJK UNIFIED IDEOGRAPH-#3A0C, IRGKangXi=0441.180, Def{to milk a cow or goat}
3A0D CJK UNIFIED IDEOGRAPH-#3A0D, IRGKangXi=0441.190, Def{to defend, on a level with; even; equal, to help; to assist}
3A0E CJK UNIFIED IDEOGRAPH-#3A0E, IRGKangXi=0442.110, Def{to dye, to dip, to soak; to rub in the hands}
3A0F CJK UNIFIED IDEOGRAPH-#3A0F, IRGKangXi=0443.120, Def{to beat; to strike; to attack}
3A10 CJK UNIFIED IDEOGRAPH-#3A10, IRGKangXi=0443.160, Def{to slap lightly on the clothes or coverlet, to beat; to strike; to attack}
3A11 CJK UNIFIED IDEOGRAPH-#3A11, IRGKangXi=0443.190, Def{to count; to enumerate, to grasp the head}
3A12 CJK UNIFIED IDEOGRAPH-#3A12, IRGKangXi=0443.200, Def{(same as 刲) to cut open and clean -- as fish, to kill; to sacrifice, to stab}
3A13 CJK UNIFIED IDEOGRAPH-#3A13, IRGKangXi=0444.080, Def{(non-classical form) to close; to shut, to block up, to pull or drag out of the water; to fish up; to salvage}
3A14 CJK UNIFIED IDEOGRAPH-#3A14, IRGKangXi=0444.210, Def{to shake; to rock; to jolt; to joggle}
3A15 CJK UNIFIED IDEOGRAPH-#3A15, IRGKangXi=0445.030, Def{to shoulder; to take on the shoulder; to take upon oneself}
3A16 CJK UNIFIED IDEOGRAPH-#3A16, IRGKangXi=0445.060, RSKangXi=64.9, Def{to stab, to rob of money; to rob of riches, to go nonstop to, to cluster together; to mass; (Cant.) to squeeze in}
3A17 CJK UNIFIED IDEOGRAPH-#3A17, IRGKangXi=0445.341, Def{(variant of 捷) alert, nimble, prompt, clever, smart}
3A18 CJK UNIFIED IDEOGRAPH-#3A18, IRGKangXi=0445.341, Def{(same as U+64E4 擤) to blow the nose with the fingers; (Cant.) to scour; to rebuke; to hit with a ball}
3A19 CJK UNIFIED IDEOGRAPH-#3A19, IRGKangXi=0445.350, Def{to clasp or hold under the arm, to support; to prop up; to aid, to exchange; to alter, to lift up or off; to raise high}
3A1A CJK UNIFIED IDEOGRAPH-#3A1A, IRGKangXi=0445.410, Def{to select; to choose; to pick out, to defend; to ward off, to refuse; to reject}
3A1B CJK UNIFIED IDEOGRAPH-#3A1B, IRGKangXi=0446.010, Def{swift; rapid quick; speedy, (same as 掞) easy; smooth; suave; comfortable}
3A1C CJK UNIFIED IDEOGRAPH-#3A1C, IRGKangXi=0446.030, Def{to help each other, to shoulder; to take upon oneself}
3A1D CJK UNIFIED IDEOGRAPH-#3A1D, IRGKangXi=0446.090, Def{the very hard stuff, to sort out of divining stalks; (Cant.) to wedge in}
3A1E CJK UNIFIED IDEOGRAPH-#3A1E, IRGKangXi=0446.110, Def{to feel about; to grope in the dark}
3A1F CJK UNIFIED IDEOGRAPH-#3A1F, IRGKangXi=0446.130, Def{to touch; to contact, to ram; to butt}
3A20 CJK UNIFIED IDEOGRAPH-#3A20, IRGKangXi=0446.150, Def{(same as 塓) to smear; to daub; to spread, to paint}
3A21 CJK UNIFIED IDEOGRAPH-#3A21, IRGKangXi=0446.230, Def{to push with hands, to hold; to grasp, (in general) something as a whole; complete; undamaged}
3A22 CJK UNIFIED IDEOGRAPH-#3A22, IRGKangXi=0447.130, Def{to rip open flesh; to cut flesh; (Cant.) to join, link, connect}
3A23 CJK UNIFIED IDEOGRAPH-#3A23, IRGKangXi=0447.220
3A24 CJK UNIFIED IDEOGRAPH-#3A24, IRGKangXi=0448.090, Def{(same as 擓) to wipe; to scrub; to rub, to dust; to clean, (a dialect) to scratch with fingers lightly, (a dialect) to carry on the arm}
3A25 CJK UNIFIED IDEOGRAPH-#3A25, IRGKangXi=0448.140, Def{to hit; to strike}
3A26 CJK UNIFIED IDEOGRAPH-#3A26, IRGKangXi=0448.200, Def{(abbreviated form) to hold; to grasp, to detain, to uphold, to push, to stand upright}
3A27 CJK UNIFIED IDEOGRAPH-#3A27, IRGKangXi=0448.210, Def{wooden stick or bamboo cane (shaped segment of a circle) used to support the covering of a carriage in ancient times}
3A28 CJK UNIFIED IDEOGRAPH-#3A28, IRGKangXi=0448.340, Def{(the large seal; a type of Chinese calligraphy) to draw out; to sprout; to rid; to whip, to build, to thresh; to hull or unhusk, to beat; to pound; (Cant.) to shake down}
3A29 CJK UNIFIED IDEOGRAPH-#3A29, IRGKangXi=0448.370, Def{(non-classical form of 捷) to win; to triumph, swift; quick; rapid}
3A2A CJK UNIFIED IDEOGRAPH-#3A2A, IRGKangXi=0449.081, Def{to shake; to be disturbed; oscillating, brightness, dazzling; glaring}
3A2B CJK UNIFIED IDEOGRAPH-#3A2B, IRGKangXi=0449.081, Def{(same as U+652C 攬) to be in full possession of; to monopolize, to grasp; to seize}
3A2C CJK UNIFIED IDEOGRAPH-#3A2C, IRGKangXi=0449.081
3A2D CJK UNIFIED IDEOGRAPH-#3A2D, IRGKangXi=0449.190, Def{unreasonable, to distribute; to make known; to circulate, book cover; book jacket, letter; correspondence}
3A2E CJK UNIFIED IDEOGRAPH-#3A2E, IRGKangXi=0449.200, Def{to lift up; to take in the hand, to control, to open; (Cant.) to seize, grasp}
3A2F CJK UNIFIED IDEOGRAPH-#3A2F, IRGKangXi=0449.230, Def{(same as 擴) to enlarge; to magnify; to expand}
3A30 CJK UNIFIED IDEOGRAPH-#3A30, IRGKangXi=0449.240, Def{to turn; to shift; to move}
3A31 CJK UNIFIED IDEOGRAPH-#3A31, IRGKangXi=0449.330, Def{to shake, to wave, to row}
3A32 CJK UNIFIED IDEOGRAPH-#3A32, IRGKangXi=0449.350, Def{to back up; to support, to take; to receive; to obtain, to select; to choose}
3A33 CJK UNIFIED IDEOGRAPH-#3A33, IRGKangXi=0450.060, Def{(same as 庋) a cupboard; a closet, to put into a cupboard or closet; to put into the proper place, to wear on the head, to support; to sustain; to bear}
3A34 CJK UNIFIED IDEOGRAPH-#3A34, IRGKangXi=0450.130, Def{to turn over; to collapse; (Cant.) to lift (a lid); to uncover}
3A35 CJK UNIFIED IDEOGRAPH-#3A35, IRGKangXi=0450.160, Def{(non-classical form of 揃) to cut away; to cut off; to cut down; to eliminate; to remove; to exterminate}
3A36 CJK UNIFIED IDEOGRAPH-#3A36, IRGKangXi=0450.190, Def{(same as 搗 擣) to thresh; to hull or unhusk, to beat; to pound; to attack}
3A37 CJK UNIFIED IDEOGRAPH-#3A37, IRGKangXi=0450.200, Def{to wipe; to cleanse, (interchangeable 艱) difficult; distress; hardship}
3A38 CJK UNIFIED IDEOGRAPH-#3A38, IRGKangXi=0451.030, Def{to hit; to strike; to beat}
3A39 CJK UNIFIED IDEOGRAPH-#3A39, IRGKangXi=0451.040, Def{to crack; to break; to rip open, to split or divide up, to hang up; to suspend, to sweep clean; to eliminate}
3A3A CJK UNIFIED IDEOGRAPH-#3A3A, IRGKangXi=0451.170, Def{to ornament; to polish; to decorate, (same as 捫) to feel; to touch with hands; to hold, to search (in one's pocket, etc.)}
3A3B CJK UNIFIED IDEOGRAPH-#3A3B, IRGKangXi=0451.220, Def{to cut; to kill; to behead, gradually; little by little; by degrees, to lift; to raise, to strike; to beat, to throw; to pitch; to deliver}
3A3C CJK UNIFIED IDEOGRAPH-#3A3C, IRGKangXi=0452.090, Def{(non-classical form of U+63A0 掠) to take by force, to throw aside}
3A3D CJK UNIFIED IDEOGRAPH-#3A3D, IRGKangXi=0453.040, Def{to cut or rip open}
3A3E CJK UNIFIED IDEOGRAPH-#3A3E, IRGKangXi=0453.191, Def{a type; a model; a mode; a style}
3A3F CJK UNIFIED IDEOGRAPH-#3A3F, IRGKangXi=0453.191, Def{(a variant of 據) to receive, as communications from a subordinate, to rely on, to lean on, evidence; proof, according to; whereas}
3A40 CJK UNIFIED IDEOGRAPH-#3A40, IRGKangXi=0453.191, Def{(a variant of 據) to receive, as communications from a subordinate, to rely on, to lean on, evidence; proof, according to; whereas}
3A41 CJK UNIFIED IDEOGRAPH-#3A41, IRGKangXi=0453.191, Def{to knock, to pick out, to ridicule, (a variant) monopoly, a footbridge. a toll levied at a bridge or a ferry}
3A42 CJK UNIFIED IDEOGRAPH-#3A42, IRGKangXi=0453.191
3A43 CJK UNIFIED IDEOGRAPH-#3A43, IRGKangXi=0453.330, Def{to take or capture (a city, etc.), to gather or to collect}
3A44 CJK UNIFIED IDEOGRAPH-#3A44, IRGKangXi=0454.050, Def{to strike; to beat, to get scattered and lost}
3A45 CJK UNIFIED IDEOGRAPH-#3A45, IRGKangXi=0454.090, Def{(ancient form of U+62BD 抽) to draw out; to pull out; to take out, to sprout; to put forth shoots, to rid; to take away; to whip; (Cant.) to shake down}
3A46 CJK UNIFIED IDEOGRAPH-#3A46, IRGKangXi=0454.120, Def{to be in full possession of; to grasp, to beat cruelly; to beat brutally; to beat severely}
3A47 CJK UNIFIED IDEOGRAPH-#3A47, IRGKangXi=0454.130, Def{the thumb, to split; to tear apart, sound of ripping or tearing, to cut open with something sharp}
3A48 CJK UNIFIED IDEOGRAPH-#3A48, IRGKangXi=0454.140, Def{to restrain; restrained; timid and awkward; to feel not at home; miserably poor}
3A49 CJK UNIFIED IDEOGRAPH-#3A49, IRGKangXi=0455.150, Def{(same as 搨) to take a rubbing of an inscription on stone, etc., (same as 拉) to pull; to drag; to hold, to beat; to strike; to attack, (same as 拹) to break; to destroy; to smash}
3A4A CJK UNIFIED IDEOGRAPH-#3A4A, IRGKangXi=0455.160, Def{to pull up the sleeves and show the arms, to fight with bare hands, to desire for more than one's rightful share; to covet; greedy}
3A4B CJK UNIFIED IDEOGRAPH-#3A4B, IRGKangXi=0456.040, Def{to beat; to strike; to attack, sound of beating or hitting, a handle; a hold; to hold; to take, to guard; to watch over}
3A4C CJK UNIFIED IDEOGRAPH-#3A4C, IRGKangXi=0456.060, Def{to strike; to fight with hands, to scratch lightly; to brush; to shake; to dust, to knock down; to floor}
3A4D CJK UNIFIED IDEOGRAPH-#3A4D, IRGKangXi=0456.110, Def{to back up; to support, to take; to receive; to fetch; to obtain; to take hold of}
3A4E CJK UNIFIED IDEOGRAPH-#3A4E, IRGKangXi=0456.200, Def{(same as 擪) to press with a finger; to tuck in; to put the finger into; to put in; to stow away}
3A4F CJK UNIFIED IDEOGRAPH-#3A4F, IRGKangXi=0457.161
3A50 CJK UNIFIED IDEOGRAPH-#3A50, IRGKangXi=0457.161
3A51 CJK UNIFIED IDEOGRAPH-#3A51, IRGKangXi=0457.161
3A52 CJK UNIFIED IDEOGRAPH-#3A52, IRGKangXi=0457.280, Def{(same as U+64D2 擒) to arrest; to capture; (Cant.) to press down firmly}
3A53 CJK UNIFIED IDEOGRAPH-#3A53, IRGKangXi=0458.030, Def{to wound; to damage; to destroy; to injure}
3A54 CJK UNIFIED IDEOGRAPH-#3A54, IRGKangXi=0458.100, Def{a tool to make (crumble and to make smooth) a bow, to beat; to strike; to attack}
3A55 CJK UNIFIED IDEOGRAPH-#3A55, IRGKangXi=0458.270, Def{(same as 拎) to haul; to take; to lift, to raise}
3A56 CJK UNIFIED IDEOGRAPH-#3A56, IRGKangXi=0458.340, Def{to back up; to support}
3A57 CJK UNIFIED IDEOGRAPH-#3A57, IRGKangXi=0459.030, Def{(non-classical form of 攜) to lead by the hand, to conduct to; to take with}
3A58 CJK UNIFIED IDEOGRAPH-#3A58, IRGKangXi=0459.100, Def{(corrupted form of 檥) (interchangeable 艤) to moor to the bank}
3A59 CJK UNIFIED IDEOGRAPH-#3A59, IRGKangXi=0459.201, Def{(same as 塞) a cork or stopper; to cork; to seal, to fill up, to block}
3A5A CJK UNIFIED IDEOGRAPH-#3A5A, IRGKangXi=0460.010, Def{to collect (tax, grains), to draw together; to contract, to become less flagrant in behavior}
3A5B CJK UNIFIED IDEOGRAPH-#3A5B, IRGKangXi=0460.050, Def{(same as 摶) to roll round with the hand, to rely on, to take or follow (a trail, etc.)}
3A5C CJK UNIFIED IDEOGRAPH-#3A5C, IRGKangXi=0460.070, Def{(same as U+652C 攬) to be in possession of; to grasp, to make selective collection or coverage of; (Cant.) actually; strong}
3A5D CJK UNIFIED IDEOGRAPH-#3A5D, IRGKangXi=0460.190, Def{to compare; to estimate}
3A5E CJK UNIFIED IDEOGRAPH-#3A5E, IRGKangXi=0460.340, Def{(corrupted form) to back up; to support, to take; to receive; to fetch; to obtain; to take hold of; (Cant.) to throw, heave, fling away}
3A5F CJK UNIFIED IDEOGRAPH-#3A5F, IRGKangXi=0461.011, Def{(a dialect) to sew some ornaments (button; decorations, etc.) on the clothes}
3A60 CJK UNIFIED IDEOGRAPH-#3A60, IRGKangXi=0461.100, Def{a fierce or bloody battle, to untie; to unbind, (same as 捊) to exchange; to trade, to guide, to quote}
3A61 CJK UNIFIED IDEOGRAPH-#3A61, IRGKangXi=0461.120, Def{shake; to toss, to wave; to sway, to row}
3A62 CJK UNIFIED IDEOGRAPH-#3A62, IRGKangXi=0461.140, Def{to beat; to strike; to attack, to cut, to diminish, to decide; to udge, to weight; to measure, to wipe; to rub, to dust; to clean}
3A63 CJK UNIFIED IDEOGRAPH-#3A63, IRGKangXi=0461.170, Def{(same as 揮) to move; to shake; to wield; to direct, to arouse}
3A64 CJK UNIFIED IDEOGRAPH-#3A64, IRGKangXi=0461.230, Def{to open; to stretch; to extend; to display; to raise, to scatter; to spread, to stir; to get excited}
3A65 CJK UNIFIED IDEOGRAPH-#3A65, IRGKangXi=0461.250, Def{(non-classical form of 攕) delicate hand (of a woman)}
3A66 CJK UNIFIED IDEOGRAPH-#3A66, IRGKangXi=0461.320, Def{(same as 攜) to lead by the hand, to conduct to; to take with, a Chinese family name}
3A67 CJK UNIFIED IDEOGRAPH-#3A67, IRGKangXi=0462.010, Def{to strike; to beat; to knock; to stone (to throw stone and hit someone); sound of hitting something}
3A68 CJK UNIFIED IDEOGRAPH-#3A68, IRGKangXi=0462.060, Def{to crack; to break, to split or divide up, to rend; to rip open, to hand up; to suspend, to worry; to think of; anxious}
3A69 CJK UNIFIED IDEOGRAPH-#3A69, IRGKangXi=0462.070, Def{(a dialect) to come to an end; to terminate}
3A6A CJK UNIFIED IDEOGRAPH-#3A6A, IRGKangXi=0462.130, Def{(corrupted form of 擷) to collect; to take up; to pick; to gather}
3A6B CJK UNIFIED IDEOGRAPH-#3A6B, IRGKangXi=0462.161
3A6C CJK UNIFIED IDEOGRAPH-#3A6C, IRGKangXi=0462.170, Def{to beat; to strike; to attack}
3A6D CJK UNIFIED IDEOGRAPH-#3A6D, IRGKangXi=0462.250, Def{(non-classical form of 攪) to disturb or to agitate; to bother; to trouble, to stir; to churn; to mix evenly by stirring}
3A6E CJK UNIFIED IDEOGRAPH-#3A6E, IRGKangXi=0463.030, Def{to lift up or off; to raise high, to unveil}
3A6F CJK UNIFIED IDEOGRAPH-#3A6F, IRGKangXi=0463.040, Def{(same as 搫) to move; to transport, to collect; to gather; to make a clean sweep of}
3A70 CJK UNIFIED IDEOGRAPH-#3A70, IRGKangXi=0463.210, Def{to stab; to cut, (same as 摷) to attack against}
3A71 CJK UNIFIED IDEOGRAPH-#3A71, IRGKangXi=0463.240, Def{to select; to choose; to pick out, to lift; to carry on the shoulders -- of two or more men, to wipe out, to brush over lightly, to carry; to take or bring along at one's convenience, to cut; to par; to trim; to shave}
3A72 CJK UNIFIED IDEOGRAPH-#3A72, IRGKangXi=0463.260, Def{a fist, to clasp}
3A73 CJK UNIFIED IDEOGRAPH-#3A73, IRGKangXi=0463.280, Def{to hold; to grasp, to detain, to uphold, to push, to stand upright; expel, to shirk, to raise up}
3A74 CJK UNIFIED IDEOGRAPH-#3A74, IRGKangXi=0463.300, Def{to seize, as a bird of prey, to seize and carry off, to grasp}
3A75 CJK UNIFIED IDEOGRAPH-#3A75, IRGKangXi=0465.020, Def{to beat; to strike; to attack}
3A76 CJK UNIFIED IDEOGRAPH-#3A76, IRGKangXi=0465.040, Def{to hold; to grasp; to seize, to retain}
3A77 CJK UNIFIED IDEOGRAPH-#3A77, IRGKangXi=0465.051
3A78 CJK UNIFIED IDEOGRAPH-#3A78, IRGKangXi=0465.130, Def{(a variant) to pile on; to fold up, to draw together; to collect}
3A79 CJK UNIFIED IDEOGRAPH-#3A79, IRGKangXi=0465.141, Def{to pile on; to fold up}
3A7A CJK UNIFIED IDEOGRAPH-#3A7A, IRGKangXi=0467.070, Def{(a dialect) a crack on the utensil}
3A7B CJK UNIFIED IDEOGRAPH-#3A7B, IRGKangXi=0467.130, Def{rugged mountain path, very skinny, to pile on upon another; accumulation; to accumulate; (Cant.) exclamation}
3A7C CJK UNIFIED IDEOGRAPH-#3A7C, IRGKangXi=0467.150, Def{many; much, more than; over}
3A7D CJK UNIFIED IDEOGRAPH-#3A7D, IRGKangXi=0467.170, Def{parasitic branches on a tree, branches growing horizontally, (variant 勑) imperial orders}
3A7E CJK UNIFIED IDEOGRAPH-#3A7E, IRGKangXi=0467.200, Def{uneven, to hang down; to let fall}
3A7F CJK UNIFIED IDEOGRAPH-#3A7F, IRGKangXi=0468.140, Def{unstable, dull, rough; coarse}
3A80 CJK UNIFIED IDEOGRAPH-#3A80, IRGKangXi=0468.191, Def{to enter, to go ahead; to proceed; to advance, to improve, to offer}
3A81 CJK UNIFIED IDEOGRAPH-#3A81, IRGKangXi=0468.240, Def{to hold; to grasp; irregular; uneven, a precipice beneath an overhanging cliff, (same as 拑) to take by force; to control with threat of force; to coerce}
3A82 CJK UNIFIED IDEOGRAPH-#3A82, IRGKangXi=0469.110, Def{unstable, dull, rough; coarse}
3A83 CJK UNIFIED IDEOGRAPH-#3A83, IRGKangXi=0469.130, Def{to thump; to beat; to strike; to attack}
3A84 CJK UNIFIED IDEOGRAPH-#3A84, IRGKangXi=0469.160, Def{broken; to break, ruined, reason; cause; right, principle; theory, to arrange; to repair, to regulate; to operate; to govern}
3A85 CJK UNIFIED IDEOGRAPH-#3A85, IRGKangXi=0469.220, Def{(same as 更) to change, to alter}
3A86 CJK UNIFIED IDEOGRAPH-#3A86, IRGKangXi=0470.030, Def{hidden; mysterious; secret, to conceal}
3A87 CJK UNIFIED IDEOGRAPH-#3A87, IRGKangXi=0470.130, Def{to disseminate; to spread, the weak sound of a Chinese musical instrument with seven or five strings}
3A88 CJK UNIFIED IDEOGRAPH-#3A88, IRGKangXi=0470.140, Def{to let go, to put, to raid; to aggress, to encroach up, a bad year; a year of famine or disaster}
3A89 CJK UNIFIED IDEOGRAPH-#3A89, IRGKangXi=0470.291, Def{(ancient form 合) to combine; to unite; to gather, to close; to shut}
3A8A CJK UNIFIED IDEOGRAPH-#3A8A, IRGKangXi=0470.300, Def{infested with bandits and robbers}
3A8B CJK UNIFIED IDEOGRAPH-#3A8B, IRGKangXi=0470.310, Def{(same as 扞, 捍) to resist; to oppose; to obstruct, to defend; to guard; to ward off, (same as 㪃) to thump; to beat; to strike; to attack}
3A8C CJK UNIFIED IDEOGRAPH-#3A8C, IRGKangXi=0470.330, Def{to lead on; to advance, to strike against; to break through}
3A8D CJK UNIFIED IDEOGRAPH-#3A8D, IRGKangXi=0470.370, Def{(same as 勃) suddenly, to change, as the countenance, a kind of animal (interchangeable 悖) perverse; contrary to what is right, to rebel}
3A8E CJK UNIFIED IDEOGRAPH-#3A8E, IRGKangXi=0471.070, Def{uncertain; not yet settled, irregular, to raise one's hands, to exhaust; to use up, to complete; to finish, all; entirely; totally; completely}
3A8F CJK UNIFIED IDEOGRAPH-#3A8F, IRGKangXi=0472.070, Def{(interchangeable 捭) to ruin; to destroy; to break down, sound of beating or striking}
3A90 CJK UNIFIED IDEOGRAPH-#3A90, IRGKangXi=0472.090, Def{unstable, dull, rough; coarse}
3A91 CJK UNIFIED IDEOGRAPH-#3A91, IRGKangXi=0472.190, Def{to follow; to attach; connected}
3A92 CJK UNIFIED IDEOGRAPH-#3A92, IRGKangXi=0472.240, Def{to ruin; to destroy; to break down}
3A93 CJK UNIFIED IDEOGRAPH-#3A93, IRGKangXi=0472.310, Def{disaster; calamity, evil; wicked; mean}
3A94 CJK UNIFIED IDEOGRAPH-#3A94, IRGKangXi=0472.320, Def{(same as 散) to scatter; to disperse; to break up or separate for a time; to dismiss}
3A95 CJK UNIFIED IDEOGRAPH-#3A95, IRGKangXi=0473.060, Def{to beat; to pound; to strike; to rush on; to pat; to dash; to smash, to take by force; to wrest from}
3A96 CJK UNIFIED IDEOGRAPH-#3A96, IRGKangXi=0473.070, Def{sound of beating, to strike, sound of an object dropping into water, etc.}
3A97 CJK UNIFIED IDEOGRAPH-#3A97, IRGKangXi=0473.110, Def{(a dialect) to open (a parcel; abundle or a package); to unroll (a scroll, etc.); (Cant.) to rest, catch one's breath}
3A98 CJK UNIFIED IDEOGRAPH-#3A98, IRGKangXi=0473.171, Def{(abbreviated form of 斂) to draw together; to accumulate, to collect; to gather}
3A99 CJK UNIFIED IDEOGRAPH-#3A99, IRGKangXi=0473.171, Def{to go to the very source; to search into carefully}
3A9A CJK UNIFIED IDEOGRAPH-#3A9A, IRGKangXi=0473.171, Def{(same as 散) to scatter; to disperse; to break up or separate for a time; to dismiss}
3A9B CJK UNIFIED IDEOGRAPH-#3A9B, IRGKangXi=0473.210, Def{to pound rocks to pieces, (same as 抌) to strike; to strike with the fist}
3A9C CJK UNIFIED IDEOGRAPH-#3A9C, IRGKangXi=0473.220, Def{(same as 揣) to measure; to estimate; to suppose; to gauge what's pon another's mind; to presume; to test; to sound out, (same as 捶) to weigh in the hand}
3A9D CJK UNIFIED IDEOGRAPH-#3A9D, IRGKangXi=0474.030, Def{to beat, (same as 柬 揀) to select; to choose}
3A9E CJK UNIFIED IDEOGRAPH-#3A9E, IRGKangXi=0474.090, Def{to be held by the hand, to resist; to oppose}
3A9F CJK UNIFIED IDEOGRAPH-#3A9F, IRGKangXi=0474.130, Def{(same as 敦) to regard as important, to esteem, honest; sincere; generous}
3AA0 CJK UNIFIED IDEOGRAPH-#3AA0, IRGKangXi=0474.190, Def{(same as U+9D6E 鵮) to peck, poverty; poor, things of the same value, to take; to fetch; to obtain, to select; to choose, (of a bird) to peck}
3AA1 CJK UNIFIED IDEOGRAPH-#3AA1, IRGKangXi=0474.240, Def{to quell; to punish by force of arms, enemy; foe, to oppose; to resist}
3AA2 CJK UNIFIED IDEOGRAPH-#3AA2, IRGKangXi=0474.350, Def{(same as 捎) to beat; to strike; to attack, to be in full possession of; to grasp, to make selective collection or coverage of}
3AA3 CJK UNIFIED IDEOGRAPH-#3AA3, IRGKangXi=0474.401, Def{a place in Han dynasty, (same as U+6572 敲) to beat; to knock}
3AA4 CJK UNIFIED IDEOGRAPH-#3AA4, IRGKangXi=0474.420, Def{to finish; concluded}
3AA5 CJK UNIFIED IDEOGRAPH-#3AA5, IRGKangXi=0474.470, Def{to take; to receive; fetch; to obtain; to take hold of, to press with fingers, use the fingers to show the distance}
3AA6 CJK UNIFIED IDEOGRAPH-#3AA6, IRGKangXi=0474.500, Def{to beat; to pound; to ram down, to attack}
3AA7 CJK UNIFIED IDEOGRAPH-#3AA7, IRGKangXi=0475.130, Def{to beat; to strike; to attack}
3AA8 CJK UNIFIED IDEOGRAPH-#3AA8, IRGKangXi=0475.220, Def{to mend; to repair; to copy; to write out}
3AA9 CJK UNIFIED IDEOGRAPH-#3AA9, IRGKangXi=0475.230, Def{to strike; to beat, sound of beating}
3AAA CJK UNIFIED IDEOGRAPH-#3AAA, IRGKangXi=0475.321, Def{to use a wooden pole to support something; to raise, to begin; to start}
3AAB CJK UNIFIED IDEOGRAPH-#3AAB, IRGKangXi=0476.050, Def{(corrupted form of 叡) wise and clever, shrewd, discreet, astute, quick of perception, the divine sagacity of sages}
3AAC CJK UNIFIED IDEOGRAPH-#3AAC, IRGKangXi=0476.080, Def{to pierce; to stab; to hurt, to give; to hand over; to confer, to teach, to build, to pound (grain) in order to remove the husk}
3AAD CJK UNIFIED IDEOGRAPH-#3AAD, IRGKangXi=0476.200, Def{to draw together; to contract to fold, to collect; to gather, to hide; to conceal}
3AAE CJK UNIFIED IDEOGRAPH-#3AAE, IRGKangXi=0476.280, Def{to beat; to attack; to strike}
3AAF CJK UNIFIED IDEOGRAPH-#3AAF, IRGKangXi=0477.011, Def{(non-classical form of U+8209 舉) to lift; to raise; to commend; to praise, entire; whole}
3AB0 CJK UNIFIED IDEOGRAPH-#3AB0, IRGKangXi=0477.060, Def{(ancient form of 齋) to abstain from meat, wine, etc., to fast; penance}
3AB1 CJK UNIFIED IDEOGRAPH-#3AB1, IRGKangXi=0477.130, Def{elegant; coloured}
3AB2 CJK UNIFIED IDEOGRAPH-#3AB2, IRGKangXi=0478.011
3AB3 CJK UNIFIED IDEOGRAPH-#3AB3, IRGKangXi=0478.011
3AB4 CJK UNIFIED IDEOGRAPH-#3AB4, IRGKangXi=0478.030, Def{to measure; to estimate}
3AB5 CJK UNIFIED IDEOGRAPH-#3AB5, IRGKangXi=0478.040, Def{half of a unit of measurement used in ancient times}
3AB6 CJK UNIFIED IDEOGRAPH-#3AB6, IRGKangXi=0478.060, Def{(same as 斛) a dry measure 10 or 5 times that of a Chinese peck; a corn measure nominally holding ten pecks but generally holding about five, used in name of a place}
3AB7 CJK UNIFIED IDEOGRAPH-#3AB7, IRGKangXi=0478.130
3AB8 CJK UNIFIED IDEOGRAPH-#3AB8, IRGKangXi=0478.171, Def{(same as 斟) to fill a cup with; to pour into a cup}
3AB9 CJK UNIFIED IDEOGRAPH-#3AB9, IRGKangXi=0478.250, Def{to rob; to loot; to plunder}
3ABA CJK UNIFIED IDEOGRAPH-#3ABA, IRGKangXi=0479.010, Def{to bale out; to decant liquids, to pour out liquor, a feast, a kind of utensil used to ladle out water}
3ABB CJK UNIFIED IDEOGRAPH-#3ABB, IRGKangXi=0479.030, Def{a kind of utensil used to ladle out wine, a container that gives a measurement of rice}
3ABC CJK UNIFIED IDEOGRAPH-#3ABC, IRGKangXi=0479.130, Def{to pull; to dray; to hinder; to santch away}
3ABD CJK UNIFIED IDEOGRAPH-#3ABD, IRGKangXi=0479.151
3ABE CJK UNIFIED IDEOGRAPH-#3ABE, IRGKangXi=0479.160, Def{to cut the flesh from the bone; to scrape off; to pick out; to get rid of, to arrest; to catch to seize, to struggle; to fight; to conflict; to vie; to compete}
3ABF CJK UNIFIED IDEOGRAPH-#3ABF, IRGKangXi=0479.161, Def{to break; to snap; to bend; to bow down}
3AC0 CJK UNIFIED IDEOGRAPH-#3AC0, IRGKangXi=0480.091, Def{huge tripod of bronze with two ears; heavy three-legged caldron or sacrificial vessel regarded as a type of imperial power, the Empire, a kind of cooking utensil used in ancient times}
3AC1 CJK UNIFIED IDEOGRAPH-#3AC1, IRGKangXi=0480.170, Def{(non-classical form of 斷) to cut apart, to sever, to break; broken; to abstain from, to conclude}
3AC2 CJK UNIFIED IDEOGRAPH-#3AC2, IRGKangXi=0480.210, Def{to chop or cut (wood)}
3AC3 CJK UNIFIED IDEOGRAPH-#3AC3, IRGKangXi=0481.050, Def{flags flying, long bands or ribbons attached to flags, streamers, etc. (ancient form of 偃) to cease; to desist from}
3AC4 CJK UNIFIED IDEOGRAPH-#3AC4, IRGKangXi=0481.100, Def{(same as 旁) side, by the side of; nearby}
3AC5 CJK UNIFIED IDEOGRAPH-#3AC5, IRGKangXi=0482.090, Def{(same as 旗) a flag; a pennant; a banner; a streamer, a sign}
3AC6 CJK UNIFIED IDEOGRAPH-#3AC6, IRGKangXi=0482.101
3AC7 CJK UNIFIED IDEOGRAPH-#3AC7, IRGKangXi=0482.101
3AC8 CJK UNIFIED IDEOGRAPH-#3AC8, IRGKangXi=0482.101
3AC9 CJK UNIFIED IDEOGRAPH-#3AC9, IRGKangXi=0483.101
3ACA CJK UNIFIED IDEOGRAPH-#3ACA, IRGKangXi=0483.180, Def{fluttering of the flag, the flags}
3ACB CJK UNIFIED IDEOGRAPH-#3ACB, IRGKangXi=0484.081, Def{(non-classical form of 旃) a silken banner hanging from a staff bent over at the top}
3ACC CJK UNIFIED IDEOGRAPH-#3ACC, IRGKangXi=0484.081
3ACD CJK UNIFIED IDEOGRAPH-#3ACD, IRGKangXi=0484.190, Def{the scallops along the lower edge of a flag; the hanging decorations (ribbons, etc.) of a flag used in ancient times, a kind of flag}
3ACE CJK UNIFIED IDEOGRAPH-#3ACE, IRGKangXi=0484.300, Def{(same as 徽 揮) mark; sign; indication; flags; pennants, streamers, etc., to prance, to brandish, to shake; to rattle, name of a flag}
3ACF CJK UNIFIED IDEOGRAPH-#3ACF, IRGKangXi=0485.010, Def{a kind of flag, flags; streamers}
3AD0 CJK UNIFIED IDEOGRAPH-#3AD0, IRGKangXi=0489.110, Def{distant and indistinguishable}
3AD1 CJK UNIFIED IDEOGRAPH-#3AD1, IRGKangXi=0490.040, Def{(same as 旨) (non-classical form 時) purpose; will; intention; objective, good; excellent, a season; an era; time}
3AD2 CJK UNIFIED IDEOGRAPH-#3AD2, IRGKangXi=0490.090, Def{(same as 廾) hands joined, to support; to aid; to help, to lean upon}
3AD3 CJK UNIFIED IDEOGRAPH-#3AD3, IRGKangXi=0490.160, Def{(ancient form of 氣) air; vapor, breath, spirit; character, bearing; manner}
3AD4 CJK UNIFIED IDEOGRAPH-#3AD4, IRGKangXi=0490.220, Def{(same as 艮) one of the Eight Diagrams for divination}
3AD5 CJK UNIFIED IDEOGRAPH-#3AD5, IRGKangXi=0490.221, Def{(same as 光) light; brightness, glossy; glory; glorious}
3AD6 CJK UNIFIED IDEOGRAPH-#3AD6, IRGKangXi=0490.221
3AD7 CJK UNIFIED IDEOGRAPH-#3AD7, IRGKangXi=0490.221, Def{(same as 厚) thick, deep friendship, to treat kindly; generous}
3AD8 CJK UNIFIED IDEOGRAPH-#3AD8, IRGKangXi=0490.380, Def{disappeared, not supported by, to avoid, unable to see}
3AD9 CJK UNIFIED IDEOGRAPH-#3AD9, IRGKangXi=0491.190, Def{the sun}
3ADA CJK UNIFIED IDEOGRAPH-#3ADA, IRGKangXi=0502.080, RSKangXi=72.4, Def{early morning, daylight}
3ADB CJK UNIFIED IDEOGRAPH-#3ADB, IRGKangXi=0492.140, Def{light; bright; brilliant, clear, intelligent; day dawn}
3ADC CJK UNIFIED IDEOGRAPH-#3ADC, IRGKangXi=0493.180, Def{light; bright; brilliant, clear, intelligent; day dawn}
3ADD CJK UNIFIED IDEOGRAPH-#3ADD, IRGKangXi=0493.210, Def{the sun}
3ADE CJK UNIFIED IDEOGRAPH-#3ADE, IRGKangXi=0493.240, Def{of look of the sun, the look of the weather}
3ADF CJK UNIFIED IDEOGRAPH-#3ADF, IRGKangXi=0494.020, Def{day after day; daily, time, moving of the sun}
3AE0 CJK UNIFIED IDEOGRAPH-#3AE0, IRGKangXi=0494.120, Def{a kind of water}
3AE1 CJK UNIFIED IDEOGRAPH-#3AE1, IRGKangXi=0494.130, Def{(same as 冬) winter, (in lunar calendar) the period from the 10th to the 12th moon}
3AE2 CJK UNIFIED IDEOGRAPH-#3AE2, IRGKangXi=0494.181
3AE3 CJK UNIFIED IDEOGRAPH-#3AE3, IRGKangXi=0494.181
3AE4 CJK UNIFIED IDEOGRAPH-#3AE4, IRGKangXi=0494.181, Def{(a variant of 昶) a long day, bright, extended, clear}
3AE5 CJK UNIFIED IDEOGRAPH-#3AE5, IRGKangXi=0495.060, Def{(non-classical form of 冥) dark; obscure; dim}
3AE6 CJK UNIFIED IDEOGRAPH-#3AE6, IRGKangXi=0495.100, Def{of look of the sun, the look of the weather}
3AE7 CJK UNIFIED IDEOGRAPH-#3AE7, IRGKangXi=0495.030, Def{(non-classical form of 暴) violent; fierce; atrocious; cruel, sudden}
3AE8 CJK UNIFIED IDEOGRAPH-#3AE8, IRGKangXi=0495.241
3AE9 CJK UNIFIED IDEOGRAPH-#3AE9, IRGKangXi=0495.241, Def{(same as 春) the first of the four season -- spring, lustful, alive, joyful, youth}
3AEA CJK UNIFIED IDEOGRAPH-#3AEA, IRGKangXi=0495.241, Def{(non-classical form of 舂) to pound (grain) in order to remove the husk}
3AEB CJK UNIFIED IDEOGRAPH-#3AEB, IRGKangXi=0495.241, Def{(non-classical form of 顯) clear; evident; eminent; prominent; renowned; famed; to expose; to make known}
3AEC CJK UNIFIED IDEOGRAPH-#3AEC, IRGKangXi=0495.241
3AED CJK UNIFIED IDEOGRAPH-#3AED, IRGKangXi=0495.241
3AEE CJK UNIFIED IDEOGRAPH-#3AEE, IRGKangXi=0494.181
3AEF CJK UNIFIED IDEOGRAPH-#3AEF, IRGKangXi=0495.300, Def{in contravention of; to offend (a superior, elder, etc.) (same as 冒) incautious; rash; imprudent}
3AF0 CJK UNIFIED IDEOGRAPH-#3AF0, IRGKangXi=0495.320, Def{light; bright; brilliant; clean; clever, to expose to sunlight, to dry something in an opening for ventilation area or a cool place}
3AF1 CJK UNIFIED IDEOGRAPH-#3AF1, IRGKangXi=0495.410, Def{mild, damp and moist, red color}
3AF2 CJK UNIFIED IDEOGRAPH-#3AF2, IRGKangXi=0496.090, Def{dark; dull}
3AF3 CJK UNIFIED IDEOGRAPH-#3AF3, IRGKangXi=0496.140, Def{(same as 晨) morning; daybreak}
3AF4 CJK UNIFIED IDEOGRAPH-#3AF4, IRGKangXi=0496.180, Def{(corrupted form of 哮) to roar; to pant; to howl}
3AF5 CJK UNIFIED IDEOGRAPH-#3AF5, IRGKangXi=0496.250, Def{white color, (corrupted form of 腓) the calf of the legs}
3AF6 CJK UNIFIED IDEOGRAPH-#3AF6, IRGKangXi=0496.270, Def{light; bright}
3AF7 CJK UNIFIED IDEOGRAPH-#3AF7, IRGKangXi=0496.350, Def{behind; the back of; afterwards; to come after (same as 期) period; time, to expect; to hope}
3AF8 CJK UNIFIED IDEOGRAPH-#3AF8, IRGKangXi=0496.380, Def{sunset}
3AF9 CJK UNIFIED IDEOGRAPH-#3AF9, IRGKangXi=0497.080, Def{light; bright, warm, genial}
3AFA CJK UNIFIED IDEOGRAPH-#3AFA, IRGKangXi=0497.130, Def{(same as 昔) bygone; of old; formerly; ancient, at night, the end}
3AFB CJK UNIFIED IDEOGRAPH-#3AFB, IRGKangXi=0497.170, Def{sunlight}
3AFC CJK UNIFIED IDEOGRAPH-#3AFC, IRGKangXi=0497.180, Def{(same as 晢) clear, bright; glorious; to be sharp and perspicacious; able to examine the tiniest things}
3AFD CJK UNIFIED IDEOGRAPH-#3AFD, IRGKangXi=0497.210, Def{darkness; the sun is dimmed}
3AFE CJK UNIFIED IDEOGRAPH-#3AFE, IRGKangXi=0497.311
3AFF CJK UNIFIED IDEOGRAPH-#3AFF, IRGKangXi=0497.311
3B00 CJK UNIFIED IDEOGRAPH-#3B00, IRGKangXi=0497.311
3B01 CJK UNIFIED IDEOGRAPH-#3B01, IRGKangXi=0497.320, Def{the sun is shining on the water}
3B02 CJK UNIFIED IDEOGRAPH-#3B02, IRGKangXi=0498.050, Def{used in person's name}
3B03 CJK UNIFIED IDEOGRAPH-#3B03, IRGKangXi=0498.080, Def{sunrise}
3B04 CJK UNIFIED IDEOGRAPH-#3B04, IRGKangXi=0498.150, Def{warm and damp (moist; humid), a little warm}
3B05 CJK UNIFIED IDEOGRAPH-#3B05, IRGKangXi=0498.180, Def{(non-classical form of 曼) long, extended, large}
3B06 CJK UNIFIED IDEOGRAPH-#3B06, IRGKangXi=0498.210, Def{(same as 湣) posthumous title conferred upon emperors and eminent officials}
3B07 CJK UNIFIED IDEOGRAPH-#3B07, IRGKangXi=0498.220, Def{name of a state in ancient China, sharp, bright-colored; brightness; bright; radiance; light}
3B08 CJK UNIFIED IDEOGRAPH-#3B08, IRGKangXi=0498.230, Def{the sun was shining and it's warm}
3B09 CJK UNIFIED IDEOGRAPH-#3B09, IRGKangXi=0498.240, Def{(a variant of 暖) warm, genial, of weather, soft and tender, pleasant and genial}
3B0A CJK UNIFIED IDEOGRAPH-#3B0A, IRGKangXi=0498.250, Def{light; bright, clear, intelligent; clever}
3B0B CJK UNIFIED IDEOGRAPH-#3B0B, IRGKangXi=0498.311, Def{name of a star}
3B0C CJK UNIFIED IDEOGRAPH-#3B0C, IRGKangXi=0498.311, Def{sunshine; sunlight}
3B0D CJK UNIFIED IDEOGRAPH-#3B0D, IRGKangXi=0498.390, Def{fierce; cruel, sudden, a scorching heat}
3B0E CJK UNIFIED IDEOGRAPH-#3B0E, IRGKangXi=0498.540, Def{(an ancient form of 顯) motes in a sunbeam, bright, fibrous, to manifest; to display, to be illustrious, evident, to seem; to appear, cocoons; chrysalis, will not have a pleasant conversation}
3B0F CJK UNIFIED IDEOGRAPH-#3B0F, IRGKangXi=0499.010, Def{light; bright, clear, intelligent; clever}
3B10 CJK UNIFIED IDEOGRAPH-#3B10, IRGKangXi=0499.060, Def{(same as 晉) a state during the period of Spring and Autumn, (same as 鄑) name of a place in today's Shandong Province}
3B11 CJK UNIFIED IDEOGRAPH-#3B11, IRGKangXi=0499.361
3B12 CJK UNIFIED IDEOGRAPH-#3B12, IRGKangXi=0499.100, Def{the sun are dimmed; darkness}
3B13 CJK UNIFIED IDEOGRAPH-#3B13, IRGKangXi=0499.120, Def{to expose to sunlight; to sun}
3B14 CJK UNIFIED IDEOGRAPH-#3B14, IRGKangXi=0499.130, Def{to defy; to disobey; to disregard, to contradict, perverse; recalcitrant; irregular; abnormal}
3B15 CJK UNIFIED IDEOGRAPH-#3B15, IRGKangXi=0499.180, Def{(corrupted form) light; bright, clear}
3B16 CJK UNIFIED IDEOGRAPH-#3B16, IRGKangXi=0499.361
3B17 CJK UNIFIED IDEOGRAPH-#3B17, IRGKangXi=0499.380, Def{(same as 晛) sunshine; light; bright, warm; genial (weather), very hot}
3B18 CJK UNIFIED IDEOGRAPH-#3B18, IRGKangXi=0499.410, Def{arid; dry; parched, impatient; restless, fierce; cruel, sudden, a scorching heat}
3B19 CJK UNIFIED IDEOGRAPH-#3B19, IRGKangXi=0499.430, Def{sunshine; light of the sun}
3B1A CJK UNIFIED IDEOGRAPH-#3B1A, IRGKangXi=0499.460, Def{light; bright, clear}
3B1B CJK UNIFIED IDEOGRAPH-#3B1B, IRGKangXi=0499.470, Def{to dry in the sun}
3B1C CJK UNIFIED IDEOGRAPH-#3B1C, IRGKangXi=0500.010, Def{(same as 晉) to advance; to increase; to flourish}
3B1D CJK UNIFIED IDEOGRAPH-#3B1D, IRGKangXi=0500.050, Def{obscure; not bright; poor visibility, white; clear; bright; pure; plain}
3B1E CJK UNIFIED IDEOGRAPH-#3B1E, IRGKangXi=0500.251, Def{(non-classical form of 暍) sunstroke, hot; feverish}
3B1F CJK UNIFIED IDEOGRAPH-#3B1F, IRGKangXi=0504.091, Def{(a dialect), an adverb, negative expression; never before; to have not happened before}
3B20 CJK UNIFIED IDEOGRAPH-#3B20, IRGKangXi=0500.310, Def{(non-classical form of 曬) to expose to sunlight; to dry in the sun (interchangeable 煞) very; much; extremely; a fierce god; a malignant deity, to conclude}
3B21 CJK UNIFIED IDEOGRAPH-#3B21, IRGKangXi=0500.370, Def{(same as 昤) sunshine; light of the sun}
3B22 CJK UNIFIED IDEOGRAPH-#3B22, IRGKangXi=0500.420, Def{sunshine; sunlight; the light of day}
3B23 CJK UNIFIED IDEOGRAPH-#3B23, IRGKangXi=0501.010, Def{luxuriant; exuberant; lush; flourishing}
3B24 CJK UNIFIED IDEOGRAPH-#3B24, IRGKangXi=0501.030, Def{wet clothes not completely dry; to dry in the sun or use sand to dry up on the ground}
3B25 CJK UNIFIED IDEOGRAPH-#3B25, IRGKangXi=0501.090, Def{(an ancient form of 曝) to sun to air; to expose to sunlight, to expose or be exposed; exposure, a tree with scatter or dispersed leaves}
3B26 CJK UNIFIED IDEOGRAPH-#3B26, IRGKangXi=0501.100, Def{brave; courageous; bold; valiant; intrepid; fearless; heroic}
3B27 CJK UNIFIED IDEOGRAPH-#3B27, IRGKangXi=0501.131, Def{(standard form) a collar, the neck, to connect collars to the clothes}
3B28 CJK UNIFIED IDEOGRAPH-#3B28, IRGKangXi=0501.131
3B29 CJK UNIFIED IDEOGRAPH-#3B29, IRGKangXi=0501.170, Def{a tiny star, numerous stars}
3B2A CJK UNIFIED IDEOGRAPH-#3B2A, IRGKangXi=0501.210, Def{(a variant of 疊) to fold up, to repeat, to duplicate}
3B2B CJK UNIFIED IDEOGRAPH-#3B2B, IRGKangXi=0501.290, Def{clear sky, a fine day}
3B2C CJK UNIFIED IDEOGRAPH-#3B2C, IRGKangXi=0501.390, Def{a family name}
3B2D CJK UNIFIED IDEOGRAPH-#3B2D, IRGKangXi=0501.410, Def{(same as, non-classical form of 皭) pure white; clean; bright, usually used for person's name in ancient times}
3B2E CJK UNIFIED IDEOGRAPH-#3B2E, IRGKangXi=0501.450, Def{gentle; mild; temperate, tender; loving; caressing}
3B2F CJK UNIFIED IDEOGRAPH-#3B2F, IRGKangXi=0501.520, Def{sunset}
3B30 CJK UNIFIED IDEOGRAPH-#3B30, IRGKangXi=0502.030, Def{(non-classical form of 臾) a moment; an instant; a little while; a short time}
3B31 CJK UNIFIED IDEOGRAPH-#3B31, IRGKangXi=0504.090, Def{(same as 替) to replace; to substitute; to decay; to decline, (a variant 朁) if, supposing, nevertheless}
3B32 CJK UNIFIED IDEOGRAPH-#3B32, IRGKangXi=0504.110, Def{to increase; to add to; to augment, to a greater extent; more, benefit; profit; advantage}
3B33 CJK UNIFIED IDEOGRAPH-#3B33, IRGKangXi=0504.300, Def{light; bright, clear}
3B34 CJK UNIFIED IDEOGRAPH-#3B34, IRGKangXi=0505.120, Def{the moon is dimmed; darkness; the word used especially by Triad Society (三合會) a secret society during the Ching Dynasty dedicated to the overthrow of the Manchus and the restoration the Ming Dynasty}
3B35 CJK UNIFIED IDEOGRAPH-#3B35, IRGKangXi=0505.210, Def{the shinbone, or tibia, (same as 交) to intersect, the sun and the moon in the sky, (simpfied form 膠) glue; gum, resin; sap, anything sticky}
3B36 CJK UNIFIED IDEOGRAPH-#3B36, IRGKangXi=0506.010, Def{flesh; meat of animals, (same as 浩) great; vast, many; much}
3B37 CJK UNIFIED IDEOGRAPH-#3B37, IRGKangXi=0506.011
3B38 CJK UNIFIED IDEOGRAPH-#3B38, IRGKangXi=0506.150, Def{a kind of services or ceremonies of offering sacrifices}
3B39 CJK UNIFIED IDEOGRAPH-#3B39, IRGKangXi=0986.140, RSKangXi=130.8, Def{tendons of the heel of the foot; (Cant.) elbow, heel}
3B3A CJK UNIFIED IDEOGRAPH-#3B3A, IRGKangXi=0506.211
3B3B CJK UNIFIED IDEOGRAPH-#3B3B, IRGKangXi=0506.230, Def{in between of the flesh, a state of a minority ethnic group in southern China, the moon is dimmed}
3B3C CJK UNIFIED IDEOGRAPH-#3B3C, IRGKangXi=0506.281, Def{to have; to be present; to exist; there is}
3B3D CJK UNIFIED IDEOGRAPH-#3B3D, IRGKangXi=0506.281
3B3E CJK UNIFIED IDEOGRAPH-#3B3E, IRGKangXi=0506.281
3B3F CJK UNIFIED IDEOGRAPH-#3B3F, IRGKangXi=0506.290, Def{moonlight}
3B40 CJK UNIFIED IDEOGRAPH-#3B40, IRGKangXi=0507.011
3B41 CJK UNIFIED IDEOGRAPH-#3B41, IRGKangXi=0510.080, Def{a kind of tree, a kind of lumber used to stop a carriage}
3B42 CJK UNIFIED IDEOGRAPH-#3B42, IRGKangXi=0511.050, Def{height of the end-point; the tip of a small branch; (Cant.) slender, thin}
3B43 CJK UNIFIED IDEOGRAPH-#3B43, IRGKangXi=0511.060, Def{(ancient form of 綱) the large rope of a net, main points; outline; principle}
3B44 CJK UNIFIED IDEOGRAPH-#3B44, IRGKangXi=0511.130, Def{a king of tree}
3B45 CJK UNIFIED IDEOGRAPH-#3B45, IRGKangXi=0513.011
3B46 CJK UNIFIED IDEOGRAPH-#3B46, IRGKangXi=0513.011
3B47 CJK UNIFIED IDEOGRAPH-#3B47, IRGKangXi=0514.010, Def{a kind of tree, (corrupted form of 杬) a kind of plant; (non-classical form 欖) the olive tree}
3B48 CJK UNIFIED IDEOGRAPH-#3B48, IRGKangXi=0514.030, Def{a basin; a bowl}
3B49 CJK UNIFIED IDEOGRAPH-#3B49, IRGKangXi=0514.180, Def{farm tools; a spade or shovel}
3B4A CJK UNIFIED IDEOGRAPH-#3B4A, IRGKangXi=0516.100, Def{(non-classical of 析) to split, to rip or break apart, to divide, to separate; to interpret, to explain, to analyze}
3B4B CJK UNIFIED IDEOGRAPH-#3B4B, IRGKangXi=0516.140, Def{(same as 棒) a club; a stick, to hit with a club, good; strong; wonderful}
3B4C CJK UNIFIED IDEOGRAPH-#3B4C, IRGKangXi=0516.150, Def{(same as 桙) a basin; a bathtub, a kind of tool or utensil, (interchangeable 模) form or shape of a thing; style; pattern; appearance; look, a sample}
3B4D CJK UNIFIED IDEOGRAPH-#3B4D, IRGKangXi=0517.011, Def{(a variant 七) capital form of seven}
3B4E CJK UNIFIED IDEOGRAPH-#3B4E, IRGKangXi=0517.011, Def{(simplified form of 棡) a tall tree; a large tree, (interchangeable 扛) to carry on the shoulders of two of more men}
3B4F CJK UNIFIED IDEOGRAPH-#3B4F, IRGKangXi=0517.011, Def{(simplified form of 椲) a kind of wood (used as a kind of material to make basin and bowl, etc.); (same as 楎) a peg for hanging things on, a clothes-horse}
3B50 CJK UNIFIED IDEOGRAPH-#3B50, IRGKangXi=0517.011
3B51 CJK UNIFIED IDEOGRAPH-#3B51, IRGKangXi=0517.150, Def{a kind of tree}
3B52 CJK UNIFIED IDEOGRAPH-#3B52, IRGKangXi=0519.150, Def{(same as non-classical form 耜) a farming instrument; a spade; a shovel}
3B53 CJK UNIFIED IDEOGRAPH-#3B53, IRGKangXi=0519.170, Def{a pillar arch}
3B54 CJK UNIFIED IDEOGRAPH-#3B54, IRGKangXi=0519.180, Def{a kind of tree}
3B55 CJK UNIFIED IDEOGRAPH-#3B55, IRGKangXi=0520.160, Def{a board (on the back of a donkey) for carrying things; saddle}
3B56 CJK UNIFIED IDEOGRAPH-#3B56, IRGKangXi=0521.121
3B57 CJK UNIFIED IDEOGRAPH-#3B57, IRGKangXi=0521.121
3B58 CJK UNIFIED IDEOGRAPH-#3B58, IRGKangXi=0521.150, Def{a scabbard; a sheath; a case for sword, a tree like the acacia}
3B59 CJK UNIFIED IDEOGRAPH-#3B59, IRGKangXi=0522.140, Def{a hammer}
3B5A CJK UNIFIED IDEOGRAPH-#3B5A, IRGKangXi=0522.160, Def{a kind of tree, a tray for carrying sacrificial meats and wine}
3B5B CJK UNIFIED IDEOGRAPH-#3B5B, IRGKangXi=0522.170, Def{a kind of climbing plants; rattan; bark can be used to weave cloth, a component parts of a loom}
3B5C CJK UNIFIED IDEOGRAPH-#3B5C, IRGKangXi=0523.070, Def{a kind of tree (like locust tree; similar to the ash; acacia)}
3B5D CJK UNIFIED IDEOGRAPH-#3B5D, IRGKangXi=0523.130, Def{name of a pavilion, in Xinshi, name of a place in Jingling}
3B5E CJK UNIFIED IDEOGRAPH-#3B5E, IRGKangXi=0523.180, Def{a kind inferior wood}
3B5F CJK UNIFIED IDEOGRAPH-#3B5F, IRGKangXi=0523.210, Def{torture used in ancient times}
3B60 CJK UNIFIED IDEOGRAPH-#3B60, IRGKangXi=0523.250
3B61 CJK UNIFIED IDEOGRAPH-#3B61, IRGKangXi=0524.010, Def{name of a mountain, a component parts of a loom}
3B62 CJK UNIFIED IDEOGRAPH-#3B62, IRGKangXi=0525.030, Def{mechanics, opportunity, urgent}
3B63 CJK UNIFIED IDEOGRAPH-#3B63, IRGKangXi=0526.211
3B64 CJK UNIFIED IDEOGRAPH-#3B64, IRGKangXi=0521.121, Def{(simplified form) (same as 蔦) the convolvulus; a kind of creeping plant, partridge; francolin, in Japan, the pole out side of a building used to post the public notice}
3B65 CJK UNIFIED IDEOGRAPH-#3B65, IRGKangXi=0526.211
3B66 CJK UNIFIED IDEOGRAPH-#3B66, IRGKangXi=0526.211
3B67 CJK UNIFIED IDEOGRAPH-#3B67, IRGKangXi=0526.211
3B68 CJK UNIFIED IDEOGRAPH-#3B68, IRGKangXi=0527.010, Def{(same as U+6930 椰) the cocoa-nut palm}
3B69 CJK UNIFIED IDEOGRAPH-#3B69, IRGKangXi=0527.070, Def{a kind of tree can be used as dye-stuff, the mast of a boat}
3B6A CJK UNIFIED IDEOGRAPH-#3B6A, IRGKangXi=0527.110, Def{a shrub (plant); dense growth of trees}
3B6B CJK UNIFIED IDEOGRAPH-#3B6B, IRGKangXi=0527.190, Def{a fruit tree (plum), (same as 菆) hemp stalks, a mat}
3B6C CJK UNIFIED IDEOGRAPH-#3B6C, IRGKangXi=0527.220, Def{(corrupted form of 椓) to beat; to tap; to thrash, castration as a punishment in ancient times, a castrate man, to accuse or charge}
3B6D CJK UNIFIED IDEOGRAPH-#3B6D, IRGKangXi=0529.050, Def{a kind of tree, a harrow; a drag, a written contract or agreement; a bond; a deed, handles of spears or lances used in ancient times}
3B6E CJK UNIFIED IDEOGRAPH-#3B6E, IRGKangXi=0529.060, Def{(corrupted form of 桚) a kind of liquor container, to squeeze; to press, an instrument of torture for squeezing the fingers of prisoners or witnesses in order to extort evidence or confession}
3B6F CJK UNIFIED IDEOGRAPH-#3B6F, IRGKangXi=0529.070, Def{tree with small leaves; mushroom}
3B70 CJK UNIFIED IDEOGRAPH-#3B70, IRGKangXi=0529.130, Def{to know; to recognize, to hide; to conceal, (same as 嘴) beak (of a bird), stone probe}
3B71 CJK UNIFIED IDEOGRAPH-#3B71, IRGKangXi=0531.131, Def{(same as 匣) a case; a small box}
3B72 CJK UNIFIED IDEOGRAPH-#3B72, IRGKangXi=0531.131, Def{(same as 极) a wooden frame (on the back of a donkey) for carrying things, (simplified form of 極) to exhaust, extreme; highest; topmost}
3B73 CJK UNIFIED IDEOGRAPH-#3B73, IRGKangXi=0531.131
3B74 CJK UNIFIED IDEOGRAPH-#3B74, IRGKangXi=0531.131, Def{(simplified form) the oscines}
3B75 CJK UNIFIED IDEOGRAPH-#3B75, IRGKangXi=0531.131
3B76 CJK UNIFIED IDEOGRAPH-#3B76, IRGKangXi=0537.131
3B77 CJK UNIFIED IDEOGRAPH-#3B77, IRGKangXi=0531.131
3B78 CJK UNIFIED IDEOGRAPH-#3B78, IRGKangXi=0531.190, Def{(same as 梌) the branches to spread out in all directions, the catalpa; a kind of hard wood used for making chessboard}
3B79 CJK UNIFIED IDEOGRAPH-#3B79, IRGKangXi=0533.120, Def{name of a county in today's Shandong Province, a kind of fabric produced in Donglai}
3B7A CJK UNIFIED IDEOGRAPH-#3B7A, IRGKangXi=0533.130, Def{the cherry-apple, a kind of tree}
3B7B CJK UNIFIED IDEOGRAPH-#3B7B, IRGKangXi=0533.150, Def{(same as 棠) the crab-apple; the wild plum}
3B7C CJK UNIFIED IDEOGRAPH-#3B7C, IRGKangXi=0534.080, Def{a rectangle shaped peg or short post between the beans and the roof timbers; the square peck-shaped box half-way up a Chinese flagstaff}
3B7D CJK UNIFIED IDEOGRAPH-#3B7D, IRGKangXi=0534.250, Def{(non-classical form of 柢) root; foundation; base, eaves of a house; brim}
3B7E CJK UNIFIED IDEOGRAPH-#3B7E, IRGKangXi=0535.140, Def{to cut the timber apart; to cut a tree; (Cant.) to blunt}
3B7F CJK UNIFIED IDEOGRAPH-#3B7F, IRGKangXi=0535.190, Def{oblique angle, a post to tie cattle and horses to}
3B80 CJK UNIFIED IDEOGRAPH-#3B80, IRGKangXi=0535.240, Def{tool to clear out (as a drain) the water, (same as 函) a case; a small box}
3B81 CJK UNIFIED IDEOGRAPH-#3B81, IRGKangXi=0536.020, Def{gardenia; a plant of which the nuts produces a yellow dye}
3B82 CJK UNIFIED IDEOGRAPH-#3B82, IRGKangXi=0536.050, Def{an appliance used to lift food; something like a narrow, long table, to carry; to transport}
3B83 CJK UNIFIED IDEOGRAPH-#3B83, IRGKangXi=0536.090, Def{farm tool, (same as 桵) a kind of tree}
3B84 CJK UNIFIED IDEOGRAPH-#3B84, IRGKangXi=0536.150, Def{(non-classical form of 榜) publicly posted roll of successful examinees}
3B85 CJK UNIFIED IDEOGRAPH-#3B85, IRGKangXi=0537.060, Def{a kind of tree}
3B86 CJK UNIFIED IDEOGRAPH-#3B86, IRGKangXi=0537.131, Def{(an ancient form) (same as 𣡌) leaves sprouting from the stump of a tree; shoots from an old stump, a large (a species of oak) from the bark of which a yellow dye is produced}
3B87 CJK UNIFIED IDEOGRAPH-#3B87, IRGKangXi=0537.131, Def{(standard form of 掭) (same as 栝) a builder's frame for measuring, juniper, a poker (for stirring fire, a cylinder part on the old style of wooden doors}
3B88 CJK UNIFIED IDEOGRAPH-#3B88, IRGKangXi=0537.131, Def{(non-classical form of 奈) but; how; what, a remedy; a resource, to bear, to endure}
3B89 CJK UNIFIED IDEOGRAPH-#3B89, IRGKangXi=0537.131
3B8A CJK UNIFIED IDEOGRAPH-#3B8A, IRGKangXi=0537.131
3B8B CJK UNIFIED IDEOGRAPH-#3B8B, IRGKangXi=0537.280, Def{(non-classical form of 栯) a kind of tree, a fruit tree}
3B8C CJK UNIFIED IDEOGRAPH-#3B8C, IRGKangXi=0538.030, Def{(same as U+68C9 棉) cotton; (Cant.) a kind of fruit}
3B8D CJK UNIFIED IDEOGRAPH-#3B8D, IRGKangXi=0538.070, Def{(ancient form of 牋 箋) amemorandum tablet, slip of paper, fancy note-paper, a note, a document, comments}
3B8E CJK UNIFIED IDEOGRAPH-#3B8E, IRGKangXi=0538.110, Def{(non-classical form of U+76C3 盃 U+676F 杯) cup; a tumbler; a glass}
3B8F CJK UNIFIED IDEOGRAPH-#3B8F, IRGKangXi=0538.160, Def{(same as 柰) a fruit tree; a crab-apple, for which the second from is strictly used, leaves sprouting from the stump of a tree; shoots from an old stump}
3B90 CJK UNIFIED IDEOGRAPH-#3B90, IRGKangXi=0538.180, Def{a rack or a stand with three sticks to cross each other, a chopping board}
3B91 CJK UNIFIED IDEOGRAPH-#3B91, IRGKangXi=0538.210, Def{sound of broken sticks; crack of a wooden stick, a forest; wooded land}
3B92 CJK UNIFIED IDEOGRAPH-#3B92, IRGKangXi=0538.280, Def{wood, (same as 禋) to worship with sincerity and reverence, to offer sacrifices to the Heaven}
3B93 CJK UNIFIED IDEOGRAPH-#3B93, IRGKangXi=0538.320, Def{(same as 亙 堥) an extreme limit, to fill, universal, connected, revolve}
3B94 CJK UNIFIED IDEOGRAPH-#3B94, IRGKangXi=0539.050, Def{vegetable, (non-classical, abbreviated from, same as 橦) a tree which grows in Yunnan, from the flowers of which a cloth is made}
3B95 CJK UNIFIED IDEOGRAPH-#3B95, IRGKangXi=0539.090, Def{fruit, plant, (same as 檽) a fruit tree; black date}
3B96 CJK UNIFIED IDEOGRAPH-#3B96, IRGKangXi=0539.110, Def{to lay; to put, drums, to rap, to quiver, to stir up}
3B97 CJK UNIFIED IDEOGRAPH-#3B97, IRGKangXi=0539.120, Def{(same as 矜) the handle of a spear}
3B98 CJK UNIFIED IDEOGRAPH-#3B98, IRGKangXi=0539.210, Def{a tree; winter peach}
3B99 CJK UNIFIED IDEOGRAPH-#3B99, IRGKangXi=0540.150, Def{a pitfall; a hole}
3B9A CJK UNIFIED IDEOGRAPH-#3B9A, IRGKangXi=0541.010, Def{(an ancient form of 栗) the chestnut tree, a kind of metalwork in ancient times}
3B9B CJK UNIFIED IDEOGRAPH-#3B9B, IRGKangXi=0541.080, Def{(same as 匙) a spoon, (same as 椸) (a dialect) a small table in front of the bed, a rack for clothes; a clothes-horse}
3B9C CJK UNIFIED IDEOGRAPH-#3B9C, IRGKangXi=0542.010, Def{a blocks engraved for holding things}
3B9D CJK UNIFIED IDEOGRAPH-#3B9D, IRGKangXi=0542.080, Def{angle steel, legs of a table}
3B9E CJK UNIFIED IDEOGRAPH-#3B9E, IRGKangXi=0542.191, Def{(same as U+6976 楶) a wooden block or bracket on top of a column}
3B9F CJK UNIFIED IDEOGRAPH-#3B9F, IRGKangXi=0542.191, Def{a whetstone, (a dialect) a corner; a nook; a crack; an opening; a cleft}
3BA0 CJK UNIFIED IDEOGRAPH-#3BA0, IRGKangXi=0542.191
3BA1 CJK UNIFIED IDEOGRAPH-#3BA1, IRGKangXi=0677.030, Def{(same as 爟) to light a fire; to set fire to}
3BA2 CJK UNIFIED IDEOGRAPH-#3BA2, IRGKangXi=0542.191, Def{fruit}
3BA3 CJK UNIFIED IDEOGRAPH-#3BA3, IRGKangXi=0542.191, Def{(a variant of 概) a piece of wood used to strike off grain in a measure, thus:--all, to level, to adjust, generally, for the most part, (interchangeable 慨) emotional excitement, (interchangeable 溉) to wash; to cleanse; to rinse}
3BA4 CJK UNIFIED IDEOGRAPH-#3BA4, IRGKangXi=0543.050, Def{pine; fir, (same as 松 鬆) loose; lax; slack}
3BA5 CJK UNIFIED IDEOGRAPH-#3BA5, IRGKangXi=0543.120, Def{sails, the mat-covering of small boats, (interchangeable 軬) the covering of a carriage}
3BA6 CJK UNIFIED IDEOGRAPH-#3BA6, IRGKangXi=0543.250, Def{branches growing upwards, the tip of a branch or things of similar shape, (interchangeable 索) to importune}
3BA7 CJK UNIFIED IDEOGRAPH-#3BA7, IRGKangXi=0543.260, Def{a tree, a fruit}
3BA8 CJK UNIFIED IDEOGRAPH-#3BA8, IRGKangXi=0543.320, Def{China cypress}
3BA9 CJK UNIFIED IDEOGRAPH-#3BA9, IRGKangXi=0543.340, Def{a tree}
3BAA CJK UNIFIED IDEOGRAPH-#3BAA, IRGKangXi=0544.060, Def{a small boat}
3BAB CJK UNIFIED IDEOGRAPH-#3BAB, IRGKangXi=0544.070, Def{a wooden article to be used to adjust a bow, a tiger shaped wooden article used to stop the music in ancient times}
3BAC CJK UNIFIED IDEOGRAPH-#3BAC, IRGKangXi=0544.100, Def{a fruit tree}
3BAD CJK UNIFIED IDEOGRAPH-#3BAD, IRGKangXi=0544.220, Def{(same as 椷) a casket; a box; a bowl; a cup, to allow, an envelope}
3BAE CJK UNIFIED IDEOGRAPH-#3BAE, IRGKangXi=0545.010, Def{a well sweep}
3BAF CJK UNIFIED IDEOGRAPH-#3BAF, IRGKangXi=0545.030, Def{whole (uncut, unsplit) firewood; complete, whole, undamaged, general; (same as 梡) a kind of tree}
3BB0 CJK UNIFIED IDEOGRAPH-#3BB0, IRGKangXi=0545.060, Def{the small beam supporting the rafters at the eaves}
3BB1 CJK UNIFIED IDEOGRAPH-#3BB1, IRGKangXi=0545.080, Def{(said of grass, trees, vegetation and flora), (non-classical form of 森) luxuriant; exuberant; lush; flourishing}
3BB2 CJK UNIFIED IDEOGRAPH-#3BB2, IRGKangXi=0545.100, Def{a small ring or a small piece of board attached to the muzzle of an ox; to thread through a halter}
3BB3 CJK UNIFIED IDEOGRAPH-#3BB3, IRGKangXi=0545.180, Def{a tree, (same as 栚) a piece of cross-wise board used for frame on which silkworms spin}
3BB4 CJK UNIFIED IDEOGRAPH-#3BB4, IRGKangXi=0546.050, Def{(same as 艘) a numerary adjunct for ships}
3BB5 CJK UNIFIED IDEOGRAPH-#3BB5, IRGKangXi=0546.120, Def{common sandalwood}
3BB6 CJK UNIFIED IDEOGRAPH-#3BB6, IRGKangXi=0546.150, Def{(same as 槊) a tree, a fence; a palisade; a railing}
3BB7 CJK UNIFIED IDEOGRAPH-#3BB7, IRGKangXi=0546.160, Def{a tree (as maple tree)}
3BB8 CJK UNIFIED IDEOGRAPH-#3BB8, IRGKangXi=0546.170, Def{(corrupted form of 送) to send; to deliver; to present; to give, to send off}
3BB9 CJK UNIFIED IDEOGRAPH-#3BB9, IRGKangXi=0546.190, Def{a tree}
3BBA CJK UNIFIED IDEOGRAPH-#3BBA, IRGKangXi=0546.240, Def{(ancient form of 本) stem; source; foundation; origin; basis, a book}
3BBB CJK UNIFIED IDEOGRAPH-#3BBB, IRGKangXi=0542.191, Def{(same as 搔) to scratch lightly, to irritate; to annoy}
3BBC CJK UNIFIED IDEOGRAPH-#3BBC, IRGKangXi=0546.251
3BBD CJK UNIFIED IDEOGRAPH-#3BBD, IRGKangXi=0546.251
3BBE CJK UNIFIED IDEOGRAPH-#3BBE, IRGKangXi=0551.181, Def{a place in today's Hunan Province}
3BBF CJK UNIFIED IDEOGRAPH-#3BBF, IRGKangXi=0547.040, Def{a tree}
3BC0 CJK UNIFIED IDEOGRAPH-#3BC0, IRGKangXi=0547.190, Def{bonds and fetters for falcons and dogs used in hunting}
3BC1 CJK UNIFIED IDEOGRAPH-#3BC1, IRGKangXi=0548.070, Def{household registers, printing plate, supporting boards used in building walls, (non-classical form 棓) to strike, a flail, a club, planks}
3BC2 CJK UNIFIED IDEOGRAPH-#3BC2, IRGKangXi=0548.130, Def{pillar or post of a frame on which silkworms spin}
3BC3 CJK UNIFIED IDEOGRAPH-#3BC3, IRGKangXi=0548.180, Def{(same as 桼漆) the varnish tree, paint, lacquer, varnish, to paint or varinish, black, sticky}
3BC4 CJK UNIFIED IDEOGRAPH-#3BC4, IRGKangXi=0549.120, Def{(of trees) luxuriant; exuberant; lush}
3BC5 CJK UNIFIED IDEOGRAPH-#3BC5, IRGKangXi=0549.190, Def{the branches growing downwards; small trees; saplings; cuttings of trees for planting}
3BC6 CJK UNIFIED IDEOGRAPH-#3BC6, IRGKangXi=0549.230, Def{a tree, a mattress}
3BC7 CJK UNIFIED IDEOGRAPH-#3BC7, IRGKangXi=0550.040, Def{(same as 梐) a stockade; a cheval de frise, a pen; a cage}
3BC8 CJK UNIFIED IDEOGRAPH-#3BC8, IRGKangXi=0550.060, Def{(non-classical form) small trees; saplings}
3BC9 CJK UNIFIED IDEOGRAPH-#3BC9, IRGKangXi=0550.090, Def{(same as 檴) a tree; material for cups, a kind of birch found in Manchuria}
3BCA CJK UNIFIED IDEOGRAPH-#3BCA, IRGKangXi=0551.030, Def{even measuring board for pecks and bushels}
3BCB CJK UNIFIED IDEOGRAPH-#3BCB, IRGKangXi=0551.070, Def{a chest; a box, footstool; footrest, a tree, handle of an awl, ring of a knife or a sword, a round pillow that roused the sleeper when he moved}
3BCC CJK UNIFIED IDEOGRAPH-#3BCC, IRGKangXi=0551.170, Def{to operate or manage}
3BCD CJK UNIFIED IDEOGRAPH-#3BCD, IRGKangXi=0551.181, Def{(same as 槳) an oar}
3BCE CJK UNIFIED IDEOGRAPH-#3BCE, IRGKangXi=0551.181, Def{stupid; dull, foolish; idiotic}
3BCF CJK UNIFIED IDEOGRAPH-#3BCF, IRGKangXi=0551.181, Def{(same as 穀) grains; corns; cereals}
3BD0 CJK UNIFIED IDEOGRAPH-#3BD0, IRGKangXi=0555.311, Def{tubular, oval, elliptical}
3BD1 CJK UNIFIED IDEOGRAPH-#3BD1, IRGKangXi=0551.181
3BD2 CJK UNIFIED IDEOGRAPH-#3BD2, IRGKangXi=0551.181
3BD3 CJK UNIFIED IDEOGRAPH-#3BD3, IRGKangXi=0552.050, Def{(same as 榻) a couch; a bed, window; shutters}
3BD4 CJK UNIFIED IDEOGRAPH-#3BD4, IRGKangXi=0552.200, Def{to hull heavily, to pound heavily}
3BD5 CJK UNIFIED IDEOGRAPH-#3BD5, IRGKangXi=0552.230, Def{sticks or frames; a wooden device used to torture the fingers by squeezing, the branches growing downwards; small trees; saplings; cuttings of trees for planting}
3BD6 CJK UNIFIED IDEOGRAPH-#3BD6, IRGKangXi=0552.260, Def{a tree, a hammer, to beat with a hammer}
3BD7 CJK UNIFIED IDEOGRAPH-#3BD7, IRGKangXi=0553.030, Def{a kind of tree}
3BD8 CJK UNIFIED IDEOGRAPH-#3BD8, IRGKangXi=0553.120, Def{(same as 梡) a small wooden stand having four legs; it was used in sacrifice, faggots}
3BD9 CJK UNIFIED IDEOGRAPH-#3BD9, IRGKangXi=0553.140, Def{the buckthorn or jujube (tree); dates}
3BDA CJK UNIFIED IDEOGRAPH-#3BDA, IRGKangXi=0553.180, Def{a kind of tree (as plum)}
3BDB CJK UNIFIED IDEOGRAPH-#3BDB, IRGKangXi=0553.220, Def{gourd shaped dates}
3BDC CJK UNIFIED IDEOGRAPH-#3BDC, IRGKangXi=0553.230, Def{(same as 椊) decayed wood}
3BDD CJK UNIFIED IDEOGRAPH-#3BDD, IRGKangXi=0554.170, Def{paulownia}
3BDE CJK UNIFIED IDEOGRAPH-#3BDE, IRGKangXi=0558.091, Def{a kind of tree; material for making clothes}
3BDF CJK UNIFIED IDEOGRAPH-#3BDF, IRGKangXi=0554.220, Def{(ancient form of 麓) foot of a hill or mountain}
3BE0 CJK UNIFIED IDEOGRAPH-#3BE0, IRGKangXi=0554.280, Def{a cross-beam; an axle, etc.}
3BE1 CJK UNIFIED IDEOGRAPH-#3BE1, IRGKangXi=0555.150, Def{to lacquer some kind of ashes on wooden articles or furniture, after drying out, smooth them and then paint, black lacquer}
3BE2 CJK UNIFIED IDEOGRAPH-#3BE2, IRGKangXi=0555.170, Def{(same as 栚) (same as 㮳) a piece of cross-wise board used for frame on which silkworms spin}
3BE3 CJK UNIFIED IDEOGRAPH-#3BE3, IRGKangXi=0555.260, Def{(same as 棻) a kind of fragrant tree used to produce perfume by burning it}
3BE4 CJK UNIFIED IDEOGRAPH-#3BE4, IRGKangXi=0555.280, Def{(same as 棘) the jujube tree, thorny brambles, a kind of date (with a sour taste)}
3BE5 CJK UNIFIED IDEOGRAPH-#3BE5, IRGKangXi=0555.290, Def{(same as 曹) a Chinese family name, surrounded, a whole day; a revolution of the sun}
3BE6 CJK UNIFIED IDEOGRAPH-#3BE6, IRGKangXi=0555.311, Def{(same as 棋) the game of chess, draughts and other similar games}
3BE7 CJK UNIFIED IDEOGRAPH-#3BE7, IRGKangXi=0555.311
3BE8 CJK UNIFIED IDEOGRAPH-#3BE8, IRGKangXi=0555.311
3BE9 CJK UNIFIED IDEOGRAPH-#3BE9, IRGKangXi=0167.081, Def{to put the growing up silkworms in different frames according to their sizes}
3BEA CJK UNIFIED IDEOGRAPH-#3BEA, IRGKangXi=0555.330, Def{(same as 櫺) carved or patterned window-railings; sills, the wooden planks which join eaves with a house}
3BEB CJK UNIFIED IDEOGRAPH-#3BEB, IRGKangXi=0555.340, Def{a wattle or bamboo fence}
3BEC CJK UNIFIED IDEOGRAPH-#3BEC, IRGKangXi=0556.080, Def{achievements; merit}
3BED CJK UNIFIED IDEOGRAPH-#3BED, IRGKangXi=0556.130, Def{(a variant of 櫓) a lookout turret on a city wall, moveable wooden tower for archers, a scull a sweep, an oar, (in ancient warfare) a big shield; a long spear}
3BEE CJK UNIFIED IDEOGRAPH-#3BEE, IRGKangXi=0556.140, Def{a kind of tree (as willow) with big leaves and in red color}
3BEF CJK UNIFIED IDEOGRAPH-#3BEF, IRGKangXi=0556.160, Def{small cup, chest; box, a kind of container usually put on one's head to carry things}
3BF0 CJK UNIFIED IDEOGRAPH-#3BF0, IRGKangXi=0556.220, Def{(same as 植) to plant; to set up, to erect, plants}
3BF1 CJK UNIFIED IDEOGRAPH-#3BF1, IRGKangXi=0557.030, Def{an enlarged bag, to wrap up, a parcel; a bundle; a package}
3BF2 CJK UNIFIED IDEOGRAPH-#3BF2, IRGKangXi=0557.080, Def{a wooden (bamboo) framework; a wooden pole; used as an obstacle to impede the door, a frame}
3BF3 CJK UNIFIED IDEOGRAPH-#3BF3, IRGKangXi=0557.170, Def{(same as 檠) a kind of tool to adjust bow; lamp holder, a tray with base}
3BF4 CJK UNIFIED IDEOGRAPH-#3BF4, IRGKangXi=0559.261
3BF5 CJK UNIFIED IDEOGRAPH-#3BF5, IRGKangXi=0558.091
3BF6 CJK UNIFIED IDEOGRAPH-#3BF6, IRGKangXi=0558.091, Def{the coir palm tree}
3BF7 CJK UNIFIED IDEOGRAPH-#3BF7, IRGKangXi=0558.270, Def{dates, a kind of oak; Quercus dentata, (same as 樸) a shrub (plant); thicket, strong and durable, a county in ancient times}
3BF8 CJK UNIFIED IDEOGRAPH-#3BF8, IRGKangXi=0558.300, Def{a basin}
3BF9 CJK UNIFIED IDEOGRAPH-#3BF9, IRGKangXi=0558.310, Def{(corrupted form of 檦) to show; to exhibit, to manifest, a kind of supporting post}
3BFA CJK UNIFIED IDEOGRAPH-#3BFA, IRGKangXi=0559.010, Def{a cabinet; a wardrobe; a cupboard, (same as 壏) hard ground}
3BFB CJK UNIFIED IDEOGRAPH-#3BFB, IRGKangXi=0559.150, Def{to bind; to tie up; a bundle; a bondage; restrictions; restraints}
3BFC CJK UNIFIED IDEOGRAPH-#3BFC, IRGKangXi=0559.261
3BFD CJK UNIFIED IDEOGRAPH-#3BFD, IRGKangXi=0559.261, Def{(a variant of U+6AB3 檳) the areca-nut; the betel-nut}
3BFE CJK UNIFIED IDEOGRAPH-#3BFE, IRGKangXi=0559.320, Def{a tree, (same as 槽) with both flowers and fruits; half and half}
3BFF CJK UNIFIED IDEOGRAPH-#3BFF, IRGKangXi=0560.100, Def{handle of a ladle, a plant; wistaria, or wisteria, a certain trees in Sichuan; material for candle}
3C00 CJK UNIFIED IDEOGRAPH-#3C00, IRGKangXi=0560.110, Def{a kind of tree}
3C01 CJK UNIFIED IDEOGRAPH-#3C01, IRGKangXi=0560.160, Def{a tree with slanted branches}
3C02 CJK UNIFIED IDEOGRAPH-#3C02, IRGKangXi=0560.190, Def{a kind of tree; the juice of which is used to make wine}
3C03 CJK UNIFIED IDEOGRAPH-#3C03, IRGKangXi=0560.200, Def{(same as 檰) a tree, the bark of which is used in medicine-- Eucommia ulmoides, an awning of the house}
3C04 CJK UNIFIED IDEOGRAPH-#3C04, IRGKangXi=0560.230, Def{(non-classical form) a small chestnut tree, a kind of fruit; mountain plum}
3C05 CJK UNIFIED IDEOGRAPH-#3C05, IRGKangXi=0561.020, Def{(same as 樀) eaves of a house; brim, part of a loom, the cross beams on the frame on which silkworms spin, a bookcase, to abandon or give up}
3C06 CJK UNIFIED IDEOGRAPH-#3C06, IRGKangXi=0561.040, Def{(same as 韛) an instrument to blow a fire; a bellows for forge, etc.}
3C07 CJK UNIFIED IDEOGRAPH-#3C07, IRGKangXi=0561.111, Def{(a variant of 櫼) the square peck-shaped box half-way up a Chinese flagstaff}
3C08 CJK UNIFIED IDEOGRAPH-#3C08, IRGKangXi=0560.150, Def{nice and pretty}
3C09 CJK UNIFIED IDEOGRAPH-#3C09, IRGKangXi=0561.120, Def{(same as 榛) the hazel nut or filbert tree, a thorny tree}
3C0A CJK UNIFIED IDEOGRAPH-#3C0A, IRGKangXi=0561.260, Def{a kind of tree; thin leaves}
3C0B CJK UNIFIED IDEOGRAPH-#3C0B, IRGKangXi=0561.300, Def{a kind of fruit tree; betel-nut; the areca-nut}
3C0C CJK UNIFIED IDEOGRAPH-#3C0C, IRGKangXi=0561.380, Def{(non-classical form of 榷) to monopolize, to levy taxes}
3C0D CJK UNIFIED IDEOGRAPH-#3C0D, IRGKangXi=0561.400, Def{a cage, a pen, a grating, bars, window; window frame}
3C0E CJK UNIFIED IDEOGRAPH-#3C0E, IRGKangXi=0562.010, Def{(same as 檇) a wooden pestle or rammer, ancient name of a place in Zhejiang province; southwest of Jiaxing, a kind of fruit}
3C0F CJK UNIFIED IDEOGRAPH-#3C0F, IRGKangXi=0562.020, Def{(same as 篙) a bamboo pole; a pole for punting a boat}
3C10 CJK UNIFIED IDEOGRAPH-#3C10, IRGKangXi=0562.050, Def{(same as 橢) oval; oblong; elliptical}
3C11 CJK UNIFIED IDEOGRAPH-#3C11, IRGKangXi=0562.060, Def{fruit tree}
3C12 CJK UNIFIED IDEOGRAPH-#3C12, IRGKangXi=0562.101
3C13 CJK UNIFIED IDEOGRAPH-#3C13, IRGKangXi=0562.101
3C14 CJK UNIFIED IDEOGRAPH-#3C14, IRGKangXi=0562.200, Def{a kind of edible mushroom}
3C15 CJK UNIFIED IDEOGRAPH-#3C15, IRGKangXi=0562.250, Def{a ladle (often made of dried calabash or gourd)}
3C16 CJK UNIFIED IDEOGRAPH-#3C16, IRGKangXi=0563.010, Def{(same as 欖) the olive}
3C17 CJK UNIFIED IDEOGRAPH-#3C17, IRGKangXi=0563.080, Def{(same as 槭) a kind of maple (Acer palmatum)}
3C18 CJK UNIFIED IDEOGRAPH-#3C18, IRGKangXi=0563.210, Def{a kind of tree; often used to make instruments for sacrificial ceremonies in ancient times}
3C19 CJK UNIFIED IDEOGRAPH-#3C19, IRGKangXi=0563.280, Def{weak, feeble and tender branches}
3C1A CJK UNIFIED IDEOGRAPH-#3C1A, IRGKangXi=0563.310, Def{(same as 籬) a bamboo fence; a hedge}
3C1B CJK UNIFIED IDEOGRAPH-#3C1B, IRGKangXi=0563.320, Def{name of a county}
3C1C CJK UNIFIED IDEOGRAPH-#3C1C, IRGKangXi=0564.031
3C1D CJK UNIFIED IDEOGRAPH-#3C1D, IRGKangXi=0565.090, Def{to cough; cough}
3C1E CJK UNIFIED IDEOGRAPH-#3C1E, IRGKangXi=0565.140, Def{(same as 蚩 嗤) to laugh at; to make fun of; to deride; to ridicule}
3C1F CJK UNIFIED IDEOGRAPH-#3C1F, IRGKangXi=0565.160, Def{(same as 冀) hope; wish; to hope and scheme for, to stammer; to stutter; stuttering, to give}
3C20 CJK UNIFIED IDEOGRAPH-#3C20, IRGKangXi=0566.100, Def{to covet; greedy}
3C21 CJK UNIFIED IDEOGRAPH-#3C21, IRGKangXi=0566.120, Def{rash; impatient, very angry}
3C22 CJK UNIFIED IDEOGRAPH-#3C22, IRGKangXi=0566.170, Def{cough}
3C23 CJK UNIFIED IDEOGRAPH-#3C23, IRGKangXi=0566.210, Def{to vomit; to throw up; to disgorge, hiccough; shortwindedness, supposed upward motion of the spirit (in Chinese herb medicine), to sigh with grief or regret; to lament; to deplore}
3C24 CJK UNIFIED IDEOGRAPH-#3C24, IRGKangXi=0566.240, Def{to laugh heartily; to roar with laughter, to breath}
3C25 CJK UNIFIED IDEOGRAPH-#3C25, IRGKangXi=0566.270, Def{laugh}
3C26 CJK UNIFIED IDEOGRAPH-#3C26, IRGKangXi=0566.280, Def{to breath with mouth open}
3C27 CJK UNIFIED IDEOGRAPH-#3C27, IRGKangXi=0566.300, Def{to drink, to swallow}
3C28 CJK UNIFIED IDEOGRAPH-#3C28, IRGKangXi=0567.020, Def{to take breath or rest (after strenuous exercise), hiccough; shortwindedness}
3C29 CJK UNIFIED IDEOGRAPH-#3C29, IRGKangXi=0567.080, Def{sound of laughter}
3C2A CJK UNIFIED IDEOGRAPH-#3C2A, IRGKangXi=0567.150, Def{sound, wicked; mean; vicious}
3C2B CJK UNIFIED IDEOGRAPH-#3C2B, IRGKangXi=0567.210, Def{glad; joyful; happy, avaricious; greedy, cold}
3C2C CJK UNIFIED IDEOGRAPH-#3C2C, IRGKangXi=0567.240, Def{shortwindedness; hiccough, supposed upward motion of the spirit (in Chinese herb medicine), honesty; good faith; trust}
3C2D CJK UNIFIED IDEOGRAPH-#3C2D, IRGKangXi=0567.260, Def{pleasure; joy}
3C2E CJK UNIFIED IDEOGRAPH-#3C2E, IRGKangXi=0567.330, Def{to laugh at}
3C2F CJK UNIFIED IDEOGRAPH-#3C2F, IRGKangXi=0567.370, Def{the way of speaking; to spit at and not agree about something, to spit (same as 否) negative, to deny, cruel; savage; wicked; coarse; rustic}
3C30 CJK UNIFIED IDEOGRAPH-#3C30, IRGKangXi=0568.050, Def{asthmatic breathing, supposed upward motion of the spirit (in Chinese herb medicine), to long for; to covet, to hum over; to moan; to groan}
3C31 CJK UNIFIED IDEOGRAPH-#3C31, IRGKangXi=0568.060, Def{(same as 歃) to smear the mouth with the blood of a victim when taking an oath, to taste; to try}
3C32 CJK UNIFIED IDEOGRAPH-#3C32, IRGKangXi=0568.090, Def{to blow off, to blow; to puff}
3C33 CJK UNIFIED IDEOGRAPH-#3C33, IRGKangXi=0568.110, Def{asses braying, shortwindedness; hiccough, asthmatic breathing, supposed upward motion of the spirit (in Chinese herb medicine), to exhaust; extreme}
3C34 CJK UNIFIED IDEOGRAPH-#3C34, IRGKangXi=0568.130, Def{(of statement) to grate on the ear; earnest and faithful remonstrance}
3C35 CJK UNIFIED IDEOGRAPH-#3C35, IRGKangXi=0568.170, Def{to suck, to drink, to swallow}
3C36 CJK UNIFIED IDEOGRAPH-#3C36, IRGKangXi=0569.010, Def{to wrinkle the nose with sorrowful (when sob or weep), (same as 嘔) to vomit; to throw up}
3C37 CJK UNIFIED IDEOGRAPH-#3C37, IRGKangXi=0580.280, Def{resurrection; to come to life again, sick}
3C38 CJK UNIFIED IDEOGRAPH-#3C38, IRGKangXi=0569.111, Def{(a abbreviated form of 歛 斂) to collect; to gather; to hold together, to desire}
3C39 CJK UNIFIED IDEOGRAPH-#3C39, IRGKangXi=0569.120, Def{(same as 欦) to laugh; to smile, greed; avarice, to cry, to shout, overbear; arrogant}
3C3A CJK UNIFIED IDEOGRAPH-#3C3A, IRGKangXi=0569.160, Def{to drink; to swallow, disease of the throat; disease of the larynx}
3C3B CJK UNIFIED IDEOGRAPH-#3C3B, IRGKangXi=0570.020, Def{asses braying, to be happy suddenly, cruel; malignant; coarse, rude}
3C3C CJK UNIFIED IDEOGRAPH-#3C3C, IRGKangXi=0570.060, Def{greed; avarice, to blow off}
3C3D CJK UNIFIED IDEOGRAPH-#3C3D, IRGKangXi=0570.100, Def{to exert oneself to yell; to yell loudly; to shout, overbearing; arrogant, vigorous}
3C3E CJK UNIFIED IDEOGRAPH-#3C3E, IRGKangXi=0570.110, Def{songs of the people of 楚, a kind of music instrument in ancient times}
3C3F CJK UNIFIED IDEOGRAPH-#3C3F, IRGKangXi=0570.270, Def{to sigh in lamentation; to lament, to exclaim}
3C40 CJK UNIFIED IDEOGRAPH-#3C40, IRGKangXi=0571.030, Def{(same as 欼) to bite; to gnaw, (same as 嘬) to swallow a big mouthful without mastication}
3C41 CJK UNIFIED IDEOGRAPH-#3C41, IRGKangXi=0571.040, Def{to ask; to inquire; to investigate, (same as 款) sincerity; article, item, etc., to entertain, slowly}
3C42 CJK UNIFIED IDEOGRAPH-#3C42, IRGKangXi=0571.230, Def{hungry; starving, a poor harvest of grains}
3C43 CJK UNIFIED IDEOGRAPH-#3C43, IRGKangXi=0571.260, Def{(ancient form of 飲) to drink; to swallow}
3C44 CJK UNIFIED IDEOGRAPH-#3C44, IRGKangXi=0572.120, Def{to spit, to cough, keep quiet; to keep silence; speechless; wordless}
3C45 CJK UNIFIED IDEOGRAPH-#3C45, IRGKangXi=0572.200, Def{(ancient form of 懿) virtuous; fine; good}
3C46 CJK UNIFIED IDEOGRAPH-#3C46, IRGKangXi=0572.240, Def{to smile at each other}
3C47 CJK UNIFIED IDEOGRAPH-#3C47, IRGKangXi=0572.270, Def{fear; dread; fright; scare, sad; sorrowful; mournful}
3C48 CJK UNIFIED IDEOGRAPH-#3C48, IRGKangXi=0572.290, Def{name of a person}
3C49 CJK UNIFIED IDEOGRAPH-#3C49, IRGKangXi=0572.310, Def{moving of the mouth}
3C4A CJK UNIFIED IDEOGRAPH-#3C4A, IRGKangXi=0573.030, Def{asthmatic breathing; shortwindedness; hiccough; husky voice, (same as 嗄) (of voice) hoarse}
3C4B CJK UNIFIED IDEOGRAPH-#3C4B, IRGKangXi=0573.050, Def{(same as 塙 確) high; lofty; noble, sure; certain; firm; real; true}
3C4C CJK UNIFIED IDEOGRAPH-#3C4C, IRGKangXi=0573.150, Def{to take, to select, to get angry; to lose the temper}
3C4D CJK UNIFIED IDEOGRAPH-#3C4D, IRGKangXi=0573.190, Def{to owe, deficient, confused; puzzled}
3C4E CJK UNIFIED IDEOGRAPH-#3C4E, IRGKangXi=0573.220, Def{cannot be known; agnostic}
3C4F CJK UNIFIED IDEOGRAPH-#3C4F, IRGKangXi=0574.090, Def{(ancient form of 正) the right side, proper, pure, honest and virtuous, original, exactly}
3C50 CJK UNIFIED IDEOGRAPH-#3C50, IRGKangXi=0575.031
3C51 CJK UNIFIED IDEOGRAPH-#3C51, IRGKangXi=0575.031
3C52 CJK UNIFIED IDEOGRAPH-#3C52, IRGKangXi=0576.110, Def{(ancient form of 訶) to scold or blame in a loud voice}
3C53 CJK UNIFIED IDEOGRAPH-#3C53, IRGKangXi=0576.151
3C54 CJK UNIFIED IDEOGRAPH-#3C54, IRGKangXi=0576.151, Def{(same as 些) a small quantity or number; a little; a few; some}
3C55 CJK UNIFIED IDEOGRAPH-#3C55, IRGKangXi=0576.290, Def{(large seal type 歸) the marriage of a woman, to return to; to revert to; to go back, to belong to, to restore, to send back}
3C56 CJK UNIFIED IDEOGRAPH-#3C56, IRGKangXi=0576.300, Def{to stay; to stop (at a certain stage); to desist, to detain, to prohibit; to end, to come to; to stop at, still; calm, later}
3C57 CJK UNIFIED IDEOGRAPH-#3C57, IRGKangXi=0577.080, Def{a breath, news; tidings, to stop; to end}
3C58 CJK UNIFIED IDEOGRAPH-#3C58, IRGKangXi=0578.060, Def{(same as 魘) nightmare}
3C59 CJK UNIFIED IDEOGRAPH-#3C59, IRGKangXi=0578.210, Def{(same as 朽) rotten, decayed, useless, (same as 咼 剮) a wry mouth, to cut a criminal in pieces; to hack}
3C5A CJK UNIFIED IDEOGRAPH-#3C5A, IRGKangXi=0579.210, Def{(same as 殘) to destroy; to injure; to damage; to spoil, cruel and fierce, crippled}
3C5B CJK UNIFIED IDEOGRAPH-#3C5B, IRGKangXi=0579.270, Def{(non-classical form) to destroy; to injure; to damage, to exhaust, to complete; to finish, (ancient form 布) cloth; textiles}
3C5C CJK UNIFIED IDEOGRAPH-#3C5C, IRGKangXi=0579.330, Def{pestilence}
3C5D CJK UNIFIED IDEOGRAPH-#3C5D, IRGKangXi=0579.331
3C5E CJK UNIFIED IDEOGRAPH-#3C5E, IRGKangXi=0579.510, Def{danger; precarious; perilous, lofty; high, to decay; to break; to snap}
3C5F CJK UNIFIED IDEOGRAPH-#3C5F, IRGKangXi=0579.600, Def{to rip open the flesh, to break; to snap}
3C60 CJK UNIFIED IDEOGRAPH-#3C60, IRGKangXi=0580.010, Def{withered; dry, calamity; disaster, (ancient form 辜) sin; crime; guilt}
3C61 CJK UNIFIED IDEOGRAPH-#3C61, IRGKangXi=0580.160, Def{the soul out of one's body; as good as dead}
3C62 CJK UNIFIED IDEOGRAPH-#3C62, IRGKangXi=0581.020, Def{the dead}
3C63 CJK UNIFIED IDEOGRAPH-#3C63, IRGKangXi=0581.070, Def{uneven, weak; feeble}
3C64 CJK UNIFIED IDEOGRAPH-#3C64, IRGKangXi=0581.150, Def{to exhaust; extreme; topmost, to die}
3C65 CJK UNIFIED IDEOGRAPH-#3C65, IRGKangXi=0581.320, Def{the evil spirits come out, sick and poor, stupid; rude, inattentive; absent-minded; careless}
3C66 CJK UNIFIED IDEOGRAPH-#3C66, IRGKangXi=0581.350, Def{to discard, to abandon, to die; death}
3C67 CJK UNIFIED IDEOGRAPH-#3C67, IRGKangXi=0582.020, Def{stinking smell, expression of a dead person}
3C68 CJK UNIFIED IDEOGRAPH-#3C68, IRGKangXi=0582.030, Def{(same as 殮) to prepare a body for the coffin}
3C69 CJK UNIFIED IDEOGRAPH-#3C69, IRGKangXi=0582.041, Def{an abortion; stillborn}
3C6A CJK UNIFIED IDEOGRAPH-#3C6A, IRGKangXi=0582.050, Def{(standard form of 殙) stupid and confused; muddled and delirious; unconscious; in a state of coma, to breathe one's last}
3C6B CJK UNIFIED IDEOGRAPH-#3C6B, IRGKangXi=0582.060, Def{destroyed or ruined; to rot or decay; to disintegrate or decompose}
3C6C CJK UNIFIED IDEOGRAPH-#3C6C, IRGKangXi=0582.100, Def{cannot recognize people}
3C6D CJK UNIFIED IDEOGRAPH-#3C6D, IRGKangXi=0582.120, Def{(same as 毈) an infertile egg}
3C6E CJK UNIFIED IDEOGRAPH-#3C6E, IRGKangXi=0582.211, Def{(simplified form of 殨) to open, as an ulcer or sore; bursting of an abscess; inflamed; inflammation}
3C6F CJK UNIFIED IDEOGRAPH-#3C6F, IRGKangXi=0582.220, Def{get the unborn baby goat by killing the mother goat}
3C70 CJK UNIFIED IDEOGRAPH-#3C70, IRGKangXi=0582.260, Def{to destroy; to ruin, to put off}
3C71 CJK UNIFIED IDEOGRAPH-#3C71, IRGKangXi=0582.290, Def{uneven; unconscious, to know nothing about...}
3C72 CJK UNIFIED IDEOGRAPH-#3C72, IRGKangXi=0582.310, Def{withered; faded; to die, a minor illness (of foot and hand)}
3C73 CJK UNIFIED IDEOGRAPH-#3C73, IRGKangXi=0583.010, Def{lonely; lonesome}
3C74 CJK UNIFIED IDEOGRAPH-#3C74, IRGKangXi=0583.100, Def{sick, a dead animal, skeleton}
3C75 CJK UNIFIED IDEOGRAPH-#3C75, IRGKangXi=0583.190, Def{to die, to open, as an ulcer or sore}
3C76 CJK UNIFIED IDEOGRAPH-#3C76, IRGKangXi=0583.290, Def{a swollen corpse, swell}
3C77 CJK UNIFIED IDEOGRAPH-#3C77, IRGKangXi=0583.301
3C78 CJK UNIFIED IDEOGRAPH-#3C78, IRGKangXi=0583.330, Def{to exhaust; extreme; highest; farthest, to die}
3C79 CJK UNIFIED IDEOGRAPH-#3C79, IRGKangXi=0584.050, Def{to die from disease}
3C7A CJK UNIFIED IDEOGRAPH-#3C7A, IRGKangXi=0584.070, Def{(interchangeable 臚) the skin; the belly}
3C7B CJK UNIFIED IDEOGRAPH-#3C7B, IRGKangXi=0584.140, Def{diseases of dumb creatures, diseases of animals, illness; disease; ailment}
3C7C CJK UNIFIED IDEOGRAPH-#3C7C, IRGKangXi=0584.190, Def{a kind of ornaments, people wore in ancient time in order to avoid evil spirits or influences}
3C7D CJK UNIFIED IDEOGRAPH-#3C7D, IRGKangXi=0584.200, Def{(same as 抌) to hit or to strikeheavily, to dip, to administer; to control, to govern; to treat; to cure, to punish}
3C7E CJK UNIFIED IDEOGRAPH-#3C7E, IRGKangXi=0584.280, Def{a kind of ornaments, people wore in ancient time in order to avoid evil spirits or influences, sound of laughter}
3C7F CJK UNIFIED IDEOGRAPH-#3C7F, IRGKangXi=0585.010, Def{(interchangeable 殼) the husk, skin or shell of fruits; the shell of snakes, insects, etc., the shells of mollusks; a bag or case made of leather for weapons, (interchangeable 慤) prudent; cautious, (same as 嗀) to vomit; to throw up, strong; durable; solid; firm; stable}
3C80 CJK UNIFIED IDEOGRAPH-#3C80, IRGKangXi=0585.050, Def{to beat; to strike; to attack, to move with happiness; excited, (a corrupted form) to laugh at}
3C81 CJK UNIFIED IDEOGRAPH-#3C81, IRGKangXi=0586.020, Def{to beat; to strike; to attack, to control, to charge; to sue, to kill all}
3C82 CJK UNIFIED IDEOGRAPH-#3C82, IRGKangXi=0586.030, Def{to push, unceremoniously; impudently}
3C83 CJK UNIFIED IDEOGRAPH-#3C83, IRGKangXi=0586.040, Def{smooth and curved, to strike or beat heavily}
3C84 CJK UNIFIED IDEOGRAPH-#3C84, IRGKangXi=0587.031, Def{unburnt bricks or tiles}
3C85 CJK UNIFIED IDEOGRAPH-#3C85, IRGKangXi=0587.090, Def{to bind, to exhaust; to use up; to complete; to finish, to slay}
3C86 CJK UNIFIED IDEOGRAPH-#3C86, IRGKangXi=0587.240, Def{noise}
3C87 CJK UNIFIED IDEOGRAPH-#3C87, IRGKangXi=0587.260, Def{(non-classical form of 鼕) the rattle of drums}
3C88 CJK UNIFIED IDEOGRAPH-#3C88, IRGKangXi=0587.270, Def{(same as 韶) the name of the music of the legendary Emperor, harmonious, (large seal type 鞀 婸) hand-drum used by pedlars; it is sounded by twirling it backwards in the hand, so that two swinging knobs can strike the face of the drum}
3C89 CJK UNIFIED IDEOGRAPH-#3C89, IRGKangXi=0588.030, Def{egg shells}
3C8A CJK UNIFIED IDEOGRAPH-#3C8A, IRGKangXi=0588.080, Def{(corrupted form of 叡) to understand thoroughly; quick or keen of perception, wise and clever, the profoundest; the divine sagacity of sages}
3C8B CJK UNIFIED IDEOGRAPH-#3C8B, IRGKangXi=0591.050, Def{a kind of animals (like rabbit, it is blue colored and much bigger)}
3C8C CJK UNIFIED IDEOGRAPH-#3C8C, IRGKangXi=0592.030, Def{dog's hair}
3C8D CJK UNIFIED IDEOGRAPH-#3C8D, IRGKangXi=0592.080, Def{woolen textiles; fine cloth}
3C8E CJK UNIFIED IDEOGRAPH-#3C8E, IRGKangXi=0592.120, Def{(non-classical form of 氀) woolen textiles; (non-classical form of 毹) woolen blanket, a kind of minority dress; stupid and vulgar}
3C8F CJK UNIFIED IDEOGRAPH-#3C8F, IRGKangXi=0592.150, Def{flying feather, soft; light}
3C90 CJK UNIFIED IDEOGRAPH-#3C90, IRGKangXi=0592.161
3C91 CJK UNIFIED IDEOGRAPH-#3C91, IRGKangXi=0592.161
3C92 CJK UNIFIED IDEOGRAPH-#3C92, IRGKangXi=0592.250, Def{(same as U+83E2 菢) to incubate; to brood; to hatch; to sit on a nest, a woolen blanket}
3C93 CJK UNIFIED IDEOGRAPH-#3C93, IRGKangXi=0593.090, Def{(a variant of 絨) fine, soft fur or hair; down, felt, camel's hair}
3C94 CJK UNIFIED IDEOGRAPH-#3C94, IRGKangXi=0593.120, Def{woolen textiles; fine cloth}
3C95 CJK UNIFIED IDEOGRAPH-#3C95, IRGKangXi=0593.130, Def{variegated; woolen fabric of different colors}
3C96 CJK UNIFIED IDEOGRAPH-#3C96, IRGKangXi=0593.140, Def{fur; feather; soft and light}
3C97 CJK UNIFIED IDEOGRAPH-#3C97, IRGKangXi=0593.190, Def{to smooth the hair, woolen textiles; fine cloth}
3C98 CJK UNIFIED IDEOGRAPH-#3C98, IRGKangXi=0593.260, Def{(corrupted form of 氍) fine woolen cloth, a mat used by the emperor in worshipping}
3C99 CJK UNIFIED IDEOGRAPH-#3C99, IRGKangXi=0593.270, Def{(same as 毹) woolen blanket with decorative design or pattern, to waste; to destroy}
3C9A CJK UNIFIED IDEOGRAPH-#3C9A, IRGKangXi=0593.290, Def{long hair}
3C9B CJK UNIFIED IDEOGRAPH-#3C9B, IRGKangXi=0594.040, Def{hairy animals}
3C9C CJK UNIFIED IDEOGRAPH-#3C9C, IRGKangXi=0594.060, Def{(non-classical form of 毯) rugs; carpets}
3C9D CJK UNIFIED IDEOGRAPH-#3C9D, IRGKangXi=0594.130, Def{(corrupt form of 氄) fine hair of birds and animals}
3C9E CJK UNIFIED IDEOGRAPH-#3C9E, IRGKangXi=0594.140, Def{short hair, growing hair}
3C9F CJK UNIFIED IDEOGRAPH-#3C9F, IRGKangXi=0594.290, Def{hair}
3CA0 CJK UNIFIED IDEOGRAPH-#3CA0, IRGKangXi=0594.330, Def{(non-classical, abbreviated form of 氂) horse tail, long hair; thick hair, (variant of 膧) a wild yak}
3CA1 CJK UNIFIED IDEOGRAPH-#3CA1, IRGKangXi=0594.350, Def{thick coat of fur, hairy}
3CA2 CJK UNIFIED IDEOGRAPH-#3CA2, IRGKangXi=0595.050, Def{hair knots in a mess}
3CA3 CJK UNIFIED IDEOGRAPH-#3CA3, IRGKangXi=0595.140, Def{woolen blanket with decorative design or pattern}
3CA4 CJK UNIFIED IDEOGRAPH-#3CA4, IRGKangXi=0595.160, Def{long hair, a few thin hair hangging down}
3CA5 CJK UNIFIED IDEOGRAPH-#3CA5, IRGKangXi=0595.220, Def{a kind of woolen textiles with curved pattern, a decorative ornament on an official hat}
3CA6 CJK UNIFIED IDEOGRAPH-#3CA6, IRGKangXi=0595.230, Def{long hair; mane}
3CA7 CJK UNIFIED IDEOGRAPH-#3CA7, IRGKangXi=0595.250, Def{hairy}
3CA8 CJK UNIFIED IDEOGRAPH-#3CA8, IRGKangXi=0595.260, Def{a decorative fine blanket on the top of a saddle, petty; trifling}
3CA9 CJK UNIFIED IDEOGRAPH-#3CA9, IRGKangXi=0595.351
3CAA CJK UNIFIED IDEOGRAPH-#3CAA, IRGKangXi=0596.120, Def{woolen blanket with decorative design or pattern, a kind of animal}
3CAB CJK UNIFIED IDEOGRAPH-#3CAB, IRGKangXi=0596.130, Def{hair knots in a mess}
3CAC CJK UNIFIED IDEOGRAPH-#3CAC, IRGKangXi=0596.180, Def{hair decorations on a helmet used in ancient times, weak and weary; weak from exhaustion; tired looking of a bird's feather}
3CAD CJK UNIFIED IDEOGRAPH-#3CAD, IRGKangXi=0596.220, Def{(corrupted form of 毯) rug; carpet; blanket}
3CAE CJK UNIFIED IDEOGRAPH-#3CAE, IRGKangXi=0596.231
3CAF CJK UNIFIED IDEOGRAPH-#3CAF, IRGKangXi=0596.360, Def{long hairy}
3CB0 CJK UNIFIED IDEOGRAPH-#3CB0, IRGKangXi=0596.380, Def{a hairy dog}
3CB1 CJK UNIFIED IDEOGRAPH-#3CB1, IRGKangXi=0597.050, Def{(same as 鬣) long beard or whiskers, a mane; bristles, as on a hog; dorsal fins}
3CB2 CJK UNIFIED IDEOGRAPH-#3CB2, IRGKangXi=0597.161, Def{fine cotton cloth; fine woolen cloth}
3CB3 CJK UNIFIED IDEOGRAPH-#3CB3, IRGKangXi=0598.090, Def{to touch; to ram, to pull with hands}
3CB4 CJK UNIFIED IDEOGRAPH-#3CB4, IRGKangXi=0599.100, Def{mind; disposition; temper}
3CB5 CJK UNIFIED IDEOGRAPH-#3CB5, IRGKangXi=0600.010, Def{(same as 霄) the skies, night, to exhaust; to dissolve, clouds or mists}
3CB6 CJK UNIFIED IDEOGRAPH-#3CB6, IRGKangXi=0600.051, Def{(old translated form) chlorine (symbol Cl)}
3CB7 CJK UNIFIED IDEOGRAPH-#3CB7, IRGKangXi=0600.051, Def{(old translated form) nitrogen (symbol N)}
3CB8 CJK UNIFIED IDEOGRAPH-#3CB8, IRGKangXi=0603.050, Def{dried up (of waterway; the channel of a river; a pond, etc.)}
3CB9 CJK UNIFIED IDEOGRAPH-#3CB9, IRGKangXi=0603.060, Def{(non-classical form of 氿) the dry soil on the river side, spring water from the hole of mountain side, a small fountain, shore; bank; beach, name of a lake in today's Jiangsu Province Yixing county}
3CBA CJK UNIFIED IDEOGRAPH-#3CBA, IRGKangXi=0603.090, Def{to wash; to rinse; to clean; to spurt; to blow out}
3CBB CJK UNIFIED IDEOGRAPH-#3CBB, IRGKangXi=0603.110, Def{(ancient form of U+6EBA 溺) sunk; perished, drawn; infatuated}
3CBC CJK UNIFIED IDEOGRAPH-#3CBC, IRGKangXi=0604.060, Def{name of a river, (same as 汊) a branching stream; branching creeks}
3CBD CJK UNIFIED IDEOGRAPH-#3CBD, IRGKangXi=0606.010, Def{name of a river in today's southwest of Shanxi Province, the wet things attach or stick up to each other, dirty and muddy}
3CBE CJK UNIFIED IDEOGRAPH-#3CBE, IRGKangXi=0607.030, Def{(same as 雨) rain, to rain down; to pour down}
3CBF CJK UNIFIED IDEOGRAPH-#3CBF, IRGKangXi=0607.051, Def{extensive body of water; broad and deep of water; momentum of moving water deep and wide}
3CC0 CJK UNIFIED IDEOGRAPH-#3CC0, IRGKangXi=0608.020, Def{a river in ancient times}
3CC1 CJK UNIFIED IDEOGRAPH-#3CC1, IRGKangXi=0609.020, Def{water flow; water current; momentum of moving water}
3CC2 CJK UNIFIED IDEOGRAPH-#3CC2, IRGKangXi=0609.080, Def{(same as 沿) to follow a course; to go along; to coast, to hand down; to continue, to conserve; along or by, as a road or a coast}
3CC3 CJK UNIFIED IDEOGRAPH-#3CC3, IRGKangXi=0611.040, Def{(non-classical of 淬) to temper iron, or steel for making swords, etc. (also used figuratively), to dip into water; to soak; to dye}
3CC4 CJK UNIFIED IDEOGRAPH-#3CC4, IRGKangXi=0611.090, Def{(a variant of 涎) spittle, saliva}
3CC5 CJK UNIFIED IDEOGRAPH-#3CC5, IRGKangXi=0611.140, Def{(ancient form of 流) to flow, to drift, to circulate, a current, to descend, unstable; weak}
3CC6 CJK UNIFIED IDEOGRAPH-#3CC6, IRGKangXi=0612.090, Def{name of a place in ancient times}
3CC7 CJK UNIFIED IDEOGRAPH-#3CC7, IRGKangXi=0612.121, Def{name of a place in today's Jiangsu Province Yixing county, to float; to waft; to swim}
3CC8 CJK UNIFIED IDEOGRAPH-#3CC8, IRGKangXi=0612.121, Def{(standard form of 沛) a great flow of water; flowing copiously, quickly; rapidly; sudden, flourishing; luxuriant; prosperous or abundant, marsh; swamp}
3CC9 CJK UNIFIED IDEOGRAPH-#3CC9, IRGKangXi=0612.121
3CCA CJK UNIFIED IDEOGRAPH-#3CCA, IRGKangXi=0612.121, Def{(same as 攸) the flowing of the water, name of a river}
3CCB CJK UNIFIED IDEOGRAPH-#3CCB, IRGKangXi=0613.050, Def{a river in ancient times}
3CCC CJK UNIFIED IDEOGRAPH-#3CCC, IRGKangXi=0614.060, Def{marshy; swampy, damp; moist}
3CCD CJK UNIFIED IDEOGRAPH-#3CCD, IRGKangXi=0615.150, Def{a place in ancient times}
3CCE CJK UNIFIED IDEOGRAPH-#3CCE, IRGKangXi=0615.160, Def{guide or lead to make the water flowing smoothly}
3CCF CJK UNIFIED IDEOGRAPH-#3CCF, IRGKangXi=0616.060, Def{a river in ancient times; in Henan Province}
3CD0 CJK UNIFIED IDEOGRAPH-#3CD0, IRGKangXi=0617.040, Def{flowing of the water, sound of the flowing water}
3CD1 CJK UNIFIED IDEOGRAPH-#3CD1, IRGKangXi=0619.040, Def{(abbreviaded form of 溢) to flow over; to brim over, excessive}
3CD2 CJK UNIFIED IDEOGRAPH-#3CD2, IRGKangXi=0619.121, Def{(a variant of 法) statutes, laws, regulations, a rule, legal standard, plan or methods, etc.}
3CD3 CJK UNIFIED IDEOGRAPH-#3CD3, IRGKangXi=0619.121
3CD4 CJK UNIFIED IDEOGRAPH-#3CD4, IRGKangXi=0619.121, Def{to soak or be soaked; to dip; to immerse}
3CD5 CJK UNIFIED IDEOGRAPH-#3CD5, IRGKangXi=0619.121, Def{(simplified form of 灡) water in which rice has been washed, (interchangeable 瀾) a great wave; a huge billow}
3CD6 CJK UNIFIED IDEOGRAPH-#3CD6, IRGKangXi=0619.240, Def{name of a river}
3CD7 CJK UNIFIED IDEOGRAPH-#3CD7, IRGKangXi=0619.300, Def{bank of a river, (same as 汊) a branching stream}
3CD8 CJK UNIFIED IDEOGRAPH-#3CD8, IRGKangXi=0619.320, Def{a fountain or spring flows downwards, sound of the flowing water}
3CD9 CJK UNIFIED IDEOGRAPH-#3CD9, IRGKangXi=0620.030, Def{(non-classical form of 涓) a brook, the smallest drop of water, to expel evil influences; to eliminate; rid off, to clean up, to select, a tributary (or a river), the flowing of a spring, (interchangeable 泫) to glisten; to sparkle, to weep}
3CDA CJK UNIFIED IDEOGRAPH-#3CDA, IRGKangXi=0620.080, Def{flowing of the water}
3CDB CJK UNIFIED IDEOGRAPH-#3CDB, IRGKangXi=0622.020, Def{dirty; filthy, corrupt, soap, black, to unravel silk threads}
3CDC CJK UNIFIED IDEOGRAPH-#3CDC, IRGKangXi=0622.060, Def{the flowing water}
3CDD CJK UNIFIED IDEOGRAPH-#3CDD, IRGKangXi=0623.130, Def{(corrupted form of U+6D2D 洭) a river in ancient times; a part of Huangjiang, Lianjiang and Beijiang in today's north-west of Guangdong Province}
3CDE CJK UNIFIED IDEOGRAPH-#3CDE, IRGKangXi=0623.171, Def{(same as 浺) deep and far; profound and abstruse (of the sea)}
3CDF CJK UNIFIED IDEOGRAPH-#3CDF, IRGKangXi=0623.171
3CE0 CJK UNIFIED IDEOGRAPH-#3CE0, IRGKangXi=0627.311, Def{(simplified form of 澾) slippery (as a road)}
3CE1 CJK UNIFIED IDEOGRAPH-#3CE1, IRGKangXi=0627.311, Def{(simplified form of 濄) (same as 渦) name of a river, to whirl, an eddy}
3CE2 CJK UNIFIED IDEOGRAPH-#3CE2, IRGKangXi=0623.171
3CE3 CJK UNIFIED IDEOGRAPH-#3CE3, IRGKangXi=0623.171
3CE4 CJK UNIFIED IDEOGRAPH-#3CE4, IRGKangXi=0624.080, Def{(non-classical form of 淑) good; pure; virtuous, beautiful or charming (women), clear}
3CE5 CJK UNIFIED IDEOGRAPH-#3CE5, IRGKangXi=0624.090, Def{a river in ancient times}
3CE6 CJK UNIFIED IDEOGRAPH-#3CE6, IRGKangXi=0624.170, Def{a river}
3CE7 CJK UNIFIED IDEOGRAPH-#3CE7, IRGKangXi=0625.080, Def{the water flowing from ..., the current of a stream}
3CE8 CJK UNIFIED IDEOGRAPH-#3CE8, IRGKangXi=0625.100, Def{to splash (of water)}
3CE9 CJK UNIFIED IDEOGRAPH-#3CE9, IRGKangXi=0625.110, Def{great billows; large waves; the waves swelling up}
3CEA CJK UNIFIED IDEOGRAPH-#3CEA, IRGKangXi=0626.050, Def{a river}
3CEB CJK UNIFIED IDEOGRAPH-#3CEB, IRGKangXi=0626.060, Def{(corrupted form of 沓) repeated; joined, crowded together, a family name}
3CEC CJK UNIFIED IDEOGRAPH-#3CEC, IRGKangXi=0626.160, Def{an eddy; a whirlpool}
3CED CJK UNIFIED IDEOGRAPH-#3CED, IRGKangXi=0627.210, Def{(non-classical form of U+6D8E 涎) spittle, saliva}
3CEE CJK UNIFIED IDEOGRAPH-#3CEE, IRGKangXi=0627.270, Def{(interchangeable 尿) urine, to urinate}
3CEF CJK UNIFIED IDEOGRAPH-#3CEF, IRGKangXi=0627.280, Def{goddess of an ink-slab}
3CF0 CJK UNIFIED IDEOGRAPH-#3CF0, IRGKangXi=0627.311, Def{(same as 溝) ditch; waterway; moat, groove}
3CF1 CJK UNIFIED IDEOGRAPH-#3CF1, IRGKangXi=0627.311
3CF2 CJK UNIFIED IDEOGRAPH-#3CF2, IRGKangXi=0627.311
3CF3 CJK UNIFIED IDEOGRAPH-#3CF3, IRGKangXi=0627.311
3CF4 CJK UNIFIED IDEOGRAPH-#3CF4, IRGKangXi=0628.060, Def{mud; quagmire}
3CF5 CJK UNIFIED IDEOGRAPH-#3CF5, IRGKangXi=0628.120, Def{name of a river}
3CF6 CJK UNIFIED IDEOGRAPH-#3CF6, IRGKangXi=0628.150, Def{name of a river, to give suck to, (same as 醹) vintage wine, (same as 乳) milk; breasts}
3CF7 CJK UNIFIED IDEOGRAPH-#3CF7, IRGKangXi=0628.220, Def{dark blue color, to combine; to unite, to close; to shut, the water is exhausted, to get the color away by soaking in the water}
3CF8 CJK UNIFIED IDEOGRAPH-#3CF8, IRGKangXi=0629.130, Def{name of a river}
3CF9 CJK UNIFIED IDEOGRAPH-#3CF9, IRGKangXi=0629.160, Def{flood; a great flood; massive water, name a river, name of a place in today's Shanxi Province east of Yin county, (same as 汪) deep and extensive (said of water)}
3CFA CJK UNIFIED IDEOGRAPH-#3CFA, IRGKangXi=0630.100, Def{(non-classical form of 游) to swim; to float, to roam; to travel}
3CFB CJK UNIFIED IDEOGRAPH-#3CFB, IRGKangXi=0630.150, Def{a bank of earth or an embankment to block the current of the water, to stop (or block) up the flowing water}
3CFC CJK UNIFIED IDEOGRAPH-#3CFC, IRGKangXi=0630.190, Def{(same as 滭) bubbling of fountain; copious of spring (same as 淢) swift currents (interchangeable 洫) a ditch; a moat, to overflow}
3CFD CJK UNIFIED IDEOGRAPH-#3CFD, IRGKangXi=0631.020, Def{(non-classical abbreviated form of 瀰) a watery expanse, to be covered with, to disseminate every where, currents of the water}
3CFE CJK UNIFIED IDEOGRAPH-#3CFE, IRGKangXi=0631.070, Def{(standard form of 羌) name of a river}
3CFF CJK UNIFIED IDEOGRAPH-#3CFF, IRGKangXi=0631.130, Def{(same as 渫) rolling billows, to get rid of; to scatter, muddy, to ooze}
3D00 CJK UNIFIED IDEOGRAPH-#3D00, IRGKangXi=0633.040, Def{deep}
3D01 CJK UNIFIED IDEOGRAPH-#3D01, IRGKangXi=0633.060, Def{to add to; to increase; increase; full, plentiful; abundant, saliva}
3D02 CJK UNIFIED IDEOGRAPH-#3D02, IRGKangXi=0633.180, Def{great billows; great upheavals; boisterous breakers}
3D03 CJK UNIFIED IDEOGRAPH-#3D03, IRGKangXi=0633.200, Def{(same as 淚) tears}
3D04 CJK UNIFIED IDEOGRAPH-#3D04, IRGKangXi=0633.250, Def{the water flowing in a turned, crooked or winding and revolving way; an eddy}
3D05 CJK UNIFIED IDEOGRAPH-#3D05, IRGKangXi=0633.260, Def{(ancient form of 消) to melt; to thaw, to disperse; to dissipate, to cancel; to annul}
3D06 CJK UNIFIED IDEOGRAPH-#3D06, IRGKangXi=0633.290, Def{(same as 浸) to dip; to immerse; to soak; to permeate; to percolate, gradual; gradually}
3D07 CJK UNIFIED IDEOGRAPH-#3D07, IRGKangXi=0633.320, Def{(same as 涉) to wade, to experience, to involve; to implicate}
3D08 CJK UNIFIED IDEOGRAPH-#3D08, IRGKangXi=0633.330, Def{(same as 垽) sediment; dregs; precipitate; lees}
3D09 CJK UNIFIED IDEOGRAPH-#3D09, IRGKangXi=0631.180, Def{(ancient form of 濟) various; varied; numerous, elegant and dignified}
3D0A CJK UNIFIED IDEOGRAPH-#3D0A, IRGKangXi=0633.371, Def{(same as U+6E06 淵) an abyss; a gulf, to be deep}
3D0B CJK UNIFIED IDEOGRAPH-#3D0B, IRGKangXi=0633.371, Def{(simplified form of 潚) deep and clear (said of water) (same as 溲) to urinate, to immerse; to soak; to drench, to wash rice (same as 瀟) rushing rain and wind; roar of gust}
3D0C CJK UNIFIED IDEOGRAPH-#3D0C, IRGKangXi=0633.371
3D0D CJK UNIFIED IDEOGRAPH-#3D0D, IRGKangXi=0633.371
3D0E CJK UNIFIED IDEOGRAPH-#3D0E, IRGKangXi=0633.371
3D0F CJK UNIFIED IDEOGRAPH-#3D0F, IRGKangXi=0634.040, Def{the pond water is still}
3D10 CJK UNIFIED IDEOGRAPH-#3D10, IRGKangXi=0634.110, Def{great current, flood, flowing water}
3D11 CJK UNIFIED IDEOGRAPH-#3D11, IRGKangXi=0634.130, Def{(same as 泝) to trace up to a source, to go against the stream/water}
3D12 CJK UNIFIED IDEOGRAPH-#3D12, IRGKangXi=0635.210, Def{water current; water flow}
3D13 CJK UNIFIED IDEOGRAPH-#3D13, IRGKangXi=0636.010, Def{to wash rice}
3D14 CJK UNIFIED IDEOGRAPH-#3D14, IRGKangXi=0636.160, Def{(same as 潝) the noise of flowing water, swift flowing water (same as non-classical form of 澀) rough; harsh; not smooth, a slightly bitter taste}
3D15 CJK UNIFIED IDEOGRAPH-#3D15, IRGKangXi=0636.180, Def{to boil away; to boil over, boiling sound, sound of the flowing water, etc., (interchangeable 渫) rolling billows}
3D16 CJK UNIFIED IDEOGRAPH-#3D16, IRGKangXi=0637.060, Def{(same as 濼) name of a stream in Shandong Province southwest of Jinan, (same as 泊) lakes, a hot spring; a mineral spring}
3D17 CJK UNIFIED IDEOGRAPH-#3D17, IRGKangXi=0637.090, Def{deep}
3D18 CJK UNIFIED IDEOGRAPH-#3D18, IRGKangXi=0638.040, Def{to ooze out; to well out; to spring out, to well up; flood tide; the water is rising}
3D19 CJK UNIFIED IDEOGRAPH-#3D19, IRGKangXi=0638.080, Def{water dripping; a drip-tile (same as 炸 煠 爚) to fry in fat or oil, to scald}
3D1A CJK UNIFIED IDEOGRAPH-#3D1A, IRGKangXi=0638.140, Def{the small ditch in the field}
3D1B CJK UNIFIED IDEOGRAPH-#3D1B, IRGKangXi=0638.240, Def{damp; wet; moist; humid}
3D1C CJK UNIFIED IDEOGRAPH-#3D1C, IRGKangXi=0638.360, Def{(same as 遍) everywhere; all over, a time}
3D1D CJK UNIFIED IDEOGRAPH-#3D1D, IRGKangXi=0639.090, Def{(a variant of U+9ECE 黎) many; numerous, black; dark}
3D1E CJK UNIFIED IDEOGRAPH-#3D1E, IRGKangXi=0639.111, Def{(same as 滔) fluent, to fill; to prevail}
3D1F CJK UNIFIED IDEOGRAPH-#3D1F, IRGKangXi=0639.111
3D20 CJK UNIFIED IDEOGRAPH-#3D20, IRGKangXi=0639.111
3D21 CJK UNIFIED IDEOGRAPH-#3D21, IRGKangXi=0639.111
3D22 CJK UNIFIED IDEOGRAPH-#3D22, IRGKangXi=0639.111
3D23 CJK UNIFIED IDEOGRAPH-#3D23, IRGKangXi=0639.111
3D24 CJK UNIFIED IDEOGRAPH-#3D24, IRGKangXi=0639.111
3D25 CJK UNIFIED IDEOGRAPH-#3D25, IRGKangXi=0639.210, Def{great billows; heavy seas rolling in}
3D26 CJK UNIFIED IDEOGRAPH-#3D26, IRGKangXi=0639.290, Def{(corrupted form of 涫) (interchangeable 盥) to wash hands, to wash, to boil}
3D27 CJK UNIFIED IDEOGRAPH-#3D27, IRGKangXi=0640.080, Def{of flowing water, a river}
3D28 CJK UNIFIED IDEOGRAPH-#3D28, IRGKangXi=0640.130, Def{water current; water flow}
3D29 CJK UNIFIED IDEOGRAPH-#3D29, IRGKangXi=0640.180, Def{(same as 灉) name of a stream in Shandong Province, the flowing back of flooding waters, a sluice}
3D2A CJK UNIFIED IDEOGRAPH-#3D2A, IRGKangXi=0640.200, Def{name of a river}
3D2B CJK UNIFIED IDEOGRAPH-#3D2B, IRGKangXi=0640.210, Def{great flowing; big flood, name of a county in ancient times}
3D2C CJK UNIFIED IDEOGRAPH-#3D2C, IRGKangXi=0640.290, Def{a river in ancient times; head of source from today's Henan Province Xinanxian; and flowing south to Luoshui}
3D2D CJK UNIFIED IDEOGRAPH-#3D2D, IRGKangXi=0641.090, Def{immeasurable depth or profundity; extremely abstruse; unfathomable}
3D2E CJK UNIFIED IDEOGRAPH-#3D2E, IRGKangXi=0641.150, Def{water current; water flow}
3D2F CJK UNIFIED IDEOGRAPH-#3D2F, IRGKangXi=0641.160, Def{water current; water flow, name of a stream}
3D30 CJK UNIFIED IDEOGRAPH-#3D30, IRGKangXi=0641.230, Def{a river in ancient times}
3D31 CJK UNIFIED IDEOGRAPH-#3D31, IRGKangXi=0641.270, Def{(ancient form of 深) deep, profound, far, very; extremely}
3D32 CJK UNIFIED IDEOGRAPH-#3D32, IRGKangXi=0642.060, Def{a river in ancient time; today's Baiquanhe, water's edge; water-front; a bank; a limit}
3D33 CJK UNIFIED IDEOGRAPH-#3D33, IRGKangXi=0642.080, Def{(corrupted form) to smear; to spread, to paint, to blot out, mud; mire, ignorant (said of a child) innocent}
3D34 CJK UNIFIED IDEOGRAPH-#3D34, IRGKangXi=0642.140, Def{(ancient form of 湛) (interchangeable 沈 沉) sink, deep; profound, joy; delight, happy; peaceful (interchangeable 潭) deep water; deep pool, leisurely; relaxed, dewy, full; filled, wet; damp; moist, clear (interchangeable 浸) to dip; to immerse; to soak, swellings; roaring waves and billows, flowing water, (same as 霪 淫) to rain cats and dogs for a long time, a river in ancient times in Henan province Jiyuanxian (blocked)}
3D35 CJK UNIFIED IDEOGRAPH-#3D35, IRGKangXi=0642.190, Def{water current; water flow}
3D36 CJK UNIFIED IDEOGRAPH-#3D36, IRGKangXi=0642.210, Def{to water; to pour water; to irrigate, to wet; to moisten; to soak in, to wash}
3D37 CJK UNIFIED IDEOGRAPH-#3D37, IRGKangXi=0642.250, Def{wet; moist; damp, incessanty rains, flood; great current}
3D38 CJK UNIFIED IDEOGRAPH-#3D38, IRGKangXi=0643.020, Def{swift currents; swift flow of water}
3D39 CJK UNIFIED IDEOGRAPH-#3D39, IRGKangXi=0643.241
3D3A CJK UNIFIED IDEOGRAPH-#3D3A, IRGKangXi=0643.241
3D3B CJK UNIFIED IDEOGRAPH-#3D3B, IRGKangXi=0643.241
3D3C CJK UNIFIED IDEOGRAPH-#3D3C, IRGKangXi=0644.050, Def{wet; moist; damp}
3D3D CJK UNIFIED IDEOGRAPH-#3D3D, IRGKangXi=0644.130, Def{water current, water flow}
3D3E CJK UNIFIED IDEOGRAPH-#3D3E, IRGKangXi=0645.060, Def{(same as 渤) (of water) swelling or rising; an inland sea among today's Liaoning, Hebei and Shandong Provinces}
3D3F CJK UNIFIED IDEOGRAPH-#3D3F, IRGKangXi=0645.100, Def{(same as 濎) (water etc.) boiling}
3D40 CJK UNIFIED IDEOGRAPH-#3D40, IRGKangXi=0646.020, Def{water flow; water current}
3D41 CJK UNIFIED IDEOGRAPH-#3D41, IRGKangXi=0646.050, Def{vast and boundless of flowing water, a water waste, to reach}
3D42 CJK UNIFIED IDEOGRAPH-#3D42, IRGKangXi=0646.070, Def{name of a river}
3D43 CJK UNIFIED IDEOGRAPH-#3D43, IRGKangXi=0646.140, Def{name of a stream}
3D44 CJK UNIFIED IDEOGRAPH-#3D44, IRGKangXi=0646.200, Def{(same as 漢) name of a dynasty, belonging to China, the Milky Way the Han River, (interchangeable 域) a frontier; a boundary; a region; a country, to live; to stay}
3D45 CJK UNIFIED IDEOGRAPH-#3D45, IRGKangXi=0646.230, Def{a river, in today's northeast of Sichuan Province, between Bazhong and Tongjiang}
3D46 CJK UNIFIED IDEOGRAPH-#3D46, IRGKangXi=0648.160, Def{(same as 澔 浩) radiance of gems, great currents; vast water flow}
3D47 CJK UNIFIED IDEOGRAPH-#3D47, IRGKangXi=0648.281
3D48 CJK UNIFIED IDEOGRAPH-#3D48, IRGKangXi=0648.281
3D49 CJK UNIFIED IDEOGRAPH-#3D49, IRGKangXi=0648.281
3D4A CJK UNIFIED IDEOGRAPH-#3D4A, IRGKangXi=0648.360, Def{moving image; moving shadow, flowing water}
3D4B CJK UNIFIED IDEOGRAPH-#3D4B, IRGKangXi=0648.380, Def{(variant of 汨) name of a river in Hunan Province}
3D4C CJK UNIFIED IDEOGRAPH-#3D4C, IRGKangXi=0649.020, Def{to flow; to move; to stray}
3D4D CJK UNIFIED IDEOGRAPH-#3D4D, IRGKangXi=0649.210, Def{filled with water; full of water, annoyed; vexed; depressed; bored, to make tea by boiling water and then put the lid on to cover it}
3D4E CJK UNIFIED IDEOGRAPH-#3D4E, IRGKangXi=0649.220, Def{a mountain stream or torrent, a number measuring used in ancient times; a hundred million waterways (ditches) equal to a mountain stream, a river in ancient, head source in south of Henan Province, flowing east then north to combine with Gushui (today's Jianhe)}
3D4F CJK UNIFIED IDEOGRAPH-#3D4F, IRGKangXi=0650.080, Def{(same as 漼) having the appearance of depth, to shed tears; to cry or weep, sharp, bright-colored, a river in ancient times; Guishui, (interchangeable 摧) to destroy; to injure; to damage, to store up; to accumulate}
3D50 CJK UNIFIED IDEOGRAPH-#3D50, IRGKangXi=0650.110, Def{name of a river in Hubei Province, name of a state in ancient times}
3D51 CJK UNIFIED IDEOGRAPH-#3D51, IRGKangXi=0650.140, Def{name of a river}
3D52 CJK UNIFIED IDEOGRAPH-#3D52, IRGKangXi=0650.180, Def{(same as U+6CB8 沸) boiling (water, etc.) to gush; bubbling up, (sane as U+6E43 湃) the roaring of billows, name of a person}
3D53 CJK UNIFIED IDEOGRAPH-#3D53, IRGKangXi=0650.250, Def{(same as 湜) the water is clear, transparent (of water)}
3D54 CJK UNIFIED IDEOGRAPH-#3D54, IRGKangXi=0650.310, Def{not clear; not pure}
3D55 CJK UNIFIED IDEOGRAPH-#3D55, IRGKangXi=0651.140, Def{(same as 滲) to permeate; to seep; to ooze; to leak; to soak through}
3D56 CJK UNIFIED IDEOGRAPH-#3D56, IRGKangXi=0651.310, Def{damp; moist; wet}
3D57 CJK UNIFIED IDEOGRAPH-#3D57, IRGKangXi=0651.370, Def{turbulent (said of water)}
3D58 CJK UNIFIED IDEOGRAPH-#3D58, IRGKangXi=0652.321, Def{great currents}
3D59 CJK UNIFIED IDEOGRAPH-#3D59, IRGKangXi=0652.321, Def{(corrupted form of 清) pure; clear, brief; virtuous; to place in order, simple and easily understandable}
3D5A CJK UNIFIED IDEOGRAPH-#3D5A, IRGKangXi=0652.321
3D5B CJK UNIFIED IDEOGRAPH-#3D5B, IRGKangXi=0652.321
3D5C CJK UNIFIED IDEOGRAPH-#3D5C, IRGKangXi=0652.321
3D5D CJK UNIFIED IDEOGRAPH-#3D5D, IRGKangXi=0652.370, Def{moving, as in ripples; moving to and fro (said of water) (interchangeable 裔) the hem of a robe, a border, a frontier, border bribes}
3D5E CJK UNIFIED IDEOGRAPH-#3D5E, IRGKangXi=0652.460, Def{bellied in water-gas, belch; burp}
3D5F CJK UNIFIED IDEOGRAPH-#3D5F, IRGKangXi=0653.040, Def{(non-classical form of 溦) light rain; drizzle}
3D60 CJK UNIFIED IDEOGRAPH-#3D60, IRGKangXi=0653.070, Def{to gush forth; to well out; to spring out, deep water}
3D61 CJK UNIFIED IDEOGRAPH-#3D61, IRGKangXi=0653.100, Def{(said of flow of water) swift and torrential; turbulent flow of water}
3D62 CJK UNIFIED IDEOGRAPH-#3D62, IRGKangXi=0653.120, Def{a marsh in ancient times; in today's Shandong Province; betweem Heze and Yun Cheng}
3D63 CJK UNIFIED IDEOGRAPH-#3D63, IRGKangXi=0653.170, Def{(same as 渴) thirsty, to thirst, urgent; anxiously (awaiting, etc.), (interchangeable 愒) to rest; to stop, to idle away (time)}
3D64 CJK UNIFIED IDEOGRAPH-#3D64, IRGKangXi=0653.230, Def{to overflow; to spread}
3D65 CJK UNIFIED IDEOGRAPH-#3D65, IRGKangXi=0653.240, Def{(a variant) water currents; flow water}
3D66 CJK UNIFIED IDEOGRAPH-#3D66, IRGKangXi=0654.030, Def{(same as 瀡) slippery}
3D67 CJK UNIFIED IDEOGRAPH-#3D67, IRGKangXi=0654.060, Def{name of a river, clear, pure; to cover; to hide}
3D68 CJK UNIFIED IDEOGRAPH-#3D68, IRGKangXi=0654.080, Def{a dry land in a river; an islet, tributary stream; an affluent stream}
3D69 CJK UNIFIED IDEOGRAPH-#3D69, IRGKangXi=0654.160, Def{many; flourishing; luxuriant growth (of vegetation)}
3D6A CJK UNIFIED IDEOGRAPH-#3D6A, IRGKangXi=0654.180, Def{(same as 涎) saliva, overflowing water, to rise, to board, a region; an area; a place}
3D6B CJK UNIFIED IDEOGRAPH-#3D6B, IRGKangXi=0654.280, Def{water gushing out; bubbling up, waves sweeping over the flowing water}
3D6C CJK UNIFIED IDEOGRAPH-#3D6C, IRGKangXi=0655.070, Def{used in person's name}
3D6D CJK UNIFIED IDEOGRAPH-#3D6D, IRGKangXi=0655.100, Def{(same as 渚) an islet, a bank; water's edge; water-front, island (in the sea), (interchangeable 劌) a pool; a pond or small lake, a stream in ancient times}
3D6E CJK UNIFIED IDEOGRAPH-#3D6E, IRGKangXi=0655.201, Def{clear (fresh) water}
3D6F CJK UNIFIED IDEOGRAPH-#3D6F, IRGKangXi=0655.260, Def{sound of water flowing; flowing water}
3D70 CJK UNIFIED IDEOGRAPH-#3D70, IRGKangXi=0655.320, Def{(same as 潊) name of a stream; Xushui (or Shuanglongjiang) in ancient times, waterside; shore}
3D71 CJK UNIFIED IDEOGRAPH-#3D71, IRGKangXi=0655.360, Def{flowing water}
3D72 CJK UNIFIED IDEOGRAPH-#3D72, IRGKangXi=0656.070, Def{(same as 潕) name of a river}
3D73 CJK UNIFIED IDEOGRAPH-#3D73, IRGKangXi=0656.160, Def{(same as non-classical form of 漻) crystal-clear (water), fluent, name of stream; in today's Hubei Province Xiaoganshi}
3D74 CJK UNIFIED IDEOGRAPH-#3D74, IRGKangXi=0656.180, Def{to sink}
3D75 CJK UNIFIED IDEOGRAPH-#3D75, IRGKangXi=0656.200, Def{swift currents of the stream, sound of water flowing; flowing water}
3D76 CJK UNIFIED IDEOGRAPH-#3D76, IRGKangXi=0657.110, Def{full; filled up}
3D77 CJK UNIFIED IDEOGRAPH-#3D77, IRGKangXi=0657.120, Def{turbulent flowing of the water, swift currents}
3D78 CJK UNIFIED IDEOGRAPH-#3D78, IRGKangXi=0657.240, Def{(same as non-classical abbreviated form of 瀹) to boil, to wash; to cleanse; to soak, to cook; to stew; to decoct, to channel, to enlighten, to clean or dredge (a waterway), water currents}
3D79 CJK UNIFIED IDEOGRAPH-#3D79, IRGKangXi=0657.300, Def{waves; breakers; billows, dense; thick}
3D7A CJK UNIFIED IDEOGRAPH-#3D7A, IRGKangXi=0657.361, Def{name of a stream in ancient times; in Danyang, to plant; to sow}
3D7B CJK UNIFIED IDEOGRAPH-#3D7B, IRGKangXi=0657.361, Def{(interchangeable 膄) to perspire from embarrassment or shame}
3D7C CJK UNIFIED IDEOGRAPH-#3D7C, IRGKangXi=0657.361
3D7D CJK UNIFIED IDEOGRAPH-#3D7D, IRGKangXi=0657.370, Def{(same as abbreviated form of 灅) the strength of a current, flowing water, name of a stream; at Yoybeiping}
3D7E CJK UNIFIED IDEOGRAPH-#3D7E, IRGKangXi=0658.020, Def{cold; chilly, (ancient form of 凈) clean; pure; to purify}
3D7F CJK UNIFIED IDEOGRAPH-#3D7F, IRGKangXi=0658.050, Def{endlessly long or vast water currents}
3D80 CJK UNIFIED IDEOGRAPH-#3D80, IRGKangXi=0658.290, Def{deep and vast of the flowing water, name of a stream}
3D81 CJK UNIFIED IDEOGRAPH-#3D81, IRGKangXi=0658.310, Def{after blocking the water flow takes different waterway, sound of the flowing water}
3D82 CJK UNIFIED IDEOGRAPH-#3D82, IRGKangXi=0659.291
3D83 CJK UNIFIED IDEOGRAPH-#3D83, IRGKangXi=0659.291
3D84 CJK UNIFIED IDEOGRAPH-#3D84, IRGKangXi=0659.370, Def{to stain, dirty; filth, water flows forward}
3D85 CJK UNIFIED IDEOGRAPH-#3D85, IRGKangXi=0659.410, Def{(same as 澩) dried up mountain creeks, a tributary of Weishui (in ancient times), sound of the roaring waves and billows}
3D86 CJK UNIFIED IDEOGRAPH-#3D86, IRGKangXi=0659.430, Def{name of a stream in Hebei Province Hengshan, name of a river (same as 涂水)}
3D87 CJK UNIFIED IDEOGRAPH-#3D87, IRGKangXi=0659.460, Def{a ferry, to across the river in a boat, a ferry boat, a raft}
3D88 CJK UNIFIED IDEOGRAPH-#3D88, IRGKangXi=0660.100, Def{(same as 濙 U+6FD9) creeks}
3D89 CJK UNIFIED IDEOGRAPH-#3D89, IRGKangXi=0659.291, Def{Mandarin duck, Aix galericulata}
3D8A CJK UNIFIED IDEOGRAPH-#3D8A, IRGKangXi=0659.291
3D8B CJK UNIFIED IDEOGRAPH-#3D8B, IRGKangXi=0659.291
3D8C CJK UNIFIED IDEOGRAPH-#3D8C, IRGKangXi=0660.330, Def{name of a stream; head source from Henan Province jiyuanxian Wangwushan}
3D8D CJK UNIFIED IDEOGRAPH-#3D8D, IRGKangXi=0661.040, Def{name of a stream}
3D8E CJK UNIFIED IDEOGRAPH-#3D8E, IRGKangXi=0661.150, Def{(same as 澴) swift and torrential (said of flow of water), name of a stream in Hubei Province}
3D8F CJK UNIFIED IDEOGRAPH-#3D8F, IRGKangXi=0661.240, Def{an ancient name of a river in Henan Province Dengfengxian}
3D90 CJK UNIFIED IDEOGRAPH-#3D90, IRGKangXi=0662.101
3D91 CJK UNIFIED IDEOGRAPH-#3D91, IRGKangXi=0662.101, Def{(same as 瀲) overflowing (water), the edge of a large body of water}
3D92 CJK UNIFIED IDEOGRAPH-#3D92, IRGKangXi=0662.130, Def{the current of a stream, brave; courageous; decision with courage; (a person) of determination, swift flowing of the water currents, to float; to waft, to overflow}
3D93 CJK UNIFIED IDEOGRAPH-#3D93, IRGKangXi=0662.190, Def{to sink; to drown; to be submerged}
3D94 CJK UNIFIED IDEOGRAPH-#3D94, IRGKangXi=0662.240, Def{(said of flow of water) swift and torrential, name of a stream}
3D95 CJK UNIFIED IDEOGRAPH-#3D95, IRGKangXi=0663.091, Def{to wash rice}
3D96 CJK UNIFIED IDEOGRAPH-#3D96, IRGKangXi=0662.290, Def{rapid; turbulent of the waves and billows}
3D97 CJK UNIFIED IDEOGRAPH-#3D97, IRGKangXi=0662.320, Def{well up; spring out of a fountain or geyser, name of a fountain in today's Henan Pronice}
3D98 CJK UNIFIED IDEOGRAPH-#3D98, IRGKangXi=0663.060, Def{full of water}
3D99 CJK UNIFIED IDEOGRAPH-#3D99, IRGKangXi=0663.091
3D9A CJK UNIFIED IDEOGRAPH-#3D9A, IRGKangXi=0663.271, Def{(a variant of 灞) name of a river in Shanxi}
3D9B CJK UNIFIED IDEOGRAPH-#3D9B, IRGKangXi=0663.290, Def{name of a river, moving; swinging as in ripples}
3D9C CJK UNIFIED IDEOGRAPH-#3D9C, IRGKangXi=0663.360, Def{(same as 淵) deep water; vast, profound}
3D9D CJK UNIFIED IDEOGRAPH-#3D9D, IRGKangXi=0663.421
3D9E CJK UNIFIED IDEOGRAPH-#3D9E, IRGKangXi=0663.440, Def{(same as 瀼) water currents; flowing of water, name of a river in Sichuan Province, heavily bedewed}
3D9F CJK UNIFIED IDEOGRAPH-#3D9F, IRGKangXi=0664.010, Def{an ancient name for a river in Shanxi and Hebei}
3DA0 CJK UNIFIED IDEOGRAPH-#3DA0, IRGKangXi=0664.160, Def{water currents; flowing of water}
3DA1 CJK UNIFIED IDEOGRAPH-#3DA1, IRGKangXi=0665.080, Def{(ancient form of 火) bright lights and illuminations of the fire, fire sounds}
3DA2 CJK UNIFIED IDEOGRAPH-#3DA2, IRGKangXi=0666.061
3DA3 CJK UNIFIED IDEOGRAPH-#3DA3, IRGKangXi=0666.100, Def{to burn; to heat, to burn over a wider and wider area; to glow; to shine, light; brightness}
3DA4 CJK UNIFIED IDEOGRAPH-#3DA4, IRGKangXi=0666.261, Def{(non-classical form of 炒) to fry; to roast; to cook}
3DA5 CJK UNIFIED IDEOGRAPH-#3DA5, IRGKangXi=0666.261
3DA6 CJK UNIFIED IDEOGRAPH-#3DA6, IRGKangXi=0666.300, Def{ashes; embers, remnants of}
3DA7 CJK UNIFIED IDEOGRAPH-#3DA7, IRGKangXi=0667.080, Def{warm}
3DA8 CJK UNIFIED IDEOGRAPH-#3DA8, IRGKangXi=0667.100, Def{(same as 炋) fire}
3DA9 CJK UNIFIED IDEOGRAPH-#3DA9, IRGKangXi=0668.031
3DAA CJK UNIFIED IDEOGRAPH-#3DAA, IRGKangXi=0668.031
3DAB CJK UNIFIED IDEOGRAPH-#3DAB, IRGKangXi=0668.070, Def{(corrupted form of 燎) to burn, to illuminate; a signal light; brilliant}
3DAC CJK UNIFIED IDEOGRAPH-#3DAC, IRGKangXi=0668.140, Def{bright lights and illuminations of the fire, flames}
3DAD CJK UNIFIED IDEOGRAPH-#3DAD, IRGKangXi=0668.230, Def{almost dry; not completely dried}
3DAE CJK UNIFIED IDEOGRAPH-#3DAE, IRGKangXi=0668.300, Def{(same as 燒) to burn, to roast, to boil; to heat}
3DAF CJK UNIFIED IDEOGRAPH-#3DAF, IRGKangXi=0669.050, Def{fire}
3DB0 CJK UNIFIED IDEOGRAPH-#3DB0, IRGKangXi=0669.090, Def{flame; fire, light; brightness}
3DB1 CJK UNIFIED IDEOGRAPH-#3DB1, IRGKangXi=0669.101
3DB2 CJK UNIFIED IDEOGRAPH-#3DB2, IRGKangXi=0669.101, Def{measuring unit for thermodynamics}
3DB3 CJK UNIFIED IDEOGRAPH-#3DB3, IRGKangXi=0669.260, Def{(same as 燼) ashes; ember}
3DB4 CJK UNIFIED IDEOGRAPH-#3DB4, IRGKangXi=0670.110, Def{a very great fire; flourishing flames, rich; exuberant; grand; prosperous}
3DB5 CJK UNIFIED IDEOGRAPH-#3DB5, IRGKangXi=0671.081, Def{(same as U+9901 飪) to cook food thoroughly}
3DB6 CJK UNIFIED IDEOGRAPH-#3DB6, IRGKangXi=0671.081, Def{scorched, burned}
3DB7 CJK UNIFIED IDEOGRAPH-#3DB7, IRGKangXi=0671.081
3DB8 CJK UNIFIED IDEOGRAPH-#3DB8, IRGKangXi=0671.081
3DB9 CJK UNIFIED IDEOGRAPH-#3DB9, IRGKangXi=0671.250, Def{fire; flames}
3DBA CJK UNIFIED IDEOGRAPH-#3DBA, IRGKangXi=0671.290, Def{the light or glow of fire}
3DBB CJK UNIFIED IDEOGRAPH-#3DBB, IRGKangXi=0672.050, Def{(same as 烽) a conical brick-structure in which to light a beacon; (in ancient China) a tall structure (on a city wall, etc.) where fire was made to signal enemy invasion or presence of bandits}
3DBC CJK UNIFIED IDEOGRAPH-#3DBC, IRGKangXi=0672.080, Def{very hot, to burn, to heat, to roast, dazzling; bright; shining, a very great fire; flourishing flames}
3DBD CJK UNIFIED IDEOGRAPH-#3DBD, IRGKangXi=0673.111, Def{(Cant.) 火㶽, to instant-boil thin slices of meat and vegetables in a chafing dish at the dining table}
3DBE CJK UNIFIED IDEOGRAPH-#3DBE, IRGKangXi=0672.150, Def{(non-classical abbreviated form of 熛) tough and honest; upright, flames burst into a blaze}
3DBF CJK UNIFIED IDEOGRAPH-#3DBF, IRGKangXi=0672.170, Def{the smoke went up; giving forth smoke; smoking; misty}
3DC0 CJK UNIFIED IDEOGRAPH-#3DC0, IRGKangXi=0673.111, Def{(same as 焭,煢,惸) solitary; alone; single; brotherless; friendless; helpless, dice; a kind of gambling game played in ancient times}
3DC1 CJK UNIFIED IDEOGRAPH-#3DC1, IRGKangXi=0673.111
3DC2 CJK UNIFIED IDEOGRAPH-#3DC2, IRGKangXi=0673.170, Def{bright; light; brilliant}
3DC3 CJK UNIFIED IDEOGRAPH-#3DC3, IRGKangXi=0673.190, Def{long-burning fire}
3DC4 CJK UNIFIED IDEOGRAPH-#3DC4, IRGKangXi=0673.250, Def{fire; flames}
3DC5 CJK UNIFIED IDEOGRAPH-#3DC5, IRGKangXi=0674.020, Def{(same as 炒) to cook; to stew or simmer; to fry; to roast; to broil (rice)}
3DC6 CJK UNIFIED IDEOGRAPH-#3DC6, IRGKangXi=0674.080, Def{thriving; flourishing}
3DC7 CJK UNIFIED IDEOGRAPH-#3DC7, IRGKangXi=0674.140, Def{(same as 恢) great; immense; enormous; vast; extensive}
3DC8 CJK UNIFIED IDEOGRAPH-#3DC8, IRGKangXi=0674.160, Def{embers kept for starting a new fire, or any burning object (covered by ashes) which causes a fire disaster, the farm products getting heated with piling up and closing completely}
3DC9 CJK UNIFIED IDEOGRAPH-#3DC9, IRGKangXi=0674.210, Def{(a variant of U+71A8 熨) to iron, an iron for smoothing garments (same as 尉) to still; to quiet, a military official}
3DCA CJK UNIFIED IDEOGRAPH-#3DCA, IRGKangXi=0675.191, Def{(non-classical form of 焚) to burn; to set fire to}
3DCB CJK UNIFIED IDEOGRAPH-#3DCB, IRGKangXi=0675.191, Def{embers}
3DCC CJK UNIFIED IDEOGRAPH-#3DCC, IRGKangXi=0675.191
3DCD CJK UNIFIED IDEOGRAPH-#3DCD, IRGKangXi=0675.191, Def{a chemical term; known formerly as benzene}
3DCE CJK UNIFIED IDEOGRAPH-#3DCE, IRGKangXi=0676.020, Def{(same as 暍) sunstroke, hot; feverish}
3DCF CJK UNIFIED IDEOGRAPH-#3DCF, IRGKangXi=0676.030, Def{used in person's name}
3DD0 CJK UNIFIED IDEOGRAPH-#3DD0, IRGKangXi=0677.040, Def{(same as 燬) fire; blaze, to destroy by fire; to burn down}
3DD1 CJK UNIFIED IDEOGRAPH-#3DD1, IRGKangXi=0677.110, Def{(same as 煙 捈) smoke; fumes, tobacco; opium; cigarette, mist; vapor}
3DD2 CJK UNIFIED IDEOGRAPH-#3DD2, IRGKangXi=0677.140, Def{to cook meals; to cook food; to prepare a dinner}
3DD3 CJK UNIFIED IDEOGRAPH-#3DD3, IRGKangXi=0677.230, Def{(same as 熜) a torch (formed by binding the stem of the hemp), chimney; stack}
3DD4 CJK UNIFIED IDEOGRAPH-#3DD4, IRGKangXi=0677.300, Def{(same as non-classical form of 焰) flame; blaze; glowing; brilliant}
3DD5 CJK UNIFIED IDEOGRAPH-#3DD5, IRGKangXi=0678.020, Def{hearing sound}
3DD6 CJK UNIFIED IDEOGRAPH-#3DD6, IRGKangXi=0678.090, Def{(same as 照) to shine upon; to light or illumine}
3DD7 CJK UNIFIED IDEOGRAPH-#3DD7, IRGKangXi=0678.161, Def{(a corrupted form) used in person's name}
3DD8 CJK UNIFIED IDEOGRAPH-#3DD8, IRGKangXi=0678.161, Def{coal; charcoal}
3DD9 CJK UNIFIED IDEOGRAPH-#3DD9, IRGKangXi=0678.161, Def{(same as 煎) to fry in fat or oil, to cook}
3DDA CJK UNIFIED IDEOGRAPH-#3DDA, IRGKangXi=0678.161
3DDB CJK UNIFIED IDEOGRAPH-#3DDB, IRGKangXi=0678.161, Def{to boil, cook; a pot, kettle}
3DDC CJK UNIFIED IDEOGRAPH-#3DDC, IRGKangXi=0678.161
3DDD CJK UNIFIED IDEOGRAPH-#3DDD, IRGKangXi=0678.161
3DDE CJK UNIFIED IDEOGRAPH-#3DDE, IRGKangXi=0678.161
3DDF CJK UNIFIED IDEOGRAPH-#3DDF, IRGKangXi=0678.180, Def{(same as non-classical form of 嬯) to scald the bristles off a pig or the feathers off a bird}
3DE0 CJK UNIFIED IDEOGRAPH-#3DE0, IRGKangXi=0678.200, Def{A will-o'-the-wisp; a flitting light}
3DE1 CJK UNIFIED IDEOGRAPH-#3DE1, IRGKangXi=0678.260, Def{to startle; to amaze; to astound}
3DE2 CJK UNIFIED IDEOGRAPH-#3DE2, IRGKangXi=0678.280, Def{bundle of charcoal, to dry in the sun}
3DE3 CJK UNIFIED IDEOGRAPH-#3DE3, IRGKangXi=0678.290, Def{red; the color of fire}
3DE4 CJK UNIFIED IDEOGRAPH-#3DE4, IRGKangXi=0678.320, Def{rosy clouds of dawn; rosy dawn, sounds of the fire}
3DE5 CJK UNIFIED IDEOGRAPH-#3DE5, IRGKangXi=0678.350, Def{(same as 烝) steam, to cook by steaming}
3DE6 CJK UNIFIED IDEOGRAPH-#3DE6, IRGKangXi=0680.050, Def{(non-classical form of 瞁) to open the eyes with astonishment}
3DE7 CJK UNIFIED IDEOGRAPH-#3DE7, IRGKangXi=0680.101
3DE8 CJK UNIFIED IDEOGRAPH-#3DE8, IRGKangXi=0680.101
3DE9 CJK UNIFIED IDEOGRAPH-#3DE9, IRGKangXi=0680.101, Def{(a variant of 熙) bright, splendid. Intelligent, prosperous}
3DEA CJK UNIFIED IDEOGRAPH-#3DEA, IRGKangXi=0680.101, Def{(a variant) fat; rich, a stew of fish}
3DEB CJK UNIFIED IDEOGRAPH-#3DEB, IRGKangXi=0680.170, Def{to bake or dry by fire}
3DEC CJK UNIFIED IDEOGRAPH-#3DEC, IRGKangXi=0680.180, Def{fire}
3DED CJK UNIFIED IDEOGRAPH-#3DED, IRGKangXi=0680.250, Def{(same as 烽) a conical brick-structure in which to light a beacon; (in ancient China) a tall structure (on a city wall, etc.) where fire was made to signal enemy invasion or presence of bandits}
3DEE CJK UNIFIED IDEOGRAPH-#3DEE, IRGKangXi=0680.290, Def{scorched or burned wood, to burn; to heat, to destroy in fire, to roast or bake}
3DEF CJK UNIFIED IDEOGRAPH-#3DEF, IRGKangXi=0680.400, Def{smoke and dust everywhere; air pollution}
3DF0 CJK UNIFIED IDEOGRAPH-#3DF0, IRGKangXi=0681.060, Def{flames}
3DF1 CJK UNIFIED IDEOGRAPH-#3DF1, IRGKangXi=0681.141
3DF2 CJK UNIFIED IDEOGRAPH-#3DF2, IRGKangXi=0681.141
3DF3 CJK UNIFIED IDEOGRAPH-#3DF3, IRGKangXi=0681.150, Def{color of the flame}
3DF4 CJK UNIFIED IDEOGRAPH-#3DF4, IRGKangXi=0682.020, Def{(same as 爏) fire}
3DF5 CJK UNIFIED IDEOGRAPH-#3DF5, IRGKangXi=0682.160, Def{(same as 爅) fire; flame; light}
3DF6 CJK UNIFIED IDEOGRAPH-#3DF6, IRGKangXi=0682.180, Def{to dry or warm (grains) near a fire}
3DF7 CJK UNIFIED IDEOGRAPH-#3DF7, IRGKangXi=0683.120, Def{(same as 臇) thick soup; broth, fat; rich, a stew of fish}
3DF8 CJK UNIFIED IDEOGRAPH-#3DF8, IRGKangXi=0684.030, Def{(a variant of 燁) blaze of fire, splendid, glorious}
3DF9 CJK UNIFIED IDEOGRAPH-#3DF9, IRGKangXi=0684.080, Def{intense heat, to fry in intensive fire}
3DFA CJK UNIFIED IDEOGRAPH-#3DFA, IRGKangXi=0684.161
3DFB CJK UNIFIED IDEOGRAPH-#3DFB, IRGKangXi=0684.161, Def{(same as 無) without, none, a negative (a variant 嬭) to burn food in cocking; singed; burnt}
3DFC CJK UNIFIED IDEOGRAPH-#3DFC, IRGKangXi=0684.161, Def{(standard form of 燕) a swallow, comfort; ease; to soothe (interchangeable 晏) to feast; to enjoy, name of a certain feudal States}
3DFD CJK UNIFIED IDEOGRAPH-#3DFD, IRGKangXi=0684.161
3DFE CJK UNIFIED IDEOGRAPH-#3DFE, IRGKangXi=0685.020, Def{blaze of fire; burning vigorously}
3DFF CJK UNIFIED IDEOGRAPH-#3DFF, IRGKangXi=0685.060, Def{flame; fire, bitter; acrid taste}
3E00 CJK UNIFIED IDEOGRAPH-#3E00, IRGKangXi=0685.201, Def{(non-classical form of 炱) blackened with soot}
3E01 CJK UNIFIED IDEOGRAPH-#3E01, IRGKangXi=0685.201, Def{(corrupted form of 熯) dry; freely burning; to burn; to roast (dialect) to dry or heat near a fire; consume by fire, to expose to sunlight (same as 焊) to weld; to join with solder, respectful; reverent; deferential}
3E02 CJK UNIFIED IDEOGRAPH-#3E02, IRGKangXi=0685.010
3E03 CJK UNIFIED IDEOGRAPH-#3E03, IRGKangXi=0685.201, Def{(same as 點) a dot; a spot; a speck, a point, a little; a mite, to count; to check on by one, to punctuate}
3E04 CJK UNIFIED IDEOGRAPH-#3E04, IRGKangXi=0686.090, Def{(same as 齌) a raging fire}
3E05 CJK UNIFIED IDEOGRAPH-#3E05, IRGKangXi=0686.210, Def{ashes; candle end}
3E06 CJK UNIFIED IDEOGRAPH-#3E06, IRGKangXi=0686.271
3E07 CJK UNIFIED IDEOGRAPH-#3E07, IRGKangXi=0686.271
3E08 CJK UNIFIED IDEOGRAPH-#3E08, IRGKangXi=0687.020, Def{(same as 焦) scorched or burned, worried and anxious}
3E09 CJK UNIFIED IDEOGRAPH-#3E09, IRGKangXi=0687.050, Def{(non-classical form of 燮) to adapt; to adjust; to blend; to harmonize}
3E0A CJK UNIFIED IDEOGRAPH-#3E0A, IRGKangXi=0687.070, Def{fierce of fire, cruel; malicious, fire; flame}
3E0B CJK UNIFIED IDEOGRAPH-#3E0B, IRGKangXi=0687.090, Def{(interchangeable 膰) meats used in sacrifice}
3E0C CJK UNIFIED IDEOGRAPH-#3E0C, IRGKangXi=0687.171, Def{to twinkle; bright light in glimpses; flashing}
3E0D CJK UNIFIED IDEOGRAPH-#3E0D, IRGKangXi=0687.190, Def{to burn, to roast, to boil; to heat}
3E0E CJK UNIFIED IDEOGRAPH-#3E0E, IRGKangXi=0687.300, Def{warm, fire; flame}
3E0F CJK UNIFIED IDEOGRAPH-#3E0F, IRGKangXi=0688.060, Def{(same as 爢) cooked or well-done; cooked soft, (interchangeable 糜) mashed}
3E10 CJK UNIFIED IDEOGRAPH-#3E10, IRGKangXi=0688.070, Def{(an ancient form of 然) to burn; to light a fire}
3E11 CJK UNIFIED IDEOGRAPH-#3E11, IRGKangXi=0688.160, Def{(same as 爨) a cooking-stove; to cook, a mess, a kind of theatrical composition}
3E12 CJK UNIFIED IDEOGRAPH-#3E12, IRGKangXi=0688.360, Def{to absurd pursuit or desire; to wish wildly; to desire to long for (usually more than one's rightful share), to knit; to weave}
3E13 CJK UNIFIED IDEOGRAPH-#3E13, IRGKangXi=0492.121, Def{to have disappeared, avoid, not at all, not supporting by}
3E14 CJK UNIFIED IDEOGRAPH-#3E14, IRGKangXi=0689.121
3E15 CJK UNIFIED IDEOGRAPH-#3E15, IRGKangXi=0689.221, Def{(same as 攫) to seize; to take hold of; to snatch}
3E16 CJK UNIFIED IDEOGRAPH-#3E16, IRGKangXi=0690.031, Def{hide or to keep in store the vegetable in cold winter days}
3E17 CJK UNIFIED IDEOGRAPH-#3E17, IRGKangXi=0690.050, Def{not a real father or a nature father (as distinct from foster father)}
3E18 CJK UNIFIED IDEOGRAPH-#3E18, IRGKangXi=0690.080, Def{(ancient form of 萬) ten thousand, all, very; extremely; absolutely}
3E19 CJK UNIFIED IDEOGRAPH-#3E19, IRGKangXi=0690.100, Def{(dialect) father, husband of a wet nurse (addressed in ancient times)}
3E1A CJK UNIFIED IDEOGRAPH-#3E1A, IRGKangXi=0690.140, Def{scattered or dispersed and clear, to stop, to detain, a connection, lineage}
3E1B CJK UNIFIED IDEOGRAPH-#3E1B, IRGKangXi=0691.180
3E1C CJK UNIFIED IDEOGRAPH-#3E1C, IRGKangXi=0692.080, Def{to get through the space enclosed by a constellation; to go out of}
3E1D CJK UNIFIED IDEOGRAPH-#3E1D, IRGKangXi=0693.070, Def{(same as 杴) a shovel, a trough to carry off water, a wood-board; a plank}
3E1E CJK UNIFIED IDEOGRAPH-#3E1E, IRGKangXi=0693.080, Def{blocks for printing, supporting boards used in building walls}
3E1F CJK UNIFIED IDEOGRAPH-#3E1F, IRGKangXi=0693.170, Def{to cover; to close; to shut}
3E20 CJK UNIFIED IDEOGRAPH-#3E20, IRGKangXi=0693.180, Def{thick stick; stout carrying pole, beam of a bed}
3E21 CJK UNIFIED IDEOGRAPH-#3E21, IRGKangXi=0693.230, Def{board to block the water current, to across a river by a closs-beam}
3E22 CJK UNIFIED IDEOGRAPH-#3E22, IRGKangXi=0694.080, Def{cross-beam of a bed, window, a mould; a pattern}
3E23 CJK UNIFIED IDEOGRAPH-#3E23, IRGKangXi=0694.280, Def{(same as 業) in ancient China, big piece of board (plank) on a music rack with the carving of the shape of saw's teeth; used to hang clock (musical stone, drum, etc.), instruction}
3E24 CJK UNIFIED IDEOGRAPH-#3E24, IRGKangXi=0694.290, Def{broken leather}
3E25 CJK UNIFIED IDEOGRAPH-#3E25, IRGKangXi=0695.020, Def{household registers, printing plate, supporting boards used in building walls, (same as 欃) sandalwood, water gate; sluice; floodgate}
3E26 CJK UNIFIED IDEOGRAPH-#3E26, IRGKangXi=0695.050, Def{(non-classical form same as 互) mutually; together; each other (dialect) scratching or clawing to and fro}
3E27 CJK UNIFIED IDEOGRAPH-#3E27, IRGKangXi=0695.070, Def{(interchangeable 啃) to bite; to gnaw, a gnashing sound, (standard form 齦) gums (of the teeth), erosion; to erode}
3E28 CJK UNIFIED IDEOGRAPH-#3E28, IRGKangXi=0697.050, Def{a big bull}
3E29 CJK UNIFIED IDEOGRAPH-#3E29, IRGKangXi=0697.080, Def{to desist an ox (止牛)}
3E2A CJK UNIFIED IDEOGRAPH-#3E2A, IRGKangXi=0697.100, Def{an ox walking slowly}
3E2B CJK UNIFIED IDEOGRAPH-#3E2B, IRGKangXi=0698.070, Def{(same as 犍) castrated bull; ox, name of a political division in ancient China; today's Sichuan Province, a kind of animal (looks like an ox)}
3E2C CJK UNIFIED IDEOGRAPH-#3E2C, IRGKangXi=0698.090, Def{a two-years-old ox, ox with a long body, ox with long and big feet}
3E2D CJK UNIFIED IDEOGRAPH-#3E2D, IRGKangXi=0698.100, Def{the opposite; contrary of the cattle's horns}
3E2E CJK UNIFIED IDEOGRAPH-#3E2E, IRGKangXi=0698.120, Def{bull; bulllock; ox (castrated), a four years old ox}
3E2F CJK UNIFIED IDEOGRAPH-#3E2F, IRGKangXi=0699.020, Def{a fine breed of cattle (cow, bull or ox), hornless cattle}
3E30 CJK UNIFIED IDEOGRAPH-#3E30, IRGKangXi=0699.120, Def{(same as 犐) hornless cattle}
3E31 CJK UNIFIED IDEOGRAPH-#3E31, IRGKangXi=0699.130, Def{(same as 㸰,犐) hornless cattle}
3E32 CJK UNIFIED IDEOGRAPH-#3E32, IRGKangXi=0699.160, Def{a kind of mountain cattle; big and heavy}
3E33 CJK UNIFIED IDEOGRAPH-#3E33, IRGKangXi=0699.190, Def{a kind of cattle}
3E34 CJK UNIFIED IDEOGRAPH-#3E34, IRGKangXi=0700.061
3E35 CJK UNIFIED IDEOGRAPH-#3E35, IRGKangXi=0700.110, Def{the lowing of an ox}
3E36 CJK UNIFIED IDEOGRAPH-#3E36, IRGKangXi=0700.120, Def{color of the oxtail; a flat yellow}
3E37 CJK UNIFIED IDEOGRAPH-#3E37, IRGKangXi=0700.130, Def{(same as 觢) a kind of cattle with two horns straight up}
3E38 CJK UNIFIED IDEOGRAPH-#3E38, IRGKangXi=0700.170, Def{calf, bull; bullock; ox (castrated), (a variant) domesticated animals}
3E39 CJK UNIFIED IDEOGRAPH-#3E39, IRGKangXi=0700.240, Def{cattle with white stripe on the back, variegated; parti-colored, mixed; impure}
3E3A CJK UNIFIED IDEOGRAPH-#3E3A, IRGKangXi=0700.250, Def{a cow; female of certain animals}
3E3B CJK UNIFIED IDEOGRAPH-#3E3B, IRGKangXi=0700.260, Def{a kind of cattle; a yearling calf}
3E3C CJK UNIFIED IDEOGRAPH-#3E3C, IRGKangXi=0700.280, Def{(same as 犎) the zebu; or humped-ox}
3E3D CJK UNIFIED IDEOGRAPH-#3E3D, IRGKangXi=0701.050, Def{a two-years-old ox, ox with long and big feet}
3E3E CJK UNIFIED IDEOGRAPH-#3E3E, IRGKangXi=0701.080, Def{(same as 牣) to filled up; full of; filled with; replete with (interchangeable 韌) soft but tough; elastic}
3E3F CJK UNIFIED IDEOGRAPH-#3E3F, IRGKangXi=0701.171, Def{(abbreviated form of 犢) a calf}
3E40 CJK UNIFIED IDEOGRAPH-#3E40, IRGKangXi=0701.171, Def{a cow; female of an animal}
3E41 CJK UNIFIED IDEOGRAPH-#3E41, IRGKangXi=0702.050, Def{generally called the animals (cattle, sheep etc.) with mixed color of white and black}
3E42 CJK UNIFIED IDEOGRAPH-#3E42, IRGKangXi=0702.120, Def{untamed and indocility cattle, huge; big; large}
3E43 CJK UNIFIED IDEOGRAPH-#3E43, IRGKangXi=0702.130, Def{two brindled cows to plough face to each other, to cultivate; to plant after the second time of ploughing; (Cant.) to push lightly, flick off}
3E44 CJK UNIFIED IDEOGRAPH-#3E44, IRGKangXi=0702.160, Def{a kind of cattle; a cattle of short statured}
3E45 CJK UNIFIED IDEOGRAPH-#3E45, IRGKangXi=0702.230, Def{(same as 總) all; general}
3E46 CJK UNIFIED IDEOGRAPH-#3E46, IRGKangXi=0702.260, Def{the coulter of a plough; head of a brindled cow, a kind of cattle}
3E47 CJK UNIFIED IDEOGRAPH-#3E47, IRGKangXi=0702.300, Def{(same as standard form 犍) a kind of cattle, castrated bull; ox}
3E48 CJK UNIFIED IDEOGRAPH-#3E48, IRGKangXi=0703.041, Def{(same as 膧 犛) a black ox, a yak, name of a state in old times}
3E49 CJK UNIFIED IDEOGRAPH-#3E49, IRGKangXi=0703.090, Def{a legendary animal (some kind looks like a cow) with three feet, a wild ox; the bison}
3E4A CJK UNIFIED IDEOGRAPH-#3E4A, IRGKangXi=0703.120, Def{a cattle of white color}
3E4B CJK UNIFIED IDEOGRAPH-#3E4B, IRGKangXi=0703.230, Def{a cow; ox; bull; cattle, a cow with no tail}
3E4C CJK UNIFIED IDEOGRAPH-#3E4C, IRGKangXi=0703.290, Def{cattle; domestic animals, a cow; female of an animal}
3E4D CJK UNIFIED IDEOGRAPH-#3E4D, IRGKangXi=0703.300, Def{bull; bullock; ox (castrated)}
3E4E CJK UNIFIED IDEOGRAPH-#3E4E, IRGKangXi=0703.360, Def{bull; bullock; ox (castrated), 求子牛}
3E4F CJK UNIFIED IDEOGRAPH-#3E4F, IRGKangXi=0703.370, Def{a tame, gentle and yielding cow; good, virtuous}
3E50 CJK UNIFIED IDEOGRAPH-#3E50, IRGKangXi=0704.040, Def{to tow a boat against the current in swift stream from the bank; to track a boat in the shallow area}
3E51 CJK UNIFIED IDEOGRAPH-#3E51, IRGKangXi=0704.110, Def{(same as large seal type form of 牭) four-year old cattle; two and a half year-old cattle}
3E52 CJK UNIFIED IDEOGRAPH-#3E52, IRGKangXi=0704.180, Def{bull; bullock, a calf}
3E53 CJK UNIFIED IDEOGRAPH-#3E53, IRGKangXi=0704.200, Def{a kind of animal, cattles and horses to prance; to be lively}
3E54 CJK UNIFIED IDEOGRAPH-#3E54, IRGKangXi=0704.230, Def{cattle with long back, a white cattle; a cattle having white color on the back}
3E55 CJK UNIFIED IDEOGRAPH-#3E55, IRGKangXi=0704.250, Def{inferior; mean, minor}
3E56 CJK UNIFIED IDEOGRAPH-#3E56, IRGKangXi=0704.260, Def{(same as 豢) to feed animals with grains, to feed; to rear; to raise; to support}
3E57 CJK UNIFIED IDEOGRAPH-#3E57, IRGKangXi=0704.330, Def{cattle and sheep have no children}
3E58 CJK UNIFIED IDEOGRAPH-#3E58, IRGKangXi=0704.340, Def{shinbone of a cattle, a kind of cattle}
3E59 CJK UNIFIED IDEOGRAPH-#3E59, IRGKangXi=0704.420, Def{sound of calling to a calf, calf, the lowing of an ox}
3E5A CJK UNIFIED IDEOGRAPH-#3E5A, IRGKangXi=0705.120, Def{(same as 㹙) sound of calling to a calf, calf, the lowing of an ox}
3E5B CJK UNIFIED IDEOGRAPH-#3E5B, IRGKangXi=0705.170, Def{a tame, gentle and yielding cow; good, virtuous}
3E5C CJK UNIFIED IDEOGRAPH-#3E5C, IRGKangXi=0707.080, Def{(same as 犾) two dogs barking at each other, rude spoken language; rude talk; unpolished; rustic and coarse}
3E5D CJK UNIFIED IDEOGRAPH-#3E5D, IRGKangXi=0707.140, Def{a legendary wild animal, snake; serpent}
3E5E CJK UNIFIED IDEOGRAPH-#3E5E, IRGKangXi=0707.150, Def{(same as 狺) to bark (said of a dog), (same as 齗) gums (of the teeth), (same as 啀) dogs to fight with gnashing and grinning; looks very angry}
3E5F CJK UNIFIED IDEOGRAPH-#3E5F, IRGKangXi=0707.160, Def{a kind of animal, the animals to run about wildly, wild; mad; crazy, (same as 獪) cunning; artful; crafty}
3E60 CJK UNIFIED IDEOGRAPH-#3E60, IRGKangXi=0707.220, Def{(same as 豚) a small big; a sucking pig, to shuffle along without lifting the feet}
3E61 CJK UNIFIED IDEOGRAPH-#3E61, IRGKangXi=0708.090, Def{a rush and impatient disposition, (non-classical form 狷) rash; quick-tempered; narrow-minded, honest and straightforward}
3E62 CJK UNIFIED IDEOGRAPH-#3E62, IRGKangXi=0708.100, Def{a large ape found in Western China, a precious mammal found in Africa}
3E63 CJK UNIFIED IDEOGRAPH-#3E63, IRGKangXi=0708.150, Def{a kind of dog}
3E64 CJK UNIFIED IDEOGRAPH-#3E64, IRGKangXi=0708.180, Def{(same as 怯) lacking in courage; cowardly, nervous; socially timid; fright}
3E65 CJK UNIFIED IDEOGRAPH-#3E65, IRGKangXi=0708.190, Def{a yellow dog with black head}
3E66 CJK UNIFIED IDEOGRAPH-#3E66, IRGKangXi=0708.230, Def{dog with a short tail, (same as non-classical form 貂) the sable; the marten; mink}
3E67 CJK UNIFIED IDEOGRAPH-#3E67, IRGKangXi=0709.030, Def{(non-classical abbreviated form) fox-like animal}
3E68 CJK UNIFIED IDEOGRAPH-#3E68, IRGKangXi=0709.181, Def{(same as 貁 non-classical form 狖) a kind of animal (looks like weasel), an ape with black color and long tail}
3E69 CJK UNIFIED IDEOGRAPH-#3E69, IRGKangXi=0709.181
3E6A CJK UNIFIED IDEOGRAPH-#3E6A, IRGKangXi=0709.181, Def{(same as 狦) a fierce dog, a kind of animal (looks like a wolf)}
3E6B CJK UNIFIED IDEOGRAPH-#3E6B, IRGKangXi=0710.030, Def{a kind of animal (same as 夷) generally called for minority groups in old China}
3E6C CJK UNIFIED IDEOGRAPH-#3E6C, IRGKangXi=0710.180, Def{a kind of animal (of dog tribe)}
3E6D CJK UNIFIED IDEOGRAPH-#3E6D, IRGKangXi=0710.220, Def{a kind of monkey, fox}
3E6E CJK UNIFIED IDEOGRAPH-#3E6E, IRGKangXi=0710.280, Def{a kind of animal (of mule tribe) (same as 貘) tapir}
3E6F CJK UNIFIED IDEOGRAPH-#3E6F, IRGKangXi=0711.060, Def{(same as 貅) a kind of animal like a tiger, a fabulous fierce beast -- thus -- fierce; valiant; heroic; brave}
3E70 CJK UNIFIED IDEOGRAPH-#3E70, IRGKangXi=0711.101
3E71 CJK UNIFIED IDEOGRAPH-#3E71, IRGKangXi=0711.140, Def{name of a dog in the period of Warring States (usually known as the magpie, jackdaw), generally called for dogs}
3E72 CJK UNIFIED IDEOGRAPH-#3E72, IRGKangXi=0711.150, Def{a frightened pig or dog, bark, a running pig}
3E73 CJK UNIFIED IDEOGRAPH-#3E73, IRGKangXi=0711.170, Def{a kind of ape (gibbon)}
3E74 CJK UNIFIED IDEOGRAPH-#3E74, IRGKangXi=0711.220, Def{a kind of animal, fierce dog; small and cute}
3E75 CJK UNIFIED IDEOGRAPH-#3E75, IRGKangXi=0711.270, Def{a hunting-dog, to hunt in winter, imperial tour}
3E76 CJK UNIFIED IDEOGRAPH-#3E76, IRGKangXi=0712.060, Def{a kind of wild animal (monkey tribe)}
3E77 CJK UNIFIED IDEOGRAPH-#3E77, IRGKangXi=0712.071, Def{(same as 狶 豨) swine; pig; hog; big wild pig, sound used in calling pigs, a legendary appellation of an emperor in ancient times}
3E78 CJK UNIFIED IDEOGRAPH-#3E78, IRGKangXi=0712.071, Def{(same as 猊) the lion, a wild beast or wild horse which can do 500 lǐ in a day}
3E79 CJK UNIFIED IDEOGRAPH-#3E79, IRGKangXi=0712.110, Def{a kind of dog}
3E7A CJK UNIFIED IDEOGRAPH-#3E7A, IRGKangXi=0712.120, Def{dog to take food, a biter (said of a dog)}
3E7B CJK UNIFIED IDEOGRAPH-#3E7B, IRGKangXi=0712.180, Def{(same as 猧) puppy, of dog tribe}
3E7C CJK UNIFIED IDEOGRAPH-#3E7C, IRGKangXi=0712.190, Def{a kind of animal}
3E7D CJK UNIFIED IDEOGRAPH-#3E7D, IRGKangXi=0713.020, Def{to bite (said of a dog), dog to take food}
3E7E CJK UNIFIED IDEOGRAPH-#3E7E, IRGKangXi=0713.190, Def{cunning; crafty; sly; wily; artful, vigorous; strong}
3E7F CJK UNIFIED IDEOGRAPH-#3E7F, IRGKangXi=0713.240, Def{a fierce dog, bite fiercely (said of dog), hunting in winter, a kind of beast}
3E80 CJK UNIFIED IDEOGRAPH-#3E80, IRGKangXi=0714.051, Def{(same as 猱) a monkey with yellow hair, crocodile; alligator}
3E81 CJK UNIFIED IDEOGRAPH-#3E81, IRGKangXi=0714.090, Def{a kind of beast}
3E82 CJK UNIFIED IDEOGRAPH-#3E82, IRGKangXi=0714.220, Def{big and strong sheep, a ewe or she-goat, kind of dog, a dog barking loudly}
3E83 CJK UNIFIED IDEOGRAPH-#3E83, IRGKangXi=0715.100, Def{(same as 狗) a dog; canine}
3E84 CJK UNIFIED IDEOGRAPH-#3E84, IRGKangXi=0715.120, Def{(same as 狳) (a variant of 貐) a kind of beast}
3E85 CJK UNIFIED IDEOGRAPH-#3E85, IRGKangXi=0716.050, Def{(same as 猴) the monkey}
3E86 CJK UNIFIED IDEOGRAPH-#3E86, IRGKangXi=0716.051
3E87 CJK UNIFIED IDEOGRAPH-#3E87, IRGKangXi=0716.150, Def{a warden; (in ancient China) minister of public works, to observe; to watch}
3E88 CJK UNIFIED IDEOGRAPH-#3E88, IRGKangXi=0716.290, Def{to go hunting; to go on a hunting expedition}
3E89 CJK UNIFIED IDEOGRAPH-#3E89, IRGKangXi=0716.350, Def{a fierce animal of the dog tribe; with dog's head and horse tail; with yellow and black colors}
3E8A CJK UNIFIED IDEOGRAPH-#3E8A, IRGKangXi=0717.020, Def{a beast (looks like lion)}
3E8B CJK UNIFIED IDEOGRAPH-#3E8B, IRGKangXi=0717.060, Def{pig; hog}
3E8C CJK UNIFIED IDEOGRAPH-#3E8C, IRGKangXi=0717.090, Def{endless barking, two dogs are fighting}
3E8D CJK UNIFIED IDEOGRAPH-#3E8D, IRGKangXi=0717.111, Def{a kind of otter}
3E8E CJK UNIFIED IDEOGRAPH-#3E8E, IRGKangXi=0717.230, Def{fierce beast; the zebu; or humped-ox}
3E8F CJK UNIFIED IDEOGRAPH-#3E8F, IRGKangXi=0717.260, Def{(same as 貗) the badger; a wild bear}
3E90 CJK UNIFIED IDEOGRAPH-#3E90, IRGKangXi=0717.280, Def{(same as U+7360 獠) a general term for minority groups (southwest area) in old China; to hunt at night by torches; lascivious, weird, allurements}
3E91 CJK UNIFIED IDEOGRAPH-#3E91, IRGKangXi=0717.340, Def{dogs wormed through a narrow place, to oppress cruelly; to injure heartlessly, dogs biting, dog's hair, legendary monster (looks like a dwarf), bark}
3E92 CJK UNIFIED IDEOGRAPH-#3E92, IRGKangXi=0717.360, Def{barking of a frightened dog, to confuse; disorder; disturbance, cunning; artful; crafty, to fail and be exposed}
3E93 CJK UNIFIED IDEOGRAPH-#3E93, IRGKangXi=0718.041, Def{(same as 蹟) footprints; traces (interchangeable 僄) agile; adroit; nimble, frivolous; playful; flippant}
3E94 CJK UNIFIED IDEOGRAPH-#3E94, IRGKangXi=0718.190, Def{a kind of beast, a legendary monster}
3E95 CJK UNIFIED IDEOGRAPH-#3E95, IRGKangXi=0718.230, Def{the fighting sound of dogs, agile; sprightly}
3E96 CJK UNIFIED IDEOGRAPH-#3E96, IRGKangXi=0718.260, Def{dogs barking, little dog; a puppy, name of a place in today's Henan Province Xinyexian}
3E97 CJK UNIFIED IDEOGRAPH-#3E97, IRGKangXi=0719.030, Def{to bite; to gnaw; dogs bite}
3E98 CJK UNIFIED IDEOGRAPH-#3E98, IRGKangXi=0719.060, Def{a kind of animal}
3E99 CJK UNIFIED IDEOGRAPH-#3E99, IRGKangXi=0719.131
3E9A CJK UNIFIED IDEOGRAPH-#3E9A, IRGKangXi=0719.150, Def{(same as 獺) an otter}
3E9B CJK UNIFIED IDEOGRAPH-#3E9B, IRGKangXi=0719.170, Def{name of a village in Henan Province, name of a pavilion}
3E9C CJK UNIFIED IDEOGRAPH-#3E9C, IRGKangXi=0719.210, Def{fierce dog with long shaggy hair; an old name for a part of the Miao nationality (in southwestern China)}
3E9D CJK UNIFIED IDEOGRAPH-#3E9D, IRGKangXi=0720.080, Def{sound of a tiger, a fierce dog barking endlessly, a fierce dog, sound of a dog's biting}
3E9E CJK UNIFIED IDEOGRAPH-#3E9E, IRGKangXi=0720.120, Def{to sign in lamentation, crying of a piggy, a kind of beast}
3E9F CJK UNIFIED IDEOGRAPH-#3E9F, IRGKangXi=0720.180, Def{a kind of beast; looks like a deer; white-tailed (same as 蠗) a kind of animal (of monkey tribe)}
3EA0 CJK UNIFIED IDEOGRAPH-#3EA0, IRGKangXi=0721.010, Def{a black ape with long tail, (same as 貁) a kind of animal (of weasel tribe)}
3EA1 CJK UNIFIED IDEOGRAPH-#3EA1, IRGKangXi=0721.040, Def{a kind of beast}
3EA2 CJK UNIFIED IDEOGRAPH-#3EA2, IRGKangXi=0721.101, Def{a kind of animal; body is smaller than a giraffe; two short horns on the head; back and legs with black and white stripes spaced in-between}
3EA3 CJK UNIFIED IDEOGRAPH-#3EA3, IRGKangXi=0721.130, Def{a kind of animal; pig hog}
3EA4 CJK UNIFIED IDEOGRAPH-#3EA4, IRGKangXi=0721.150, Def{a kind of beast}
3EA5 CJK UNIFIED IDEOGRAPH-#3EA5, IRGKangXi=0721.160, Def{bark, (same as 毚) a cunning hare; a wily rabbit}
3EA6 CJK UNIFIED IDEOGRAPH-#3EA6, IRGKangXi=0721.171, Def{a running animal, monkey climbing along the trees, a rutted dog}
3EA7 CJK UNIFIED IDEOGRAPH-#3EA7, IRGKangXi=0722.071, Def{a white-yellow dog, a yellow dog, a mad dog, a group of dogs bark wildly}
3EA8 CJK UNIFIED IDEOGRAPH-#3EA8, IRGKangXi=0727.050, Def{fine stone like jade}
3EA9 CJK UNIFIED IDEOGRAPH-#3EA9, IRGKangXi=0727.060, Def{jade articles, (same as 玌) a kind of jade}
3EAA CJK UNIFIED IDEOGRAPH-#3EAA, IRGKangXi=0727.090, Def{(same as 璞) an uncarved of unpolished jade or gem}
3EAB CJK UNIFIED IDEOGRAPH-#3EAB, IRGKangXi=0727.101, Def{(same as 玌) a kind of jade}
3EAC CJK UNIFIED IDEOGRAPH-#3EAC, IRGKangXi=0727.110, Def{(same as 珙) a large piece of jade-stone}
3EAD CJK UNIFIED IDEOGRAPH-#3EAD, IRGKangXi=0727.180, Def{a kind of jade}
3EAE CJK UNIFIED IDEOGRAPH-#3EAE, IRGKangXi=0727.250, Def{(same as 玗) fine stone like jade}
3EAF CJK UNIFIED IDEOGRAPH-#3EAF, IRGKangXi=0727.251
3EB0 CJK UNIFIED IDEOGRAPH-#3EB0, IRGKangXi=0728.010, Def{(same as 瑡) a kind of jade}
3EB1 CJK UNIFIED IDEOGRAPH-#3EB1, IRGKangXi=0728.020, Def{a kind of jade}
3EB2 CJK UNIFIED IDEOGRAPH-#3EB2, IRGKangXi=0728.110, Def{(ancient form of 鈕) buttons}
3EB3 CJK UNIFIED IDEOGRAPH-#3EB3, IRGKangXi=0728.211, Def{(same as 玫) black mica (a sparkling red gem)}
3EB4 CJK UNIFIED IDEOGRAPH-#3EB4, IRGKangXi=0728.211, Def{name of a spirit; a god, a kind of jade}
3EB5 CJK UNIFIED IDEOGRAPH-#3EB5, IRGKangXi=0728.211, Def{(corrupted form of 玖) black jade-stone}
3EB6 CJK UNIFIED IDEOGRAPH-#3EB6, IRGKangXi=0728.211
3EB7 CJK UNIFIED IDEOGRAPH-#3EB7, IRGKangXi=0728.250, Def{(same as 珬) a kind of jade (jade decorative article for a horse)}
3EB8 CJK UNIFIED IDEOGRAPH-#3EB8, IRGKangXi=0728.290, Def{a kind of jade}
3EB9 CJK UNIFIED IDEOGRAPH-#3EB9, IRGKangXi=0729.140, Def{a kind of jade, a conical cap (wore on ceremonious occasions in ancient times) decorated with jade}
3EBA CJK UNIFIED IDEOGRAPH-#3EBA, IRGKangXi=0730.070, Def{(ancient abbreviated form of 瑁) a very precious piece of jade worn by ancient emperors to match tables borne by the nobles}
3EBB CJK UNIFIED IDEOGRAPH-#3EBB, IRGKangXi=0728.211
3EBC CJK UNIFIED IDEOGRAPH-#3EBC, IRGKangXi=0730.081
3EBD CJK UNIFIED IDEOGRAPH-#3EBD, IRGKangXi=0730.081
3EBE CJK UNIFIED IDEOGRAPH-#3EBE, IRGKangXi=0730.081
3EBF CJK UNIFIED IDEOGRAPH-#3EBF, IRGKangXi=0730.250, Def{a jade-like stone, a kind of jade}
3EC0 CJK UNIFIED IDEOGRAPH-#3EC0, IRGKangXi=0731.020, Def{fine stone which is little less valuable than jade}
3EC1 CJK UNIFIED IDEOGRAPH-#3EC1, IRGKangXi=0731.030, Def{(non-classical form of 瓌) (variant of 瑰) a kind of jasper; stone which is little less valuable than jade, extraordinary; fabulous or admirable}
3EC2 CJK UNIFIED IDEOGRAPH-#3EC2, IRGKangXi=0731.090, Def{a kind of jade, (non-classical form of 玭) pearls}
3EC3 CJK UNIFIED IDEOGRAPH-#3EC3, IRGKangXi=0732.021, Def{crooked; to bend; to twist, involved; indirect}
3EC4 CJK UNIFIED IDEOGRAPH-#3EC4, IRGKangXi=0732.021, Def{(same as 寶) treasure, precious; valuable, respectable; honorable}
3EC5 CJK UNIFIED IDEOGRAPH-#3EC5, IRGKangXi=0732.021, Def{(si mplified form of 璯) jade decorated cap, used in person's name}
3EC6 CJK UNIFIED IDEOGRAPH-#3EC6, IRGKangXi=0732.021
3EC7 CJK UNIFIED IDEOGRAPH-#3EC7, IRGKangXi=0732.021
3EC8 CJK UNIFIED IDEOGRAPH-#3EC8, IRGKangXi=0732.021
3EC9 CJK UNIFIED IDEOGRAPH-#3EC9, IRGKangXi=0732.100, Def{fine jade}
3ECA CJK UNIFIED IDEOGRAPH-#3ECA, IRGKangXi=0732.130, Def{(same as non-classical form of 璊) a red colored jade}
3ECB CJK UNIFIED IDEOGRAPH-#3ECB, IRGKangXi=0732.140, Def{(abbreviated form) (interchangeable 瓬) a kind of jade; a kind of red colored precious stone}
3ECC CJK UNIFIED IDEOGRAPH-#3ECC, IRGKangXi=0732.210, Def{fine jade}
3ECD CJK UNIFIED IDEOGRAPH-#3ECD, IRGKangXi=0732.270, Def{(interchangeable 珸) name of a sword, fine stone which is little less valuable than jade}
3ECE CJK UNIFIED IDEOGRAPH-#3ECE, IRGKangXi=0733.070, Def{(ancient form of 瑟) a large horizontal musical instrument, usually have 25 strings which pass over bridges for tuning; anciently this instrument had 50 strings, but the number varies}
3ECF CJK UNIFIED IDEOGRAPH-#3ECF, IRGKangXi=0733.151, Def{(same as U+73B2 玲) tinkling of jade pendants}
3ED0 CJK UNIFIED IDEOGRAPH-#3ED0, IRGKangXi=0733.151
3ED1 CJK UNIFIED IDEOGRAPH-#3ED1, IRGKangXi=0733.180, Def{a kind of jade}
3ED2 CJK UNIFIED IDEOGRAPH-#3ED2, IRGKangXi=0733.190, Def{red colored jade, even; regular; equal}
3ED3 CJK UNIFIED IDEOGRAPH-#3ED3, IRGKangXi=0733.200, Def{a fine jade, the stripes (lines) on a jade}
3ED4 CJK UNIFIED IDEOGRAPH-#3ED4, IRGKangXi=0734.070, Def{a kind of jade}
3ED5 CJK UNIFIED IDEOGRAPH-#3ED5, IRGKangXi=0734.080, Def{a kind of jade}
3ED6 CJK UNIFIED IDEOGRAPH-#3ED6, IRGKangXi=0734.150, Def{a kind of jade}
3ED7 CJK UNIFIED IDEOGRAPH-#3ED7, IRGKangXi=0736.060, Def{(same as 琲) a string of pearls; 500 beads}
3ED8 CJK UNIFIED IDEOGRAPH-#3ED8, IRGKangXi=0736.081
3ED9 CJK UNIFIED IDEOGRAPH-#3ED9, IRGKangXi=0736.081
3EDA CJK UNIFIED IDEOGRAPH-#3EDA, IRGKangXi=0736.081
3EDB CJK UNIFIED IDEOGRAPH-#3EDB, IRGKangXi=0736.081
3EDC CJK UNIFIED IDEOGRAPH-#3EDC, IRGKangXi=0736.081
3EDD CJK UNIFIED IDEOGRAPH-#3EDD, IRGKangXi=0736.130, Def{a kind of jade}
3EDE CJK UNIFIED IDEOGRAPH-#3EDE, IRGKangXi=0737.040, Def{(interchangeable 彬) flourishing and radiant of the colorful jades, ornamental, refined, lines or stripes on the jade}
3EDF CJK UNIFIED IDEOGRAPH-#3EDF, IRGKangXi=0738.060, Def{a kind of jade}
3EE0 CJK UNIFIED IDEOGRAPH-#3EE0, IRGKangXi=0738.100, Def{jade hanging on the sides of the cap in ancient times; used to plug the ears, to take; to receive}
3EE1 CJK UNIFIED IDEOGRAPH-#3EE1, IRGKangXi=0738.180, Def{(interchangeable 鞢) a jade ring with a small segment cut off; used to indicate separation, a thumb-ring worn by archers, tinkling sound of clicking (said of metal), (corrupted form of 渫) to remove; to eliminate}
3EE2 CJK UNIFIED IDEOGRAPH-#3EE2, IRGKangXi=0738.181
3EE3 CJK UNIFIED IDEOGRAPH-#3EE3, IRGKangXi=0738.181
3EE4 CJK UNIFIED IDEOGRAPH-#3EE4, IRGKangXi=0738.181
3EE5 CJK UNIFIED IDEOGRAPH-#3EE5, IRGKangXi=0738.181
3EE6 CJK UNIFIED IDEOGRAPH-#3EE6, IRGKangXi=0738.181
3EE7 CJK UNIFIED IDEOGRAPH-#3EE7, IRGKangXi=0740.010, Def{a kind of jade}
3EE8 CJK UNIFIED IDEOGRAPH-#3EE8, IRGKangXi=0740.111, Def{fine stone a little less valuable than jade}
3EE9 CJK UNIFIED IDEOGRAPH-#3EE9, IRGKangXi=0740.111
3EEA CJK UNIFIED IDEOGRAPH-#3EEA, IRGKangXi=0740.111, Def{a kind of jade (same as 璿 璇) fine jade}
3EEB CJK UNIFIED IDEOGRAPH-#3EEB, IRGKangXi=0740.150, Def{(same as ancient form of 珌) a gem or ornament on a scabbard}
3EEC CJK UNIFIED IDEOGRAPH-#3EEC, IRGKangXi=0740.200, Def{a kind of jade}
3EED CJK UNIFIED IDEOGRAPH-#3EED, IRGKangXi=0740.220, Def{(same as 璱) clear; pure and fine (said of jade)}
3EEE CJK UNIFIED IDEOGRAPH-#3EEE, IRGKangXi=0741.020, Def{(same as non-classical form of 璨) bright and brilliant; lustrous and luminous}
3EEF CJK UNIFIED IDEOGRAPH-#3EEF, IRGKangXi=0741.120, Def{(same as non-classical form of 㻬) a kind of jade}
3EF0 CJK UNIFIED IDEOGRAPH-#3EF0, IRGKangXi=0741.140, Def{decorated jade or ornament on a scabbard}
3EF1 CJK UNIFIED IDEOGRAPH-#3EF1, IRGKangXi=0741.200, Def{to circle; to revolve round; to surround; to encase, (same as 璡) used in person's name, jade like stone}
3EF2 CJK UNIFIED IDEOGRAPH-#3EF2, IRGKangXi=0741.220, Def{a rite or service for beginning of Autumn (date marking the beginning of one of the 24 seasonal periods in a year, falling normally on August 8 or 9)}
3EF3 CJK UNIFIED IDEOGRAPH-#3EF3, IRGKangXi=0741.221
3EF4 CJK UNIFIED IDEOGRAPH-#3EF4, IRGKangXi=0741.221
3EF5 CJK UNIFIED IDEOGRAPH-#3EF5, IRGKangXi=0741.310, Def{a kind of jade}
3EF6 CJK UNIFIED IDEOGRAPH-#3EF6, IRGKangXi=0741.340, Def{a jade tube with white and nature colors, jade with the colour of nature (green; blue; black), sapphire}
3EF7 CJK UNIFIED IDEOGRAPH-#3EF7, IRGKangXi=0742.040, Def{name of a place (be famous for fine jade), a kind of jade}
3EF8 CJK UNIFIED IDEOGRAPH-#3EF8, IRGKangXi=0742.070, Def{jade like stone}
3EF9 CJK UNIFIED IDEOGRAPH-#3EF9, IRGKangXi=0742.150, Def{a crack; a crevice, spare time; leisure}
3EFA CJK UNIFIED IDEOGRAPH-#3EFA, IRGKangXi=0742.180, Def{a kind of jade}
3EFB CJK UNIFIED IDEOGRAPH-#3EFB, IRGKangXi=0742.251
3EFC CJK UNIFIED IDEOGRAPH-#3EFC, IRGKangXi=0742.251
3EFD CJK UNIFIED IDEOGRAPH-#3EFD, IRGKangXi=0743.050, Def{(same as U+74BF 璿 U+7487 璇) fine jade}
3EFE CJK UNIFIED IDEOGRAPH-#3EFE, IRGKangXi=0743.100, Def{jade articles, fine stone which is little less valuable than jade}
3EFF CJK UNIFIED IDEOGRAPH-#3EFF, IRGKangXi=0743.190, Def{a kind of jade}
3F00 CJK UNIFIED IDEOGRAPH-#3F00, IRGKangXi=0744.021
3F01 CJK UNIFIED IDEOGRAPH-#3F01, IRGKangXi=0744.021
3F02 CJK UNIFIED IDEOGRAPH-#3F02, IRGKangXi=0744.021, Def{(same as 璺) a crack in jade (or porcelain)}
3F03 CJK UNIFIED IDEOGRAPH-#3F03, IRGKangXi=0745.021
3F04 CJK UNIFIED IDEOGRAPH-#3F04, IRGKangXi=0745.051, Def{(same as 璣) pearls, jade, etc. which are not quite circular}
3F05 CJK UNIFIED IDEOGRAPH-#3F05, IRGKangXi=0745.051
3F06 CJK UNIFIED IDEOGRAPH-#3F06, IRGKangXi=0745.051
3F07 CJK UNIFIED IDEOGRAPH-#3F07, IRGKangXi=0745.080, Def{(same as non-classical form of 瓗) (same as 瓊) fine jade or agate; red stone, exquisite; fine, variety of jade}
3F08 CJK UNIFIED IDEOGRAPH-#3F08, IRGKangXi=0745.291
3F09 CJK UNIFIED IDEOGRAPH-#3F09, IRGKangXi=0746.040, Def{green colored melons}
3F0A CJK UNIFIED IDEOGRAPH-#3F0A, IRGKangXi=0746.060, Def{a kind of melon}
3F0B CJK UNIFIED IDEOGRAPH-#3F0B, IRGKangXi=0746.130, Def{the cucumber, dried (preserved) vegetable}
3F0C CJK UNIFIED IDEOGRAPH-#3F0C, IRGKangXi=0746.150, Def{lot of melons growing but the root is weak and feeble, wearied and worn}
3F0D CJK UNIFIED IDEOGRAPH-#3F0D, IRGKangXi=0746.170, Def{pulp of a melon, a kind of melon}
3F0E CJK UNIFIED IDEOGRAPH-#3F0E, IRGKangXi=0746.180, Def{a small melon}
3F0F CJK UNIFIED IDEOGRAPH-#3F0F, IRGKangXi=0747.020, Def{a bruised, overripe or rotten melon (傷瓜,傷熟瓜)}
3F10 CJK UNIFIED IDEOGRAPH-#3F10, IRGKangXi=0747.090, Def{a kind of white melon}
3F11 CJK UNIFIED IDEOGRAPH-#3F11, IRGKangXi=0747.110, Def{pulp of a melon}
3F12 CJK UNIFIED IDEOGRAPH-#3F12, IRGKangXi=0747.120, Def{a kind of big melon, a long melon}
3F13 CJK UNIFIED IDEOGRAPH-#3F13, IRGKangXi=0747.150, Def{melon seeds, a kind of melon}
3F14 CJK UNIFIED IDEOGRAPH-#3F14, IRGKangXi=0747.180, Def{a kind of melon}
3F15 CJK UNIFIED IDEOGRAPH-#3F15, IRGKangXi=0747.240, Def{pulp of a melon}
3F16 CJK UNIFIED IDEOGRAPH-#3F16, IRGKangXi=0747.340, Def{gourd used as a ladle or dipper}
3F17 CJK UNIFIED IDEOGRAPH-#3F17, IRGKangXi=0748.010, Def{a brick}
3F18 CJK UNIFIED IDEOGRAPH-#3F18, IRGKangXi=0748.030, Def{of mountain; high and lofty}
3F19 CJK UNIFIED IDEOGRAPH-#3F19, IRGKangXi=0748.060, Def{(same as ancient form of 甃) brickwork of a well, to repair a well, to lay bricks}
3F1A CJK UNIFIED IDEOGRAPH-#3F1A, IRGKangXi=0748.130, Def{earthware; pottery (a basin; a pot; a bowl. a cistern; a crock), (interchangeable 缸) a big earthen jar}
3F1B CJK UNIFIED IDEOGRAPH-#3F1B, IRGKangXi=0748.170, Def{(same as 鈃) long necked wine vessels (bottle; pot; jar; and cups etc.)}
3F1C CJK UNIFIED IDEOGRAPH-#3F1C, IRGKangXi=0748.250, Def{(same as 盎) a basin; pot; bowl or dish, sleek; well-favoured, abundant, a musical instrument}
3F1D CJK UNIFIED IDEOGRAPH-#3F1D, IRGKangXi=0748.270, Def{(same as 盌) (a variant of 碗) a bowl; a basin; a cup; a dish}
3F1E CJK UNIFIED IDEOGRAPH-#3F1E, IRGKangXi=0748.310, Def{jar with a small mouth, an earthen jar, a jar for the ashes of the dead}
3F1F CJK UNIFIED IDEOGRAPH-#3F1F, IRGKangXi=0748.320, Def{a tiled house, brick wall of a well}
3F20 CJK UNIFIED IDEOGRAPH-#3F20, IRGKangXi=0748.330, Def{a crock with narrow opening, an earthen jar}
3F21 CJK UNIFIED IDEOGRAPH-#3F21, IRGKangXi=0748.340, Def{a small jar with a small mouth, a bottle; pitcher; jug etc.}
3F22 CJK UNIFIED IDEOGRAPH-#3F22, IRGKangXi=0749.010, Def{bricks (same as 瓵) an eathen jar, a jar for the ashes of the dead}
3F23 CJK UNIFIED IDEOGRAPH-#3F23, IRGKangXi=0749.030, Def{bricks of the well; brick wall of a well, to build a well, to construct with bricks}
3F24 CJK UNIFIED IDEOGRAPH-#3F24, IRGKangXi=0749.050, Def{earthenware (a basin; a pot; a bowl; a crock with a narrow opening)}
3F25 CJK UNIFIED IDEOGRAPH-#3F25, IRGKangXi=0749.090, Def{bottle, earthenware}
3F26 CJK UNIFIED IDEOGRAPH-#3F26, IRGKangXi=0749.131, Def{earthenware; pottery (bottle; pitcher; jug; vase; crock with a narrow opening)}
3F27 CJK UNIFIED IDEOGRAPH-#3F27, IRGKangXi=0749.170, Def{tiles in cylinder shape; used to build a palace; a temple or a shrine}
3F28 CJK UNIFIED IDEOGRAPH-#3F28, IRGKangXi=0749.190, Def{a water-jar with ears for carrying it}
3F29 CJK UNIFIED IDEOGRAPH-#3F29, IRGKangXi=0749.210, Def{concave channels of tiling, a long-necked jar, utensil; instrument; implement}
3F2A CJK UNIFIED IDEOGRAPH-#3F2A, IRGKangXi=0749.290, Def{fragments of a tile haven't t been kiln-dried completely, tiles overlapping}
3F2B CJK UNIFIED IDEOGRAPH-#3F2B, IRGKangXi=0749.310, Def{earthenware or pottery with big opening, wine utensil (containers) with big opening}
3F2C CJK UNIFIED IDEOGRAPH-#3F2C, IRGKangXi=0749.320, Def{earthenware (a basin; a pot; a bowl; a crock etc.)}
3F2D CJK UNIFIED IDEOGRAPH-#3F2D, IRGKangXi=0749.330, Def{(interchangeable 墊) to steady by putting something underneath, to shore up; to prop}
3F2E CJK UNIFIED IDEOGRAPH-#3F2E, IRGKangXi=0749.380, Def{to rub out the filth with broken tiles, brickwork of a well, to repair a well, to lay bricks}
3F2F CJK UNIFIED IDEOGRAPH-#3F2F, IRGKangXi=0749.420, Def{earthenware (jar with a small mouth)}
3F30 CJK UNIFIED IDEOGRAPH-#3F30, IRGKangXi=0749.440, Def{an earthenware jar with a small mouth and two or four ears; used to store water for fire prevention in ancient times}
3F31 CJK UNIFIED IDEOGRAPH-#3F31, IRGKangXi=0750.050, Def{to manage or regulate the leather material, soft, hunting clothes (leather trousers)}
3F32 CJK UNIFIED IDEOGRAPH-#3F32, IRGKangXi=0750.080, Def{sound of broken tiles, thin tiles}
3F33 CJK UNIFIED IDEOGRAPH-#3F33, IRGKangXi=0750.100, Def{earthenware (a basin; a pot; a bowl; a crock etc.)}
3F34 CJK UNIFIED IDEOGRAPH-#3F34, IRGKangXi=0750.110, Def{an earthen vessel; a basin; a pot; a jar}
3F35 CJK UNIFIED IDEOGRAPH-#3F35, IRGKangXi=0750.170, Def{a small basin; a bowl. a cup; a pot; a jar}
3F36 CJK UNIFIED IDEOGRAPH-#3F36, IRGKangXi=0750.180, Def{earthenware (a basin; a pot; a bowl; a crock etc.)}
3F37 CJK UNIFIED IDEOGRAPH-#3F37, IRGKangXi=0750.210, Def{a basin, (same as 甎) a brick; a square tile}
3F38 CJK UNIFIED IDEOGRAPH-#3F38, IRGKangXi=0751.010, Def{earthenware (a basin; a pot; a bowl; a crock etc.)}
3F39 CJK UNIFIED IDEOGRAPH-#3F39, IRGKangXi=0751.050, Def{earthenware; pottery, a kind container; vessel}
3F3A CJK UNIFIED IDEOGRAPH-#3F3A, IRGKangXi=0751.110, Def{porcelain; porcelain ware; chinaware; china, a small bottle with ears}
3F3B CJK UNIFIED IDEOGRAPH-#3F3B, IRGKangXi=0751.160, Def{earthenware (a jar; a jar with a small mouth and two or four ears; a pot; a pitcher)}
3F3C CJK UNIFIED IDEOGRAPH-#3F3C, IRGKangXi=0751.180, Def{(same as 瓢) a ladle (often made of dried calabash or gourd)}
3F3D CJK UNIFIED IDEOGRAPH-#3F3D, IRGKangXi=0751.210, Def{fragments of tile incompletely kiln-dried; to scrub out filth with broken tiles}
3F3E CJK UNIFIED IDEOGRAPH-#3F3E, IRGKangXi=0752.010, Def{bricks}
3F3F CJK UNIFIED IDEOGRAPH-#3F3F, IRGKangXi=0752.040, Def{the brick wall of a well, earthenware (a jar; a jar with a small mouth and two or four ears; a pot; a pitcher)}
3F40 CJK UNIFIED IDEOGRAPH-#3F40, IRGKangXi=0752.060, Def{earthenware (a basin; a pot; a bowl; a crock etc.)}
3F41 CJK UNIFIED IDEOGRAPH-#3F41, IRGKangXi=0752.080, Def{(same as 鬲) a large earthen pot, a large iron cauldron used in old time}
3F42 CJK UNIFIED IDEOGRAPH-#3F42, IRGKangXi=0752.100, Def{a cracked container, a movement of a musical conposition in Tang Dynasty}
3F43 CJK UNIFIED IDEOGRAPH-#3F43, IRGKangXi=0752.120, Def{a big piece of brick}
3F44 CJK UNIFIED IDEOGRAPH-#3F44, IRGKangXi=0752.150, Def{an earthen jar, crack of earthen container, hoarse voice}
3F45 CJK UNIFIED IDEOGRAPH-#3F45, IRGKangXi=0752.151, Def{vessel for ceremony in ancient times}
3F46 CJK UNIFIED IDEOGRAPH-#3F46, IRGKangXi=0752.200, Def{earthenware; a bowl; a cup, tiles with a circular facade at one end used along the edge of palace eaves during the Han Dynasty}
3F47 CJK UNIFIED IDEOGRAPH-#3F47, IRGKangXi=0752.240, Def{unburnt tiles, earthenware}
3F48 CJK UNIFIED IDEOGRAPH-#3F48, IRGKangXi=0752.280, Def{a large earthenware jar with a small mouth and two or four ears; a big pot; bottle; pitcher; jug; vase}
3F49 CJK UNIFIED IDEOGRAPH-#3F49, IRGKangXi=0752.290, Def{a big jar; a big basin}
3F4A CJK UNIFIED IDEOGRAPH-#3F4A, IRGKangXi=0753.080, Def{cracking of tile}
3F4B CJK UNIFIED IDEOGRAPH-#3F4B, IRGKangXi=0753.150, Def{a kind of tile, earthenware, a cylinder shaped tile used for chimney}
3F4C CJK UNIFIED IDEOGRAPH-#3F4C, IRGKangXi=0753.141, Def{the ridge of a roof}
3F4D CJK UNIFIED IDEOGRAPH-#3F4D, IRGKangXi=0754.100, Def{(same as 坩) an earthen vessel}
3F4E CJK UNIFIED IDEOGRAPH-#3F4E, IRGKangXi=0754.170, Def{the profundity of the harem, the mysterious and profound of the forbidden palace, the flourishing and exuberant of the flame}
3F4F CJK UNIFIED IDEOGRAPH-#3F4F, IRGKangXi=0754.181
3F50 CJK UNIFIED IDEOGRAPH-#3F50, IRGKangXi=0754.190, Def{(same as 馦) fragrant}
3F51 CJK UNIFIED IDEOGRAPH-#3F51, IRGKangXi=0754.230, Def{delicious; tasty (same as 醰) full flavoured; rich}
3F52 CJK UNIFIED IDEOGRAPH-#3F52, IRGKangXi=0755.160, Def{(same as 甥) the children of a sister, a son-in-law}
3F53 CJK UNIFIED IDEOGRAPH-#3F53, IRGKangXi=0755.201
3F54 CJK UNIFIED IDEOGRAPH-#3F54, IRGKangXi=0755.201
3F55 CJK UNIFIED IDEOGRAPH-#3F55, IRGKangXi=0759.050, Def{new branches growing (said of trees), hollow; empty}
3F56 CJK UNIFIED IDEOGRAPH-#3F56, IRGKangXi=0759.081, Def{(same as 男) a human; a man; a boy (non-classical form of 留) to remain; to stay, to keep, to preserve}
3F57 CJK UNIFIED IDEOGRAPH-#3F57, IRGKangXi=0759.081
3F58 CJK UNIFIED IDEOGRAPH-#3F58, IRGKangXi=0760.050, Def{borderland; the frontier, a pit; a cave, a narrow path in the field, administrative unit for rural community of 傣族 (under the feudal system), pond; a marsh, saltpond, (same as 䴚) salt marsh}
3F59 CJK UNIFIED IDEOGRAPH-#3F59, IRGKangXi=0760.320, Def{(same as 畯) official in charge of farmlands in ancient times; a bailiff or landlord, rustic; crude (ancient form of 允) to allow; to grant}
3F5A CJK UNIFIED IDEOGRAPH-#3F5A, IRGKangXi=0760.341, Def{agricultural implements; farm tools, name of a place}
3F5B CJK UNIFIED IDEOGRAPH-#3F5B, IRGKangXi=0760.360, Def{narrow trail of path in the fields, a name of an old county in today's Yunnan Province}
3F5C CJK UNIFIED IDEOGRAPH-#3F5C, IRGKangXi=0761.110
3F5D CJK UNIFIED IDEOGRAPH-#3F5D, IRGKangXi=0762.080, Def{to sink; to fall, to entrap, to crush; to capture}
3F5E CJK UNIFIED IDEOGRAPH-#3F5E, IRGKangXi=0763.031, Def{(abbreviated form of 留) to remain; to stay, to detain, to leave behind}
3F5F CJK UNIFIED IDEOGRAPH-#3F5F, IRGKangXi=0763.040, Def{to till or to plough the fields (same as 埒) an enclosure, an embankment, a dike}
3F60 CJK UNIFIED IDEOGRAPH-#3F60, IRGKangXi=0764.020, Def{connection of the ditches or waterways}
3F61 CJK UNIFIED IDEOGRAPH-#3F61, IRGKangXi=0764.100, Def{field, block up the water to irrigate the fields}
3F62 CJK UNIFIED IDEOGRAPH-#3F62, IRGKangXi=0764.110, Def{to plough the fields}
3F63 CJK UNIFIED IDEOGRAPH-#3F63, IRGKangXi=0764.140, Def{(ancient form of 域) a frontier; a boundary; a region; a country, to keep within bounds}
3F64 CJK UNIFIED IDEOGRAPH-#3F64, IRGKangXi=0764.170, Def{a small plot of land}
3F65 CJK UNIFIED IDEOGRAPH-#3F65, IRGKangXi=0765.140, Def{fertile fields; good land (during the Epoch of Spring and Autumn) name of a place in Zheng Guo (today's Henan Province LuShan Xian}
3F66 CJK UNIFIED IDEOGRAPH-#3F66, IRGKangXi=0765.190, Def{reclaimed land; flat and in even level}
3F67 CJK UNIFIED IDEOGRAPH-#3F67, IRGKangXi=0766.030, Def{name of a place}
3F68 CJK UNIFIED IDEOGRAPH-#3F68, IRGKangXi=0766.060, Def{fragmented; uncultivated and desolated fields, to eliminate; remove, to clean (interchangeable 瘥) an epidemic; a plague}
3F69 CJK UNIFIED IDEOGRAPH-#3F69, IRGKangXi=0766.110, Def{connected banks of earth or paths in the field}
3F6A CJK UNIFIED IDEOGRAPH-#3F6A, IRGKangXi=0766.260, Def{paddy field; rice field}
3F6B CJK UNIFIED IDEOGRAPH-#3F6B, IRGKangXi=0766.290, Def{seeds of the plant allied to the water-lily; used when ground into meal; as a coarse food, also as medicine (same as 壅) to block up, to bank up roots of plants, to impede (flow, etc.)}
3F6C CJK UNIFIED IDEOGRAPH-#3F6C, IRGKangXi=0766.310, Def{(same as 副) to assist, secondary (in importance), rich and dense}
3F6D CJK UNIFIED IDEOGRAPH-#3F6D, IRGKangXi=0766.350, Def{vacant lot or space, soft land; land on the river side}
3F6E CJK UNIFIED IDEOGRAPH-#3F6E, IRGKangXi=0767.041, Def{(same as 星) a point of light, stars; planets, a spark}
3F6F CJK UNIFIED IDEOGRAPH-#3F6F, IRGKangXi=0767.100
3F70 CJK UNIFIED IDEOGRAPH-#3F70, IRGKangXi=0768.010, Def{(corrupted form) carved window frame on a door, the windows with scattered or dispersed frames, a wine filterer}
3F71 CJK UNIFIED IDEOGRAPH-#3F71, IRGKangXi=0769.060, Def{griping colic, a swelling, a little painful; some not serious}
3F72 CJK UNIFIED IDEOGRAPH-#3F72, IRGKangXi=0769.070, Def{(same as U+3F71 㽱) griping colic, illness; disease}
3F73 CJK UNIFIED IDEOGRAPH-#3F73, IRGKangXi=0769.110, Def{illness; disease}
3F74 CJK UNIFIED IDEOGRAPH-#3F74, IRGKangXi=0769.160, Def{illness; disease}
3F75 CJK UNIFIED IDEOGRAPH-#3F75, IRGKangXi=0769.210, Def{(same as non-classical form of 莊) solemn, large farmhouse}
3F76 CJK UNIFIED IDEOGRAPH-#3F76, IRGKangXi=0769.221
3F77 CJK UNIFIED IDEOGRAPH-#3F77, IRGKangXi=0769.250, Def{dropsy; hydrophillic swelling}
3F78 CJK UNIFIED IDEOGRAPH-#3F78, IRGKangXi=0769.290, Def{(corrupted form 瘎) diseases of the abdomen, illness, sick for the second time; get sick again}
3F79 CJK UNIFIED IDEOGRAPH-#3F79, IRGKangXi=0770.010, Def{to faint, to feel nausea, abuse; vilification}
3F7A CJK UNIFIED IDEOGRAPH-#3F7A, IRGKangXi=0770.040, Def{to be weakened by disease; feeble; lean (a dialect) poor in quality}
3F7B CJK UNIFIED IDEOGRAPH-#3F7B, IRGKangXi=0770.150, Def{diseases; illness}
3F7C CJK UNIFIED IDEOGRAPH-#3F7C, IRGKangXi=0770.191
3F7D CJK UNIFIED IDEOGRAPH-#3F7D, IRGKangXi=0770.220, Def{(same as U+75FC 痼) chronic disease, a sore in the mouth of a child}
3F7E CJK UNIFIED IDEOGRAPH-#3F7E, IRGKangXi=0770.250, Def{a kind of woman's disease, to cut apart, to break}
3F7F CJK UNIFIED IDEOGRAPH-#3F7F, IRGKangXi=0770.260, Def{(same as 瘑) ulcer; sore; boil, illness; disease}
3F80 CJK UNIFIED IDEOGRAPH-#3F80, IRGKangXi=0771.010, Def{(interchangeable 怯) to be weakened by disease; weak; feeble, lean; emaciated, illness; disease; sick}
3F81 CJK UNIFIED IDEOGRAPH-#3F81, IRGKangXi=0771.050, Def{walking like mad; mad}
3F82 CJK UNIFIED IDEOGRAPH-#3F82, IRGKangXi=0771.060, Def{illness; disease (a dialect) a chronic disease; never recover after a long illness}
3F83 CJK UNIFIED IDEOGRAPH-#3F83, IRGKangXi=0771.110, Def{hump-backed}
3F84 CJK UNIFIED IDEOGRAPH-#3F84, IRGKangXi=0771.140, Def{(ancient form same as 讟) to libel; to slander; complaints; grumblings, blames or curses; to blame, (same as 怞) to grieve, sorrowful, sad and weary}
3F85 CJK UNIFIED IDEOGRAPH-#3F85, IRGKangXi=0771.170, Def{defects; flaws, illness; disease}
3F86 CJK UNIFIED IDEOGRAPH-#3F86, IRGKangXi=0771.200, Def{(non-classical form) (said of some kinds of reptiles or insects) ecdysis; to cast off the skin; to molt}
3F87 CJK UNIFIED IDEOGRAPH-#3F87, IRGKangXi=0771.280, Def{illness; disease; ailment}
3F88 CJK UNIFIED IDEOGRAPH-#3F88, IRGKangXi=0771.310, Def{hunchbacked; curved spine, short, dropsy}
3F89 CJK UNIFIED IDEOGRAPH-#3F89, IRGKangXi=0771.320, Def{thin; lean; slim; emaciated}
3F8A CJK UNIFIED IDEOGRAPH-#3F8A, IRGKangXi=0772.130, Def{(same as 瘦 瘠) thin; lean; slim; emaciated, a kind of skin disease, a chill, a cold, malaria, (interchangeable 瘶,瘷) cough; chilly disease; catching cold}
3F8B CJK UNIFIED IDEOGRAPH-#3F8B, IRGKangXi=0772.140, Def{dysentery; diarrhea, a sore; a boil; an ulcer}
3F8C CJK UNIFIED IDEOGRAPH-#3F8C, IRGKangXi=0772.220, Def{(same as 癬) ringworm, used for various diseases of the skin}
3F8D CJK UNIFIED IDEOGRAPH-#3F8D, IRGKangXi=0772.260, Def{diseases, sticking up or protruding of the big bottom}
3F8E CJK UNIFIED IDEOGRAPH-#3F8E, IRGKangXi=0772.290, Def{(a dialect) sickness; disease, favus (a dialect) everything is good except this particular one}
3F8F CJK UNIFIED IDEOGRAPH-#3F8F, IRGKangXi=0773.020, Def{illness; disease; sickness, idiotic; crazy; insane; silly}
3F90 CJK UNIFIED IDEOGRAPH-#3F90, IRGKangXi=0773.060, Def{ulcer, a sore; swelling and sores caused by varnish-poisoning; pestilence; epidemic, leprosy, (interchangeable 勵) to exhort to great effort; to urge}
3F91 CJK UNIFIED IDEOGRAPH-#3F91, IRGKangXi=0773.100, Def{fat; plump, a chill, a cold, malaria, a wart; a pimple, a round lump}
3F92 CJK UNIFIED IDEOGRAPH-#3F92, IRGKangXi=0773.140, Def{illness; disease, could not have access to ...}
3F93 CJK UNIFIED IDEOGRAPH-#3F93, IRGKangXi=0773.160, Def{fatigue; exhaustion; weariness, ache of the joints (of bones); gout, melancholy; depressed, anger; fury, hatred; bitterness}
3F94 CJK UNIFIED IDEOGRAPH-#3F94, IRGKangXi=0773.200, Def{long illness, ulcer; sore; boil}
3F95 CJK UNIFIED IDEOGRAPH-#3F95, IRGKangXi=0773.210, Def{a chill, a cold, malaria, shivering with cold, a shudder; a shiver; tremble}
3F96 CJK UNIFIED IDEOGRAPH-#3F96, IRGKangXi=0773.220, Def{grieved; distressed; ill with grief and exhausted}
3F97 CJK UNIFIED IDEOGRAPH-#3F97, IRGKangXi=0773.230, Def{eye disease; strabismus; squint; to look askance (a dialect) bright; light; brilliant, bright eyes}
3F98 CJK UNIFIED IDEOGRAPH-#3F98, IRGKangXi=0773.330, Def{(same as U+6897 梗) ailment; bane; distress; (Cant.) a bruise}
3F99 CJK UNIFIED IDEOGRAPH-#3F99, IRGKangXi=0773.360, Def{(same as 脪) Erysipelas, sloughing of an ulcer, painful; aching}
3F9A CJK UNIFIED IDEOGRAPH-#3F9A, IRGKangXi=0774.010, Def{itchy; ticklish}
3F9B CJK UNIFIED IDEOGRAPH-#3F9B, IRGKangXi=0774.050, Def{ugly; bad-looking}
3F9C CJK UNIFIED IDEOGRAPH-#3F9C, IRGKangXi=0774.060, Def{weak breath of a sick man}
3F9D CJK UNIFIED IDEOGRAPH-#3F9D, IRGKangXi=0774.100, Def{(corrupted form) to leak out; to ejaculate, to scatter; to disperse; to vent}
3F9E CJK UNIFIED IDEOGRAPH-#3F9E, IRGKangXi=0774.130, Def{illness; disease (interchangeable 庮) stinking smell of the decayed wood}
3F9F CJK UNIFIED IDEOGRAPH-#3F9F, IRGKangXi=0774.190, Def{(said of illness) relapse; to relapse (a dialect) relapse of typhoid fever (typhus)}
3FA0 CJK UNIFIED IDEOGRAPH-#3FA0, IRGKangXi=0774.200, Def{a fever}
3FA1 CJK UNIFIED IDEOGRAPH-#3FA1, IRGKangXi=0774.230, Def{ulcer; sore; boil}
3FA2 CJK UNIFIED IDEOGRAPH-#3FA2, IRGKangXi=0774.260, Def{a malignant disease, a chronic disease}
3FA3 CJK UNIFIED IDEOGRAPH-#3FA3, IRGKangXi=0774.300, Def{to shiver; to shudder; to tremble because of a malaria and a very bad cold}
3FA4 CJK UNIFIED IDEOGRAPH-#3FA4, IRGKangXi=0775.050, Def{disease of the throat}
3FA5 CJK UNIFIED IDEOGRAPH-#3FA5, IRGKangXi=0775.190, Def{bellyache}
3FA6 CJK UNIFIED IDEOGRAPH-#3FA6, IRGKangXi=0775.210, Def{scab over a sore, scar of an ulcer, weak; feeble}
3FA7 CJK UNIFIED IDEOGRAPH-#3FA7, IRGKangXi=0775.250, Def{favus, swelling of the glands, a lump; scrofulous swellings}
3FA8 CJK UNIFIED IDEOGRAPH-#3FA8, IRGKangXi=0775.290, Def{weak; feeble, to mourn, ulcer; cancer; carbuncle, short}
3FA9 CJK UNIFIED IDEOGRAPH-#3FA9, IRGKangXi=0776.010, Def{malignant boils}
3FAA CJK UNIFIED IDEOGRAPH-#3FAA, IRGKangXi=0776.140, Def{lean; thin; slim}
3FAB CJK UNIFIED IDEOGRAPH-#3FAB, IRGKangXi=0776.220, Def{hemiplegia -- paralysis of half of one's body}
3FAC CJK UNIFIED IDEOGRAPH-#3FAC, IRGKangXi=0776.330, Def{(same as 痎) malaria}
3FAD CJK UNIFIED IDEOGRAPH-#3FAD, IRGKangXi=0776.390, Def{to shrink; to contract; to deflate; to shorten; to reduce in length}
3FAE CJK UNIFIED IDEOGRAPH-#3FAE, IRGKangXi=0776.440, Def{(same as U+7640 癀) jaundice}
3FAF CJK UNIFIED IDEOGRAPH-#3FAF, IRGKangXi=0777.090, Def{to suffer a stroke of paralysis or apoplexy, disease of the private part (of the human body)}
3FB0 CJK UNIFIED IDEOGRAPH-#3FB0, IRGKangXi=0777.100, Def{choke, lump in throat; food stuck in the throat}
3FB1 CJK UNIFIED IDEOGRAPH-#3FB1, IRGKangXi=0777.211, Def{(abbreviated form 癈) incurable disease}
3FB2 CJK UNIFIED IDEOGRAPH-#3FB2, IRGKangXi=0780.091
3FB3 CJK UNIFIED IDEOGRAPH-#3FB3, IRGKangXi=0777.211
3FB4 CJK UNIFIED IDEOGRAPH-#3FB4, IRGKangXi=0777.211, Def{the erythema of acne rosacea}
3FB5 CJK UNIFIED IDEOGRAPH-#3FB5, IRGKangXi=0777.211, Def{a dark colored birth-mark}
3FB6 CJK UNIFIED IDEOGRAPH-#3FB6, IRGKangXi=0777.220, Def{disease of the knee}
3FB7 CJK UNIFIED IDEOGRAPH-#3FB7, IRGKangXi=0777.250, Def{to ache}
3FB8 CJK UNIFIED IDEOGRAPH-#3FB8, IRGKangXi=0777.280, Def{a scabby, itching disease}
3FB9 CJK UNIFIED IDEOGRAPH-#3FB9, IRGKangXi=0777.330, Def{lean; thin; slim, illness; disease, an epidemic; a pestilence}
3FBA CJK UNIFIED IDEOGRAPH-#3FBA, IRGKangXi=0777.370, Def{eye disease, with noxious air on, disease of an animal, decayed sore}
3FBB CJK UNIFIED IDEOGRAPH-#3FBB, IRGKangXi=0778.190, Def{not any progressive, swelling, a mark of scar on the skin}
3FBC CJK UNIFIED IDEOGRAPH-#3FBC, IRGKangXi=0778.210, Def{to suffer a stroke of paralysis or apoplexy}
3FBD CJK UNIFIED IDEOGRAPH-#3FBD, IRGKangXi=0778.260, Def{(same as 膇) swelling feet, disease of the private part of the human body}
3FBE CJK UNIFIED IDEOGRAPH-#3FBE, IRGKangXi=0778.270, Def{disease of the throat, something stuck in the throat, to be stung, emaciated; illness of losing flesh}
3FBF CJK UNIFIED IDEOGRAPH-#3FBF, IRGKangXi=0779.010, Def{roar of asthma or expectorate from a dying person}
3FC0 CJK UNIFIED IDEOGRAPH-#3FC0, IRGKangXi=0779.041, Def{(same as U+764D 癍) unhealthy marks on the skin; blotches; pustules}
3FC1 CJK UNIFIED IDEOGRAPH-#3FC1, IRGKangXi=0779.041
3FC2 CJK UNIFIED IDEOGRAPH-#3FC2, IRGKangXi=0779.100, Def{(abbreviated form of 癥) obstruction of the bowels}
3FC3 CJK UNIFIED IDEOGRAPH-#3FC3, IRGKangXi=0779.120, Def{an ox-headed boil, dysentery; diarrhea, popular name for women's peculiar diseases}
3FC4 CJK UNIFIED IDEOGRAPH-#3FC4, IRGKangXi=0779.160, Def{the groans or moans from a person in a critical condition}
3FC5 CJK UNIFIED IDEOGRAPH-#3FC5, IRGKangXi=0779.180, Def{(same as 癬) ringworm, used for various diseases of the skin}
3FC6 CJK UNIFIED IDEOGRAPH-#3FC6, IRGKangXi=0779.300, Def{damage by the pests to the rice seedling, boil; ulcer; sore}
3FC7 CJK UNIFIED IDEOGRAPH-#3FC7, IRGKangXi=0779.310, Def{paralysis, rheumatism, having no sense of feeling; numb}
3FC8 CJK UNIFIED IDEOGRAPH-#3FC8, IRGKangXi=0780.050, Def{(non-classical form of 癰) an ulcer; an abscess; a carbuncle; sometimes use for a cancer, loss of the sense of smell}
3FC9 CJK UNIFIED IDEOGRAPH-#3FC9, IRGKangXi=0780.130, Def{disease of the private part of the human body}
3FCA CJK UNIFIED IDEOGRAPH-#3FCA, IRGKangXi=0780.210, Def{very painful; agonizing (same as 憯) sad; sorrowful; grieved}
3FCB CJK UNIFIED IDEOGRAPH-#3FCB, IRGKangXi=0781.240, Def{(same as U+7619 瘙) a kind of skin disease (like sores from scabies)}
3FCC CJK UNIFIED IDEOGRAPH-#3FCC, IRGKangXi=0781.280, Def{(interchangeable U+3FBE 㾾) lump in the throat, sting of a poisonous insect (scorpion)}
3FCD CJK UNIFIED IDEOGRAPH-#3FCD, IRGKangXi=0781.370, Def{(same as U+75A5 疥) scabies}
3FCE CJK UNIFIED IDEOGRAPH-#3FCE, IRGKangXi=0781.420, Def{sick; depress and melancholy, swelling, heat rashes; heat spots; prickly heat}
3FCF CJK UNIFIED IDEOGRAPH-#3FCF, IRGKangXi=0782.021, Def{paralysis of the body}
3FD0 CJK UNIFIED IDEOGRAPH-#3FD0, IRGKangXi=0782.021
3FD1 CJK UNIFIED IDEOGRAPH-#3FD1, IRGKangXi=0782.080, Def{illness; disease; ailment}
3FD2 CJK UNIFIED IDEOGRAPH-#3FD2, IRGKangXi=0782.100, Def{illness; disease; ailment, disease of the internal organs, disease of the abdomen, palpitation of the heart}
3FD3 CJK UNIFIED IDEOGRAPH-#3FD3, IRGKangXi=0782.120, Def{disease of the hoof}
3FD4 CJK UNIFIED IDEOGRAPH-#3FD4, IRGKangXi=0782.311, Def{a wart; a pimple; a pustule on the skin}
3FD5 CJK UNIFIED IDEOGRAPH-#3FD5, IRGKangXi=0782.320, Def{ulcer; sore; boil, a wound}
3FD6 CJK UNIFIED IDEOGRAPH-#3FD6, IRGKangXi=0782.330, Def{carbuncle (interchangeable 廬) used in naming of a place, a swelling of the abdomen from constipation}
3FD7 CJK UNIFIED IDEOGRAPH-#3FD7, IRGKangXi=0782.340, Def{(same as U+3FC9 㿉) disease of the private part of the human body}
3FD8 CJK UNIFIED IDEOGRAPH-#3FD8, IRGKangXi=0783.030, Def{to get sick; to fall ill}
3FD9 CJK UNIFIED IDEOGRAPH-#3FD9, IRGKangXi=0783.110, Def{full; filled, full of air or gas, a heart full of (enthusiasm, sorrow, etc.)}
3FDA CJK UNIFIED IDEOGRAPH-#3FDA, IRGKangXi=0783.150, Def{sickness; ailment; disease}
3FDB CJK UNIFIED IDEOGRAPH-#3FDB, IRGKangXi=0783.190, Def{carbuncle, sallow and emaciated, scrofulous swellings}
3FDC CJK UNIFIED IDEOGRAPH-#3FDC, IRGKangXi=0783.271, Def{(non-classical form of 癟) shrivelled up; empty; limp; flat; not full; sunken}
3FDD CJK UNIFIED IDEOGRAPH-#3FDD, IRGKangXi=0786.050, Def{(ancient form of 香) sweet; fragrant, delicious, incense}
3FDE CJK UNIFIED IDEOGRAPH-#3FDE, IRGKangXi=0787.020, Def{(non-classical form of 耄) an old man of eighty, aged}
3FDF CJK UNIFIED IDEOGRAPH-#3FDF, IRGKangXi=0787.090, Def{(same as U+767D 白) he bright, white moon; a pure glistening white, splendid, white}
3FE0 CJK UNIFIED IDEOGRAPH-#3FE0, IRGKangXi=0788.121
3FE1 CJK UNIFIED IDEOGRAPH-#3FE1, IRGKangXi=0788.121, Def{(corrupted form of 兜) a helmet; a head-covering, a small pocket in clothes}
3FE2 CJK UNIFIED IDEOGRAPH-#3FE2, IRGKangXi=0788.260, Def{(same as 耀) to shine; to dazzle, to show off}
3FE3 CJK UNIFIED IDEOGRAPH-#3FE3, IRGKangXi=0788.300, Def{white color}
3FE4 CJK UNIFIED IDEOGRAPH-#3FE4, IRGKangXi=0788.340, Def{white, clear}
3FE5 CJK UNIFIED IDEOGRAPH-#3FE5, IRGKangXi=0789.020, Def{shine; clear and pure white feather (same as 皬) white, white but not pure}
3FE6 CJK UNIFIED IDEOGRAPH-#3FE6, IRGKangXi=0789.130, Def{to tell; to inform; to report; to accuse}
3FE7 CJK UNIFIED IDEOGRAPH-#3FE7, IRGKangXi=0789.290, Def{(same as 疇) fields, a pronoun; who?, formerly; previously, a class; a rank}
3FE8 CJK UNIFIED IDEOGRAPH-#3FE8, IRGKangXi=0790.050, Def{(same as 皪) small stones, gravel, shingle}
3FE9 CJK UNIFIED IDEOGRAPH-#3FE9, IRGKangXi=0790.100, Def{light; bright, white color}
3FEA CJK UNIFIED IDEOGRAPH-#3FEA, IRGKangXi=0790.170, Def{skin disease}
3FEB CJK UNIFIED IDEOGRAPH-#3FEB, IRGKangXi=0790.230, Def{to split tangled hemp}
3FEC CJK UNIFIED IDEOGRAPH-#3FEC, IRGKangXi=0790.250, Def{nasal disease, (same as 疤) a scar; a birthmark (same as 巴) to hope; to wish}
3FED CJK UNIFIED IDEOGRAPH-#3FED, IRGKangXi=0791.010, Def{cracks; creases; wrinkles; rumples on the skin; surname; (Cant.) hoarse}
3FEE CJK UNIFIED IDEOGRAPH-#3FEE, IRGKangXi=0791.070, Def{green; blue; black, extravasation of blood, to look pale or pallid (of the facial complexion)}
3FEF CJK UNIFIED IDEOGRAPH-#3FEF, IRGKangXi=0791.110, Def{wide piece of leather}
3FF0 CJK UNIFIED IDEOGRAPH-#3FF0, IRGKangXi=0791.150, Def{durable and solid leather}
3FF1 CJK UNIFIED IDEOGRAPH-#3FF1, IRGKangXi=0791.170, Def{dry and decayed, to peel off the skin; to scrape; to pare}
3FF2 CJK UNIFIED IDEOGRAPH-#3FF2, IRGKangXi=0791.300, Def{(same as 欹) a fierce dog, an interjection of pleasure -- Bravo! Good! (interchangeable 騎) to sit astride on}
3FF3 CJK UNIFIED IDEOGRAPH-#3FF3, IRGKangXi=0791.410
3FF4 CJK UNIFIED IDEOGRAPH-#3FF4, IRGKangXi=0791.310, Def{wide piece of leather}
3FF5 CJK UNIFIED IDEOGRAPH-#3FF5, IRGKangXi=0791.330, Def{soft leather}
3FF6 CJK UNIFIED IDEOGRAPH-#3FF6, IRGKangXi=0791.440, Def{(same as 幫) the sides of a shoe or gutter}
3FF7 CJK UNIFIED IDEOGRAPH-#3FF7, IRGKangXi=0791.450, Def{(same as 糙) rough; coarse; inferior unpolished rice, goose flesh}
3FF8 CJK UNIFIED IDEOGRAPH-#3FF8, IRGKangXi=0792.070, Def{to cast off the skin; to molt, skin}
3FF9 CJK UNIFIED IDEOGRAPH-#3FF9, IRGKangXi=0792.150, Def{jutting on the epidermis or the cuticle (of plants); (Cant.) skin peeling off}
3FFA CJK UNIFIED IDEOGRAPH-#3FFA, IRGKangXi=0792.240, Def{jutting on the epidermis; swelling, wounded; (Cant.) courageous}
3FFB CJK UNIFIED IDEOGRAPH-#3FFB, IRGKangXi=0792.390, Def{a tray; a plate; a dish, large bowl}
3FFC CJK UNIFIED IDEOGRAPH-#3FFC, IRGKangXi=0792.440, Def{(a non-classical form) a bowl, a small shallow container; a small cup}
3FFD CJK UNIFIED IDEOGRAPH-#3FFD, IRGKangXi=0793.020, Def{a small bowl; a small basin}
3FFE CJK UNIFIED IDEOGRAPH-#3FFE, IRGKangXi=0793.160, Def{vessel; container}
3FFF CJK UNIFIED IDEOGRAPH-#3FFF, IRGKangXi=0793.200, Def{wine cups}
4000 CJK UNIFIED IDEOGRAPH-#4000, IRGKangXi=0793.230, Def{cups; small cups}
4001 CJK UNIFIED IDEOGRAPH-#4001, IRGKangXi=0794.060, Def{a small bowl; a small basin, a kind of vessel to remove (or to strain out) the water}
4002 CJK UNIFIED IDEOGRAPH-#4002, IRGKangXi=0794.140, Def{a big basin}
4003 CJK UNIFIED IDEOGRAPH-#4003, IRGKangXi=0795.020, Def{a kind of vessel; a container}
4004 CJK UNIFIED IDEOGRAPH-#4004, IRGKangXi=0795.080, Def{(same as U+995B 饛) container full of food}
4005 CJK UNIFIED IDEOGRAPH-#4005, IRGKangXi=0795.160, Def{vessel; container}
4006 CJK UNIFIED IDEOGRAPH-#4006, IRGKangXi=0795.230, Def{(standard form of 盡) to exhaust; to complete; to finish; all; totally}
4007 CJK UNIFIED IDEOGRAPH-#4007, IRGKangXi=0796.110, Def{a pot, an earthen pot; a deep cooking pot}
4008 CJK UNIFIED IDEOGRAPH-#4008, IRGKangXi=0796.130, Def{a vessel; a container, a kind of animal with red hair looks like hedgehog}
4009 CJK UNIFIED IDEOGRAPH-#4009, IRGKangXi=0797.080, Def{food containers (bowl; basin, etc.) used in ancient times}
400A CJK UNIFIED IDEOGRAPH-#400A, IRGKangXi=0798.100, Def{a kind of water containers (to keep warm in cold days); a mental hot-water bottle, to stir or scratch and make it muddy or turbid}
400B CJK UNIFIED IDEOGRAPH-#400B, IRGKangXi=0798.171, Def{(same as U+9E7D 鹽) salt}
400C CJK UNIFIED IDEOGRAPH-#400C, IRGKangXi=0798.211
400D CJK UNIFIED IDEOGRAPH-#400D, IRGKangXi=0798.240, Def{vessel; container; a box; a chest; a trunk, a small cup}
400E CJK UNIFIED IDEOGRAPH-#400E, IRGKangXi=0799.040, Def{(same as non-classical form of 眄) to look askance; to ogle}
400F CJK UNIFIED IDEOGRAPH-#400F, IRGKangXi=0799.070, Def{to move one's eyes (same as 眴) to express or indicate with eyes (interchangeable 眩) dizzy; giddy}
4010 CJK UNIFIED IDEOGRAPH-#4010, IRGKangXi=0799.110, Def{to regard; to look up to, to look, to take a glance at}
4011 CJK UNIFIED IDEOGRAPH-#4011, IRGKangXi=0799.120, Def{to gouge out an eye or eyes (a corrupted form)}
4012 CJK UNIFIED IDEOGRAPH-#4012, IRGKangXi=0799.140, Def{gloomy; dark; obscure}
4013 CJK UNIFIED IDEOGRAPH-#4013, IRGKangXi=0799.160, Def{to turn one's eyes to; big eyes}
4014 CJK UNIFIED IDEOGRAPH-#4014, IRGKangXi=0799.230, Def{to look, to confuse; to dazzle}
4015 CJK UNIFIED IDEOGRAPH-#4015, IRGKangXi=0801.010, Def{angry glances; to look angrily, eyeballs}
4016 CJK UNIFIED IDEOGRAPH-#4016, IRGKangXi=0801.030, Def{to look up to; to respect}
4017 CJK UNIFIED IDEOGRAPH-#4017, IRGKangXi=0801.070, Def{to look askance at, to dislike, a kind of eye disease (tears all the times), pretty eyes, (same as 瞲) to look at in surprise}
4018 CJK UNIFIED IDEOGRAPH-#4018, IRGKangXi=0801.100, Def{(a corrupted abbreviated form) to cover the line of vision or sight --the straight line between an object and one's eyes, to look steadily at, to look at impatiently}
4019 CJK UNIFIED IDEOGRAPH-#4019, IRGKangXi=0801.180, Def{to look at, to examine; to observe; to survey}
401A CJK UNIFIED IDEOGRAPH-#401A, IRGKangXi=0802.110, Def{to lift up the eyes and look around}
401B CJK UNIFIED IDEOGRAPH-#401B, IRGKangXi=0803.040, Def{to look far with the eyes half-closed (to narrow the eyes), to look at for a long time, daybreak; dawn, to look not straight forward, to disturb; to dizzy; dark, to look at ferocious}
401C CJK UNIFIED IDEOGRAPH-#401C, IRGKangXi=0803.050, Def{down; to see obscurely, (same as U+401B 䀛)}
401D CJK UNIFIED IDEOGRAPH-#401D, IRGKangXi=0803.151
401E CJK UNIFIED IDEOGRAPH-#401E, IRGKangXi=0803.151, Def{with heavy eyelids}
401F CJK UNIFIED IDEOGRAPH-#401F, IRGKangXi=0803.170, Def{sight blurred; unclear; dim}
4020 CJK UNIFIED IDEOGRAPH-#4020, IRGKangXi=0803.220, Def{a Chinese family name, the timid look of a bird; (of birds) to look around, nervous (same as 瞿) shocked or scared}
4021 CJK UNIFIED IDEOGRAPH-#4021, IRGKangXi=0804.170, Def{(same as 覘) to spy on; to see; to observe; to inspect, to cast the eyes down, the insight of the debauchee, to move the eyes; to look around}
4022 CJK UNIFIED IDEOGRAPH-#4022, IRGKangXi=0805.090, Def{(same as 瞬) to glance; to blink; wink,, (interchangeable 眴 瞚), to indicate one's wish or intention by expressions of the eyes}
4023 CJK UNIFIED IDEOGRAPH-#4023, IRGKangXi=0805.210, Def{to look steadily at, ashamed, to look at ferocious}
4024 CJK UNIFIED IDEOGRAPH-#4024, IRGKangXi=0806.020, Def{insight (version) of jealousy}
4025 CJK UNIFIED IDEOGRAPH-#4025, IRGKangXi=0806.081, Def{(simplified form of 䁻) beautiful eyes, to look at just for a short time}
4026 CJK UNIFIED IDEOGRAPH-#4026, IRGKangXi=0806.081, Def{(a dialect) to stare at}
4027 CJK UNIFIED IDEOGRAPH-#4027, IRGKangXi=0806.100, Def{sight blurred; obscure and dim; unclear}
4028 CJK UNIFIED IDEOGRAPH-#4028, IRGKangXi=0806.140, Def{to look, an angry look; to look at some one angrily, sight blurred; obscure and dim; unclear}
4029 CJK UNIFIED IDEOGRAPH-#4029, IRGKangXi=0806.150, Def{to look askance, to look; to see, to hope, big eyes}
402A CJK UNIFIED IDEOGRAPH-#402A, IRGKangXi=0806.200, Def{birds flying up and down, to look at; to regard; to inspect}
402B CJK UNIFIED IDEOGRAPH-#402B, IRGKangXi=0806.310, Def{narrow and dim eye sight; having one eye smallerthantthe other, one-eyed, wink of the eyelashes, sleepy; drowsy; dim; vague and hazy}
402C CJK UNIFIED IDEOGRAPH-#402C, IRGKangXi=0806.350, Def{to glance; to wink, having one eye smaller than the other, one eyed, gazing into distance, sight blurred; obscure and dim; unclear}
402D CJK UNIFIED IDEOGRAPH-#402D, IRGKangXi=0806.360, Def{with big eyes}
402E CJK UNIFIED IDEOGRAPH-#402E, IRGKangXi=0807.130, Def{sight blurred; obscure and dim; obscured}
402F CJK UNIFIED IDEOGRAPH-#402F, IRGKangXi=0808.070, Def{to look at; to see; to observe; to examine; to consider}
4030 CJK UNIFIED IDEOGRAPH-#4030, IRGKangXi=0808.080, Def{open eyes, big eyes, to move one's eyes}
4031 CJK UNIFIED IDEOGRAPH-#4031, IRGKangXi=0808.140, Def{to examine; to observe; to survey; to study}
4032 CJK UNIFIED IDEOGRAPH-#4032, IRGKangXi=0808.180, Def{diseases in the eyes}
4033 CJK UNIFIED IDEOGRAPH-#4033, IRGKangXi=0808.230, Def{(abbreviated form) not to look straight forward, the pupil of the eyes not in the right place}
4034 CJK UNIFIED IDEOGRAPH-#4034, IRGKangXi=0808.260, Def{to look straight forward, to look, eyesight blurred; not clear}
4035 CJK UNIFIED IDEOGRAPH-#4035, IRGKangXi=0808.280, Def{(same as 瞬) to blink; wink or twinkle, by eyes (facial expressions) to indicate one's wish or intention}
4036 CJK UNIFIED IDEOGRAPH-#4036, IRGKangXi=0808.340, Def{strabismus; squint, to look askance; to ogle, (a dialect) bright; light; brilliant, bright eyes}
4037 CJK UNIFIED IDEOGRAPH-#4037, IRGKangXi=0808.350, Def{to have quick glance; look-in; to look hastily}
4038 CJK UNIFIED IDEOGRAPH-#4038, IRGKangXi=0808.400, Def{(interchangeable 䀿) to have a casual and short glance; to catch a glimpse of, pretty eyes, insight; vision, bright eyes}
4039 CJK UNIFIED IDEOGRAPH-#4039, IRGKangXi=0809.030, Def{(same as 眨) to wink; (same as 睫) eyelashes, having one eye smaller than the other, joke; witticism; pleasantry; jest; fun; (Cant.) to peep at; to blink, wink}
403A CJK UNIFIED IDEOGRAPH-#403A, IRGKangXi=0809.060, Def{squinting eyes; prominent eyes, all blind, eyesight not clear, upper eyelid which has a double fold at the lower edge}
403B CJK UNIFIED IDEOGRAPH-#403B, IRGKangXi=0809.090, Def{to look; to regard; to inspect}
403C CJK UNIFIED IDEOGRAPH-#403C, IRGKangXi=0809.100, Def{(non-classical form of 瞋) angry; anger, complaining; grudging, wide open the eyes, depressed; melancholy, to look at, to confuse, confused vision}
403D CJK UNIFIED IDEOGRAPH-#403D, IRGKangXi=0809.110, Def{to look at each other}
403E CJK UNIFIED IDEOGRAPH-#403E, IRGKangXi=0809.180, Def{many; much, more than; over}
403F CJK UNIFIED IDEOGRAPH-#403F, IRGKangXi=0809.211, Def{(same as 䀸) to have a casual and short glance; to catch a glimpse of, pretty eyes, insight; vision, bright eyes}
4040 CJK UNIFIED IDEOGRAPH-#4040, IRGKangXi=0809.211
4041 CJK UNIFIED IDEOGRAPH-#4041, IRGKangXi=0809.240, Def{(same as 䀶) strabismus; squint, to look askance; to ogle, (a dialect) bright; light; brilliant, bright eyes}
4042 CJK UNIFIED IDEOGRAPH-#4042, IRGKangXi=0809.290, Def{big eyes}
4043 CJK UNIFIED IDEOGRAPH-#4043, IRGKangXi=0809.300, Def{to look attentively; to focus one's look at; to gaze at}
4044 CJK UNIFIED IDEOGRAPH-#4044, IRGKangXi=0809.350, Def{to close the eyes, to die without regreat or in peace}
4045 CJK UNIFIED IDEOGRAPH-#4045, IRGKangXi=0810.060, Def{rage; anger, to cast an angry look; to give the black looks}
4046 CJK UNIFIED IDEOGRAPH-#4046, IRGKangXi=0810.110, Def{eyes, closed eyes}
4047 CJK UNIFIED IDEOGRAPH-#4047, IRGKangXi=0810.180, Def{to look for a short time, attentive vision}
4048 CJK UNIFIED IDEOGRAPH-#4048, IRGKangXi=0810.190, Def{to examine; to survey; to inspect; to visit, to watch or see in secret; to spy; to peep}
4049 CJK UNIFIED IDEOGRAPH-#4049, IRGKangXi=0810.200, Def{(same as 䁈) to examine; to survey; to inspect; to visit, to watch or see in secret; to spy; to peep}
404A CJK UNIFIED IDEOGRAPH-#404A, IRGKangXi=0812.020, Def{dark and deep eyed, to look down, to block, to stuff, to cork; to seal}
404B CJK UNIFIED IDEOGRAPH-#404B, IRGKangXi=0812.030, Def{with one eye closed, to close the eyes; (same as U+77B8 瞸) to look askance at; (Cant.) to close the eyes}
404C CJK UNIFIED IDEOGRAPH-#404C, IRGKangXi=0812.080, Def{to see for a short time}
404D CJK UNIFIED IDEOGRAPH-#404D, IRGKangXi=0812.150, Def{blind, hollow-eyed, to look at}
404E CJK UNIFIED IDEOGRAPH-#404E, IRGKangXi=0812.210, Def{to make a close inspection, secretion of the eye, (same as 瞠) to look straight at; to stare at}
404F CJK UNIFIED IDEOGRAPH-#404F, IRGKangXi=0812.240, Def{farsightedness (as a physical defect); hypermetropia, to look from a distance}
4050 CJK UNIFIED IDEOGRAPH-#4050, IRGKangXi=0812.260, Def{deep eyed, to look at; to inspect; to see}
4051 CJK UNIFIED IDEOGRAPH-#4051, IRGKangXi=0812.320, Def{(same as 眻) pretty eyes, the space between eyebrows, (interchangeable 揚) to raise; to praise, to display}
4052 CJK UNIFIED IDEOGRAPH-#4052, IRGKangXi=0812.380, Def{to wink, to shed tears}
4053 CJK UNIFIED IDEOGRAPH-#4053, IRGKangXi=0812.400, Def{to look at; to see, to peep; to look something stealthily, angry}
4054 CJK UNIFIED IDEOGRAPH-#4054, IRGKangXi=0812.410, Def{big eyes (same as 睅) protuberant eyes, goggle-eye}
4055 CJK UNIFIED IDEOGRAPH-#4055, IRGKangXi=0813.010, Def{(same as 盿) to look at; to see, to look down; to look from above}
4056 CJK UNIFIED IDEOGRAPH-#4056, IRGKangXi=0813.161, Def{to see; to look at; to observe}
4057 CJK UNIFIED IDEOGRAPH-#4057, IRGKangXi=0813.190, Def{light; bright; brilliant, clear, to shine upon; to light or illumine}
4058 CJK UNIFIED IDEOGRAPH-#4058, IRGKangXi=0813.200, Def{to look at; to see, pretty eyes; (same as U+404F 䁏) farsightedness (as a physical defect); hypermetropia, to look from a distance}
4059 CJK UNIFIED IDEOGRAPH-#4059, IRGKangXi=0813.220, Def{eloquent eyes; to converse with eyes; to make sheep eyes or passes, to look at; to see, to look up to; to respect}
405A CJK UNIFIED IDEOGRAPH-#405A, IRGKangXi=0814.010, Def{a kind of eye disease, (a non-classical form)}
405B CJK UNIFIED IDEOGRAPH-#405B, IRGKangXi=0814.230, Def{to look; to see; to inspect}
405C CJK UNIFIED IDEOGRAPH-#405C, IRGKangXi=0814.350, Def{big eyes, a kind of eye disease}
405D CJK UNIFIED IDEOGRAPH-#405D, IRGKangXi=0815.090, Def{deluding and causing disorder (interchangeable 熒) lights shining; sparkling; twinkling; shimmering}
405E CJK UNIFIED IDEOGRAPH-#405E, IRGKangXi=0815.110, Def{(same as ancient form of 省) a province, to examine; to watch, to reduce, to diminish}
405F CJK UNIFIED IDEOGRAPH-#405F, IRGKangXi=0815.130, Def{(interchangeable 差) wrong; mistaken; erroneous, disorderly; untidy; irregular}
4060 CJK UNIFIED IDEOGRAPH-#4060, IRGKangXi=0815.160, Def{to hang down (eyes)}
4061 CJK UNIFIED IDEOGRAPH-#4061, IRGKangXi=0815.181
4062 CJK UNIFIED IDEOGRAPH-#4062, IRGKangXi=0815.190, Def{(same as 嫙) exquisite; fine}
4063 CJK UNIFIED IDEOGRAPH-#4063, IRGKangXi=0815.240, Def{to wink}
4064 CJK UNIFIED IDEOGRAPH-#4064, IRGKangXi=0815.340, Def{moistened eyes, to stare in anger or contempt}
4065 CJK UNIFIED IDEOGRAPH-#4065, IRGKangXi=0815.350, Def{to blink; to half-close the eyes, small eyes (same as U+7724 昵) very dear; very intimate; very much in love}
4066 CJK UNIFIED IDEOGRAPH-#4066, IRGKangXi=0815.410, Def{(same as U+89B0 覷) to see; to look at, to steal a glance; to glance quickly, to spy on; to peep at}
4067 CJK UNIFIED IDEOGRAPH-#4067, IRGKangXi=0816.020, Def{to open wide (eyes)}
4068 CJK UNIFIED IDEOGRAPH-#4068, IRGKangXi=0816.080, Def{to open the eyes with astonishment, (interchangeable 矐) to lose one's eyesight; to become blind; blind}
4069 CJK UNIFIED IDEOGRAPH-#4069, IRGKangXi=0816.140, Def{(same as 魚) fish, inferior horse with blind eyes}
406A CJK UNIFIED IDEOGRAPH-#406A, IRGKangXi=0816.211, Def{to wink}
406B CJK UNIFIED IDEOGRAPH-#406B, IRGKangXi=0817.020, Def{muddy; dirty, eyesight obscured}
406C CJK UNIFIED IDEOGRAPH-#406C, IRGKangXi=0817.040, Def{to act pretentiously (by slit-eyed), eyesight obscured}
406D CJK UNIFIED IDEOGRAPH-#406D, IRGKangXi=0817.070, Def{to give an angry look, to watch; to view}
406E CJK UNIFIED IDEOGRAPH-#406E, IRGKangXi=0817.150, Def{sad; mournful; grieved, to worry about, to think with one's eyes closed, to close the eyes}
406F CJK UNIFIED IDEOGRAPH-#406F, IRGKangXi=0817.160, Def{to look at; to see; to inspect; (same as U+77B8 瞸) gazing into distance, having one eye smaller than the other, to look askance at; (Cant.) to close the eyes}
4070 CJK UNIFIED IDEOGRAPH-#4070, IRGKangXi=0817.220, Def{to look in a evil or wicked way; wicked vision}
4071 CJK UNIFIED IDEOGRAPH-#4071, IRGKangXi=0817.250, Def{(same as 眗) hollow-eyed}
4072 CJK UNIFIED IDEOGRAPH-#4072, IRGKangXi=0818.060, Def{to peep; to look at something stealthily; (Cant.) to close the eyes}
4073 CJK UNIFIED IDEOGRAPH-#4073, IRGKangXi=0818.120, Def{to lose one eye}
4074 CJK UNIFIED IDEOGRAPH-#4074, IRGKangXi=0818.250, Def{keep on looking, change the facial expression}
4075 CJK UNIFIED IDEOGRAPH-#4075, IRGKangXi=0818.280, Def{newborn baby with the eyelids closed, big eyes, to close the eyes}
4076 CJK UNIFIED IDEOGRAPH-#4076, IRGKangXi=0818.290, Def{to look at something without winking, bright}
4077 CJK UNIFIED IDEOGRAPH-#4077, IRGKangXi=0818.310, Def{bright eyes, angry look; angry eyes (ancient form of 覺) to awaken, to wake up from sleep, to feel}
4078 CJK UNIFIED IDEOGRAPH-#4078, IRGKangXi=0818.320, Def{eyesight obscured, angry glances}
4079 CJK UNIFIED IDEOGRAPH-#4079, IRGKangXi=0818.330, Def{(same as U+7764 睥) to look askance -- a expression of disdain or despise}
407A CJK UNIFIED IDEOGRAPH-#407A, IRGKangXi=0818.350, Def{to look at; to see; to inspect, sharp, bright-colored; bright eyes, (same as non-classical form of 睪) spy on, to lead on}
407B CJK UNIFIED IDEOGRAPH-#407B, IRGKangXi=0820.110, Def{pretty eyes, to have a casual and short glance}
407C CJK UNIFIED IDEOGRAPH-#407C, IRGKangXi=0820.120, Def{(literally) to look but see nothing -- absent-minded, to regard as nothing}
407D CJK UNIFIED IDEOGRAPH-#407D, IRGKangXi=0820.140, Def{eyesight obscured, abnormal vision; (Cant.) to glance at, sweep the eyes over}
407E CJK UNIFIED IDEOGRAPH-#407E, IRGKangXi=0820.200, Def{red and swelling of the eye socket, dim-sighted; poor visioned}
407F CJK UNIFIED IDEOGRAPH-#407F, IRGKangXi=0820.300, Def{sleepy; drowsy, to startle; to surprise; to amaze}
4080 CJK UNIFIED IDEOGRAPH-#4080, IRGKangXi=0820.310, Def{to wink}
4081 CJK UNIFIED IDEOGRAPH-#4081, IRGKangXi=0820.350, Def{an angry look; to look at someone angrily, hollow-eyed}
4082 CJK UNIFIED IDEOGRAPH-#4082, IRGKangXi=0821.010, Def{to gaze at in terror, a surname}
4083 CJK UNIFIED IDEOGRAPH-#4083, IRGKangXi=0821.070, Def{dark; dim; eyesight obscured, angry look; angry eyes}
4084 CJK UNIFIED IDEOGRAPH-#4084, IRGKangXi=0821.160, Def{to startle; to surprise; to amaze; to look at in surprise}
4085 CJK UNIFIED IDEOGRAPH-#4085, IRGKangXi=0821.210, Def{to have insight or vision of a simple and honest person, silly}
4086 CJK UNIFIED IDEOGRAPH-#4086, IRGKangXi=0821.270, Def{weapons; arms (a lance; a spear)}
4087 CJK UNIFIED IDEOGRAPH-#4087, IRGKangXi=0822.020, Def{to pierce; to stab; to irritate; to hurt, a thorn}
4088 CJK UNIFIED IDEOGRAPH-#4088, IRGKangXi=0822.130, Def{to pierce; to stab; to irritate; to hurt, a thorn, a lance; a spear}
4089 CJK UNIFIED IDEOGRAPH-#4089, IRGKangXi=0822.270, Def{weapons; arms (a lance; a spear)}
408A CJK UNIFIED IDEOGRAPH-#408A, IRGKangXi=0823.170, Def{weapons; arms (a lance; a spear)}
408B CJK UNIFIED IDEOGRAPH-#408B, IRGKangXi=0558.091
408C CJK UNIFIED IDEOGRAPH-#408C, IRGKangXi=0823.190, Def{a short weapon (daggers; swords; knives)}
408D CJK UNIFIED IDEOGRAPH-#408D, IRGKangXi=0823.290, Def{a kind of weapon carried by the honor guard before the Emperor in ancient times}
408E CJK UNIFIED IDEOGRAPH-#408E, IRGKangXi=0823.310, Def{a short spear; a lance with two points, a halberd, to pierce; to stab; to irritate, to catch a spear from away}
408F CJK UNIFIED IDEOGRAPH-#408F, IRGKangXi=0824.120, Def{short, dog with short tail}
4090 CJK UNIFIED IDEOGRAPH-#4090, IRGKangXi=0824.140, Def{short (ancient form of 拙) stupid; crude; poor; slow and clumsy}
4091 CJK UNIFIED IDEOGRAPH-#4091, IRGKangXi=0824.150, RSKangXi=111.5, Def{short; (Cant.) intensifier}
4092 CJK UNIFIED IDEOGRAPH-#4092, IRGKangXi=0824.240, Def{short (dialect) to curry favor; to toady; to flatter; to try hard to please}
4093 CJK UNIFIED IDEOGRAPH-#4093, IRGKangXi=0825.010, Def{(standard form of 規) regulations; laws; rules; customs or usages, a pair of compasses}
4094 CJK UNIFIED IDEOGRAPH-#4094, IRGKangXi=0825.040, Def{short}
4095 CJK UNIFIED IDEOGRAPH-#4095, IRGKangXi=0825.140, Def{short}
4096 CJK UNIFIED IDEOGRAPH-#4096, IRGKangXi=0827.031, Def{(same as 石) rocks; stones; minerals, etc.}
4097 CJK UNIFIED IDEOGRAPH-#4097, IRGKangXi=0827.100, Def{to be careful; to exercise caution; to take care; to pay attention}
4098 CJK UNIFIED IDEOGRAPH-#4098, IRGKangXi=0827.191, Def{pebble; small piece of stone}
4099 CJK UNIFIED IDEOGRAPH-#4099, IRGKangXi=1270.071
409A CJK UNIFIED IDEOGRAPH-#409A, IRGKangXi=0828.110, Def{a kind of stone, rugged rocks, difficult; hard; difficulty; hardship}
409B CJK UNIFIED IDEOGRAPH-#409B, IRGKangXi=0828.120, Def{a kind of rock}
409C CJK UNIFIED IDEOGRAPH-#409C, IRGKangXi=0828.140, Def{rocky (same as 玤) fine stone which is little less valuable than jade (interchangeable 崩) to collapse; to fall}
409D CJK UNIFIED IDEOGRAPH-#409D, IRGKangXi=0828.241, Def{(same as 矺) to rap; to tap; to beat(same as 磔) torture of dismemberment used in the ancient times, sound of throwing something to the ground}
409E CJK UNIFIED IDEOGRAPH-#409E, IRGKangXi=0521.121, Def{(same as 柘) a thorny tree about 15 feet high, the leaves are used for feeding silkworms before the mulberry leaves are ready or when they are scarce, bark contains a yellow dye (interchangeable 蔗) the sugar cane}
409F CJK UNIFIED IDEOGRAPH-#409F, IRGKangXi=0828.290, Def{rocks; stones; minerals, etc.}
40A0 CJK UNIFIED IDEOGRAPH-#40A0, IRGKangXi=0828.340, Def{sound of falling rocks, the arrowhead made of stone}
40A1 CJK UNIFIED IDEOGRAPH-#40A1, IRGKangXi=0828.380, Def{(non-classical form 砥) a whetstone, smooth, to polish}
40A2 CJK UNIFIED IDEOGRAPH-#40A2, IRGKangXi=0828.400, Def{sound of falling rocks, fallen rocks}
40A3 CJK UNIFIED IDEOGRAPH-#40A3, IRGKangXi=0828.410, Def{a kind of mineral}
40A4 CJK UNIFIED IDEOGRAPH-#40A4, IRGKangXi=0828.440, Def{white stone}
40A5 CJK UNIFIED IDEOGRAPH-#40A5, IRGKangXi=0829.030, Def{(same as 賨) a fine stone resembling jade}
40A6 CJK UNIFIED IDEOGRAPH-#40A6, IRGKangXi=0829.260, Def{tired; exhausted, rugged stone, coarse whetstone, to pile up rocks on the river-bank}
40A7 CJK UNIFIED IDEOGRAPH-#40A7, IRGKangXi=0829.320, Def{rocks clustered pile up together}
40A8 CJK UNIFIED IDEOGRAPH-#40A8, IRGKangXi=0829.331
40A9 CJK UNIFIED IDEOGRAPH-#40A9, IRGKangXi=0829.390, Def{(same as 硯) an in-slab or ink-stone (same as 硜) sound of pebbles or stones rubbing or knocking together}
40AA CJK UNIFIED IDEOGRAPH-#40AA, IRGKangXi=0829.450, Def{(same as 磽) hard barren land, a kind of stone (interchangeable 銚) a small pot with a handle}
40AB CJK UNIFIED IDEOGRAPH-#40AB, IRGKangXi=0829.460, Def{noise of stones rolling down, to ram the earth for foundations, (same as U+592F 夯) to raise with force; a heavy load; burden, to fill cracks and leakages with earth (in levee construction)}
40AC CJK UNIFIED IDEOGRAPH-#40AC, IRGKangXi=0829.550, Def{big rocks on the riverside (interchangeable 栱) an arched opening}
40AD CJK UNIFIED IDEOGRAPH-#40AD, IRGKangXi=0830.050, Def{name of a place; today's Jizhou}
40AE CJK UNIFIED IDEOGRAPH-#40AE, IRGKangXi=0830.070, Def{stone, to sharpen a knife, sharp-pointed; sharp, vigorous; energetic; keen}
40AF CJK UNIFIED IDEOGRAPH-#40AF, IRGKangXi=0830.131, Def{a fine stone resembling jade}
40B0 CJK UNIFIED IDEOGRAPH-#40B0, IRGKangXi=0830.190, Def{rocks; stones; minerals, etc.}
40B1 CJK UNIFIED IDEOGRAPH-#40B1, IRGKangXi=0830.220, Def{to wear out; rubbed out; to die out; to wear away; frayed}
40B2 CJK UNIFIED IDEOGRAPH-#40B2, IRGKangXi=0830.260, Def{(same as 砝) standard weights used in scales; steelyard weights}
40B3 CJK UNIFIED IDEOGRAPH-#40B3, IRGKangXi=0830.330, Def{gravel; macadam; (interchangeable 剉) to damage; to destroy, medicines; orpiment (common monoclinic arsenic sulfide mineral, As2S3)}
40B4 CJK UNIFIED IDEOGRAPH-#40B4, IRGKangXi=0831.120, Def{(same as U+7814 研) to rub; to grind; to powder, to go the very source; to study; to investigate; to research; to examine; to search into carefully}
40B5 CJK UNIFIED IDEOGRAPH-#40B5, IRGKangXi=0831.131, Def{(a simplified form of 碽) sound of bumping or striking, arched bridge}
40B6 CJK UNIFIED IDEOGRAPH-#40B6, IRGKangXi=0831.131, Def{the Crustacea; a sea-anemone}
40B7 CJK UNIFIED IDEOGRAPH-#40B7, IRGKangXi=0831.140, Def{broken; smashed, trivial, irregular, different; varied sizes (of rocks)}
40B8 CJK UNIFIED IDEOGRAPH-#40B8, IRGKangXi=0831.190, Def{to smash or to knock to pieces of the stone, broken}
40B9 CJK UNIFIED IDEOGRAPH-#40B9, IRGKangXi=0831.210, Def{sound of the falling pieces of rocks}
40BA CJK UNIFIED IDEOGRAPH-#40BA, IRGKangXi=0831.240, Def{rocks; stones (same as 顆) a drop; a grain; a bead}
40BB CJK UNIFIED IDEOGRAPH-#40BB, IRGKangXi=0831.270, Def{to block; to stop up, to cork; to seal; (same as U+92E5 鋥) to polish; to grind; (Cant.) to push; to burst; to stuff}
40BC CJK UNIFIED IDEOGRAPH-#40BC, IRGKangXi=0831.310, Def{(a kind of) rocks; stones}
40BD CJK UNIFIED IDEOGRAPH-#40BD, IRGKangXi=0831.340, Def{(a kind of) rocks; stones}
40BE CJK UNIFIED IDEOGRAPH-#40BE, IRGKangXi=0831.350, Def{to polish; to grind; to rub}
40BF CJK UNIFIED IDEOGRAPH-#40BF, IRGKangXi=0831.380, Def{to pound (grain) in order to remove the husk; refine; polished (rice), to tread upon; to step upon a pestle (for husking grain)}
40C0 CJK UNIFIED IDEOGRAPH-#40C0, IRGKangXi=0831.390, Def{millstone; grindstone, to rub; to grind; to polish; to wear, to sharpen (a knife), to train; to harden; to temper}
40C1 CJK UNIFIED IDEOGRAPH-#40C1, IRGKangXi=0832.060, Def{uneven or rugged terrains}
40C2 CJK UNIFIED IDEOGRAPH-#40C2, IRGKangXi=0832.120, Def{dull sound of the tolling bell, sound of rolling, rolling stone, a farm tool made of stone (a stone roller for hulling grains, etc.)}
40C3 CJK UNIFIED IDEOGRAPH-#40C3, IRGKangXi=0832.211
40C4 CJK UNIFIED IDEOGRAPH-#40C4, IRGKangXi=0832.211
40C5 CJK UNIFIED IDEOGRAPH-#40C5, IRGKangXi=0832.211, Def{(simplified form 磾) dyestuff (black colored mineral)}
40C6 CJK UNIFIED IDEOGRAPH-#40C6, IRGKangXi=0832.211
40C7 CJK UNIFIED IDEOGRAPH-#40C7, IRGKangXi=0832.211, Def{ink (usually red) for imprinting of seals}
40C8 CJK UNIFIED IDEOGRAPH-#40C8, IRGKangXi=0832.240, Def{mountain rocks(same as 瑎) a black stone resembling jade}
40C9 CJK UNIFIED IDEOGRAPH-#40C9, IRGKangXi=0832.330, Def{(same as 賨) a stone resembling jade}
40CA CJK UNIFIED IDEOGRAPH-#40CA, IRGKangXi=0832.350, Def{to rub; to grind; to polish; to wear}
40CB CJK UNIFIED IDEOGRAPH-#40CB, IRGKangXi=0833.100, Def{a fine stone resembling jade}
40CC CJK UNIFIED IDEOGRAPH-#40CC, IRGKangXi=0833.180, Def{rocky mountain, used in naming a place}
40CD CJK UNIFIED IDEOGRAPH-#40CD, IRGKangXi=0833.200, Def{(ancient form of 墜) to fall down; to sink}
40CE CJK UNIFIED IDEOGRAPH-#40CE, IRGKangXi=0833.220, Def{name of a place (usually to be used in naming a place) (interchangeable 砟) small piece of coal}
40CF CJK UNIFIED IDEOGRAPH-#40CF, IRGKangXi=0833.230, Def{a kind of rock}
40D0 CJK UNIFIED IDEOGRAPH-#40D0, IRGKangXi=0833.291
40D1 CJK UNIFIED IDEOGRAPH-#40D1, IRGKangXi=0834.030, Def{(same as standard form 斑) speckles; spots; mottles (same as 磐) a massive rock}
40D2 CJK UNIFIED IDEOGRAPH-#40D2, IRGKangXi=0834.060, Def{(of land) poor and barren; field which is not arable}
40D3 CJK UNIFIED IDEOGRAPH-#40D3, IRGKangXi=0834.080, Def{to punish; to chastise; to penalize, to kill; to execute, pedal (a footboard) of a cart, brick work of a well, strong and durable, solid; firm}
40D4 CJK UNIFIED IDEOGRAPH-#40D4, IRGKangXi=0834.090, Def{sound of falling rocks, loud noise, stone with strange and unique shapes}
40D5 CJK UNIFIED IDEOGRAPH-#40D5, IRGKangXi=0834.130, Def{stoneware; stone implement, soap-stone, sound of the bumping rocks, (in music) a chord}
40D6 CJK UNIFIED IDEOGRAPH-#40D6, IRGKangXi=0834.200, Def{(same as U+9696 塢) a bank; a low wall; an entrenchment, a structure which slants to a lower center on all sides -- as a shipyard}
40D7 CJK UNIFIED IDEOGRAPH-#40D7, IRGKangXi=0834.230, Def{rocks; stones, rocks paved bank, big rocks}
40D8 CJK UNIFIED IDEOGRAPH-#40D8, IRGKangXi=0835.100, Def{simple and crude (same as 硜) the sound of pebbles or stones knocking together, obstinate; determined; resolute}
40D9 CJK UNIFIED IDEOGRAPH-#40D9, IRGKangXi=0835.120, Def{rocks; stones; minerals, etc.}
40DA CJK UNIFIED IDEOGRAPH-#40DA, IRGKangXi=0835.160, Def{rugged land of sand and pebble; poor and barren (of land) (same as 鏃) the barb of an arrow, arrowhead; the head of a javelin}
40DB CJK UNIFIED IDEOGRAPH-#40DB, IRGKangXi=0835.280, Def{(same as 鏈) chain, cable}
40DC CJK UNIFIED IDEOGRAPH-#40DC, IRGKangXi=0835.320, Def{a fine black stone}
40DD CJK UNIFIED IDEOGRAPH-#40DD, IRGKangXi=0835.370, Def{(same as 礉) rugged rocks}
40DE CJK UNIFIED IDEOGRAPH-#40DE, IRGKangXi=0836.070, Def{a kind of stone, sound of pebbles or stones rubbing or knocking together}
40DF CJK UNIFIED IDEOGRAPH-#40DF, IRGKangXi=0836.091, Def{䃟頭窰, a place in Hong Kong}
40E0 CJK UNIFIED IDEOGRAPH-#40E0, IRGKangXi=0836.091
40E1 CJK UNIFIED IDEOGRAPH-#40E1, IRGKangXi=0836.110, Def{a small pebble; small piece of stone or rock, a stone door}
40E2 CJK UNIFIED IDEOGRAPH-#40E2, IRGKangXi=0836.190, Def{name of a mountain (same as 嶔) lofty (of a mountain)}
40E3 CJK UNIFIED IDEOGRAPH-#40E3, IRGKangXi=0836.230, Def{(same as 毀) to ruin, to destroy, to break down}
40E4 CJK UNIFIED IDEOGRAPH-#40E4, IRGKangXi=0836.250, Def{black colored grindstone or whetstone}
40E5 CJK UNIFIED IDEOGRAPH-#40E5, IRGKangXi=0836.370, Def{stones; rocks}
40E6 CJK UNIFIED IDEOGRAPH-#40E6, IRGKangXi=0836.380, Def{a flat and great rock people squat or crouch on it}
40E7 CJK UNIFIED IDEOGRAPH-#40E7, IRGKangXi=0837.030, Def{sound of falling rocks}
40E8 CJK UNIFIED IDEOGRAPH-#40E8, IRGKangXi=0837.091
40E9 CJK UNIFIED IDEOGRAPH-#40E9, IRGKangXi=0837.110, Def{(same as 縭) a mineral, used as a medicine}
40EA CJK UNIFIED IDEOGRAPH-#40EA, IRGKangXi=0837.130, Def{(same as 壇) a platform for sacrificial rites; an altar, an arena; a hall for important meetings and ceremonies in ancient China}
40EB CJK UNIFIED IDEOGRAPH-#40EB, IRGKangXi=0837.250, Def{a silicate substance from the salt-wells in Szechwan; it is used as a wash for hardening plaster, etc., also for certain skin diseases, like ringworm, sulphate of copper}
40EC CJK UNIFIED IDEOGRAPH-#40EC, IRGKangXi=0837.380, Def{rocky; plenty of stones and rocks (same as 磈) piles of rugged stones; lumpy and uneven rocks}
40ED CJK UNIFIED IDEOGRAPH-#40ED, IRGKangXi=0837.390, Def{a stone box; a stone case, to cover with a piece of stone, (interchangeable 撼) to shake; to rock}
40EE CJK UNIFIED IDEOGRAPH-#40EE, IRGKangXi=0837.410, Def{a stone build hydraulic measures (to store and to vent the water) in ancient times, rocks in the mountain stream}
40EF CJK UNIFIED IDEOGRAPH-#40EF, IRGKangXi=0837.411, Def{(abbreviated form of 礫) small stones; pebble; gravel; shingle}
40F0 CJK UNIFIED IDEOGRAPH-#40F0, IRGKangXi=0838.040, Def{brick or stone steps}
40F1 CJK UNIFIED IDEOGRAPH-#40F1, IRGKangXi=0838.110, Def{(non-classical form of 䃸) electric light; a flash of lightning, wedge, preface foreword}
40F2 CJK UNIFIED IDEOGRAPH-#40F2, IRGKangXi=0838.150, Def{(same as 磐) a great rock}
40F3 CJK UNIFIED IDEOGRAPH-#40F3, IRGKangXi=0838.170, Def{falling stone, a mineral; an ore (with the element of bronze; copper), appearance of the connected mountains; a mountain range; a chain}
40F4 CJK UNIFIED IDEOGRAPH-#40F4, IRGKangXi=0838.330, Def{a whetstone used to grind precious stone (jade; a gem)}
40F5 CJK UNIFIED IDEOGRAPH-#40F5, IRGKangXi=0838.340, Def{a kind of stone, bends; curves; turns and twists of the mountains}
40F6 CJK UNIFIED IDEOGRAPH-#40F6, IRGKangXi=0838.370, Def{rugged and uneven of the rocks, small piece of stone; pebble, a fine stone resembling jade}
40F7 CJK UNIFIED IDEOGRAPH-#40F7, IRGKangXi=0838.380, Def{a kind of stone, to research and examine}
40F8 CJK UNIFIED IDEOGRAPH-#40F8, IRGKangXi=0838.390, Def{electric light; a flash of lightning, wedge, preface foreword}
40F9 CJK UNIFIED IDEOGRAPH-#40F9, IRGKangXi=0839.020, Def{jade and stone, fine jade}
40FA CJK UNIFIED IDEOGRAPH-#40FA, IRGKangXi=0839.110, Def{(a standard form of 磨) to grind, to rub, to sharpen}
40FB CJK UNIFIED IDEOGRAPH-#40FB, IRGKangXi=0839.150, Def{(same as 壩) an embankment; a dike; a levee; a dam; a bank of earth}
40FC CJK UNIFIED IDEOGRAPH-#40FC, IRGKangXi=0839.251
40FD CJK UNIFIED IDEOGRAPH-#40FD, IRGKangXi=0840.040, Def{name of a mountain (of warship), (same as 禔) happiness; good fortune; good luck; blessing, (same as standard form 祓) to exorcise; to remove evil; to cleanse; to clean; to wash away}
40FE CJK UNIFIED IDEOGRAPH-#40FE, IRGKangXi=0840.110, Def{to offer a small pig as sacrifice when worshipping the god of life}
40FF CJK UNIFIED IDEOGRAPH-#40FF, IRGKangXi=0841.010, Def{a rite or service, message offered to the gods in worship}
4100 CJK UNIFIED IDEOGRAPH-#4100, IRGKangXi=0841.031, Def{(same as 禍) calamity; disaster; evil; misfortune}
4101 CJK UNIFIED IDEOGRAPH-#4101, IRGKangXi=0841.080, Def{to worship; to honor by a service or rite; to offer sacrifices to}
4102 CJK UNIFIED IDEOGRAPH-#4102, IRGKangXi=0841.110, Def{(ancient form) to pray and to curse (the ways of treating a patient in ancient times)}
4103 CJK UNIFIED IDEOGRAPH-#4103, IRGKangXi=0841.250, Def{(ancient standard form 殃) misfortune; calamity; retribution, a departed spirit}
4104 CJK UNIFIED IDEOGRAPH-#4104, IRGKangXi=0842.170, Def{achievement; accomplishment, (non-classical form of 禋) to worship with sincerity and reverence, to offer sacrifices to the Heaven}
4105 CJK UNIFIED IDEOGRAPH-#4105, IRGKangXi=0842.180, Def{(same as standard form U+990B 餋) to worship; to honor by a rite or service; to offer sacrifices}
4106 CJK UNIFIED IDEOGRAPH-#4106, IRGKangXi=0843.030, Def{to worship; to honor by a rite or service; to offer sacrifices, an institution, law, to perform rites in honor of gods}
4107 CJK UNIFIED IDEOGRAPH-#4107, IRGKangXi=0843.100, Def{(corrupted form) a family name}
4108 CJK UNIFIED IDEOGRAPH-#4108, IRGKangXi=0843.130, Def{sacrifice to happiness and good luck}
4109 CJK UNIFIED IDEOGRAPH-#4109, IRGKangXi=0843.150, Def{a rite or service, (same as 娥) good; beautiful, a common name for a girl}
410A CJK UNIFIED IDEOGRAPH-#410A, IRGKangXi=0843.261
410B CJK UNIFIED IDEOGRAPH-#410B, IRGKangXi=0843.270, Def{to pray for preventing or forestalling calamities, muddy}
410C CJK UNIFIED IDEOGRAPH-#410C, IRGKangXi=0843.300, Def{to perform rites in honor of the ancestral temple; the next day's service of the above mentioned rites, (same as 醊) wine poured in a libation}
410D CJK UNIFIED IDEOGRAPH-#410D, IRGKangXi=0843.310, Def{(same as U+8721 蜡) year-end sacrifice of the Zhou Dynasty; imperial sacrifice of thanksgiving to the earth for crops, offered at the end of the year, the name varying in different dynastic periods}
410E CJK UNIFIED IDEOGRAPH-#410E, IRGKangXi=0844.010, Def{(same as 婍) pretty; beautiful (of a woman)}
410F CJK UNIFIED IDEOGRAPH-#410F, IRGKangXi=0844.020, Def{(same as 祅) bizarre, calamity due to terrestrial disturbances (as distinct from 災 -- disaster which is sent down from above) (interchangeable 妖) weird; supernatural, a ghost, bewitching; seductive (said of a woman)}
4110 CJK UNIFIED IDEOGRAPH-#4110, IRGKangXi=0844.120, Def{to worship; to honor by a service or rite; to offer sacrifices, happiness; good fortune; good luck; blessing; bliss}
4111 CJK UNIFIED IDEOGRAPH-#4111, IRGKangXi=0844.171, Def{(same as standard form 䄆) (non-classical form) to worship; to honor by a rite or service; to offer sacrifices, an institution, law, to perform rites in honor of gods}
4112 CJK UNIFIED IDEOGRAPH-#4112, IRGKangXi=0844.171, Def{(same as standard form 稔) ripening of paddy or rice; a harvest, a year}
4113 CJK UNIFIED IDEOGRAPH-#4113, IRGKangXi=0844.210, Def{to worship, a rite; a service}
4114 CJK UNIFIED IDEOGRAPH-#4114, IRGKangXi=0844.290, Def{a family name}
4115 CJK UNIFIED IDEOGRAPH-#4115, IRGKangXi=0845.150, Def{(ancient form of 社) god of the land, an association; an organization; society; community}
4116 CJK UNIFIED IDEOGRAPH-#4116, IRGKangXi=0845.161, Def{used in name of a person}
4117 CJK UNIFIED IDEOGRAPH-#4117, IRGKangXi=0845.161
4118 CJK UNIFIED IDEOGRAPH-#4118, IRGKangXi=0845.230, Def{a rite; a service; to worship}
4119 CJK UNIFIED IDEOGRAPH-#4119, IRGKangXi=0846.020, Def{happiness; good luck; good fortune; blessing; bliss}
411A CJK UNIFIED IDEOGRAPH-#411A, IRGKangXi=0846.120, Def{to worship the god (of the hog; pig), blessed; bliss; divine help, to protect; to defend}
411B CJK UNIFIED IDEOGRAPH-#411B, IRGKangXi=0846.130, Def{(standard form 膢) (in ancient times) service or rites of offering sacrifices for drink and food}
411C CJK UNIFIED IDEOGRAPH-#411C, IRGKangXi=0846.170, Def{happiness and well-being; bliss; propitious; auspicious, evil spirit; a hobgoblin produced from the weird emanations of the trees and rocks on the hills, (interchangeable 魑) a mountain demon resembling a tiger}
411D CJK UNIFIED IDEOGRAPH-#411D, IRGKangXi=0846.180, Def{show no respect to the service of worship}
411E CJK UNIFIED IDEOGRAPH-#411E, IRGKangXi=0846.261
411F CJK UNIFIED IDEOGRAPH-#411F, IRGKangXi=0846.290, Def{to worship; to offer sacrifices couple times, to thank}
4120 CJK UNIFIED IDEOGRAPH-#4120, IRGKangXi=0847.050, Def{(ancient form of 禪) to sacrifice to heaven, the imperial power, as only the emperor was allowed to offer these sacrifices, to cleanse; to exorcize, of Buddhism; Buddhist}
4121 CJK UNIFIED IDEOGRAPH-#4121, IRGKangXi=0847.110, Def{northern minority ethnic group (in ancient times), (corrupted form of 襜) the lower front of a robe, gown, etc., clean and neat (said of appearance)}
4122 CJK UNIFIED IDEOGRAPH-#4122, IRGKangXi=0847.220, Def{(same as 齋) pious; respectful; chaste; pure, to abstain from meat, wine, etc., to fast, (same as 齊) equal; uniform, name of an ancient feudal state}
4123 CJK UNIFIED IDEOGRAPH-#4123, IRGKangXi=0847.251
4124 CJK UNIFIED IDEOGRAPH-#4124, IRGKangXi=0847.270, Def{to sink; to fall; decadent, to idle about; to be negligent of worship}
4125 CJK UNIFIED IDEOGRAPH-#4125, IRGKangXi=0847.401, Def{a god; a spirit; an immortal}
4126 CJK UNIFIED IDEOGRAPH-#4126, IRGKangXi=0849.070, Def{to put forth ears and to blossom of the grains (corns and cereals)}
4127 CJK UNIFIED IDEOGRAPH-#4127, IRGKangXi=0849.080, Def{a kind of grain}
4128 CJK UNIFIED IDEOGRAPH-#4128, IRGKangXi=0849.130, Def{grains producing neither flower nor fruit}
4129 CJK UNIFIED IDEOGRAPH-#4129, IRGKangXi=0849.170, Def{(same as 䴬) bran; chaff, grains; corns; cereals}
412A CJK UNIFIED IDEOGRAPH-#412A, IRGKangXi=0849.180, Def{hanging down of the ears of the grains, something to hang or be hanged or hung}
412B CJK UNIFIED IDEOGRAPH-#412B, IRGKangXi=0850.031, Def{(same as 芑) a kind of sorghum with white sprouts, a kind of wild vegetable; bitter herbs}
412C CJK UNIFIED IDEOGRAPH-#412C, IRGKangXi=0850.030, Def{(same as 移) to change; to shift; to move; to influence, to coney; to forward}
412D CJK UNIFIED IDEOGRAPH-#412D, IRGKangXi=0850.031, Def{(same as 年) a year, one's age}
412E CJK UNIFIED IDEOGRAPH-#412E, IRGKangXi=0850.050, Def{dark rice plant, millet grain (in black color), (same as 稃) bran}
412F CJK UNIFIED IDEOGRAPH-#412F, IRGKangXi=0850.140, Def{ten handle of grains (rice plant)}
4130 CJK UNIFIED IDEOGRAPH-#4130, IRGKangXi=0850.250, Def{forty bundles of rice plant, panicled millet, (same as 芽) sprout; shoot; bud}
4131 CJK UNIFIED IDEOGRAPH-#4131, IRGKangXi=0850.260, Def{a kind of grain}
4132 CJK UNIFIED IDEOGRAPH-#4132, IRGKangXi=0851.020, Def{inside; within; inner; interior; domestic, heartlessness}
4133 CJK UNIFIED IDEOGRAPH-#4133, IRGKangXi=0851.091
4134 CJK UNIFIED IDEOGRAPH-#4134, IRGKangXi=0851.091
4135 CJK UNIFIED IDEOGRAPH-#4135, IRGKangXi=0850.031
4136 CJK UNIFIED IDEOGRAPH-#4136, IRGKangXi=0851.190, Def{rice plant growing the second time, the ear of grain (corn, millet etc.) growing upward}
4137 CJK UNIFIED IDEOGRAPH-#4137, IRGKangXi=0852.010, Def{(same as 石) a measurement (in ancient times) equal to 120 catty (Chinese pound)}
4138 CJK UNIFIED IDEOGRAPH-#4138, IRGKangXi=0852.060, Def{grains producing no fruit}
4139 CJK UNIFIED IDEOGRAPH-#4139, IRGKangXi=0852.101, Def{(same as 年) a year, age, harvest}
413A CJK UNIFIED IDEOGRAPH-#413A, IRGKangXi=0852.130, Def{(same as U+7A3A 稚) young and tender; small; delicate; immature, (same as U+7A0A 稊) darnels; tares, grass}
413B CJK UNIFIED IDEOGRAPH-#413B, IRGKangXi=0852.140, Def{a second time growing of rice plant, rice plant, (dialect) sorghum; kaoliang}
413C CJK UNIFIED IDEOGRAPH-#413C, IRGKangXi=0852.170, Def{name of a place in ancient times}
413D CJK UNIFIED IDEOGRAPH-#413D, IRGKangXi=0852.180, Def{(same as U+79C8 秈, U+7C7C 籼) common rice, as distinguished from glutinous rice; (corrupted form of U+413C 䄼) name of a place in ancient times}
413E CJK UNIFIED IDEOGRAPH-#413E, IRGKangXi=0852.210, Def{thick; height, black millet}
413F CJK UNIFIED IDEOGRAPH-#413F, IRGKangXi=0852.270, Def{a kind of rice plant}
4140 CJK UNIFIED IDEOGRAPH-#4140, IRGKangXi=0852.290, Def{the stalk (stem) of grain, neat and orderly rows of rice seedling}
4141 CJK UNIFIED IDEOGRAPH-#4141, IRGKangXi=0852.310, Def{to husk rice; to get the grains by oppressing the ears of the rice plant}
4142 CJK UNIFIED IDEOGRAPH-#4142, IRGKangXi=0852.320, Def{a kind of grain (looks like millet but much smaller)}
4143 CJK UNIFIED IDEOGRAPH-#4143, IRGKangXi=0852.340, Def{late crop, to reap or harvest; to cut grain}
4144 CJK UNIFIED IDEOGRAPH-#4144, IRGKangXi=0853.010, Def{long grains}
4145 CJK UNIFIED IDEOGRAPH-#4145, IRGKangXi=0853.030, Def{farm tool; agricultural implements, to till; to plough; to cultivate}
4146 CJK UNIFIED IDEOGRAPH-#4146, IRGKangXi=0853.060, Def{dense; crowded; closely, a piece of wood used to strike off grain in a measure thus - to level; all; to adjust; overall}
4147 CJK UNIFIED IDEOGRAPH-#4147, IRGKangXi=0853.080, Def{(ancient form of 粟) grains, millet, Indian corn}
4148 CJK UNIFIED IDEOGRAPH-#4148, IRGKangXi=0853.081
4149 CJK UNIFIED IDEOGRAPH-#4149, IRGKangXi=0853.081, Def{a kind of rice plant, shaking and waving of the rice plant}
414A CJK UNIFIED IDEOGRAPH-#414A, IRGKangXi=0853.081, Def{a spacious house, (corrupted form of 秺) bundle of rice plant, name of a place}
414B CJK UNIFIED IDEOGRAPH-#414B, IRGKangXi=0853.140, Def{a kind of grain; sweet and round rice}
414C CJK UNIFIED IDEOGRAPH-#414C, IRGKangXi=0853.170, Def{stalk (stem) of wheat or rice plant}
414D CJK UNIFIED IDEOGRAPH-#414D, IRGKangXi=0853.180, Def{straight upward of the wheat and rice plant}
414E CJK UNIFIED IDEOGRAPH-#414E, IRGKangXi=0853.190, Def{different; to distinguish}
414F CJK UNIFIED IDEOGRAPH-#414F, IRGKangXi=0854.010, Def{rice boiled to gruel, congee; porridge}
4150 CJK UNIFIED IDEOGRAPH-#4150, IRGKangXi=0854.050, Def{a bundle, to bind; bondage, a small bundle of, term of measurement; 10 bundle of rice plants}
4151 CJK UNIFIED IDEOGRAPH-#4151, IRGKangXi=0854.060, Def{four bundle of grains}
4152 CJK UNIFIED IDEOGRAPH-#4152, IRGKangXi=0854.160, Def{(interchangeable 芒) a sharp-edged grass, the awn or beard of wheat, etc.}
4153 CJK UNIFIED IDEOGRAPH-#4153, IRGKangXi=0854.190, Def{curved piece of wood, to bend; to crouch, name of a tree, name of a fruit}
4154 CJK UNIFIED IDEOGRAPH-#4154, IRGKangXi=0854.240, Def{dead (withered) crops; dried grains; (same as U+43A9 䎩) to till; to plough; to cultivate}
4155 CJK UNIFIED IDEOGRAPH-#4155, IRGKangXi=0854.280, Def{a variety of millet}
4156 CJK UNIFIED IDEOGRAPH-#4156, IRGKangXi=0854.310, Def{(same as 馣) sweet-smelling, tasty; delicious, to farm; to cultivate the land, luxuriant or exuberant of growing rice, grains;; rice plants producing no fruit, to fertilize, the grains not growing; shriveled rice plants}
4157 CJK UNIFIED IDEOGRAPH-#4157, IRGKangXi=0854.320, Def{(same as 䅑) four bundle of grains, to accumulate; to store up grains, grains; rice plant}
4158 CJK UNIFIED IDEOGRAPH-#4158, IRGKangXi=0854.370, Def{wheat}
4159 CJK UNIFIED IDEOGRAPH-#4159, IRGKangXi=0854.380, Def{grass; herb; straw; weed, bundle of straw}
415A CJK UNIFIED IDEOGRAPH-#415A, IRGKangXi=0854.390, Def{closely growing of the rice plants}
415B CJK UNIFIED IDEOGRAPH-#415B, IRGKangXi=0855.060, Def{husks of rice; rice bran or chaff}
415C CJK UNIFIED IDEOGRAPH-#415C, IRGKangXi=0855.110, Def{to store up grains, weeping rice plants, an ear of grain}
415D CJK UNIFIED IDEOGRAPH-#415D, IRGKangXi=0855.130, Def{the stalk of grain; straw}
415E CJK UNIFIED IDEOGRAPH-#415E, IRGKangXi=0855.260, Def{stalks of grain (rice plant)}
415F CJK UNIFIED IDEOGRAPH-#415F, IRGKangXi=0855.311, Def{(simplified form of 穇) varieties of millet; panicled millet, ear of grain producing no fruit, short grains}
4160 CJK UNIFIED IDEOGRAPH-#4160, IRGKangXi=0855.340, Def{(same as 蕛) a kind of grass, (interchangeable 稊) darnels, tender shoot of thatch (straw; couch grass)}
4161 CJK UNIFIED IDEOGRAPH-#4161, IRGKangXi=0855.360, Def{a kind of grass, grass growing in between of (among) the grains}
4162 CJK UNIFIED IDEOGRAPH-#4162, IRGKangXi=0855.400, Def{mature or ripen of the grains (rice; corns; cereals)}
4163 CJK UNIFIED IDEOGRAPH-#4163, IRGKangXi=0856.040, Def{a variety of panicled millet, a small coarse grain resembling sorghum}
4164 CJK UNIFIED IDEOGRAPH-#4164, IRGKangXi=0856.070, Def{to plant; to sow; to cultivate}
4165 CJK UNIFIED IDEOGRAPH-#4165, IRGKangXi=0856.140, Def{ripening crops, long grains, husks; chaff; bran (of grain)}
4166 CJK UNIFIED IDEOGRAPH-#4166, IRGKangXi=0856.150, Def{feeble; weak of the rice plant}
4167 CJK UNIFIED IDEOGRAPH-#4167, IRGKangXi=0856.200, Def{fine rice seedling; growing rice in order, (same as 蔭) shade of trees; shade}
4168 CJK UNIFIED IDEOGRAPH-#4168, IRGKangXi=0856.260, Def{(same as 香) fragrant; sweet-smelling}
4169 CJK UNIFIED IDEOGRAPH-#4169, IRGKangXi=0856.300, Def{crooked and winding (of grass, trees, vegetation, flora); crooked branches of a tree adjoin each other; (same as 歧) forked; divergent, anything that goes astray; wayward}
416A CJK UNIFIED IDEOGRAPH-#416A, IRGKangXi=0856.321, Def{(a simplified form) disease of the private part, hernia, colic}
416B CJK UNIFIED IDEOGRAPH-#416B, IRGKangXi=0856.321
416C CJK UNIFIED IDEOGRAPH-#416C, IRGKangXi=0857.010, Def{small bundle of rice plant, seed, grain}
416D CJK UNIFIED IDEOGRAPH-#416D, IRGKangXi=0857.030, Def{a variety of panicled millet, a small coarse grain resembling sorghum}
416E CJK UNIFIED IDEOGRAPH-#416E, IRGKangXi=0857.050, Def{a full head of grain; bent over by its own weight, two small pieces bract on the base of the ears of a rice plant, grass; weeds; tares}
416F CJK UNIFIED IDEOGRAPH-#416F, IRGKangXi=0857.080, Def{a variety of millet}
4170 CJK UNIFIED IDEOGRAPH-#4170, IRGKangXi=0857.100, Def{a kind of grass}
4171 CJK UNIFIED IDEOGRAPH-#4171, IRGKangXi=0857.110, Def{to eat to the full; surfeited}
4172 CJK UNIFIED IDEOGRAPH-#4172, IRGKangXi=0857.120, Def{to plant; to sow wheat}
4173 CJK UNIFIED IDEOGRAPH-#4173, IRGKangXi=0857.180, Def{stalk of the panicled millet; stalk of the rice plant}
4174 CJK UNIFIED IDEOGRAPH-#4174, IRGKangXi=0857.240, Def{grains, rice plant, an ear of grain}
4175 CJK UNIFIED IDEOGRAPH-#4175, IRGKangXi=0857.270, Def{chaff; bran; husks of grain, name of a place in ancient times}
4176 CJK UNIFIED IDEOGRAPH-#4176, IRGKangXi=0858.100, Def{to hoe, to weed; to hoe up weeds}
4177 CJK UNIFIED IDEOGRAPH-#4177, IRGKangXi=0858.150, Def{an ear of grain, (non-classical form of 稌) ancient term for glutinous rice, (same as 藷) a term for plants with tubers}
4178 CJK UNIFIED IDEOGRAPH-#4178, IRGKangXi=0858.180, Def{a grain, (same as 莘) lush growth; dense growth of the grass (trees, etc.) a marshy plant, known as asarum, a name derived from the bitterness of the root which is used in medicine}
4179 CJK UNIFIED IDEOGRAPH-#4179, IRGKangXi=0859.170, Def{(same as 耬) a kind of drill for sowing grain, to till lands}
417A CJK UNIFIED IDEOGRAPH-#417A, IRGKangXi=0859.220, Def{grain in the ear; to put forth ears, (same as 秒) the beard of grain, (same as 蔈) a measuring unit of weight used in ancient times, a plant (resembling reed) much used for making brooms}
417B CJK UNIFIED IDEOGRAPH-#417B, IRGKangXi=0859.230, Def{measurement; two bundle of grains (same as 離) bend of the ears of the variety of millet (because of the weight of the ears)}
417C CJK UNIFIED IDEOGRAPH-#417C, IRGKangXi=0859.260, Def{a kind of grains, to plant; to sow; to cultivate}
417D CJK UNIFIED IDEOGRAPH-#417D, IRGKangXi=0860.041, Def{(same as 馨) fragrance or aroma (especially that which comes from after), (same as 榖) grains and corns; cereals}
417E CJK UNIFIED IDEOGRAPH-#417E, IRGKangXi=0860.120, Def{starting to put forth ears, a kind of grain}
417F CJK UNIFIED IDEOGRAPH-#417F, IRGKangXi=0860.130, Def{(non-classical form) luxuriant or exuberant (of grain) (interchangeable 華) flowery; variegated, splendour}
4180 CJK UNIFIED IDEOGRAPH-#4180, IRGKangXi=0860.180, Def{(same as U+9EE3 霉 黴) to corrupt or be corrupted; to ruin or be ruined, dark sports; black specks, black}
4181 CJK UNIFIED IDEOGRAPH-#4181, IRGKangXi=0860.350, Def{syrup; jelly-like sugar made from grains}
4182 CJK UNIFIED IDEOGRAPH-#4182, IRGKangXi=0860.430, Def{a kind of grain, (same as 稴) trees producing no fruit}
4183 CJK UNIFIED IDEOGRAPH-#4183, IRGKangXi=0860.440, Def{a kind of rice plant; Excellent crop, to choose or to select hulled rice, millet; grains}
4184 CJK UNIFIED IDEOGRAPH-#4184, IRGKangXi=0860.450, Def{a bundle, a bundle of rice plant}
4185 CJK UNIFIED IDEOGRAPH-#4185, IRGKangXi=0860.460, Def{to accumulate or to store up rice, to purchase grain with public funds and store it against famine}
4186 CJK UNIFIED IDEOGRAPH-#4186, IRGKangXi=0861.051
4187 CJK UNIFIED IDEOGRAPH-#4187, IRGKangXi=0861.051
4188 CJK UNIFIED IDEOGRAPH-#4188, IRGKangXi=0861.270, Def{(non-classical form of U+7A3A 稚) young and tender; small; delicate; immature}
4189 CJK UNIFIED IDEOGRAPH-#4189, IRGKangXi=0861.340, Def{the swing of rice plant, a kind of paddy}
418A CJK UNIFIED IDEOGRAPH-#418A, IRGKangXi=0861.420, Def{unhusked glutinous rice, to sow seeds}
418B CJK UNIFIED IDEOGRAPH-#418B, IRGKangXi=0861.441, Def{(ancient form of U+79CB 秋) the autumn, the fall of the year, a season, a time}
418C CJK UNIFIED IDEOGRAPH-#418C, IRGKangXi=0861.441
418D CJK UNIFIED IDEOGRAPH-#418D, IRGKangXi=0861.450, Def{cut crops (not yet collected and tied up)}
418E CJK UNIFIED IDEOGRAPH-#418E, IRGKangXi=0862.020, Def{grass and grains producing no fruit}
418F CJK UNIFIED IDEOGRAPH-#418F, IRGKangXi=0862.060, Def{a kind of rice plant (not glutinous and with purple colored stalk), (same as 糞) to apply fertilizers}
4190 CJK UNIFIED IDEOGRAPH-#4190, IRGKangXi=0862.190, Def{(ancient form of 國) a country; a nation; a kingdom; a state}
4191 CJK UNIFIED IDEOGRAPH-#4191, IRGKangXi=0862.230, Def{a little protruded}
4192 CJK UNIFIED IDEOGRAPH-#4192, IRGKangXi=0863.101, Def{(corrupted form of 究) to examine; to study; to investigate exhaustively}
4193 CJK UNIFIED IDEOGRAPH-#4193, IRGKangXi=0863.120, Def{a hole; a cave; a pit, to dig the ground and build underground living quarters, to make smooth of the leather}
4194 CJK UNIFIED IDEOGRAPH-#4194, IRGKangXi=0863.130, Def{to pierce through; to penetrate or bore through; to thread, to cross; (Cant.) hole, hollow, cavity}
4195 CJK UNIFIED IDEOGRAPH-#4195, IRGKangXi=0863.160, Def{to pierce through; to penetrate through; to cross, extremely; to the extreme, a hole; an opening; an aperture, with no door or window}
4196 CJK UNIFIED IDEOGRAPH-#4196, IRGKangXi=0863.190, Def{a big house, (same as 宏) great; vast; wide; ample}
4197 CJK UNIFIED IDEOGRAPH-#4197, IRGKangXi=0864.130, Def{deep and dark; profound, (same as 窈) tranquil; placid; serene, soft and pleasing; plausible; exquisite; very pleasant}
4198 CJK UNIFIED IDEOGRAPH-#4198, IRGKangXi=0864.190, Def{acupuncture, narrow and protrude, (non-classical form of 拶) a torture device in old China consisting of several contracting wooden sticks, in between which the fingers of a suspect are placed and pressed to extort confessions}
4199 CJK UNIFIED IDEOGRAPH-#4199, IRGKangXi=0864.380, Def{(a non-classical form) (same as standard form of 7AB0 窯) a kiln; a brick furnace; a pottery, a coal shaft, a cave -- for human dwelling}
419A CJK UNIFIED IDEOGRAPH-#419A, IRGKangXi=0864.390, Def{to go through; to penetrate; passed through, (same as 洞) a cave; a hole}
419B CJK UNIFIED IDEOGRAPH-#419B, IRGKangXi=0865.020, Def{something in the cave}
419C CJK UNIFIED IDEOGRAPH-#419C, IRGKangXi=0865.040, Def{empty; hollow, unreal, high and vast, the space}
419D CJK UNIFIED IDEOGRAPH-#419D, IRGKangXi=0865.050, Def{a cave; a hole, to bore through or drill a cave as a dwelling}
419E CJK UNIFIED IDEOGRAPH-#419E, IRGKangXi=0865.060, Def{deep and dark; profound, far; vast, obscure, mysterious}
419F CJK UNIFIED IDEOGRAPH-#419F, IRGKangXi=0865.100, Def{corresponding; equivalent, considerable, appropriate, (same as 凹) indented; a hollow, concave}
41A0 CJK UNIFIED IDEOGRAPH-#41A0, IRGKangXi=0865.170, Def{(non-classical form of 宦) a government official; the government service, castrated}
41A1 CJK UNIFIED IDEOGRAPH-#41A1, IRGKangXi=0865.260, Def{a cave; a hole}
41A2 CJK UNIFIED IDEOGRAPH-#41A2, IRGKangXi=0865.280, Def{to penetrate; to pierce through, a hole; an aperture; an opening, a cave}
41A3 CJK UNIFIED IDEOGRAPH-#41A3, IRGKangXi=0866.170, Def{(same as 宸) abode of the emperor, a large mansion}
41A4 CJK UNIFIED IDEOGRAPH-#41A4, IRGKangXi=0866.220, Def{(same as 穿) to pierce through; to penetrate or bore through; to wear, to cross}
41A5 CJK UNIFIED IDEOGRAPH-#41A5, IRGKangXi=0866.230, Def{(same as 䆤) (non-classical form of 穿) to pierce through; to penetrate or bore through; to wear, to cross}
41A6 CJK UNIFIED IDEOGRAPH-#41A6, IRGKangXi=0866.340, Def{(a corrupted form) (same as 深) deep; profound, the chimney; stack (on the top of a cooking stove or furnace), to bury the coffin of a dead person}
41A7 CJK UNIFIED IDEOGRAPH-#41A7, IRGKangXi=0866.360, Def{(same as 窩) a cave; a den, living quarters; a house, to hide; to harbor}
41A8 CJK UNIFIED IDEOGRAPH-#41A8, IRGKangXi=0866.490, Def{(same as 冥) the sky; the heaven; the void, Nature; God, big; large; great, light; bright}
41A9 CJK UNIFIED IDEOGRAPH-#41A9, IRGKangXi=0866.500, Def{(same as 冥) dark; obscure; dim, far and high, deep; profound, the unseen world}
41AA CJK UNIFIED IDEOGRAPH-#41AA, IRGKangXi=0866.560, Def{color of the light; brilliance or gleaming}
41AB CJK UNIFIED IDEOGRAPH-#41AB, IRGKangXi=0866.570, Def{(same as U+7A97 窗) window}
41AC CJK UNIFIED IDEOGRAPH-#41AC, IRGKangXi=0867.260, Def{(a non-classical form) (same as standard form 霣) (interchangeable 隕) to fall down}
41AD CJK UNIFIED IDEOGRAPH-#41AD, IRGKangXi=0867.280, Def{cave; inside of a cave}
41AE CJK UNIFIED IDEOGRAPH-#41AE, IRGKangXi=0867.351, Def{(same as ancient form of 浸) to dip; to immerse; to soak, gradual; gradually, name of a place in today's Henan Province}
41AF CJK UNIFIED IDEOGRAPH-#41AF, IRGKangXi=0867.390, Def{a short shaped face, charming; beautiful; delicate}
41B0 CJK UNIFIED IDEOGRAPH-#41B0, IRGKangXi=0867.400, Def{a cave; a tunnel; a grotto, name of a mountain}
41B1 CJK UNIFIED IDEOGRAPH-#41B1, IRGKangXi=0867.450, Def{big; large; thin; light, rugged; uneven, a deep cave}
41B2 CJK UNIFIED IDEOGRAPH-#41B2, IRGKangXi=0868.110, Def{a spacious house, emptiness; (Cant.) an intensifier}
41B3 CJK UNIFIED IDEOGRAPH-#41B3, IRGKangXi=0868.120, Def{(same as non-classical form 邃) far distant; remote, the extreme; the farthest}
41B4 CJK UNIFIED IDEOGRAPH-#41B4, IRGKangXi=0868.211, Def{(abbreviated form)}
41B5 CJK UNIFIED IDEOGRAPH-#41B5, IRGKangXi=0868.240, Def{an echo, a high and deep; large; big; specious house}
41B6 CJK UNIFIED IDEOGRAPH-#41B6, IRGKangXi=0868.260, Def{noise of a mouse in the cave}
41B7 CJK UNIFIED IDEOGRAPH-#41B7, IRGKangXi=0868.280, Def{a hole; an opening; a aperture; deep; far and profound}
41B8 CJK UNIFIED IDEOGRAPH-#41B8, IRGKangXi=0868.290, Def{spacious; capacious, sound (of the house), a picture (on silk) scroll}
41B9 CJK UNIFIED IDEOGRAPH-#41B9, IRGKangXi=0868.310, Def{empty; hollow, dark; obscure}
41BA CJK UNIFIED IDEOGRAPH-#41BA, IRGKangXi=0868.370, Def{whirling of the flowing water, (interchangeable 潘) water in which rice has been washed}
41BB CJK UNIFIED IDEOGRAPH-#41BB, IRGKangXi=0868.390, Def{(corrupted form of 竅) a hole; a cavity; (the mind's pores, the crux; key points}
41BC CJK UNIFIED IDEOGRAPH-#41BC, IRGKangXi=0868.450, Def{(non-classical form of standard form 窠) a nest; hole; a den; burrow, a dwelling for people}
41BD CJK UNIFIED IDEOGRAPH-#41BD, IRGKangXi=0869.040, Def{a hole; an opening, a cave, empty; hollow}
41BE CJK UNIFIED IDEOGRAPH-#41BE, IRGKangXi=0869.080, Def{big; large; thin; light, rugged; uneven, a deep cave}
41BF CJK UNIFIED IDEOGRAPH-#41BF, IRGKangXi=0869.100, Def{(same as 寱) (standard form of 囈) to talk in sleep; somniloquy}
41C0 CJK UNIFIED IDEOGRAPH-#41C0, IRGKangXi=0869.200, Def{(non-classical form) ornaments of fine feather or fur (for decoration)}
41C1 CJK UNIFIED IDEOGRAPH-#41C1, IRGKangXi=0870.100, Def{a cave; a hole}
41C2 CJK UNIFIED IDEOGRAPH-#41C2, IRGKangXi=0870.180, Def{(ancient form) fault; sin}
41C3 CJK UNIFIED IDEOGRAPH-#41C3, IRGKangXi=0870.210, Def{(same as 竢) (ancient form of 俟) to wait for, until; when; as soon as}
41C4 CJK UNIFIED IDEOGRAPH-#41C4, IRGKangXi=0870.231
41C5 CJK UNIFIED IDEOGRAPH-#41C5, IRGKangXi=0870.240, Def{to stand still}
41C6 CJK UNIFIED IDEOGRAPH-#41C6, IRGKangXi=0870.271, Def{(abbreviated form) capacity unit in France (Decalitre) equal to ten times of one litre}
41C7 CJK UNIFIED IDEOGRAPH-#41C7, IRGKangXi=0870.320, Def{(corrupted form of 氓) the people; the populace, rascal; vagabond}
41C8 CJK UNIFIED IDEOGRAPH-#41C8, IRGKangXi=0870.350, Def{to put into a cupboard or closet; to put into the proper place; to put away, to put away for safekeeping, to collect and keep}
41C9 CJK UNIFIED IDEOGRAPH-#41C9, IRGKangXi=0871.031, Def{capacity unit in France (Hectolit) equal to one hundred times of one litre}
41CA CJK UNIFIED IDEOGRAPH-#41CA, IRGKangXi=0871.031
41CB CJK UNIFIED IDEOGRAPH-#41CB, IRGKangXi=0871.060, Def{name of a god}
41CC CJK UNIFIED IDEOGRAPH-#41CC, IRGKangXi=0871.170, Def{to stand, to erect; to create; to start}
41CD CJK UNIFIED IDEOGRAPH-#41CD, IRGKangXi=0872.050, Def{to wait, (same as 齪) tidy, prudent; careful; attentive, a person's name}
41CE CJK UNIFIED IDEOGRAPH-#41CE, IRGKangXi=0872.100, Def{to startle; to amaze; to surprise, afraid; scared; fearful, respectful; reverent}
41CF CJK UNIFIED IDEOGRAPH-#41CF, IRGKangXi=0872.160, Def{to pile one upon another, trees fruits well and the branches hanging down}
41D0 CJK UNIFIED IDEOGRAPH-#41D0, IRGKangXi=0872.190, Def{(same as 搯 蒞) to arrive, from; by; through, to manage; to undertake, to follow, thin; few, distant, idle}
41D1 CJK UNIFIED IDEOGRAPH-#41D1, IRGKangXi=0872.210, Def{a standing short person, unstable in walking}
41D2 CJK UNIFIED IDEOGRAPH-#41D2, IRGKangXi=0873.050, Def{(ancient form of 屆) numerary adjunct for periodic terms or events, to arrive, to expire}
41D3 CJK UNIFIED IDEOGRAPH-#41D3, IRGKangXi=0873.120, Def{to wait for; to wait (same as 須) to stop at, to have to, a moment; a while, (interchangeable 需) to need; demand}
41D4 CJK UNIFIED IDEOGRAPH-#41D4, IRGKangXi=0873.150, Def{atrophy, paralysis; impotent, stand}
41D5 CJK UNIFIED IDEOGRAPH-#41D5, IRGKangXi=0873.210, Def{(same as 䇓) to wait for; to wait}
41D6 CJK UNIFIED IDEOGRAPH-#41D6, IRGKangXi=0878.040, Def{rope made of bamboo strips}
41D7 CJK UNIFIED IDEOGRAPH-#41D7, IRGKangXi=0878.140, Def{bamboo with long joints}
41D8 CJK UNIFIED IDEOGRAPH-#41D8, IRGKangXi=0878.150, Def{tool to collect rope; a spinning machine, spinning wheel; the tender shoots of the bamboo with a bitter flavour}
41D9 CJK UNIFIED IDEOGRAPH-#41D9, IRGKangXi=0878.230, Def{name of a variety of bamboo}
41DA CJK UNIFIED IDEOGRAPH-#41DA, IRGKangXi=0879.110, Def{(same as U+6534 攴) to tap; to rap, (same as U+64B2 撲) to pat; to beat; to strike; to dash; to smash}
41DB CJK UNIFIED IDEOGRAPH-#41DB, IRGKangXi=0879.120, Def{name of a variety of bamboo}
41DC CJK UNIFIED IDEOGRAPH-#41DC, IRGKangXi=0879.140, Def{small bamboo, a kind of bamboo}
41DD CJK UNIFIED IDEOGRAPH-#41DD, IRGKangXi=0879.191, Def{(abbreviated form) (same as 㦰) to break off (relations); to sever, to exterminate; to annihilate; to wipe out, to pierce; to stab; to irritate; to hurt, to hold weapons, agricultural implements; far tools, sharp will; eager intention; determination}
41DE CJK UNIFIED IDEOGRAPH-#41DE, IRGKangXi=0879.220, Def{name of a variety of bamboo; sweet bamboo, large bamboo}
41DF CJK UNIFIED IDEOGRAPH-#41DF, IRGKangXi=0879.250, Def{(same as 腱) tendon}
41E0 CJK UNIFIED IDEOGRAPH-#41E0, IRGKangXi=0879.280, Def{wrench to adjust the string on stringed instrument}
41E1 CJK UNIFIED IDEOGRAPH-#41E1, IRGKangXi=0880.080, Def{(same as 杼) the shuttle of a loom}
41E2 CJK UNIFIED IDEOGRAPH-#41E2, IRGKangXi=0880.130, Def{(standard form 苦) bamboo, bitter bamboo, usually used as the material for making an umbrella's handle, (same as 罟) net}
41E3 CJK UNIFIED IDEOGRAPH-#41E3, IRGKangXi=0880.160, Def{bamboo with white bark, (same as 籋) tongs; pincers; tweezers, weary; tired; fatigued, small box}
41E4 CJK UNIFIED IDEOGRAPH-#41E4, IRGKangXi=0881.180, Def{sharp; acute, clever, vigorous}
41E5 CJK UNIFIED IDEOGRAPH-#41E5, IRGKangXi=0881.210, Def{(same as 笮) narrow, boards laid across rafters, an arrow bag, a kind of liquor container, to squeeze; to press, (same as 筰) rope made from bamboo-splints, (interchangeable 鑿) to bore or pierce through}
41E6 CJK UNIFIED IDEOGRAPH-#41E6, IRGKangXi=0881.220, Def{a kind of bamboo, colorless bamboo, bamboo shoot}
41E7 CJK UNIFIED IDEOGRAPH-#41E7, IRGKangXi=0882.020, Def{to fill an opening with bamboo, (ancient form of 箕) a winnowing basket; a sieve, a dust basket; dustpan}
41E8 CJK UNIFIED IDEOGRAPH-#41E8, IRGKangXi=0882.030, Def{a bamboo basket for food containers (such as cup; plate; dish and bowl, etc.) used in ancient times, a basket for chopsticks, bamboo basket used to filter or to strain out the wine, a sail made of a thin and long strip of bamboo}
41E9 CJK UNIFIED IDEOGRAPH-#41E9, IRGKangXi=0882.060, Def{long, a big raft, a kind of equipment made of bamboo used to catch fishes}
41EA CJK UNIFIED IDEOGRAPH-#41EA, IRGKangXi=0882.070, Def{name of a variety of bamboo}
41EB CJK UNIFIED IDEOGRAPH-#41EB, IRGKangXi=0882.100, Def{bamboo-splints; laths, to plait, (same as 篦) a comb; especially a fine-toothed one)}
41EC CJK UNIFIED IDEOGRAPH-#41EC, IRGKangXi=0882.130, Def{thin bamboo laths knitted sail, a thin and long strip of bamboo; books in ancient style, to set sail; to depart}
41ED CJK UNIFIED IDEOGRAPH-#41ED, IRGKangXi=0882.170, Def{containers made of thin and long strip of bamboo or willow branches}
41EE CJK UNIFIED IDEOGRAPH-#41EE, IRGKangXi=0882.210, Def{a bamboo mat used in ancient times, (interchangeable with U+88B5 衽) a sleeping mat}
41EF CJK UNIFIED IDEOGRAPH-#41EF, IRGKangXi=0884.020, Def{a kind of bamboo with patterns on the head}
41F0 CJK UNIFIED IDEOGRAPH-#41F0, IRGKangXi=0884.050, Def{a bamboo binded torch, a kind of bamboo with patterns on the bark}
41F1 CJK UNIFIED IDEOGRAPH-#41F1, IRGKangXi=0884.110, Def{(same as 笝) a hawser; a cable; a bamboo rope used to tie on a boat, to mend a bamboo fence}
41F2 CJK UNIFIED IDEOGRAPH-#41F2, IRGKangXi=0884.150, Def{(simplified form of 筴) tongs; tweezers; pincers, to use pressure upon; to force, a kind of grass used for divination in ancient times, (same as 策) a whip, a plan}
41F3 CJK UNIFIED IDEOGRAPH-#41F3, IRGKangXi=0884.181, Def{(abbreviated form of 箋) a memoradum tablet, slip of paper, fancy notepaper, a note, a document}
41F4 CJK UNIFIED IDEOGRAPH-#41F4, IRGKangXi=0884.181
41F5 CJK UNIFIED IDEOGRAPH-#41F5, IRGKangXi=0884.190, Def{one of the wind instruments; a bamboo flute with seven holes}
41F6 CJK UNIFIED IDEOGRAPH-#41F6, IRGKangXi=0884.280, Def{a small rafters made of bamboo which project form the eaves and support the tiles, a kind of bamboo}
41F7 CJK UNIFIED IDEOGRAPH-#41F7, IRGKangXi=0884.290, Def{in ancient times; to separated (to rip of; to cut open) the contract or agreement on slips of bamboo and give to both parties as evidence}
41F8 CJK UNIFIED IDEOGRAPH-#41F8, IRGKangXi=0884.330, Def{a bamboo mat, a kind of bamboo, bamboo ware, a seat cushion in a carriage}
41F9 CJK UNIFIED IDEOGRAPH-#41F9, IRGKangXi=0885.060, Def{(same as 箘) a kind of bamboo}
41FA CJK UNIFIED IDEOGRAPH-#41FA, IRGKangXi=0885.070, Def{(same as 豆) beans and peas collectively, a vessel like a platter, made of wood, bronze, or porcelain, used for holding food in sacrifices, etc.}
41FB CJK UNIFIED IDEOGRAPH-#41FB, IRGKangXi=0885.080, Def{a kind of bamboo, broom; a besom}
41FC CJK UNIFIED IDEOGRAPH-#41FC, IRGKangXi=0885.090, Def{a bamboo vessel used to catch fishes}
41FD CJK UNIFIED IDEOGRAPH-#41FD, IRGKangXi=0885.130, Def{a coarse bamboo mat}
41FE CJK UNIFIED IDEOGRAPH-#41FE, IRGKangXi=0886.010, Def{a flute with 23 tubes; 4 inches long (of bamboo, etc.); a pipe; a wind instrument, (interchangeable 言) speech; words, to say, a dialect; language}
41FF CJK UNIFIED IDEOGRAPH-#41FF, IRGKangXi=0886.231
4200 CJK UNIFIED IDEOGRAPH-#4200, IRGKangXi=0885.020, Def{bamboo ware (used to hold food or clothes)}
4201 CJK UNIFIED IDEOGRAPH-#4201, IRGKangXi=0886.260, Def{tools used on a boat}
4202 CJK UNIFIED IDEOGRAPH-#4202, IRGKangXi=0886.290, Def{a kind of bamboo}
4203 CJK UNIFIED IDEOGRAPH-#4203, IRGKangXi=0886.370, Def{a kind of bamboo, hem; margin; edge of bamboo}
4204 CJK UNIFIED IDEOGRAPH-#4204, IRGKangXi=0887.010, Def{(same as 筨) a kind of solid bamboo}
4205 CJK UNIFIED IDEOGRAPH-#4205, IRGKangXi=0887.050, Def{(same as 籆) tools to unreel silk}
4206 CJK UNIFIED IDEOGRAPH-#4206, IRGKangXi=0887.070, Def{a shallow and long shaped bamboo basket}
4207 CJK UNIFIED IDEOGRAPH-#4207, IRGKangXi=0887.100, Def{(same as U+7F69 罩) a cover, a shade, a basket used to catch fish}
4208 CJK UNIFIED IDEOGRAPH-#4208, IRGKangXi=0887.130, Def{a kind of bamboo, exuberant and flourishing of bamboo, (same as 笆) a barrier made of bamboo or willow branch; bamboo fence, a mat}
4209 CJK UNIFIED IDEOGRAPH-#4209, IRGKangXi=0887.190, Def{(same as 箑) a fan, (same as 翣) feathers adorning a coffin, bamboo ware}
420A CJK UNIFIED IDEOGRAPH-#420A, IRGKangXi=0889.050, Def{name of a variety of bamboo; (Cant.) 䈊仔, a useless fellow}
420B CJK UNIFIED IDEOGRAPH-#420B, IRGKangXi=0889.120, Def{name of a variety of bamboo, a cover made of bamboo}
420C CJK UNIFIED IDEOGRAPH-#420C, IRGKangXi=0889.150, Def{name of a variety of bamboo, submerged; fertilized by water}
420D CJK UNIFIED IDEOGRAPH-#420D, IRGKangXi=0889.200, Def{name of a variety of bamboo}
420E CJK UNIFIED IDEOGRAPH-#420E, IRGKangXi=0890.020, Def{(same as 葉) a leaf; the page of a book, a leaf of a door, a lobe of the lungs or liver}
420F CJK UNIFIED IDEOGRAPH-#420F, IRGKangXi=0890.070, Def{name of a variety of bamboo, a woven tool}
4210 CJK UNIFIED IDEOGRAPH-#4210, IRGKangXi=0890.100, Def{an arched frame made of bamboo of wood board, a covering, mats woven from bamboo and other leaves top on vehicles, (same as 簂 槶) a bamboo chest; a wicker chest, a woman's headdress}
4211 CJK UNIFIED IDEOGRAPH-#4211, IRGKangXi=0890.140, Def{tools to unreel silk}
4212 CJK UNIFIED IDEOGRAPH-#4212, IRGKangXi=0890.150, Def{fragile; tender bamboo, (interchangeable 蹐) a kind of spring fishing-net, an equipment used to pull or drag (water plant, mud, etc.) out of the water}
4213 CJK UNIFIED IDEOGRAPH-#4213, IRGKangXi=0890.220, Def{a kind of bamboo with a red skin; it is used for fine mats and other purposes, an ancient musical instrument which was used to give the signal to cease playing}
4214 CJK UNIFIED IDEOGRAPH-#4214, IRGKangXi=0890.240, Def{(same as 笳) whistle made of reed without holes for fingering}
4215 CJK UNIFIED IDEOGRAPH-#4215, IRGKangXi=0890.260, Def{the metal tongue in the reed instruments, (interchangeable 匙) key, bamboo ware, (same as 筓) a clasp; a hair-pin with flat spoon-shaped ends, (same as 椸) a clothes-horse; a rack for clothes}
4216 CJK UNIFIED IDEOGRAPH-#4216, IRGKangXi=0890.270, Def{name of a variety of bamboo}
4217 CJK UNIFIED IDEOGRAPH-#4217, IRGKangXi=0891.050, Def{name of a variety of bamboo, bamboo mats, (interchangeable 葰) a cover, a shade, a basket used to catch fishes}
4218 CJK UNIFIED IDEOGRAPH-#4218, IRGKangXi=0891.220, Def{name of a variety of bamboo}
4219 CJK UNIFIED IDEOGRAPH-#4219, IRGKangXi=0892.010, Def{bamboo to wither; to dry up and die}
421A CJK UNIFIED IDEOGRAPH-#421A, IRGKangXi=0892.020, Def{a bamboo shoot, skin (bark) of a bamboo shoot, (same as 箈 苔) moss; lichen}
421B CJK UNIFIED IDEOGRAPH-#421B, IRGKangXi=0892.090, Def{small bamboo whose joints are three feet apart, used for arrows}
421C CJK UNIFIED IDEOGRAPH-#421C, IRGKangXi=0892.110, Def{a thread used by carpenters for marking, (interchangeable 沁) to leak; to soak through}
421D CJK UNIFIED IDEOGRAPH-#421D, IRGKangXi=0892.200, Def{name of a variety of bamboo, a kind of winnowing basket}
421E CJK UNIFIED IDEOGRAPH-#421E, IRGKangXi=0892.220, Def{(same as 竺) ancient name of India, a Chinese family name, (interchangeable 篤) honest; straightforward}
421F CJK UNIFIED IDEOGRAPH-#421F, IRGKangXi=0892.230, Def{broken sound, to cut grass}
4220 CJK UNIFIED IDEOGRAPH-#4220, IRGKangXi=0893.030, Def{books and volumes, letters and correspondence, to snap; to break; broken bamboo}
4221 CJK UNIFIED IDEOGRAPH-#4221, IRGKangXi=0893.070, Def{name of a variety of bamboo, (same as 檧) a small basket or a small cage}
4222 CJK UNIFIED IDEOGRAPH-#4222, IRGKangXi=0893.080, Def{name of a variety of bamboo, a thin and long strip of bamboo form making basket}
4223 CJK UNIFIED IDEOGRAPH-#4223, IRGKangXi=0893.130, Def{name of a variety of bamboo}
4224 CJK UNIFIED IDEOGRAPH-#4224, IRGKangXi=0893.170, Def{(same as 鉗) pincers; tweezers; tongs}
4225 CJK UNIFIED IDEOGRAPH-#4225, IRGKangXi=0893.190, Def{(non-classical form of 筋) tendons; sinews; muscles, name of a variety of bamboo}
4226 CJK UNIFIED IDEOGRAPH-#4226, IRGKangXi=0893.200, Def{a curved bamboo whip, thin branches of a tree}
4227 CJK UNIFIED IDEOGRAPH-#4227, IRGKangXi=0893.260, Def{(corrupted form) skin of bamboo shoots, bark of bamboo}
4228 CJK UNIFIED IDEOGRAPH-#4228, IRGKangXi=0893.291
4229 CJK UNIFIED IDEOGRAPH-#4229, IRGKangXi=0893.291
422A CJK UNIFIED IDEOGRAPH-#422A, IRGKangXi=0893.460, Def{a small, tall and no ears basket made of bamboo used to hold grains}
422B CJK UNIFIED IDEOGRAPH-#422B, IRGKangXi=0894.080, Def{(same as 笝) a hawser; a cable; a bamboo rope used to tie on a boat}
422C CJK UNIFIED IDEOGRAPH-#422C, IRGKangXi=0894.100, Def{a small; thin strip (of bamboo) net}
422D CJK UNIFIED IDEOGRAPH-#422D, IRGKangXi=0894.160, Def{name of a variety of bamboo, bamboo with high joints}
422E CJK UNIFIED IDEOGRAPH-#422E, IRGKangXi=0894.190, Def{a woven instrument; a knitting tool, name of a variety of bamboo}
422F CJK UNIFIED IDEOGRAPH-#422F, IRGKangXi=0894.200, Def{name of a variety of bamboo, utensils; implements}
4230 CJK UNIFIED IDEOGRAPH-#4230, IRGKangXi=0894.240, Def{a brush for washing kitchen utensils, a bamboo ware for holding rice used in ancient times, a basket for washing rice, a small bucket for chopsticks, (same as 梢) the tip of a branch or things of similar shape, the end of something, the rudder, (interchangeable 筲)}
4231 CJK UNIFIED IDEOGRAPH-#4231, IRGKangXi=0894.280, Def{an open bamboo basket used to feed domestic animals (cow, hog, etc.)}
4232 CJK UNIFIED IDEOGRAPH-#4232, IRGKangXi=0894.300, Def{a bamboo basket for fishing, name of a variety of bamboo, thin and flat slips of bamboo used for weaving purpose}
4233 CJK UNIFIED IDEOGRAPH-#4233, IRGKangXi=0894.340, Def{a window-leaf; something made of strips of bamboo to block sunlight}
4234 CJK UNIFIED IDEOGRAPH-#4234, IRGKangXi=0895.010, Def{a cage; a basket; a noose}
4235 CJK UNIFIED IDEOGRAPH-#4235, IRGKangXi=0895.020, Def{luxuriant; exuberant of bamboo}
4236 CJK UNIFIED IDEOGRAPH-#4236, IRGKangXi=0895.200, Def{an arrow; a dart, asparagus fern}
4237 CJK UNIFIED IDEOGRAPH-#4237, IRGKangXi=0895.290, Def{(same as standard form 格) a bamboo fence}
4238 CJK UNIFIED IDEOGRAPH-#4238, IRGKangXi=0895.400, Def{a big chest, a big basket for holding rice}
4239 CJK UNIFIED IDEOGRAPH-#4239, IRGKangXi=0896.010, Def{(same as 籔) a bamboo ware for washing rice, a measuring unit used in ancient times; equal to 16 Chinese peck}
423A CJK UNIFIED IDEOGRAPH-#423A, IRGKangXi=0896.120, Def{bamboo, a chest; a box}
423B CJK UNIFIED IDEOGRAPH-#423B, IRGKangXi=0896.140, Def{heavy bamboo mats used for deep water fishing}
423C CJK UNIFIED IDEOGRAPH-#423C, IRGKangXi=0896.210, Def{(same as 篾) name of a variety of bamboo, a thin and long strip of bamboo for making baskets, etc.; thin (bamboo) laths, a kind of small bamboo with pulp}
423D CJK UNIFIED IDEOGRAPH-#423D, IRGKangXi=0897.020, Def{name of a variety of bamboo; with short joints and white bark; big ones used as pole for punting a boat and roots used as medicine}
423E CJK UNIFIED IDEOGRAPH-#423E, IRGKangXi=0897.030, Def{(same as 稍) move a little; shake slightly, (same as 梢) the tip of a branch or things of similar shape, the end of rudder or helm, a besom for rice}
423F CJK UNIFIED IDEOGRAPH-#423F, IRGKangXi=0897.050, Def{belt of the canvas top on vehicles}
4240 CJK UNIFIED IDEOGRAPH-#4240, IRGKangXi=0897.100, Def{rectangular chest or box woven from bamboo strips (or wicker)}
4241 CJK UNIFIED IDEOGRAPH-#4241, IRGKangXi=0897.130, Def{name of a variety of bamboo, bamboo ware}
4242 CJK UNIFIED IDEOGRAPH-#4242, IRGKangXi=0897.260, Def{a basket for earth or soil, regulations; law, model}
4243 CJK UNIFIED IDEOGRAPH-#4243, IRGKangXi=0897.330, Def{sliced open bamboo with the joints used as an oar, a board made equipment with angles; children used to practice writing and taking notes in ancient times, mats, bamboo}
4244 CJK UNIFIED IDEOGRAPH-#4244, IRGKangXi=0897.350, Def{name of a variety of bamboo}
4245 CJK UNIFIED IDEOGRAPH-#4245, IRGKangXi=0898.040, Def{small bamboo whose joints are three feet apart, used for arrows, name of a variety of bamboo}
4246 CJK UNIFIED IDEOGRAPH-#4246, IRGKangXi=0898.240, Def{name of a variety of bamboo}
4247 CJK UNIFIED IDEOGRAPH-#4247, IRGKangXi=0898.371
4248 CJK UNIFIED IDEOGRAPH-#4248, IRGKangXi=0898.400, Def{a kind of bamboo with a red skin; it is used for fine mats and other purposes}
4249 CJK UNIFIED IDEOGRAPH-#4249, IRGKangXi=0898.420, Def{(interchangeable 觚) a writing-tablet; a square piece of wood, a corner; an angle; an edge}
424A CJK UNIFIED IDEOGRAPH-#424A, IRGKangXi=0898.450, Def{bamboo ware, awning in front of a cart, covering the horse or mule in the shafts; canvas top on vehicles}
424B CJK UNIFIED IDEOGRAPH-#424B, IRGKangXi=0899.030, Def{a variety of bamboo shoots that sprout in winter}
424C CJK UNIFIED IDEOGRAPH-#424C, IRGKangXi=0899.070, Def{crude bamboo mats, a vessel for raising silk-worms}
424D CJK UNIFIED IDEOGRAPH-#424D, IRGKangXi=0899.130, Def{(non-classical form) to observe; to watch; to examine}
424E CJK UNIFIED IDEOGRAPH-#424E, IRGKangXi=0899.180, Def{a cover, a shade, a basket used to catch fish}
424F CJK UNIFIED IDEOGRAPH-#424F, IRGKangXi=0899.200, Def{name of a variety of bamboo}
4250 CJK UNIFIED IDEOGRAPH-#4250, IRGKangXi=0899.210, Def{a thin and long strip of bamboo for making baskets, etc.; thin (bamboo) laths, name of a variety of bamboo, (corrupted form of U+7C35 簬) used for arrows}
4251 CJK UNIFIED IDEOGRAPH-#4251, IRGKangXi=0900.020, Def{black skinned bamboo}
4252 CJK UNIFIED IDEOGRAPH-#4252, IRGKangXi=0900.030, Def{(same as 籓) a winnow, a container for dust, (same as 藩) a bamboo fence; a barrier, a bamboo basket with handles for carrying earth or dirt, family name}
4253 CJK UNIFIED IDEOGRAPH-#4253, IRGKangXi=0900.090, Def{mattress made of bamboo strips, bed}
4254 CJK UNIFIED IDEOGRAPH-#4254, IRGKangXi=0900.130, Def{bamboo slips, crude; coarse bamboo mats}
4255 CJK UNIFIED IDEOGRAPH-#4255, IRGKangXi=0900.170, Def{a bamboo hat, a bamboo shade or covering, name of a variety of bamboo}
4256 CJK UNIFIED IDEOGRAPH-#4256, IRGKangXi=0900.230, Def{(same as 笭) framework of a carriage, a door-screen; a railing in the front and on both sides of a carriage, a stand; frame; rack in a cabin of a ship, a bamboo cage; a bamboo basket with a narrow opening}
4257 CJK UNIFIED IDEOGRAPH-#4257, IRGKangXi=0900.260, Def{a receptacle or container, as a cup, ladle, spoon, etc.}
4258 CJK UNIFIED IDEOGRAPH-#4258, IRGKangXi=0900.270, Def{to pierce; to stab with a sharp wooden stick or a piece of bamboo slip}
4259 CJK UNIFIED IDEOGRAPH-#4259, IRGKangXi=0901.160, Def{name of a variety of bamboo; big bamboo}
425A CJK UNIFIED IDEOGRAPH-#425A, IRGKangXi=0901.250, Def{name of a variety of bamboo, a bamboo shoot, a bamboo tube}
425B CJK UNIFIED IDEOGRAPH-#425B, IRGKangXi=0901.310, Def{bamboo basket for washing rice, implements used to move the silkworm}
425C CJK UNIFIED IDEOGRAPH-#425C, IRGKangXi=0901.350, Def{young and tender bamboo}
425D CJK UNIFIED IDEOGRAPH-#425D, IRGKangXi=0901.400, Def{bamboo ware}
425E CJK UNIFIED IDEOGRAPH-#425E, IRGKangXi=0901.410, Def{a box; a chest made of bamboo; bamboo ware, name of a variety of bamboo}
425F CJK UNIFIED IDEOGRAPH-#425F, IRGKangXi=0901.450, Def{a bamboo basket used to catch fishes}
4260 CJK UNIFIED IDEOGRAPH-#4260, IRGKangXi=0902.050, Def{name of a variety of bamboo; leaves to make covering and the stems make arrows}
4261 CJK UNIFIED IDEOGRAPH-#4261, IRGKangXi=0902.160, Def{name of a variety of bamboo, a towrope used to tow a boat against the current in swift stream from the bank}
4262 CJK UNIFIED IDEOGRAPH-#4262, IRGKangXi=0902.200, Def{a sieve; a screen; a sifter; a strainer}
4263 CJK UNIFIED IDEOGRAPH-#4263, IRGKangXi=0902.220, Def{slips of bamboo provided for writing in ancient times}
4264 CJK UNIFIED IDEOGRAPH-#4264, IRGKangXi=0902.321, Def{(a simplified form of 籔) a bamboo ware for washing rice, a measuring unit used in ancient times; equal to 16 Chinese peck}
4265 CJK UNIFIED IDEOGRAPH-#4265, IRGKangXi=0902.440, Def{(same as 檧) a small basket for chopsticks}
4266 CJK UNIFIED IDEOGRAPH-#4266, IRGKangXi=0903.200, Def{name of a variety of bamboo, a farm tool used to collect rice plants}
4267 CJK UNIFIED IDEOGRAPH-#4267, IRGKangXi=0903.220, Def{sound of bamboo, name of a variety of bamboo}
4268 CJK UNIFIED IDEOGRAPH-#4268, IRGKangXi=0903.270, Def{bamboo joints, name of a variety of bamboo, small bamboo}
4269 CJK UNIFIED IDEOGRAPH-#4269, IRGKangXi=0903.320, Def{a bamboo ware; a cradle}
426A CJK UNIFIED IDEOGRAPH-#426A, IRGKangXi=0903.340, Def{to grind; by turning a mill to get the chaff, bran or husks off, a mill}
426B CJK UNIFIED IDEOGRAPH-#426B, IRGKangXi=0903.360, Def{name of a variety of bamboo; used as a musical instrument}
426C CJK UNIFIED IDEOGRAPH-#426C, IRGKangXi=0903.370, Def{coarse bamboo mats}
426D CJK UNIFIED IDEOGRAPH-#426D, IRGKangXi=0904.010, Def{name of a variety of bamboo, covering made of bamboo strips}
426E CJK UNIFIED IDEOGRAPH-#426E, IRGKangXi=0904.390, Def{to plant; to set up, to damage, to lose, weak}
426F CJK UNIFIED IDEOGRAPH-#426F, IRGKangXi=0905.010, Def{dried bamboo}
4270 CJK UNIFIED IDEOGRAPH-#4270, IRGKangXi=0905.040, Def{bamboo shoots, (same as 筊) a rope made of bamboo strips, a kind of bamboo device used in divination}
4271 CJK UNIFIED IDEOGRAPH-#4271, IRGKangXi=0905.090, Def{a cradle}
4272 CJK UNIFIED IDEOGRAPH-#4272, IRGKangXi=0905.120, Def{thin and flat slips of bamboo used for weaving purpose}
4273 CJK UNIFIED IDEOGRAPH-#4273, IRGKangXi=0905.170, Def{name of a variety of bamboo, a domicile; record of the population}
4274 CJK UNIFIED IDEOGRAPH-#4274, IRGKangXi=0905.210, Def{a bamboo ware to collect and keep something in, a kind of bamboo ware used to dripping rice}
4275 CJK UNIFIED IDEOGRAPH-#4275, IRGKangXi=1427.020, Def{(same as 饌) to feed, to provide for, to prepare food; to eat and drink; delicacies, dainties}
4276 CJK UNIFIED IDEOGRAPH-#4276, IRGKangXi=0905.340, Def{a sail (of a boat), a untensil made of bamboo used to filter or to strain out wine}
4277 CJK UNIFIED IDEOGRAPH-#4277, IRGKangXi=0906.160, Def{a feather screen, a shade, imperial garden}
4278 CJK UNIFIED IDEOGRAPH-#4278, IRGKangXi=0906.200, Def{slips of bamboo for writing}
4279 CJK UNIFIED IDEOGRAPH-#4279, IRGKangXi=0906.270, Def{(same as 䉁) name of a variety of bamboo, bamboo ware}
427A CJK UNIFIED IDEOGRAPH-#427A, IRGKangXi=0906.390, Def{to deteriorate and become red; old rice; decaying rice, red rice; (Cant.) the smell of long-stored rice}
427B CJK UNIFIED IDEOGRAPH-#427B, IRGKangXi=0907.070, Def{red rice, coarse rice}
427C CJK UNIFIED IDEOGRAPH-#427C, IRGKangXi=0907.211, Def{(non-classical form of 料) materials; ingredients}
427D CJK UNIFIED IDEOGRAPH-#427D, IRGKangXi=0907.240, Def{(same as 粄) rice cake; cake made of glutinous rice}
427E CJK UNIFIED IDEOGRAPH-#427E, IRGKangXi=0907.290, Def{bad; poor quality of rice}
427F CJK UNIFIED IDEOGRAPH-#427F, IRGKangXi=0908.020, Def{(same as 糊) paste; to paste, sticky; glutinous, to stick}
4280 CJK UNIFIED IDEOGRAPH-#4280, IRGKangXi=0908.050, Def{(same as 䉿) (same as 糊) paste; to paste, sticky; glutinous, to stick}
4281 CJK UNIFIED IDEOGRAPH-#4281, IRGKangXi=0908.200, Def{(same as U+7C78 籸) leavings; refuse (from foodstuff, petroleum, oil, etc.; siftings, congee; rice gruel (the surface part); a kind of cooked rice}
4282 CJK UNIFIED IDEOGRAPH-#4282, IRGKangXi=0908.220, Def{poor quality of rice; bad rice cakes stick to each other}
4283 CJK UNIFIED IDEOGRAPH-#4283, IRGKangXi=0908.240, Def{mixing rice with broth, a grain of rice}
4284 CJK UNIFIED IDEOGRAPH-#4284, IRGKangXi=0908.270, Def{polished rice}
4285 CJK UNIFIED IDEOGRAPH-#4285, IRGKangXi=0908.280, Def{to soak rice}
4286 CJK UNIFIED IDEOGRAPH-#4286, IRGKangXi=0908.340, Def{cooked, dry rice flour, (same as 糗) cured dried grain; parched wheat or rice}
4287 CJK UNIFIED IDEOGRAPH-#4287, IRGKangXi=0909.110, Def{(same as 餔) to feed; to eat, (interchangeable 晡) time for supper, sunset}
4288 CJK UNIFIED IDEOGRAPH-#4288, IRGKangXi=0909.140, Def{(same as 酶) distiller's grains or yeast}
4289 CJK UNIFIED IDEOGRAPH-#4289, IRGKangXi=0909.170, Def{preserved fruit, cucumbers, gourds, etc.}
428A CJK UNIFIED IDEOGRAPH-#428A, IRGKangXi=0909.220, Def{well-boiled congee or rice gruel}
428B CJK UNIFIED IDEOGRAPH-#428B, IRGKangXi=0909.311, Def{(same as 妝) to adorn oneself, to disguise, to pretend}
428C CJK UNIFIED IDEOGRAPH-#428C, IRGKangXi=0909.311
428D CJK UNIFIED IDEOGRAPH-#428D, IRGKangXi=0909.350, Def{thick congee or porridge; well-boiled congee or gruel, (same as 黎) many; numerous}
428E CJK UNIFIED IDEOGRAPH-#428E, IRGKangXi=0910.050, Def{powder; flour, to roll round with the hand, thick congee or porridge}
428F CJK UNIFIED IDEOGRAPH-#428F, IRGKangXi=0910.070, Def{(non-classical form of U+7CC2 糝) mixing rice with broth, a grain of rice}
4290 CJK UNIFIED IDEOGRAPH-#4290, IRGKangXi=0910.120, Def{(same as 餛) fluffy stuffed dumplings; stuffed dumpling with delicate flour wrapping; ravioli}
4291 CJK UNIFIED IDEOGRAPH-#4291, IRGKangXi=0910.170, Def{(same as 餉 饟) pay, provisions, etc. for military or police, to entertain with food; to feast}
4292 CJK UNIFIED IDEOGRAPH-#4292, IRGKangXi=0910.201, Def{(same as 精) refined; polished (rice); unmixed, the essence, fine and delicate, keen; sharp}
4293 CJK UNIFIED IDEOGRAPH-#4293, IRGKangXi=0910.230, Def{to paste up; to attach to; to stickup; to glue}
4294 CJK UNIFIED IDEOGRAPH-#4294, IRGKangXi=0910.260, Def{polished rice; refined rice}
4295 CJK UNIFIED IDEOGRAPH-#4295, IRGKangXi=0910.270, Def{(same as 饘) well-boiled congee or gruel, thick, rich}
4296 CJK UNIFIED IDEOGRAPH-#4296, IRGKangXi=0910.300, Def{to eat rice-gruel mixed with meat}
4297 CJK UNIFIED IDEOGRAPH-#4297, IRGKangXi=0910.320, Def{a kind of grain; yellow color; not sticky, (same as 餭) fried puffy shredded, sugar-plums; sweetmeats}
4298 CJK UNIFIED IDEOGRAPH-#4298, IRGKangXi=0911.030, Def{a grain (of rice, etc.)}
4299 CJK UNIFIED IDEOGRAPH-#4299, IRGKangXi=0911.190, Def{cooked or well-done, ripe, fine rice}
429A CJK UNIFIED IDEOGRAPH-#429A, IRGKangXi=0911.270, Def{steamed dumplings}
429B CJK UNIFIED IDEOGRAPH-#429B, IRGKangXi=0912.090, Def{shreds; splinters (of rice)}
429C CJK UNIFIED IDEOGRAPH-#429C, IRGKangXi=0912.160, Def{(same as 糰) dumplings; doughnuts}
429D CJK UNIFIED IDEOGRAPH-#429D, IRGKangXi=0912.170, Def{to exile; to banish}
429E CJK UNIFIED IDEOGRAPH-#429E, IRGKangXi=0912.180, Def{to roll round with the hand; to paste up; to attach to; to stick up; to glue, poor quality of rice}
429F CJK UNIFIED IDEOGRAPH-#429F, IRGKangXi=0912.230, Def{adorned; beautified; made up; glossy, thick and sticky thing on the surface of congee; rice gruel}
42A0 CJK UNIFIED IDEOGRAPH-#42A0, IRGKangXi=0912.290, Def{(same as 氣 餼) to give a supply of grain for rations, grain, a sacrificial victim, explained as used of the living beast}
42A1 CJK UNIFIED IDEOGRAPH-#42A1, IRGKangXi=0912.330, Def{(same as non-classical form 饅) steamed bread; bread of any kind; steamed dumplings}
42A2 CJK UNIFIED IDEOGRAPH-#42A2, IRGKangXi=0912.391, Def{(same as 漿) thick fluid; starch; to starch}
42A3 CJK UNIFIED IDEOGRAPH-#42A3, IRGKangXi=0912.450, Def{light yellow dust-like fungoid growth on wine, etc., barley, chaff or husks of wheat (non-classical form of 餭) fried puffy shredded, sugar-plums; sweetmeats}
42A4 CJK UNIFIED IDEOGRAPH-#42A4, IRGKangXi=0912.470, Def{vegetable mixed with thick soup (broth), congee; gruel}
42A5 CJK UNIFIED IDEOGRAPH-#42A5, IRGKangXi=0913.010, Def{congee; porridge; rice gruel, mashed; rotten}
42A6 CJK UNIFIED IDEOGRAPH-#42A6, IRGKangXi=0913.040, Def{food (some food as glutinouss rice tamale -- made by wrapping the rice in broad leaves of reeds and boiled for a few hours --usually with other ingredients, as dates, meat, oyster, beams, etc.}
42A7 CJK UNIFIED IDEOGRAPH-#42A7, IRGKangXi=0913.080, Def{(same as 屁) a fart; to break wind}
42A8 CJK UNIFIED IDEOGRAPH-#42A8, IRGKangXi=0913.130, Def{storing grains; to store up food}
42A9 CJK UNIFIED IDEOGRAPH-#42A9, IRGKangXi=0912.150, Def{rice gravy}
42AA CJK UNIFIED IDEOGRAPH-#42AA, IRGKangXi=0913.190, Def{coarse rice -- unhulled, (interchangeable 糲) coarse -- of grain}
42AB CJK UNIFIED IDEOGRAPH-#42AB, IRGKangXi=0913.200, Def{coarse rice, red rice}
42AC CJK UNIFIED IDEOGRAPH-#42AC, IRGKangXi=0913.340, Def{name of a variety of grain, hollyhock; the mallow; root and flower can be used as medicine to neutralize poison; antiphretic (febrifuge)}
42AD CJK UNIFIED IDEOGRAPH-#42AD, IRGKangXi=0913.350, Def{to overturn; to pour out, to respond, to examine carefully, to stick, thick congee}
42AE CJK UNIFIED IDEOGRAPH-#42AE, IRGKangXi=0913.380, Def{name of a variety of grain}
42AF CJK UNIFIED IDEOGRAPH-#42AF, IRGKangXi=0913.460, Def{(same as standard form 穬) grains with beard (rice plant, wheat, etc.) unripe rice plant}
42B0 CJK UNIFIED IDEOGRAPH-#42B0, IRGKangXi=0914.010, Def{foodstuff; provisions; grains for human consumption}
42B1 CJK UNIFIED IDEOGRAPH-#42B1, IRGKangXi=0914.050, Def{cakes made of rice-flour}
42B2 CJK UNIFIED IDEOGRAPH-#42B2, IRGKangXi=0914.060, Def{to hull rice roughly (to make a rush pounding of the rice); coarse rice, to grind (grains, millet, etc.)}
42B3 CJK UNIFIED IDEOGRAPH-#42B3, IRGKangXi=0914.140, Def{to break into pieces; to smash; completely smashed, chips; crumbs, refined; polished (rice); unmixed}
42B4 CJK UNIFIED IDEOGRAPH-#42B4, IRGKangXi=0914.180, Def{food made of rice-flour}
42B5 CJK UNIFIED IDEOGRAPH-#42B5, IRGKangXi=0915.050, Def{young and small, (same as 絿) rash and impatient}
42B6 CJK UNIFIED IDEOGRAPH-#42B6, IRGKangXi=0915.170, Def{(same as 紖) a rope for leading cattle}
42B7 CJK UNIFIED IDEOGRAPH-#42B7, IRGKangXi=0915.190, Def{(same as 緇) black silk; a dark, drab colour, used for Buddhists, from the dark colour of their robes (same as 純) pure, honest}
42B8 CJK UNIFIED IDEOGRAPH-#42B8, IRGKangXi=0916.090, Def{(standard form of 紆) to twist; to distort, a cord}
42B9 CJK UNIFIED IDEOGRAPH-#42B9, IRGKangXi=0916.121, Def{(a abbreviated form of 纖) small, fine, delicate}
42BA CJK UNIFIED IDEOGRAPH-#42BA, IRGKangXi=0916.130, Def{an implement to draw or to collect ropes or cords}
42BB CJK UNIFIED IDEOGRAPH-#42BB, IRGKangXi=0916.190, Def{silky, very fine thread}
42BC CJK UNIFIED IDEOGRAPH-#42BC, IRGKangXi=0917.110, Def{measuring unit; end of spoilt silk}
42BD CJK UNIFIED IDEOGRAPH-#42BD, IRGKangXi=0917.130, Def{a fine thread, linen thread; silk thread; a thread; a yarn}
42BE CJK UNIFIED IDEOGRAPH-#42BE, IRGKangXi=0917.160, Def{ropes; cords; cables}
42BF CJK UNIFIED IDEOGRAPH-#42BF, IRGKangXi=0917.170, Def{(same as 衭) the lapel or collar of a garment or robe, drawers, (dialect) trousers or pants}
42C0 CJK UNIFIED IDEOGRAPH-#42C0, IRGKangXi=0918.010, Def{shoes made of hemp or hair}
42C1 CJK UNIFIED IDEOGRAPH-#42C1, IRGKangXi=0918.030, Def{(ancient form 綆) a rope for drawing up water (from a well, stream, etc.)}
42C2 CJK UNIFIED IDEOGRAPH-#42C2, IRGKangXi=0918.130, Def{dresses for the bride, green color, yellow color, (interchangeable 絞) a greenish yellow color}
42C3 CJK UNIFIED IDEOGRAPH-#42C3, IRGKangXi=0918.140, Def{stinging; hairy silk fabrics}
42C4 CJK UNIFIED IDEOGRAPH-#42C4, IRGKangXi=0919.110, Def{(same as 網) web; net; network}
42C5 CJK UNIFIED IDEOGRAPH-#42C5, IRGKangXi=0919.171
42C6 CJK UNIFIED IDEOGRAPH-#42C6, IRGKangXi=0919.171
42C7 CJK UNIFIED IDEOGRAPH-#42C7, IRGKangXi=0919.171
42C8 CJK UNIFIED IDEOGRAPH-#42C8, IRGKangXi=0919.190, Def{to bind loose hemp, old yarn, to stuff; to fill, waste silk or cotton and silk to be laid and attached each other; to padding; cushioning}
42C9 CJK UNIFIED IDEOGRAPH-#42C9, IRGKangXi=0919.220, Def{(interchangeable 䊽) a numerary adjunct (classifier) for practically everything; a thread; a yarn, clothes for the dead, linen thread; silk thread}
42CA CJK UNIFIED IDEOGRAPH-#42CA, IRGKangXi=0919.240, Def{decorations of the emperor's carriage; ornamental items on horses}
42CB CJK UNIFIED IDEOGRAPH-#42CB, IRGKangXi=0919.310, Def{(same as 罠) a kind of spring fishing net}
42CC CJK UNIFIED IDEOGRAPH-#42CC, IRGKangXi=0920.040, Def{(ancient form 堅) strong; durable; solid; firm; stable, (same as 䋗) tight; firm, pressing}
42CD CJK UNIFIED IDEOGRAPH-#42CD, IRGKangXi=0920.110, Def{(an abbreviated form of 䋪) fine and delicate silk, plain white sackcloth for mourning}
42CE CJK UNIFIED IDEOGRAPH-#42CE, IRGKangXi=0920.120, Def{to mend (clothes, etc.), (interchangeable 綻) ripped seam; a crack; split}
42CF CJK UNIFIED IDEOGRAPH-#42CF, IRGKangXi=0920.130, Def{thick and big ropes or cords; bulky cables, spoilt silk}
42D0 CJK UNIFIED IDEOGRAPH-#42D0, IRGKangXi=0920.210, Def{fabric; textile with patterns used for hem decorations, decorations on carriage and horses, varicolored silk or fine cloth loose in texture}
42D1 CJK UNIFIED IDEOGRAPH-#42D1, IRGKangXi=0921.250, Def{to tie; to knot, to join}
42D2 CJK UNIFIED IDEOGRAPH-#42D2, IRGKangXi=0921.270, Def{(corrupted form of 紓) to relax, to free from}
42D3 CJK UNIFIED IDEOGRAPH-#42D3, IRGKangXi=0921.290, Def{(abbreviated form 縐) wrinkled, to shrink, crepe, a coarse, yellowish cloth for summer wear}
42D4 CJK UNIFIED IDEOGRAPH-#42D4, IRGKangXi=0921.291, Def{to band together; to twist; to wring and to disperse fiber then to make thin silk, cloth, cotton-yarn or rope}
42D5 CJK UNIFIED IDEOGRAPH-#42D5, IRGKangXi=0921.310, Def{(same as U+7D4D 紝) to lay the warp; to weave}
42D6 CJK UNIFIED IDEOGRAPH-#42D6, IRGKangXi=0921.380, Def{long, a gown; a long dress}
42D7 CJK UNIFIED IDEOGRAPH-#42D7, IRGKangXi=0922.030, Def{(same as 䋌) (same as 堅) strong and durable, solid and firm; tight; pressing}
42D8 CJK UNIFIED IDEOGRAPH-#42D8, IRGKangXi=0922.070, Def{(same as 縋) to hand by a rope; to let down by a rope}
42D9 CJK UNIFIED IDEOGRAPH-#42D9, IRGKangXi=0922.130, Def{reins; bridle}
42DA CJK UNIFIED IDEOGRAPH-#42DA, IRGKangXi=0923.020, Def{(same as 翼) wings, fins, to help, to protect}
42DB CJK UNIFIED IDEOGRAPH-#42DB, IRGKangXi=0923.080, Def{the clustered embroidery patterns (as tiny and fine rice)}
42DC CJK UNIFIED IDEOGRAPH-#42DC, IRGKangXi=0924.120, Def{(same as 綮) crucial points; critical points, an embroidered banner, sheath for a lancehead}
42DD CJK UNIFIED IDEOGRAPH-#42DD, IRGKangXi=0924.161, Def{(abbreviated form of 纓) a throat-band; chin strap for holding the hat, tassel; a fringe}
42DE CJK UNIFIED IDEOGRAPH-#42DE, IRGKangXi=0924.161, Def{(abbreviated form of 網) web; net; network}
42DF CJK UNIFIED IDEOGRAPH-#42DF, IRGKangXi=0924.190, Def{the weight on a steelyard, connected stitches}
42E0 CJK UNIFIED IDEOGRAPH-#42E0, IRGKangXi=0924.320, Def{(interchangeable 補) to repair; to mend, to add to, to make up}
42E1 CJK UNIFIED IDEOGRAPH-#42E1, IRGKangXi=0925.020, Def{(same as 紓) (interchangeable 舒) to relax, to free from}
42E2 CJK UNIFIED IDEOGRAPH-#42E2, IRGKangXi=0925.120, Def{to twist ropes, a belt or string to hold the bow, to tie; to bind, the cart turning back to the left, to draw or pull (of a cart), to mourn}
42E3 CJK UNIFIED IDEOGRAPH-#42E3, IRGKangXi=0926.040, Def{decorations put on the mane or horsehair, (standard form of 繁) many, troublesome, a family name}
42E4 CJK UNIFIED IDEOGRAPH-#42E4, IRGKangXi=0926.050, Def{plain white silk, to soften and whiten raw silk by boiling}
42E5 CJK UNIFIED IDEOGRAPH-#42E5, IRGKangXi=0926.060, Def{lines; stripes; veins}
42E6 CJK UNIFIED IDEOGRAPH-#42E6, IRGKangXi=0926.110, Def{ravelled silk}
42E7 CJK UNIFIED IDEOGRAPH-#42E7, IRGKangXi=0926.250, Def{(same as 絇) ornaments for the frontal part of shoes}
42E8 CJK UNIFIED IDEOGRAPH-#42E8, IRGKangXi=0926.280, Def{to set in order the old, raw, coarse, waste silk or cotton}
42E9 CJK UNIFIED IDEOGRAPH-#42E9, IRGKangXi=0926.290, Def{pretty and fine silk fabrics}
42EA CJK UNIFIED IDEOGRAPH-#42EA, IRGKangXi=0926.330, Def{(interchangeable 䋍) fine and delicate silk, plain white sackcloth for mourning}
42EB CJK UNIFIED IDEOGRAPH-#42EB, IRGKangXi=0927.020, Def{to wind round the ropes, crooked; winding; bends; turns; curves; turns and twists, to play a sound of hasty (fast) string (of a musical instrument)}
42EC CJK UNIFIED IDEOGRAPH-#42EC, IRGKangXi=0927.050, Def{rug; carpet; blanket, woolen textiles; woolen goods; woolen stuff; woolen fabrics}
42ED CJK UNIFIED IDEOGRAPH-#42ED, IRGKangXi=0927.090, Def{to weave silk fabrics with green color for longitude and white for latitude, silk fabrics from Yuyang}
42EE CJK UNIFIED IDEOGRAPH-#42EE, IRGKangXi=0927.140, Def{(the large seal; a type of Chinese calligraphy) (same as 紟) a sash, to tie, a kind of cloth or textiles, lapel of a Chinese dress, a single coverlet}
42EF CJK UNIFIED IDEOGRAPH-#42EF, IRGKangXi=0927.170, Def{(same as 綮) crucial points; critical points, an embroidered banner, sheath for a lancehead}
42F0 CJK UNIFIED IDEOGRAPH-#42F0, IRGKangXi=0927.190, Def{to bind or restrain; restraint; restriction, timid and awkward, to wind around; to tangle, to connect; to join, together with}
42F1 CJK UNIFIED IDEOGRAPH-#42F1, IRGKangXi=0927.220, Def{(same as 斄) a wild yak, hard and curved hair, name of a county in ancient times}
42F2 CJK UNIFIED IDEOGRAPH-#42F2, IRGKangXi=0929.291, Def{(non-classical form of U+7E69 繩) a rope; a cord, to restrain, to rectify; to correct}
42F3 CJK UNIFIED IDEOGRAPH-#42F3, IRGKangXi=0929.310, Def{(same as 褙) cloth or paper pasted together; pasteboard; to mount (paintings or calligraphic works), short clothes}
42F4 CJK UNIFIED IDEOGRAPH-#42F4, IRGKangXi=0930.010, Def{silk fabrics with mixed colors}
42F5 CJK UNIFIED IDEOGRAPH-#42F5, IRGKangXi=0930.040, Def{quick, urgent, anxious, not going to succeed, poor quality of silk fabrics}
42F6 CJK UNIFIED IDEOGRAPH-#42F6, IRGKangXi=0930.060, Def{to stumble; to trip the front feet of a beast, a kind of brocade from Shu}
42F7 CJK UNIFIED IDEOGRAPH-#42F7, IRGKangXi=0930.110, Def{a kind of thick, loosely-woven raw silk fabric}
42F8 CJK UNIFIED IDEOGRAPH-#42F8, IRGKangXi=0930.170, Def{back center suture of the clothes}
42F9 CJK UNIFIED IDEOGRAPH-#42F9, IRGKangXi=0930.180, Def{(same as 幅) breadth of material (cloth or paper, etc.)}
42FA CJK UNIFIED IDEOGRAPH-#42FA, IRGKangXi=0931.070, Def{(same as 鞦) a swing (same as U+97A7 緧) a crupper; traces}
42FB CJK UNIFIED IDEOGRAPH-#42FB, IRGKangXi=0931.090, Def{to spin and weave, equal; uniform; (same as U+7D1D 紝) to lay the warp; to weave}
42FC CJK UNIFIED IDEOGRAPH-#42FC, IRGKangXi=0931.100, Def{slow; leisurely, to delay; to slacken, silk ribbons}
42FD CJK UNIFIED IDEOGRAPH-#42FD, IRGKangXi=0931.290, Def{hempen sandals, leather shoes (for children)}
42FE CJK UNIFIED IDEOGRAPH-#42FE, IRGKangXi=0932.060, Def{cotton and silk to be laid and attached each other}
42FF CJK UNIFIED IDEOGRAPH-#42FF, IRGKangXi=0932.090, Def{a decorative knot made of colorful silk (blue, yellow, red, white and black)}
4300 CJK UNIFIED IDEOGRAPH-#4300, IRGKangXi=0932.110, Def{to arrange; to repair silk, colored patterns (stripes; lines; streaks; veins)}
4301 CJK UNIFIED IDEOGRAPH-#4301, IRGKangXi=0932.200, Def{a pleat; fold, a piece of string; ribbon used to tie clothes, a rope; a line; a cord}
4302 CJK UNIFIED IDEOGRAPH-#4302, IRGKangXi=0932.280, Def{(same as 握) in ancient times, article for preparing the body for the coffin (something slip on the hand of the dead)}
4303 CJK UNIFIED IDEOGRAPH-#4303, IRGKangXi=0932.290, Def{(same as 綃) raw silk, to seal; to close}
4304 CJK UNIFIED IDEOGRAPH-#4304, IRGKangXi=0933.061, Def{(standard form of 綆) a rope for drawing up water (form a well, stream, etc.)}
4305 CJK UNIFIED IDEOGRAPH-#4305, IRGKangXi=0933.180, Def{a thick ropes}
4306 CJK UNIFIED IDEOGRAPH-#4306, IRGKangXi=0933.200, Def{silk fabrics}
4307 CJK UNIFIED IDEOGRAPH-#4307, IRGKangXi=0933.380, Def{(non-classical form of 索) a thick rope; a cable, alone, to tighten; to squeeze, to need, to demand}
4308 CJK UNIFIED IDEOGRAPH-#4308, IRGKangXi=0934.210, Def{to get something with a lasso}
4309 CJK UNIFIED IDEOGRAPH-#4309, IRGKangXi=0935.120, Def{(non-classical form of 綱) the large of a net, main point, principle}
430A CJK UNIFIED IDEOGRAPH-#430A, IRGKangXi=0935.181, Def{(corrupted form of 繇) entourage; aides; attendants, cause; means, by way of, etc., forced labour; labor service}
430B CJK UNIFIED IDEOGRAPH-#430B, IRGKangXi=0935.181, Def{a kerchief hung at the waist, a tiny sack; a purse or pouch carried hanging over the girdle}
430C CJK UNIFIED IDEOGRAPH-#430C, IRGKangXi=0935.220, Def{lace; embroidered hem (of a garment), (same as 緁) a narrow strip of woven material (such as the hem of a straw hat)}
430D CJK UNIFIED IDEOGRAPH-#430D, IRGKangXi=0935.230, Def{fine woven pattern}
430E CJK UNIFIED IDEOGRAPH-#430E, IRGKangXi=0935.290, Def{to baste for sewing, to connect; to sew; to stitch; to mend}
430F CJK UNIFIED IDEOGRAPH-#430F, IRGKangXi=0936.010
4310 CJK UNIFIED IDEOGRAPH-#4310, IRGKangXi=0936.030, Def{ropes; cords; cables}
4311 CJK UNIFIED IDEOGRAPH-#4311, IRGKangXi=0936.040, Def{(interchangeable 堅) tight; firm; fast; secure; close}
4312 CJK UNIFIED IDEOGRAPH-#4312, IRGKangXi=0936.190, Def{pure; unallyed, honest; simple, purely}
4313 CJK UNIFIED IDEOGRAPH-#4313, IRGKangXi=0937.020, Def{(corrupted form of U+7E41 繁) many; abundant, complex; intricate}
4314 CJK UNIFIED IDEOGRAPH-#4314, IRGKangXi=0938.080, Def{(corrupted form of 漚) to soak, foam; bubble; froth}
4315 CJK UNIFIED IDEOGRAPH-#4315, IRGKangXi=0938.140, Def{(same as 縻) to tie; to fasten; to connect}
4316 CJK UNIFIED IDEOGRAPH-#4316, IRGKangXi=0938.210, Def{to gather; to assemble; to come together; to blend; to mix, disorderly; mixed, a general term for wealthy goods and textiles (in southern minority group)}
4317 CJK UNIFIED IDEOGRAPH-#4317, IRGKangXi=0938.240, Def{the left over of drawing silk (from cocoons), silk, to arrange raw, coarse, old, waste cotton or silk}
4318 CJK UNIFIED IDEOGRAPH-#4318, IRGKangXi=0939.070, Def{to knit; to twist ropes, a belt to hang sword, poor qualitied silk wadding}
4319 CJK UNIFIED IDEOGRAPH-#4319, IRGKangXi=0939.080, Def{hank of ropes}
431A CJK UNIFIED IDEOGRAPH-#431A, IRGKangXi=0939.210, Def{wrinkles; creases; folds}
431B CJK UNIFIED IDEOGRAPH-#431B, IRGKangXi=0940.031, Def{(same as 繇 徭 陶 謠 由 猶 悠 籀) entourage; aides; attendants, compulsory labor service, to make pottery or earthenware, happy, ballad; folk song, rumor, through; via; by way of, like; similar to, still; yet, far, sad, soft; slow, to deduce (interchangeable 搖 遙 傜)}
431C CJK UNIFIED IDEOGRAPH-#431C, IRGKangXi=0940.160, Def{to sew; to stitch; to suture; to mend; to patch a garment; dresses, etc.. to twist; to tie up with ropes}
431D CJK UNIFIED IDEOGRAPH-#431D, IRGKangXi=0940.220, Def{silk, a general name of silk fabrics or goods, (interchangeable 紺) reddish dark color; violet or purple}
431E CJK UNIFIED IDEOGRAPH-#431E, IRGKangXi=0941.020, Def{a knot to hang the apparatus made of reed for raising silkworms, a rope}
431F CJK UNIFIED IDEOGRAPH-#431F, IRGKangXi=0941.030, Def{to weave silk ribbons, (interchangeable 澼) to wash; to launder}
4320 CJK UNIFIED IDEOGRAPH-#4320, IRGKangXi=0941.080, Def{hold on to one's own views, to keep the mouth shut, stingy; miserly; niggardly; parsimonious}
4321 CJK UNIFIED IDEOGRAPH-#4321, IRGKangXi=0941.130, Def{to wind around; to bind; to wrap; to tangle, to bother persistently}
4322 CJK UNIFIED IDEOGRAPH-#4322, IRGKangXi=0941.160, Def{raw, coarse, old, waste cotton or silk, wooly; fluffy}
4323 CJK UNIFIED IDEOGRAPH-#4323, IRGKangXi=0941.310, Def{to accumulate; to store up}
4324 CJK UNIFIED IDEOGRAPH-#4324, IRGKangXi=0942.010, Def{a kind of unrefined or unpolished silken textiles; silken goods; silken fabrics, to sew; to patch clothes (of sword)}
4325 CJK UNIFIED IDEOGRAPH-#4325, IRGKangXi=0942.030, Def{to sew clothes; to do needle-work}
4326 CJK UNIFIED IDEOGRAPH-#4326, IRGKangXi=0942.050, Def{green color; bluish yellow}
4327 CJK UNIFIED IDEOGRAPH-#4327, IRGKangXi=0942.110, Def{(non-classical form of 紬 綢) a kind of silk fabric; thin silk goods}
4328 CJK UNIFIED IDEOGRAPH-#4328, IRGKangXi=0942.280, Def{thin silk fabrics, sound of the rubbing of clothes}
4329 CJK UNIFIED IDEOGRAPH-#4329, IRGKangXi=0942.420, Def{fine, thin stockings or socks}
432A CJK UNIFIED IDEOGRAPH-#432A, IRGKangXi=0943.090, Def{to continue; to extend; to review}
432B CJK UNIFIED IDEOGRAPH-#432B, IRGKangXi=0943.100, Def{(non-classical form of U+7E9C 纜) a hawser, a cable, a rope}
432C CJK UNIFIED IDEOGRAPH-#432C, IRGKangXi=0943.130, Def{straight; right; just, straight-forward, uninterrupted}
432D CJK UNIFIED IDEOGRAPH-#432D, IRGKangXi=0943.190, Def{raw hemp, a kind of fabric}
432E CJK UNIFIED IDEOGRAPH-#432E, IRGKangXi=0943.330, Def{silk fabrics with the color of new leaves}
432F CJK UNIFIED IDEOGRAPH-#432F, IRGKangXi=0943.340, Def{a turban; a kerchief, children's hat, a girdle, belt of the clothes}
4330 CJK UNIFIED IDEOGRAPH-#4330, IRGKangXi=0944.010, Def{connected silk, measurement}
4331 CJK UNIFIED IDEOGRAPH-#4331, IRGKangXi=0944.030, Def{(same as 䌴) uneven; silk with knots}
4332 CJK UNIFIED IDEOGRAPH-#4332, IRGKangXi=0944.050, Def{(same as 纁) light red}
4333 CJK UNIFIED IDEOGRAPH-#4333, IRGKangXi=0944.120, Def{a kind of unrefined or unpolished silken textiles; silken goods; silken fabrics}
4334 CJK UNIFIED IDEOGRAPH-#4334, IRGKangXi=0944.150, Def{uneven; silk with knots; unpolished}
4335 CJK UNIFIED IDEOGRAPH-#4335, IRGKangXi=0944.190, Def{lapel and belt}
4336 CJK UNIFIED IDEOGRAPH-#4336, IRGKangXi=0944.251, Def{(simplified form of 䊷) (same as 緇)) black silk; a dark, drab colour, used for Buddhists, from the dark colour of their robes (same as 純) pure, honest}
4337 CJK UNIFIED IDEOGRAPH-#4337, IRGKangXi=0944.251, Def{(simplified form of 紬) a thread; a clue}
4338 CJK UNIFIED IDEOGRAPH-#4338, IRGKangXi=0944.251, Def{(simplified form of 縳) fine silk fabric of bright white colour, to tie up, (interchangeable 卷) a book or painting which can be easily folded or rolled up, a division of a book, files}
4339 CJK UNIFIED IDEOGRAPH-#4339, IRGKangXi=0944.251, Def{(simplified form of 絅) (same as 褧) a garment of one colour with no lining, a dust coat}
433A CJK UNIFIED IDEOGRAPH-#433A, IRGKangXi=0944.251, Def{(simplified form) (interchangeable 耳) flourishing; thriving; vigorous}
433B CJK UNIFIED IDEOGRAPH-#433B, IRGKangXi=0944.251, Def{(simplified form) (same as 翼) wings, fins, to help; to assist}
433C CJK UNIFIED IDEOGRAPH-#433C, IRGKangXi=0944.251, Def{a kind of fine silk fabric}
433D CJK UNIFIED IDEOGRAPH-#433D, IRGKangXi=0944.251, Def{varicolored silk; motley}
433E CJK UNIFIED IDEOGRAPH-#433E, IRGKangXi=0944.251, Def{(same as U+7D1D 紝) to lay the warp; to weave}
433F CJK UNIFIED IDEOGRAPH-#433F, IRGKangXi=0944.251, Def{(simplified form) (same as 幅) the breadth of cloth or paper; a piece (of cloth)}
4340 CJK UNIFIED IDEOGRAPH-#4340, IRGKangXi=0944.251, Def{(same as U+8964 襤) clothes without hem; ragged garments; sloppily dressed}
4341 CJK UNIFIED IDEOGRAPH-#4341, IRGKangXi=0944.251, Def{(simplified form of 繸) the hem or border of a garment, a tassel}
4342 CJK UNIFIED IDEOGRAPH-#4342, IRGKangXi=0944.290, Def{tools to draw water or liquid}
4343 CJK UNIFIED IDEOGRAPH-#4343, IRGKangXi=0945.030, Def{a vase, a pitcher, earthenware}
4344 CJK UNIFIED IDEOGRAPH-#4344, IRGKangXi=0945.070, Def{an indenture (of earthenware)}
4345 CJK UNIFIED IDEOGRAPH-#4345, IRGKangXi=0945.080, Def{containers for water or wine used in ancient times}
4346 CJK UNIFIED IDEOGRAPH-#4346, IRGKangXi=0945.090, Def{container for grains used in ancient times}
4347 CJK UNIFIED IDEOGRAPH-#4347, IRGKangXi=0945.100, RSKangXi=121.5, Def{flat-bottom crock (with narrow opening); jug, pitcher, vase, etc; (Cant.) stool}
4348 CJK UNIFIED IDEOGRAPH-#4348, IRGKangXi=0945.140, Def{(same as 缾 瓶) bottle; pitcher; jug; vase}
4349 CJK UNIFIED IDEOGRAPH-#4349, IRGKangXi=0945.150, Def{traces or marks of incomplete or damage}
434A CJK UNIFIED IDEOGRAPH-#434A, IRGKangXi=0945.180, Def{clay-made blowing wind instruments; music instruments made of clay}
434B CJK UNIFIED IDEOGRAPH-#434B, IRGKangXi=0945.330, Def{bottle; pitcher; jug; vase; an earthen jar with narrow opening}
434C CJK UNIFIED IDEOGRAPH-#434C, IRGKangXi=0945.350, Def{(same as 瓿) a jar; a pot}
434D CJK UNIFIED IDEOGRAPH-#434D, IRGKangXi=0945.420, Def{unburnt bricks; tiles; eathenware, etc.}
434E CJK UNIFIED IDEOGRAPH-#434E, IRGKangXi=0946.140, Def{a spindle, a earthenware used to pinch or knead, a small crock}
434F CJK UNIFIED IDEOGRAPH-#434F, IRGKangXi=0946.241
4350 CJK UNIFIED IDEOGRAPH-#4350, IRGKangXi=0946.340, Def{(standard form 罕) a net or snare, a flag, rare; strange; scarce; few, name of a place in ancient times}
4351 CJK UNIFIED IDEOGRAPH-#4351, IRGKangXi=0947.031, Def{(same as 䍐) (standard form 罕) a net or snare, a flag, rare; strange; scarce; few, name of a place in ancient times}
4352 CJK UNIFIED IDEOGRAPH-#4352, IRGKangXi=0947.040, Def{(corrupted form) net; web; network}
4353 CJK UNIFIED IDEOGRAPH-#4353, IRGKangXi=0947.060, Def{(a corrupted form) net for catching rabbit}
4354 CJK UNIFIED IDEOGRAPH-#4354, IRGKangXi=0947.090, Def{a full net, a thick rope; a cable}
4355 CJK UNIFIED IDEOGRAPH-#4355, IRGKangXi=0947.150, Def{net; web; network, net for catching rabbit}
4356 CJK UNIFIED IDEOGRAPH-#4356, IRGKangXi=0947.200, Def{(same as 罦) a kind of net in a trap used to catch birds and beasts; a covering for a cart}
4357 CJK UNIFIED IDEOGRAPH-#4357, IRGKangXi=0947.300, Def{(same as 罥) to hang up; to bind; to entangle, net; web; network}
4358 CJK UNIFIED IDEOGRAPH-#4358, IRGKangXi=0947.340, Def{a general term for nets}
4359 CJK UNIFIED IDEOGRAPH-#4359, IRGKangXi=0947.430, Def{nets for catching birds, net; web; network}
435A CJK UNIFIED IDEOGRAPH-#435A, IRGKangXi=0948.010, Def{vast}
435B CJK UNIFIED IDEOGRAPH-#435B, IRGKangXi=0948.070, Def{a kind of tool used to get fish}
435C CJK UNIFIED IDEOGRAPH-#435C, IRGKangXi=0948.110, Def{a basket or a cage used to keep wild and domestic fowls}
435D CJK UNIFIED IDEOGRAPH-#435D, IRGKangXi=0948.250, Def{net; web; network}
435E CJK UNIFIED IDEOGRAPH-#435E, IRGKangXi=0948.291, Def{(same as 罭) a drag-net; a fine net used to catch small fish}
435F CJK UNIFIED IDEOGRAPH-#435F, IRGKangXi=0948.350, Def{a kind of fish net with fine meshes}
4360 CJK UNIFIED IDEOGRAPH-#4360, IRGKangXi=0949.271, Def{(simplified form of 䍦) turban used in ancient times}
4361 CJK UNIFIED IDEOGRAPH-#4361, IRGKangXi=0949.220, Def{small fish net, to catch fish with small fish net}
4362 CJK UNIFIED IDEOGRAPH-#4362, IRGKangXi=0949.290, Def{netted veined window-sill}
4363 CJK UNIFIED IDEOGRAPH-#4363, IRGKangXi=0950.010, Def{a kind of fish net}
4364 CJK UNIFIED IDEOGRAPH-#4364, IRGKangXi=0950.060, Def{to strain out; to filter wine; to squeeze juice out of; to draw; to press milk}
4365 CJK UNIFIED IDEOGRAPH-#4365, IRGKangXi=0950.250, Def{smoky, covering; to spread, cloth for covering food}
4366 CJK UNIFIED IDEOGRAPH-#4366, IRGKangXi=0950.280, Def{(traditional form of 䍠) a kind of turban used in ancient times}
4367 CJK UNIFIED IDEOGRAPH-#4367, IRGKangXi=0951.200, Def{(same as 牂) a ewe or she-goat}
4368 CJK UNIFIED IDEOGRAPH-#4368, IRGKangXi=0951.210, Def{to castrate, a ram or he-goat, last name}
4369 CJK UNIFIED IDEOGRAPH-#4369, IRGKangXi=0951.320, Def{(ancient form of 養) to offer provision (esp. to one's elders); to feed one's children}
436A CJK UNIFIED IDEOGRAPH-#436A, IRGKangXi=0951.340, Def{castrated ram}
436B CJK UNIFIED IDEOGRAPH-#436B, IRGKangXi=0951.350, Def{a legendary goat-like animal with 4 ears and 9 tails, a kind of goat with no horn}
436C CJK UNIFIED IDEOGRAPH-#436C, IRGKangXi=0951.370, Def{to use; to made; to act, a kind of goat with mixed colors}
436D CJK UNIFIED IDEOGRAPH-#436D, IRGKangXi=0952.080, Def{(same as 牂) a ewe or she-goat}
436E CJK UNIFIED IDEOGRAPH-#436E, IRGKangXi=0952.100, Def{young goat (sheep) under one year old, castrated ram of hundred catties (Chinese pound)}
436F CJK UNIFIED IDEOGRAPH-#436F, IRGKangXi=0952.130, Def{(same as 觤) goat with asymmetric horns}
4370 CJK UNIFIED IDEOGRAPH-#4370, IRGKangXi=0952.150, Def{a plague or a pestilence of goat (sheep); black goat or sheep, black}
4371 CJK UNIFIED IDEOGRAPH-#4371, IRGKangXi=0953.020, Def{the wild goat or sheep}
4372 CJK UNIFIED IDEOGRAPH-#4372, IRGKangXi=0953.090, Def{a kind of sheep (goat) with curled hairs}
4373 CJK UNIFIED IDEOGRAPH-#4373, IRGKangXi=0953.110, Def{disease; illness, goat (or sheep) get sick, a throbbing goat (or sheep)}
4374 CJK UNIFIED IDEOGRAPH-#4374, IRGKangXi=0953.120, Def{to squeeze and to crowd against each other (of sheep)}
4375 CJK UNIFIED IDEOGRAPH-#4375, IRGKangXi=0953.150, Def{young goat, antelope}
4376 CJK UNIFIED IDEOGRAPH-#4376, IRGKangXi=0953.160, Def{unicorn}
4377 CJK UNIFIED IDEOGRAPH-#4377, IRGKangXi=0953.230, Def{to chase each other (of sheep or goats)}
4378 CJK UNIFIED IDEOGRAPH-#4378, IRGKangXi=0953.320, Def{a legendary goat-like animal with 4 ears and 9 tails}
4379 CJK UNIFIED IDEOGRAPH-#4379, IRGKangXi=0953.330, Def{(same as U+7FB4 羶) odor of a sheep or goat, flock of goats or sheep, name and description of snuff (a kind of tobacco)}
437A CJK UNIFIED IDEOGRAPH-#437A, IRGKangXi=0954.010, Def{a legendary goat-like beast}
437B CJK UNIFIED IDEOGRAPH-#437B, IRGKangXi=0954.070, Def{young goat of sheep under one year old}
437C CJK UNIFIED IDEOGRAPH-#437C, IRGKangXi=0954.150, Def{salted mutton, to store up the meat under the ground, a goat-like beast, odor of a sheep or goat}
437D CJK UNIFIED IDEOGRAPH-#437D, IRGKangXi=0954.360, Def{a fierce goat, a castrated ram}
437E CJK UNIFIED IDEOGRAPH-#437E, IRGKangXi=0955.160, Def{flying}
437F CJK UNIFIED IDEOGRAPH-#437F, IRGKangXi=0955.240, Def{a kind of dance accompanied by music performed in ancient times, (same as 凰) the female phoenix, a legendary bird in Chinese mythology}
4380 CJK UNIFIED IDEOGRAPH-#4380, IRGKangXi=0956.060, Def{flying, to run swiftly; to go at express speed}
4381 CJK UNIFIED IDEOGRAPH-#4381, IRGKangXi=0956.120, Def{used in person's name}
4382 CJK UNIFIED IDEOGRAPH-#4382, IRGKangXi=0956.130, Def{colorful feather, a feather decorated arrow}
4383 CJK UNIFIED IDEOGRAPH-#4383, IRGKangXi=0956.140, Def{fine down; floss; wool}
4384 CJK UNIFIED IDEOGRAPH-#4384, IRGKangXi=0956.170, Def{hairy; long tail feather of a bird}
4385 CJK UNIFIED IDEOGRAPH-#4385, IRGKangXi=0956.220, Def{flying}
4386 CJK UNIFIED IDEOGRAPH-#4386, IRGKangXi=0956.270, Def{flying}
4387 CJK UNIFIED IDEOGRAPH-#4387, IRGKangXi=0956.340, Def{quick; quickly, hasty, soft and meek feather}
4388 CJK UNIFIED IDEOGRAPH-#4388, IRGKangXi=0956.350, Def{flying}
4389 CJK UNIFIED IDEOGRAPH-#4389, IRGKangXi=0956.360, Def{to walk swiftly, (same as 矞) scared; afraid; fearful; frightened}
438A CJK UNIFIED IDEOGRAPH-#438A, IRGKangXi=0956.380, Def{flying, flying away}
438B CJK UNIFIED IDEOGRAPH-#438B, IRGKangXi=0957.100, Def{fly}
438C CJK UNIFIED IDEOGRAPH-#438C, IRGKangXi=0957.110, Def{feather, flying, neat feather}
438D CJK UNIFIED IDEOGRAPH-#438D, IRGKangXi=0957.140, Def{fine and soft hair, feather}
438E CJK UNIFIED IDEOGRAPH-#438E, IRGKangXi=0957.190, Def{to glide or to hover up in the air, to soaring}
438F CJK UNIFIED IDEOGRAPH-#438F, IRGKangXi=0957.230, Def{young birds flying}
4390 CJK UNIFIED IDEOGRAPH-#4390, IRGKangXi=0957.270, Def{hairy}
4391 CJK UNIFIED IDEOGRAPH-#4391, IRGKangXi=0957.280, Def{flying over the water surface, flying up; soaring}
4392 CJK UNIFIED IDEOGRAPH-#4392, IRGKangXi=0957.380, Def{flying quickly and to attack suddenly (said of bird)}
4393 CJK UNIFIED IDEOGRAPH-#4393, IRGKangXi=0958.041, Def{flying}
4394 CJK UNIFIED IDEOGRAPH-#4394, IRGKangXi=0958.360, Def{fine and soft hair, feather}
4395 CJK UNIFIED IDEOGRAPH-#4395, IRGKangXi=0958.400, Def{flying birds}
4396 CJK UNIFIED IDEOGRAPH-#4396, IRGKangXi=0959.220, Def{soaring up in the sky}
4397 CJK UNIFIED IDEOGRAPH-#4397, IRGKangXi=0959.300, Def{flying}
4398 CJK UNIFIED IDEOGRAPH-#4398, IRGKangXi=0959.330, Def{birds flying, sound of the flying wings}
4399 CJK UNIFIED IDEOGRAPH-#4399, IRGKangXi=0960.120, Def{flying}
439A CJK UNIFIED IDEOGRAPH-#439A, IRGKangXi=0960.170, Def{the end of bird wings, bird wings}
439B CJK UNIFIED IDEOGRAPH-#439B, IRGKangXi=0960.301
439C CJK UNIFIED IDEOGRAPH-#439C, IRGKangXi=0961.090, Def{aged; to get old, advanced age; great age; old age}
439D CJK UNIFIED IDEOGRAPH-#439D, IRGKangXi=0961.120, Def{(same as 翥) to soar}
439E CJK UNIFIED IDEOGRAPH-#439E, IRGKangXi=0961.131
439F CJK UNIFIED IDEOGRAPH-#439F, IRGKangXi=0961.230, Def{to fawn on; to flatter; to please, to love, attractive}
43A0 CJK UNIFIED IDEOGRAPH-#43A0, IRGKangXi=0962.030, Def{to twist or to crumple between hands and make something turn, (same as U+611E 懦) cowardice; timid; weak and cowardly}
43A1 CJK UNIFIED IDEOGRAPH-#43A1, IRGKangXi=0962.040, Def{to shrink; to recoil; to flinch, weak, soft and meek; gentle, (corrupted form of 耎) soft; weak, pliable}
43A2 CJK UNIFIED IDEOGRAPH-#43A2, IRGKangXi=0962.220, Def{to measure (esp. for grains) by pints and pecks}
43A3 CJK UNIFIED IDEOGRAPH-#43A3, IRGKangXi=0963.080, Def{(same as 耜) a plough; a ploughshare}
43A4 CJK UNIFIED IDEOGRAPH-#43A4, IRGKangXi=0963.170, Def{to till; to plough; to cultivate, agricultural implements; farm tools}
43A5 CJK UNIFIED IDEOGRAPH-#43A5, IRGKangXi=0963.191
43A6 CJK UNIFIED IDEOGRAPH-#43A6, IRGKangXi=0963.220, Def{to till; to plough, sharp-pointed spade or shovel}
43A7 CJK UNIFIED IDEOGRAPH-#43A7, IRGKangXi=0963.240, Def{agricultural implements; farm tools (a plough; a ploughshare), to till; to plough}
43A8 CJK UNIFIED IDEOGRAPH-#43A8, IRGKangXi=0963.280, Def{to plough and sow, to farm}
43A9 CJK UNIFIED IDEOGRAPH-#43A9, IRGKangXi=0963.300, Def{to till; to plough, (same as 菑) land under cultivation for one year, to weed grass}
43AA CJK UNIFIED IDEOGRAPH-#43AA, IRGKangXi=0963.330, Def{the stalk of grain; straw, a hammer used to pound grains and corns, etc.}
43AB CJK UNIFIED IDEOGRAPH-#43AB, IRGKangXi=0964.010, Def{to plant; to sow; to cultivate}
43AC CJK UNIFIED IDEOGRAPH-#43AC, IRGKangXi=0964.161, Def{(simplified form of 䎱) (same as 耙) a drag; a harrow; a rake}
43AD CJK UNIFIED IDEOGRAPH-#43AD, IRGKangXi=0964.241, Def{a kind of farm tool made of twisted thron strips used to flaten the land}
43AE CJK UNIFIED IDEOGRAPH-#43AE, IRGKangXi=0964.180, Def{to plant; to raise or grow (plants); to cultivate}
43AF CJK UNIFIED IDEOGRAPH-#43AF, IRGKangXi=0964.190, Def{winter ploughing, to plough a dry farmland (upland), to till; to plough}
43B0 CJK UNIFIED IDEOGRAPH-#43B0, IRGKangXi=0964.290, Def{name of a place in Sichuan Province}
43B1 CJK UNIFIED IDEOGRAPH-#43B1, IRGKangXi=0964.380, Def{(same as 耙) a drag; a harrow; a rake}
43B2 CJK UNIFIED IDEOGRAPH-#43B2, IRGKangXi=0965.071, Def{ear lobe; lobule}
43B3 CJK UNIFIED IDEOGRAPH-#43B3, IRGKangXi=0965.170, Def{lose of the ear}
43B4 CJK UNIFIED IDEOGRAPH-#43B4, IRGKangXi=0966.030, Def{a legendary spirit; immortal, (non-classical form of 聖) sage, sacred; holy}
43B5 CJK UNIFIED IDEOGRAPH-#43B5, IRGKangXi=0966.220, Def{(corrupted form) to look straight forward, ashamed, to look in a mean way}
43B6 CJK UNIFIED IDEOGRAPH-#43B6, IRGKangXi=0967.030, Def{offering blood to God}
43B7 CJK UNIFIED IDEOGRAPH-#43B7, IRGKangXi=0967.160, Def{an old man with white hair, source; head (of a stream), loud cries}
43B8 CJK UNIFIED IDEOGRAPH-#43B8, IRGKangXi=0967.180, Def{to hear; to listen; to obey; to understand}
43B9 CJK UNIFIED IDEOGRAPH-#43B9, IRGKangXi=0967.300, Def{(ancient form of 聞) to hear, to learn, to convey, to smell}
43BA CJK UNIFIED IDEOGRAPH-#43BA, IRGKangXi=0967.370, Def{to learn; to hear; (Cant.) to work; to be willing}
43BB CJK UNIFIED IDEOGRAPH-#43BB, IRGKangXi=0968.050, Def{to hear, clear, bright, ears}
43BC CJK UNIFIED IDEOGRAPH-#43BC, IRGKangXi=0968.060, Def{a kind of insect}
43BD CJK UNIFIED IDEOGRAPH-#43BD, IRGKangXi=0968.090, Def{(ancient form of 聞) to hear, to learn, to convey, to smell, to hear of}
43BE CJK UNIFIED IDEOGRAPH-#43BE, IRGKangXi=0968.221, Def{(corrupted form of 睔) big and round eyes}
43BF CJK UNIFIED IDEOGRAPH-#43BF, IRGKangXi=0968.240, Def{buzzing in the ears; tinnitus aurium}
43C0 CJK UNIFIED IDEOGRAPH-#43C0, IRGKangXi=0968.370, Def{inharmonious}
43C1 CJK UNIFIED IDEOGRAPH-#43C1, IRGKangXi=0968.420, Def{unable to hear distinctly or clearly}
43C2 CJK UNIFIED IDEOGRAPH-#43C2, IRGKangXi=0968.430, Def{clever, quick of apprehension, with a good faculty of hearing}
43C3 CJK UNIFIED IDEOGRAPH-#43C3, IRGKangXi=0968.440, Def{to hear, to listen carefully}
43C4 CJK UNIFIED IDEOGRAPH-#43C4, IRGKangXi=0969.090, Def{not to listen, disease of the ears, a dull sense of hearing (inefficacious; unresponsive)}
43C5 CJK UNIFIED IDEOGRAPH-#43C5, IRGKangXi=0969.130, Def{to hear; to listen, a keen sense of hearing}
43C6 CJK UNIFIED IDEOGRAPH-#43C6, IRGKangXi=0969.160, Def{buzzing in the ears; tinnitus aurium}
43C7 CJK UNIFIED IDEOGRAPH-#43C7, IRGKangXi=0969.210, Def{to hear; barely enough to hear clearly, hearsay; groundless talk}
43C8 CJK UNIFIED IDEOGRAPH-#43C8, IRGKangXi=0970.080, Def{(standard form of 聯) to unite; to connect; to join together (same as 攣) tangled; to bind; entwined}
43C9 CJK UNIFIED IDEOGRAPH-#43C9, IRGKangXi=0970.210, Def{to waver; to shake ears (said of cattle and horses)}
43CA CJK UNIFIED IDEOGRAPH-#43CA, IRGKangXi=0970.270, Def{(same as 聾) deaf; hard of hearing}
43CB CJK UNIFIED IDEOGRAPH-#43CB, IRGKangXi=0972.010, Def{(ancient form of 肅) respectful; solemn; serious; majestic, neat and quite}
43CC CJK UNIFIED IDEOGRAPH-#43CC, IRGKangXi=0973.100, Def{to vibrate; vibration, (same as 佾) a row or file of dancers, esp. referring to those in ancient dances at sacrifices or other rites}
43CD CJK UNIFIED IDEOGRAPH-#43CD, IRGKangXi=0973.150, Def{(same as 肙 蜎) a small worm; larvae of mosquitoes, empty, to twist; to surround}
43CE CJK UNIFIED IDEOGRAPH-#43CE, IRGKangXi=0973.160, Def{milk; breasts, the young of animals, birds}
43CF CJK UNIFIED IDEOGRAPH-#43CF, IRGKangXi=0974.130, Def{(same as 吁) signs and groans; moan, name of a county}
43D0 CJK UNIFIED IDEOGRAPH-#43D0, IRGKangXi=0974.140, Def{the buttocks, the anus}
43D1 CJK UNIFIED IDEOGRAPH-#43D1, IRGKangXi=0974.150, Def{(same as U+7099 炙) to burn; to heat; to roast; to broil}
43D2 CJK UNIFIED IDEOGRAPH-#43D2, IRGKangXi=0974.160, Def{half of the body, (non-classical form of 胖) fat; obese}
43D3 CJK UNIFIED IDEOGRAPH-#43D3, IRGKangXi=0974.190, Def{(same as 脘) the stomach; gizzard (of birds and fowls)}
43D4 CJK UNIFIED IDEOGRAPH-#43D4, IRGKangXi=0975.030, Def{to eat meat, (same as 肘) the elbow, (same as 腬) fine quality of meat, (same as 衄) nose bleeding}
43D5 CJK UNIFIED IDEOGRAPH-#43D5, IRGKangXi=0975.040, Def{(ancient form of 飪) to cook food thoroughly}
43D6 CJK UNIFIED IDEOGRAPH-#43D6, IRGKangXi=0975.110, Def{a wound; a bruise; a sore, scar, muscles of the back}
43D7 CJK UNIFIED IDEOGRAPH-#43D7, IRGKangXi=0976.120, Def{unexpectedly; suddenly aching of the midriff or waist; lumbago}
43D8 CJK UNIFIED IDEOGRAPH-#43D8, IRGKangXi=0976.130, Def{a big abdomen, a female animal with a fat belly}
43D9 CJK UNIFIED IDEOGRAPH-#43D9, IRGKangXi=0976.170, Def{(same as U+9193 醓) brine from pickled meat; condiments, juicy meat pulp; mashed meat cooked with soybean sauce, short and ugly, light of the setting moon; (Cant.) 肚䏙 stomach}
43DA CJK UNIFIED IDEOGRAPH-#43DA, IRGKangXi=0976.250, Def{small, missing; wanting; lost, the floating ribs on the sides of the trunk}
43DB CJK UNIFIED IDEOGRAPH-#43DB, IRGKangXi=0977.041, Def{(a corrupted form) a kind of insects; earthworm, strips of meat cut from the flank and dried in the wind}
43DC CJK UNIFIED IDEOGRAPH-#43DC, IRGKangXi=0977.041, Def{fat; plump; obesity; obese}
43DD CJK UNIFIED IDEOGRAPH-#43DD, IRGKangXi=0977.041, Def{(simplified form of 膞) sincere; earnest, a part of offering in sacrifice, gizzard of a fowl, chopped meat, small pig, the kneecap; patella, bone of one's limbs}
43DE CJK UNIFIED IDEOGRAPH-#43DE, IRGKangXi=0977.090, Def{the belly; the abdomen}
43DF CJK UNIFIED IDEOGRAPH-#43DF, IRGKangXi=0977.130, Def{fat meat, big; large}
43E0 CJK UNIFIED IDEOGRAPH-#43E0, IRGKangXi=0977.220, Def{(ancient form of 汁) meat soup, mixed meat}
43E1 CJK UNIFIED IDEOGRAPH-#43E1, IRGKangXi=0978.050, Def{uncooked or raw meat, an organic compound; Proteose}
43E2 CJK UNIFIED IDEOGRAPH-#43E2, IRGKangXi=0978.150, Def{meat, rough; cracked skin}
43E3 CJK UNIFIED IDEOGRAPH-#43E3, IRGKangXi=0979.040, Def{(same as non-classical form 蛆) maggot}
43E4 CJK UNIFIED IDEOGRAPH-#43E4, IRGKangXi=0979.060, Def{(same as U+9856 囟) top of the human head; the skull}
43E5 CJK UNIFIED IDEOGRAPH-#43E5, IRGKangXi=0980.080, Def{dry, dandruff-like scales of dead flesh and skin}
43E6 CJK UNIFIED IDEOGRAPH-#43E6, IRGKangXi=0980.160, Def{fat of animals or plants, (same as 胋) fat; plump, fertile, animal fat}
43E7 CJK UNIFIED IDEOGRAPH-#43E7, IRGKangXi=0980.180, Def{fatty; greasy, not thick; not tight, plump and pretty of the flesh}
43E8 CJK UNIFIED IDEOGRAPH-#43E8, IRGKangXi=0981.060, Def{to swell up greatly, to swell; a swelling; a boil}
43E9 CJK UNIFIED IDEOGRAPH-#43E9, IRGKangXi=0981.080, Def{(same as 脅) to shrug the shoulders, the ribs}
43EA CJK UNIFIED IDEOGRAPH-#43EA, IRGKangXi=0982.090, Def{tendon (of meat animals); sinews; muscles}
43EB CJK UNIFIED IDEOGRAPH-#43EB, IRGKangXi=0982.120, Def{in between of the abdomen and the spine; the spinal column}
43EC CJK UNIFIED IDEOGRAPH-#43EC, IRGKangXi=0981.110, Def{the spine; the spinal column, the ridge}
43ED CJK UNIFIED IDEOGRAPH-#43ED, IRGKangXi=0982.171, Def{the cheeks; the jaw}
43EE CJK UNIFIED IDEOGRAPH-#43EE, IRGKangXi=0982.171, Def{(abbreviated form of 脇=脅) the sides of the trunk from armpits to ribs; the flank}
43EF CJK UNIFIED IDEOGRAPH-#43EF, IRGKangXi=0983.070, Def{(same as 痣) moles; birthmarks}
43F0 CJK UNIFIED IDEOGRAPH-#43F0, IRGKangXi=0983.110, Def{a kind of insects; earthworm, durable; strong and soft; pliable yet tough}
43F1 CJK UNIFIED IDEOGRAPH-#43F1, IRGKangXi=0983.120, Def{body, fat; plump}
43F2 CJK UNIFIED IDEOGRAPH-#43F2, IRGKangXi=0983.160, Def{(same as 胅) protruded bones, swelling, a crooked nose}
43F3 CJK UNIFIED IDEOGRAPH-#43F3, IRGKangXi=0983.170, Def{(in chemistry) olein, oil and grease; fats (esp. animal), the ribs and skin}
43F4 CJK UNIFIED IDEOGRAPH-#43F4, IRGKangXi=0983.180, Def{dim; ambiguous; unclear eyesight, sharp ends of something}
43F5 CJK UNIFIED IDEOGRAPH-#43F5, IRGKangXi=0983.190, Def{plump, rich and full, plentiful, swelling, a plump trunk (body)}
43F6 CJK UNIFIED IDEOGRAPH-#43F6, IRGKangXi=0983.210, Def{the stomach; gizzard (of birds and fowls), (same as 髀) buttocks, thigh}
43F7 CJK UNIFIED IDEOGRAPH-#43F7, IRGKangXi=0984.030, Def{medicine for a sore; a boil (injure by a sword or a knief)}
43F8 CJK UNIFIED IDEOGRAPH-#43F8, IRGKangXi=0985.111, Def{fish, eyes of the fishes}
43F9 CJK UNIFIED IDEOGRAPH-#43F9, IRGKangXi=0985.111, Def{to watch stealthily}
43FA CJK UNIFIED IDEOGRAPH-#43FA, IRGKangXi=0985.111, Def{to swell; swelling}
43FB CJK UNIFIED IDEOGRAPH-#43FB, IRGKangXi=0985.111, Def{(same as 能) can; to be able to, capability; talent, energy}
43FC CJK UNIFIED IDEOGRAPH-#43FC, IRGKangXi=0985.150, Def{what is left over of the food (of birds and animals), a big belly}
43FD CJK UNIFIED IDEOGRAPH-#43FD, IRGKangXi=0985.180, Def{meat pulp; mashed meat cooked with soybean sauce, last name}
43FE CJK UNIFIED IDEOGRAPH-#43FE, IRGKangXi=0985.210, Def{(non-classical form of U+43FA 䏺) to swell; swelling}
43FF CJK UNIFIED IDEOGRAPH-#43FF, IRGKangXi=0985.260, Def{the calf of the legs}
4400 CJK UNIFIED IDEOGRAPH-#4400, IRGKangXi=0986.010, Def{to dismember body of the livestock}
4401 CJK UNIFIED IDEOGRAPH-#4401, IRGKangXi=0986.070, Def{the buttocks; the rump, fat; plump, one of the seven constellations; name of a star, the anus}
4402 CJK UNIFIED IDEOGRAPH-#4402, IRGKangXi=0986.100, Def{fat of animals or plants, fat; plump; obese}
4403 CJK UNIFIED IDEOGRAPH-#4403, IRGKangXi=0986.200, Def{fat in the abdomen or intestine, protuberances of the muscle, a fetus inside the belly}
4404 CJK UNIFIED IDEOGRAPH-#4404, IRGKangXi=0986.210, Def{hunger for meat, to cook meat}
4405 CJK UNIFIED IDEOGRAPH-#4405, IRGKangXi=0986.230, Def{the buttocks; the bottom; the rump, to groan; to moan}
4406 CJK UNIFIED IDEOGRAPH-#4406, IRGKangXi=0986.240, Def{big belly, swollen of the belly}
4407 CJK UNIFIED IDEOGRAPH-#4407, IRGKangXi=0986.260, Def{clear; bright, (same as 吻) to agree; match, (same as 唇) the lips; the labia}
4408 CJK UNIFIED IDEOGRAPH-#4408, IRGKangXi=0986.300, Def{a piece of one foot two inches dried seasoned meat, to paste up; to attach to; to stick up; to glue, (same as 殖) rotten fat; grease, lard, etc., bowels, fat}
4409 CJK UNIFIED IDEOGRAPH-#4409, IRGKangXi=0987.080, Def{fat, (interchangeable 腦) the head}
440A CJK UNIFIED IDEOGRAPH-#440A, IRGKangXi=0987.140, Def{(same as 䖵) insects, (same as 餛) cakes; biscuits; pastry, an ellipse}
440B CJK UNIFIED IDEOGRAPH-#440B, IRGKangXi=0987.210, Def{sick; illness; disease, red}
440C CJK UNIFIED IDEOGRAPH-#440C, IRGKangXi=0986.170, Def{(ancient form of 腆) luxuriant; abundant; rich; plentiful of food, brazen-faced; shameless, good; virtuous, protruding, as belly, etc., to go to excess}
440D CJK UNIFIED IDEOGRAPH-#440D, IRGKangXi=0988.040, Def{(same as 䐢) excellent food; delicacies, to wrinkle; to contract, beautiful; elegant, dried and seasoned meat}
440E CJK UNIFIED IDEOGRAPH-#440E, IRGKangXi=0988.080, Def{fat; greasy}
440F CJK UNIFIED IDEOGRAPH-#440F, IRGKangXi=0988.130, Def{fat; plump}
4410 CJK UNIFIED IDEOGRAPH-#4410, IRGKangXi=0988.150, Def{curved part of the knee, between the thigh and calf}
4411 CJK UNIFIED IDEOGRAPH-#4411, IRGKangXi=0988.190, Def{thin cut of the sliced meat}
4412 CJK UNIFIED IDEOGRAPH-#4412, IRGKangXi=0988.270, Def{not fine; coarse, to stickup; to paste up; to attach to; to glue, scar}
4413 CJK UNIFIED IDEOGRAPH-#4413, IRGKangXi=0988.280, Def{soft, (same as U+811C 脜) gentle; mild; temperate facial expression}
4414 CJK UNIFIED IDEOGRAPH-#4414, IRGKangXi=0988.290, Def{muscle of the calf (of the leg), tendon (of meat animals), stopping and rising of the pulse like a plaited ropes}
4415 CJK UNIFIED IDEOGRAPH-#4415, IRGKangXi=0989.090, Def{oil and grease; fats, the bursting of a wound}
4416 CJK UNIFIED IDEOGRAPH-#4416, IRGKangXi=0989.190, Def{(same as 㕧) to laugh heartily; to roar with laughter; to groan; to moan}
4417 CJK UNIFIED IDEOGRAPH-#4417, IRGKangXi=0989.220, Def{(same as 豬) a pig, (same as 肚) the belly; the abdomen}
4418 CJK UNIFIED IDEOGRAPH-#4418, IRGKangXi=0989.230, Def{to laugh heartily; to roar with laughter, tongue of the cow}
4419 CJK UNIFIED IDEOGRAPH-#4419, IRGKangXi=0989.240, Def{(same as 膈) the diaphragm}
441A CJK UNIFIED IDEOGRAPH-#441A, IRGKangXi=0990.120, Def{good graces; great favors, luster}
441B CJK UNIFIED IDEOGRAPH-#441B, IRGKangXi=0990.131, Def{to loosen; to widen skin}
441C CJK UNIFIED IDEOGRAPH-#441C, IRGKangXi=0990.170, Def{a swollen belly; dropsical, edematous; to swell; inflated}
441D CJK UNIFIED IDEOGRAPH-#441D, IRGKangXi=0990.180, Def{thick; heavy fat of animals or plants}
441E CJK UNIFIED IDEOGRAPH-#441E, IRGKangXi=0990.190, Def{the thin membrane between skin and flesh that protects internal organs or tissues in the human body, weak; fragile; delicate, flesh, meat}
441F CJK UNIFIED IDEOGRAPH-#441F, IRGKangXi=0990.240, Def{fat; plump, bent; curved feet}
4420 CJK UNIFIED IDEOGRAPH-#4420, IRGKangXi=0990.260, Def{between the flesh, name of state in southern China (of minority group), dim moon}
4421 CJK UNIFIED IDEOGRAPH-#4421, IRGKangXi=0990.270, Def{(same as 臍) the navel; the umbilicus, the underside of a crab}
4422 CJK UNIFIED IDEOGRAPH-#4422, IRGKangXi=0990.290, Def{to wrinkle; to contract, beautiful; elegant, dried and seasoned meat, excellent food; delicacies}
4423 CJK UNIFIED IDEOGRAPH-#4423, IRGKangXi=0990.340, Def{soup made of cut meat mixed with blood}
4424 CJK UNIFIED IDEOGRAPH-#4424, IRGKangXi=0991.010, Def{dried and seasoned meat, sound of the abdomen}
4425 CJK UNIFIED IDEOGRAPH-#4425, IRGKangXi=0991.060, Def{stinky; offensive-smelling; odorous, fat; plump}
4426 CJK UNIFIED IDEOGRAPH-#4426, IRGKangXi=0991.070, Def{sleepy}
4427 CJK UNIFIED IDEOGRAPH-#4427, IRGKangXi=0991.090, Def{(same as 犒) to reward or cheer troops with food, money, gifts, etc., (same as 臛) meat broth}
4428 CJK UNIFIED IDEOGRAPH-#4428, IRGKangXi=0991.210, Def{back of the foot, the back feet of the animal, covering; shell, to strike; heat from the top}
4429 CJK UNIFIED IDEOGRAPH-#4429, IRGKangXi=0991.260, Def{fat; plump, the fetus of livestock, delicious meat}
442A CJK UNIFIED IDEOGRAPH-#442A, IRGKangXi=0992.071, Def{(same as standard form 臇) fat; rich, a stew of fish}
442B CJK UNIFIED IDEOGRAPH-#442B, IRGKangXi=0992.120, Def{obesity, fat; plump}
442C CJK UNIFIED IDEOGRAPH-#442C, IRGKangXi=0992.130, Def{crisp, brittle, light, sound from the abdomen}
442D CJK UNIFIED IDEOGRAPH-#442D, IRGKangXi=0992.140, Def{a discharge or flux, diarrhoea and dysentery}
442E CJK UNIFIED IDEOGRAPH-#442E, IRGKangXi=0992.160, Def{skin}
442F CJK UNIFIED IDEOGRAPH-#442F, IRGKangXi=0992.210, Def{ugly appearance of a person, dry meat; preserved meat}
4430 CJK UNIFIED IDEOGRAPH-#4430, IRGKangXi=0992.220, Def{(same as U+7F9E 羞) to offer food as tribute; delicacies, savoury food}
4431 CJK UNIFIED IDEOGRAPH-#4431, IRGKangXi=0992.310, Def{to pick the meat in between of bones}
4432 CJK UNIFIED IDEOGRAPH-#4432, IRGKangXi=0992.320, Def{half-raw meat; not well cooked meat, the light or grow of fire, raw meat, offensve smell, especially of fish or blood, thin sliced meat}
4433 CJK UNIFIED IDEOGRAPH-#4433, IRGKangXi=0993.050, Def{(same as 魚) fish}
4434 CJK UNIFIED IDEOGRAPH-#4434, IRGKangXi=0993.120, Def{lumbago}
4435 CJK UNIFIED IDEOGRAPH-#4435, IRGKangXi=0994.120, Def{fat; obese, swelling}
4436 CJK UNIFIED IDEOGRAPH-#4436, IRGKangXi=0994.160, Def{to cook; to boil; to decoct, diseases of the lips; hare-lip, pieces of meat}
4437 CJK UNIFIED IDEOGRAPH-#4437, IRGKangXi=0994.200, Def{paunchy; a large belly}
4438 CJK UNIFIED IDEOGRAPH-#4438, IRGKangXi=0994.240, Def{(non-classical form of 膕) the back of the knee, crooked feet}
4439 CJK UNIFIED IDEOGRAPH-#4439, IRGKangXi=0994.270, Def{preserved and dried meat, (a dialect) fried; cooked small pieces of meat, meat broth}
443A CJK UNIFIED IDEOGRAPH-#443A, IRGKangXi=0994.310, Def{delicious; tasty food, (same as U+91B0 醰) of a fine flavour}
443B CJK UNIFIED IDEOGRAPH-#443B, IRGKangXi=0994.320, Def{big pieces of dried meat}
443C CJK UNIFIED IDEOGRAPH-#443C, IRGKangXi=0995.070, Def{thin membrane of the throat; bullet}
443D CJK UNIFIED IDEOGRAPH-#443D, IRGKangXi=0993.201
443E CJK UNIFIED IDEOGRAPH-#443E, IRGKangXi=0995.120, Def{fat; plump}
443F CJK UNIFIED IDEOGRAPH-#443F, IRGKangXi=0995.210, Def{gizzard, to store up meat, the five lowest pieces of bone of the spinal column}
4440 CJK UNIFIED IDEOGRAPH-#4440, IRGKangXi=0996.100, Def{the navel, the bowels; the entrails; the viscera, (same as 癖) chronic swelling of the spleen}
4441 CJK UNIFIED IDEOGRAPH-#4441, IRGKangXi=0996.200, Def{fatty; greasy, ointment}
4442 CJK UNIFIED IDEOGRAPH-#4442, IRGKangXi=0996.310, Def{fat; plump}
4443 CJK UNIFIED IDEOGRAPH-#4443, IRGKangXi=0997.080, Def{dim moon, dark; obscure, stupid; ignorant, to cheat; to hide the truth, to cover up; to hide, plump; fleshy}
4444 CJK UNIFIED IDEOGRAPH-#4444, IRGKangXi=0997.090, Def{rich; abundant; big and strong; vigorous, husky, (same as 瘜) (nasal) polypus}
4445 CJK UNIFIED IDEOGRAPH-#4445, IRGKangXi=0997.161, Def{(non-classical form) dizzy and sleepy; slumberous}
4446 CJK UNIFIED IDEOGRAPH-#4446, IRGKangXi=0997.220, Def{feel like vomiting}
4447 CJK UNIFIED IDEOGRAPH-#4447, IRGKangXi=0997.280, Def{medicine for a sore; a boil (injure by a sword or a knief)}
4448 CJK UNIFIED IDEOGRAPH-#4448, IRGKangXi=0997.290, Def{meat to offer for worship}
4449 CJK UNIFIED IDEOGRAPH-#4449, IRGKangXi=0998.040, Def{excrement, shit; night soil}
444A CJK UNIFIED IDEOGRAPH-#444A, IRGKangXi=0998.090, Def{fat; plump, physical disease; carnal}
444B CJK UNIFIED IDEOGRAPH-#444B, IRGKangXi=0998.160, Def{fat; obese}
444C CJK UNIFIED IDEOGRAPH-#444C, IRGKangXi=0998.170, Def{what is left over of the food (of birds and animals); (same as 爛) overripe; rotten, cooked soft; well cooked}
444D CJK UNIFIED IDEOGRAPH-#444D, IRGKangXi=0998.180, Def{(same as 咽) to swallow; the throat, (same as 癭) a reddish swelling on the neck, gnarl}
444E CJK UNIFIED IDEOGRAPH-#444E, IRGKangXi=0998.190, Def{soup of pig's intestines, meat soup; meat broth}
444F CJK UNIFIED IDEOGRAPH-#444F, IRGKangXi=0998.280, Def{ugly, a legendary animal}
4450 CJK UNIFIED IDEOGRAPH-#4450, IRGKangXi=0999.200, Def{bright; light, clear, (same as 瞇) to close the eyes; to narrow the eyes}
4451 CJK UNIFIED IDEOGRAPH-#4451, IRGKangXi=1000.020, Def{(ancient form of 僕) a servant, a modest term referring to oneself}
4452 CJK UNIFIED IDEOGRAPH-#4452, IRGKangXi=1001.191, Def{a kind of farm tool used in ancient times}
4453 CJK UNIFIED IDEOGRAPH-#4453, IRGKangXi=1002.030, Def{(same as 臺) a lookout, a tower, a terrace, a platform, a stage}
4454 CJK UNIFIED IDEOGRAPH-#4454, IRGKangXi=1003.100, Def{to pound (grain) in order to remove the husk}
4455 CJK UNIFIED IDEOGRAPH-#4455, IRGKangXi=1004.041, Def{(a non-classical abbreviated form of 鼠) a rat, a mouse, squirrels, moles, etc., KangXi radical 208}
4456 CJK UNIFIED IDEOGRAPH-#4456, IRGKangXi=1005.021
4457 CJK UNIFIED IDEOGRAPH-#4457, IRGKangXi=1005.030, Def{to pound (grain) in order to remove the husk}
4458 CJK UNIFIED IDEOGRAPH-#4458, IRGKangXi=1005.100, Def{to pound; to ram down, to polish; to grind barley or wheat}
4459 CJK UNIFIED IDEOGRAPH-#4459, IRGKangXi=1007.070, Def{put out the tongue; (same as U+3401 㐁) to lick; to taste}
445A CJK UNIFIED IDEOGRAPH-#445A, IRGKangXi=1007.071, Def{(non-classical form of 甜) sweet; agreeable; pleasant}
445B CJK UNIFIED IDEOGRAPH-#445B, IRGKangXi=1007.081, Def{(standard form of 舐) to lick}
445C CJK UNIFIED IDEOGRAPH-#445C, IRGKangXi=1007.220, Def{to eat heavily, cooked rice, a meal, to drink, to swallow, to lick, the uvula, the ligule}
445D CJK UNIFIED IDEOGRAPH-#445D, IRGKangXi=1008.180, Def{(non-classical form of 斝) a small cup with ears, used in ancient times for libations}
445E CJK UNIFIED IDEOGRAPH-#445E, IRGKangXi=1008.190, Def{(same as 舜) Shun, name of a legendary Chinese ruler, said to have ruled from 2255-2205 B.C., wise; good}
445F CJK UNIFIED IDEOGRAPH-#445F, IRGKangXi=1008.210, Def{(same as 葟) luxuriant; exuberant; flourishing (said of grass and tress; vegetation; flora)}
4460 CJK UNIFIED IDEOGRAPH-#4460, IRGKangXi=1009.050, Def{long and narrow boat, a small boat}
4461 CJK UNIFIED IDEOGRAPH-#4461, IRGKangXi=1009.060, Def{(same as 艖) small boat (short and deep)}
4462 CJK UNIFIED IDEOGRAPH-#4462, IRGKangXi=1009.070, Def{(non-classical form) (same as 舠) a knife shaped small boat}
4463 CJK UNIFIED IDEOGRAPH-#4463, IRGKangXi=1009.090, Def{a sailing boat}
4464 CJK UNIFIED IDEOGRAPH-#4464, IRGKangXi=1009.210, Def{a boat; a ship; vessel}
4465 CJK UNIFIED IDEOGRAPH-#4465, IRGKangXi=1009.220, Def{a moving boat; a sailing boat, tools used on a boat, a speedy boat}
4466 CJK UNIFIED IDEOGRAPH-#4466, IRGKangXi=1010.040, Def{a boat; a ship; vessel}
4467 CJK UNIFIED IDEOGRAPH-#4467, IRGKangXi=1010.050, Def{a short, deep and small boat}
4468 CJK UNIFIED IDEOGRAPH-#4468, IRGKangXi=1010.110, Def{(same as 舵) rudder; helm}
4469 CJK UNIFIED IDEOGRAPH-#4469, IRGKangXi=1010.221, Def{a kind of inland rivers warship used in Qing Dynasty}
446A CJK UNIFIED IDEOGRAPH-#446A, IRGKangXi=1010.280, Def{a sailing; moving boat}
446B CJK UNIFIED IDEOGRAPH-#446B, IRGKangXi=1010.290, Def{tools for boat, name of a boat}
446C CJK UNIFIED IDEOGRAPH-#446C, IRGKangXi=1010.340, Def{boat, large boat, to dispel; to remove; to move, to stir up}
446D CJK UNIFIED IDEOGRAPH-#446D, IRGKangXi=1010.351, Def{war vessel; man-of-war; warship}
446E CJK UNIFIED IDEOGRAPH-#446E, IRGKangXi=1010.351
446F CJK UNIFIED IDEOGRAPH-#446F, IRGKangXi=1011.040, Def{a boat; a ship; vessel}
4470 CJK UNIFIED IDEOGRAPH-#4470, IRGKangXi=1011.100, Def{small boat}
4471 CJK UNIFIED IDEOGRAPH-#4471, IRGKangXi=1011.140, Def{a boat; a ship; vessel}
4472 CJK UNIFIED IDEOGRAPH-#4472, IRGKangXi=1011.160, Def{(same as 棹 櫂) to row a boat, an oar, a scull, a boat}
4473 CJK UNIFIED IDEOGRAPH-#4473, IRGKangXi=1011.190, Def{a horizontal bar in front of a boat, a boat}
4474 CJK UNIFIED IDEOGRAPH-#4474, IRGKangXi=1011.200, Def{a boat; a ship; vessel}
4475 CJK UNIFIED IDEOGRAPH-#4475, IRGKangXi=1011.210, Def{(corrupted form of 艒) a small boat}
4476 CJK UNIFIED IDEOGRAPH-#4476, IRGKangXi=1011.250, Def{sprightly boat; light boat}
4477 CJK UNIFIED IDEOGRAPH-#4477, IRGKangXi=1011.271
4478 CJK UNIFIED IDEOGRAPH-#4478, IRGKangXi=1011.271, Def{a group of boats, boat; warship}
4479 CJK UNIFIED IDEOGRAPH-#4479, IRGKangXi=1011.360, Def{(same as 艘) a numerary adjunct for ships, groove of a boat}
447A CJK UNIFIED IDEOGRAPH-#447A, IRGKangXi=1011.400, Def{(same as 帆) a sail (of a boat)}
447B CJK UNIFIED IDEOGRAPH-#447B, IRGKangXi=1011.410, Def{covering; curtain, or screen of a boat, to sail a boat}
447C CJK UNIFIED IDEOGRAPH-#447C, IRGKangXi=1012.040, Def{ocean-going liner, steamer, a boat; a ship; vessel}
447D CJK UNIFIED IDEOGRAPH-#447D, IRGKangXi=1012.100, Def{a large boat}
447E CJK UNIFIED IDEOGRAPH-#447E, IRGKangXi=1012.131
447F CJK UNIFIED IDEOGRAPH-#447F, IRGKangXi=1012.140, Def{small boat}
4480 CJK UNIFIED IDEOGRAPH-#4480, IRGKangXi=1012.150, Def{short and deep boat}
4481 CJK UNIFIED IDEOGRAPH-#4481, IRGKangXi=1012.180, Def{a small boat connected to the back of a big boat; used to load the passengers, cargo or goods, warship, a kind of tools used to capsize}
4482 CJK UNIFIED IDEOGRAPH-#4482, IRGKangXi=1012.210, Def{an oar}
4483 CJK UNIFIED IDEOGRAPH-#4483, IRGKangXi=1012.230, Def{(same as U+8241 造) to build; to make; to do, to arrive at; to go to}
4484 CJK UNIFIED IDEOGRAPH-#4484, IRGKangXi=1012.280, Def{fully laden of a boat, name of a ship}
4485 CJK UNIFIED IDEOGRAPH-#4485, IRGKangXi=0817.130, Def{beautiful eyes, (dialect) a pair; two}
4486 CJK UNIFIED IDEOGRAPH-#4486, IRGKangXi=1012.400, Def{name of a ship, a sailing boat}
4487 CJK UNIFIED IDEOGRAPH-#4487, IRGKangXi=1012.441, Def{name of a ship, fully load of a boat}
4488 CJK UNIFIED IDEOGRAPH-#4488, IRGKangXi=1012.560, Def{(same as 橨) side beam of a boat}
4489 CJK UNIFIED IDEOGRAPH-#4489, IRGKangXi=1013.020, Def{a long, narrow boat}
448A CJK UNIFIED IDEOGRAPH-#448A, IRGKangXi=1014.040, Def{a patient (of jaundice; icterus) facial complexion}
448B CJK UNIFIED IDEOGRAPH-#448B, IRGKangXi=1014.050, Def{air current; atmospheric current}
448C CJK UNIFIED IDEOGRAPH-#448C, IRGKangXi=1014.130, Def{dark blue color, without color, to close the eyes}
448D CJK UNIFIED IDEOGRAPH-#448D, IRGKangXi=1014.170, Def{without color, clear and lucid}
448E CJK UNIFIED IDEOGRAPH-#448E, IRGKangXi=1014.180, Def{without color, clear and lucid}
448F CJK UNIFIED IDEOGRAPH-#448F, IRGKangXi=1014.190, Def{disturbed in mind, not in good health, a fierce or ferocious appearance}
4490 CJK UNIFIED IDEOGRAPH-#4490, IRGKangXi=1014.230, Def{disturbed in mind, not in good health, a fierce or ferocious appearance, a bad look}
4491 CJK UNIFIED IDEOGRAPH-#4491, IRGKangXi=1017.011, Def{(non-classical form of 艸) grass; straw; herbs; weeds}
4492 CJK UNIFIED IDEOGRAPH-#4492, IRGKangXi=1017.060, Def{(same as 芀) name of a plant (much used for making brooms); a reed}
4493 CJK UNIFIED IDEOGRAPH-#4493, IRGKangXi=1017.110, Def{to do violence, perverse; rebellious, calamities; tribulations; miseries; crime; sin}
4494 CJK UNIFIED IDEOGRAPH-#4494, IRGKangXi=1017.191, Def{name of a variety of grass}
4495 CJK UNIFIED IDEOGRAPH-#4495, IRGKangXi=1017.200, Def{a kind of herb medicine, luxuriant; flourishing of grass and trees}
4496 CJK UNIFIED IDEOGRAPH-#4496, IRGKangXi=1018.020, Def{a kind of herb medicine (plants of the mugwort or artemisia family)}
4497 CJK UNIFIED IDEOGRAPH-#4497, IRGKangXi=1018.130, Def{(same as 芞) fragrant herb, vanilla}
4498 CJK UNIFIED IDEOGRAPH-#4498, IRGKangXi=1019.061, Def{(same as 荾) parsley, (same as 葰) ginger, pistil}
4499 CJK UNIFIED IDEOGRAPH-#4499, IRGKangXi=1019.061
449A CJK UNIFIED IDEOGRAPH-#449A, IRGKangXi=1019.070, Def{name of a variety of grass}
449B CJK UNIFIED IDEOGRAPH-#449B, IRGKangXi=1019.190, Def{name of a variety of grass}
449C CJK UNIFIED IDEOGRAPH-#449C, IRGKangXi=1019.200, Def{name of a variety of grass, a kind of herb}
449D CJK UNIFIED IDEOGRAPH-#449D, IRGKangXi=1019.240, Def{root of the thatch, straw or couch grass; a herb medicine to quench thirst}
449E CJK UNIFIED IDEOGRAPH-#449E, IRGKangXi=1019.250, Def{name of a variety of grass, hot}
449F CJK UNIFIED IDEOGRAPH-#449F, IRGKangXi=1020.060, Def{name of a variety of grass}
44A0 CJK UNIFIED IDEOGRAPH-#44A0, IRGKangXi=1020.070, Def{(same as 丰) luxuriant; exuberant of the grass and trees, young shoots of the rape-turnip--Brassica rapa}
44A1 CJK UNIFIED IDEOGRAPH-#44A1, IRGKangXi=1020.080, Def{name of a variety of grass}
44A2 CJK UNIFIED IDEOGRAPH-#44A2, IRGKangXi=1021.120, Def{sweet flag; the calamus; its leaves are hung on the door lintels on the 5th of the 5th lunar month, to avert evil influences}
44A3 CJK UNIFIED IDEOGRAPH-#44A3, IRGKangXi=1021.160, Def{(same as 苒) (of flowers and grass) lush or delicate}
44A4 CJK UNIFIED IDEOGRAPH-#44A4, IRGKangXi=1022.030, Def{name of a variety of grass}
44A5 CJK UNIFIED IDEOGRAPH-#44A5, IRGKangXi=1022.160, Def{corresponding; equivalent, considerable; to a great extent, appropriate}
44A6 CJK UNIFIED IDEOGRAPH-#44A6, IRGKangXi=1022.220, Def{grass floats on water}
44A7 CJK UNIFIED IDEOGRAPH-#44A7, IRGKangXi=1023.010, Def{a vessel or utensil made of straw, grass or weeds, a kind of grass}
44A8 CJK UNIFIED IDEOGRAPH-#44A8, IRGKangXi=1025.030, Def{a kind of vegetable, plants of the mugwort or artemisia family}
44A9 CJK UNIFIED IDEOGRAPH-#44A9, IRGKangXi=1025.160, Def{name of a variety of grass, (same as 莫) not}
44AA CJK UNIFIED IDEOGRAPH-#44AA, IRGKangXi=1027.030, Def{name of a variety of grass}
44AB CJK UNIFIED IDEOGRAPH-#44AB, IRGKangXi=1027.100, Def{grassy}
44AC CJK UNIFIED IDEOGRAPH-#44AC, IRGKangXi=1027.170, Def{(ancient form of 莫) not, (standard form of 暮) sunset; dusk}
44AD CJK UNIFIED IDEOGRAPH-#44AD, IRGKangXi=1027.201, Def{(same as 等) rank; grade, same; equal, to wait, and so on; etc.}
44AE CJK UNIFIED IDEOGRAPH-#44AE, IRGKangXi=1027.201
44AF CJK UNIFIED IDEOGRAPH-#44AF, IRGKangXi=1027.201
44B0 CJK UNIFIED IDEOGRAPH-#44B0, IRGKangXi=1027.320, Def{to follow; to trace, to submit; to accord with, to accompany, a kind of grass}
44B1 CJK UNIFIED IDEOGRAPH-#44B1, IRGKangXi=1027.360, Def{(same as 蒸) twigs of hemp used for fuel; to rise, as steam, steam}
44B2 CJK UNIFIED IDEOGRAPH-#44B2, IRGKangXi=1027.380, Def{another name name for 黃岑 (Scutellaria baikalensis)}
44B3 CJK UNIFIED IDEOGRAPH-#44B3, IRGKangXi=1028.060, Def{(same as U+6736 朵) a flower; a cluster of flowers; a bud, lobe of the ear}
44B4 CJK UNIFIED IDEOGRAPH-#44B4, IRGKangXi=1028.110, Def{name of a variety of grass}
44B5 CJK UNIFIED IDEOGRAPH-#44B5, IRGKangXi=1028.200, Def{name of a variety of grass}
44B6 CJK UNIFIED IDEOGRAPH-#44B6, IRGKangXi=1028.250, Def{(ancient form of 天) the sky; the heaven, Nature; God, day}
44B7 CJK UNIFIED IDEOGRAPH-#44B7, IRGKangXi=1028.270, Def{a kind of plant, a kind of herb; Chinese trichosanthes (Trichosanthes kirilowii); bryonia}
44B8 CJK UNIFIED IDEOGRAPH-#44B8, IRGKangXi=1029.080, Def{grass}
44B9 CJK UNIFIED IDEOGRAPH-#44B9, IRGKangXi=1030.020, Def{grassy, fruitful}
44BA CJK UNIFIED IDEOGRAPH-#44BA, IRGKangXi=1030.100, Def{(ancient form of 堇) clay}
44BB CJK UNIFIED IDEOGRAPH-#44BB, IRGKangXi=1030.130, Def{a medical herb; acrid taste; poisonless; harmless}
44BC CJK UNIFIED IDEOGRAPH-#44BC, IRGKangXi=1030.160, Def{(same as 曲) a bamboo tray for raising silkworms}
44BD CJK UNIFIED IDEOGRAPH-#44BD, IRGKangXi=1031.150, Def{Illicium anisatum, and kind of poisonous shrub}
44BE CJK UNIFIED IDEOGRAPH-#44BE, IRGKangXi=1031.381
44BF CJK UNIFIED IDEOGRAPH-#44BF, IRGKangXi=1031.381
44C0 CJK UNIFIED IDEOGRAPH-#44C0, IRGKangXi=1031.381
44C1 CJK UNIFIED IDEOGRAPH-#44C1, IRGKangXi=1031.381
44C2 CJK UNIFIED IDEOGRAPH-#44C2, IRGKangXi=1032.020, Def{name of a variety of grass, last name}
44C3 CJK UNIFIED IDEOGRAPH-#44C3, IRGKangXi=1032.070, Def{melancholy and sad, withered (said of grass and trees)}
44C4 CJK UNIFIED IDEOGRAPH-#44C4, IRGKangXi=1032.080, Def{grassy, name of a variety of grass}
44C5 CJK UNIFIED IDEOGRAPH-#44C5, IRGKangXi=1032.090, Def{(same as 芹) celery; a kind of watr plant}
44C6 CJK UNIFIED IDEOGRAPH-#44C6, IRGKangXi=1032.120, Def{to cut the; to sever grass}
44C7 CJK UNIFIED IDEOGRAPH-#44C7, IRGKangXi=1033.170, Def{luxuriant; lush of grass and trees, (same as 赫) bright; glowing, brilliant; glorious, (same as 嚇) angry, fear; dread; fright; scare}
44C8 CJK UNIFIED IDEOGRAPH-#44C8, IRGKangXi=1033.190, Def{a kind of plant; chicken-head; Euryale ferox}
44C9 CJK UNIFIED IDEOGRAPH-#44C9, IRGKangXi=1033.200, Def{name of a variety of grass, a kind of vegetable, (same as 椰) coconut; coconut palm; coconut tree}
44CA CJK UNIFIED IDEOGRAPH-#44CA, IRGKangXi=1033.340, Def{name of a variety of grass, (as moxa) (Perilla ocimoides)}
44CB CJK UNIFIED IDEOGRAPH-#44CB, IRGKangXi=1034.010, Def{elm-seeds -- used as food}
44CC CJK UNIFIED IDEOGRAPH-#44CC, IRGKangXi=1034.110, Def{polygala (a medical herb)}
44CD CJK UNIFIED IDEOGRAPH-#44CD, IRGKangXi=1034.120, Def{cruciferous flowers; with acrid seeds; used as medicine}
44CE CJK UNIFIED IDEOGRAPH-#44CE, IRGKangXi=1034.150, Def{name of a variety of grass}
44CF CJK UNIFIED IDEOGRAPH-#44CF, IRGKangXi=1035.200, Def{flourishing; luxuriant; a lush growth of flowers}
44D0 CJK UNIFIED IDEOGRAPH-#44D0, IRGKangXi=1036.030, Def{name of a variety of grass}
44D1 CJK UNIFIED IDEOGRAPH-#44D1, IRGKangXi=1036.120, Def{(same as 荓) name of a variety of grass (same as 萍) duckweeds}
44D2 CJK UNIFIED IDEOGRAPH-#44D2, IRGKangXi=1036.280, Def{(same as 蒯) Scirpus cyperinus var, concolor, a rush, from which many things are woven}
44D3 CJK UNIFIED IDEOGRAPH-#44D3, IRGKangXi=1036.401, Def{(simplified form of 薵) name of a variety of grass, (same as 葤) use grass to wrap things, to cover; to put a cover over something}
44D4 CJK UNIFIED IDEOGRAPH-#44D4, IRGKangXi=1036.401
44D5 CJK UNIFIED IDEOGRAPH-#44D5, IRGKangXi=1042.261, Def{polygala (a medical herb)}
44D6 CJK UNIFIED IDEOGRAPH-#44D6, IRGKangXi=1036.401, Def{(simplified form of 藭) Cnidium officinale, a kind of medicinal herb}
44D7 CJK UNIFIED IDEOGRAPH-#44D7, IRGKangXi=1037.230, Def{(same as U+8471 葱 U+8525 蔥) scallions; leeks; onions}
44D8 CJK UNIFIED IDEOGRAPH-#44D8, IRGKangXi=1038.050, Def{a kind of plant, name of a variety of grass}
44D9 CJK UNIFIED IDEOGRAPH-#44D9, IRGKangXi=1038.070, Def{slanting; inclined; sloping}
44DA CJK UNIFIED IDEOGRAPH-#44DA, IRGKangXi=1038.100, Def{a kind of vegetable, a water-plant; the bulbs of which art used as food -- Sagittaria sagittifolia}
44DB CJK UNIFIED IDEOGRAPH-#44DB, IRGKangXi=1038.290, Def{molecular formula (C18H12), to brush}
44DC CJK UNIFIED IDEOGRAPH-#44DC, IRGKangXi=1038.330, Def{salted or pickled vegetables}
44DD CJK UNIFIED IDEOGRAPH-#44DD, IRGKangXi=1039.170, Def{Chinese pennisetum) Pennisetum alopecuroides)}
44DE CJK UNIFIED IDEOGRAPH-#44DE, IRGKangXi=1039.260, Def{a kind of plant used as dyestuff, material for making paper and coir raincoats, edible, Chinese pennisetum (Pennisetum alopecuroides)}
44DF CJK UNIFIED IDEOGRAPH-#44DF, IRGKangXi=1040.020, Def{name of a variety of grass, (same as 茢) a broom}
44E0 CJK UNIFIED IDEOGRAPH-#44E0, IRGKangXi=1040.330, Def{the water plantain, the lotus floating on the water}
44E1 CJK UNIFIED IDEOGRAPH-#44E1, IRGKangXi=1041.080, Def{a medical herb (知母)}
44E2 CJK UNIFIED IDEOGRAPH-#44E2, IRGKangXi=1041.090, Def{name of a variety of grass}
44E3 CJK UNIFIED IDEOGRAPH-#44E3, IRGKangXi=1041.190, Def{name of a variety of grass}
44E4 CJK UNIFIED IDEOGRAPH-#44E4, IRGKangXi=1041.360, Def{vegetation}
44E5 CJK UNIFIED IDEOGRAPH-#44E5, IRGKangXi=1042.030, Def{sound of the wriggled insects on the grass}
44E6 CJK UNIFIED IDEOGRAPH-#44E6, IRGKangXi=1042.200, Def{(same as 典) a rule; a law, a tale or story, pawn; to mortgage, to take charge of}
44E7 CJK UNIFIED IDEOGRAPH-#44E7, IRGKangXi=1042.261, Def{(same as 亟) urgent; pressing}
44E8 CJK UNIFIED IDEOGRAPH-#44E8, IRGKangXi=1042.261, Def{(simplified form of 罃) long-necked bottle; an earthenware jar with a small mouth and two or four ears}
44E9 CJK UNIFIED IDEOGRAPH-#44E9, IRGKangXi=1042.261
44EA CJK UNIFIED IDEOGRAPH-#44EA, IRGKangXi=1042.261
44EB CJK UNIFIED IDEOGRAPH-#44EB, IRGKangXi=1042.261, Def{name of a mountain, in Taiwan Province}
44EC CJK UNIFIED IDEOGRAPH-#44EC, IRGKangXi=1042.261
44ED CJK UNIFIED IDEOGRAPH-#44ED, IRGKangXi=1042.261, Def{weed or grass with narrow thick glades (as bamboo); water-pepper group}
44EE CJK UNIFIED IDEOGRAPH-#44EE, IRGKangXi=1042.300, Def{lush growth; dense growth of silky grass; fine grass}
44EF CJK UNIFIED IDEOGRAPH-#44EF, IRGKangXi=1042.310, Def{water-pepper}
44F0 CJK UNIFIED IDEOGRAPH-#44F0, IRGKangXi=1042.450, Def{absinthin, Artemisia capillaris, a kind of medicinal herb}
44F1 CJK UNIFIED IDEOGRAPH-#44F1, IRGKangXi=1043.320, Def{a kind of herb medicine; Bupleurum}
44F2 CJK UNIFIED IDEOGRAPH-#44F2, IRGKangXi=1044.210, Def{fine; silky; new growth of grass}
44F3 CJK UNIFIED IDEOGRAPH-#44F3, IRGKangXi=1044.230, Def{name of a variety of grass}
44F4 CJK UNIFIED IDEOGRAPH-#44F4, IRGKangXi=1045.020, Def{edible fungus from trees}
44F5 CJK UNIFIED IDEOGRAPH-#44F5, IRGKangXi=1045.080, Def{to blossom; to flower}
44F6 CJK UNIFIED IDEOGRAPH-#44F6, IRGKangXi=1045.150, Def{(same as 藾) a kind of plant; a kind of herb}
44F7 CJK UNIFIED IDEOGRAPH-#44F7, IRGKangXi=1047.250, Def{(same as 莕 荇) Nymphoides peltalum; a kind of water plant, name of a variety of grass}
44F8 CJK UNIFIED IDEOGRAPH-#44F8, IRGKangXi=1047.340, Def{weed}
44F9 CJK UNIFIED IDEOGRAPH-#44F9, IRGKangXi=1047.510, Def{(same as 饐) to stuff full and to gulp down, cooked food which has become mouldy, sour}
44FA CJK UNIFIED IDEOGRAPH-#44FA, IRGKangXi=1047.670, Def{name of a variety of grass}
44FB CJK UNIFIED IDEOGRAPH-#44FB, IRGKangXi=1047.671
44FC CJK UNIFIED IDEOGRAPH-#44FC, IRGKangXi=1047.690, Def{name of a variety of grass, grunting of hogs}
44FD CJK UNIFIED IDEOGRAPH-#44FD, IRGKangXi=1047.720, Def{name of a variety of grass}
44FE CJK UNIFIED IDEOGRAPH-#44FE, IRGKangXi=1047.730, Def{lush; luxuriant of grass and trees}
44FF CJK UNIFIED IDEOGRAPH-#44FF, IRGKangXi=1048.160, Def{a lotus flower}
4500 CJK UNIFIED IDEOGRAPH-#4500, IRGKangXi=1048.280, Def{(same as 荽 葰) parsley}
4501 CJK UNIFIED IDEOGRAPH-#4501, IRGKangXi=1049.090, Def{name of a variety of grass}
4502 CJK UNIFIED IDEOGRAPH-#4502, IRGKangXi=1049.170, Def{vegetable soup, a kind of vegetable}
4503 CJK UNIFIED IDEOGRAPH-#4503, IRGKangXi=1049.180, Def{cordate houttuynia (Houttuynia cordata)}
4504 CJK UNIFIED IDEOGRAPH-#4504, IRGKangXi=1049.330, Def{name of a variety of grass; rushes, dodder}
4505 CJK UNIFIED IDEOGRAPH-#4505, IRGKangXi=1049.350, Def{name of a variety of trees, name of a variety of grass, fruit of the tree}
4506 CJK UNIFIED IDEOGRAPH-#4506, IRGKangXi=1050.010, Def{a kind of bean; edible}
4507 CJK UNIFIED IDEOGRAPH-#4507, IRGKangXi=1050.210, Def{a kind of plant, the root is used for food}
4508 CJK UNIFIED IDEOGRAPH-#4508, IRGKangXi=1051.110, Def{lush growth of grass, trees and fruits}
4509 CJK UNIFIED IDEOGRAPH-#4509, IRGKangXi=1051.150, Def{scattered or dispersed of grass and trees, (non-classical form of 蒜) the garlic (belongs to meat and fish diet)}
450A CJK UNIFIED IDEOGRAPH-#450A, IRGKangXi=1052.051, Def{dense growth of grass}
450B CJK UNIFIED IDEOGRAPH-#450B, IRGKangXi=1052.051, Def{a kind of tree; very tall and its lieaves like bird's wings; edible}
450C CJK UNIFIED IDEOGRAPH-#450C, IRGKangXi=1052.051, Def{name of a variety of grass, (Pueraria thunbergiana); the white birch}
450D CJK UNIFIED IDEOGRAPH-#450D, IRGKangXi=1052.051
450E CJK UNIFIED IDEOGRAPH-#450E, IRGKangXi=1052.100, Def{name of a variety of grass}
450F CJK UNIFIED IDEOGRAPH-#450F, IRGKangXi=1052.120, Def{a lush; dense growth of weeds, mixed; mingled roots of the grass, (same as 簉) deputy; a deputy; an attendant, an escorting vehicle}
4510 CJK UNIFIED IDEOGRAPH-#4510, IRGKangXi=1052.240, Def{delicate, colorful and beautiful small piece of paper}
4511 CJK UNIFIED IDEOGRAPH-#4511, IRGKangXi=1052.260, Def{a white colored cluster grown at the tip of cogongrass, a kind of plants of the mugwort or artemisia family, an ear of grain}
4512 CJK UNIFIED IDEOGRAPH-#4512, IRGKangXi=1053.080, Def{name of a variety of grass}
4513 CJK UNIFIED IDEOGRAPH-#4513, IRGKangXi=1053.120, Def{herb medicine; teasel root}
4514 CJK UNIFIED IDEOGRAPH-#4514, IRGKangXi=1053.170, Def{name of a variety of grass}
4515 CJK UNIFIED IDEOGRAPH-#4515, IRGKangXi=1053.180, Def{chicken breast}
4516 CJK UNIFIED IDEOGRAPH-#4516, IRGKangXi=1053.200, Def{(same as 菱 蔆) water caltrop}
4517 CJK UNIFIED IDEOGRAPH-#4517, IRGKangXi=1054.140, Def{a kind of vegetable}
4518 CJK UNIFIED IDEOGRAPH-#4518, IRGKangXi=1054.200, Def{fish paste; fish cooked in soy sauce}
4519 CJK UNIFIED IDEOGRAPH-#4519, IRGKangXi=1054.210, Def{name of a variety of grass}
451A CJK UNIFIED IDEOGRAPH-#451A, IRGKangXi=1054.220, Def{herb medicine; the water plantain}
451B CJK UNIFIED IDEOGRAPH-#451B, IRGKangXi=1054.260, Def{fibrous plant of which cloth, rope, bag are made}
451C CJK UNIFIED IDEOGRAPH-#451C, IRGKangXi=1054.290, Def{herb medicine; hellebore}
451D CJK UNIFIED IDEOGRAPH-#451D, IRGKangXi=1054.310, Def{name of a variety of grass}
451E CJK UNIFIED IDEOGRAPH-#451E, IRGKangXi=1055.070, Def{the beginning; to start, new growing of the grass}
451F CJK UNIFIED IDEOGRAPH-#451F, IRGKangXi=1055.120, Def{shake and wave of the grass}
4520 CJK UNIFIED IDEOGRAPH-#4520, IRGKangXi=1055.240, Def{thin root (rhizome) of the lotus, (same as 梢) the tip of a branch, (same as U+77DF 槊) a long spear; a lance}
4521 CJK UNIFIED IDEOGRAPH-#4521, IRGKangXi=1055.340, Def{name of a variety of grass; perilla ocimoides, whose seeds are a bird feed}
4522 CJK UNIFIED IDEOGRAPH-#4522, IRGKangXi=1056.110, Def{(ancient form of 華) Cathay; China, splendid; gorgeous; colorful; beautiful; luxurious, a family name}
4523 CJK UNIFIED IDEOGRAPH-#4523, IRGKangXi=1056.121, Def{a tribe in ancient times}
4524 CJK UNIFIED IDEOGRAPH-#4524, IRGKangXi=1056.121, Def{the lush and luxuriant of the grass and flowers}
4525 CJK UNIFIED IDEOGRAPH-#4525, IRGKangXi=1056.121, Def{(non-classical form of U+856D 蕭) common variety of artemisia}
4526 CJK UNIFIED IDEOGRAPH-#4526, IRGKangXi=1056.121
4527 CJK UNIFIED IDEOGRAPH-#4527, IRGKangXi=1056.121, Def{(same as 蔾) a kind of plant; the caltrop; caltrap}
4528 CJK UNIFIED IDEOGRAPH-#4528, IRGKangXi=1056.121
4529 CJK UNIFIED IDEOGRAPH-#4529, IRGKangXi=1056.121
452A CJK UNIFIED IDEOGRAPH-#452A, IRGKangXi=1054.090, Def{name of a variety of grass, scattered or dispersed of the grass and trees}
452B CJK UNIFIED IDEOGRAPH-#452B, IRGKangXi=1056.121
452C CJK UNIFIED IDEOGRAPH-#452C, IRGKangXi=1056.170, Def{hemp, marijuana (female; pistillate), herbage}
452D CJK UNIFIED IDEOGRAPH-#452D, IRGKangXi=1056.200, Def{name of a variety of grass; poisonous herb}
452E CJK UNIFIED IDEOGRAPH-#452E, IRGKangXi=1056.210, Def{name of a variety of grass; growing in the water with edible flowers}
452F CJK UNIFIED IDEOGRAPH-#452F, IRGKangXi=1056.240, Def{salted; pickled leeks or scallions}
4530 CJK UNIFIED IDEOGRAPH-#4530, IRGKangXi=1056.290, Def{(variant of 葍) name of a variety of grass; perennial; creeping plants}
4531 CJK UNIFIED IDEOGRAPH-#4531, IRGKangXi=1056.300, Def{name of a variety of grass}
4532 CJK UNIFIED IDEOGRAPH-#4532, IRGKangXi=1056.360, Def{name of a variety of grass, (same as 橙) the orange}
4533 CJK UNIFIED IDEOGRAPH-#4533, IRGKangXi=1056.380, Def{chickling}
4534 CJK UNIFIED IDEOGRAPH-#4534, IRGKangXi=1056.410, Def{name of a variety of grass, growing grass, to weed (in farming); to mow grass or cut weed}
4535 CJK UNIFIED IDEOGRAPH-#4535, IRGKangXi=1056.420, Def{(same as 葌 蕑) fragrant thoroughwort (Eupatorium fortunei)}
4536 CJK UNIFIED IDEOGRAPH-#4536, IRGKangXi=1057.040, Def{name of a variety of grass, weed (in farming); to mow grass or cut weed}
4537 CJK UNIFIED IDEOGRAPH-#4537, IRGKangXi=1057.140, Def{Cyperus rotundus, a kind of medicinal herb}
4538 CJK UNIFIED IDEOGRAPH-#4538, IRGKangXi=1057.260, Def{name of a variety of grass, fragrant herb; vanilla, fragrant; delicious; balm; spice}
4539 CJK UNIFIED IDEOGRAPH-#4539, IRGKangXi=1057.320, Def{a fungus which grows on rotten plants and is eaten when fresh}
453A CJK UNIFIED IDEOGRAPH-#453A, IRGKangXi=1057.370, Def{heading; earing; to flower; to blossom (of the smartweed group), Cyperus rotundus, a kind of medicinal herb, a peduncle or footstalk of a flower or fruit; a stem; a base, new growing leaves}
453B CJK UNIFIED IDEOGRAPH-#453B, IRGKangXi=1058.050, Def{name of a variety of grass, luxuriant; lush of the grass}
453C CJK UNIFIED IDEOGRAPH-#453C, IRGKangXi=1058.110, Def{sound of the grass; parsley}
453D CJK UNIFIED IDEOGRAPH-#453D, IRGKangXi=1058.200, Def{to cover; to put a cover over something, small, low, weak, pure; clean; clear}
453E CJK UNIFIED IDEOGRAPH-#453E, IRGKangXi=1058.230, Def{a kind of fragrant herb, a kind of vegetable (growing in the water; something like the bracken)}
453F CJK UNIFIED IDEOGRAPH-#453F, IRGKangXi=1059.050, Def{lush growth; dense growth of trees and grass, to huddle together; to crowd together}
4540 CJK UNIFIED IDEOGRAPH-#4540, IRGKangXi=1059.070, Def{name of a variety of grass, Compositae; chrysanthemum family, perennial herbage; to blossom in winter}
4541 CJK UNIFIED IDEOGRAPH-#4541, IRGKangXi=1059.120, Def{suddenly, name of a variety of grass}
4542 CJK UNIFIED IDEOGRAPH-#4542, IRGKangXi=1059.291
4543 CJK UNIFIED IDEOGRAPH-#4543, IRGKangXi=1059.291, Def{(same as 蔭) the shade of a tree, to cover up; to cover or screen}
4544 CJK UNIFIED IDEOGRAPH-#4544, IRGKangXi=1050.080, Def{meat in the form of paste; salted or pickled meat}
4545 CJK UNIFIED IDEOGRAPH-#4545, IRGKangXi=1059.420, Def{name of a variety of grass}
4546 CJK UNIFIED IDEOGRAPH-#4546, IRGKangXi=1059.460, Def{round straw quilt; bedding; cushion; mattress; mat for the chair, name of a variety of grass}
4547 CJK UNIFIED IDEOGRAPH-#4547, IRGKangXi=1059.490, Def{name of a variety of grass, a kind of vegetable}
4548 CJK UNIFIED IDEOGRAPH-#4548, IRGKangXi=1060.090, Def{name of a variety of grass, (same as U+5C5F 屧) the wooden sole of a shoe}
4549 CJK UNIFIED IDEOGRAPH-#4549, IRGKangXi=1060.130, Def{a kind of plant, Pueraria thunbergiana, a creeping, edible bean whose fibers can be made into linen-like cloth and whose roots are used in herbal medicine}
454A CJK UNIFIED IDEOGRAPH-#454A, IRGKangXi=1060.170, Def{name of a variety of grass, grass that creep and spread luxuriantly}
454B CJK UNIFIED IDEOGRAPH-#454B, IRGKangXi=1060.260, Def{of elm group}
454C CJK UNIFIED IDEOGRAPH-#454C, IRGKangXi=1061.170, Def{(same as U+7A49 稚) young grain, tender; young, delicate; small}
454D CJK UNIFIED IDEOGRAPH-#454D, IRGKangXi=1062.050, Def{name of a variety of grass}
454E CJK UNIFIED IDEOGRAPH-#454E, IRGKangXi=1062.360, Def{(non-classical form) name of a variety of grass (corrupted form of 葍) perennial; creeping plants}
454F CJK UNIFIED IDEOGRAPH-#454F, IRGKangXi=1062.420, Def{Artemisia, a kind of plant with edible leaves}
4550 CJK UNIFIED IDEOGRAPH-#4550, IRGKangXi=1064.421
4551 CJK UNIFIED IDEOGRAPH-#4551, IRGKangXi=1062.441, Def{(same as 葰) parsley}
4552 CJK UNIFIED IDEOGRAPH-#4552, IRGKangXi=1063.070, Def{name of a variety of grass}
4553 CJK UNIFIED IDEOGRAPH-#4553, IRGKangXi=1063.160, Def{name of a variety of grass; poisonous; used to kill fishes, valueless things; insignificant things}
4554 CJK UNIFIED IDEOGRAPH-#4554, IRGKangXi=1063.230, Def{name of a variety of grass, couch grass family}
4555 CJK UNIFIED IDEOGRAPH-#4555, IRGKangXi=1063.250, Def{name of a variety of grass}
4556 CJK UNIFIED IDEOGRAPH-#4556, IRGKangXi=1063.380, Def{(same as 蓀) fragrant herb, vanilla}
4557 CJK UNIFIED IDEOGRAPH-#4557, IRGKangXi=1064.070, Def{name of a variety of grass}
4558 CJK UNIFIED IDEOGRAPH-#4558, IRGKangXi=1064.080, Def{(same as 苓) a variety of fungus; tuckahoe, licorice, or liquorice, name of a variety of grass}
4559 CJK UNIFIED IDEOGRAPH-#4559, IRGKangXi=1064.310, Def{to set in order; to adjust and repair}
455A CJK UNIFIED IDEOGRAPH-#455A, IRGKangXi=1064.360, Def{(same as 蕢) a straw basket, a vegetable with red stalk}
455B CJK UNIFIED IDEOGRAPH-#455B, IRGKangXi=1064.420, Def{name of a variety of grass}
455C CJK UNIFIED IDEOGRAPH-#455C, IRGKangXi=1064.421
455D CJK UNIFIED IDEOGRAPH-#455D, IRGKangXi=1059.440, Def{medical herb; sesame}
455E CJK UNIFIED IDEOGRAPH-#455E, IRGKangXi=1065.010, Def{Henbane, poisonous, seeds for medical use, a plant which produces a brown dye}
455F CJK UNIFIED IDEOGRAPH-#455F, IRGKangXi=1065.090, Def{a kind of vegetable; rape}
4560 CJK UNIFIED IDEOGRAPH-#4560, IRGKangXi=1065.260, Def{(non-classical form 蕟) coarse bamboo mat, a kind of ailment, probably of a rheumatic nature, which causes stiff neck and backbone}
4561 CJK UNIFIED IDEOGRAPH-#4561, IRGKangXi=1065.280, Def{Compositae; chrysanthemum family; perennial herbage; herb medicine}
4562 CJK UNIFIED IDEOGRAPH-#4562, IRGKangXi=1065.430, Def{weak, crude and coarse, careless; rash, bad behavior}
4563 CJK UNIFIED IDEOGRAPH-#4563, IRGKangXi=1066.160, Def{water plant}
4564 CJK UNIFIED IDEOGRAPH-#4564, IRGKangXi=1066.180, Def{(same as 蘄) name of a county in ancient times; today's south of Anhui Province, Suxian}
4565 CJK UNIFIED IDEOGRAPH-#4565, IRGKangXi=1066.270, Def{(ancient form of 苨) herb medicine; Chinese bellflower family; Platycodon grandiforus}
4566 CJK UNIFIED IDEOGRAPH-#4566, IRGKangXi=1066.410, Def{flower of the chrysanthemum; chrysanthemum}
4567 CJK UNIFIED IDEOGRAPH-#4567, IRGKangXi=1066.420, Def{(same as U+832D 茭) Zizania latifolia, a kind of edible aquatic grass, rootstock (of the lotus), the joint of the sides of arms and the end of a bow}
4568 CJK UNIFIED IDEOGRAPH-#4568, IRGKangXi=1066.450, Def{(same as 藤) rattan}
4569 CJK UNIFIED IDEOGRAPH-#4569, IRGKangXi=1067.130, Def{dry fruit (e.g. nuts), dried fruit}
456A CJK UNIFIED IDEOGRAPH-#456A, IRGKangXi=1067.170, Def{the water plantain}
456B CJK UNIFIED IDEOGRAPH-#456B, IRGKangXi=1067.220, Def{(corrupted form of U+5914 夔) a one-legged monster; a walrus, name of a court musician in the reign of Emperor Shun (2255 B.C.)}
456C CJK UNIFIED IDEOGRAPH-#456C, IRGKangXi=1067.240, Def{(same as 薑) ginger}
456D CJK UNIFIED IDEOGRAPH-#456D, IRGKangXi=1067.260, Def{name of a variety of grass, a kind of vegetable, a variety of nettle, urtica}
456E CJK UNIFIED IDEOGRAPH-#456E, IRGKangXi=1068.100, Def{(interchangeable 菊) flower of the chrysanthemum; chrysanthemun}
456F CJK UNIFIED IDEOGRAPH-#456F, IRGKangXi=1068.110, Def{duckweed}
4570 CJK UNIFIED IDEOGRAPH-#4570, IRGKangXi=1068.270, Def{another name for 知母}
4571 CJK UNIFIED IDEOGRAPH-#4571, IRGKangXi=1068.320, Def{name of a variety of grass}
4572 CJK UNIFIED IDEOGRAPH-#4572, IRGKangXi=1069.061, Def{Artemisia, a kind of plant with edible leaves}
4573 CJK UNIFIED IDEOGRAPH-#4573, IRGKangXi=1069.140, Def{name of a variety of grass}
4574 CJK UNIFIED IDEOGRAPH-#4574, IRGKangXi=1069.350, Def{a second for monkshood (附子); Chinese herb medicine}
4575 CJK UNIFIED IDEOGRAPH-#4575, IRGKangXi=1069.370, Def{name of a variety of grass; another name for 葒草 (Polygonum orientale)}
4576 CJK UNIFIED IDEOGRAPH-#4576, IRGKangXi=1070.321, Def{name of a variety of grass}
4577 CJK UNIFIED IDEOGRAPH-#4577, IRGKangXi=1070.321, Def{a kind of plant; putchuck, the root of a species of thistle found in Cashmere; roseleaf raspberry (Rubus rosaefolius var. Coronarius)}
4578 CJK UNIFIED IDEOGRAPH-#4578, IRGKangXi=1070.340, Def{(same as U+7A2D 秸) wheat straw; the stem of hem}
4579 CJK UNIFIED IDEOGRAPH-#4579, IRGKangXi=1070.380, Def{a curtain; a shade; screen; blinds}
457A CJK UNIFIED IDEOGRAPH-#457A, IRGKangXi=1070.390, Def{dense growth; lush growth or the grass, a tree; a numerary auxiliary for counting trees or similar things, roots that grow above ground}
457B CJK UNIFIED IDEOGRAPH-#457B, IRGKangXi=1071.220, Def{to adhere to; to stick together}
457C CJK UNIFIED IDEOGRAPH-#457C, IRGKangXi=1071.290, Def{name of a variety of grass}
457D CJK UNIFIED IDEOGRAPH-#457D, IRGKangXi=1071.350, Def{the rhododendron -- it is said to cause sheep to stagger and die, hence the name}
457E CJK UNIFIED IDEOGRAPH-#457E, IRGKangXi=1072.150, Def{(ancient form of 荶) a kind of vegetable; something like garlic; growing in the water, name of a variety of grass}
457F CJK UNIFIED IDEOGRAPH-#457F, IRGKangXi=1072.330, Def{name of a variety of grass}
4580 CJK UNIFIED IDEOGRAPH-#4580, IRGKangXi=1072.351, Def{(same as 虈) angelica; the root of Dahurian angelica}
4581 CJK UNIFIED IDEOGRAPH-#4581, IRGKangXi=1072.420, Def{number, to count; to enumerate}
4582 CJK UNIFIED IDEOGRAPH-#4582, IRGKangXi=1072.430, Def{an edible water-plant -- Brasenia purpurca}
4583 CJK UNIFIED IDEOGRAPH-#4583, IRGKangXi=1072.450, Def{the water is waving in the breeze, old and desolate; rags and rubbish}
4584 CJK UNIFIED IDEOGRAPH-#4584, IRGKangXi=1072.491, Def{(ancient standard form of 然 燃) to burn; to ignite; to light}
4585 CJK UNIFIED IDEOGRAPH-#4585, IRGKangXi=1072.500, Def{name of a variety of grass; nasturtium}
4586 CJK UNIFIED IDEOGRAPH-#4586, IRGKangXi=1072.520, Def{medicinal herb; a kind of vegetable, salted vegetables}
4587 CJK UNIFIED IDEOGRAPH-#4587, IRGKangXi=1072.570, Def{fragrant herb; fragrant plant; tulip}
4588 CJK UNIFIED IDEOGRAPH-#4588, IRGKangXi=1073.070, Def{(same as U+8650 虐) cruel; ferocious; atrocious}
4589 CJK UNIFIED IDEOGRAPH-#4589, IRGKangXi=1073.121, Def{(of tiger) to roar or howl}
458A CJK UNIFIED IDEOGRAPH-#458A, IRGKangXi=1073.150, Def{tiger-like}
458B CJK UNIFIED IDEOGRAPH-#458B, IRGKangXi=1073.180, Def{(same as U+8650 虐) cruel; ferocious; atrocious}
458C CJK UNIFIED IDEOGRAPH-#458C, IRGKangXi=1073.190, Def{of tiger, to roar}
458D CJK UNIFIED IDEOGRAPH-#458D, IRGKangXi=1073.191, Def{(same as 虔) to act with reverence, devout; sincere}
458E CJK UNIFIED IDEOGRAPH-#458E, IRGKangXi=1073.210, Def{tiger}
458F CJK UNIFIED IDEOGRAPH-#458F, IRGKangXi=1074.101, Def{(same as U+8655 處) to dwell; to abide in; to stay on; to be at rest in; to occupy, a place; an office; a department}
4590 CJK UNIFIED IDEOGRAPH-#4590, IRGKangXi=1074.140, Def{sound of a tiger}
4591 CJK UNIFIED IDEOGRAPH-#4591, IRGKangXi=1074.150, Def{a white tiger}
4592 CJK UNIFIED IDEOGRAPH-#4592, IRGKangXi=1074.180, Def{earthenware with the shape of a bean; used in ancient times}
4593 CJK UNIFIED IDEOGRAPH-#4593, IRGKangXi=1074.200, Def{of a walking tiger}
4594 CJK UNIFIED IDEOGRAPH-#4594, IRGKangXi=1074.210, Def{a kind of white tiger, an angry tiger, sound of a tiger}
4595 CJK UNIFIED IDEOGRAPH-#4595, IRGKangXi=1074.230, Def{a tiger}
4596 CJK UNIFIED IDEOGRAPH-#4596, IRGKangXi=1074.280, Def{(same as 狎) to show familiarity, intimacy, or disrespect (of a tiger)}
4597 CJK UNIFIED IDEOGRAPH-#4597, IRGKangXi=1075.210, Def{strong; great fighters or warriors -- the bear and the tiger}
4598 CJK UNIFIED IDEOGRAPH-#4598, IRGKangXi=1075.270, Def{a tiger}
4599 CJK UNIFIED IDEOGRAPH-#4599, IRGKangXi=1075.440, Def{a resting tiger; a tiger to lie down and take some rest}
459A CJK UNIFIED IDEOGRAPH-#459A, IRGKangXi=1075.460, Def{a tiger}
459B CJK UNIFIED IDEOGRAPH-#459B, IRGKangXi=1075.490, Def{of tiger}
459C CJK UNIFIED IDEOGRAPH-#459C, IRGKangXi=1076.040, Def{the fighting sound made by two tigers}
459D CJK UNIFIED IDEOGRAPH-#459D, IRGKangXi=1076.280, Def{(corrupted form of 虫 蟲) insects; worms}
459E CJK UNIFIED IDEOGRAPH-#459E, IRGKangXi=1076.380, Def{a sea-insect; in the shape of a human's elbow}
459F CJK UNIFIED IDEOGRAPH-#459F, IRGKangXi=1077.070, Def{(non-classical form of U+8771 虻) a gadfly}
45A0 CJK UNIFIED IDEOGRAPH-#45A0, IRGKangXi=1077.100, Def{(non-classical form of 螈) a kind of lizard found in damp places; Diemyctylus pyrrhogaster, a kind of amphibious reptile}
45A1 CJK UNIFIED IDEOGRAPH-#45A1, IRGKangXi=1078.140, Def{millipede}
45A2 CJK UNIFIED IDEOGRAPH-#45A2, IRGKangXi=1078.150, Def{first-born silkworm}
45A3 CJK UNIFIED IDEOGRAPH-#45A3, IRGKangXi=1078.210, Def{(same as U+86A4 蚤) flea, to scratch, the mortices in the hub for the spokes of the wheel}
45A4 CJK UNIFIED IDEOGRAPH-#45A4, IRGKangXi=1079.140, Def{(same as 蜿) to creep; to wriggle}
45A5 CJK UNIFIED IDEOGRAPH-#45A5, IRGKangXi=1079.270, Def{(same as 蟊) insects that are injurious to crops}
45A6 CJK UNIFIED IDEOGRAPH-#45A6, IRGKangXi=1079.320, Def{scorpion; a grub which bores into trees and destroys them, a kind of spider}
45A7 CJK UNIFIED IDEOGRAPH-#45A7, IRGKangXi=1079.370, Def{a poisonous insect; scorpion; to sting; prick of a poisonous insect; venomous sting, to ache}
45A8 CJK UNIFIED IDEOGRAPH-#45A8, IRGKangXi=1080.110, Def{mantis, (same as 蟅) ground beetle (Eupolyphage sinensis)}
45A9 CJK UNIFIED IDEOGRAPH-#45A9, IRGKangXi=1080.150, Def{a kind of bee; black bee}
45AA CJK UNIFIED IDEOGRAPH-#45AA, IRGKangXi=1080.260, Def{(same as 蠀) grub (a kind of larva); maggots, looper; inchworm; geometer}
45AB CJK UNIFIED IDEOGRAPH-#45AB, IRGKangXi=1081.090, Def{(same as 蚌) oyster}
45AC CJK UNIFIED IDEOGRAPH-#45AC, IRGKangXi=1081.111
45AD CJK UNIFIED IDEOGRAPH-#45AD, IRGKangXi=1081.200, Def{grub (a kind of larva), second for spider, a variety of spider; octopus; a long-legged spider}
45AE CJK UNIFIED IDEOGRAPH-#45AE, IRGKangXi=1081.230, Def{(same as 蠁) larvae; grubs}
45AF CJK UNIFIED IDEOGRAPH-#45AF, IRGKangXi=1081.270, Def{poisonous insect, (same as 奎) one of the 28 constellations which ancient Chinese astrologers believed to control the literary trends of the world, (same as 蛙) frog}
45B0 CJK UNIFIED IDEOGRAPH-#45B0, IRGKangXi=1081.330, Def{a kind of gnat; a small flying insect}
45B1 CJK UNIFIED IDEOGRAPH-#45B1, IRGKangXi=1081.380, Def{large shrimp in the sea}
45B2 CJK UNIFIED IDEOGRAPH-#45B2, IRGKangXi=1082.100, Def{a kind of insect (looks like cicada)}
45B3 CJK UNIFIED IDEOGRAPH-#45B3, IRGKangXi=1082.140, Def{jelly-fish; sea-blubber, (interchangeable 虴) looks like grasshopper but smaller}
45B4 CJK UNIFIED IDEOGRAPH-#45B4, IRGKangXi=1082.210, Def{a kind of insect, (non-classical form of 珧) scallops, found in abundance in the China Sea; the shells contain mother-of-pearl, and the compressor muscle or ligament is dried and imported into China as Compoy (干貝); also called (江瑤柱) it is highly esteemed as an article of food, both in China and Japan}
45B5 CJK UNIFIED IDEOGRAPH-#45B5, IRGKangXi=1082.220, Def{insects}
45B6 CJK UNIFIED IDEOGRAPH-#45B6, IRGKangXi=1083.180, Def{(of a hog:) to root (rout) earth with the snout; animal of the hedgehog family}
45B7 CJK UNIFIED IDEOGRAPH-#45B7, IRGKangXi=1083.290, Def{a kind of insect}
45B8 CJK UNIFIED IDEOGRAPH-#45B8, IRGKangXi=1084.010, Def{(same as 蛾) moth}
45B9 CJK UNIFIED IDEOGRAPH-#45B9, IRGKangXi=1084.020, Def{(interchangeable 蛘) weevil}
45BA CJK UNIFIED IDEOGRAPH-#45BA, IRGKangXi=1084.120, Def{a legendary animal in ancient times}
45BB CJK UNIFIED IDEOGRAPH-#45BB, IRGKangXi=1085.050, Def{ephemera; ephemerid; May fly, poison of the snake}
45BC CJK UNIFIED IDEOGRAPH-#45BC, IRGKangXi=1085.160, Def{the dung beetle, scarabaeus; the scavenger beetle}
45BD CJK UNIFIED IDEOGRAPH-#45BD, IRGKangXi=1085.260, Def{(same as 蜊) a kind of clam with thick white shells}
45BE CJK UNIFIED IDEOGRAPH-#45BE, IRGKangXi=1085.261
45BF CJK UNIFIED IDEOGRAPH-#45BF, IRGKangXi=1086.150, Def{(same as 蜊) a kind of clam with thick white shells}
45C0 CJK UNIFIED IDEOGRAPH-#45C0, IRGKangXi=1086.160, Def{a kind of clam}
45C1 CJK UNIFIED IDEOGRAPH-#45C1, IRGKangXi=1086.190, Def{a kind of cicada, long-legged spider}
45C2 CJK UNIFIED IDEOGRAPH-#45C2, IRGKangXi=1086.210, Def{Diemyctylus pyrrhogaster, a kind of amphibious reptile, a kind of spider; a fly-eating spider}
45C3 CJK UNIFIED IDEOGRAPH-#45C3, IRGKangXi=1087.050, Def{the millipede, a kind of cicada; big and with black color}
45C4 CJK UNIFIED IDEOGRAPH-#45C4, IRGKangXi=1087.130, Def{a kind of insect; golden beetle}
45C5 CJK UNIFIED IDEOGRAPH-#45C5, IRGKangXi=1087.220, Def{millipede, (of a road) winding; zigzag}
45C6 CJK UNIFIED IDEOGRAPH-#45C6, IRGKangXi=1087.250, Def{a kind of insect, ant}
45C7 CJK UNIFIED IDEOGRAPH-#45C7, IRGKangXi=1087.260, Def{the toad (especially in reference to the one supposed to live on the moon), earthworm}
45C8 CJK UNIFIED IDEOGRAPH-#45C8, IRGKangXi=1087.280, Def{(non-classical form of U+8771 虻) a gadfly}
45C9 CJK UNIFIED IDEOGRAPH-#45C9, IRGKangXi=1088.070, Def{a small solitary wasp}
45CA CJK UNIFIED IDEOGRAPH-#45CA, IRGKangXi=1088.090, Def{to put out the tongue (said of animal)}
45CB CJK UNIFIED IDEOGRAPH-#45CB, IRGKangXi=1088.370, Def{a marine crab}
45CC CJK UNIFIED IDEOGRAPH-#45CC, IRGKangXi=1089.110, Def{dragonfly}
45CD CJK UNIFIED IDEOGRAPH-#45CD, IRGKangXi=1089.240, Def{(same as 蠡) wood-boring insect, (of insects) to bore or eat wood, a tribe of the huns}
45CE CJK UNIFIED IDEOGRAPH-#45CE, IRGKangXi=1089.260, Def{a kind of insect}
45CF CJK UNIFIED IDEOGRAPH-#45CF, IRGKangXi=1090.020, Def{name of a insect; a black insect with six legs, capable of ejecting poison for self-defense; the spider millipede}
45D0 CJK UNIFIED IDEOGRAPH-#45D0, IRGKangXi=1090.060, Def{a weevil found in rice, etc.}
45D1 CJK UNIFIED IDEOGRAPH-#45D1, IRGKangXi=1090.160, Def{firefly}
45D2 CJK UNIFIED IDEOGRAPH-#45D2, IRGKangXi=1090.170, Def{a kind of clam; long and narrow}
45D3 CJK UNIFIED IDEOGRAPH-#45D3, IRGKangXi=1091.200, Def{dragonfly}
45D4 CJK UNIFIED IDEOGRAPH-#45D4, IRGKangXi=1091.280, Def{a house-lizard or gecko, a kind of insect; living in the water}
45D5 CJK UNIFIED IDEOGRAPH-#45D5, IRGKangXi=1092.170, Def{(same as 蜿) bends; turns; curves; turns and twists, to circle; to hover around, a name for the earthworm}
45D6 CJK UNIFIED IDEOGRAPH-#45D6, IRGKangXi=1092.211, Def{rainbow}
45D7 CJK UNIFIED IDEOGRAPH-#45D7, IRGKangXi=1092.340, Def{(same as 蚈) the millipede, firefly}
45D8 CJK UNIFIED IDEOGRAPH-#45D8, IRGKangXi=1093.010, Def{a weevil}
45D9 CJK UNIFIED IDEOGRAPH-#45D9, IRGKangXi=1093.050, Def{earthworm}
45DA CJK UNIFIED IDEOGRAPH-#45DA, IRGKangXi=1093.120, Def{eggs of mantis; chrysalis}
45DB CJK UNIFIED IDEOGRAPH-#45DB, IRGKangXi=1093.140, Def{a kind of insect}
45DC CJK UNIFIED IDEOGRAPH-#45DC, IRGKangXi=1093.380, Def{a mole-cricket, a kind of insect; (same as U+45BB 䖻) ephemera; ephemerid; mayfly; snake poison}
45DD CJK UNIFIED IDEOGRAPH-#45DD, IRGKangXi=1093.420, Def{(non-classical form of 蠶) silkworm}
45DE CJK UNIFIED IDEOGRAPH-#45DE, IRGKangXi=1094.200, Def{(same as 蠶) silkworm}
45DF CJK UNIFIED IDEOGRAPH-#45DF, IRGKangXi=1094.340, Def{a kind of insect}
45E0 CJK UNIFIED IDEOGRAPH-#45E0, IRGKangXi=1094.360, Def{the larva of mosquitoes}
45E1 CJK UNIFIED IDEOGRAPH-#45E1, IRGKangXi=1094.380, Def{a kind of insect, name of a place recorded in ancient books}
45E2 CJK UNIFIED IDEOGRAPH-#45E2, IRGKangXi=1094.460, Def{(same as 蚤) flea}
45E3 CJK UNIFIED IDEOGRAPH-#45E3, IRGKangXi=1094.550, Def{insect of mulberry, insects that damage to the melons}
45E4 CJK UNIFIED IDEOGRAPH-#45E4, IRGKangXi=1094.560, Def{a kind of worm produced in water}
45E5 CJK UNIFIED IDEOGRAPH-#45E5, IRGKangXi=1095.140, Def{the solitary wasp, lice on cattle, a kind of gad-fly}
45E6 CJK UNIFIED IDEOGRAPH-#45E6, IRGKangXi=1095.170, Def{(same as 蜂) bee; wasp}
45E7 CJK UNIFIED IDEOGRAPH-#45E7, IRGKangXi=1095.210, Def{Libellulidae, a variety of dragonfly}
45E8 CJK UNIFIED IDEOGRAPH-#45E8, IRGKangXi=1095.250, Def{Lepsima saccharina, a kind of silvery worm that eats clothes, books, etc.}
45E9 CJK UNIFIED IDEOGRAPH-#45E9, IRGKangXi=1095.260, Def{toad (especially in reference to the one supposed to live on the moon), molluscs; mollusks generally}
45EA CJK UNIFIED IDEOGRAPH-#45EA, IRGKangXi=1096.030, Def{a kind of worm; can be used in Chinese medicine}
45EB CJK UNIFIED IDEOGRAPH-#45EB, IRGKangXi=1096.080, Def{(same as 蟆) a frog, a toad}
45EC CJK UNIFIED IDEOGRAPH-#45EC, IRGKangXi=1096.271, Def{(same as U+882D 蜂) bee; wasp, hornets, wasps}
45ED CJK UNIFIED IDEOGRAPH-#45ED, IRGKangXi=1096.271
45EE CJK UNIFIED IDEOGRAPH-#45EE, IRGKangXi=1096.271, Def{a kind of insect}
45EF CJK UNIFIED IDEOGRAPH-#45EF, IRGKangXi=1097.140, Def{a kind of insect, clam family}
45F0 CJK UNIFIED IDEOGRAPH-#45F0, IRGKangXi=1097.210, Def{spiral shell; conch, spiral}
45F1 CJK UNIFIED IDEOGRAPH-#45F1, IRGKangXi=1098.050, Def{a kind of insect, snail family, snake family}
45F2 CJK UNIFIED IDEOGRAPH-#45F2, IRGKangXi=1098.060, Def{firefly}
45F3 CJK UNIFIED IDEOGRAPH-#45F3, IRGKangXi=1098.441
45F4 CJK UNIFIED IDEOGRAPH-#45F4, IRGKangXi=1100.321
45F5 CJK UNIFIED IDEOGRAPH-#45F5, IRGKangXi=1098.480, Def{a disease attacked silkworm, a dying silkworm}
45F6 CJK UNIFIED IDEOGRAPH-#45F6, IRGKangXi=1099.040, Def{(non-classical form of 蠟) wax}
45F7 CJK UNIFIED IDEOGRAPH-#45F7, IRGKangXi=1099.100, Def{a kind of wasp}
45F8 CJK UNIFIED IDEOGRAPH-#45F8, IRGKangXi=1100.030, Def{a kind of insect; a weevil found in rice, etc.}
45F9 CJK UNIFIED IDEOGRAPH-#45F9, IRGKangXi=1100.050, Def{(same as 蛓) hairy caterpillar}
45FA CJK UNIFIED IDEOGRAPH-#45FA, IRGKangXi=1100.100, Def{creeping; wriggly, (same as 蜑), the boat people in the coastal areas of Fukien (Fugian) and Kwangtung (Guangdong); Southern tribes}
45FB CJK UNIFIED IDEOGRAPH-#45FB, IRGKangXi=1102.131, Def{a kind of sea crab}
45FC CJK UNIFIED IDEOGRAPH-#45FC, IRGKangXi=1100.350, Def{a kind of insect}
45FD CJK UNIFIED IDEOGRAPH-#45FD, IRGKangXi=1100.360, Def{a small gadfly that suck blood of horse or cow; weevil found in rice, etc.}
45FE CJK UNIFIED IDEOGRAPH-#45FE, IRGKangXi=1100.410, Def{(same as 蜆) Corbicula leana, a variety of bivalves}
45FF CJK UNIFIED IDEOGRAPH-#45FF, IRGKangXi=1100.430, Def{a kind of insect; mole cricket}
4600 CJK UNIFIED IDEOGRAPH-#4600, IRGKangXi=1100.480, Def{(same as 蛗) grasshoppers}
4601 CJK UNIFIED IDEOGRAPH-#4601, IRGKangXi=1101.020, Def{(same as 蠽) a blue-green colored cicada}
4602 CJK UNIFIED IDEOGRAPH-#4602, IRGKangXi=1101.230, Def{(same as U+460B 䘋) a kind of insect}
4603 CJK UNIFIED IDEOGRAPH-#4603, IRGKangXi=1101.370, Def{a kind of crab, (same as 蟔) a caterpillar}
4604 CJK UNIFIED IDEOGRAPH-#4604, IRGKangXi=1101.380, Def{cicada family; a poisonous insect}
4605 CJK UNIFIED IDEOGRAPH-#4605, IRGKangXi=1102.170, Def{same as U+879A 螚}
4606 CJK UNIFIED IDEOGRAPH-#4606, IRGKangXi=1102.210, Def{earthworm}
4607 CJK UNIFIED IDEOGRAPH-#4607, IRGKangXi=1102.330, Def{(same as 蚊) mosquito; gnat}
4608 CJK UNIFIED IDEOGRAPH-#4608, IRGKangXi=1102.400, Def{(corrupted form of 蠣) oyster}
4609 CJK UNIFIED IDEOGRAPH-#4609, IRGKangXi=1102.470, Def{(standard form of 蠶) silkworm}
460A CJK UNIFIED IDEOGRAPH-#460A, IRGKangXi=1103.291, Def{flies; small insects produced in damp places; a kind of gnat}
460B CJK UNIFIED IDEOGRAPH-#460B, IRGKangXi=1103.260, Def{a kind of insect}
460C CJK UNIFIED IDEOGRAPH-#460C, IRGKangXi=1103.110, Def{gadfly}
460D CJK UNIFIED IDEOGRAPH-#460D, IRGKangXi=1104.280, Def{(same as 蠆) a kind of scorpion, a poisonous insect}
460E CJK UNIFIED IDEOGRAPH-#460E, IRGKangXi=1105.160, Def{name of an insect}
460F CJK UNIFIED IDEOGRAPH-#460F, IRGKangXi=1107.050, Def{(same as 恤) sympathy, pity}
4610 CJK UNIFIED IDEOGRAPH-#4610, IRGKangXi=1107.110, Def{(same as standard form 衄) the bleed at the nose, to damage; a setback; a failure}
4611 CJK UNIFIED IDEOGRAPH-#4611, IRGKangXi=1107.140, Def{(non-classical form of U+8108 脈) the pulse, the veins or arteries}
4612 CJK UNIFIED IDEOGRAPH-#4612, IRGKangXi=1107.220, Def{boy's reproductive organs, to fleece; to cut down; to scrape; to pare, to enfeeble}
4613 CJK UNIFIED IDEOGRAPH-#4613, IRGKangXi=1107.290, Def{thick blood of cattle and goat}
4614 CJK UNIFIED IDEOGRAPH-#4614, IRGKangXi=1108.030, Def{(same as 喀) to vomit; to throw up; to disgorge, coughs}
4615 CJK UNIFIED IDEOGRAPH-#4615, IRGKangXi=1109.050, Def{prostitute, a trade; an occupation; a profession}
4616 CJK UNIFIED IDEOGRAPH-#4616, IRGKangXi=1109.201
4617 CJK UNIFIED IDEOGRAPH-#4617, IRGKangXi=1110.131, Def{beautiful, exquisite; fine}
4618 CJK UNIFIED IDEOGRAPH-#4618, IRGKangXi=1110.100, Def{(same as 御) to drive; to control; to manage, imperial, to wait on, clean; pure}
4619 CJK UNIFIED IDEOGRAPH-#4619, IRGKangXi=1110.200, Def{(same as 衛) to guard; to protect, a keeper}
461A CJK UNIFIED IDEOGRAPH-#461A, IRGKangXi=1111.030, Def{(same as U+5352 卒) a servant; an underling, a pawn in chess, abrupt; hurried}
461B CJK UNIFIED IDEOGRAPH-#461B, IRGKangXi=1111.061, Def{(Cant.) 卡䘛, khaki}
461C CJK UNIFIED IDEOGRAPH-#461C, IRGKangXi=1111.070, Def{(same as standard form 巾) a napkin; kerchief or towel, a headgear}
461D CJK UNIFIED IDEOGRAPH-#461D, IRGKangXi=1111.200, Def{a shirt; a garment; a gown, a black dress}
461E CJK UNIFIED IDEOGRAPH-#461E, IRGKangXi=1112.041
461F CJK UNIFIED IDEOGRAPH-#461F, IRGKangXi=1112.110, Def{kind of silk woven with double threads and water proof; lining the coffin, leather lining of clothing}
4620 CJK UNIFIED IDEOGRAPH-#4620, IRGKangXi=1112.170, Def{(corrupted form of 袚) greaves, knee-pads, buskins, dress; clothes of minority group in ancient times, children's garments, a mat for wrapping garment, (same as 帗)(in ancient China) a multicolored prop used in dancing rituals}
4621 CJK UNIFIED IDEOGRAPH-#4621, IRGKangXi=1112.250, Def{the sleeve}
4622 CJK UNIFIED IDEOGRAPH-#4622, IRGKangXi=1113.260, Def{old and shabby (said of clothes), to fill in or to pack clothes with cotton, to remain in a standstill for a long time}
4623 CJK UNIFIED IDEOGRAPH-#4623, IRGKangXi=1114.070, Def{clothes that have no lining, stitches in the clothes, wrinkled; crinkled clothes, cotton clothes}
4624 CJK UNIFIED IDEOGRAPH-#4624, IRGKangXi=1114.120, Def{a sword covering to protect the scabbard}
4625 CJK UNIFIED IDEOGRAPH-#4625, IRGKangXi=1114.160, Def{the front of a Chinese gown, lapel of a Chinese dress-worn by the literati in former days, a short coat; a short top garment, neck-wears for babies, very fine silk fabric}
4626 CJK UNIFIED IDEOGRAPH-#4626, IRGKangXi=1114.350, Def{a kind of head-dress wore in funeral rites in old days, fine clothes}
4627 CJK UNIFIED IDEOGRAPH-#4627, IRGKangXi=1115.211
4628 CJK UNIFIED IDEOGRAPH-#4628, IRGKangXi=1116.010, Def{short leggings drawn over the trousers, clothes for fisherman}
4629 CJK UNIFIED IDEOGRAPH-#4629, IRGKangXi=1116.170, Def{collar, a throat-band to hold the hat, a tassel; a fringe, (same as 袨) in full dress, black colored ceremonial dress}
462A CJK UNIFIED IDEOGRAPH-#462A, IRGKangXi=1116.200, Def{clothes without hem; ragged garments; a garment without a lining, single}
462B CJK UNIFIED IDEOGRAPH-#462B, IRGKangXi=1116.300, Def{(same as 袽) old rags; old clothing, caulking}
462C CJK UNIFIED IDEOGRAPH-#462C, IRGKangXi=1116.330, Def{armour, military dress}
462D CJK UNIFIED IDEOGRAPH-#462D, IRGKangXi=1116.341, Def{the pleates on the lapel of a garment of thin silk}
462E CJK UNIFIED IDEOGRAPH-#462E, IRGKangXi=0109.171, Def{(same as 喪) to lose; death; funeral, to mourn, to destroy}
462F CJK UNIFIED IDEOGRAPH-#462F, IRGKangXi=1117.150, Def{the lapel or collar of a garment or robe, hat}
4630 CJK UNIFIED IDEOGRAPH-#4630, IRGKangXi=1118.030, Def{a hood; some kind of covering used on a carriage, towel; kerchief}
4631 CJK UNIFIED IDEOGRAPH-#4631, IRGKangXi=1118.070, Def{(same as 裕) wealthy; abundance; plenty, generous}
4632 CJK UNIFIED IDEOGRAPH-#4632, IRGKangXi=1118.131
4633 CJK UNIFIED IDEOGRAPH-#4633, IRGKangXi=1118.150, Def{(interchangeable 襟) a garment of single thickness, lapel of a garment, collar of a robe formerly worn by the literati, therefore used for educated classes}
4634 CJK UNIFIED IDEOGRAPH-#4634, IRGKangXi=1118.200, Def{(same as 衳) short pants; trousers; drawers}
4635 CJK UNIFIED IDEOGRAPH-#4635, IRGKangXi=1118.220, Def{hissing sound of the clothes}
4636 CJK UNIFIED IDEOGRAPH-#4636, IRGKangXi=1118.250, Def{sleeves, a piece of towel used to block up the ears}
4637 CJK UNIFIED IDEOGRAPH-#4637, IRGKangXi=1118.330, Def{sleeves, old and meanly clothes}
4638 CJK UNIFIED IDEOGRAPH-#4638, IRGKangXi=1118.340, Def{the lower front of a robe, gown, etc., sleeves, the opening on the lower front of a robe}
4639 CJK UNIFIED IDEOGRAPH-#4639, IRGKangXi=1118.370, Def{clothes that have no lining (usually for summer wear)}
463A CJK UNIFIED IDEOGRAPH-#463A, IRGKangXi=1119.090, Def{a seam which has come unsewn; to mend (clothes, etc.), (same as U+8892 袒 U+7DBB 綻) to bare; to strip; bared, ripped seam; a crack, ripped; split}
463B CJK UNIFIED IDEOGRAPH-#463B, IRGKangXi=1119.150, Def{curtain on a carriage or car}
463C CJK UNIFIED IDEOGRAPH-#463C, IRGKangXi=1119.170, Def{stockings; socks, the sleeve}
463D CJK UNIFIED IDEOGRAPH-#463D, IRGKangXi=1119.220, Def{clothing and ornaments; an ornamental item; a decorative artical of a garment}
463E CJK UNIFIED IDEOGRAPH-#463E, IRGKangXi=1119.240, Def{trouser legs; trousers; fur pants}
463F CJK UNIFIED IDEOGRAPH-#463F, IRGKangXi=1119.260, Def{shirt or a jacket without any decorated hem}
4640 CJK UNIFIED IDEOGRAPH-#4640, IRGKangXi=1119.280, Def{(same as 綳繃) a cloth to carry an infant on the back, to tie; to bind, to break open, to endure or bear}
4641 CJK UNIFIED IDEOGRAPH-#4641, IRGKangXi=1120.040, Def{children's garments, a mat for wrapping garments}
4642 CJK UNIFIED IDEOGRAPH-#4642, IRGKangXi=1120.050, Def{(non-classical form of 衳) short pants; trousers; drawers}
4643 CJK UNIFIED IDEOGRAPH-#4643, IRGKangXi=1120.160, Def{sleeveless clothes}
4644 CJK UNIFIED IDEOGRAPH-#4644, IRGKangXi=1120.190, Def{clothes with thick hem, to adjust, to regulate}
4645 CJK UNIFIED IDEOGRAPH-#4645, IRGKangXi=1120.260, Def{the waistline (in dress-making), a loop for button, a waist band or belt, pleat; a fold}
4646 CJK UNIFIED IDEOGRAPH-#4646, IRGKangXi=1121.120, Def{slits on the lower part of a gown for freedom of movement}
4647 CJK UNIFIED IDEOGRAPH-#4647, IRGKangXi=1121.130, Def{clothes of coarse fabric, seams; a fold; pleat of a garment, shirt; jacket}
4648 CJK UNIFIED IDEOGRAPH-#4648, IRGKangXi=1121.160, Def{a loose garment or cloak, shirt; jacket}
4649 CJK UNIFIED IDEOGRAPH-#4649, IRGKangXi=1121.180, Def{clothes, the central suture; seams on the back (said of clothes)}
464A CJK UNIFIED IDEOGRAPH-#464A, IRGKangXi=1121.321, Def{arid; dry; parched}
464B CJK UNIFIED IDEOGRAPH-#464B, IRGKangXi=1121.321
464C CJK UNIFIED IDEOGRAPH-#464C, IRGKangXi=1121.321, Def{(simplified form) a knot; a button, (dialect) to tie up; fastening; to wear; to slip on, to make a knot by a rope; a piece of string or a ribbon, (same as 繪) to draw (picture)}
464D CJK UNIFIED IDEOGRAPH-#464D, IRGKangXi=1121.321
464E CJK UNIFIED IDEOGRAPH-#464E, IRGKangXi=1121.340, Def{sleeves, a piece of string; a ribbon; (shoe, boot, etc.) lace}
464F CJK UNIFIED IDEOGRAPH-#464F, IRGKangXi=1121.390, Def{short sleeves shirt, clothes that have no lining, (same as 薄) thin; light; slight}
4650 CJK UNIFIED IDEOGRAPH-#4650, IRGKangXi=1122.010, Def{furs and linen garments, thin; light; slight, to pound; to beat, to attack, to hull or unhusk}
4651 CJK UNIFIED IDEOGRAPH-#4651, IRGKangXi=1122.090, Def{(same as 縗 衰) a piece of sackcloth worn on the breast in mourning, the frayed edges of mourning garments}
4652 CJK UNIFIED IDEOGRAPH-#4652, IRGKangXi=1122.260, Def{to store or save up; to hoard, to strip off; to deprive of, to undress forcibly}
4653 CJK UNIFIED IDEOGRAPH-#4653, IRGKangXi=1122.391, Def{the lower part of a garment; skirt; petticoat}
4654 CJK UNIFIED IDEOGRAPH-#4654, IRGKangXi=1123.010, Def{clothes made of poor fabric, head-dress for children (or minority group), an infant's bib}
4655 CJK UNIFIED IDEOGRAPH-#4655, IRGKangXi=1123.030, Def{clothes that have no lining}
4656 CJK UNIFIED IDEOGRAPH-#4656, IRGKangXi=1123.080, Def{(same as 綳繃) a cloth to carry an infant on the back, to tie; to bind, to break open, to endure or bear}
4657 CJK UNIFIED IDEOGRAPH-#4657, IRGKangXi=1123.140, Def{a swaddling cloth for infant; a broad bandage for carrying an infant on the back}
4658 CJK UNIFIED IDEOGRAPH-#4658, IRGKangXi=1123.250, Def{exquisite; fine, bright-colored clothes, clear white}
4659 CJK UNIFIED IDEOGRAPH-#4659, IRGKangXi=1123.290, Def{clothes}
465A CJK UNIFIED IDEOGRAPH-#465A, IRGKangXi=1124.080, Def{(same as 裊 褭) curling up, as smoke, wavering gently; to sway enticingly; winding round and round, in ancient time to cast gold in the shape of horse's hoofs; fine horse}
465B CJK UNIFIED IDEOGRAPH-#465B, IRGKangXi=1124.130, Def{(same as 袞 渿) ceremonial dress of the emperor or very high officials}
465C CJK UNIFIED IDEOGRAPH-#465C, IRGKangXi=1124.141, Def{(corrupted form) legendary mountain deity, (interchangeable 逢) to meet; to come across, to happen; to fall in with}
465D CJK UNIFIED IDEOGRAPH-#465D, IRGKangXi=1124.141, Def{under garments, intimate with, dirty; ragged, undress; thus -- to treat with irreverence}
465E CJK UNIFIED IDEOGRAPH-#465E, IRGKangXi=1124.200, Def{woolen string; ribbon or lace}
465F CJK UNIFIED IDEOGRAPH-#465F, IRGKangXi=1124.300, Def{heavy clothes (thickness), to hang down}
4660 CJK UNIFIED IDEOGRAPH-#4660, IRGKangXi=1124.370, Def{short clothes, to lift up clothes and across a river}
4661 CJK UNIFIED IDEOGRAPH-#4661, IRGKangXi=1124.420, Def{(simplified form) a knot; a button, (dialect) to tie up; fastening; to wear; to slip on, to make a knot by a rope; a piece of string or a ribbon, (same as 繪) to draw (picture)}
4662 CJK UNIFIED IDEOGRAPH-#4662, IRGKangXi=1124.450, Def{short T-shirt, lined garments without padding}
4663 CJK UNIFIED IDEOGRAPH-#4663, IRGKangXi=1125.090, Def{ragged garments or clothing}
4664 CJK UNIFIED IDEOGRAPH-#4664, IRGKangXi=1125.250, Def{good; nice; fine, long and large clothes}
4665 CJK UNIFIED IDEOGRAPH-#4665, IRGKangXi=1125.310, Def{shiny dresses}
4666 CJK UNIFIED IDEOGRAPH-#4666, IRGKangXi=1126.170, Def{upper garments}
4667 CJK UNIFIED IDEOGRAPH-#4667, IRGKangXi=1126.200, Def{red color; crimson}
4668 CJK UNIFIED IDEOGRAPH-#4668, IRGKangXi=1126.350, Def{(non-classical form of 裹) to wrap or bind}
4669 CJK UNIFIED IDEOGRAPH-#4669, IRGKangXi=1126.371, Def{clothes}
466A CJK UNIFIED IDEOGRAPH-#466A, IRGKangXi=1126.420, Def{(same as 襻) a loop for button}
466B CJK UNIFIED IDEOGRAPH-#466B, IRGKangXi=1127.121
466C CJK UNIFIED IDEOGRAPH-#466C, IRGKangXi=1127.150, Def{plaits on the sides of a petticoat, pleates of a skirt, contrast of the mixed colors}
466D CJK UNIFIED IDEOGRAPH-#466D, IRGKangXi=1127.160, Def{(same as U+8930 褰) to lift or raise (one's dress, skirt, etc.), trousers; drawers; pants}
466E CJK UNIFIED IDEOGRAPH-#466E, IRGKangXi=1127.220, Def{belt, strip of cloth}
466F CJK UNIFIED IDEOGRAPH-#466F, IRGKangXi=1127.230, Def{exquisite; fine, sharp; distinct, bright-colored}
4670 CJK UNIFIED IDEOGRAPH-#4670, IRGKangXi=1127.310, Def{new feather; damp; moist and sticky, a thin-silk curtain}
4671 CJK UNIFIED IDEOGRAPH-#4671, IRGKangXi=1127.390, Def{(same as 襡) a long coat; a long jacket, the connection of the top and bottom of clothes}
4672 CJK UNIFIED IDEOGRAPH-#4672, IRGKangXi=1128.150, Def{(same as 遷) to move; to remove, to change}
4673 CJK UNIFIED IDEOGRAPH-#4673, IRGKangXi=1128.231, Def{(same as 熛) spiting flames, flashed fire, to shine off and on, to cover; to hide, to seal, to build}
4674 CJK UNIFIED IDEOGRAPH-#4674, IRGKangXi=1128.250, Def{to soar as a bird, (ancient form of U+9077 遷) to move, to change}
4675 CJK UNIFIED IDEOGRAPH-#4675, IRGKangXi=1128.280, Def{rustic; low; mean, to despise, family name}
4676 CJK UNIFIED IDEOGRAPH-#4676, IRGKangXi=1128.321
4677 CJK UNIFIED IDEOGRAPH-#4677, IRGKangXi=1133.080, Def{(ancient form of 得) to obtain; to acquire; to gain, to effect; to attain, can; may; able to be done}
4678 CJK UNIFIED IDEOGRAPH-#4678, IRGKangXi=1133.090, Def{(same as U+4677 䙷) to obtain; to acquire; to gain, to effect; to attain, can; may; able to be done}
4679 CJK UNIFIED IDEOGRAPH-#4679, IRGKangXi=1134.060, Def{to vomit milk (said of baby), to vomit unwillingly}
467A CJK UNIFIED IDEOGRAPH-#467A, IRGKangXi=1134.070, Def{(corrupted form of 覝)(standard form of 廉) to observe; to watch; to examine}
467B CJK UNIFIED IDEOGRAPH-#467B, IRGKangXi=1134.361, Def{to steal a look; to steal a glance}
467C CJK UNIFIED IDEOGRAPH-#467C, IRGKangXi=1134.150, Def{to see; to observe, to appear, now; present, ready, to summon; to call up, far, deep; profound}
467D CJK UNIFIED IDEOGRAPH-#467D, IRGKangXi=1134.200, Def{to see; to observe}
467E CJK UNIFIED IDEOGRAPH-#467E, IRGKangXi=1134.290, Def{to wait for; to await (interchangeable 伺), (same as 施) to act; to do; to make, to grant; to give, to apply}
467F CJK UNIFIED IDEOGRAPH-#467F, IRGKangXi=1134.360, Def{to see; to observe}
4680 CJK UNIFIED IDEOGRAPH-#4680, IRGKangXi=1134.370, Def{(non-classical form) to see stealthily; to peek}
4681 CJK UNIFIED IDEOGRAPH-#4681, IRGKangXi=1134.380, Def{(same as U+4680 䚀) to see, to see stealthily; to peek}
4682 CJK UNIFIED IDEOGRAPH-#4682, IRGKangXi=1135.150, Def{to see; to observe or examine}
4683 CJK UNIFIED IDEOGRAPH-#4683, IRGKangXi=1135.210, Def{to realize fully, to make a thorough examination}
4684 CJK UNIFIED IDEOGRAPH-#4684, IRGKangXi=1135.260, Def{to make fun of, to having the same idea, feeling, etc.}
4685 CJK UNIFIED IDEOGRAPH-#4685, IRGKangXi=1135.310, Def{to look after home or domestic affairs, to search one's own soul, to see; to observe}
4686 CJK UNIFIED IDEOGRAPH-#4686, IRGKangXi=1136.020, Def{to see; to look at, to examine}
4687 CJK UNIFIED IDEOGRAPH-#4687, IRGKangXi=1136.070, Def{to observe; to inspect carefully, leaking out, a measurement, (non-classical of 省) economical, a province, to save; to avoid}
4688 CJK UNIFIED IDEOGRAPH-#4688, IRGKangXi=1136.080, Def{to see; to look at, to examine}
4689 CJK UNIFIED IDEOGRAPH-#4689, IRGKangXi=1136.180, Def{to see; to look at, to examine, to spy upon, to wait upon}
468A CJK UNIFIED IDEOGRAPH-#468A, IRGKangXi=1136.240, Def{to look from a distance}
468B CJK UNIFIED IDEOGRAPH-#468B, IRGKangXi=1136.260, Def{eyesight blurred; dim of sight; giddy or dizzy, (same as 鄖) name of a state (today's Hobei province) in ancient China, name of a place in today's Jiangsu province}
468C CJK UNIFIED IDEOGRAPH-#468C, IRGKangXi=1136.341
468D CJK UNIFIED IDEOGRAPH-#468D, IRGKangXi=1137.050, Def{to look at; to observe or inspect; to see}
468E CJK UNIFIED IDEOGRAPH-#468E, IRGKangXi=1137.060, Def{eyesight blurred; dim of sight, to look steadily at; (Cant.) to peep (through a crack)}
468F CJK UNIFIED IDEOGRAPH-#468F, IRGKangXi=1137.100, Def{to love; intimate; near to; dear; parents; relatives, to see; to look at; to observe}
4690 CJK UNIFIED IDEOGRAPH-#4690, IRGKangXi=1137.110, Def{getting red in the eyes, to look from a distance}
4691 CJK UNIFIED IDEOGRAPH-#4691, IRGKangXi=1137.140, Def{to steal a glance; to peep; to spy on}
4692 CJK UNIFIED IDEOGRAPH-#4692, IRGKangXi=1137.150, Def{eyesight blurred; dim of sight, to look steadily at}
4693 CJK UNIFIED IDEOGRAPH-#4693, IRGKangXi=1137.190, Def{(same as 瞫) to observe; to examine; to look deeply into}
4694 CJK UNIFIED IDEOGRAPH-#4694, IRGKangXi=1138.040, Def{to look suddenly; to look shortly}
4695 CJK UNIFIED IDEOGRAPH-#4695, IRGKangXi=1139.020, Def{to search out; to examine into, (Cant.) to give an angry glances at somebody}
4696 CJK UNIFIED IDEOGRAPH-#4696, IRGKangXi=1139.040, Def{mountain deity; with human face and animal body}
4697 CJK UNIFIED IDEOGRAPH-#4697, IRGKangXi=1140.150, Def{to lift; to raise}
4698 CJK UNIFIED IDEOGRAPH-#4698, IRGKangXi=1141.140, Def{the long and upright horns of cattle}
4699 CJK UNIFIED IDEOGRAPH-#4699, IRGKangXi=1141.170, Def{a spoon for cooked rice made of horn of an animal, uneven horns of cattle}
469A CJK UNIFIED IDEOGRAPH-#469A, IRGKangXi=1141.180, Def{horn of an animal}
469B CJK UNIFIED IDEOGRAPH-#469B, IRGKangXi=1143.100, Def{regulate; polish ivory to make it more white}
469C CJK UNIFIED IDEOGRAPH-#469C, IRGKangXi=1143.180, Def{cattle with crosswise horns, crosswise horns of a cattle}
469D CJK UNIFIED IDEOGRAPH-#469D, IRGKangXi=1143.250, Def{new-growing horns, to clasp or hold under the arm, to bosom; to embrace}
469E CJK UNIFIED IDEOGRAPH-#469E, IRGKangXi=1143.260, Def{the middle of the horn}
469F CJK UNIFIED IDEOGRAPH-#469F, IRGKangXi=1143.270, Def{horns, middle of the horn, (same as 歹) bad; wicked; depraved; vicious}
46A0 CJK UNIFIED IDEOGRAPH-#46A0, IRGKangXi=1143.330, Def{(ancient form) unbroken firewood, complete; whole; general, round horn, animal's horns, a whole horn}
46A1 CJK UNIFIED IDEOGRAPH-#46A1, IRGKangXi=1143.360, Def{bones in a horn of cattle and goat}
46A2 CJK UNIFIED IDEOGRAPH-#46A2, IRGKangXi=1143.380, Def{horn, jewelry; ornaments used for woman in old days, an eyelet for the hook of a leather belt, a second for childhood}
46A3 CJK UNIFIED IDEOGRAPH-#46A3, IRGKangXi=1144.090, Def{crooked horns of the animal}
46A4 CJK UNIFIED IDEOGRAPH-#46A4, IRGKangXi=1144.101
46A5 CJK UNIFIED IDEOGRAPH-#46A5, IRGKangXi=1144.110, Def{to adjust a bow}
46A6 CJK UNIFIED IDEOGRAPH-#46A6, IRGKangXi=1144.160, Def{slanted corners; curved corners, crooked horn}
46A7 CJK UNIFIED IDEOGRAPH-#46A7, IRGKangXi=1144.260, Def{curved with angles; curved corner}
46A8 CJK UNIFIED IDEOGRAPH-#46A8, IRGKangXi=1145.010, Def{a string fastened to an arrow to draw it back after shooting}
46A9 CJK UNIFIED IDEOGRAPH-#46A9, IRGKangXi=1145.060, Def{high; curved; long horns}
46AA CJK UNIFIED IDEOGRAPH-#46AA, IRGKangXi=1145.100, Def{curved horns, (non-classical form of 鱞 鰥) Huge fish found in the Yellow River, said to be unable to close its eyes}
46AB CJK UNIFIED IDEOGRAPH-#46AB, IRGKangXi=1145.140, Def{ornamental articles made of horns used to decorate the top of a stick or horsewhip, to hit; to beat}
46AC CJK UNIFIED IDEOGRAPH-#46AC, IRGKangXi=1145.081
46AD CJK UNIFIED IDEOGRAPH-#46AD, IRGKangXi=1145.290
46AE CJK UNIFIED IDEOGRAPH-#46AE, IRGKangXi=1146.080, Def{thicker, heavy, still; yet}
46AF CJK UNIFIED IDEOGRAPH-#46AF, IRGKangXi=1146.090, Def{(ancient form of 討) to quell (uprising, rebellion, etc.) to punish (another nation, etc.) by force fo arms, sound; voice; tone}
46B0 CJK UNIFIED IDEOGRAPH-#46B0, IRGKangXi=1146.140, Def{to prepare, all complete; all ready, (corrupted and abbreviated form of 訛) false; fake, errors; wrong}
46B1 CJK UNIFIED IDEOGRAPH-#46B1, IRGKangXi=1147.120, Def{(ancient form of 信) honesty; good faith; to believe or trust; a letter}
46B2 CJK UNIFIED IDEOGRAPH-#46B2, IRGKangXi=1148.050, Def{(non-classical form of 訕) to laugh at; to sneer, to slander; to abuse}
46B3 CJK UNIFIED IDEOGRAPH-#46B3, IRGKangXi=1149.050, Def{do not know, to know nothing about, quickly; fast, sharp; keen}
46B4 CJK UNIFIED IDEOGRAPH-#46B4, IRGKangXi=1149.100, Def{anger; rage; furious, to scold in a loud voice; to upbraid or revile}
46B5 CJK UNIFIED IDEOGRAPH-#46B5, IRGKangXi=1149.130, Def{to induce; to lure; to allure; to attract; to entice; to tempt; to seduce (with speech; words; through talking)}
46B6 CJK UNIFIED IDEOGRAPH-#46B6, IRGKangXi=1149.150, Def{to scold in a loud voice}
46B7 CJK UNIFIED IDEOGRAPH-#46B7, IRGKangXi=1149.170, Def{to treat; to detain, according to one's wishes, good words; honest; sincere words, an echo, joke; witticism; pleasantry; jest; fun}
46B8 CJK UNIFIED IDEOGRAPH-#46B8, IRGKangXi=1150.030, Def{good; virtuous}
46B9 CJK UNIFIED IDEOGRAPH-#46B9, IRGKangXi=1150.050, Def{(same as 庀) to prepare, to prepare, all complete; all ready}
46BA CJK UNIFIED IDEOGRAPH-#46BA, IRGKangXi=1150.100, Def{(non-classical form of 謠) ballad; folk song; song, rumor}
46BB CJK UNIFIED IDEOGRAPH-#46BB, IRGKangXi=1150.160, Def{(ancient form of 謠) to sing, a ballad, rumour; slander; a false report, from, to follow, to undertake; to attend to}
46BC CJK UNIFIED IDEOGRAPH-#46BC, IRGKangXi=1151.020, Def{ashamed}
46BD CJK UNIFIED IDEOGRAPH-#46BD, IRGKangXi=1151.040, Def{(interchangeable 耗) news; tidings; report; information; message}
46BE CJK UNIFIED IDEOGRAPH-#46BE, IRGKangXi=1152.050, Def{to think of; to remember (someone), to read out aloud, (same as U+46D8 䛘)}
46BF CJK UNIFIED IDEOGRAPH-#46BF, IRGKangXi=1151.060, Def{to shout in rage; angry shouts, angry speech, to cry continuously, to groan; to moan}
46C0 CJK UNIFIED IDEOGRAPH-#46C0, IRGKangXi=1151.120, Def{reasonable authority statements, (same as 呶) noise (especially from a brawling crowd); uproar; turmoil, abusive language, to boast}
46C1 CJK UNIFIED IDEOGRAPH-#46C1, IRGKangXi=1151.180, Def{(interchangeable 喃 諵) to murmur; in a low voice, to chatter; to gabble}
46C2 CJK UNIFIED IDEOGRAPH-#46C2, IRGKangXi=1152.070, Def{(same as 誃 謻) to separate from; to leave or depart; to break away, (same as 詑) to cheat; to swindle}
46C3 CJK UNIFIED IDEOGRAPH-#46C3, IRGKangXi=1152.080, Def{used in person's name}
46C4 CJK UNIFIED IDEOGRAPH-#46C4, IRGKangXi=1152.170, Def{to console; to comfort; to soothe; to show sympathy for, ill-will; enmity; animus}
46C5 CJK UNIFIED IDEOGRAPH-#46C5, IRGKangXi=1152.180, Def{loquacious}
46C6 CJK UNIFIED IDEOGRAPH-#46C6, IRGKangXi=1152.190, Def{(same as 咒 U+546A) to curse; to swear}
46C7 CJK UNIFIED IDEOGRAPH-#46C7, IRGKangXi=1152.230, Def{to laugh; to smile; to grin; to giggle; to titter; to chuckle, well-intentioned advice}
46C8 CJK UNIFIED IDEOGRAPH-#46C8, IRGKangXi=1153.100, Def{(interchangeable 誓) to vow; to swear; to take an oath}
46C9 CJK UNIFIED IDEOGRAPH-#46C9, IRGKangXi=1154.020, Def{to induce by words}
46CA CJK UNIFIED IDEOGRAPH-#46CA, IRGKangXi=1154.040, Def{cheerful all the time; without stopping, to tell; to say, to designated, to think}
46CB CJK UNIFIED IDEOGRAPH-#46CB, IRGKangXi=1154.090, Def{to scheme; to plan; to plot, to seek; to try to get}
46CC CJK UNIFIED IDEOGRAPH-#46CC, IRGKangXi=1155.050, Def{to provoke or arouse (ill-will, etc.) to cause disputes; to sow discord between two parties, to talk nonsense; to talk incoherently or unintelligibly; lies or wild talks}
46CD CJK UNIFIED IDEOGRAPH-#46CD, IRGKangXi=1155.060, Def{loquacious, to talk quickly}
46CE CJK UNIFIED IDEOGRAPH-#46CE, IRGKangXi=1155.080, Def{to shout in rage; to scold in anger}
46CF CJK UNIFIED IDEOGRAPH-#46CF, IRGKangXi=1155.110, Def{to call somebody, (same as 泥) to beg; to entreat; to implore, to be bigoted; to adhere to the letter of the law; bigoted and conservative, poor (speech)}
46D0 CJK UNIFIED IDEOGRAPH-#46D0, IRGKangXi=1156.110, Def{(same as 詞) an expression, words; phrases; a part of speech, tales; stroies, a form of poetry}
46D1 CJK UNIFIED IDEOGRAPH-#46D1, IRGKangXi=1156.120, Def{(same as 謐) silent; quiet; serene; still, cautious; careful}
46D2 CJK UNIFIED IDEOGRAPH-#46D2, IRGKangXi=1156.140, Def{(standard form of 辯) to argue; to dispute; to discuss; to explain}
46D3 CJK UNIFIED IDEOGRAPH-#46D3, IRGKangXi=1156.171, Def{(abbreviated form of 譼) (ancient form of 監) an official position in former times, a government establishment in former times}
46D4 CJK UNIFIED IDEOGRAPH-#46D4, IRGKangXi=1157.040, Def{to hold in hand; to grasp; to take, to arrest; to use, (non-classical form of 誽) to spy; to find out secretly}
46D5 CJK UNIFIED IDEOGRAPH-#46D5, IRGKangXi=1157.050, Def{(non-classical form of 諛) to flatter, flattery}
46D6 CJK UNIFIED IDEOGRAPH-#46D6, IRGKangXi=1157.060, Def{(same as 詍) loquacious}
46D7 CJK UNIFIED IDEOGRAPH-#46D7, IRGKangXi=1157.070, Def{to pry into or expose another's secret; to gossip about a man's private affairs or about his faults, to accuse or charge}
46D8 CJK UNIFIED IDEOGRAPH-#46D8, IRGKangXi=1157.090, Def{to think of; to remember (someone), to read out aloud, loquacious, guttural sound, noise; uproar; turmoil}
46D9 CJK UNIFIED IDEOGRAPH-#46D9, IRGKangXi=1158.050, Def{to smell the fragrance}
46DA CJK UNIFIED IDEOGRAPH-#46DA, IRGKangXi=1158.070, Def{to praise; to extol; to exalt; to glorify}
46DB CJK UNIFIED IDEOGRAPH-#46DB, IRGKangXi=1158.150, Def{(same as 詯) courage}
46DC CJK UNIFIED IDEOGRAPH-#46DC, IRGKangXi=1161.050, Def{(same as ancient form of 訊) to ask; to inquire; to question, information; news}
46DD CJK UNIFIED IDEOGRAPH-#46DD, IRGKangXi=1161.190, Def{to like, to puzzle}
46DE CJK UNIFIED IDEOGRAPH-#46DE, IRGKangXi=1161.200, Def{loquacity, boasting; hyperbole, to talk harshly; to shout angrily}
46DF CJK UNIFIED IDEOGRAPH-#46DF, IRGKangXi=1161.220, Def{(same as 唊) wild statements; deliberate lies}
46E0 CJK UNIFIED IDEOGRAPH-#46E0, IRGKangXi=1161.270, Def{unable to talk, incapable; inefficient}
46E1 CJK UNIFIED IDEOGRAPH-#46E1, IRGKangXi=1162.110, Def{(ancient form of 話) words; saying; talk, to speak}
46E2 CJK UNIFIED IDEOGRAPH-#46E2, IRGKangXi=1162.140, Def{cunning; crafty; sly; sily; artful}
46E3 CJK UNIFIED IDEOGRAPH-#46E3, IRGKangXi=1163.140, Def{speech; words, to say; to talk, negative, hesitate}
46E4 CJK UNIFIED IDEOGRAPH-#46E4, IRGKangXi=1163.190, Def{urgently; hastily; hurriedly, a hasty speech}
46E5 CJK UNIFIED IDEOGRAPH-#46E5, IRGKangXi=1163.210, Def{speech; word, a speech sound, tone (of one's speech), boasting}
46E6 CJK UNIFIED IDEOGRAPH-#46E6, IRGKangXi=1164.100, Def{(ancient form of 訟) litigation, to argue over}
46E7 CJK UNIFIED IDEOGRAPH-#46E7, IRGKangXi=1165.051, Def{(corrupted form of 謎) riddle, puzzle, conundrum}
46E8 CJK UNIFIED IDEOGRAPH-#46E8, IRGKangXi=1165.051
46E9 CJK UNIFIED IDEOGRAPH-#46E9, IRGKangXi=1165.060, Def{to slander; to defame, (same as 惡) to abominate; to detest, (same as 啞) to laugh; to grin}
46EA CJK UNIFIED IDEOGRAPH-#46EA, IRGKangXi=1165.070, Def{loquacity, to inquire; to ask; to make inquiry}
46EB CJK UNIFIED IDEOGRAPH-#46EB, IRGKangXi=1165.080, Def{to deceive; to delude, careless; lax; heedless}
46EC CJK UNIFIED IDEOGRAPH-#46EC, IRGKangXi=1165.180, Def{baby talk, to pray, to felicitate}
46ED CJK UNIFIED IDEOGRAPH-#46ED, IRGKangXi=1165.250, Def{angry, reproof; scolding}
46EE CJK UNIFIED IDEOGRAPH-#46EE, IRGKangXi=1166.020, Def{to destroy, to slander; to abuse; to defame, (non-classical form of 咎) a fault; a defect, an error, to blame; to censure}
46EF CJK UNIFIED IDEOGRAPH-#46EF, IRGKangXi=1166.060, Def{the reasonable of speeking}
46F0 CJK UNIFIED IDEOGRAPH-#46F0, IRGKangXi=1166.090, Def{(non-classical) sketchy; not clear speech}
46F1 CJK UNIFIED IDEOGRAPH-#46F1, IRGKangXi=1166.140, Def{to talk unremittingly}
46F2 CJK UNIFIED IDEOGRAPH-#46F2, IRGKangXi=1166.170, Def{(same as 謾) to deceive, to scorn; to disdain}
46F3 CJK UNIFIED IDEOGRAPH-#46F3, IRGKangXi=1167.050, Def{to malign, to hide; to conceal}
46F4 CJK UNIFIED IDEOGRAPH-#46F4, IRGKangXi=1168.040, Def{joke; pleasantry, wild talk; a lie}
46F5 CJK UNIFIED IDEOGRAPH-#46F5, IRGKangXi=1168.140, Def{(same as 授) to teach orally}
46F6 CJK UNIFIED IDEOGRAPH-#46F6, IRGKangXi=1169.070, Def{(same as 誄) writings eulogizing a dead person; a speech, ode, etc. in praise of the dead, to pray for the dead}
46F7 CJK UNIFIED IDEOGRAPH-#46F7, IRGKangXi=1169.080, Def{(same as 婉) to obey; obedient; to comply, to console; to comfort; to soothe}
46F8 CJK UNIFIED IDEOGRAPH-#46F8, IRGKangXi=1169.151, Def{(corrupted form of 詀) garrulous, to whisper, to joke}
46F9 CJK UNIFIED IDEOGRAPH-#46F9, IRGKangXi=1170.060, Def{to accuse; to censure; to charge}
46FA CJK UNIFIED IDEOGRAPH-#46FA, IRGKangXi=1170.140, Def{(same as 誡) to warn; to admonish}
46FB CJK UNIFIED IDEOGRAPH-#46FB, IRGKangXi=1171.060, Def{(same as 誘) to induce; to entice; to mislead; to lead on}
46FC CJK UNIFIED IDEOGRAPH-#46FC, IRGKangXi=1171.080, Def{(same as U+6BC0 毀) to slander; to defame}
46FD CJK UNIFIED IDEOGRAPH-#46FD, IRGKangXi=1173.060, Def{loquacious, to break into a conversation, an irrelevant episode}
46FE CJK UNIFIED IDEOGRAPH-#46FE, IRGKangXi=1176.040, Def{familiar with; skilled; versed in}
46FF CJK UNIFIED IDEOGRAPH-#46FF, IRGKangXi=1176.100, Def{cunning; craft; sly; wily; artful, bright; wise}
4700 CJK UNIFIED IDEOGRAPH-#4700, IRGKangXi=1177.021, Def{to insult with words}
4701 CJK UNIFIED IDEOGRAPH-#4701, IRGKangXi=1174.121, Def{(same as 謑) to abuse and insult, shame; disgrace}
4702 CJK UNIFIED IDEOGRAPH-#4702, IRGKangXi=1177.021
4703 CJK UNIFIED IDEOGRAPH-#4703, IRGKangXi=1177.110, Def{to blame; to reproach, to punish, to throw; to cast, (same as 堆) to pile; a heap}
4704 CJK UNIFIED IDEOGRAPH-#4704, IRGKangXi=1177.140, Def{(same as 謘) slow on talking; incapable; obtuse; awkward}
4705 CJK UNIFIED IDEOGRAPH-#4705, IRGKangXi=1177.290, Def{to follow; to comply with, to refute; to rebuke; to accuse}
4706 CJK UNIFIED IDEOGRAPH-#4706, IRGKangXi=1178.010, Def{(same as 讘) hasty words, loquacity, for the sake of comparison (large to small; big to little, etc.)}
4707 CJK UNIFIED IDEOGRAPH-#4707, IRGKangXi=1178.100, Def{to speak not in a clear way, (same as 謴) to play jokes on; to fool (somebody)}
4708 CJK UNIFIED IDEOGRAPH-#4708, IRGKangXi=1178.140, Def{(same as 勦) to speak on behalf of another, buzzing in the ears}
4709 CJK UNIFIED IDEOGRAPH-#4709, IRGKangXi=1178.160, Def{to jest; to joke; to quip (same as 誺) unintelligible answering}
470A CJK UNIFIED IDEOGRAPH-#470A, IRGKangXi=1178.220, Def{(same as U+5608 嘈) noise; uproar; din}
470B CJK UNIFIED IDEOGRAPH-#470B, IRGKangXi=1180.060, Def{to suspend; to interrupt, to become aware; to realize}
470C CJK UNIFIED IDEOGRAPH-#470C, IRGKangXi=1180.100, Def{(ancient form) chaos; distraction; confusion, confused, continuous; uninterruptedto tie together, to manage}
470D CJK UNIFIED IDEOGRAPH-#470D, IRGKangXi=1180.180, Def{sweet; artful words}
470E CJK UNIFIED IDEOGRAPH-#470E, IRGKangXi=1180.260, Def{sound, noisy; full of confused noises; clamorous}
470F CJK UNIFIED IDEOGRAPH-#470F, IRGKangXi=1181.090, Def{to withdraw; to decline, clever}
4710 CJK UNIFIED IDEOGRAPH-#4710, IRGKangXi=1181.100, Def{to libel; to slander, to make excuses; to shirk (responsibility, etc.)}
4711 CJK UNIFIED IDEOGRAPH-#4711, IRGKangXi=1181.130, Def{(same as U+46E9 䛩) to slander; to defame; (same as U+60E1 惡) to hate; to hold a grudge against}
4712 CJK UNIFIED IDEOGRAPH-#4712, IRGKangXi=1182.140, Def{expression; sentence, speech, to tell; to inform; to accuse; to report}
4713 CJK UNIFIED IDEOGRAPH-#4713, IRGKangXi=1182.160, Def{a slip of the tongue}
4714 CJK UNIFIED IDEOGRAPH-#4714, IRGKangXi=1182.170, Def{to speak on the ideas of someone else; to speak without much thought of ones own, to obey}
4715 CJK UNIFIED IDEOGRAPH-#4715, IRGKangXi=1182.200, Def{to exaggerate; exaggeration, arrogant; to boast, to dispute with anger}
4716 CJK UNIFIED IDEOGRAPH-#4716, IRGKangXi=1183.010, Def{(non-classical form) (same as 談) to talk; to converse; to chat}
4717 CJK UNIFIED IDEOGRAPH-#4717, IRGKangXi=1184.020, Def{angry words}
4718 CJK UNIFIED IDEOGRAPH-#4718, IRGKangXi=1184.070, Def{(same as 警) to guard; to keep watch; to warn; to alert, quick; agile}
4719 CJK UNIFIED IDEOGRAPH-#4719, IRGKangXi=1184.110, Def{not clever, to make fun of; to poke fun at}
471A CJK UNIFIED IDEOGRAPH-#471A, IRGKangXi=1184.250, Def{to speak recklessly or without forethought; a wild talk, use words to investigate}
471B CJK UNIFIED IDEOGRAPH-#471B, IRGKangXi=1184.260, Def{(non-classical form of 讒) to slander; to defame}
471C CJK UNIFIED IDEOGRAPH-#471C, IRGKangXi=1184.300, Def{words of anger; words of dislike or hate}
471D CJK UNIFIED IDEOGRAPH-#471D, IRGKangXi=1185.090, Def{uncertain}
471E CJK UNIFIED IDEOGRAPH-#471E, IRGKangXi=1185.130, Def{a dose, prepared medicines or drugs, to prepare (medicines and drugs)}
471F CJK UNIFIED IDEOGRAPH-#471F, IRGKangXi=1185.230, Def{(non-classical form of 讖) to verify; to fulfill (a prophecy); a hint, an omen}
4720 CJK UNIFIED IDEOGRAPH-#4720, IRGKangXi=1185.260, Def{language of the savage or barbarian}
4721 CJK UNIFIED IDEOGRAPH-#4721, IRGKangXi=1185.360, Def{to smell a fragrance}
4722 CJK UNIFIED IDEOGRAPH-#4722, IRGKangXi=1186.100, Def{cruel and violent}
4723 CJK UNIFIED IDEOGRAPH-#4723, IRGKangXi=1188.181, Def{(simplified form of 訢) (same as 欣) joy; delight; happy}
4724 CJK UNIFIED IDEOGRAPH-#4724, IRGKangXi=1188.181
4725 CJK UNIFIED IDEOGRAPH-#4725, IRGKangXi=1188.181, Def{birthday; to be born, give birth to}
4726 CJK UNIFIED IDEOGRAPH-#4726, IRGKangXi=1188.181
4727 CJK UNIFIED IDEOGRAPH-#4727, IRGKangXi=1188.181, Def{to insult with words}
4728 CJK UNIFIED IDEOGRAPH-#4728, IRGKangXi=1188.181
4729 CJK UNIFIED IDEOGRAPH-#4729, IRGKangXi=1188.181, Def{(simplified form of 讌) a feast, banquet; to entertain, feast}
472A CJK UNIFIED IDEOGRAPH-#472A, IRGKangXi=1189.030, Def{name of a pavilion in old times}
472B CJK UNIFIED IDEOGRAPH-#472B, IRGKangXi=1189.060, Def{name of a valley in today's Hobei Province, (same as 谼) deep ditch; big valley}
472C CJK UNIFIED IDEOGRAPH-#472C, IRGKangXi=1190.030, Def{(same as 岫) a cavern; a cave, a mountain peak}
472D CJK UNIFIED IDEOGRAPH-#472D, IRGKangXi=1190.040, Def{(same as 濬 浚) to dredge; to dig or wash (a well, etc.), (same as 睿) wise and clever}
472E CJK UNIFIED IDEOGRAPH-#472E, IRGKangXi=1190.100, Def{deep valley}
472F CJK UNIFIED IDEOGRAPH-#472F, IRGKangXi=1190.120, Def{name of a valley in today's Shanxi Province}
4730 CJK UNIFIED IDEOGRAPH-#4730, IRGKangXi=1190.241, Def{deep valley}
4731 CJK UNIFIED IDEOGRAPH-#4731, IRGKangXi=1190.270, Def{name of a pavilion in today's Shanxi Province}
4732 CJK UNIFIED IDEOGRAPH-#4732, IRGKangXi=1191.090, Def{name of a village in old China, name of a valley}
4733 CJK UNIFIED IDEOGRAPH-#4733, IRGKangXi=1191.171
4734 CJK UNIFIED IDEOGRAPH-#4734, IRGKangXi=1191.220, Def{brave; courageous; bold, for the good of, to manage; to handle, (same as 豉) fermented beans}
4735 CJK UNIFIED IDEOGRAPH-#4735, IRGKangXi=1192.031, Def{(non-classical form of 豉) fermented beans}
4736 CJK UNIFIED IDEOGRAPH-#4736, IRGKangXi=1192.050, Def{a small kidney bean; cowpea}
4737 CJK UNIFIED IDEOGRAPH-#4737, IRGKangXi=1192.100, Def{fermented and seasoned soybeans, (of beans) wild; undomesticated}
4738 CJK UNIFIED IDEOGRAPH-#4738, IRGKangXi=1192.140, Def{small pieces of bean-stalks, leaves under the bean-stalks}
4739 CJK UNIFIED IDEOGRAPH-#4739, IRGKangXi=1192.141
473A CJK UNIFIED IDEOGRAPH-#473A, IRGKangXi=1192.170, Def{husking (smashed) beans for cake, congee or gruel}
473B CJK UNIFIED IDEOGRAPH-#473B, IRGKangXi=1192.250, Def{(same as 豉) fermented beans}
473C CJK UNIFIED IDEOGRAPH-#473C, IRGKangXi=1192.260, Def{a kind of bean, bean-stalks}
473D CJK UNIFIED IDEOGRAPH-#473D, IRGKangXi=1192.280, Def{a kind of bean, beans that changed the colors}
473E CJK UNIFIED IDEOGRAPH-#473E, IRGKangXi=1192.290, Def{fermented beans; salted beans}
473F CJK UNIFIED IDEOGRAPH-#473F, IRGKangXi=1192.291
4740 CJK UNIFIED IDEOGRAPH-#4740, IRGKangXi=1193.020, Def{garden peas (Pisum sativum), an ancient name for beans used in Shanxi}
4741 CJK UNIFIED IDEOGRAPH-#4741, IRGKangXi=1193.030, Def{a kind of wild leguminous plants; wild green lentils}
4742 CJK UNIFIED IDEOGRAPH-#4742, IRGKangXi=1193.090, Def{(same as 豎) to erect; upright}
4743 CJK UNIFIED IDEOGRAPH-#4743, IRGKangXi=1193.270, Def{beans}
4744 CJK UNIFIED IDEOGRAPH-#4744, IRGKangXi=1193.300, Def{cowpea}
4745 CJK UNIFIED IDEOGRAPH-#4745, IRGKangXi=1194.140, Def{a pig}
4746 CJK UNIFIED IDEOGRAPH-#4746, IRGKangXi=1194.160, Def{hog; pig}
4747 CJK UNIFIED IDEOGRAPH-#4747, IRGKangXi=1195.090, Def{(standard form of 豗) grunting of pigs, to clash, sound of altercation}
4748 CJK UNIFIED IDEOGRAPH-#4748, IRGKangXi=1195.030, Def{a large, very strong pig (five hands in height)}
4749 CJK UNIFIED IDEOGRAPH-#4749, IRGKangXi=1196.181
474A CJK UNIFIED IDEOGRAPH-#474A, IRGKangXi=1197.090, Def{a sow; an aged sow}
474B CJK UNIFIED IDEOGRAPH-#474B, IRGKangXi=1197.150, Def{a little of pigs; a little pig, a boar}
474C CJK UNIFIED IDEOGRAPH-#474C, IRGKangXi=1197.170, Def{a pig seek for food through digging on the earth}
474D CJK UNIFIED IDEOGRAPH-#474D, IRGKangXi=1197.250, Def{a wild boar, a hog; a pig}
474E CJK UNIFIED IDEOGRAPH-#474E, IRGKangXi=1197.260, Def{a pig; a hog, a kind of fat animal looks like a pig}
474F CJK UNIFIED IDEOGRAPH-#474F, IRGKangXi=1199.030, Def{a sow}
4750 CJK UNIFIED IDEOGRAPH-#4750, IRGKangXi=1199.070, Def{a castrated hog, a pig}
4751 CJK UNIFIED IDEOGRAPH-#4751, IRGKangXi=1199.080, Def{a local produced pig, a sucking pig}
4752 CJK UNIFIED IDEOGRAPH-#4752, IRGKangXi=1199.200, Def{a sow, a small pig}
4753 CJK UNIFIED IDEOGRAPH-#4753, IRGKangXi=1199.250, Def{(same as 鬣) long beard or whiskers, mane, fins}
4754 CJK UNIFIED IDEOGRAPH-#4754, IRGKangXi=1199.310, Def{(same as 貛) the badger; a wild boar}
4755 CJK UNIFIED IDEOGRAPH-#4755, IRGKangXi=1199.320, Def{good, fine pig; an ancient term for pigs used in Liangzhou}
4756 CJK UNIFIED IDEOGRAPH-#4756, IRGKangXi=1200.030, Def{reptiles without feet, a fabulous beast}
4757 CJK UNIFIED IDEOGRAPH-#4757, IRGKangXi=1200.100, Def{(same as 貅) a kind of animal like a tiger; a fierce and courageous soldier}
4758 CJK UNIFIED IDEOGRAPH-#4758, IRGKangXi=1200.120, Def{(same as 毅) firm; resolute; determined}
4759 CJK UNIFIED IDEOGRAPH-#4759, IRGKangXi=1200.121, Def{a kind of animal like a tiger; fierce wild beasts}
475A CJK UNIFIED IDEOGRAPH-#475A, IRGKangXi=1200.150, Def{a kind of animal; fur can be used for clothes}
475B CJK UNIFIED IDEOGRAPH-#475B, IRGKangXi=1200.321
475C CJK UNIFIED IDEOGRAPH-#475C, IRGKangXi=1201.230, Def{(same as U+72FB 狻) a Tibetan lion}
475D CJK UNIFIED IDEOGRAPH-#475D, IRGKangXi=1202.150, Def{(same as 猗) an exclamation indicating admiration, an adverbial particle}
475E CJK UNIFIED IDEOGRAPH-#475E, IRGKangXi=1202.180, Def{name of a immortal; with man's face and bird's body; be known as (禺號)}
475F CJK UNIFIED IDEOGRAPH-#475F, IRGKangXi=1202.210, Def{a fierce man-eating animal in legend}
4760 CJK UNIFIED IDEOGRAPH-#4760, IRGKangXi=1203.010, Def{(same as 獂) a kind of wild boar}
4761 CJK UNIFIED IDEOGRAPH-#4761, IRGKangXi=1203.080, Def{(same as 獌) an animal in old times; like fox but much bigger}
4762 CJK UNIFIED IDEOGRAPH-#4762, IRGKangXi=1203.130, Def{same as U+734C 獌 or U+8C99 貙}
4763 CJK UNIFIED IDEOGRAPH-#4763, IRGKangXi=1203.180, Def{a kind of animal}
4764 CJK UNIFIED IDEOGRAPH-#4764, IRGKangXi=1203.190, Def{a primitive tribe in southwest China; also known as U+5937 夷; (same as U+7360 獠) nocturnal hunting}
4765 CJK UNIFIED IDEOGRAPH-#4765, IRGKangXi=1203.210, Def{to roar or howl (of beasts) frantic barks of dogs or wolves}
4766 CJK UNIFIED IDEOGRAPH-#4766, IRGKangXi=1203.220, Def{a kind of animal looks like leopard; with horns}
4767 CJK UNIFIED IDEOGRAPH-#4767, IRGKangXi=1205.090, Def{capital (in business), to compute taxes}
4768 CJK UNIFIED IDEOGRAPH-#4768, IRGKangXi=1206.061, Def{(non-classical form of 賢) virtuous; worthy; good, to esteem as worthy, excelling}
4769 CJK UNIFIED IDEOGRAPH-#4769, IRGKangXi=1206.070, Def{(same as 賑) to relieve or give aid to the distressed; to support, rich; wealthy}
476A CJK UNIFIED IDEOGRAPH-#476A, IRGKangXi=1206.110, Def{to provide money or gift and to consult fortune-teller; pay for guidance from divination}
476B CJK UNIFIED IDEOGRAPH-#476B, IRGKangXi=1206.230, Def{money; currency and finances}
476C CJK UNIFIED IDEOGRAPH-#476C, IRGKangXi=1206.250, Def{a wealthy man}
476D CJK UNIFIED IDEOGRAPH-#476D, IRGKangXi=1207.010, Def{wages; salary, to redeem; to ransom}
476E CJK UNIFIED IDEOGRAPH-#476E, IRGKangXi=1207.110, Def{(same as 衒) to brag; to boast; to show off}
476F CJK UNIFIED IDEOGRAPH-#476F, IRGKangXi=1207.130, Def{(same as 貤) to change hands; to shift, a series, steps; grades, to promote; to reward; ennobled; to bestow, to extend; to prolong}
4770 CJK UNIFIED IDEOGRAPH-#4770, IRGKangXi=1208.060, Def{to store or to accumulate riches or valuables}
4771 CJK UNIFIED IDEOGRAPH-#4771, IRGKangXi=1208.090, Def{to trouble; to worry; to vex; to annoy}
4772 CJK UNIFIED IDEOGRAPH-#4772, IRGKangXi=1208.241, Def{(abbreviated form 贐) farewell presents}
4773 CJK UNIFIED IDEOGRAPH-#4773, IRGKangXi=1208.270, Def{to kill for money; to commit murder for money, deeply meaningful; deep and profound; deep and thick}
4774 CJK UNIFIED IDEOGRAPH-#4774, IRGKangXi=1208.300, Def{(non-classical form of 齎) to present; to offer; to entertain; to have in one's mind}
4775 CJK UNIFIED IDEOGRAPH-#4775, IRGKangXi=1208.360, Def{to thank with money or gifts}
4776 CJK UNIFIED IDEOGRAPH-#4776, IRGKangXi=1209.120, Def{to levy taxes}
4777 CJK UNIFIED IDEOGRAPH-#4777, IRGKangXi=1209.170, Def{securities; to assign something as security under an arrangement; to mortgage, to relieve or give aid to the distressed; to support}
4778 CJK UNIFIED IDEOGRAPH-#4778, IRGKangXi=1209.180, Def{a kind of tool; instrument; apparatus; implement}
4779 CJK UNIFIED IDEOGRAPH-#4779, IRGKangXi=1209.200, Def{fairly prosperous, well-to-do; not very rich}
477A CJK UNIFIED IDEOGRAPH-#477A, IRGKangXi=1209.260, Def{(non-classical form of 貫) to pierce through}
477B CJK UNIFIED IDEOGRAPH-#477B, IRGKangXi=1209.270, Def{to sell, to store up; to stockpile; to deposit}
477C CJK UNIFIED IDEOGRAPH-#477C, IRGKangXi=1210.020, Def{to bestow, to confer upon; to grant to}
477D CJK UNIFIED IDEOGRAPH-#477D, IRGKangXi=1210.080, Def{name of a person in old China}
477E CJK UNIFIED IDEOGRAPH-#477E, IRGKangXi=1210.110, Def{to bestow; to give, natural endowment or gifts, tax; revenue, to spread; to diffuse, to compose or sing, one of the Chinese literary forms akin to poetry}
477F CJK UNIFIED IDEOGRAPH-#477F, IRGKangXi=1210.210, Def{(ancient form of 貴) honorable, expensive; costly, prized, high-class, to hold in honor}
4780 CJK UNIFIED IDEOGRAPH-#4780, IRGKangXi=1210.220, Def{to desire for more money than one's rightful share}
4781 CJK UNIFIED IDEOGRAPH-#4781, IRGKangXi=1210.260, Def{corresponding; equivalent, appropriate, to compare the length of two articles}
4782 CJK UNIFIED IDEOGRAPH-#4782, IRGKangXi=1211.010, Def{fairly prosperous, well-to-do; not very rich}
4783 CJK UNIFIED IDEOGRAPH-#4783, IRGKangXi=1211.030, Def{to relieve or give aid to the distressed; to support, shells; precious; valuable}
4784 CJK UNIFIED IDEOGRAPH-#4784, IRGKangXi=1211.060, Def{(interchangeable 俵) to disperse; scattered, to distribute; to divide}
4785 CJK UNIFIED IDEOGRAPH-#4785, IRGKangXi=1211.190, Def{(non-classical form of 貽) to give to; to present to, to hand down; to pass on to; to bequeath}
4786 CJK UNIFIED IDEOGRAPH-#4786, IRGKangXi=1211.260, Def{bone, grease and oil}
4787 CJK UNIFIED IDEOGRAPH-#4787, IRGKangXi=1212.051, Def{gifts to superiors or friends, offerings of ceremony}
4788 CJK UNIFIED IDEOGRAPH-#4788, IRGKangXi=1212.100, Def{(ancient form of 貨) money; wealth, natural endowment or gifts, to aid or help, to gamble; to bet, to compete}
4789 CJK UNIFIED IDEOGRAPH-#4789, IRGKangXi=1212.351, Def{(same as 賸) a surplus; an overplus, remains, superfluous}
478A CJK UNIFIED IDEOGRAPH-#478A, IRGKangXi=1213.061, Def{to increase; to add to; to augment, in a higher degree; more, benefit; profit; advantage}
478B CJK UNIFIED IDEOGRAPH-#478B, IRGKangXi=1213.140, Def{to do alms for the Buddhist priests or monks in old times, to bestow; to present; to confer; to give; to donate}
478C CJK UNIFIED IDEOGRAPH-#478C, IRGKangXi=1213.211, Def{to lose in trade; to lose in weight or measure}
478D CJK UNIFIED IDEOGRAPH-#478D, IRGKangXi=1213.211, Def{(simplified form of U+477C 䝼) to bestow, to confer upon; to grant to}
478E CJK UNIFIED IDEOGRAPH-#478E, IRGKangXi=1213.211
478F CJK UNIFIED IDEOGRAPH-#478F, IRGKangXi=1213.211
4790 CJK UNIFIED IDEOGRAPH-#4790, IRGKangXi=1213.211, Def{plentiful, wealthy or rich; handsome (pay, gifts, etc.)}
4791 CJK UNIFIED IDEOGRAPH-#4791, IRGKangXi=1213.260, Def{a red swelling of the skin}
4792 CJK UNIFIED IDEOGRAPH-#4792, IRGKangXi=1214.070, Def{red color}
4793 CJK UNIFIED IDEOGRAPH-#4793, IRGKangXi=1214.100, Def{(same as U+8D6C 赬) deep red, to blush, to dye red}
4794 CJK UNIFIED IDEOGRAPH-#4794, IRGKangXi=1214.110, Def{deep red}
4795 CJK UNIFIED IDEOGRAPH-#4795, IRGKangXi=1214.250, Def{color of the fire, color fading, (interchangeable 渝) to change mind, another name of Chongqing}
4796 CJK UNIFIED IDEOGRAPH-#4796, IRGKangXi=1215.100, Def{name of a person}
4797 CJK UNIFIED IDEOGRAPH-#4797, IRGKangXi=1215.130, Def{suspicion; to doubt, to go up, to start, to occur}
4798 CJK UNIFIED IDEOGRAPH-#4798, IRGKangXi=1215.140, Def{to go straight forward; (Cant.) to raise up}
4799 CJK UNIFIED IDEOGRAPH-#4799, IRGKangXi=1215.320, Def{to walk in hurriedly}
479A CJK UNIFIED IDEOGRAPH-#479A, IRGKangXi=1215.360, Def{to hang on a big tree, to walk (the way of Alces machlis, a kind of deer)}
479B CJK UNIFIED IDEOGRAPH-#479B, IRGKangXi=1215.390, Def{dancing of a eastern minority group in old China}
479C CJK UNIFIED IDEOGRAPH-#479C, IRGKangXi=1215.441, Def{to reach; to arrive, to lie flat, stiff}
479D CJK UNIFIED IDEOGRAPH-#479D, IRGKangXi=1216.040, Def{lame; crippled}
479E CJK UNIFIED IDEOGRAPH-#479E, IRGKangXi=1216.050, Def{to walk, to jump; to leap; to bounce; to spring}
479F CJK UNIFIED IDEOGRAPH-#479F, IRGKangXi=1216.070, Def{to press; to compel, to draw near, to excel; to surpass; to rise above; to transcend, to fly across; to jump over}
47A0 CJK UNIFIED IDEOGRAPH-#47A0, IRGKangXi=1216.110, Def{to walk}
47A1 CJK UNIFIED IDEOGRAPH-#47A1, IRGKangXi=1216.120, Def{to walk}
47A2 CJK UNIFIED IDEOGRAPH-#47A2, IRGKangXi=1216.200, Def{to walk}
47A3 CJK UNIFIED IDEOGRAPH-#47A3, IRGKangXi=1216.240, Def{to resist; to hold out, angry, to break up; to split, half step, evil; wicked; mean; vicious}
47A4 CJK UNIFIED IDEOGRAPH-#47A4, IRGKangXi=1216.250, Def{to walk, to use; to employ, to control}
47A5 CJK UNIFIED IDEOGRAPH-#47A5, IRGKangXi=1216.330, Def{to walk}
47A6 CJK UNIFIED IDEOGRAPH-#47A6, IRGKangXi=1217.010, Def{to lie flat, to be inactive; stiff; rigid, dead-locked}
47A7 CJK UNIFIED IDEOGRAPH-#47A7, IRGKangXi=1217.020, Def{hard to walk, lame; crippled}
47A8 CJK UNIFIED IDEOGRAPH-#47A8, IRGKangXi=1217.060, Def{(same as 跬) half a pace}
47A9 CJK UNIFIED IDEOGRAPH-#47A9, IRGKangXi=1217.170, Def{lame; crippled}
47AA CJK UNIFIED IDEOGRAPH-#47AA, IRGKangXi=1217.230, Def{walking rapidly}
47AB CJK UNIFIED IDEOGRAPH-#47AB, IRGKangXi=1217.300, Def{to walk}
47AC CJK UNIFIED IDEOGRAPH-#47AC, IRGKangXi=1217.330, Def{(same as 透) to pass through, to let out; to let through}
47AD CJK UNIFIED IDEOGRAPH-#47AD, IRGKangXi=1217.370, Def{walking rapidly, to go ahead, to move quickly; to run; to hurry}
47AE CJK UNIFIED IDEOGRAPH-#47AE, IRGKangXi=1217.380, Def{to crawl; to creep}
47AF CJK UNIFIED IDEOGRAPH-#47AF, IRGKangXi=1217.390, Def{to walk, to move quickly; to run; to hurry, to reach the time-limit; to mature}
47B0 CJK UNIFIED IDEOGRAPH-#47B0, IRGKangXi=1217.440, Def{walking rapidly}
47B1 CJK UNIFIED IDEOGRAPH-#47B1, IRGKangXi=1217.450, Def{to fall over; to lie down}
47B2 CJK UNIFIED IDEOGRAPH-#47B2, IRGKangXi=1218.071
47B3 CJK UNIFIED IDEOGRAPH-#47B3, IRGKangXi=1218.100, Def{(same as 踣) to stumble and fall}
47B4 CJK UNIFIED IDEOGRAPH-#47B4, IRGKangXi=1218.160, Def{to jump; to leap; to hop, limping; walking unsteadily; limping}
47B5 CJK UNIFIED IDEOGRAPH-#47B5, IRGKangXi=1218.180, Def{to jump}
47B6 CJK UNIFIED IDEOGRAPH-#47B6, IRGKangXi=1218.250, Def{walking rapidly}
47B7 CJK UNIFIED IDEOGRAPH-#47B7, IRGKangXi=1218.290, Def{(same as 趉) walking rapidly, to walk}
47B8 CJK UNIFIED IDEOGRAPH-#47B8, IRGKangXi=1218.421, Def{(corrupted and non-classical form) to reach; to arrive, (same as 仆) to fall; to prostrate}
47B9 CJK UNIFIED IDEOGRAPH-#47B9, IRGKangXi=1218.430, Def{to walk}
47BA CJK UNIFIED IDEOGRAPH-#47BA, IRGKangXi=1218.440, Def{to walk}
47BB CJK UNIFIED IDEOGRAPH-#47BB, IRGKangXi=1219.040, Def{to walk}
47BC CJK UNIFIED IDEOGRAPH-#47BC, IRGKangXi=1219.150, Def{(same as 竄) to escape; to run away; to flee, to banish, to change or alter (the wording)}
47BD CJK UNIFIED IDEOGRAPH-#47BD, IRGKangXi=1219.190, Def{to lie flat, stiff; rigid; to be inactive, dead-locked}
47BE CJK UNIFIED IDEOGRAPH-#47BE, IRGKangXi=1219.200, Def{frivolous; contemptuous, to despise; to speak ill of}
47BF CJK UNIFIED IDEOGRAPH-#47BF, IRGKangXi=1219.270, Def{(interchangeable 蹇) lame; crippled, slow, weak; feeble, difficult; hard}
47C0 CJK UNIFIED IDEOGRAPH-#47C0, IRGKangXi=1219.320, Def{to walk}
47C1 CJK UNIFIED IDEOGRAPH-#47C1, IRGKangXi=1219.410, Def{a foot-race}
47C2 CJK UNIFIED IDEOGRAPH-#47C2, IRGKangXi=1219.450, Def{slow; tardy}
47C3 CJK UNIFIED IDEOGRAPH-#47C3, IRGKangXi=1219.460, Def{to move or march swiftly; to walk quickly; to run, to go; to go to a meeting}
47C4 CJK UNIFIED IDEOGRAPH-#47C4, IRGKangXi=1219.500, Def{in a hurry, deceitful; cunning; swindling; wily, to walk quickly}
47C5 CJK UNIFIED IDEOGRAPH-#47C5, IRGKangXi=1219.530, Def{to go ahead; to proceed; to advance, to jump; to leap swiftly, brief; short period}
47C6 CJK UNIFIED IDEOGRAPH-#47C6, IRGKangXi=1220.010, Def{to keep persons off the route of the emperor, when on tour, imperial halting-place, worship of the kitchen god (performed on the 23rd day of the 12th moon)}
47C7 CJK UNIFIED IDEOGRAPH-#47C7, IRGKangXi=1220.100, Def{to walk}
47C8 CJK UNIFIED IDEOGRAPH-#47C8, IRGKangXi=1220.250, Def{to walk}
47C9 CJK UNIFIED IDEOGRAPH-#47C9, IRGKangXi=1220.270, Def{to walk, toddling, jump; leap}
47CA CJK UNIFIED IDEOGRAPH-#47CA, IRGKangXi=1220.280, Def{short strides, with rapid strides, swiftly; quickly}
47CB CJK UNIFIED IDEOGRAPH-#47CB, IRGKangXi=1220.300, Def{to press forward; to go in haste; to run quickly}
47CC CJK UNIFIED IDEOGRAPH-#47CC, IRGKangXi=1220.421, Def{(standard form) diverging, to go, to walk}
47CD CJK UNIFIED IDEOGRAPH-#47CD, IRGKangXi=1220.440, Def{to walk; to travel, to go}
47CE CJK UNIFIED IDEOGRAPH-#47CE, IRGKangXi=1220.450
47CF CJK UNIFIED IDEOGRAPH-#47CF, IRGKangXi=1221.010, Def{to jump; to leap; to bounce; to spring, to run over; to oppress}
47D0 CJK UNIFIED IDEOGRAPH-#47D0, IRGKangXi=1221.060, Def{to walk, agile; adroit, a method of wielding the brush in writing Chinese characters}
47D1 CJK UNIFIED IDEOGRAPH-#47D1, IRGKangXi=1221.080, Def{walking rapidly, (ancient form of 躍) to jump; to leap; to bound; to spring}
47D2 CJK UNIFIED IDEOGRAPH-#47D2, IRGKangXi=1221.110, Def{coiled; curled; not stretched; contracted}
47D3 CJK UNIFIED IDEOGRAPH-#47D3, IRGKangXi=1221.220, Def{to walk slowly, lame; crippled, long and thin legs, to walk alone, to insist on one's ways in doing things}
47D4 CJK UNIFIED IDEOGRAPH-#47D4, IRGKangXi=1221.250, Def{(same as 赴) to go to; to attend (same as 踣) to stumble and fall prone, stiff in death}
47D5 CJK UNIFIED IDEOGRAPH-#47D5, IRGKangXi=1221.320, Def{to step upon; to tread upon; to trample, a path branching out from the main road; a diverging road}
47D6 CJK UNIFIED IDEOGRAPH-#47D6, IRGKangXi=1221.350
47D7 CJK UNIFIED IDEOGRAPH-#47D7, IRGKangXi=1221.370, Def{to stand for a long time, to accumulate; to amass; to store up}
47D8 CJK UNIFIED IDEOGRAPH-#47D8, IRGKangXi=1222.060, Def{to straighten; to stretch out}
47D9 CJK UNIFIED IDEOGRAPH-#47D9, IRGKangXi=1222.080, Def{to stagger; to fall; to drop; to stumble}
47DA CJK UNIFIED IDEOGRAPH-#47DA, IRGKangXi=1222.090, Def{(same as 踑) to sit with the legs spread out; to squat with the legs crossed, traces; footsteps, to follow up; to search out}
47DB CJK UNIFIED IDEOGRAPH-#47DB, IRGKangXi=1222.120, Def{walking rapidly; in a hurry, to stride over; to step across}
47DC CJK UNIFIED IDEOGRAPH-#47DC, IRGKangXi=1222.130, Def{break; damage, wound of the foot, to walk}
47DD CJK UNIFIED IDEOGRAPH-#47DD, IRGKangXi=1222.180, Def{to walk right into}
47DE CJK UNIFIED IDEOGRAPH-#47DE, IRGKangXi=1222.220, Def{to falter; to hesitate}
47DF CJK UNIFIED IDEOGRAPH-#47DF, IRGKangXi=1222.330, Def{urgent; pressed for time}
47E0 CJK UNIFIED IDEOGRAPH-#47E0, IRGKangXi=1222.350, Def{swift; walking rapidly, (same as 越) to go beyond; to go across; to transgress; to skip}
47E1 CJK UNIFIED IDEOGRAPH-#47E1, IRGKangXi=1222.370, Def{to trample; to tread down, (same as 胝) callosities on the hands or feet}
47E2 CJK UNIFIED IDEOGRAPH-#47E2, IRGKangXi=1222.380, Def{(non-classical form of 跈), (same as 踐) to step upon; to tread upon; to trample, (same as 趁) to take advantage, hard to proceeding}
47E3 CJK UNIFIED IDEOGRAPH-#47E3, IRGKangXi=1223.010, Def{an animal in legend, traces or footprints of an animal}
47E4 CJK UNIFIED IDEOGRAPH-#47E4, IRGKangXi=1223.020
47E5 CJK UNIFIED IDEOGRAPH-#47E5, IRGKangXi=1223.060, Def{(same as 髳) luxuriant; exuberant; lush of the grass, trees and vegetation}
47E6 CJK UNIFIED IDEOGRAPH-#47E6, IRGKangXi=1223.100, Def{(non-classical of 跋) to walk; to travel, the heel}
47E7 CJK UNIFIED IDEOGRAPH-#47E7, IRGKangXi=1223.110, Def{sound of treading or stepping}
47E8 CJK UNIFIED IDEOGRAPH-#47E8, IRGKangXi=1223.170, Def{lame; crippled, to go across; to go beyond, hoofs of the animal}
47E9 CJK UNIFIED IDEOGRAPH-#47E9, IRGKangXi=1223.190, Def{hard of walk forward}
47EA CJK UNIFIED IDEOGRAPH-#47EA, IRGKangXi=1223.210, Def{(same as 覂) repeatedly; over and over again}
47EB CJK UNIFIED IDEOGRAPH-#47EB, IRGKangXi=1223.320, Def{(Cant.) to press down or push out with the foot; to pedal, kick, tread, step on}
47EC CJK UNIFIED IDEOGRAPH-#47EC, IRGKangXi=1223.330, Def{to walk}
47ED CJK UNIFIED IDEOGRAPH-#47ED, IRGKangXi=1224.090, Def{(non-classical form of 跳) to jump; to leap; to bounce; to spring, (same as 阼) the main steps; the throne; the steps leading to the eastern door}
47EE CJK UNIFIED IDEOGRAPH-#47EE, IRGKangXi=1224.250, Def{(same as 匐) to crawl on hands and knees, to fall in ruins; to slip down}
47EF CJK UNIFIED IDEOGRAPH-#47EF, IRGKangXi=1225.040, Def{to tread on, to kick}
47F0 CJK UNIFIED IDEOGRAPH-#47F0, IRGKangXi=1226.080, Def{to walk}
47F1 CJK UNIFIED IDEOGRAPH-#47F1, IRGKangXi=1226.091, Def{(same as 迹) traces, footsteps, to follow up; to search out}
47F2 CJK UNIFIED IDEOGRAPH-#47F2, IRGKangXi=1226.091
47F3 CJK UNIFIED IDEOGRAPH-#47F3, IRGKangXi=1226.091
47F4 CJK UNIFIED IDEOGRAPH-#47F4, IRGKangXi=1226.240, Def{to shake; to vibrate; to move, to be shocked or shaken}
47F5 CJK UNIFIED IDEOGRAPH-#47F5, IRGKangXi=1226.280, Def{to tread on}
47F6 CJK UNIFIED IDEOGRAPH-#47F6, IRGKangXi=1226.290, Def{(same as 蓌) to squat; to crouch, setback; defeat; failure; not doing well; disappointed; very discouraged; frustrated}
47F7 CJK UNIFIED IDEOGRAPH-#47F7, IRGKangXi=1226.310, Def{to jump; to leap; to bounce; to spring, to pass over; to go beyond; to transgress; to exceed, lame; crippled}
47F8 CJK UNIFIED IDEOGRAPH-#47F8, IRGKangXi=1226.330, Def{the calf; muscles; tissue of the part of leg between the knee and ankle, to stumble; to slip, the instep, to jump; to leap, a disease of the feet}
47F9 CJK UNIFIED IDEOGRAPH-#47F9, IRGKangXi=1226.370, Def{to hop about; to fling oneself about in temper, to pass over; to go beyond; to exceed}
47FA CJK UNIFIED IDEOGRAPH-#47FA, IRGKangXi=1226.420, Def{walk slowly because of the wrong position of the feet, (same as 狽) a kind of wolf with shorter forelegs, lame; crippled}
47FB CJK UNIFIED IDEOGRAPH-#47FB, IRGKangXi=1226.430, Def{bare feet; bare-footed, to walk in bare feet, hard to go forward}
47FC CJK UNIFIED IDEOGRAPH-#47FC, IRGKangXi=1226.440, Def{footprints; track, whereabout}
47FD CJK UNIFIED IDEOGRAPH-#47FD, IRGKangXi=1227.091, Def{(same as 疏) scattered or dispersed}
47FE CJK UNIFIED IDEOGRAPH-#47FE, IRGKangXi=1227.130, Def{to jump; to leap; to bounce; to spring, (same as U+47B5 䞵)}
47FF CJK UNIFIED IDEOGRAPH-#47FF, IRGKangXi=1227.140, Def{to reverence; to respect, (same as 蹗) to walk}
4800 CJK UNIFIED IDEOGRAPH-#4800, IRGKangXi=1227.150, Def{to sit cross-legged like a Buddhist priest}
4801 CJK UNIFIED IDEOGRAPH-#4801, IRGKangXi=1227.200, Def{(same as 躋) to go up; to rise; to ascend}
4802 CJK UNIFIED IDEOGRAPH-#4802, IRGKangXi=1227.230, Def{(same as 楚) name of a powerful feudal state which existed 740-330 B.C.}
4803 CJK UNIFIED IDEOGRAPH-#4803, IRGKangXi=1227.300, Def{to squat; to crouch}
4804 CJK UNIFIED IDEOGRAPH-#4804, IRGKangXi=1227.340, Def{to walk, tracks or whereabouts, disease of the feet}
4805 CJK UNIFIED IDEOGRAPH-#4805, IRGKangXi=1228.050, Def{hands and feet chapped from the cold}
4806 CJK UNIFIED IDEOGRAPH-#4806, IRGKangXi=1228.080, Def{to kowtow; to kneel and make obeisance}
4807 CJK UNIFIED IDEOGRAPH-#4807, IRGKangXi=1228.100, Def{strong; robust; healthy}
4808 CJK UNIFIED IDEOGRAPH-#4808, IRGKangXi=1228.140, Def{hard to move forward, to trample; to tread upon}
4809 CJK UNIFIED IDEOGRAPH-#4809, IRGKangXi=1228.150, Def{(same as 逭) to run away or escape from; to flee; to avoid}
480A CJK UNIFIED IDEOGRAPH-#480A, IRGKangXi=1228.180, Def{to cut off the feet (one of the five punishments in ancient times)}
480B CJK UNIFIED IDEOGRAPH-#480B, IRGKangXi=1228.260, Def{bell shaped with large base, (ancient form of U+9AC0 髀) buttocks, hipbone; innominate bone; (Cant.) to stagger}
480C CJK UNIFIED IDEOGRAPH-#480C, IRGKangXi=1229.071
480D CJK UNIFIED IDEOGRAPH-#480D, IRGKangXi=1229.130, Def{at the feet; to learn; now, shoes, (dialect) to take a stride, to sit astride on; to straddle; to ride, to stride over (a ditch, etc.)}
480E CJK UNIFIED IDEOGRAPH-#480E, IRGKangXi=1229.160, Def{narrow; small, dirty}
480F CJK UNIFIED IDEOGRAPH-#480F, IRGKangXi=1229.240, Def{feet; (same as U+47F8 䟸) the calf; muscles; tissue of the part of leg between the knee and ankle, a disease of the feet}
4810 CJK UNIFIED IDEOGRAPH-#4810, IRGKangXi=1229.270, Def{to squat; to crouch, to move elastically; to be easily bent and stretched; to be flexible: (firuratively) to submit or rise according to circumstances}
4811 CJK UNIFIED IDEOGRAPH-#4811, IRGKangXi=1229.360, Def{between the buttocks; the stride made by a man}
4812 CJK UNIFIED IDEOGRAPH-#4812, IRGKangXi=1229.380, Def{courtesy of a minority group in ancient times, to fall, drop, or go down, on one's knees; to kneel down}
4813 CJK UNIFIED IDEOGRAPH-#4813, IRGKangXi=1230.060, Def{(same as 趥) to walk, to crawl on hands and knees}
4814 CJK UNIFIED IDEOGRAPH-#4814, IRGKangXi=1230.270, Def{far and deep}
4815 CJK UNIFIED IDEOGRAPH-#4815, IRGKangXi=1230.050, Def{rapid marching or running; to go quickly, to tread upon; to trample; to step upon}
4816 CJK UNIFIED IDEOGRAPH-#4816, IRGKangXi=1230.291
4817 CJK UNIFIED IDEOGRAPH-#4817, IRGKangXi=1230.310, Def{lame; crippled, to jump; to leap, to walk}
4818 CJK UNIFIED IDEOGRAPH-#4818, IRGKangXi=1230.350, Def{one-legged, crippled; halt, a mate; to mate}
4819 CJK UNIFIED IDEOGRAPH-#4819, IRGKangXi=1230.370, Def{urgent; hurriedly}
481A CJK UNIFIED IDEOGRAPH-#481A, IRGKangXi=1231.060, Def{to step on the ground with a bang, hard to go forward; limping, to scrape; to move along the side of}
481B CJK UNIFIED IDEOGRAPH-#481B, IRGKangXi=1231.080, Def{to jump; to leap; to spring; to bounce}
481C CJK UNIFIED IDEOGRAPH-#481C, IRGKangXi=1231.250, Def{to walk}
481D CJK UNIFIED IDEOGRAPH-#481D, IRGKangXi=1231.300, Def{to stand up, to establish}
481E CJK UNIFIED IDEOGRAPH-#481E, IRGKangXi=1232.070, Def{wrinkled; contracted; to draw together, urgent; imminent; sad; sorrowful}
481F CJK UNIFIED IDEOGRAPH-#481F, IRGKangXi=1232.110, Def{to trip up; to be hindered; to stroll}
4820 CJK UNIFIED IDEOGRAPH-#4820, IRGKangXi=1232.210, Def{to go, to walk in one leg; leap; crippled, (ancient form of 逝) to pass; to be gone; to depart, (interchangeable 滯) in a standstill; stagnant; impeded; blocked}
4821 CJK UNIFIED IDEOGRAPH-#4821, IRGKangXi=1232.240, Def{sound of footsteps; to tread on; to stamp, to stagger; to fall; to drop; to stumble, to stop up; to gag; blocked}
4822 CJK UNIFIED IDEOGRAPH-#4822, IRGKangXi=1232.340, Def{weary; tired; fatigued, lime; crippled, to stumble and fall}
4823 CJK UNIFIED IDEOGRAPH-#4823, IRGKangXi=1233.010, Def{net to trap the animals}
4824 CJK UNIFIED IDEOGRAPH-#4824, IRGKangXi=1233.030, Def{toddle, to fall; fallen; prostrate}
4825 CJK UNIFIED IDEOGRAPH-#4825, IRGKangXi=1233.050, Def{(same as U+8E69 蹩) to limp; lame}
4826 CJK UNIFIED IDEOGRAPH-#4826, IRGKangXi=1233.160, Def{(non-classical form of 躓) to stumble; to trip, to be frustrated}
4827 CJK UNIFIED IDEOGRAPH-#4827, IRGKangXi=1233.250, Def{hard to go forward, stop; to delay}
4828 CJK UNIFIED IDEOGRAPH-#4828, IRGKangXi=1234.380, Def{walking rapidly, (said of a horse)}
4829 CJK UNIFIED IDEOGRAPH-#4829, IRGKangXi=1235.020, Def{to urinate; to pass urine; to empty the bladder; to make water; weary, tired, fatigued}
482A CJK UNIFIED IDEOGRAPH-#482A, IRGKangXi=1235.140, Def{footprints; track, to trample, to walk far and fast}
482B CJK UNIFIED IDEOGRAPH-#482B, IRGKangXi=1235.160, Def{to succumb to the effect of alcohol; to walk unsteadily (said of drunkards)}
482C CJK UNIFIED IDEOGRAPH-#482C, IRGKangXi=1235.400, Def{insomnia, to exhaust; highest; farthest}
482D CJK UNIFIED IDEOGRAPH-#482D, IRGKangXi=1236.030, Def{lame; crippled, to stumble}
482E CJK UNIFIED IDEOGRAPH-#482E, IRGKangXi=1236.080, Def{(same as 騰) to prance; to rear; to leap; to jump, to go up, to turn over}
482F CJK UNIFIED IDEOGRAPH-#482F, IRGKangXi=1236.190, Def{to ascend; to climb; to rise, to step on; to tread on; to walk upon, to pull out; to uproot, to promote, to jump; to leap}
4830 CJK UNIFIED IDEOGRAPH-#4830, IRGKangXi=1236.260, Def{(same as 踡) coiled; curled; drawn together; not stretched, (dialect) to surround; to encircle; to enclose}
4831 CJK UNIFIED IDEOGRAPH-#4831, IRGKangXi=1236.440, Def{(same as 蠋 躅) to walk slowly and cautiously; to limp}
4832 CJK UNIFIED IDEOGRAPH-#4832, IRGKangXi=1237.200, Def{(non-classical form of 聆) to listen; to hear}
4833 CJK UNIFIED IDEOGRAPH-#4833, IRGKangXi=1237.250, Def{to walk, (corrupted form of 邪 射) evil, to shoot}
4834 CJK UNIFIED IDEOGRAPH-#4834, IRGKangXi=1237.260, Def{with a symmetric well-formed; upright; respectable; proper carriage}
4835 CJK UNIFIED IDEOGRAPH-#4835, IRGKangXi=1237.290, Def{to wear clothes}
4836 CJK UNIFIED IDEOGRAPH-#4836, IRGKangXi=1237.300, Def{(same as 射) to project; to shoot out, to aim at}
4837 CJK UNIFIED IDEOGRAPH-#4837, IRGKangXi=1237.330, Def{the appearance of height in a person}
4838 CJK UNIFIED IDEOGRAPH-#4838, IRGKangXi=1237.350, Def{obsequious; servile; fawning, to obey; obedient; to comply}
4839 CJK UNIFIED IDEOGRAPH-#4839, IRGKangXi=1237.360, Def{(non-classical form of 骸) shinbone, skeleton}
483A CJK UNIFIED IDEOGRAPH-#483A, IRGKangXi=1237.411
483B CJK UNIFIED IDEOGRAPH-#483B, IRGKangXi=1237.500, Def{to bend the body, to employ as a servant, (non-classical form of 竆) (same as 窮) poor}
483C CJK UNIFIED IDEOGRAPH-#483C, IRGKangXi=1237.610, Def{to wear; to put on clothes}
483D CJK UNIFIED IDEOGRAPH-#483D, IRGKangXi=1237.660, Def{height or stature of a person, tall; a tall trunk, (dialect) to sit down and take some rest}
483E CJK UNIFIED IDEOGRAPH-#483E, IRGKangXi=1238.021, Def{to dodge; to ward off}
483F CJK UNIFIED IDEOGRAPH-#483F, IRGKangXi=1238.080, Def{name of a person, (non-classical form of 聵) deaf; born deaf}
4840 CJK UNIFIED IDEOGRAPH-#4840, IRGKangXi=1238.160, Def{nude; naked; without a stitch on, to shake; to tremble or shiver; to vibrate}
4841 CJK UNIFIED IDEOGRAPH-#4841, IRGKangXi=1238.270, Def{not well-formed figure, incorrect; unrespectable; improper physical build}
4842 CJK UNIFIED IDEOGRAPH-#4842, IRGKangXi=1239.100, Def{the long wooden bumper at the rear of a cart or carriage}
4843 CJK UNIFIED IDEOGRAPH-#4843, IRGKangXi=1239.130, Def{a tool for brushing the thread, ornamental; brilliant}
4844 CJK UNIFIED IDEOGRAPH-#4844, IRGKangXi=1239.131
4845 CJK UNIFIED IDEOGRAPH-#4845, IRGKangXi=1240.040, Def{something used to bind the frame work in a cart (compartment) of old times, (same as 輴) a hearse; a funeral carriage, (interchangeable 巡) to inspect (said of ranking officials)}
4846 CJK UNIFIED IDEOGRAPH-#4846, IRGKangXi=1240.070, Def{a moving cart}
4847 CJK UNIFIED IDEOGRAPH-#4847, IRGKangXi=1240.150, Def{(same as 軏) the cross-bar at the end of the pole of a carriage}
4848 CJK UNIFIED IDEOGRAPH-#4848, IRGKangXi=1240.160, Def{the cross-bar at the sides of a carriage, (same as 較) to compare}
4849 CJK UNIFIED IDEOGRAPH-#4849, IRGKangXi=1240.170, Def{a kind of cart}
484A CJK UNIFIED IDEOGRAPH-#484A, IRGKangXi=1240.210, Def{the protruded sides of a carriage (used in ancient times to screen off muddy dust)}
484B CJK UNIFIED IDEOGRAPH-#484B, IRGKangXi=1240.240, Def{(same as 軝) decoration on the nave or hub of a wheel}
484C CJK UNIFIED IDEOGRAPH-#484C, IRGKangXi=1241.040, Def{(same as 鞃) horizontal front bar on a cart or carriage, leaning board in a sedan chair}
484D CJK UNIFIED IDEOGRAPH-#484D, IRGKangXi=1241.110, Def{the linch-pin of a sheel}
484E CJK UNIFIED IDEOGRAPH-#484E, IRGKangXi=1241.111, Def{(non-classical of 轤) a windlass; a pulley; a capstan}
484F CJK UNIFIED IDEOGRAPH-#484F, IRGKangXi=1241.170, Def{(same as 鞃) horizontal front bar on a cart or carriage, leaning board in a sedan chair}
4850 CJK UNIFIED IDEOGRAPH-#4850, IRGKangXi=1242.040, Def{to move swiftly; to dart; to fleet; to drive v ery fast}
4851 CJK UNIFIED IDEOGRAPH-#4851, IRGKangXi=1242.060, Def{the rim or felloe of a wheel; a tire, a yoke, a collar}
4852 CJK UNIFIED IDEOGRAPH-#4852, IRGKangXi=1242.120, Def{sound of moving carriages; noise of a number of vehicles}
4853 CJK UNIFIED IDEOGRAPH-#4853, IRGKangXi=1242.250, Def{shake of a cart, awning in front of a cart, covering the horse or mule in the shafts, (same as 軒) high front of a chariot or carriage}
4854 CJK UNIFIED IDEOGRAPH-#4854, IRGKangXi=1243.020, Def{to hinder; to impede; to interfere with, to obstruct}
4855 CJK UNIFIED IDEOGRAPH-#4855, IRGKangXi=1243.151, Def{the rear platform of a light carriage, a subordinate cart}
4856 CJK UNIFIED IDEOGRAPH-#4856, IRGKangXi=1243.151, Def{still, motionless}
4857 CJK UNIFIED IDEOGRAPH-#4857, IRGKangXi=1243.151, Def{rim of a wheel; felly; felloe, (or a wheel) to run over, to oppress, the shafts of a cart or carriage}
4858 CJK UNIFIED IDEOGRAPH-#4858, IRGKangXi=1243.230, Def{sound of moving carriages}
4859 CJK UNIFIED IDEOGRAPH-#4859, IRGKangXi=1244.020, Def{an armed carriage; a military cart; cart used by the soldiers}
485A CJK UNIFIED IDEOGRAPH-#485A, IRGKangXi=1244.060, Def{implements; equipment to catch the birds and animals, to entice; to tempt, to exchange; to trade}
485B CJK UNIFIED IDEOGRAPH-#485B, IRGKangXi=1244.111, Def{(corrupted form) name of a carriage}
485C CJK UNIFIED IDEOGRAPH-#485C, IRGKangXi=1244.210, Def{car (of a train); compartment; the inside of a cart, axis; pivot; axle; an axletree}
485D CJK UNIFIED IDEOGRAPH-#485D, IRGKangXi=1244.220, Def{a rear covering of a big carriage, an armed carriage; a military cart; cart used by the soldiers, name of a carriage}
485E CJK UNIFIED IDEOGRAPH-#485E, IRGKangXi=1244.270, Def{leather that wind round on the shafts of a big carriage, (interchangeable 挶) a receptacle for earth}
485F CJK UNIFIED IDEOGRAPH-#485F, IRGKangXi=1244.280, Def{a ring of the horizontal front bar on a carriage; to control the wheel}
4860 CJK UNIFIED IDEOGRAPH-#4860, IRGKangXi=1245.290, Def{strong and durable}
4861 CJK UNIFIED IDEOGRAPH-#4861, IRGKangXi=1246.010, Def{to get up into a carriage}
4862 CJK UNIFIED IDEOGRAPH-#4862, IRGKangXi=1246.090, Def{a small carriage}
4863 CJK UNIFIED IDEOGRAPH-#4863, IRGKangXi=1246.130, Def{a piece of curved board; a crank -- of a (plough) machine, etc., shafts (of a cart or carriage), to return, to avoid bumping against each other}
4864 CJK UNIFIED IDEOGRAPH-#4864, IRGKangXi=1247.010, Def{a carriage, an evergreen oak}
4865 CJK UNIFIED IDEOGRAPH-#4865, IRGKangXi=1247.040, Def{(same as U+4846 䡆) a moving cart}
4866 CJK UNIFIED IDEOGRAPH-#4866, IRGKangXi=1247.080, Def{the empty space of a wheel, rim of a wheel; felly; felloe}
4867 CJK UNIFIED IDEOGRAPH-#4867, IRGKangXi=1247.300, Def{a carriage; the head of a carriage}
4868 CJK UNIFIED IDEOGRAPH-#4868, IRGKangXi=1247.340, Def{connected carts, back and park the cart, to block; to stop up}
4869 CJK UNIFIED IDEOGRAPH-#4869, IRGKangXi=1248.010, Def{sound of carts or stones (big things) knocking together, cross-bar in the rear of a carriage}
486A CJK UNIFIED IDEOGRAPH-#486A, IRGKangXi=1248.030, Def{fan of a carriage}
486B CJK UNIFIED IDEOGRAPH-#486B, IRGKangXi=1248.050, Def{sound of moving carriages; noise of a number of vehicles}
486C CJK UNIFIED IDEOGRAPH-#486C, IRGKangXi=1248.060, Def{covering of a carriage, a tank (an armored vehicle), a chariot, a cover or shelter of a chariot}
486D CJK UNIFIED IDEOGRAPH-#486D, IRGKangXi=1248.090, Def{a hearse; a funeral carriage}
486E CJK UNIFIED IDEOGRAPH-#486E, IRGKangXi=1248.100, Def{(interchangeable 蹤 趿) trace of a wheel}
486F CJK UNIFIED IDEOGRAPH-#486F, IRGKangXi=1248.110, Def{sound of moving carriages; noise of a number of vehicles, a prison cart; a police van to transport prisoners, carts wheels}
4870 CJK UNIFIED IDEOGRAPH-#4870, IRGKangXi=1248.140, Def{strong and durable (same as 轂) hub (of a wheel), wheel}
4871 CJK UNIFIED IDEOGRAPH-#4871, IRGKangXi=1248.191
4872 CJK UNIFIED IDEOGRAPH-#4872, IRGKangXi=1248.260, Def{rim of a wheel; felly; felloe, a kind of carriage}
4873 CJK UNIFIED IDEOGRAPH-#4873, IRGKangXi=1248.320, Def{cart, carriage etc.}
4874 CJK UNIFIED IDEOGRAPH-#4874, IRGKangXi=1248.350, Def{carriage used in ancient times to take enemy position, (interchangeable 幢) a curtain for a carriage}
4875 CJK UNIFIED IDEOGRAPH-#4875, IRGKangXi=1249.110, Def{decoration on carriage}
4876 CJK UNIFIED IDEOGRAPH-#4876, IRGKangXi=1249.180, Def{vehicles and garments (commonloy used in feudal times to reward vassals), covering on the crossbar at the ends of carriage poles, crank axle of a shade}
4877 CJK UNIFIED IDEOGRAPH-#4877, IRGKangXi=1249.260, Def{(same as 轄) noise of vehicles}
4878 CJK UNIFIED IDEOGRAPH-#4878, IRGKangXi=1249.281
4879 CJK UNIFIED IDEOGRAPH-#4879, IRGKangXi=1250.011, Def{(same as 輊) the low rear of a chariot, etc.}
487A CJK UNIFIED IDEOGRAPH-#487A, IRGKangXi=1249.310, Def{(same as 轊) the end of an axle-tree}
487B CJK UNIFIED IDEOGRAPH-#487B, IRGKangXi=1250.011, Def{(same as U+4851 䡑) shake of a cart, awning in front of a cart, covering the horse or mule in the shafts; (same as U+8ED2 軒) high front of a chariot or carriage}
487C CJK UNIFIED IDEOGRAPH-#487C, IRGKangXi=1250.110, Def{(same as 軨) frames on the sides and front of a carriage, wheels of a carriage}
487D CJK UNIFIED IDEOGRAPH-#487D, IRGKangXi=1250.170, Def{the shafts of a vehicle}
487E CJK UNIFIED IDEOGRAPH-#487E, IRGKangXi=1250.180, Def{high cartloads, (same as 轙) rings on the yokes}
487F CJK UNIFIED IDEOGRAPH-#487F, IRGKangXi=1250.240, Def{(same as 軨) frames on the sides and front of a carriage, wheels of a carriage}
4880 CJK UNIFIED IDEOGRAPH-#4880, IRGKangXi=1250.241, Def{(simplified form of 𨊰[U+282b0])}
4881 CJK UNIFIED IDEOGRAPH-#4881, IRGKangXi=1250.241, Def{(simplified form) tire of a wheel}
4882 CJK UNIFIED IDEOGRAPH-#4882, IRGKangXi=1250.241, Def{(Cant.) an elevator (from the British 'lift')}
4883 CJK UNIFIED IDEOGRAPH-#4883, IRGKangXi=1251.130, Def{to administer; to regulate; to manage; to govern, people to have both talent and virtue, quiet; calm; safe; secure; stable}
4884 CJK UNIFIED IDEOGRAPH-#4884, IRGKangXi=1252.120
4885 CJK UNIFIED IDEOGRAPH-#4885, IRGKangXi=1253.030, Def{(interchangeable 晨) daybreak}
4886 CJK UNIFIED IDEOGRAPH-#4886, IRGKangXi=1253.031
4887 CJK UNIFIED IDEOGRAPH-#4887, IRGKangXi=1253.040, Def{a son who is not so good as his father; good-for-nothing; a rotten apple, inferior; mean, busy with many different matters; no leisure, mixed; confused; miscellaneous}
4888 CJK UNIFIED IDEOGRAPH-#4888, IRGKangXi=1253.080
4889 CJK UNIFIED IDEOGRAPH-#4889, IRGKangXi=1253.090, Def{(same as 農) agriculture; farming, farmer}
488A CJK UNIFIED IDEOGRAPH-#488A, IRGKangXi=1253.160, Def{(ancient form of 遊) to travel; to roam; to saunter}
488B CJK UNIFIED IDEOGRAPH-#488B, IRGKangXi=1253.190, Def{a marshal or herald; an official rank in old times, indicating exclamation (same as 哉)}
488C CJK UNIFIED IDEOGRAPH-#488C, IRGKangXi=1253.310, Def{to walk, rapid marching or running}
488D CJK UNIFIED IDEOGRAPH-#488D, IRGKangXi=1253.380, Def{to hasten; to hurry to}
488E CJK UNIFIED IDEOGRAPH-#488E, IRGKangXi=1254.160, Def{(same as U+488B 䢋) indicating exclamation}
488F CJK UNIFIED IDEOGRAPH-#488F, IRGKangXi=1254.171
4890 CJK UNIFIED IDEOGRAPH-#4890, IRGKangXi=1254.200, Def{(same as 徂) to go to; to go ahead; to advance}
4891 CJK UNIFIED IDEOGRAPH-#4891, IRGKangXi=1255.020, Def{angry; furious, frightened; terrified; terror-stricken}
4892 CJK UNIFIED IDEOGRAPH-#4892, IRGKangXi=1255.180, Def{to meet; to co-operate; interaction, to have friendly relations, interlocking; interchanging}
4893 CJK UNIFIED IDEOGRAPH-#4893, IRGKangXi=1255.210, Def{bed, window}
4894 CJK UNIFIED IDEOGRAPH-#4894, IRGKangXi=1256.090, Def{mixed; abundant; assorted, repeated}
4895 CJK UNIFIED IDEOGRAPH-#4895, IRGKangXi=1256.200, Def{a group of people walking together}
4896 CJK UNIFIED IDEOGRAPH-#4896, IRGKangXi=1256.240, Def{to be scattered (over an area); to spread, to give an account of; to explain; to expound, to follow}
4897 CJK UNIFIED IDEOGRAPH-#4897, IRGKangXi=1257.041
4898 CJK UNIFIED IDEOGRAPH-#4898, IRGKangXi=1257.041
4899 CJK UNIFIED IDEOGRAPH-#4899, IRGKangXi=1257.060, Def{(same as 敗) to ruin; to destroy; to spoil, defeat; to be defeated, bad; as meat}
489A CJK UNIFIED IDEOGRAPH-#489A, IRGKangXi=1257.170, Def{a narrow path (for rabbit), (same as 迒) animal tracks, path; way; road}
489B CJK UNIFIED IDEOGRAPH-#489B, IRGKangXi=1259.050, Def{(non-classical form of 迥) far; distant; different from; separated}
489C CJK UNIFIED IDEOGRAPH-#489C, IRGKangXi=1259.290, Def{(same as 歸) the marriage of a woman, to return to; to revert to; to go back, to belong to, to restore, to send back}
489D CJK UNIFIED IDEOGRAPH-#489D, IRGKangXi=1260.020, Def{(interchangeable 亞) the next in order; secondary; second (in excellence), inferior; lower}
489E CJK UNIFIED IDEOGRAPH-#489E, IRGKangXi=1260.151, Def{(corrupted form U+48A4 䢤) rows and columns}
489F CJK UNIFIED IDEOGRAPH-#489F, IRGKangXi=1260.151, Def{(same as 遊) to travel; to roam; to saunter, (interchangeable 游) to wander about}
48A0 CJK UNIFIED IDEOGRAPH-#48A0, IRGKangXi=1259.061, Def{(standard form of 送) to send; to deliver; to convey, to give}
48A1 CJK UNIFIED IDEOGRAPH-#48A1, IRGKangXi=1260.230, Def{to stamp the foot forward, to walk, to stop}
48A2 CJK UNIFIED IDEOGRAPH-#48A2, IRGKangXi=1262.240, Def{to pass; to pass through or by}
48A3 CJK UNIFIED IDEOGRAPH-#48A3, IRGKangXi=1262.260, Def{(same as 遙) distant; far; remote}
48A4 CJK UNIFIED IDEOGRAPH-#48A4, IRGKangXi=1263.160
48A5 CJK UNIFIED IDEOGRAPH-#48A5, IRGKangXi=1263.251, Def{(corrupted form) (to walk) in harmony; in accord, to look after; to care for each other}
48A6 CJK UNIFIED IDEOGRAPH-#48A6, IRGKangXi=1263.270, Def{(interchangeable 率 帥) to lead the way; a guide; a forerunner; to head, model; a mentor; a teacher, to guide; to lead; to direct, to follow; to accord with; to obey}
48A7 CJK UNIFIED IDEOGRAPH-#48A7, IRGKangXi=1263.320, Def{to go forward; to depart}
48A8 CJK UNIFIED IDEOGRAPH-#48A8, IRGKangXi=1264.120, Def{to walk slowly; to walk in a leisurely manner, (same as 蹤) track; trace; vestige, to keep track; to follow up clues}
48A9 CJK UNIFIED IDEOGRAPH-#48A9, IRGKangXi=1264.210, Def{(same as 禦御) to forbid to prohibit; to ban, to resist; to sustain; to ward off}
48AA CJK UNIFIED IDEOGRAPH-#48AA, IRGKangXi=1265.170, Def{(non-classical form of 橇) a sledge for transportation over mud or snow}
48AB CJK UNIFIED IDEOGRAPH-#48AB, IRGKangXi=1266.061, Def{(same as 隨) to follow; to trace, to submit to; to accord with, to let, to come after}
48AC CJK UNIFIED IDEOGRAPH-#48AC, IRGKangXi=1266.061, Def{(ancient form of 遷) to move; to remove; to change, to be banished}
48AD CJK UNIFIED IDEOGRAPH-#48AD, IRGKangXi=1266.150, Def{to cover; to screen; to shade; to conceal; to shut off, to block, to shift; to move, to forward; to convey, to walk}
48AE CJK UNIFIED IDEOGRAPH-#48AE, IRGKangXi=1266.250, Def{rapid marching or running}
48AF CJK UNIFIED IDEOGRAPH-#48AF, IRGKangXi=1267.030, Def{(standard form of 遴) to choose or select careful, to desire for more than one's rightful share; to covet; greedy}
48B0 CJK UNIFIED IDEOGRAPH-#48B0, IRGKangXi=1267.080, Def{(same as 趯) to jump; to leap; to hop}
48B1 CJK UNIFIED IDEOGRAPH-#48B1, IRGKangXi=1267.120, Def{to slight; to abuse; to insult; to blaspheme, to desecrate}
48B2 CJK UNIFIED IDEOGRAPH-#48B2, IRGKangXi=1267.380, Def{to go all the way forward; without stopping}
48B3 CJK UNIFIED IDEOGRAPH-#48B3, IRGKangXi=1268.010, Def{name of a place}
48B4 CJK UNIFIED IDEOGRAPH-#48B4, IRGKangXi=1268.180, Def{(interchangeable 邘) name of a place}
48B5 CJK UNIFIED IDEOGRAPH-#48B5, IRGKangXi=1269.030, Def{(same as 鄖) name of an old country in today's Hubei province, name of a place in today's Jiangsu province}
48B6 CJK UNIFIED IDEOGRAPH-#48B6, IRGKangXi=1269.161, Def{(same as 邦) a state; a country; a nation}
48B7 CJK UNIFIED IDEOGRAPH-#48B7, IRGKangXi=1269.161
48B8 CJK UNIFIED IDEOGRAPH-#48B8, IRGKangXi=1269.280, Def{name of a county in today's Shanxi Province}
48B9 CJK UNIFIED IDEOGRAPH-#48B9, IRGKangXi=1270.010, Def{name of a pavilion in today's Hunan Province}
48BA CJK UNIFIED IDEOGRAPH-#48BA, IRGKangXi=1270.071, Def{name of a place in today's Sichuan Province}
48BB CJK UNIFIED IDEOGRAPH-#48BB, IRGKangXi=1270.080, Def{name of a place}
48BC CJK UNIFIED IDEOGRAPH-#48BC, IRGKangXi=1270.120, Def{name of a state in old times, name of a pavilion}
48BD CJK UNIFIED IDEOGRAPH-#48BD, IRGKangXi=1270.130, Def{(same as 巷) (interchangeable 衖) a lane; an alley}
48BE CJK UNIFIED IDEOGRAPH-#48BE, IRGKangXi=1270.220, Def{(same as 姺) name of an ancient small State}
48BF CJK UNIFIED IDEOGRAPH-#48BF, IRGKangXi=1270.230, Def{name of a place in today's Hobei Province}
48C0 CJK UNIFIED IDEOGRAPH-#48C0, IRGKangXi=1270.250, Def{name of a mountain, name of a place, name of a state}
48C1 CJK UNIFIED IDEOGRAPH-#48C1, IRGKangXi=1271.060, Def{name of a pavilion (Han Dynasty) in today's Henan Province}
48C2 CJK UNIFIED IDEOGRAPH-#48C2, IRGKangXi=1271.070, Def{name of a county in today's Hunan Province}
48C3 CJK UNIFIED IDEOGRAPH-#48C3, IRGKangXi=1271.121
48C4 CJK UNIFIED IDEOGRAPH-#48C4, IRGKangXi=1271.160, Def{name of a place in today's Shandong Province}
48C5 CJK UNIFIED IDEOGRAPH-#48C5, IRGKangXi=1271.200, Def{name of an ancient state, in today's Henan Province}
48C6 CJK UNIFIED IDEOGRAPH-#48C6, IRGKangXi=1271.320, Def{name of a county in Gaomi}
48C7 CJK UNIFIED IDEOGRAPH-#48C7, IRGKangXi=1272.060, Def{name of a place, name of a county in today's Henan Province}
48C8 CJK UNIFIED IDEOGRAPH-#48C8, IRGKangXi=1272.101, Def{(ancient form of 巷) (interchangeable 衖) a lane; an alley}
48C9 CJK UNIFIED IDEOGRAPH-#48C9, IRGKangXi=1272.101
48CA CJK UNIFIED IDEOGRAPH-#48CA, IRGKangXi=1272.120, Def{name of a place, (same as 黨) party; gang; clique}
48CB CJK UNIFIED IDEOGRAPH-#48CB, IRGKangXi=1273.010, Def{name of a place}
48CC CJK UNIFIED IDEOGRAPH-#48CC, IRGKangXi=1273.050, Def{(non-classical form of 邸) residence of a prince or nobility}
48CD CJK UNIFIED IDEOGRAPH-#48CD, IRGKangXi=1273.070, Def{(interchangeable 奄) name of an ancient state, name of a country in old times}
48CE CJK UNIFIED IDEOGRAPH-#48CE, IRGKangXi=1273.180, Def{name of county (a village)}
48CF CJK UNIFIED IDEOGRAPH-#48CF, IRGKangXi=1273.271, Def{(non-classical form of U+48BC 䢼) name of a state in old times, name of a pavilion}
48D0 CJK UNIFIED IDEOGRAPH-#48D0, IRGKangXi=1274.170, Def{name of a place}
48D1 CJK UNIFIED IDEOGRAPH-#48D1, IRGKangXi=1275.021, Def{(same as 廛) living space for one family in ancient times, a store; a shop (abbreviated form of 鄽)}
48D2 CJK UNIFIED IDEOGRAPH-#48D2, IRGKangXi=1275.021
48D3 CJK UNIFIED IDEOGRAPH-#48D3, IRGKangXi=1275.120, Def{name of a state, name of a county}
48D4 CJK UNIFIED IDEOGRAPH-#48D4, IRGKangXi=1275.150, Def{name of a pavilion in today's Henan Province}
48D5 CJK UNIFIED IDEOGRAPH-#48D5, IRGKangXi=1275.250, Def{name of a county in ancient times}
48D6 CJK UNIFIED IDEOGRAPH-#48D6, IRGKangXi=1276.051, Def{(same as U+48D5 䣕) name of a county in ancient times}
48D7 CJK UNIFIED IDEOGRAPH-#48D7, IRGKangXi=1276.051
48D8 CJK UNIFIED IDEOGRAPH-#48D8, IRGKangXi=1276.090, Def{(ancient form of 堂) a hall, an office; a reception room, a court of justice}
48D9 CJK UNIFIED IDEOGRAPH-#48D9, IRGKangXi=1276.130, Def{name of a county in today's Shanxi Province, name of an ancient state in Inner Mongolia name of a place}
48DA CJK UNIFIED IDEOGRAPH-#48DA, IRGKangXi=1276.220, Def{name of a village in today's Henan Province}
48DB CJK UNIFIED IDEOGRAPH-#48DB, IRGKangXi=1276.290, Def{name of a place in ancient times, (same as 5380 膝) the knee}
48DC CJK UNIFIED IDEOGRAPH-#48DC, IRGKangXi=1277.080, Def{(same as 酇) name of a county (in today's Henan Province) in ancient times}
48DD CJK UNIFIED IDEOGRAPH-#48DD, IRGKangXi=1277.190, Def{name of a place in today's Shanxi Province}
48DE CJK UNIFIED IDEOGRAPH-#48DE, IRGKangXi=1277.280, Def{(standard form of 鄂) name of an ancient State which occupied the site of the present province of Hubei, short for Hubei Province}
48DF CJK UNIFIED IDEOGRAPH-#48DF, IRGKangXi=1278.050, Def{name of pavilion in today's Shandong Province, to pierce; to stab; to irritate; to hurt}
48E0 CJK UNIFIED IDEOGRAPH-#48E0, IRGKangXi=1278.060, Def{name of a village in today's Sichuan Province; (a corrupted form of U+48DF U+48E2 䣟䣢) name of pavilion}
48E1 CJK UNIFIED IDEOGRAPH-#48E1, IRGKangXi=1278.190, Def{name of a place in old times; in today's Anhui Province}
48E2 CJK UNIFIED IDEOGRAPH-#48E2, IRGKangXi=1278.350, Def{name of a place in ancient times, name of a river in ancient times}
48E3 CJK UNIFIED IDEOGRAPH-#48E3, IRGKangXi=1279.350, Def{(same as U+9EE8 黨) name of a place, party; gang; clique}
48E4 CJK UNIFIED IDEOGRAPH-#48E4, IRGKangXi=1280.010, Def{name of village in today's Shanxi Province}
48E5 CJK UNIFIED IDEOGRAPH-#48E5, IRGKangXi=1280.060, Def{a kind of wine}
48E6 CJK UNIFIED IDEOGRAPH-#48E6, IRGKangXi=1280.061, Def{to cut; to mince; to slice; to carve}
48E7 CJK UNIFIED IDEOGRAPH-#48E7, IRGKangXi=1280.080, Def{(interchangeable 黓) black, color of the wine, sweet; honeyed; or pleasing}
48E8 CJK UNIFIED IDEOGRAPH-#48E8, IRGKangXi=1281.040, Def{(same as 䣩) rich; good; as wine, pure, unmixed; (same as 純) beautiful; fine; pretty, net; pure; (same as 醇) rich wine; strong wine, gentle; gracious; judicious, pure and fair}
48E9 CJK UNIFIED IDEOGRAPH-#48E9, IRGKangXi=1281.090, Def{(same as U+7D14 純) beautiful; fine; pretty, net, (same as U+9187 醇) rich; good; as wine, pure, unmixed}
48EA CJK UNIFIED IDEOGRAPH-#48EA, IRGKangXi=1281.210, Def{color of the wine, smell of alcohol}
48EB CJK UNIFIED IDEOGRAPH-#48EB, IRGKangXi=1281.230, Def{soured bean-curd; a milky preparation from beans}
48EC CJK UNIFIED IDEOGRAPH-#48EC, IRGKangXi=1281.281, Def{the shiny colorful of the wine, sweet; color of the wine}
48ED CJK UNIFIED IDEOGRAPH-#48ED, IRGKangXi=1281.281, Def{an organic compound; phtholein}
48EE CJK UNIFIED IDEOGRAPH-#48EE, IRGKangXi=1281.290, Def{(non-classical of U+48EA 䣪) smell of alcohol}
48EF CJK UNIFIED IDEOGRAPH-#48EF, IRGKangXi=1281.320, Def{wine or any thick fluid of the best quality; (corrupted form of 靦) ashamed}
48F0 CJK UNIFIED IDEOGRAPH-#48F0, IRGKangXi=1281.350, Def{(same as 醵) to pool money (for a feast, etc.); to contribute to a feast}
48F1 CJK UNIFIED IDEOGRAPH-#48F1, IRGKangXi=1281.390, Def{(same as 酗) drunk; to lose temper when drunk}
48F2 CJK UNIFIED IDEOGRAPH-#48F2, IRGKangXi=1282.030, Def{to heat the wine over night, to generally indicate the wine, to sell or buy alcoholic drinks, (dialect) to change in color, wore out clothes, to get worse}
48F3 CJK UNIFIED IDEOGRAPH-#48F3, IRGKangXi=1282.120, Def{unstrained wine, vinegar}
48F4 CJK UNIFIED IDEOGRAPH-#48F4, IRGKangXi=1282.140, Def{(non classical form of 酗) to lose temper when drunk}
48F5 CJK UNIFIED IDEOGRAPH-#48F5, IRGKangXi=1282.150, Def{to brew the wine a second time, to get over a drinking bout}
48F6 CJK UNIFIED IDEOGRAPH-#48F6, IRGKangXi=1282.190, Def{unstrained wine, to offer plenty of food, to treat kindly and generously; to (same as 甜) pleasant to the taste -- as wine, sweet}
48F7 CJK UNIFIED IDEOGRAPH-#48F7, IRGKangXi=1282.200, Def{to pour (wine), unstrained wine}
48F8 CJK UNIFIED IDEOGRAPH-#48F8, IRGKangXi=1282.230, Def{tasteless, light, soybean sauce; soy, food in the form of paste, to eat to the full; satiated; surfeited, to dislike}
48F9 CJK UNIFIED IDEOGRAPH-#48F9, IRGKangXi=1283.050, Def{to brew 10 percent of the wine}
48FA CJK UNIFIED IDEOGRAPH-#48FA, IRGKangXi=1283.070, Def{filtrated the wine}
48FB CJK UNIFIED IDEOGRAPH-#48FB, IRGKangXi=1283.180, Def{color of the wine, dark red color of the face, (non-classical form of 酣) intoxicated, merry, as with drink}
48FC CJK UNIFIED IDEOGRAPH-#48FC, IRGKangXi=1284.030, Def{mixed starch; one of the six drinks in old time, (interchangeable 涼) cold}
48FD CJK UNIFIED IDEOGRAPH-#48FD, IRGKangXi=1284.140, Def{wine; rich wine, (same as 醍) a kind of reddish wine}
48FE CJK UNIFIED IDEOGRAPH-#48FE, IRGKangXi=1284.230, Def{(non-classical form) cheese dregs; lees, cheese, drunken sound}
48FF CJK UNIFIED IDEOGRAPH-#48FF, IRGKangXi=1284.270, Def{to entertain; to feast, to drink within limits; to drink appropriately}
4900 CJK UNIFIED IDEOGRAPH-#4900, IRGKangXi=1285.371
4901 CJK UNIFIED IDEOGRAPH-#4901, IRGKangXi=1285.040, Def{cooked or well-done; prepared or processed, to brew wine and store up for a long time, (interchangeable 酖) addicted to alcoholic drinks; to imbibe or to indulge in (vices, etc.), to be infatuated with, to be a slave of}
4902 CJK UNIFIED IDEOGRAPH-#4902, IRGKangXi=1285.060, Def{vinegar; yeast or distiller's grains}
4903 CJK UNIFIED IDEOGRAPH-#4903, IRGKangXi=1285.070, Def{drunken sound, drunk, to ferment; food made through the way of fermentation}
4904 CJK UNIFIED IDEOGRAPH-#4904, IRGKangXi=1285.140, Def{flushed with drink; addicted to intoxicants}
4905 CJK UNIFIED IDEOGRAPH-#4905, IRGKangXi=1285.170, Def{southernwood, bitter wine}
4906 CJK UNIFIED IDEOGRAPH-#4906, IRGKangXi=1285.220, Def{a kind of rice wine; sake, wine used in ancestral worshipping or in offerings}
4907 CJK UNIFIED IDEOGRAPH-#4907, IRGKangXi=1285.270, Def{white wine, a measure of wine containing about 3 pints}
4908 CJK UNIFIED IDEOGRAPH-#4908, IRGKangXi=1285.290, Def{(same as 醯) vinegar}
4909 CJK UNIFIED IDEOGRAPH-#4909, IRGKangXi=1285.410, Def{emptied the drink completely, bean sauce; salted preparations}
490A CJK UNIFIED IDEOGRAPH-#490A, IRGKangXi=1286.030, Def{wine, to brew a second time}
490B CJK UNIFIED IDEOGRAPH-#490B, IRGKangXi=1286.230, Def{yellow-faced; emaciated look, (same as 聝) to cut off the ear; to cut off the left ears of the slain; to count the number of enemy troops one killed by the number of the left ears cut from the bodies}
490C CJK UNIFIED IDEOGRAPH-#490C, IRGKangXi=1286.241, Def{a kind of wine be brewed from grains, a kind of daily drinks for a minority group}
490D CJK UNIFIED IDEOGRAPH-#490D, IRGKangXi=1286.290, Def{rotten paste or soybean sauce; to grow mildewed}
490E CJK UNIFIED IDEOGRAPH-#490E, IRGKangXi=1287.230, Def{soybean sauce; soy, food in the form of paste, oysters sauce}
490F CJK UNIFIED IDEOGRAPH-#490F, IRGKangXi=1287.240, Def{(same as 圮) destroyed; ruined, wine and women -- sensual pleasures}
4910 CJK UNIFIED IDEOGRAPH-#4910, IRGKangXi=1287.260, Def{to drink; refreshment; to have a little drink sweet, delicious; tasty}
4911 CJK UNIFIED IDEOGRAPH-#4911, IRGKangXi=1287.270, Def{wine}
4912 CJK UNIFIED IDEOGRAPH-#4912, IRGKangXi=1287.310, Def{wine made from glutinous rice, a kind wine to drink after bathing, color of the rice wine, a kind of good wine, bubbles of the wine}
4913 CJK UNIFIED IDEOGRAPH-#4913, IRGKangXi=1288.200
4914 CJK UNIFIED IDEOGRAPH-#4914, IRGKangXi=1288.220, Def{dregs of wine, tasteless; insipid}
4915 CJK UNIFIED IDEOGRAPH-#4915, IRGKangXi=1289.030, Def{vinegar, smell of vinegar, bitter wine (same as 嚛)}
4916 CJK UNIFIED IDEOGRAPH-#4916, IRGKangXi=1289.050, Def{a kind of wine, a kind of wine that brew for one night}
4917 CJK UNIFIED IDEOGRAPH-#4917, IRGKangXi=1289.200, Def{taste of strong drink, the bitterness of the wine}
4918 CJK UNIFIED IDEOGRAPH-#4918, IRGKangXi=1289.250, Def{vinegar, smell of vinegar}
4919 CJK UNIFIED IDEOGRAPH-#4919, IRGKangXi=1290.010, Def{dregs; lees of cheese, cheese}
491A CJK UNIFIED IDEOGRAPH-#491A, IRGKangXi=1292.030, Def{(same as 李) plums, a plum tree}
491B CJK UNIFIED IDEOGRAPH-#491B, IRGKangXi=1296.060, Def{component parts of a cross-bow, (same as 銶) a single headed hatchet}
491C CJK UNIFIED IDEOGRAPH-#491C, IRGKangXi=1297.141, Def{(same as 鈍) blunt, obtuse; dull-witted}
491D CJK UNIFIED IDEOGRAPH-#491D, IRGKangXi=1298.060, Def{bracelet; armlet}
491E CJK UNIFIED IDEOGRAPH-#491E, IRGKangXi=1299.030, Def{(corrupted form of 鈗) a kind of weapons held by the officials in attendance in old times, (same as 銳) a sharp-pointed weapon}
491F CJK UNIFIED IDEOGRAPH-#491F, IRGKangXi=1299.191, Def{(standard form of 鈂) a spade, an iron bar for making hole, to dig, heavy}
4920 CJK UNIFIED IDEOGRAPH-#4920, IRGKangXi=1299.191, Def{(same as 鍺) chemical element, Germanium}
4921 CJK UNIFIED IDEOGRAPH-#4921, IRGKangXi=1301.130, Def{iron}
4922 CJK UNIFIED IDEOGRAPH-#4922, IRGKangXi=1303.020, Def{(same as 釛) metal, gold}
4923 CJK UNIFIED IDEOGRAPH-#4923, IRGKangXi=1303.060, Def{(corrupted from of 鋝) a metal ring, an ancient weight of over six taels}
4924 CJK UNIFIED IDEOGRAPH-#4924, IRGKangXi=1303.170, Def{implement; tool; instrument; utensil}
4925 CJK UNIFIED IDEOGRAPH-#4925, IRGKangXi=1304.070, Def{agricultural implements; from tools, shining iron, a plectrum from stringed the teeth of a saw}
4926 CJK UNIFIED IDEOGRAPH-#4926, IRGKangXi=1304.140, Def{(same as 鉞) a battle-axe; a halberd}
4927 CJK UNIFIED IDEOGRAPH-#4927, IRGKangXi=1305.010
4928 CJK UNIFIED IDEOGRAPH-#4928, IRGKangXi=1305.100, Def{to split; to slash or rip open (by means of a knife), jewels or ornaments on a sword, to analyze; to study; to investigate}
4929 CJK UNIFIED IDEOGRAPH-#4929, IRGKangXi=1305.190, Def{an ornament at the end of a belt used in ancient times}
492A CJK UNIFIED IDEOGRAPH-#492A, IRGKangXi=1305.211, Def{short; imcomplete; deficient (same as 剁) to chop; to mince; to hash}
492B CJK UNIFIED IDEOGRAPH-#492B, IRGKangXi=1306.010, Def{(same as 鑱) a chisel, a coulter, mattock, sharp}
492C CJK UNIFIED IDEOGRAPH-#492C, IRGKangXi=1306.070, Def{a small gong, a sieve; a sifter; a strainer}
492D CJK UNIFIED IDEOGRAPH-#492D, IRGKangXi=1306.260, Def{to ornament; to decorate, to push}
492E CJK UNIFIED IDEOGRAPH-#492E, IRGKangXi=1307.090, Def{iron, golden ornaments}
492F CJK UNIFIED IDEOGRAPH-#492F, IRGKangXi=1307.140, Def{(same as 鉶) container for thick soup, sacrificial utensil, thick soup of meat and vegetables, (interchangeable 硎) a whetstone; grindstone}
4930 CJK UNIFIED IDEOGRAPH-#4930, IRGKangXi=1308.120, Def{to smelt; to fuse metals}
4931 CJK UNIFIED IDEOGRAPH-#4931, IRGKangXi=1308.190, Def{(ancient form of 誓) a solemn pledge; a vow; an oath}
4932 CJK UNIFIED IDEOGRAPH-#4932, IRGKangXi=1308.261, Def{chemical element; (鍶) old translation; Sr}
4933 CJK UNIFIED IDEOGRAPH-#4933, IRGKangXi=1309.080, Def{a mirrow, lens; glass}
4934 CJK UNIFIED IDEOGRAPH-#4934, IRGKangXi=1309.270, Def{armor; coat of mail, (interchangeable 函) a case; a small box, cup}
4935 CJK UNIFIED IDEOGRAPH-#4935, IRGKangXi=1311.060, Def{a tiny needle; thin pin; one of the nine needles used in Chinese medicine, (same as 扉) a door leaf}
4936 CJK UNIFIED IDEOGRAPH-#4936, IRGKangXi=1311.070, Def{a hammer; a mallet; a bludgeon, agricultural tools; farming implements, an iron (for pressing clothes)}
4937 CJK UNIFIED IDEOGRAPH-#4937, IRGKangXi=1313.160, Def{a lance with three or two points, edge or margin of an utensil}
4938 CJK UNIFIED IDEOGRAPH-#4938, IRGKangXi=1313.180, Def{short spear or lance}
4939 CJK UNIFIED IDEOGRAPH-#4939, IRGKangXi=1313.220, Def{to engrave; to carve, rust}
493A CJK UNIFIED IDEOGRAPH-#493A, IRGKangXi=1315.010, Def{(same as 釿 斤) an ax; a hatchet, to cut off; to chop off}
493B CJK UNIFIED IDEOGRAPH-#493B, IRGKangXi=1315.070, Def{heavy iron part of a plough, the linch-pin of a wheel}
493C CJK UNIFIED IDEOGRAPH-#493C, IRGKangXi=1316.111, Def{metal wire}
493D CJK UNIFIED IDEOGRAPH-#493D, IRGKangXi=1316.260, Def{farm tools; agricultural implements; a tool used to till the lands; a spade or shovel}
493E CJK UNIFIED IDEOGRAPH-#493E, IRGKangXi=1317.020, Def{to contain; to envelop, a case a box}
493F CJK UNIFIED IDEOGRAPH-#493F, IRGKangXi=1317.040, Def{(same as 鍥) to carve; to cut, a sickle}
4940 CJK UNIFIED IDEOGRAPH-#4940, IRGKangXi=1317.090, Def{to pull out; to stretch}
4941 CJK UNIFIED IDEOGRAPH-#4941, IRGKangXi=1317.160, Def{armor, (standard form 圅) to contain; to envelop, a sheath, a letter}
4942 CJK UNIFIED IDEOGRAPH-#4942, IRGKangXi=1317.200, Def{the sharp edge of a shovel or a spade}
4943 CJK UNIFIED IDEOGRAPH-#4943, IRGKangXi=1318.070, Def{a big hammer}
4944 CJK UNIFIED IDEOGRAPH-#4944, IRGKangXi=1318.090, Def{to plaster with gold}
4945 CJK UNIFIED IDEOGRAPH-#4945, IRGKangXi=1318.220, Def{(ancient form of 琴) a musical instrument}
4946 CJK UNIFIED IDEOGRAPH-#4946, IRGKangXi=1318.230, Def{(ancient form of 琴) a musical instrument}
4947 CJK UNIFIED IDEOGRAPH-#4947, IRGKangXi=1318.281, Def{chemical element; Sarmarium (Sm); old translation of (鋱) Tb, (same as 釤) a sickle with a long handle, to swing a sickle to cut (grass or wheat)}
4948 CJK UNIFIED IDEOGRAPH-#4948, IRGKangXi=1319.040, Def{the symbol for Cobalt, an iron (for pressing clothes)}
4949 CJK UNIFIED IDEOGRAPH-#4949, IRGKangXi=1319.050, Def{the curved iron part of a hoe}
494A CJK UNIFIED IDEOGRAPH-#494A, IRGKangXi=1319.220, Def{(non-classical of 錆) refined; polished; unmixed, the essence, fine and delicate, keen, very}
494B CJK UNIFIED IDEOGRAPH-#494B, IRGKangXi=1319.250, Def{to smelt; to refine the gold; alchemy}
494C CJK UNIFIED IDEOGRAPH-#494C, IRGKangXi=1319.310, Def{(ancient form of 證) evidence, proof, to give evidence, to testify}
494D CJK UNIFIED IDEOGRAPH-#494D, IRGKangXi=1320.120, Def{(corrupted form) a whip, a farm tool used to regulate seedling and to weed}
494E CJK UNIFIED IDEOGRAPH-#494E, IRGKangXi=1320.160, Def{instrument; implement; utensil; tool; apparatus}
494F CJK UNIFIED IDEOGRAPH-#494F, IRGKangXi=1320.170, Def{unfitted for each other; irregular; unsuitable; not well-matched, a hoe, (same as 鋙) a musical instrument, pewter}
4950 CJK UNIFIED IDEOGRAPH-#4950, IRGKangXi=1321.060, Def{(corrupted form of 鍪) cooking utensils used in ancient times; an iron pan, a helmet; a metal cap}
4951 CJK UNIFIED IDEOGRAPH-#4951, IRGKangXi=1321.071, Def{(corrupted form of 錽) a kind of decoration on the head of a horse; usually in a shape of an animal face, ornaments of a bridle or reins, to engrave incised inscriptions on copper or iron plate; to engrave on metal or wood; (mài) meitnerium}
4952 CJK UNIFIED IDEOGRAPH-#4952, IRGKangXi=1323.121, Def{lead (a metal)}
4953 CJK UNIFIED IDEOGRAPH-#4953, IRGKangXi=1321.071, Def{a hoe}
4954 CJK UNIFIED IDEOGRAPH-#4954, IRGKangXi=1321.240, Def{gold}
4955 CJK UNIFIED IDEOGRAPH-#4955, IRGKangXi=1321.330, Def{(same as 鐅) the blade or edge of a spade, an open-lidded shallow pan used to boil salt}
4956 CJK UNIFIED IDEOGRAPH-#4956, IRGKangXi=1322.080, Def{(same as 鈿) silver of gold filigree, hairpin, inlaid work}
4957 CJK UNIFIED IDEOGRAPH-#4957, IRGKangXi=1322.110, Def{a branding-iron, to solder}
4958 CJK UNIFIED IDEOGRAPH-#4958, IRGKangXi=1322.200, Def{(same as 錯) wrong; mistake; error; a fault, a blunder, to mistake, to be confused}
4959 CJK UNIFIED IDEOGRAPH-#4959, IRGKangXi=1323.080, Def{(same as 鐆) a speculum used in ancient times, to produce fire from the rays of the sun}
495A CJK UNIFIED IDEOGRAPH-#495A, IRGKangXi=1323.090, Def{(ancient form of 初) the beginning; the first}
495B CJK UNIFIED IDEOGRAPH-#495B, IRGKangXi=1323.121, Def{a kind of sickle, chemical element; old translation of (鎳); Nickel Ni, to carve}
495C CJK UNIFIED IDEOGRAPH-#495C, IRGKangXi=1323.121, Def{(same as 鐗,鐧) protective metal on the axis of a wheel, a kind of ancient weapon}
495D CJK UNIFIED IDEOGRAPH-#495D, IRGKangXi=1323.140, Def{(standard form of 鏖) desperate fighting; to fight hard, (a stove) for keeping warm; to stew something until it's tender}
495E CJK UNIFIED IDEOGRAPH-#495E, IRGKangXi=1323.270, Def{to cut with shears}
495F CJK UNIFIED IDEOGRAPH-#495F, IRGKangXi=1323.330, Def{(non-classical form 楬) a metal marking- stake; a guidepost; a pile}
4960 CJK UNIFIED IDEOGRAPH-#4960, IRGKangXi=1323.340, Def{(same as 鍼 針) needle; pin; probe}
4961 CJK UNIFIED IDEOGRAPH-#4961, IRGKangXi=1324.020, Def{(non-classical form of 鍱) thin plates of metal, to wrap with metal plates, iron of copper ore, ingots, bars of metal, a metal ring}
4962 CJK UNIFIED IDEOGRAPH-#4962, IRGKangXi=1324.050, Def{sound of drums; loud music, to beat the drum and to keep the watches at night}
4963 CJK UNIFIED IDEOGRAPH-#4963, IRGKangXi=1324.080, Def{(same as 鑿) an instrument for boring wood; to chisel, to bore or pierce through}
4964 CJK UNIFIED IDEOGRAPH-#4964, IRGKangXi=1324.110, Def{the neck of a pestle; the neck part of a baton used to pound clothes in washing}
4965 CJK UNIFIED IDEOGRAPH-#4965, IRGKangXi=1326.121, Def{a sickle, a reaping-hook, an angle of the arrowhead, medical instrument used in old times}
4966 CJK UNIFIED IDEOGRAPH-#4966, IRGKangXi=1324.161
4967 CJK UNIFIED IDEOGRAPH-#4967, IRGKangXi=1324.190, Def{(same as 璿 璇) a fine kind of jade}
4968 CJK UNIFIED IDEOGRAPH-#4968, IRGKangXi=1324.200, Def{a file; a rasp; a polishing tool, to burnish, to polish, the handle of a lances and spear}
4969 CJK UNIFIED IDEOGRAPH-#4969, IRGKangXi=1324.300, Def{hooks to hang; to suspend something}
496A CJK UNIFIED IDEOGRAPH-#496A, IRGKangXi=1325.010, Def{to cup; to pare; to trim; to shave}
496B CJK UNIFIED IDEOGRAPH-#496B, IRGKangXi=1325.140, Def{(ancient form of 鐵) iron, strong; firm}
496C CJK UNIFIED IDEOGRAPH-#496C, IRGKangXi=1325.150, Def{(interchangeable 鎛) a musical instrument in old times, a large bell suspended from a frame; a kind of ancient bell, a variety of hoe}
496D CJK UNIFIED IDEOGRAPH-#496D, IRGKangXi=1325.180, Def{(same as 證) evidence, proof, to give evidence, to testify)}
496E CJK UNIFIED IDEOGRAPH-#496E, IRGKangXi=1325.181, Def{to beat; to strike}
496F CJK UNIFIED IDEOGRAPH-#496F, IRGKangXi=1325.200, Def{a farm tool to crush the clod of earth into pieces and make the land flat, a big iron stick, to till lands; to plough; to cultivate; to harrow}
4970 CJK UNIFIED IDEOGRAPH-#4970, IRGKangXi=1326.040, Def{to melt, to sell, to fling a lance or a spear; to brandish spears as if they were flying}
4971 CJK UNIFIED IDEOGRAPH-#4971, IRGKangXi=1326.050, Def{to melt or cast (metal) by using a mould, (non-classical form of 寫) to write; to draw}
4972 CJK UNIFIED IDEOGRAPH-#4972, IRGKangXi=1326.121, Def{a chemical element; old translation of (銪) Eu}
4973 CJK UNIFIED IDEOGRAPH-#4973, IRGKangXi=1326.121, Def{a chemical element; old translation of (銪) Eu}
4974 CJK UNIFIED IDEOGRAPH-#4974, IRGKangXi=1326.261, Def{(same as 鐫) to engrave or carve; as a block for printing}
4975 CJK UNIFIED IDEOGRAPH-#4975, IRGKangXi=1326.130, Def{lines; stripes; veins on an iron plate}
4976 CJK UNIFIED IDEOGRAPH-#4976, IRGKangXi=1326.150, Def{(same as 鬲) cooking utensil used in old times, sacrificial vessel; a heavy three-legged caldron; huge tripod of bronze with two ears}
4977 CJK UNIFIED IDEOGRAPH-#4977, IRGKangXi=1326.260, Def{(same as U+9358 鍘) a hinged shear or long knife for cutting fodder or hay; sheet-iron, etc., to cut up}
4978 CJK UNIFIED IDEOGRAPH-#4978, IRGKangXi=1327.020, Def{a sickle}
4979 CJK UNIFIED IDEOGRAPH-#4979, IRGKangXi=1328.061
497A CJK UNIFIED IDEOGRAPH-#497A, IRGKangXi=1328.061, Def{(same as 鋣) name of a double-edged sword, (simplified form 釾) a chemical element (鎄) (Es)}
497B CJK UNIFIED IDEOGRAPH-#497B, IRGKangXi=1328.061, Def{(simplified form)}
497C CJK UNIFIED IDEOGRAPH-#497C, IRGKangXi=1328.061, Def{(simplified form)}
497D CJK UNIFIED IDEOGRAPH-#497D, IRGKangXi=1328.061, Def{(simplified form of 鏺) farm tool; blade in both side with a long handle used to cut weeds, to exterminate; to settle disorders}
497E CJK UNIFIED IDEOGRAPH-#497E, IRGKangXi=1328.061, Def{(simplified form of U+4971 䥱) to melt or cast (metal) by using a mold; (non-classical form of U+5BEB 寫) to write; to draw}
497F CJK UNIFIED IDEOGRAPH-#497F, IRGKangXi=1328.061
4980 CJK UNIFIED IDEOGRAPH-#4980, IRGKangXi=1328.061
4981 CJK UNIFIED IDEOGRAPH-#4981, IRGKangXi=1328.061, Def{a broad hoe, a mattock}
4982 CJK UNIFIED IDEOGRAPH-#4982, IRGKangXi=1328.061, Def{(simplified form of U+4947 䥇) sarmarium (Sm); old ideograph for U+92F1 鋱, terbium (Tb); (same as U+91E4 釤) a sickle with a long handle, to swing a sickle to cut (grass or wheat)}
4983 CJK UNIFIED IDEOGRAPH-#4983, IRGKangXi=1328.061, Def{(simplified form) to dig with a hoe, a big hoe}
4984 CJK UNIFIED IDEOGRAPH-#4984, IRGKangXi=1328.061, Def{(simplified form)}
4985 CJK UNIFIED IDEOGRAPH-#4985, IRGKangXi=1328.061, Def{(simplified form of 鐥) a kind of weapon used in ancient times, (same as 釤) a sickle with a long handle, to swing a sickle to cut (grass or wheat)}
4986 CJK UNIFIED IDEOGRAPH-#4986, IRGKangXi=1328.061, Def{(simplified form) a big hoe, to eliminate; to uproot; to clear; to dig; to excavate}
4987 CJK UNIFIED IDEOGRAPH-#4987, IRGKangXi=1329.011, Def{(ancient form of 髻) dressed hair of a Chinese woman; a coiffure with a topknot}
4988 CJK UNIFIED IDEOGRAPH-#4988, IRGKangXi=1329.120, Def{(ancient form of 嗟) to sigh in lamentation; to lament; an exclamation expressing grief or regret; to exclaim, name of a hill}
4989 CJK UNIFIED IDEOGRAPH-#4989, IRGKangXi=1329.131
498A CJK UNIFIED IDEOGRAPH-#498A, IRGKangXi=1329.160, Def{an appliance for walking on the sands (as boat for river; car for highway)}
498B CJK UNIFIED IDEOGRAPH-#498B, IRGKangXi=1329.380, Def{to grow; to increase or advance, to become}
498C CJK UNIFIED IDEOGRAPH-#498C, IRGKangXi=1330.100, Def{the door is wide open; directly in the front}
498D CJK UNIFIED IDEOGRAPH-#498D, IRGKangXi=1330.160, Def{to include; to embrace, to search for, intransigent; stubborn; obstinate}
498E CJK UNIFIED IDEOGRAPH-#498E, IRGKangXi=1331.020, Def{(interchangeable 管) a mechanical device for lead ore, (non-classical form of 閌) high; tall and big; lofty (said of the door)}
498F CJK UNIFIED IDEOGRAPH-#498F, IRGKangXi=1331.110, Def{wing of a door}
4990 CJK UNIFIED IDEOGRAPH-#4990, IRGKangXi=1331.160, Def{the bolt of a door; door latch, (non-classical form of 開) open}
4991 CJK UNIFIED IDEOGRAPH-#4991, IRGKangXi=1333.020, Def{without a door; no family}
4992 CJK UNIFIED IDEOGRAPH-#4992, IRGKangXi=1333.110, Def{the door is closed, to knock at the door; to beat or to strike lightly}
4993 CJK UNIFIED IDEOGRAPH-#4993, IRGKangXi=1333.200, Def{to wait for something to happen immediately; (same as U+8998 覘) to spy on; to peep; to watch or see in secret}
4994 CJK UNIFIED IDEOGRAPH-#4994, IRGKangXi=1333.220, Def{a peg; a stake; a door stopper, the bolt of a door; door latch}
4995 CJK UNIFIED IDEOGRAPH-#4995, IRGKangXi=1334.010, Def{(same as 閛) bang of the door; the sound of opening or closing the door}
4996 CJK UNIFIED IDEOGRAPH-#4996, IRGKangXi=1334.020, Def{sound of the door, the gate of the Zheng State city wall (the Epoch of Spring and Autumn)}
4997 CJK UNIFIED IDEOGRAPH-#4997, IRGKangXi=1334.100, Def{(same as 侐) quiet (house, surrounding, etc.)}
4998 CJK UNIFIED IDEOGRAPH-#4998, IRGKangXi=1334.170, Def{(same as 限) a threshold; door-sill}
4999 CJK UNIFIED IDEOGRAPH-#4999, IRGKangXi=1334.180, Def{(same as U+5BFA 寺) a government agency, the court, a eunuch}
499A CJK UNIFIED IDEOGRAPH-#499A, IRGKangXi=1335.050, Def{wide open of the door, (non-classical form of 闊) broad; wide; width}
499B CJK UNIFIED IDEOGRAPH-#499B, IRGKangXi=1335.091, Def{to struggle; struggle; to strive}
499C CJK UNIFIED IDEOGRAPH-#499C, IRGKangXi=1335.150, Def{(same as standard form 郚) name of a state in old times}
499D CJK UNIFIED IDEOGRAPH-#499D, IRGKangXi=1336.030, Def{sound of the door, to open}
499E CJK UNIFIED IDEOGRAPH-#499E, IRGKangXi=1336.111, Def{(same as 閏) extra; inserted between others, as a day or month, to intercalate}
499F CJK UNIFIED IDEOGRAPH-#499F, IRGKangXi=1336.111, Def{to struggle; struggle; to strive, firm; stable; secure}
49A0 CJK UNIFIED IDEOGRAPH-#49A0, IRGKangXi=1336.150, Def{name of a river, door}
49A1 CJK UNIFIED IDEOGRAPH-#49A1, IRGKangXi=1336.160, Def{a door-keeper, an entrance of a palace, a secluded dweling}
49A2 CJK UNIFIED IDEOGRAPH-#49A2, IRGKangXi=1337.010, Def{(non-classical form of 闊) broad; wide; width}
49A3 CJK UNIFIED IDEOGRAPH-#49A3, IRGKangXi=1337.090, Def{open the door}
49A4 CJK UNIFIED IDEOGRAPH-#49A4, IRGKangXi=1337.140, Def{seed of grains}
49A5 CJK UNIFIED IDEOGRAPH-#49A5, IRGKangXi=1338.040, Def{to learn, habit; practice, ways of doing things, law; regulations}
49A6 CJK UNIFIED IDEOGRAPH-#49A6, IRGKangXi=1338.081, Def{(same as 琴) a musical instrument}
49A7 CJK UNIFIED IDEOGRAPH-#49A7, IRGKangXi=1338.081, Def{(same as 鬩) to quarrel; to conflict, contention; animosity; resentment; recriminations}
49A8 CJK UNIFIED IDEOGRAPH-#49A8, IRGKangXi=1338.081, Def{(corrupted form of 闌) a door curtain or screen, a fence, to separate; to block up, the end of; late}
49A9 CJK UNIFIED IDEOGRAPH-#49A9, IRGKangXi=1338.081
49AA CJK UNIFIED IDEOGRAPH-#49AA, IRGKangXi=1338.090, Def{sound of the door}
49AB CJK UNIFIED IDEOGRAPH-#49AB, IRGKangXi=1338.100, Def{inside the door}
49AC CJK UNIFIED IDEOGRAPH-#49AC, IRGKangXi=1338.130, Def{a vacancy; an opening}
49AD CJK UNIFIED IDEOGRAPH-#49AD, IRGKangXi=1338.150, Def{to open; sweet-smelling; fragrant, delicious}
49AE CJK UNIFIED IDEOGRAPH-#49AE, IRGKangXi=1338.200, Def{door of the center}
49AF CJK UNIFIED IDEOGRAPH-#49AF, IRGKangXi=1338.270, Def{very dense; no break; to cluster together}
49B0 CJK UNIFIED IDEOGRAPH-#49B0, IRGKangXi=1341.141, Def{(same as 鬮) lots, to draw lots}
49B1 CJK UNIFIED IDEOGRAPH-#49B1, IRGKangXi=1341.180, Def{open the door, the door is slanted}
49B2 CJK UNIFIED IDEOGRAPH-#49B2, IRGKangXi=1342.160, Def{eaves of a ancestral temple (of the ruling family), door of a shrine or a temple, small opening (of a door), to spy; to peep}
49B3 CJK UNIFIED IDEOGRAPH-#49B3, IRGKangXi=1342.170, Def{between steps, window}
49B4 CJK UNIFIED IDEOGRAPH-#49B4, IRGKangXi=1343.010, Def{open the door}
49B5 CJK UNIFIED IDEOGRAPH-#49B5, IRGKangXi=1343.030, Def{incapable, weak; feeble, narrow minded}
49B6 CJK UNIFIED IDEOGRAPH-#49B6, IRGKangXi=1343.121, Def{(simplified form of U+499B 䦛) to struggle; struggle; to strive}
49B7 CJK UNIFIED IDEOGRAPH-#49B7, IRGKangXi=1343.121, Def{(simplified form of U+499F 䦟) to struggle; struggle; to strive, firm; stable; secure}
49B8 CJK UNIFIED IDEOGRAPH-#49B8, IRGKangXi=1343.121
49B9 CJK UNIFIED IDEOGRAPH-#49B9, IRGKangXi=1345.060, Def{name of a county in today's Sichuan Province}
49BA CJK UNIFIED IDEOGRAPH-#49BA, IRGKangXi=1345.080, Def{name of a hill}
49BB CJK UNIFIED IDEOGRAPH-#49BB, IRGKangXi=1345.140, Def{name of a place}
49BC CJK UNIFIED IDEOGRAPH-#49BC, IRGKangXi=1346.160, Def{to dig a passage through a mountain or hill; to drill, collapsed in ruins; to crumble, the earth cracking up}
49BD CJK UNIFIED IDEOGRAPH-#49BD, IRGKangXi=1347.010, Def{(same as 序) an east and west wall; side rooms, screen-walls to private rooms of the palace, ancient school which was also an asylum for aged scholars}
49BE CJK UNIFIED IDEOGRAPH-#49BE, IRGKangXi=0125.191, Def{lofty, (same as U+9656 陖), rock; stone, name of a place}
49BF CJK UNIFIED IDEOGRAPH-#49BF, IRGKangXi=1347.081
49C0 CJK UNIFIED IDEOGRAPH-#49C0, IRGKangXi=1347.081
49C1 CJK UNIFIED IDEOGRAPH-#49C1, IRGKangXi=1347.090, Def{to leave; to depart; to separate, distant from, a village in ancient times in Anyi}
49C2 CJK UNIFIED IDEOGRAPH-#49C2, IRGKangXi=1347.130, Def{to turn over the clod of the earth with a shovel or a spade, to plough the land for rotation of crops, a channel for irrigation in farmland}
49C3 CJK UNIFIED IDEOGRAPH-#49C3, IRGKangXi=1347.160, Def{name of a place}
49C4 CJK UNIFIED IDEOGRAPH-#49C4, IRGKangXi=1349.070, Def{name of a person}
49C5 CJK UNIFIED IDEOGRAPH-#49C5, IRGKangXi=1350.010, Def{dangerous; hazardous; difficult; trouble, disaster or distress, name of a place}
49C6 CJK UNIFIED IDEOGRAPH-#49C6, IRGKangXi=1350.080, Def{a pit; a hole; a gully}
49C7 CJK UNIFIED IDEOGRAPH-#49C7, IRGKangXi=1350.120, Def{name of a hillside, name of a village, name of tomb of an emperor; name of a high mound}
49C8 CJK UNIFIED IDEOGRAPH-#49C8, IRGKangXi=1350.201
49C9 CJK UNIFIED IDEOGRAPH-#49C9, IRGKangXi=1351.050, Def{name of a pavilion in Han Dynasty, name of a county in ancient China}
49CA CJK UNIFIED IDEOGRAPH-#49CA, IRGKangXi=1351.110, Def{a big mound, name of a mound in today's Shanxi Province}
49CB CJK UNIFIED IDEOGRAPH-#49CB, IRGKangXi=1351.180, Def{name of a place, boundary; a line}
49CC CJK UNIFIED IDEOGRAPH-#49CC, IRGKangXi=1352.030, Def{name of a place}
49CD CJK UNIFIED IDEOGRAPH-#49CD, IRGKangXi=1352.050, Def{(non-classical form of 隙) a crack; a crevice; a fissure}
49CE CJK UNIFIED IDEOGRAPH-#49CE, IRGKangXi=1352.141, Def{a pit; a hole; a gully}
49CF CJK UNIFIED IDEOGRAPH-#49CF, IRGKangXi=1352.141
49D0 CJK UNIFIED IDEOGRAPH-#49D0, IRGKangXi=1352.150, Def{a mountain in Shanxi Province, name of a county in old times}
49D1 CJK UNIFIED IDEOGRAPH-#49D1, IRGKangXi=1352.160, Def{(ancient form of 隄 堤) a dike; levee or embankment}
49D2 CJK UNIFIED IDEOGRAPH-#49D2, IRGKangXi=1353.030, Def{steps leading up to a building}
49D3 CJK UNIFIED IDEOGRAPH-#49D3, IRGKangXi=1353.160, Def{a big mound, abundant; fertile}
49D4 CJK UNIFIED IDEOGRAPH-#49D4, IRGKangXi=1353.170, Def{to meet at the bank; shore; beach; coast}
49D5 CJK UNIFIED IDEOGRAPH-#49D5, IRGKangXi=1354.020, Def{(same as 域) boundary; a frontier, a region; a country, (ancient form of 城) a city; a town}
49D6 CJK UNIFIED IDEOGRAPH-#49D6, IRGKangXi=1354.030, Def{a small mound}
49D7 CJK UNIFIED IDEOGRAPH-#49D7, IRGKangXi=1356.070, Def{mountains collapsing; a land-slide}
49D8 CJK UNIFIED IDEOGRAPH-#49D8, IRGKangXi=1356.170, Def{a low wall on the road side, a wall, the space enclosed by a constellation}
49D9 CJK UNIFIED IDEOGRAPH-#49D9, IRGKangXi=1357.100, Def{(ancient form of 陵) a high mound, tomb of an emperor, to usurp; to abuse}
49DA CJK UNIFIED IDEOGRAPH-#49DA, IRGKangXi=1358.030, Def{(same as 鄗) the name of a place in the south-west of Hebei Province}
49DB CJK UNIFIED IDEOGRAPH-#49DB, IRGKangXi=1358.060, Def{(same as 傍) beside; by the side of; near; close, sound of vehicles; wheels}
49DC CJK UNIFIED IDEOGRAPH-#49DC, IRGKangXi=1358.070, Def{(same as 塘) an embankment; a bund; a bank; a dike, to generally the roads, (interchangeable 唐) the Tand Dynasty, abrupt; rude}
49DD CJK UNIFIED IDEOGRAPH-#49DD, IRGKangXi=1358.100, Def{name of a place, name of a mountain}
49DE CJK UNIFIED IDEOGRAPH-#49DE, IRGKangXi=1358.160, Def{to increase; to profit; to augment, artful; clever; skillful, chips (in gambling, etc.), a number (for identification), abundant; rich; exuberant; flourishing; prosperous}
49DF CJK UNIFIED IDEOGRAPH-#49DF, IRGKangXi=1359.161, Def{(same as 陷) to skin, to involve; to beguile, to betray}
49E0 CJK UNIFIED IDEOGRAPH-#49E0, IRGKangXi=1359.250, Def{(same as 鄟) name of a place (the Epoch of Spring and Autumn) in what is today's Shandong Province}
49E1 CJK UNIFIED IDEOGRAPH-#49E1, IRGKangXi=1360.030, Def{(same as 墉) a fortified wall, a wall}
49E2 CJK UNIFIED IDEOGRAPH-#49E2, IRGKangXi=1360.040, Def{a rough road, a rugged; steep mountain uneasy}
49E3 CJK UNIFIED IDEOGRAPH-#49E3, IRGKangXi=1360.090, Def{(same as 鄄 堙) to stop up; to gag; blocked}
49E4 CJK UNIFIED IDEOGRAPH-#49E4, IRGKangXi=1360.130, Def{(same as 濮) name of a river in Shandong Province, name of an ancient tribe in Hubei Province}
49E5 CJK UNIFIED IDEOGRAPH-#49E5, IRGKangXi=1360.140, Def{border; frontier}
49E6 CJK UNIFIED IDEOGRAPH-#49E6, IRGKangXi=1360.180, Def{name of a hillside; a slope in today's Henan Province}
49E7 CJK UNIFIED IDEOGRAPH-#49E7, IRGKangXi=1360.370, Def{(same as 嶬) high mountains; steep; lofty}
49E8 CJK UNIFIED IDEOGRAPH-#49E8, IRGKangXi=1360.380, Def{precipitous; steep and lofty of a high mountain}
49E9 CJK UNIFIED IDEOGRAPH-#49E9, IRGKangXi=1360.341
49EA CJK UNIFIED IDEOGRAPH-#49EA, IRGKangXi=1362.020, Def{sissy; womanish, fawning manner; obsequiousness}
49EB CJK UNIFIED IDEOGRAPH-#49EB, IRGKangXi=1362.110, Def{a trench (in warfare); a ditch, to soar; to fly, to roam}
49EC CJK UNIFIED IDEOGRAPH-#49EC, IRGKangXi=1362.191, Def{(same as 瀕 濱) water's edge; to border on; to brink on, near at hand; close by}
49ED CJK UNIFIED IDEOGRAPH-#49ED, IRGKangXi=1362.191
49EE CJK UNIFIED IDEOGRAPH-#49EE, IRGKangXi=1363.070, Def{name of a place, (same as 顯) to manifest, to display, to be illustrious, evident, to seem; to appear}
49EF CJK UNIFIED IDEOGRAPH-#49EF, IRGKangXi=1363.120, Def{name of a place, to skin, to involve; to beguile, to betray}
49F0 CJK UNIFIED IDEOGRAPH-#49F0, IRGKangXi=1363.150, Def{a mound}
49F1 CJK UNIFIED IDEOGRAPH-#49F1, IRGKangXi=1364.060, Def{(same as 鳩) the pigeon, the turtle dove}
49F2 CJK UNIFIED IDEOGRAPH-#49F2, IRGKangXi=1364.160, Def{the magpie, jackdaw; jay and similar birds}
49F3 CJK UNIFIED IDEOGRAPH-#49F3, IRGKangXi=1364.190, Def{(same as 雌) female; feminine, a female bird, to dwell, to stop}
49F4 CJK UNIFIED IDEOGRAPH-#49F4, IRGKangXi=1365.020, Def{a bird, to map out or draw up (a plan); a plan or scheme; to calculate; to count; to consider}
49F5 CJK UNIFIED IDEOGRAPH-#49F5, IRGKangXi=1365.100, Def{(non-classical form of 鴆) a bird like the secretary falcon}
49F6 CJK UNIFIED IDEOGRAPH-#49F6, IRGKangXi=1365.181, Def{to care for; to concern about affectionately, (a corrupted form of 奊) slanting; not straight; curved (of the head)}
49F7 CJK UNIFIED IDEOGRAPH-#49F7, IRGKangXi=1365.190, Def{a kind of bird}
49F8 CJK UNIFIED IDEOGRAPH-#49F8, IRGKangXi=1366.020, Def{(same as 鴣) a kind of pigeon; partridge; francolin}
49F9 CJK UNIFIED IDEOGRAPH-#49F9, IRGKangXi=1366.100, RSKangXi=172.5, Def{(same as U+9DF9 鷹) hawk; eagle; falcon}
49FA CJK UNIFIED IDEOGRAPH-#49FA, IRGKangXi=1366.180, Def{(same as 雄) the male of birds}
49FB CJK UNIFIED IDEOGRAPH-#49FB, IRGKangXi=1366.190, Def{(same as 鴿) dove; pigeon}
49FC CJK UNIFIED IDEOGRAPH-#49FC, IRGKangXi=1367.200, Def{(same as 鵠) the the snow goose; swan, standing erect; standing quietly, target; bull's-eye}
49FD CJK UNIFIED IDEOGRAPH-#49FD, IRGKangXi=1367.330, Def{(corrupted form) small, thin and slim neck}
49FE CJK UNIFIED IDEOGRAPH-#49FE, IRGKangXi=1367.440, Def{a kind of bird; like wild duck}
49FF CJK UNIFIED IDEOGRAPH-#49FF, IRGKangXi=1367.480, Def{(same as 鵲) the magpie}
4A00 CJK UNIFIED IDEOGRAPH-#4A00, IRGKangXi=0912.030, Def{(same as 籴 糴) to lay in grain; to buy grain}
4A01 CJK UNIFIED IDEOGRAPH-#4A01, IRGKangXi=1368.090, Def{(same as 鶩) ducks; either wild or tame, a chick, a very young bird -- fledgling}
4A02 CJK UNIFIED IDEOGRAPH-#4A02, IRGKangXi=1368.180, Def{a chick}
4A03 CJK UNIFIED IDEOGRAPH-#4A03, IRGKangXi=1369.041
4A04 CJK UNIFIED IDEOGRAPH-#4A04, IRGKangXi=1370.040, Def{(same as 鵪) quail}
4A05 CJK UNIFIED IDEOGRAPH-#4A05, IRGKangXi=1370.160, Def{(same as 鷯) small birds -- the wren, tit, etc.}
4A06 CJK UNIFIED IDEOGRAPH-#4A06, IRGKangXi=1370.290, Def{(same as 鷩) a kind of pheasant}
4A07 CJK UNIFIED IDEOGRAPH-#4A07, IRGKangXi=1370.291, Def{(same as 雙) a pair; a couple; a brace, two; both}
4A08 CJK UNIFIED IDEOGRAPH-#4A08, IRGKangXi=1370.430, Def{a small bird}
4A09 CJK UNIFIED IDEOGRAPH-#4A09, IRGKangXi=1371.140, Def{(same as 鸚) parrot}
4A0A CJK UNIFIED IDEOGRAPH-#4A0A, IRGKangXi=1371.170, Def{a flock of birds}
4A0B CJK UNIFIED IDEOGRAPH-#4A0B, IRGKangXi=1371.301, Def{(same as 虐) cruel; ferocious; atrocious}
4A0C CJK UNIFIED IDEOGRAPH-#4A0C, IRGKangXi=1371.340, Def{(same as 雹) hail; hailstone}
4A0D CJK UNIFIED IDEOGRAPH-#4A0D, IRGKangXi=1372.020, Def{deep pond; deep pool}
4A0E CJK UNIFIED IDEOGRAPH-#4A0E, IRGKangXi=1372.070, Def{(same as 霐) deep and dark}
4A0F CJK UNIFIED IDEOGRAPH-#4A0F, IRGKangXi=1373.110, Def{sound of raining, a great fall of rain; heavy rain; it rained large drops}
4A10 CJK UNIFIED IDEOGRAPH-#4A10, IRGKangXi=1373.120, Def{(same as 洽) to spread; to diffuse, harmony; agreement, name of a frontier pass; near today's Sichuan Province}
4A11 CJK UNIFIED IDEOGRAPH-#4A11, IRGKangXi=1373.150, Def{to stop raining; to clear up, dispersion, a clear sky after rain}
4A12 CJK UNIFIED IDEOGRAPH-#4A12, IRGKangXi=1373.170, Def{sound of the water drops, raining, acquired dialects, (interchangeable 羽) feather; plume}
4A13 CJK UNIFIED IDEOGRAPH-#4A13, IRGKangXi=1373.190, Def{(ancient form of U+9741 雷) thunder, mine (an explosive); fuse}
4A14 CJK UNIFIED IDEOGRAPH-#4A14, IRGKangXi=1373.270, Def{(same as U+96F9 雹) hail; hailstone}
4A15 CJK UNIFIED IDEOGRAPH-#4A15, IRGKangXi=1374.020, Def{(a variant) pouring with rain}
4A16 CJK UNIFIED IDEOGRAPH-#4A16, IRGKangXi=1374.021, Def{(non-classical form of 霽) to stop raining; to clear up; the sky clearing up}
4A17 CJK UNIFIED IDEOGRAPH-#4A17, IRGKangXi=1374.040, Def{excessive rain and snow}
4A18 CJK UNIFIED IDEOGRAPH-#4A18, IRGKangXi=1374.100, Def{(same as U+9730 霰) sleet}
4A19 CJK UNIFIED IDEOGRAPH-#4A19, IRGKangXi=1374.150, Def{(same as 霪) to rain cats and dogs for a long time, incessant rain}
4A1A CJK UNIFIED IDEOGRAPH-#4A1A, IRGKangXi=1375.100, Def{to rain}
4A1B CJK UNIFIED IDEOGRAPH-#4A1B, IRGKangXi=1375.130, Def{to rain, snowflakes, light rain; drizzle}
4A1C CJK UNIFIED IDEOGRAPH-#4A1C, IRGKangXi=1375.220, Def{a pouring rain; to rain cats and dogs, completely, with leaving a trace, dull; stupid; doltish}
4A1D CJK UNIFIED IDEOGRAPH-#4A1D, IRGKangXi=1375.230, Def{a pure woman; name of a goddess of frost and snow}
4A1E CJK UNIFIED IDEOGRAPH-#4A1E, IRGKangXi=1376.100, Def{to rain, to stretch; to open; to relax; to unfold, slow; unhurried; leisurely}
4A1F CJK UNIFIED IDEOGRAPH-#4A1F, IRGKangXi=1376.120, Def{puddle (water in the hoof's track), (same as 窪) deep, a pit; a swamp; a hollow; a depression}
4A20 CJK UNIFIED IDEOGRAPH-#4A20, IRGKangXi=1376.190, Def{(same as 靄) cloudy sky, fair clouds; a beautiful sky, mild; amiable; peaceful}
4A21 CJK UNIFIED IDEOGRAPH-#4A21, IRGKangXi=1376.200, Def{rained for a long time; too much rain}
4A22 CJK UNIFIED IDEOGRAPH-#4A22, IRGKangXi=1376.240, Def{(same as 霮) a passing cloud; floating clouds, densely covered by clouds; gathering clouds}
4A23 CJK UNIFIED IDEOGRAPH-#4A23, IRGKangXi=1376.260, Def{leather to be moistened by rain}
4A24 CJK UNIFIED IDEOGRAPH-#4A24, IRGKangXi=1377.010, Def{rain, to rain}
4A25 CJK UNIFIED IDEOGRAPH-#4A25, IRGKangXi=1377.110, Def{a pouring rain; to rain hard; to rain cats and dogs, a pair; a couple, two; both, to rain}
4A26 CJK UNIFIED IDEOGRAPH-#4A26, IRGKangXi=1377.130, Def{(same as 雱) snowing heavily}
4A27 CJK UNIFIED IDEOGRAPH-#4A27, IRGKangXi=1377.160, Def{(standard form of 霠), (corrupted form of 霒) cloudy; dark and gloomy}
4A28 CJK UNIFIED IDEOGRAPH-#4A28, IRGKangXi=1377.200, Def{thunder, hidden; concealed; secret, (same as 頤) the chin; the jaws}
4A29 CJK UNIFIED IDEOGRAPH-#4A29, IRGKangXi=1377.290, Def{(same as 靈) the spirit; the soul, divine, super-natural}
4A2A CJK UNIFIED IDEOGRAPH-#4A2A, IRGKangXi=1377.300, Def{(same as 霾) a dust-storm, misty; foggy; cloudy}
4A2B CJK UNIFIED IDEOGRAPH-#4A2B, IRGKangXi=1377.350, Def{(interchangeable 霢) drizzling rain}
4A2C CJK UNIFIED IDEOGRAPH-#4A2C, IRGKangXi=1377.430, Def{rained for a long time}
4A2D CJK UNIFIED IDEOGRAPH-#4A2D, IRGKangXi=1377.450, Def{(same as 霄) the skies, clouds or mists}
4A2E CJK UNIFIED IDEOGRAPH-#4A2E, IRGKangXi=1377.460, Def{(same as 雪) snow, to clean; to wash or wipe away}
4A2F CJK UNIFIED IDEOGRAPH-#4A2F, IRGKangXi=1378.041, Def{cloudy}
4A30 CJK UNIFIED IDEOGRAPH-#4A30, IRGKangXi=1378.120, Def{rain; to rain, (same as 濼) to dock; to lay anchor}
4A31 CJK UNIFIED IDEOGRAPH-#4A31, IRGKangXi=1378.260, Def{spilt water, to pour out water}
4A32 CJK UNIFIED IDEOGRAPH-#4A32, IRGKangXi=1379.250, Def{a small hare; a small rabbit}
4A33 CJK UNIFIED IDEOGRAPH-#4A33, IRGKangXi=1379.260, Def{the rain stopped}
4A34 CJK UNIFIED IDEOGRAPH-#4A34, IRGKangXi=1379.270, Def{gathering clouds}
4A35 CJK UNIFIED IDEOGRAPH-#4A35, IRGKangXi=1380.090, Def{rained for a long time}
4A36 CJK UNIFIED IDEOGRAPH-#4A36, IRGKangXi=1380.131, Def{(ancient form of 霣) thunderstorm, thunder, (interchangeable 隕 殞) to fall, to die}
4A37 CJK UNIFIED IDEOGRAPH-#4A37, IRGKangXi=1380.311, Def{(same as 霰) sleet}
4A38 CJK UNIFIED IDEOGRAPH-#4A38, IRGKangXi=1381.010, Def{cloudy}
4A39 CJK UNIFIED IDEOGRAPH-#4A39, IRGKangXi=1381.100, Def{swift; rapid; quick; fast}
4A3A CJK UNIFIED IDEOGRAPH-#4A3A, IRGKangXi=1381.150, Def{cloudy}
4A3B CJK UNIFIED IDEOGRAPH-#4A3B, IRGKangXi=1381.180, Def{roar of thunders; thunderpeal, very loud sounds}
4A3C CJK UNIFIED IDEOGRAPH-#4A3C, IRGKangXi=1382.100, Def{dyestuff (of dark green)}
4A3D CJK UNIFIED IDEOGRAPH-#4A3D, IRGKangXi=1382.150, Def{to resolve, to dissolve; to decompose, to analyze, to part, to differ, different, a bird (like a legendary bird with man's face and one leg)}
4A3E CJK UNIFIED IDEOGRAPH-#4A3E, IRGKangXi=1382.180, Def{hidden; concealed; secret, narrow and small, ugly, low; mean, inferior}
4A3F CJK UNIFIED IDEOGRAPH-#4A3F, IRGKangXi=1382.240, Def{bad; evil; wicked; vice; wickedness}
4A40 CJK UNIFIED IDEOGRAPH-#4A40, IRGKangXi=1383.010
4A41 CJK UNIFIED IDEOGRAPH-#4A41, IRGKangXi=1383.050, Def{thin hairs; fine hairs}
4A42 CJK UNIFIED IDEOGRAPH-#4A42, IRGKangXi=1383.120, Def{to come to the front; to take the lead; to bear responsibility, to make good or to succeed (said of people of humble origin)}
4A43 CJK UNIFIED IDEOGRAPH-#4A43, IRGKangXi=1383.160, Def{appearance; a person's features}
4A44 CJK UNIFIED IDEOGRAPH-#4A44, IRGKangXi=1383.161, Def{face to face; to blush; ashamed, embarrassed}
4A45 CJK UNIFIED IDEOGRAPH-#4A45, IRGKangXi=1383.200, Def{broad; wide; spacious; vast, to turn red from shame or embarrassment; to blush, to be ashamed}
4A46 CJK UNIFIED IDEOGRAPH-#4A46, IRGKangXi=1384.010, Def{old, wrinkles; creases, ashamed, shamed-faced look}
4A47 CJK UNIFIED IDEOGRAPH-#4A47, IRGKangXi=1384.020, Def{a small head, to come to the front; to take the lead; to bear responsibility, to make good or to succeed (said of people of humble origin), an ugly face}
4A48 CJK UNIFIED IDEOGRAPH-#4A48, IRGKangXi=1384.080, Def{a plump, fat face}
4A49 CJK UNIFIED IDEOGRAPH-#4A49, IRGKangXi=1384.140, Def{the face, the cheeks; the jaw}
4A4A CJK UNIFIED IDEOGRAPH-#4A4A, IRGKangXi=1384.190, Def{(interchangeable 婉) good-looking; beautiful, with the eyes wide open}
4A4B CJK UNIFIED IDEOGRAPH-#4A4B, IRGKangXi=1384.310, Def{a green face; to look aghast, (interchangeable with U+61E1 懡) ashamed}
4A4C CJK UNIFIED IDEOGRAPH-#4A4C, IRGKangXi=1384.360, Def{to have a worn look; to look haggard, to suffer distress, worries, etc.}
4A4D CJK UNIFIED IDEOGRAPH-#4A4D, IRGKangXi=1384.370, Def{to look pale or pallid}
4A4E CJK UNIFIED IDEOGRAPH-#4A4E, IRGKangXi=1384.411
4A4F CJK UNIFIED IDEOGRAPH-#4A4F, IRGKangXi=1384.450, Def{a small face, small, young, (dialect) a junior}
4A50 CJK UNIFIED IDEOGRAPH-#4A50, IRGKangXi=1385.070, Def{tie it tightly, to lead an ox, a wart; a pustule; a pimple, a round lump}
4A51 CJK UNIFIED IDEOGRAPH-#4A51, IRGKangXi=1385.110, Def{(same as 鞃) horizontal front bar on a cart or carriage, leaning board in a sedan chair}
4A52 CJK UNIFIED IDEOGRAPH-#4A52, IRGKangXi=1385.120, Def{dressed leather; a large belt}
4A53 CJK UNIFIED IDEOGRAPH-#4A53, IRGKangXi=1385.200, Def{(a non-classical form) boots, the leather belts that connect a cart with the horse, etc., the leather decorations on the ends of the hub (of a wheel)}
4A54 CJK UNIFIED IDEOGRAPH-#4A54, IRGKangXi=1385.260, Def{the hem; margin of the heel of a shoe, weeping sash or cord on a saddle, a leather rope, fringes of pearls on crowns, a pennant, (same as 鞶) a large belt}
4A55 CJK UNIFIED IDEOGRAPH-#4A55, IRGKangXi=1386.080, Def{clogs; pattens (protective overshoes); (same as 硬) hard; strong; sturdy; firm}
4A56 CJK UNIFIED IDEOGRAPH-#4A56, IRGKangXi=1386.100, Def{shoes; boots}
4A57 CJK UNIFIED IDEOGRAPH-#4A57, IRGKangXi=1386.101, Def{(same as 霸) to rule by might rather than right; a feudal lord}
4A58 CJK UNIFIED IDEOGRAPH-#4A58, IRGKangXi=1386.101, Def{(same as U+976A 靪) to mend the soles of shoes, patchings; (same as U+97AE 鞮) leather shoes}
4A59 CJK UNIFIED IDEOGRAPH-#4A59, IRGKangXi=1386.110, Def{a scabbard, reins or traces}
4A5A CJK UNIFIED IDEOGRAPH-#4A5A, IRGKangXi=1386.120, Def{(interchangeable 靪) to mend the soles of shoes, patchings, (same as 鞮) leather shoes}
4A5B CJK UNIFIED IDEOGRAPH-#4A5B, IRGKangXi=1386.220, Def{leather belt used to bind or restrain a cart, (same as 轡) reins and bit; a bridle}
4A5C CJK UNIFIED IDEOGRAPH-#4A5C, IRGKangXi=1386.240, Def{(same as 冑) descendants; posterity, a helmet; a head-gear in ancient battles for protection}
4A5D CJK UNIFIED IDEOGRAPH-#4A5D, IRGKangXi=1386.300, Def{(non-classical form of 鞄) to tan and soften leather, (same as 匏) a bottle-gourd, one of the eight kinds of musical sounds, a kind of musical instrument, (interchangeable 枹) a drum-stick (interchangeable 包) handbag or purse (especially one made of leather)}
4A5E CJK UNIFIED IDEOGRAPH-#4A5E, IRGKangXi=1386.310, Def{a saddle-flap, trappings}
4A5F CJK UNIFIED IDEOGRAPH-#4A5F, IRGKangXi=1387.120, Def{leather; processed hides, trappings, known together as saddle; a saddle-like terrain or thing and rein, etc.}
4A60 CJK UNIFIED IDEOGRAPH-#4A60, IRGKangXi=1387.320, Def{(same as 鞓) a girdle; a leather waistband, a leather belt, silk ribbons, sash, etc. attached to an official seal or medal; cordon (as a badge of honor)}
4A61 CJK UNIFIED IDEOGRAPH-#4A61, IRGKangXi=1387.330, Def{a kind of boots in old times, heel of a shoe, (same as 鞈) a leather made breast-plate, to guard; defend}
4A62 CJK UNIFIED IDEOGRAPH-#4A62, IRGKangXi=1387.360, Def{a scabbard; a sheath, a fine mats made from bamboo, (non-classical form of 靼) dressed leather; soft leather}
4A63 CJK UNIFIED IDEOGRAPH-#4A63, IRGKangXi=1387.370, Def{shoe-cushions}
4A64 CJK UNIFIED IDEOGRAPH-#4A64, IRGKangXi=1388.020, Def{to lead an ox, tie it tightly, quick, urgent; hurried; hasty}
4A65 CJK UNIFIED IDEOGRAPH-#4A65, IRGKangXi=1388.040, Def{a belt for horse, horses without saddle or rein, leather shoes}
4A66 CJK UNIFIED IDEOGRAPH-#4A66, IRGKangXi=1388.140, Def{the reins, a small bronze ring used to connect the reins}
4A67 CJK UNIFIED IDEOGRAPH-#4A67, IRGKangXi=1388.150, Def{to tie up hurriedly}
4A68 CJK UNIFIED IDEOGRAPH-#4A68, IRGKangXi=1388.190, Def{(same as 韔) a wrapper or case for bow, to pull an arrow}
4A69 CJK UNIFIED IDEOGRAPH-#4A69, IRGKangXi=1388.210, Def{a measure of capacity, a tool used to take out the mud from a well, back covering or shelter of a large carriage, military vehicles}
4A6A CJK UNIFIED IDEOGRAPH-#4A6A, IRGKangXi=1388.240, Def{known together as saddle; rein and bridle, etc.}
4A6B CJK UNIFIED IDEOGRAPH-#4A6B, IRGKangXi=1388.270, Def{(same as 緉) a unit to count shoes in ancient times; a pair}
4A6C CJK UNIFIED IDEOGRAPH-#4A6C, IRGKangXi=1388.330, Def{an ornamental item on a scabbard, leather shoes, weapons; arms (interchangeable 鞛)}
4A6D CJK UNIFIED IDEOGRAPH-#4A6D, IRGKangXi=1388.370, Def{(same as 羈) halter; to restrain}
4A6E CJK UNIFIED IDEOGRAPH-#4A6E, IRGKangXi=1388.420, Def{a quiver}
4A6F CJK UNIFIED IDEOGRAPH-#4A6F, IRGKangXi=1389.110, Def{(interchangeable 革) urgent; anxious, hard, solid and durable leather, a leather whip}
4A70 CJK UNIFIED IDEOGRAPH-#4A70, IRGKangXi=1389.120, Def{(corrupted form of 鞙) a scabbard, reins or traces}
4A71 CJK UNIFIED IDEOGRAPH-#4A71, IRGKangXi=1389.290, Def{a scabbard; a sheath, remaining; overplus; surplus, sin; evil, the front of a cutting strip of cloth}
4A72 CJK UNIFIED IDEOGRAPH-#4A72, IRGKangXi=1389.300, Def{a tool used to cut leather, an ox to tow, drag or pull a boat}
4A73 CJK UNIFIED IDEOGRAPH-#4A73, IRGKangXi=1390.040, Def{tanning, soft leather}
4A74 CJK UNIFIED IDEOGRAPH-#4A74, IRGKangXi=1390.070, Def{a quiver}
4A75 CJK UNIFIED IDEOGRAPH-#4A75, IRGKangXi=1390.120, Def{(same as 韗) tanner who made the leather drum in ancient times}
4A76 CJK UNIFIED IDEOGRAPH-#4A76, IRGKangXi=1390.160, Def{saddle and rein etc. for the imperial carriage; or for the two outside horses of a team of four abreast, equipments used to saddle a horse}
4A77 CJK UNIFIED IDEOGRAPH-#4A77, IRGKangXi=1390.250, Def{(same as 幫) the sides of a shoe}
4A78 CJK UNIFIED IDEOGRAPH-#4A78, IRGKangXi=1390.270, Def{fine woolen blanket on top of a saddle; used as some decoration, (same as 氄) fine; soft fur}
4A79 CJK UNIFIED IDEOGRAPH-#4A79, IRGKangXi=1390.290, Def{to repair shoes, the front part of a shoe, (same as 鞹 U+979F) leather; hides with the hair removed}
4A7A CJK UNIFIED IDEOGRAPH-#4A7A, IRGKangXi=1391.010, Def{boots; cotton boots}
4A7B CJK UNIFIED IDEOGRAPH-#4A7B, IRGKangXi=1391.071, Def{(same as U+9738 霸) to be chief, to rule by might rather than by right, a tyrant; a usurper; the strong the fierce ones}
4A7C CJK UNIFIED IDEOGRAPH-#4A7C, IRGKangXi=1391.170, Def{stitches on a coverlet, to drum, drum beat}
4A7D CJK UNIFIED IDEOGRAPH-#4A7D, IRGKangXi=1391.210, Def{a quiver (for bows and arrows) one a horse, to store; to keep and collect, a lance; a spear; a trident}
4A7E CJK UNIFIED IDEOGRAPH-#4A7E, IRGKangXi=1391.220, Def{herb medicine; dendrobium}
4A7F CJK UNIFIED IDEOGRAPH-#4A7F, IRGKangXi=1391.300, Def{(same as 鼖) a big drum used in the army (in ancient times)}
4A80 CJK UNIFIED IDEOGRAPH-#4A80, IRGKangXi=1391.330, Def{(same as U+4A6A 䩪) saddle; rein and bridle}
4A81 CJK UNIFIED IDEOGRAPH-#4A81, IRGKangXi=1391.340, Def{a halter}
4A82 CJK UNIFIED IDEOGRAPH-#4A82, IRGKangXi=1391.360, Def{reins; a halter, (interchangeable 革) hides stripped of hair; leather, the target, to force; to compel, to carve, to stop}
4A83 CJK UNIFIED IDEOGRAPH-#4A83, IRGKangXi=1391.410, Def{wine container used by minority tribe in ancient times}
4A84 CJK UNIFIED IDEOGRAPH-#4A84, IRGKangXi=1391.431, Def{(ancient form of 煌) great blaze; luminous; glittering, as the stars; bright and brilliant}
4A85 CJK UNIFIED IDEOGRAPH-#4A85, IRGKangXi=1392.100, Def{(same as 韣) a quiver; bow case}
4A86 CJK UNIFIED IDEOGRAPH-#4A86, IRGKangXi=1392.120, Def{soft; tender, weak; feeble, gentle; mild}
4A87 CJK UNIFIED IDEOGRAPH-#4A87, IRGKangXi=1392.210, Def{cushioned seat on a vehicle, a leather wrapped collar or yoke of a carriage}
4A88 CJK UNIFIED IDEOGRAPH-#4A88, IRGKangXi=1392.230, Def{a leather belt; a leather waistband}
4A89 CJK UNIFIED IDEOGRAPH-#4A89, IRGKangXi=1392.320, Def{metal decoration on a halter}
4A8A CJK UNIFIED IDEOGRAPH-#4A8A, IRGKangXi=1392.380, Def{a halter}
4A8B CJK UNIFIED IDEOGRAPH-#4A8B, IRGKangXi=1392.390, Def{silk cordage; twine; rope}
4A8C CJK UNIFIED IDEOGRAPH-#4A8C, IRGKangXi=1392.430, Def{cushion for saddle, (same as 縿) the weeping decorations of banners and flags; the ends of banners and flags; the weeping decorations of saddles}
4A8D CJK UNIFIED IDEOGRAPH-#4A8D, IRGKangXi=1392.440, Def{a container for bows and arrows}
4A8E CJK UNIFIED IDEOGRAPH-#4A8E, IRGKangXi=1392.450, Def{strings of a cap, decorations for saddle, a sash; a band; a cord, a flag}
4A8F CJK UNIFIED IDEOGRAPH-#4A8F, IRGKangXi=1393.120, Def{weak; feeble; tender; delicate; soft, (dialect) to hang down the head and sleepy}
4A90 CJK UNIFIED IDEOGRAPH-#4A90, IRGKangXi=1393.160, Def{something made of bamboo put in the bow case to protect from damage}
4A91 CJK UNIFIED IDEOGRAPH-#4A91, IRGKangXi=1393.200, Def{to stick; to paste leather to shoes}
4A92 CJK UNIFIED IDEOGRAPH-#4A92, IRGKangXi=1393.240, Def{leather pants, a kind of military uniform, gaiters and leggings}
4A93 CJK UNIFIED IDEOGRAPH-#4A93, IRGKangXi=1393.270, Def{a metal ornament on some kind of belt (clothing of the Northern barbarians)}
4A94 CJK UNIFIED IDEOGRAPH-#4A94, IRGKangXi=1394.100, Def{cross-bar of wood under the carriage, under garments}
4A95 CJK UNIFIED IDEOGRAPH-#4A95, IRGKangXi=1394.190, Def{to wrap or band, (same as 鞠) to nourish, to inform, a ball a child}
4A96 CJK UNIFIED IDEOGRAPH-#4A96, IRGKangXi=1394.250, Def{(same as U+4A99 䪙) leather wrapped collar for a draft animal of a carriage, bags used on a carriage; (same as U+4A94 䪔) undergarments}
4A97 CJK UNIFIED IDEOGRAPH-#4A97, IRGKangXi=1394.290, Def{shoes}
4A98 CJK UNIFIED IDEOGRAPH-#4A98, IRGKangXi=1394.350, Def{(same as 韙) right; proper; propriety, official in charge of music}
4A99 CJK UNIFIED IDEOGRAPH-#4A99, IRGKangXi=1394.390, Def{leather wrapped collar for a draft animal of a carriage, bags used on a carriage; (same as U+4A94 䪔) undergarments}
4A9A CJK UNIFIED IDEOGRAPH-#4A9A, IRGKangXi=1394.430, Def{hot; burning, fur clothing, weapons, drum}
4A9B CJK UNIFIED IDEOGRAPH-#4A9B, IRGKangXi=1395.150, Def{group; crowd; swarm; a flock, a square of leather, leather wrapped}
4A9C CJK UNIFIED IDEOGRAPH-#4A9C, IRGKangXi=1395.220, Def{a shield; a screen, (same as 襜) the low front of a robe, gown, etc., a short coat that have no lining, a small mud guard, or fender, a leather garment worn during sacrificial rituals in ancient times}
4A9D CJK UNIFIED IDEOGRAPH-#4A9D, IRGKangXi=1395.270, Def{leather thong wound around the handle of a sword}
4A9E CJK UNIFIED IDEOGRAPH-#4A9E, IRGKangXi=1396.060, Def{bad; evil; wicked; vice, last name written in the seal type}
4A9F CJK UNIFIED IDEOGRAPH-#4A9F, IRGKangXi=1396.081
4AA0 CJK UNIFIED IDEOGRAPH-#4AA0, IRGKangXi=1396.121, Def{(same as U+97F2 齏) pulverized; powdered; crumbs; bits}
4AA1 CJK UNIFIED IDEOGRAPH-#4AA1, IRGKangXi=1396.170, Def{(same as 齏) to fall down; to sink}
4AA2 CJK UNIFIED IDEOGRAPH-#4AA2, IRGKangXi=1396.171, Def{smashed; pickled vegetable}
4AA3 CJK UNIFIED IDEOGRAPH-#4AA3, IRGKangXi=1396.191, Def{(same as 䪢) smashed; pickled vegetable}
4AA4 CJK UNIFIED IDEOGRAPH-#4AA4, IRGKangXi=1396.200, Def{garlic}
4AA5 CJK UNIFIED IDEOGRAPH-#4AA5, IRGKangXi=1396.220, Def{shallots or scallions, small (piece of land); narrow (minded)}
4AA6 CJK UNIFIED IDEOGRAPH-#4AA6, IRGKangXi=1397.010, Def{loud}
4AA7 CJK UNIFIED IDEOGRAPH-#4AA7, IRGKangXi=1397.020, Def{ancient music; Chinese classical music}
4AA8 CJK UNIFIED IDEOGRAPH-#4AA8, IRGKangXi=1397.021
4AA9 CJK UNIFIED IDEOGRAPH-#4AA9, IRGKangXi=1397.040, Def{(same as 吟) to chant; to intone; to sing; to recite; to moan; to sigh}
4AAA CJK UNIFIED IDEOGRAPH-#4AAA, IRGKangXi=1397.111
4AAB CJK UNIFIED IDEOGRAPH-#4AAB, IRGKangXi=1397.190, Def{ancient music; Chinese classical music}
4AAC CJK UNIFIED IDEOGRAPH-#4AAC, IRGKangXi=1397.200, Def{sound of pressing something down}
4AAD CJK UNIFIED IDEOGRAPH-#4AAD, IRGKangXi=1397.251, Def{a kind of musical instrument}
4AAE CJK UNIFIED IDEOGRAPH-#4AAE, IRGKangXi=1397.260, Def{beautiful sound, appealing to the ear; fascinating to listen to (said of music), noise or uproar of the crowd}
4AAF CJK UNIFIED IDEOGRAPH-#4AAF, IRGKangXi=1397.280, Def{sound, whisper, to groan; to moan}
4AB0 CJK UNIFIED IDEOGRAPH-#4AB0, IRGKangXi=1398.010, Def{(same as 噫) (in grammar) interjection, to exclaim}
4AB1 CJK UNIFIED IDEOGRAPH-#4AB1, IRGKangXi=1399.100, Def{(same as 胲) cheek; face, ugly (same as 孩) a child}
4AB2 CJK UNIFIED IDEOGRAPH-#4AB2, IRGKangXi=1399.130, Def{(interchangeable 頑 髡) ancient punishment of shaving the head}
4AB3 CJK UNIFIED IDEOGRAPH-#4AB3, IRGKangXi=1401.020, Def{slanted face causing by the paralyzed of the facial nerve}
4AB4 CJK UNIFIED IDEOGRAPH-#4AB4, IRGKangXi=1401.060, Def{the occiput, or occipital bone, to hang down one's head, ugly, silly; foolish; stupid; idiotic; crazy; insane}
4AB5 CJK UNIFIED IDEOGRAPH-#4AB5, IRGKangXi=1401.151
4AB6 CJK UNIFIED IDEOGRAPH-#4AB6, IRGKangXi=1401.170, Def{the chin; the jaws}
4AB7 CJK UNIFIED IDEOGRAPH-#4AB7, IRGKangXi=1401.200, Def{to toil or labor sedulously}
4AB8 CJK UNIFIED IDEOGRAPH-#4AB8, IRGKangXi=1401.210, Def{strong; powerful; vigorous, (same as 頢) a short face, a small head}
4AB9 CJK UNIFIED IDEOGRAPH-#4AB9, IRGKangXi=1401.220, Def{a large face}
4ABA CJK UNIFIED IDEOGRAPH-#4ABA, IRGKangXi=1402.110, Def{(non-classical form) teethridge; gum; the jaw bone, the skull, the top of the skull}
4ABB CJK UNIFIED IDEOGRAPH-#4ABB, IRGKangXi=1402.170, Def{a cap, a slanting cap, face, bald head}
4ABC CJK UNIFIED IDEOGRAPH-#4ABC, IRGKangXi=1402.190, Def{the cheek-bone; the malar bone; the malar}
4ABD CJK UNIFIED IDEOGRAPH-#4ABD, IRGKangXi=1402.210, Def{hoary-haired person}
4ABE CJK UNIFIED IDEOGRAPH-#4ABE, IRGKangXi=1402.220, Def{to deal with affairs cautiously, head with less hair, ashamed; humiliated}
4ABF CJK UNIFIED IDEOGRAPH-#4ABF, IRGKangXi=1402.330, Def{(same as 囟) the top of the head, the skull}
4AC0 CJK UNIFIED IDEOGRAPH-#4AC0, IRGKangXi=1402.350, Def{the lower end of the jaws, high cheek-bone, to bend (or lower) one's head}
4AC1 CJK UNIFIED IDEOGRAPH-#4AC1, IRGKangXi=1403.030, Def{the first son; a dog's first pup}
4AC2 CJK UNIFIED IDEOGRAPH-#4AC2, IRGKangXi=1403.040, Def{ugly}
4AC3 CJK UNIFIED IDEOGRAPH-#4AC3, IRGKangXi=1404.080, Def{(ancient form of 脣 唇) the lips, to move one's head}
4AC4 CJK UNIFIED IDEOGRAPH-#4AC4, IRGKangXi=1404.100, Def{better than, small head, short face}
4AC5 CJK UNIFIED IDEOGRAPH-#4AC5, IRGKangXi=1404.140, Def{to shake one's head}
4AC6 CJK UNIFIED IDEOGRAPH-#4AC6, IRGKangXi=1404.190, Def{the front and back of the neck}
4AC7 CJK UNIFIED IDEOGRAPH-#4AC7, IRGKangXi=1404.290, Def{(same as 髯) the whiskers; the beard}
4AC8 CJK UNIFIED IDEOGRAPH-#4AC8, IRGKangXi=1404.310, Def{ugly, to bend (or lower) of one's head}
4AC9 CJK UNIFIED IDEOGRAPH-#4AC9, IRGKangXi=1405.150, Def{(ancient form of U+7683 貌) facial appearance, manner; bearing}
4ACA CJK UNIFIED IDEOGRAPH-#4ACA, IRGKangXi=1405.200, Def{(same as U+4AB9 䪹) chin; the jaws; the cheeks}
4ACB CJK UNIFIED IDEOGRAPH-#4ACB, IRGKangXi=1405.290, Def{female attendants or servants, (same as 隤) to fall in ruins; to collapse}
4ACC CJK UNIFIED IDEOGRAPH-#4ACC, IRGKangXi=1405.300, Def{bowed one's head}
4ACD CJK UNIFIED IDEOGRAPH-#4ACD, IRGKangXi=1405.310, Def{(corrupted form of 頫) (interchangeable 俯) to bow one's head; chin down, to wash oneself, to view; to watch}
4ACE CJK UNIFIED IDEOGRAPH-#4ACE, IRGKangXi=1405.370, Def{short}
4ACF CJK UNIFIED IDEOGRAPH-#4ACF, IRGKangXi=1405.390, Def{(same as 魌) ugly, physical or moral deformity, the mask worn by one who is driving away spirits}
4AD0 CJK UNIFIED IDEOGRAPH-#4AD0, IRGKangXi=1406.040, Def{to bend (or lower) one's head; to bow (usually refer to submission or admission of a wrong doing)}
4AD1 CJK UNIFIED IDEOGRAPH-#4AD1, IRGKangXi=1406.090, Def{good; nice; fine; (same as U+4ACF 䫏; standard form of U+9B4C 魌) ugly, physical or moral deformity, the mask wearing by one who is driven away spirits}
4AD2 CJK UNIFIED IDEOGRAPH-#4AD2, IRGKangXi=1406.180, Def{disease, in a coma; apoplexy; unconscious; stupor}
4AD3 CJK UNIFIED IDEOGRAPH-#4AD3, IRGKangXi=1406.240, Def{(corrupted form) large head}
4AD4 CJK UNIFIED IDEOGRAPH-#4AD4, IRGKangXi=1406.290, Def{a servant, to fear, short; a short person, angry, small headed}
4AD5 CJK UNIFIED IDEOGRAPH-#4AD5, IRGKangXi=1406.330, Def{small headed}
4AD6 CJK UNIFIED IDEOGRAPH-#4AD6, IRGKangXi=1406.340, Def{timid; weak and dulll}
4AD7 CJK UNIFIED IDEOGRAPH-#4AD7, IRGKangXi=1406.350, Def{reckless; unrestrained; without limit (said of speech; words, etc.), hard to tell}
4AD8 CJK UNIFIED IDEOGRAPH-#4AD8, IRGKangXi=1406.360, Def{healthy; strong, hair-less}
4AD9 CJK UNIFIED IDEOGRAPH-#4AD9, IRGKangXi=1406.410, Def{(non-classical of 顙) the forehead}
4ADA CJK UNIFIED IDEOGRAPH-#4ADA, IRGKangXi=1407.020, Def{short headed}
4ADB CJK UNIFIED IDEOGRAPH-#4ADB, IRGKangXi=1407.090, Def{reckless; unrestrained; without limit (said of speech; words, etc.)}
4ADC CJK UNIFIED IDEOGRAPH-#4ADC, IRGKangXi=1407.110, Def{sunken eyes, a hollow}
4ADD CJK UNIFIED IDEOGRAPH-#4ADD, IRGKangXi=1407.170, Def{(same as 馥) fragrance; aroma}
4ADE CJK UNIFIED IDEOGRAPH-#4ADE, IRGKangXi=1407.200, Def{large head, a wide forehead, numerous; crowd, (interchangeable 頒) a fish with a large head}
4ADF CJK UNIFIED IDEOGRAPH-#4ADF, IRGKangXi=1407.210, Def{facial complexion (yellowish because of worrying), a round skull and face}
4AE0 CJK UNIFIED IDEOGRAPH-#4AE0, IRGKangXi=1407.230, Def{short hair and beard}
4AE1 CJK UNIFIED IDEOGRAPH-#4AE1, IRGKangXi=1407.260, Def{a long shape of head and face, the cheeks; the jaw, ugly, a long face}
4AE2 CJK UNIFIED IDEOGRAPH-#4AE2, IRGKangXi=1407.270, Def{good; fine; excellent, pleasing, a wry neck}
4AE3 CJK UNIFIED IDEOGRAPH-#4AE3, IRGKangXi=1408.020, Def{a wry neck}
4AE4 CJK UNIFIED IDEOGRAPH-#4AE4, IRGKangXi=1408.040, Def{between the eyebrows and eyes; general facial appearance}
4AE5 CJK UNIFIED IDEOGRAPH-#4AE5, IRGKangXi=1408.080, Def{a wry neck, a large head}
4AE6 CJK UNIFIED IDEOGRAPH-#4AE6, IRGKangXi=1408.110, Def{the lower jawbone, the cranium}
4AE7 CJK UNIFIED IDEOGRAPH-#4AE7, IRGKangXi=1408.211
4AE8 CJK UNIFIED IDEOGRAPH-#4AE8, IRGKangXi=1408.230, Def{tall and big; colossal}
4AE9 CJK UNIFIED IDEOGRAPH-#4AE9, IRGKangXi=1409.020, Def{to shake one's head}
4AEA CJK UNIFIED IDEOGRAPH-#4AEA, IRGKangXi=1409.060, Def{ugly; repulsive}
4AEB CJK UNIFIED IDEOGRAPH-#4AEB, IRGKangXi=1409.120, Def{(same as 髏) human skeleton, (interchangeable 鏤) to engrave; to carve}
4AEC CJK UNIFIED IDEOGRAPH-#4AEC, IRGKangXi=1409.260, Def{to bow; to lower the head in shame, long and sharp of the head, weak and dull}
4AED CJK UNIFIED IDEOGRAPH-#4AED, IRGKangXi=1409.270, Def{bald-headed}
4AEE CJK UNIFIED IDEOGRAPH-#4AEE, IRGKangXi=1409.280, Def{to bend or lower of one's head; to bow (usually refer to submission or admission of a wrong doing), to take, to choose, to dwell, to stop}
4AEF CJK UNIFIED IDEOGRAPH-#4AEF, IRGKangXi=1409.410, Def{(abbreviated form) to take a casual look at, to look sideways, female beauty; handsome}
4AF0 CJK UNIFIED IDEOGRAPH-#4AF0, IRGKangXi=1409.421, Def{sparse hair}
4AF1 CJK UNIFIED IDEOGRAPH-#4AF1, IRGKangXi=1409.421, Def{(same as 顬) a part of the skull}
4AF2 CJK UNIFIED IDEOGRAPH-#4AF2, IRGKangXi=1409.450, Def{thin and sickly in appearance; emaciated look, to move one's head}
4AF3 CJK UNIFIED IDEOGRAPH-#4AF3, IRGKangXi=1410.020, Def{(same as 髑) human skull}
4AF4 CJK UNIFIED IDEOGRAPH-#4AF4, IRGKangXi=1410.030, Def{weak and dull, to gnash the teeth (in anger or hatred)}
4AF5 CJK UNIFIED IDEOGRAPH-#4AF5, IRGKangXi=1410.311, Def{twins}
4AF6 CJK UNIFIED IDEOGRAPH-#4AF6, IRGKangXi=1410.280, Def{ugly}
4AF7 CJK UNIFIED IDEOGRAPH-#4AF7, IRGKangXi=1410.320, Def{(same as 顎) the jowl; the cheek bones, high cheek-boned}
4AF8 CJK UNIFIED IDEOGRAPH-#4AF8, IRGKangXi=1411.080, Def{to blow, hot wind; wind of heat}
4AF9 CJK UNIFIED IDEOGRAPH-#4AF9, IRGKangXi=1411.120, Def{(non-classical form) the sound of the wind, a typhoon; great gale of wind}
4AFA CJK UNIFIED IDEOGRAPH-#4AFA, IRGKangXi=1411.150, Def{a typhoon; great gale of wind}
4AFB CJK UNIFIED IDEOGRAPH-#4AFB, IRGKangXi=1411.170, Def{a typhoon; great gale of wind}
4AFC CJK UNIFIED IDEOGRAPH-#4AFC, IRGKangXi=1411.220, Def{breeze; light wind, sound of the wind}
4AFD CJK UNIFIED IDEOGRAPH-#4AFD, IRGKangXi=1411.250, Def{breeze; light wind}
4AFE CJK UNIFIED IDEOGRAPH-#4AFE, IRGKangXi=1412.020, Def{breeze; light wind, cold or flu}
4AFF CJK UNIFIED IDEOGRAPH-#4AFF, IRGKangXi=1412.050, Def{a cool breeze; cold wind from the north; cold wind from the south-west}
4B00 CJK UNIFIED IDEOGRAPH-#4B00, IRGKangXi=1412.070, Def{sound of the wind}
4B01 CJK UNIFIED IDEOGRAPH-#4B01, IRGKangXi=1412.090, Def{a light cyclone; a whirlwind}
4B02 CJK UNIFIED IDEOGRAPH-#4B02, IRGKangXi=1412.120, Def{breeze; light wind}
4B03 CJK UNIFIED IDEOGRAPH-#4B03, IRGKangXi=1412.210, Def{(same as 颯) the sound of wind, a gust; suddenly}
4B04 CJK UNIFIED IDEOGRAPH-#4B04, IRGKangXi=1412.270, Def{breeze; light wind}
4B05 CJK UNIFIED IDEOGRAPH-#4B05, IRGKangXi=1412.350, Def{a gale; a gust of swift wind, timely wind}
4B06 CJK UNIFIED IDEOGRAPH-#4B06, IRGKangXi=1412.370, Def{a blustering gale; violent storm}
4B07 CJK UNIFIED IDEOGRAPH-#4B07, IRGKangXi=1412.390, Def{breeze; light wind}
4B08 CJK UNIFIED IDEOGRAPH-#4B08, IRGKangXi=1412.400, Def{breeze; light wind}
4B09 CJK UNIFIED IDEOGRAPH-#4B09, IRGKangXi=1412.420, Def{hot wind; wind of heat}
4B0A CJK UNIFIED IDEOGRAPH-#4B0A, IRGKangXi=1412.430, Def{a gale; a gust of swift wind}
4B0B CJK UNIFIED IDEOGRAPH-#4B0B, IRGKangXi=1412.550, Def{violent wind; strong wind}
4B0C CJK UNIFIED IDEOGRAPH-#4B0C, IRGKangXi=1413.010, Def{the wind blows, blown by the wind}
4B0D CJK UNIFIED IDEOGRAPH-#4B0D, IRGKangXi=1413.040, Def{the sound of wind, a gale; a typhoon}
4B0E CJK UNIFIED IDEOGRAPH-#4B0E, IRGKangXi=1413.100, Def{hot air; hot vapor, wind of the heat}
4B0F CJK UNIFIED IDEOGRAPH-#4B0F, IRGKangXi=1413.210, Def{wind; light breezes}
4B10 CJK UNIFIED IDEOGRAPH-#4B10, IRGKangXi=1413.220, Def{breeze}
4B11 CJK UNIFIED IDEOGRAPH-#4B11, IRGKangXi=1413.370, Def{a gale; a typhoon, the sound of wind}
4B12 CJK UNIFIED IDEOGRAPH-#4B12, IRGKangXi=1413.410, Def{to blow chilly; (same as U+98BC 颼) a whizzing sound, a cool breeze; the south-west wind}
4B13 CJK UNIFIED IDEOGRAPH-#4B13, IRGKangXi=1413.420, Def{hurricane; gale; cyclone}
4B14 CJK UNIFIED IDEOGRAPH-#4B14, IRGKangXi=1413.430, Def{hurricane; gale; cyclone}
4B15 CJK UNIFIED IDEOGRAPH-#4B15, IRGKangXi=1413.450, Def{sound of the wind, degenerate social customs and practices}
4B16 CJK UNIFIED IDEOGRAPH-#4B16, IRGKangXi=1413.470, Def{(same as U+4B1D 䬝) a storm; a tempest}
4B17 CJK UNIFIED IDEOGRAPH-#4B17, IRGKangXi=1413.491, Def{(non-classical form of 颺) blown or tossed about by the wind, to fly or blow away, to scatter; to spread}
4B18 CJK UNIFIED IDEOGRAPH-#4B18, IRGKangXi=1414.070, Def{the wind blows, blown by the wind}
4B19 CJK UNIFIED IDEOGRAPH-#4B19, IRGKangXi=1414.111, Def{(same as 颻) to dance and toss about in the wind; waving and drifting with the wind, unsteady}
4B1A CJK UNIFIED IDEOGRAPH-#4B1A, IRGKangXi=1414.111, Def{(same as 颿) to move fast; to hasten, a swift horse, (same as 帆) a sail (of a boat)}
4B1B CJK UNIFIED IDEOGRAPH-#4B1B, IRGKangXi=1414.150, Def{the roaring of the wind, cold wind}
4B1C CJK UNIFIED IDEOGRAPH-#4B1C, IRGKangXi=1414.190, Def{(same as standard form 魑) evil spirits; a mountain demon resembling a tiger; a mountain elf}
4B1D CJK UNIFIED IDEOGRAPH-#4B1D, IRGKangXi=1414.310, Def{(same as U+4B16 䬖) a storm; a tempest}
4B1E CJK UNIFIED IDEOGRAPH-#4B1E, IRGKangXi=1414.410, Def{wind; storm, sound of the wind}
4B1F CJK UNIFIED IDEOGRAPH-#4B1F, IRGKangXi=1415.010, Def{sound of wind}
4B20 CJK UNIFIED IDEOGRAPH-#4B20, IRGKangXi=1415.200, Def{(ancient form of 霏) the falling of snow and rain, driving sleet}
4B21 CJK UNIFIED IDEOGRAPH-#4B21, IRGKangXi=1415.210, Def{to soar; to take off}
4B22 CJK UNIFIED IDEOGRAPH-#4B22, IRGKangXi=1416.050, Def{(same as 饕) gluttonous; rapacious; covetous; greedy, name of a legendary ferocious animal, a fierce person; a greedy and gluttonous person}
4B23 CJK UNIFIED IDEOGRAPH-#4B23, IRGKangXi=1416.150, Def{(same as 餼) a sacrificial victim, explained as used of the living beast, to bite; to gnaw, to eat to the full; surfeited, a wart; a pimple; a pustule}
4B24 CJK UNIFIED IDEOGRAPH-#4B24, IRGKangXi=1416.160, Def{(ancient form of 饡) to put the thick soup or broth on top of the rice (same as 饘) thick congee or porridge}
4B25 CJK UNIFIED IDEOGRAPH-#4B25, IRGKangXi=1416.200, Def{(ancient form of 饐) cooked food which has become mouldy, sour}
4B26 CJK UNIFIED IDEOGRAPH-#4B26, IRGKangXi=1417.100, Def{food items merely arranged for display purpose only; not to ber eaten; to set out fruit, etc., in plates arranged only for show}
4B27 CJK UNIFIED IDEOGRAPH-#4B27, IRGKangXi=1417.110, Def{round shaped cakes}
4B28 CJK UNIFIED IDEOGRAPH-#4B28, IRGKangXi=1417.120, Def{to eat to the full; surfeited}
4B29 CJK UNIFIED IDEOGRAPH-#4B29, IRGKangXi=1417.330, Def{(same as 齋) to abstain from meat, wine, etc., to fast; penance}
4B2A CJK UNIFIED IDEOGRAPH-#4B2A, IRGKangXi=1417.331, Def{(same as 餺) a kind of cooked noodle}
4B2B CJK UNIFIED IDEOGRAPH-#4B2B, IRGKangXi=1417.340, Def{clarified butter (regarded as symbol of Buddhist wisdom or truth), cream cheese, to sponge on others; to board}
4B2C CJK UNIFIED IDEOGRAPH-#4B2C, IRGKangXi=1418.050, Def{to eat to the full; surfeited, well-stacked (figure, etc.); plump}
4B2D CJK UNIFIED IDEOGRAPH-#4B2D, IRGKangXi=1418.060, Def{(non-classical form of 饕) name of a legendary ferocious animal, a fierce person; a greedy and gluttonous person; wild; fierce; furious}
4B2E CJK UNIFIED IDEOGRAPH-#4B2E, IRGKangXi=1418.090, Def{(ancient form of 飴) syrup; jelly-like sugar made from grains}
4B2F CJK UNIFIED IDEOGRAPH-#4B2F, IRGKangXi=1418.140, Def{to have congee (wheat gruel) with friends in old times, (interchangeable 餂) to obtain by hook}
4B30 CJK UNIFIED IDEOGRAPH-#4B30, IRGKangXi=1418.150, Def{light refreshment, (dialect) animal feeds; fodder; forage made of wild vegetables, rice bran and water from washing rice}
4B31 CJK UNIFIED IDEOGRAPH-#4B31, IRGKangXi=1418.160, Def{coarse grains such as corn, millet, etc.; simple food}
4B32 CJK UNIFIED IDEOGRAPH-#4B32, IRGKangXi=1418.230, Def{to eat to the half full, (corrupted and abbreviated form of 饇) to eat to much; surfeited}
4B33 CJK UNIFIED IDEOGRAPH-#4B33, IRGKangXi=1418.310, Def{cakes made of rice flour}
4B34 CJK UNIFIED IDEOGRAPH-#4B34, IRGKangXi=1418.370, Def{(same as 秣) fodder for animals, to nourish; horse feed; horse grains; fodder, to feed a horse}
4B35 CJK UNIFIED IDEOGRAPH-#4B35, IRGKangXi=1419.080, Def{syrup; jelly-like sugar made from grains, to hiccough; to hiccup, (same as 餲) cooked food which has turned sour}
4B36 CJK UNIFIED IDEOGRAPH-#4B36, IRGKangXi=1419.170, Def{to starve; hungry, famished; feeble; decay or decomposition of fish}
4B37 CJK UNIFIED IDEOGRAPH-#4B37, IRGKangXi=1419.200, Def{well-feed., to glut; to eat to one's heart's content}
4B38 CJK UNIFIED IDEOGRAPH-#4B38, IRGKangXi=1419.110, Def{(corrupted form of 餐) a meal, to eat, food}
4B39 CJK UNIFIED IDEOGRAPH-#4B39, IRGKangXi=1419.230, Def{(same as 銍) a sickle}
4B3A CJK UNIFIED IDEOGRAPH-#4B3A, IRGKangXi=1419.250, Def{same as 䭐; cakes; pastry}
4B3B CJK UNIFIED IDEOGRAPH-#4B3B, IRGKangXi=1419.351, Def{(non-classical of 餞) to entertain a departing friend, a parting present of food or money}
4B3C CJK UNIFIED IDEOGRAPH-#4B3C, IRGKangXi=1419.360, Def{satiated; to dislike}
4B3D CJK UNIFIED IDEOGRAPH-#4B3D, IRGKangXi=1420.010, Def{wine poured in a libation, a little drink or a few drinks, cakes; pastry}
4B3E CJK UNIFIED IDEOGRAPH-#4B3E, IRGKangXi=1420.040, Def{cakes and biscuits}
4B3F CJK UNIFIED IDEOGRAPH-#4B3F, IRGKangXi=1420.060, Def{small; little, congee; rice gruel}
4B40 CJK UNIFIED IDEOGRAPH-#4B40, IRGKangXi=1420.090, Def{food (of the Taoist)}
4B41 CJK UNIFIED IDEOGRAPH-#4B41, IRGKangXi=1420.110, Def{stinking smell}
4B42 CJK UNIFIED IDEOGRAPH-#4B42, IRGKangXi=1420.170, Def{damp; humid, to eat to the full}
4B43 CJK UNIFIED IDEOGRAPH-#4B43, IRGKangXi=1421.150, Def{to eat to until full (飽); (same as 飪) to cook food thoroughly; cakes}
4B44 CJK UNIFIED IDEOGRAPH-#4B44, IRGKangXi=1421.170, Def{gluttonous; to eat piggishly}
4B45 CJK UNIFIED IDEOGRAPH-#4B45, IRGKangXi=1421.200, Def{cakes, (same as 餬) congee; porridge; gruel}
4B46 CJK UNIFIED IDEOGRAPH-#4B46, IRGKangXi=1421.320, Def{small children eat less, tired of eating, baked cakes}
4B47 CJK UNIFIED IDEOGRAPH-#4B47, IRGKangXi=1422.110, Def{(same as 噎) to choke on food, (ancient form of 饐) decayed; rotten and smelly}
4B48 CJK UNIFIED IDEOGRAPH-#4B48, IRGKangXi=1422.320, Def{(same as 餰) congee; rice gruel, (same as 饘) thick congee or porridge}
4B49 CJK UNIFIED IDEOGRAPH-#4B49, IRGKangXi=1422.340, Def{mashed beans, sugared cakes}
4B4A CJK UNIFIED IDEOGRAPH-#4B4A, IRGKangXi=1423.070, Def{(same as U+4B58 䭘) well-stacked (figure, etc.); full; plump, food, cakes}
4B4B CJK UNIFIED IDEOGRAPH-#4B4B, IRGKangXi=1423.140, Def{(same as 飽) to eat to the full; surfeited}
4B4C CJK UNIFIED IDEOGRAPH-#4B4C, IRGKangXi=1423.160, Def{(same as 餬 糊) congee; porridge; gruel, paste}
4B4D CJK UNIFIED IDEOGRAPH-#4B4D, IRGKangXi=1423.240, Def{(non-classical form of 餬) to live with another at his expense; to live by eating at another's table; to be parasite, congee; porridge; gruel, paste, to erase; to obliterate, to scribble, to use a fake in place of a genuine article; to deceive and swindle, to whitewash; to make up; to touch up}
4B4E CJK UNIFIED IDEOGRAPH-#4B4E, IRGKangXi=1423.241, Def{cakes}
4B4F CJK UNIFIED IDEOGRAPH-#4B4F, IRGKangXi=1423.241
4B50 CJK UNIFIED IDEOGRAPH-#4B50, IRGKangXi=1423.290, Def{cakes; pastry; biscuits, a bait; food}
4B51 CJK UNIFIED IDEOGRAPH-#4B51, IRGKangXi=1423.310, Def{incorruptable; honest; clean, (same as 歉) deficient, poor crop or harvest, to regret; sorry, (same as 餡) anything serving as stuffing for dumplings, etc.}
4B52 CJK UNIFIED IDEOGRAPH-#4B52, IRGKangXi=1423.380, Def{breath, to grow; to thrive, to eat, food}
4B53 CJK UNIFIED IDEOGRAPH-#4B53, IRGKangXi=1424.060, Def{food (wheat gruel, etc.) to welcome the guest in old times, to eat to the full; surfeited}
4B54 CJK UNIFIED IDEOGRAPH-#4B54, IRGKangXi=1424.080, Def{steamed dumplings; cakes}
4B55 CJK UNIFIED IDEOGRAPH-#4B55, IRGKangXi=1424.330, Def{tasteless; without enough salt; insipid; dull; not interesting, to taste food before royalty partook}
4B56 CJK UNIFIED IDEOGRAPH-#4B56, IRGKangXi=1424.350, Def{animal feeds; fodder; forage}
4B57 CJK UNIFIED IDEOGRAPH-#4B57, IRGKangXi=1425.050, Def{(same as 䭘) well-stacked (figure, etc.); full; plump, cakes}
4B58 CJK UNIFIED IDEOGRAPH-#4B58, IRGKangXi=1425.160, Def{well-stacked (figure, etc.); full; plump, food, cakes}
4B59 CJK UNIFIED IDEOGRAPH-#4B59, IRGKangXi=1425.220, Def{exquisite; fine, sweet; taste a little sweet, to taste, diseases (of the lips)}
4B5A CJK UNIFIED IDEOGRAPH-#4B5A, IRGKangXi=1425.310, Def{(same as standard form 噇) to eat, to eat heavily; to eat without limits}
4B5B CJK UNIFIED IDEOGRAPH-#4B5B, IRGKangXi=1425.431, Def{(same as 饏) tasteless; without enough salt; insipid; dull, (non-classical of standard form 澉) to wash}
4B5C CJK UNIFIED IDEOGRAPH-#4B5C, IRGKangXi=1425.431
4B5D CJK UNIFIED IDEOGRAPH-#4B5D, IRGKangXi=1425.440, Def{to eat, ((non-classical form of 膾) minced meat}
4B5E CJK UNIFIED IDEOGRAPH-#4B5E, IRGKangXi=1426.050, Def{(same as 繹) a kind of sacrifice offered to gods or the deceased; rotten food; food; cakes and biscuits}
4B5F CJK UNIFIED IDEOGRAPH-#4B5F, IRGKangXi=1426.110, Def{(same as 䭎) cakes}
4B60 CJK UNIFIED IDEOGRAPH-#4B60, IRGKangXi=1426.120, Def{a snack, supplementary dishes, (corrupted form of U+4B51 䭑) incorruptable; honest; clean, (same as U+6B49 歉) deficient, poor crop or harvest, to regret; sorry; (same as U+9921 餡) anything serving as stuffing for dumplings, etc.}
4B61 CJK UNIFIED IDEOGRAPH-#4B61, IRGKangXi=1426.220, Def{food (wheat gruel, etc.) to welcome the guest in old times, to eat to the full; surfeited}
4B62 CJK UNIFIED IDEOGRAPH-#4B62, IRGKangXi=1426.280, Def{rich; abundance, to eat, to eat without spontaneity; to eat reluctantly}
4B63 CJK UNIFIED IDEOGRAPH-#4B63, IRGKangXi=1426.290, Def{(same as 餈 粢 躄) rice cakes, rice to offered as sacrifice, the grains}
4B64 CJK UNIFIED IDEOGRAPH-#4B64, IRGKangXi=1426.310, Def{to chew; to eat, to roll round with the hand, cakes; biscuits}
4B65 CJK UNIFIED IDEOGRAPH-#4B65, IRGKangXi=1427.070, Def{(non-classical form) a bait, food, cakes and biscuits}
4B66 CJK UNIFIED IDEOGRAPH-#4B66, IRGKangXi=1427.190, Def{cakes; biscuits; pastry, (same as 餺) cooked food made of rice flour}
4B67 CJK UNIFIED IDEOGRAPH-#4B67, IRGKangXi=1427.210, Def{to feed a baby, (non-classical form of 糜) congee; porridge; rice gruel}
4B68 CJK UNIFIED IDEOGRAPH-#4B68, IRGKangXi=1427.240, Def{(same as 䬽) wine poured in a libation, to have a little drink or a few drinks}
4B69 CJK UNIFIED IDEOGRAPH-#4B69, IRGKangXi=1427.310, Def{to feed a baby, to eat, food}
4B6A CJK UNIFIED IDEOGRAPH-#4B6A, IRGKangXi=1427.311, Def{(simplified form) (same as 糧) grains; foodstuff; provisions; rations}
4B6B CJK UNIFIED IDEOGRAPH-#4B6B, IRGKangXi=1428.100, Def{(interchangeable 稽) to kowtow; to bow to the ground}
4B6C CJK UNIFIED IDEOGRAPH-#4B6C, IRGKangXi=1428.101, Def{(same as 䭫) (interchangeable 稽) to kowtow; to bow to the ground}
4B6D CJK UNIFIED IDEOGRAPH-#4B6D, IRGKangXi=1428.140, Def{the eldest son, to give birth to the first child}
4B6E CJK UNIFIED IDEOGRAPH-#4B6E, IRGKangXi=1428.170, Def{jewelry; ornaments; trinkets (for the forehead of a woman)}
4B6F CJK UNIFIED IDEOGRAPH-#4B6F, IRGKangXi=1429.070, Def{(same as 馞) strong sweet smell; strong fragrance}
4B70 CJK UNIFIED IDEOGRAPH-#4B70, IRGKangXi=1429.140, Def{strong sweet smell; strong fragrance; (Cant.) classifier for odors}
4B71 CJK UNIFIED IDEOGRAPH-#4B71, IRGKangXi=1429.150, Def{a little; slightly sweet-smelling}
4B72 CJK UNIFIED IDEOGRAPH-#4B72, IRGKangXi=1429.180, Def{sweet-smelling; fragrant, tasty; delicious}
4B73 CJK UNIFIED IDEOGRAPH-#4B73, IRGKangXi=1429.360, Def{a kind of herb; Asafoetida}
4B74 CJK UNIFIED IDEOGRAPH-#4B74, IRGKangXi=1433.090, Def{an one-year-old horse}
4B75 CJK UNIFIED IDEOGRAPH-#4B75, IRGKangXi=1434.080, Def{(same as standard form 颿) a swift horse}
4B76 CJK UNIFIED IDEOGRAPH-#4B76, IRGKangXi=1434.090, Def{(ancient form of 騏) dark-blue horse; a piebald horse; fine horse, dark blue, spotted}
4B77 CJK UNIFIED IDEOGRAPH-#4B77, IRGKangXi=1435.040, Def{horse with long mane}
4B78 CJK UNIFIED IDEOGRAPH-#4B78, IRGKangXi=1435.090, Def{a stallion; a male horse}
4B79 CJK UNIFIED IDEOGRAPH-#4B79, IRGKangXi=1435.130, Def{movement of a horse, a horse with enormous speed and staying power, a horse with white abdominal region}
4B7A CJK UNIFIED IDEOGRAPH-#4B7A, IRGKangXi=1435.150, Def{a horse to raise its head high, (same as 䭹) movement of a horse, an angry horse, a scared horse}
4B7B CJK UNIFIED IDEOGRAPH-#4B7B, IRGKangXi=1435.170, Def{a swift horse}
4B7C CJK UNIFIED IDEOGRAPH-#4B7C, IRGKangXi=1435.210, Def{(ancient form of 騏) dark-blue horse; a piebald horse; fine horse, dark blue, spotted}
4B7D CJK UNIFIED IDEOGRAPH-#4B7D, IRGKangXi=1435.211, Def{(same as U+7FA3 群) group; multitude; crowd; swarm; a flock}
4B7E CJK UNIFIED IDEOGRAPH-#4B7E, IRGKangXi=1435.211, Def{(same as U+99B1 馱) to carry (a load) on the back}
4B7F CJK UNIFIED IDEOGRAPH-#4B7F, IRGKangXi=1435.280, Def{a swift horse, to summon; to ask; to solicit; to request; to seek for}
4B80 CJK UNIFIED IDEOGRAPH-#4B80, IRGKangXi=1435.340, Def{a kind of animal; with a horse shape; the tail of an ox and with only one horn}
4B81 CJK UNIFIED IDEOGRAPH-#4B81, IRGKangXi=1435.400, Def{(same as 駢) a pair of horses, to stand, lie or go side by side}
4B82 CJK UNIFIED IDEOGRAPH-#4B82, IRGKangXi=1437.121, Def{horse with long hair}
4B83 CJK UNIFIED IDEOGRAPH-#4B83, IRGKangXi=1436.110, Def{(same as 驅) to go before others, to drive; to urge, to expel}
4B84 CJK UNIFIED IDEOGRAPH-#4B84, IRGKangXi=1436.120, Def{an one-year-old horse, a black horse}
4B85 CJK UNIFIED IDEOGRAPH-#4B85, IRGKangXi=1437.121
4B86 CJK UNIFIED IDEOGRAPH-#4B86, IRGKangXi=1437.320, Def{(same as 駓) a horse with mixed color of yellow and white}
4B87 CJK UNIFIED IDEOGRAPH-#4B87, IRGKangXi=1437.330, Def{(same as 驈) black horse with white thigh}
4B88 CJK UNIFIED IDEOGRAPH-#4B88, IRGKangXi=1438.010, Def{(same as 馳) to go swiftly; to fleet; to rush; to speed}
4B89 CJK UNIFIED IDEOGRAPH-#4B89, IRGKangXi=1438.110, Def{horses kept at a courier station in former times}
4B8A CJK UNIFIED IDEOGRAPH-#4B8A, IRGKangXi=1438.130, Def{name of a horse}
4B8B CJK UNIFIED IDEOGRAPH-#4B8B, IRGKangXi=1438.190, Def{name of a horse, horses in an ordered line; to travel quickly; to move fast; to hasten, tame, well-bred, to put under control}
4B8C CJK UNIFIED IDEOGRAPH-#4B8C, IRGKangXi=1438.261, Def{fine horse, swift horse, swift; speedy}
4B8D CJK UNIFIED IDEOGRAPH-#4B8D, IRGKangXi=1438.261, Def{(same as 褭 裊) curling up, as smoke; wavering gently, around; all around}
4B8E CJK UNIFIED IDEOGRAPH-#4B8E, IRGKangXi=1439.030, Def{a running horse}
4B8F CJK UNIFIED IDEOGRAPH-#4B8F, IRGKangXi=1439.070, Def{name of a horse}
4B90 CJK UNIFIED IDEOGRAPH-#4B90, IRGKangXi=1439.080, Def{(non-classical form of 駉) in good condition; as a horse}
4B91 CJK UNIFIED IDEOGRAPH-#4B91, IRGKangXi=1439.110, Def{a gray horse, a kind of grain}
4B92 CJK UNIFIED IDEOGRAPH-#4B92, IRGKangXi=1439.140, Def{name of a horse}
4B93 CJK UNIFIED IDEOGRAPH-#4B93, IRGKangXi=1440.100, Def{a walking horse, a horse not moving forward, a swift horse}
4B94 CJK UNIFIED IDEOGRAPH-#4B94, IRGKangXi=1440.230, Def{a young and fleet-footed horse; foal, a horse with a heavy load and hard to move forward}
4B95 CJK UNIFIED IDEOGRAPH-#4B95, IRGKangXi=1440.260, Def{horse with white forehead, (的盧)}
4B96 CJK UNIFIED IDEOGRAPH-#4B96, IRGKangXi=1440.310, Def{name of a horse}
4B97 CJK UNIFIED IDEOGRAPH-#4B97, IRGKangXi=1440.320, Def{white from forehead to lips of a horse, reddish (of a horse head), horse head}
4B98 CJK UNIFIED IDEOGRAPH-#4B98, IRGKangXi=1440.400, Def{young horse, stallion; male horse}
4B99 CJK UNIFIED IDEOGRAPH-#4B99, IRGKangXi=1440.430, Def{name of a horse, a traveling horse}
4B9A CJK UNIFIED IDEOGRAPH-#4B9A, IRGKangXi=1441.010, Def{diseases of horse, horse eat grains}
4B9B CJK UNIFIED IDEOGRAPH-#4B9B, IRGKangXi=1441.030, Def{(same as 駙) extra horse harnessed by the side of the team, swift}
4B9C CJK UNIFIED IDEOGRAPH-#4B9C, IRGKangXi=1441.120, Def{(same as 䮢) to gallop, swift, to walk lightly (said of a horse)}
4B9D CJK UNIFIED IDEOGRAPH-#4B9D, IRGKangXi=1441.160, Def{a legendary animal, a wild horse; mustang}
4B9E CJK UNIFIED IDEOGRAPH-#4B9E, IRGKangXi=1441.230, Def{a piebald horse, particoloured, miscellaneous, confused and disorderly, a stupid horse}
4B9F CJK UNIFIED IDEOGRAPH-#4B9F, IRGKangXi=1441.310, Def{big and tall (said of horse), (same as 搜) to search; to reconnoiter, (same as 駷) a walking horse, by a riding-whip to keep the horse walking fast}
4BA0 CJK UNIFIED IDEOGRAPH-#4BA0, IRGKangXi=1441.330, Def{a kind of animal}
4BA1 CJK UNIFIED IDEOGRAPH-#4BA1, IRGKangXi=1441.410, Def{a supernatural horse, (same as 駜) a strong; husky horse, (same as 駁) color of a horse, variegated; parti-colored, mixed; impure}
4BA2 CJK UNIFIED IDEOGRAPH-#4BA2, IRGKangXi=1441.430, Def{a walking horse, to gallop, swift}
4BA3 CJK UNIFIED IDEOGRAPH-#4BA3, IRGKangXi=1442.180, Def{a yellow with a white tail}
4BA4 CJK UNIFIED IDEOGRAPH-#4BA4, IRGKangXi=1442.240, Def{one of the 36 gardens in Han Dynasty, (same as 馰) horse with white forehead; fine horse}
4BA5 CJK UNIFIED IDEOGRAPH-#4BA5, IRGKangXi=1442.270, Def{color of the horse}
4BA6 CJK UNIFIED IDEOGRAPH-#4BA6, IRGKangXi=1443.030, Def{(non-classical form of 驕) untamed; intractable; disobedient, proud; haughty; arrogant}
4BA7 CJK UNIFIED IDEOGRAPH-#4BA7, IRGKangXi=1443.110, Def{long-hair horse}
4BA8 CJK UNIFIED IDEOGRAPH-#4BA8, IRGKangXi=1443.130, Def{a piebald horse, particoloured}
4BA9 CJK UNIFIED IDEOGRAPH-#4BA9, IRGKangXi=1443.160, Def{a kind of animal (from Beihai)}
4BAA CJK UNIFIED IDEOGRAPH-#4BAA, IRGKangXi=1443.280, Def{(corrupted form) (same as 騬) to geld a horse or ass, etc.}
4BAB CJK UNIFIED IDEOGRAPH-#4BAB, IRGKangXi=1443.290, Def{a big mule (same as 驢) an ass; a donkey}
4BAC CJK UNIFIED IDEOGRAPH-#4BAC, IRGKangXi=1444.030, Def{name of a horse, (same as 驀) sudden; abrupt, to mount the horse}
4BAD CJK UNIFIED IDEOGRAPH-#4BAD, IRGKangXi=1444.140, Def{to look at in surprise, to gnaw; to bite (said of a horse)}
4BAE CJK UNIFIED IDEOGRAPH-#4BAE, IRGKangXi=1444.160, Def{a kind of mule; a kind of beast}
4BAF CJK UNIFIED IDEOGRAPH-#4BAF, IRGKangXi=1444.190, Def{(same as 驁) fine horse, untamed horse, vicious horse}
4BB0 CJK UNIFIED IDEOGRAPH-#4BB0, IRGKangXi=1444.260, Def{a kind of beast, a kind of mule}
4BB1 CJK UNIFIED IDEOGRAPH-#4BB1, IRGKangXi=1444.270, Def{a kind of beast; to chase one another (of herding horses)}
4BB2 CJK UNIFIED IDEOGRAPH-#4BB2, IRGKangXi=1445.020, Def{(same as 騜) horse with mixed colors of yellow and white, chestnut color mixed with white}
4BB3 CJK UNIFIED IDEOGRAPH-#4BB3, IRGKangXi=1445.110, Def{to give birth to, to bring and to rear (interchangeable 蕃) to increase; to multiply; to propagate}
4BB4 CJK UNIFIED IDEOGRAPH-#4BB4, IRGKangXi=1445.130, Def{unstable walking, fall, disease of the horse}
4BB5 CJK UNIFIED IDEOGRAPH-#4BB5, IRGKangXi=1445.180, Def{name of a horse, a young horse}
4BB6 CJK UNIFIED IDEOGRAPH-#4BB6, IRGKangXi=1445.240, Def{(same as 驫) herd of horses stampeding}
4BB7 CJK UNIFIED IDEOGRAPH-#4BB7, IRGKangXi=1445.350, Def{movement of a horse, a traveling horse}
4BB8 CJK UNIFIED IDEOGRAPH-#4BB8, IRGKangXi=1445.360, Def{to move slowly and then swiftly (said of a horse), a swift horse, to neigh}
4BB9 CJK UNIFIED IDEOGRAPH-#4BB9, IRGKangXi=1446.020, Def{an angry horse, a hot-tempered; an evil horse}
4BBA CJK UNIFIED IDEOGRAPH-#4BBA, IRGKangXi=1446.110, Def{luxuriant of the grass; the grass growing densely, horses traveling in line order and swiftly}
4BBB CJK UNIFIED IDEOGRAPH-#4BBB, IRGKangXi=1446.130, Def{(same as 禂) to pray, to offer livestock for sacrifice}
4BBC CJK UNIFIED IDEOGRAPH-#4BBC, IRGKangXi=1446.200, Def{(standard form of 驎) (of horse) piebald; fine horse; white horse with black back, name of a fabulous, auspicious animal, horse with black lips, horse with pattern of scales}
4BBD CJK UNIFIED IDEOGRAPH-#4BBD, IRGKangXi=1446.350, Def{(same as 鑣) bit for a horse, to ride on a horse}
4BBE CJK UNIFIED IDEOGRAPH-#4BBE, IRGKangXi=1446.380, Def{(same as 龐) huge, rich; abundance, to fill up; full of (same as 龍) a legendary; miraculous; marvelous animal; the dragon, associated with rain, floods, and geomancy, an emblem of imperialism}
4BBF CJK UNIFIED IDEOGRAPH-#4BBF, IRGKangXi=1447.080, Def{(same as 蹇) lame; crippled, slow, weak; feeble; a vicious horse; a feeble donkey}
4BC0 CJK UNIFIED IDEOGRAPH-#4BC0, IRGKangXi=1447.130, Def{a swift horse}
4BC1 CJK UNIFIED IDEOGRAPH-#4BC1, IRGKangXi=1447.191, Def{(same as abbreviated form U+9A58 騾) a mule; the offspring of an ass and a mare}
4BC2 CJK UNIFIED IDEOGRAPH-#4BC2, IRGKangXi=1447.240, Def{numerous; very many, large group of horses traveling in a line}
4BC3 CJK UNIFIED IDEOGRAPH-#4BC3, IRGKangXi=1447.241, Def{(same as U+978D 鞍) saddle; a saddle-like terrain or thing}
4BC4 CJK UNIFIED IDEOGRAPH-#4BC4, IRGKangXi=1447.241, Def{a piebald horse; a yellow horse with black mouth}
4BC5 CJK UNIFIED IDEOGRAPH-#4BC5, IRGKangXi=1447.241, Def{a swift horse}
4BC6 CJK UNIFIED IDEOGRAPH-#4BC6, IRGKangXi=1447.260, Def{(same as 骮) small and thin piece of bones}
4BC7 CJK UNIFIED IDEOGRAPH-#4BC7, IRGKangXi=1447.290, Def{to exert oneself; to make an effort; diligent; sedulous}
4BC8 CJK UNIFIED IDEOGRAPH-#4BC8, IRGKangXi=1448.160, Def{the pelvis (髂=䯊)}
4BC9 CJK UNIFIED IDEOGRAPH-#4BC9, IRGKangXi=1448.180, Def{to choke; the throat chocked and unable to breath smoothly}
4BCA CJK UNIFIED IDEOGRAPH-#4BCA, IRGKangXi=1448.310, Def{the pelvis, bone stuck in the throat, the kneecap; patella; the five lowest pieces of bone of the spinal column}
4BCB CJK UNIFIED IDEOGRAPH-#4BCB, IRGKangXi=1448.320, Def{the shoulder blade; scapula}
4BCC CJK UNIFIED IDEOGRAPH-#4BCC, IRGKangXi=1448.330, Def{the sacrum; the coccyx; the end of the spine; the rump; the buttocks}
4BCD CJK UNIFIED IDEOGRAPH-#4BCD, IRGKangXi=1448.380, Def{bones, the pelvis; the five lowest pieces of bone of the spinal column}
4BCE CJK UNIFIED IDEOGRAPH-#4BCE, IRGKangXi=1448.440, Def{(same as 骭) shinbone; tibia, the ribs, calf bone (the part of leg between the knee and ankle)}
4BCF CJK UNIFIED IDEOGRAPH-#4BCF, IRGKangXi=1448.490, Def{the shoulder blade; scapula}
4BD0 CJK UNIFIED IDEOGRAPH-#4BD0, IRGKangXi=1449.010, Def{(non-classical form of 骸) shinbone; skeleton}
4BD1 CJK UNIFIED IDEOGRAPH-#4BD1, IRGKangXi=1449.020, Def{the pelvis, bone stuck in the throat, the kneecap; patella; the five lowest pieces of bone of the spinal column}
4BD2 CJK UNIFIED IDEOGRAPH-#4BD2, IRGKangXi=1449.030, Def{(same as 胻) the upper part of the shinbone, or tibia}
4BD3 CJK UNIFIED IDEOGRAPH-#4BD3, IRGKangXi=1449.070, Def{the head bone of livestock, the shoulder blade; scapula}
4BD4 CJK UNIFIED IDEOGRAPH-#4BD4, IRGKangXi=1449.130, Def{to incline; to turn on one side}
4BD5 CJK UNIFIED IDEOGRAPH-#4BD5, IRGKangXi=1449.170, Def{bony; skinny}
4BD6 CJK UNIFIED IDEOGRAPH-#4BD6, IRGKangXi=1449.190, Def{the muscles of the thigh, the hips, the haunches}
4BD7 CJK UNIFIED IDEOGRAPH-#4BD7, IRGKangXi=1449.200, Def{(same as 髀) buttocks, hipbone; innominate bone}
4BD8 CJK UNIFIED IDEOGRAPH-#4BD8, IRGKangXi=1449.240, Def{the kneecap; patella, (same as 垸) to smear with varnishes and ashes}
4BD9 CJK UNIFIED IDEOGRAPH-#4BD9, IRGKangXi=1449.270, Def{(same as 髆) the five lowest pieces of bone of the spinal column}
4BDA CJK UNIFIED IDEOGRAPH-#4BDA, IRGKangXi=1449.280, Def{the ribs}
4BDB CJK UNIFIED IDEOGRAPH-#4BDB, IRGKangXi=1449.390, Def{the knee bones; the carpus of the knee, (same as 腕) the wrist}
4BDC CJK UNIFIED IDEOGRAPH-#4BDC, IRGKangXi=1449.420, Def{marrow; fluid of yellow color, between the waist bones}
4BDD CJK UNIFIED IDEOGRAPH-#4BDD, IRGKangXi=1450.040, Def{(same as 髓) marrow; pith; essence}
4BDE CJK UNIFIED IDEOGRAPH-#4BDE, IRGKangXi=1450.110, Def{bone (the lowest pieces of bone of the spinal column and sides of the abdominal region)}
4BDF CJK UNIFIED IDEOGRAPH-#4BDF, IRGKangXi=1450.120, Def{bone, stupid; dull}
4BE0 CJK UNIFIED IDEOGRAPH-#4BE0, IRGKangXi=1450.250, Def{the five lowest pieces of bone of the spinal column}
4BE1 CJK UNIFIED IDEOGRAPH-#4BE1, IRGKangXi=1450.290
4BE2 CJK UNIFIED IDEOGRAPH-#4BE2, IRGKangXi=1450.340, Def{partial paralysis; hemiplegia -- paralysis of half of one's body, very small; diminutive; minute}
4BE3 CJK UNIFIED IDEOGRAPH-#4BE3, IRGKangXi=1450.480, Def{the kneecap; patella, the cranium}
4BE4 CJK UNIFIED IDEOGRAPH-#4BE4, IRGKangXi=1450.610, Def{boneware used to comb the hair, to bind the hair, (same as 鬠) hair tied in a knot for the mourning rites}
4BE5 CJK UNIFIED IDEOGRAPH-#4BE5, IRGKangXi=1451.110, Def{with a high skull, dried meat strips}
4BE6 CJK UNIFIED IDEOGRAPH-#4BE6, IRGKangXi=1451.170, Def{tiny bone}
4BE7 CJK UNIFIED IDEOGRAPH-#4BE7, IRGKangXi=1451.270, Def{(same as 廎) a small hall, store-room for melon}
4BE8 CJK UNIFIED IDEOGRAPH-#4BE8, IRGKangXi=1451.290, Def{(ancient form of 敲) to rap; to tap; to beat, big; great; large; tall; high}
4BE9 CJK UNIFIED IDEOGRAPH-#4BE9, IRGKangXi=1451.341
4BEA CJK UNIFIED IDEOGRAPH-#4BEA, IRGKangXi=1452.080, Def{big head}
4BEB CJK UNIFIED IDEOGRAPH-#4BEB, IRGKangXi=1452.150, Def{(same as 顥) bright; luminous; hoary; white}
4BEC CJK UNIFIED IDEOGRAPH-#4BEC, IRGKangXi=1452.240, Def{(same as 嚲) to hang down; to let fall}
4BED CJK UNIFIED IDEOGRAPH-#4BED, IRGKangXi=1452.270, Def{of nice and good hair}
4BEE CJK UNIFIED IDEOGRAPH-#4BEE, IRGKangXi=1452.280, Def{dishevelled hair}
4BEF CJK UNIFIED IDEOGRAPH-#4BEF, IRGKangXi=1452.350, Def{(same as 髿) hang down of the hair; dishevelled hair}
4BF0 CJK UNIFIED IDEOGRAPH-#4BF0, IRGKangXi=1452.360, Def{use a hair-pin to set and dress the hair}
4BF1 CJK UNIFIED IDEOGRAPH-#4BF1, IRGKangXi=1452.410, Def{(said of wild beasts) the hair stands up, walk with one's hair hang down, hairy, hair}
4BF2 CJK UNIFIED IDEOGRAPH-#4BF2, IRGKangXi=1453.040, Def{a coiffure with a topknot, dishevelled hair}
4BF3 CJK UNIFIED IDEOGRAPH-#4BF3, IRGKangXi=1453.050, Def{(same as 鬆) (said of hair) loosely arranged, dishevelled hair}
4BF4 CJK UNIFIED IDEOGRAPH-#4BF4, IRGKangXi=1453.080, Def{a coiffure with a topknot}
4BF5 CJK UNIFIED IDEOGRAPH-#4BF5, IRGKangXi=1453.190, Def{hair style for little children}
4BF6 CJK UNIFIED IDEOGRAPH-#4BF6, IRGKangXi=1453.411, Def{(non-classical form of 鬘) fair of hair, to blacken eyebrows}
4BF7 CJK UNIFIED IDEOGRAPH-#4BF7, IRGKangXi=1453.450, Def{fine hair}
4BF8 CJK UNIFIED IDEOGRAPH-#4BF8, IRGKangXi=1454.100, Def{a wig}
4BF9 CJK UNIFIED IDEOGRAPH-#4BF9, IRGKangXi=1454.290, Def{hair}
4BFA CJK UNIFIED IDEOGRAPH-#4BFA, IRGKangXi=1454.390, Def{(standard form of 髺) the hair dishevelled, as in mourning}
4BFB CJK UNIFIED IDEOGRAPH-#4BFB, IRGKangXi=1454.391, Def{dressesd hair}
4BFC CJK UNIFIED IDEOGRAPH-#4BFC, IRGKangXi=1454.391, Def{a coiffure with a topknot; a wig}
4BFD CJK UNIFIED IDEOGRAPH-#4BFD, IRGKangXi=1454.430, Def{fine hair; beautiful hair, short hair, a coiffure with a topknot}
4BFE CJK UNIFIED IDEOGRAPH-#4BFE, IRGKangXi=1454.450, Def{hairy; with lots of hair, to let the hair grow, as children do}
4BFF CJK UNIFIED IDEOGRAPH-#4BFF, IRGKangXi=1454.460, Def{a coiffure with a topknot, hairy, dishevelled hair}
4C00 CJK UNIFIED IDEOGRAPH-#4C00, IRGKangXi=1454.470, Def{dressed hair of a Chinese woman}
4C01 CJK UNIFIED IDEOGRAPH-#4C01, IRGKangXi=1454.490, Def{to meet; to run into suddenly; unexpectedly}
4C02 CJK UNIFIED IDEOGRAPH-#4C02, IRGKangXi=1455.020, Def{a coiffure with a topknot, a turban; a kerchief}
4C03 CJK UNIFIED IDEOGRAPH-#4C03, IRGKangXi=1455.190, Def{dishevelled hair, (same as 碰) to meet unexpectedly, to collide; to hit; to touch}
4C04 CJK UNIFIED IDEOGRAPH-#4C04, IRGKangXi=1455.200, Def{short hair, bearded; with lots of beard, whiskers}
4C05 CJK UNIFIED IDEOGRAPH-#4C05, IRGKangXi=1455.300, Def{(same as 須 鬚) beard; whiskers}
4C06 CJK UNIFIED IDEOGRAPH-#4C06, IRGKangXi=1455.320, Def{beautiful and hairy mane, yellow hair; the hoary hair of the aged}
4C07 CJK UNIFIED IDEOGRAPH-#4C07, IRGKangXi=1455.420, Def{(same as 鬐) mane, fins}
4C08 CJK UNIFIED IDEOGRAPH-#4C08, IRGKangXi=1455.550, Def{fine hair, hairy}
4C09 CJK UNIFIED IDEOGRAPH-#4C09, IRGKangXi=1456.020, Def{dressed hair in a horizontal way, variegated; grey-of hair}
4C0A CJK UNIFIED IDEOGRAPH-#4C0A, IRGKangXi=1456.030, Def{hair, sparse hair}
4C0B CJK UNIFIED IDEOGRAPH-#4C0B, IRGKangXi=1456.090, Def{(same as 髮 鬘) hair, fair of hair}
4C0C CJK UNIFIED IDEOGRAPH-#4C0C, IRGKangXi=1456.120, Def{to bind the hair in a knot on the top of the head, mane, dishevelled hair}
4C0D CJK UNIFIED IDEOGRAPH-#4C0D, IRGKangXi=1456.140, Def{(same as U+9AE4 髹) a kind of dark-red paint, to paint or lacquer (articles)}
4C0E CJK UNIFIED IDEOGRAPH-#4C0E, IRGKangXi=1456.340, Def{to twist the hair in a knot on the top of the head}
4C0F CJK UNIFIED IDEOGRAPH-#4C0F, IRGKangXi=1457.030, Def{sparse hair on a knot on the top of the head, hair dressed without ornaments}
4C10 CJK UNIFIED IDEOGRAPH-#4C10, IRGKangXi=1457.050, Def{long hair, hairy, sparse hair}
4C11 CJK UNIFIED IDEOGRAPH-#4C11, IRGKangXi=1457.060, Def{(non-classical form of 䰅) (same as 須 鬚) beard; whiskers}
4C12 CJK UNIFIED IDEOGRAPH-#4C12, IRGKangXi=1457.070, Def{vague; ambiguous; dim; hazy, mane}
4C13 CJK UNIFIED IDEOGRAPH-#4C13, IRGKangXi=1457.140, Def{hair, (in old times) to burn a certain stick and then to blacken the eyebrows}
4C14 CJK UNIFIED IDEOGRAPH-#4C14, IRGKangXi=1457.160, Def{(non-classical of 䰉) dressed hair in a horizontal way, variegated; grey (of hair)}
4C15 CJK UNIFIED IDEOGRAPH-#4C15, IRGKangXi=1457.200, Def{mane}
4C16 CJK UNIFIED IDEOGRAPH-#4C16, IRGKangXi=1457.280, Def{fine hair; luster of hair; smooth and glossy of the hair, the woman's hair in a knot on the top of the head, hairy}
4C17 CJK UNIFIED IDEOGRAPH-#4C17, IRGKangXi=1457.400, Def{(non-classical) a lot; a ticket, to draw lots}
4C18 CJK UNIFIED IDEOGRAPH-#4C18, IRGKangXi=1457.430, Def{to kill by hanging or to strangulation, kill, to lower the grade of mourning garments, when wearing the sackcloth with the edges evenly bound}
4C19 CJK UNIFIED IDEOGRAPH-#4C19, IRGKangXi=1459.030, Def{an ancient unit of capacity with three feet and a big opening, a container used to wash rice}
4C1A CJK UNIFIED IDEOGRAPH-#4C1A, IRGKangXi=1459.040, Def{the top part of the rice gruel, to chafe; to scour; to rub; to wipe with hand}
4C1B CJK UNIFIED IDEOGRAPH-#4C1B, IRGKangXi=1459.070, Def{(same as 鬲) a large earthen pot, a large iron cauldron}
4C1C CJK UNIFIED IDEOGRAPH-#4C1C, IRGKangXi=1459.160, Def{(ancient form of 鬲) a large earthen pot, a large iron cauldron}
4C1D CJK UNIFIED IDEOGRAPH-#4C1D, IRGKangXi=1459.440, Def{a large earthen pot for cooking, a large iron cauldron used to cook in old times}
4C1E CJK UNIFIED IDEOGRAPH-#4C1E, IRGKangXi=1460.120, Def{(same as U+7151 煮) to cook; to boil; to stew}
4C1F CJK UNIFIED IDEOGRAPH-#4C1F, IRGKangXi=1461.130, Def{(same as 魂) the soul, the spiritual part of man that ascends to heaven, the wits; the spiritual faculties}
4C20 CJK UNIFIED IDEOGRAPH-#4C20, IRGKangXi=1461.180, Def{god; spirit; immortal, mountain deity}
4C21 CJK UNIFIED IDEOGRAPH-#4C21, IRGKangXi=1461.320, Def{a fierce ghost; a malicious spirit; evil spirits}
4C22 CJK UNIFIED IDEOGRAPH-#4C22, IRGKangXi=1462.050, Def{ghost; a star}
4C23 CJK UNIFIED IDEOGRAPH-#4C23, IRGKangXi=1462.121, Def{(same as 魍) an elf, a sprite, an animal which is said to eat the brains of the dead under ground; a monster}
4C24 CJK UNIFIED IDEOGRAPH-#4C24, IRGKangXi=1462.250, Def{ugly, monster; ghost}
4C25 CJK UNIFIED IDEOGRAPH-#4C25, IRGKangXi=1462.290, Def{(same as 魊) a cyclone; a whirlwind, a fabulous creature which supposedly hurts human beings by casting sand out of its mouth; ghost}
4C26 CJK UNIFIED IDEOGRAPH-#4C26, IRGKangXi=1462.340, Def{ugly, ghost; evil spirits; bogy; goblin; demons and monsters}
4C27 CJK UNIFIED IDEOGRAPH-#4C27, IRGKangXi=1462.350, Def{sinister, evil and shrewd}
4C28 CJK UNIFIED IDEOGRAPH-#4C28, IRGKangXi=1462.470, Def{(same as U+9B3D 魅) mischievous spirit; goblin; elf, a demon with a man's face and four legs, and exhalation of the mountains and forests, to charm; to mislead}
4C29 CJK UNIFIED IDEOGRAPH-#4C29, IRGKangXi=1462.480, Def{ugly; repulsive, mountain ghosts}
4C2A CJK UNIFIED IDEOGRAPH-#4C2A, IRGKangXi=1462.530, Def{(corrupted form of 魅) mischievous spirit; goblin; elf, a demon with a man's face and four legs, and exhalation of the mountains and forests, to charm; to mislead}
4C2B CJK UNIFIED IDEOGRAPH-#4C2B, IRGKangXi=1463.060, Def{nimble and active ghost, to move swiftly, strong, crafty; cunning; wily, smart; clever; shrewd}
4C2C CJK UNIFIED IDEOGRAPH-#4C2C, IRGKangXi=1463.090, Def{wild ghost; ghost without head; a demon}
4C2D CJK UNIFIED IDEOGRAPH-#4C2D, IRGKangXi=1463.150, Def{(same as 䰰) dreary cries of ghosts; sound of monsters}
4C2E CJK UNIFIED IDEOGRAPH-#4C2E, IRGKangXi=1463.161
4C2F CJK UNIFIED IDEOGRAPH-#4C2F, IRGKangXi=1463.190, Def{to fear; to dread; to be afraid of}
4C30 CJK UNIFIED IDEOGRAPH-#4C30, IRGKangXi=1463.210, Def{(same as 䰭) dreary cries of ghosts; sound of monsters}
4C31 CJK UNIFIED IDEOGRAPH-#4C31, IRGKangXi=1463.310, Def{name of a god; a legendary spirits having the face of a man and the body of a beast}
4C32 CJK UNIFIED IDEOGRAPH-#4C32, IRGKangXi=1465.030, Def{the sheat-fish}
4C33 CJK UNIFIED IDEOGRAPH-#4C33, IRGKangXi=1465.121
4C34 CJK UNIFIED IDEOGRAPH-#4C34, IRGKangXi=1465.190, Def{a wafting fish, a fish, to cut a fish}
4C35 CJK UNIFIED IDEOGRAPH-#4C35, IRGKangXi=1465.210, Def{blackfish or mullet; anchovy}
4C36 CJK UNIFIED IDEOGRAPH-#4C36, IRGKangXi=1465.211
4C37 CJK UNIFIED IDEOGRAPH-#4C37, IRGKangXi=1466.030, Def{a fish, (same as 蚌) oyster, a kind of clam, a pretty pearl}
4C38 CJK UNIFIED IDEOGRAPH-#4C38, IRGKangXi=1466.040, Def{(interchangeable 魟 same as 鰩) the nautilus; the ray, a fish; looks like crab or king crab}
4C39 CJK UNIFIED IDEOGRAPH-#4C39, IRGKangXi=1466.050, Def{(non-classical and abbreviated form of 鱡) (same as 鰂) the cuttlefish; the inkfish}
4C3A CJK UNIFIED IDEOGRAPH-#4C3A, IRGKangXi=1466.150, Def{(corrupted form of 魪) a flatfish; a sole}
4C3B CJK UNIFIED IDEOGRAPH-#4C3B, IRGKangXi=1466.160, Def{(same as 漁) to catch fish, to fish, to seize}
4C3C CJK UNIFIED IDEOGRAPH-#4C3C, IRGKangXi=1466.250, Def{a condiment made from minced fish salted, preserved fish; salted fish; fish cured in distiller's grains, a fish}
4C3D CJK UNIFIED IDEOGRAPH-#4C3D, IRGKangXi=1466.340, Def{the globefish, blowfish, puffer}
4C3E CJK UNIFIED IDEOGRAPH-#4C3E, IRGKangXi=1467.041, Def{a kind of fish; a bonito, (same as U+9B81 鮁) shark}
4C3F CJK UNIFIED IDEOGRAPH-#4C3F, IRGKangXi=1467.130, Def{(non-classical of 鮀) a kind of small fish grown in fresh water}
4C40 CJK UNIFIED IDEOGRAPH-#4C40, IRGKangXi=1467.140, Def{a kind of small fish}
4C41 CJK UNIFIED IDEOGRAPH-#4C41, IRGKangXi=1467.240, Def{a kind of medium sized fish grown in the sea, long and flat; with a big mouth}
4C42 CJK UNIFIED IDEOGRAPH-#4C42, IRGKangXi=1467.250, Def{a fish; common carp}
4C43 CJK UNIFIED IDEOGRAPH-#4C43, IRGKangXi=1467.280, Def{a fish}
4C44 CJK UNIFIED IDEOGRAPH-#4C44, IRGKangXi=1467.300, Def{(non-classical and corrupted form of 魪) a flatfish; a sole}
4C45 CJK UNIFIED IDEOGRAPH-#4C45, IRGKangXi=1467.310, Def{(same as 鱴 鮆) the mullet, a kind of fish grown in the sea; like abalone; a salted fish}
4C46 CJK UNIFIED IDEOGRAPH-#4C46, IRGKangXi=1468.080, Def{(same as 鱦) small fish, spawn, or roe, frog group}
4C47 CJK UNIFIED IDEOGRAPH-#4C47, IRGKangXi=1468.120, Def{(same as 鱔) the eel}
4C48 CJK UNIFIED IDEOGRAPH-#4C48, IRGKangXi=1468.170, Def{(ancient form of 鮨) fish pulp; mashed fish, fine-cut meat, something like the large amphibious creature; newt but very much larger, small fish, (same as 鰭) fins}
4C49 CJK UNIFIED IDEOGRAPH-#4C49, IRGKangXi=1468.200, Def{(corrupted form of 䱇) (same as 鱓,鱔) an eel}
4C4A CJK UNIFIED IDEOGRAPH-#4C4A, IRGKangXi=1469.050, Def{roe or spawn, a fish}
4C4B CJK UNIFIED IDEOGRAPH-#4C4B, IRGKangXi=1469.090, Def{spawn; roe, a kind of legendary fish said to be thousands of miles long, (interchangeable 魟) the nautilus; the ray}
4C4C CJK UNIFIED IDEOGRAPH-#4C4C, IRGKangXi=1469.200, Def{globefish; blowfish; puffer}
4C4D CJK UNIFIED IDEOGRAPH-#4C4D, IRGKangXi=1470.010, Def{tuna, something like sturgeon}
4C4E CJK UNIFIED IDEOGRAPH-#4C4E, IRGKangXi=1470.101, Def{(same as 䱍) tuna, something like sturgeon}
4C4F CJK UNIFIED IDEOGRAPH-#4C4F, IRGKangXi=1470.130, Def{a fish}
4C50 CJK UNIFIED IDEOGRAPH-#4C50, IRGKangXi=1470.300, Def{globefish; blowfish; puffer}
4C51 CJK UNIFIED IDEOGRAPH-#4C51, IRGKangXi=1471.020, Def{a fish; something like crab grown in the sea}
4C52 CJK UNIFIED IDEOGRAPH-#4C52, IRGKangXi=1471.040, Def{salted fish, globefish; blowfish; puffer}
4C53 CJK UNIFIED IDEOGRAPH-#4C53, IRGKangXi=1471.070, Def{a kind of fish, something like the sheat-fish}
4C54 CJK UNIFIED IDEOGRAPH-#4C54, IRGKangXi=1471.150, Def{(same as 鰷) a long narrow and silver colored fish; Trichiurus armatus}
4C55 CJK UNIFIED IDEOGRAPH-#4C55, IRGKangXi=1471.180, Def{labrus, moving fish}
4C56 CJK UNIFIED IDEOGRAPH-#4C56, IRGKangXi=1471.190, Def{(same as 鰡) shark}
4C57 CJK UNIFIED IDEOGRAPH-#4C57, IRGKangXi=1471.200, Def{a long narrow fish Trichiurus armatus}
4C58 CJK UNIFIED IDEOGRAPH-#4C58, IRGKangXi=1471.260
4C59 CJK UNIFIED IDEOGRAPH-#4C59, IRGKangXi=1472.070, Def{(same as 鮛) a small kind of tuna or sturgeon}
4C5A CJK UNIFIED IDEOGRAPH-#4C5A, IRGKangXi=1472.080, Def{a kind of fish}
4C5B CJK UNIFIED IDEOGRAPH-#4C5B, IRGKangXi=1472.090, Def{a kind of fish; small fish; fry, a large amphibious creature, something like the newt but very much larger}
4C5C CJK UNIFIED IDEOGRAPH-#4C5C, IRGKangXi=1472.110, Def{shark}
4C5D CJK UNIFIED IDEOGRAPH-#4C5D, IRGKangXi=1472.150, Def{black carp}
4C5E CJK UNIFIED IDEOGRAPH-#4C5E, IRGKangXi=1472.170, Def{a kind of fish}
4C5F CJK UNIFIED IDEOGRAPH-#4C5F, IRGKangXi=1472.230, Def{(an ancient name) a kind of silver fish, a kind of insect}
4C60 CJK UNIFIED IDEOGRAPH-#4C60, IRGKangXi=1472.250, Def{a kind of fish}
4C61 CJK UNIFIED IDEOGRAPH-#4C61, IRGKangXi=1472.320, Def{the globefish; blowfish; puffer}
4C62 CJK UNIFIED IDEOGRAPH-#4C62, IRGKangXi=1473.050, Def{a kind of fish}
4C63 CJK UNIFIED IDEOGRAPH-#4C63, IRGKangXi=1473.060, Def{a long narrow fish; tuna}
4C64 CJK UNIFIED IDEOGRAPH-#4C64, IRGKangXi=1473.080, Def{same as U+9C64 鱤}
4C65 CJK UNIFIED IDEOGRAPH-#4C65, IRGKangXi=1473.160, Def{a kind of fish; silver-gray color with black dots; with small mouth and no teeth}
4C66 CJK UNIFIED IDEOGRAPH-#4C66, IRGKangXi=1473.190, Def{the globefish; blowfish; puffer}
4C67 CJK UNIFIED IDEOGRAPH-#4C67, IRGKangXi=1473.270, Def{(record in an antique books) a kind of fish (same as 鱔) eels}
4C68 CJK UNIFIED IDEOGRAPH-#4C68, IRGKangXi=1473.271, Def{(same as 䱥) a kind of fish; silver-gray color with black dots; with small mouth and no teeth}
4C69 CJK UNIFIED IDEOGRAPH-#4C69, IRGKangXi=1473.271
4C6A CJK UNIFIED IDEOGRAPH-#4C6A, IRGKangXi=1473.271
4C6B CJK UNIFIED IDEOGRAPH-#4C6B, IRGKangXi=1473.370, Def{(same as 鯻) a kind of fish}
4C6C CJK UNIFIED IDEOGRAPH-#4C6C, IRGKangXi=1474.030, Def{a kind of fish}
4C6D CJK UNIFIED IDEOGRAPH-#4C6D, IRGKangXi=1474.040, Def{tuna}
4C6E CJK UNIFIED IDEOGRAPH-#4C6E, IRGKangXi=1474.120, Def{a kind of fish; skin for making arms or weapons}
4C6F CJK UNIFIED IDEOGRAPH-#4C6F, IRGKangXi=1474.260, Def{(corrupted form) a kind of fish}
4C70 CJK UNIFIED IDEOGRAPH-#4C70, IRGKangXi=1474.310, Def{(same as 鮦 鯉 鱧) a kind of fish; black fish}
4C71 CJK UNIFIED IDEOGRAPH-#4C71, IRGKangXi=1474.350, Def{Parasilurus asotus; small fish, fry; large carp}
4C72 CJK UNIFIED IDEOGRAPH-#4C72, IRGKangXi=1475.020, Def{a kind of fish}
4C73 CJK UNIFIED IDEOGRAPH-#4C73, IRGKangXi=1475.160, Def{(same as 鱣) a kind of sturgeon; Acipenser mikadoi, (interchangeable 鱔) eels}
4C74 CJK UNIFIED IDEOGRAPH-#4C74, IRGKangXi=1475.161, Def{(same as 䱭) tuna}
4C75 CJK UNIFIED IDEOGRAPH-#4C75, IRGKangXi=1475.210, Def{a kind of fish; live in the ocean}
4C76 CJK UNIFIED IDEOGRAPH-#4C76, IRGKangXi=1475.230, Def{a male crab, cod oil}
4C77 CJK UNIFIED IDEOGRAPH-#4C77, IRGKangXi=1475.380, Def{(same as 魚 漁) to fish, to seize}
4C78 CJK UNIFIED IDEOGRAPH-#4C78, IRGKangXi=1476.030, Def{a family name, (same as 緧) a crupper}
4C79 CJK UNIFIED IDEOGRAPH-#4C79, IRGKangXi=1476.090, Def{(standard form) (same as 鮓) a condiment made from minced fish salted, preserved fish}
4C7A CJK UNIFIED IDEOGRAPH-#4C7A, IRGKangXi=1476.100, Def{a male crab}
4C7B CJK UNIFIED IDEOGRAPH-#4C7B, IRGKangXi=1476.110, Def{a kind of fish; a flashing fly-fish in legend}
4C7C CJK UNIFIED IDEOGRAPH-#4C7C, IRGKangXi=1476.180, Def{a kind of fish; seven inchs long; good for soup}
4C7D CJK UNIFIED IDEOGRAPH-#4C7D, IRGKangXi=1476.251, Def{(same as U+9BE7 鯧) the pomfret}
4C7E CJK UNIFIED IDEOGRAPH-#4C7E, IRGKangXi=1476.280, Def{a carp-like savory fish}
4C7F CJK UNIFIED IDEOGRAPH-#4C7F, IRGKangXi=1476.380, Def{a kind of fish}
4C80 CJK UNIFIED IDEOGRAPH-#4C80, IRGKangXi=1476.420, Def{a kind of fish}
4C81 CJK UNIFIED IDEOGRAPH-#4C81, IRGKangXi=1477.050, Def{general term of a kind of fish, a snake-like fish}
4C82 CJK UNIFIED IDEOGRAPH-#4C82, IRGKangXi=1477.130, Def{a kind of fish}
4C83 CJK UNIFIED IDEOGRAPH-#4C83, IRGKangXi=1477.220, Def{a carp-like fish with chicken feet, spawn or roe}
4C84 CJK UNIFIED IDEOGRAPH-#4C84, IRGKangXi=1477.260, Def{(same as 鮸) an ocean fish with long flat body, big mouth, sharp teeth (a cod, same as 鰵)}
4C85 CJK UNIFIED IDEOGRAPH-#4C85, IRGKangXi=1477.280, Def{the globefish; blowfish; puffer}
4C86 CJK UNIFIED IDEOGRAPH-#4C86, IRGKangXi=1477.301
4C87 CJK UNIFIED IDEOGRAPH-#4C87, IRGKangXi=1477.301
4C88 CJK UNIFIED IDEOGRAPH-#4C88, IRGKangXi=1477.301
4C89 CJK UNIFIED IDEOGRAPH-#4C89, IRGKangXi=1477.370, Def{a kind of fish; tuna}
4C8A CJK UNIFIED IDEOGRAPH-#4C8A, IRGKangXi=1477.380, Def{fry (of fish), crab, get rid of the scales of a fish}
4C8B CJK UNIFIED IDEOGRAPH-#4C8B, IRGKangXi=1478.010, Def{(non-classical form) a kind of fish}
4C8C CJK UNIFIED IDEOGRAPH-#4C8C, IRGKangXi=1478.150, Def{a fish, the sound of touching the fish net}
4C8D CJK UNIFIED IDEOGRAPH-#4C8D, IRGKangXi=1478.170, Def{(standard form of 鰧) a perch-like fish with white body and red tail}
4C8E CJK UNIFIED IDEOGRAPH-#4C8E, IRGKangXi=1478.260, Def{(corrupted form of U+9BD8 鯘; same as U+9BBE 鮾) to spoil, to go down, to corrupt; spoiled fish-meat}
4C8F CJK UNIFIED IDEOGRAPH-#4C8F, IRGKangXi=1478.311, Def{a kind of fish}
4C90 CJK UNIFIED IDEOGRAPH-#4C90, IRGKangXi=1478.360, Def{a kind of fish}
4C91 CJK UNIFIED IDEOGRAPH-#4C91, IRGKangXi=1478.380, Def{spawn, or roe, a kind of fish}
4C92 CJK UNIFIED IDEOGRAPH-#4C92, IRGKangXi=1478.390, Def{(same as 蟹) crab}
4C93 CJK UNIFIED IDEOGRAPH-#4C93, IRGKangXi=1479.110, Def{a kind of fish, the mouth of a fish at surface of the water; gasping for breath}
4C94 CJK UNIFIED IDEOGRAPH-#4C94, IRGKangXi=1479.120, Def{a whale, huge}
4C95 CJK UNIFIED IDEOGRAPH-#4C95, IRGKangXi=1479.240, Def{the Yangtze porpoise}
4C96 CJK UNIFIED IDEOGRAPH-#4C96, IRGKangXi=1479.310, Def{big fish}
4C97 CJK UNIFIED IDEOGRAPH-#4C97, IRGKangXi=1480.060, Def{a kind of fish; with long and flat body; small mouth and pointed lips}
4C98 CJK UNIFIED IDEOGRAPH-#4C98, IRGKangXi=1480.071, Def{a kind of fish; with a long cylinder body}
4C99 CJK UNIFIED IDEOGRAPH-#4C99, IRGKangXi=1480.090, Def{a kind of fish; grown in fresh water; with flat body; orange color or blue colored pattern}
4C9A CJK UNIFIED IDEOGRAPH-#4C9A, IRGKangXi=1480.230, Def{shad}
4C9B CJK UNIFIED IDEOGRAPH-#4C9B, IRGKangXi=1480.280, Def{an ancient name for tuna, a kind of sturgeon}
4C9C CJK UNIFIED IDEOGRAPH-#4C9C, IRGKangXi=1480.510, Def{lots of fish}
4C9D CJK UNIFIED IDEOGRAPH-#4C9D, IRGKangXi=1480.511, Def{(same as U+9BE7 鯧) the pomfret}
4C9E CJK UNIFIED IDEOGRAPH-#4C9E, IRGKangXi=1480.511, Def{a general name for perch, etc.}
4C9F CJK UNIFIED IDEOGRAPH-#4C9F, IRGKangXi=1480.511, Def{(simplified form of 鮣) a kind of fish, live in the ocean, dark brown color with two white vertical marks; flat shaped head}
4CA0 CJK UNIFIED IDEOGRAPH-#4CA0, IRGKangXi=1480.511, Def{(simplified form 鰆) a kind of fish; long and flat; silver-gray with dark color dots and cross-grained strips}
4CA1 CJK UNIFIED IDEOGRAPH-#4CA1, IRGKangXi=1480.511, Def{(simplified form U+9C0C 鰍) loach}
4CA2 CJK UNIFIED IDEOGRAPH-#4CA2, IRGKangXi=0997.161, Def{(simplified form of 鰧) a kind of fish; stout; bluish gray color; big flat head; big mouth and small eyes; usually stay in the bottom of the shallow sea; half bured in the muddy sand}
4CA3 CJK UNIFIED IDEOGRAPH-#4CA3, IRGKangXi=0476.131, Def{(simplified form) to fish; to seize}
4CA4 CJK UNIFIED IDEOGRAPH-#4CA4, IRGKangXi=1480.511, Def{a kind of clam}
4CA5 CJK UNIFIED IDEOGRAPH-#4CA5, IRGKangXi=1481.140, Def{(same as 鳩) the pigeon; the turtle dove}
4CA6 CJK UNIFIED IDEOGRAPH-#4CA6, IRGKangXi=1482.050, Def{a legendary bird}
4CA7 CJK UNIFIED IDEOGRAPH-#4CA7, IRGKangXi=1482.060, Def{cuckoo; goatsucker or nightjar}
4CA8 CJK UNIFIED IDEOGRAPH-#4CA8, IRGKangXi=1482.110, Def{(same as 鴻) wild swan, a wild goose, vast; profound}
4CA9 CJK UNIFIED IDEOGRAPH-#4CA9, IRGKangXi=1483.020, Def{(same as 鳲) the cuckoo; the wood-pigeon or the turtle-dove}
4CAA CJK UNIFIED IDEOGRAPH-#4CAA, IRGKangXi=1483.031, Def{a kind of bird}
4CAB CJK UNIFIED IDEOGRAPH-#4CAB, IRGKangXi=1483.031, Def{(corrupted form of 鳩) the pigeon; the turtle dove}
4CAC CJK UNIFIED IDEOGRAPH-#4CAC, IRGKangXi=1483.040, Def{chicken; pheasant; wild goose}
4CAD CJK UNIFIED IDEOGRAPH-#4CAD, IRGKangXi=1483.080, Def{kite, owl, wine cups}
4CAE CJK UNIFIED IDEOGRAPH-#4CAE, IRGKangXi=1483.170, Def{a kind of bird}
4CAF CJK UNIFIED IDEOGRAPH-#4CAF, IRGKangXi=1483.180, Def{a kind of black small bird}
4CB0 CJK UNIFIED IDEOGRAPH-#4CB0, IRGKangXi=1483.270, Def{a name for the pigeon or the turtle dove}
4CB1 CJK UNIFIED IDEOGRAPH-#4CB1, IRGKangXi=1483.300, Def{(same as 鶭) a kind of black bird; most of the time stay by the marsh; where water gathers}
4CB2 CJK UNIFIED IDEOGRAPH-#4CB2, IRGKangXi=1483.320, Def{a hawk-like bird; much smaller}
4CB3 CJK UNIFIED IDEOGRAPH-#4CB3, IRGKangXi=1484.040, Def{birds flying up and down}
4CB4 CJK UNIFIED IDEOGRAPH-#4CB4, IRGKangXi=1484.170, Def{(same as 鴆) a kind of venomous bird, poisoned wine}
4CB5 CJK UNIFIED IDEOGRAPH-#4CB5, IRGKangXi=1484.250, Def{(same as 雀) a general name of small birds, as sparrows, chickadees, etc.}
4CB6 CJK UNIFIED IDEOGRAPH-#4CB6, IRGKangXi=1484.261
4CB7 CJK UNIFIED IDEOGRAPH-#4CB7, IRGKangXi=1484.261
4CB8 CJK UNIFIED IDEOGRAPH-#4CB8, IRGKangXi=1484.261, Def{a kind of bird}
4CB9 CJK UNIFIED IDEOGRAPH-#4CB9, IRGKangXi=1484.270, Def{osprey; water hawk}
4CBA CJK UNIFIED IDEOGRAPH-#4CBA, IRGKangXi=1484.280, Def{birds singing; chirps}
4CBB CJK UNIFIED IDEOGRAPH-#4CBB, IRGKangXi=1484.300, Def{the swallow, (same as 鳶) kite (a bird), kite (a toy)}
4CBC CJK UNIFIED IDEOGRAPH-#4CBC, IRGKangXi=1485.050, Def{a kind of bird, (same as 鼪) weasel}
4CBD CJK UNIFIED IDEOGRAPH-#4CBD, IRGKangXi=1485.140, Def{a kind of bird; suspended rocks}
4CBE CJK UNIFIED IDEOGRAPH-#4CBE, IRGKangXi=1485.150, Def{tailor bird; wren}
4CBF CJK UNIFIED IDEOGRAPH-#4CBF, IRGKangXi=1485.160, Def{(non-classical form of 鶿 U+9DC0) cormorant}
4CC0 CJK UNIFIED IDEOGRAPH-#4CC0, IRGKangXi=1485.200, Def{the cuckoo, a kind of pigeon, a kind of water bird}
4CC1 CJK UNIFIED IDEOGRAPH-#4CC1, IRGKangXi=1485.240, Def{a wild duck-like water bird, a pheasant like bird}
4CC2 CJK UNIFIED IDEOGRAPH-#4CC2, IRGKangXi=1485.250, Def{a kind of small bird, sound of birds, the feathered; birds}
4CC3 CJK UNIFIED IDEOGRAPH-#4CC3, IRGKangXi=1485.270, Def{a kind of phoenix-like bird}
4CC4 CJK UNIFIED IDEOGRAPH-#4CC4, IRGKangXi=1486.010, Def{(same as 鴜) a kind of water bird; with black color, (same as 雌) female; woman-like}
4CC5 CJK UNIFIED IDEOGRAPH-#4CC5, IRGKangXi=1486.020, Def{a kind of bird which shares its nest with rats, sound of birds}
4CC6 CJK UNIFIED IDEOGRAPH-#4CC6, IRGKangXi=1486.040, Def{a kind of species of myna (or mynah); a grackle}
4CC7 CJK UNIFIED IDEOGRAPH-#4CC7, IRGKangXi=1486.140, Def{(same as 鵡) parrot}
4CC8 CJK UNIFIED IDEOGRAPH-#4CC8, IRGKangXi=1486.150, Def{(same as 鴇) a bird resembling the wild goose; Otis dybowskii}
4CC9 CJK UNIFIED IDEOGRAPH-#4CC9, IRGKangXi=1487.030, Def{a kind of water bird, (same as 鴆) a kind of venomous bird}
4CCA CJK UNIFIED IDEOGRAPH-#4CCA, IRGKangXi=1487.151, Def{(same as 䳁) a wild duck-like water bird, a pheasant like bird}
4CCB CJK UNIFIED IDEOGRAPH-#4CCB, IRGKangXi=1487.190, Def{a pheasant-like bird with black and body and red feet, a kind of bird, (same as 蟂) an otter-like animal}
4CCC CJK UNIFIED IDEOGRAPH-#4CCC, IRGKangXi=1487.300, Def{(non-classical form of 鵑) the cuckoo}
4CCD CJK UNIFIED IDEOGRAPH-#4CCD, IRGKangXi=1488.080, Def{a kind of pheasant-like bird}
4CCE CJK UNIFIED IDEOGRAPH-#4CCE, IRGKangXi=1488.090, Def{a pigeon-like bird; with a comb or crest}
4CCF CJK UNIFIED IDEOGRAPH-#4CCF, IRGKangXi=1488.160, Def{cuckoo, pelican, (same as 鴃) a shrike; butcherbird}
4CD0 CJK UNIFIED IDEOGRAPH-#4CD0, IRGKangXi=1488.220, Def{an owl-like bird}
4CD1 CJK UNIFIED IDEOGRAPH-#4CD1, IRGKangXi=1488.250, Def{a pheasant-like bird}
4CD2 CJK UNIFIED IDEOGRAPH-#4CD2, IRGKangXi=1489.050, Def{a kind of bird, a hawk; sparrow hawk}
4CD3 CJK UNIFIED IDEOGRAPH-#4CD3, IRGKangXi=1489.161, Def{a kind of water bird, a vulture; a condor}
4CD4 CJK UNIFIED IDEOGRAPH-#4CD4, IRGKangXi=1489.220, Def{a pigeon-like bird; with a comb or crest, a shrike; butcherbird}
4CD5 CJK UNIFIED IDEOGRAPH-#4CD5, IRGKangXi=1490.130, Def{the pigeon, the turtle dove}
4CD6 CJK UNIFIED IDEOGRAPH-#4CD6, IRGKangXi=1490.230, Def{flying birds, a kind of bird}
4CD7 CJK UNIFIED IDEOGRAPH-#4CD7, IRGKangXi=1491.220, Def{(ancient form of 鵝) goose; gander}
4CD8 CJK UNIFIED IDEOGRAPH-#4CD8, IRGKangXi=1491.010, Def{(same as 䳗,鵝) goose; gander}
4CD9 CJK UNIFIED IDEOGRAPH-#4CD9, IRGKangXi=1491.030, Def{a egret-like bird, a kind of water bird}
4CDA CJK UNIFIED IDEOGRAPH-#4CDA, IRGKangXi=1491.050, Def{a sort of nightingale which is said to sing for the dawn; also the name for a large bat with awing-spread of two feet, a sort of pheasant}
4CDB CJK UNIFIED IDEOGRAPH-#4CDB, IRGKangXi=1491.140, Def{(same as 鷃) a small brown speckled bird like the quail}
4CDC CJK UNIFIED IDEOGRAPH-#4CDC, IRGKangXi=1491.241, Def{(same as 鵌) a kind of bird which shares its nest with rats}
4CDD CJK UNIFIED IDEOGRAPH-#4CDD, IRGKangXi=1491.350, Def{a kind of small birds, a kind of bird}
4CDE CJK UNIFIED IDEOGRAPH-#4CDE, IRGKangXi=1492.010, Def{birds flying all directions}
4CDF CJK UNIFIED IDEOGRAPH-#4CDF, IRGKangXi=1492.060, Def{a legendary bird, divine birds; the phoenix}
4CE0 CJK UNIFIED IDEOGRAPH-#4CE0, IRGKangXi=1492.260, Def{owl, kite, hawk; sparrow hawk, stop flying (said of bird)}
4CE1 CJK UNIFIED IDEOGRAPH-#4CE1, IRGKangXi=1493.030, Def{(same as 鵻) a kind of bird in ancient books; a wood-pigeon; a hawk}
4CE2 CJK UNIFIED IDEOGRAPH-#4CE2, IRGKangXi=1493.120, Def{(same as 鶀) small wild goose}
4CE3 CJK UNIFIED IDEOGRAPH-#4CE3, IRGKangXi=1493.130, Def{(non-classical form of 鳶) kite (bird), kite (toy), owl, to soar; to fly}
4CE4 CJK UNIFIED IDEOGRAPH-#4CE4, IRGKangXi=1493.190, Def{a legendary bird; second name for an owl}
4CE5 CJK UNIFIED IDEOGRAPH-#4CE5, IRGKangXi=1494.101
4CE6 CJK UNIFIED IDEOGRAPH-#4CE6, IRGKangXi=1494.120, Def{wren; the tailorbird, a kind of small bird}
4CE7 CJK UNIFIED IDEOGRAPH-#4CE7, IRGKangXi=1495.341, Def{an eagle; a hawk}
4CE8 CJK UNIFIED IDEOGRAPH-#4CE8, IRGKangXi=1494.180, Def{(same as 凰) the female phoenix, a legendary bird in Chinese mythology, (standard form of 皇) beautiful; brilliant, royal}
4CE9 CJK UNIFIED IDEOGRAPH-#4CE9, IRGKangXi=1494.290, Def{a kind of bird; a pheasant-like bird; red body and with a long tail}
4CEA CJK UNIFIED IDEOGRAPH-#4CEA, IRGKangXi=1494.310, Def{(non-classical form of 鷒) a kind of bird, a kind of stork-like bird}
4CEB CJK UNIFIED IDEOGRAPH-#4CEB, IRGKangXi=1494.380, Def{(standard form) a small pigeon}
4CEC CJK UNIFIED IDEOGRAPH-#4CEC, IRGKangXi=1494.440, Def{(same as 鷊) a kind of bird, a kind of grass, (same as U+9D83) a fabulous sea bird}
4CED CJK UNIFIED IDEOGRAPH-#4CED, IRGKangXi=1494.460, RSKangXi=196.9, Def{wagtail}
4CEE CJK UNIFIED IDEOGRAPH-#4CEE, IRGKangXi=1495.180, Def{to look at in surprise (said of bird)}
4CEF CJK UNIFIED IDEOGRAPH-#4CEF, IRGKangXi=1495.220, Def{a kind of bird, small bird flying, a general name of small birds}
4CF0 CJK UNIFIED IDEOGRAPH-#4CF0, IRGKangXi=1495.340, Def{(same as 鴇) a bird resembling the wild goose; Otis dybowskii}
4CF1 CJK UNIFIED IDEOGRAPH-#4CF1, IRGKangXi=1495.350, Def{(non-classical form of 鶩) ducks}
4CF2 CJK UNIFIED IDEOGRAPH-#4CF2, IRGKangXi=1496.070, Def{a swarm of flying birds; birds soar in groups}
4CF3 CJK UNIFIED IDEOGRAPH-#4CF3, IRGKangXi=1496.130, Def{a kind of small bird, strange; weird bird}
4CF4 CJK UNIFIED IDEOGRAPH-#4CF4, IRGKangXi=1496.220, Def{a kind of bird, a flying young bird}
4CF5 CJK UNIFIED IDEOGRAPH-#4CF5, IRGKangXi=1498.050, Def{a kind of water bird with colorful feather}
4CF6 CJK UNIFIED IDEOGRAPH-#4CF6, IRGKangXi=1498.160, Def{(same as 㶉) a kind of water bird, (same as 雞) chickens}
4CF7 CJK UNIFIED IDEOGRAPH-#4CF7, IRGKangXi=1498.230, Def{chicken}
4CF8 CJK UNIFIED IDEOGRAPH-#4CF8, IRGKangXi=1498.260, Def{the wild goose, sparrow; the house-sparrow}
4CF9 CJK UNIFIED IDEOGRAPH-#4CF9, IRGKangXi=1500.091, Def{a kind dove-like bird, (same as 鵽鳩)}
4CFA CJK UNIFIED IDEOGRAPH-#4CFA, IRGKangXi=1499.040, Def{(same as 鵪) the quail}
4CFB CJK UNIFIED IDEOGRAPH-#4CFB, IRGKangXi=1499.230, Def{eagle; hawk; osprey}
4CFC CJK UNIFIED IDEOGRAPH-#4CFC, IRGKangXi=1500.020, Def{(standard form of 鷗) gull, water bird}
4CFD CJK UNIFIED IDEOGRAPH-#4CFD, IRGKangXi=1500.091, Def{(non-classical form of 鸖) (same as 鶴) crane}
4CFE CJK UNIFIED IDEOGRAPH-#4CFE, IRGKangXi=1500.120, Def{an owl, the rail (a bird)}
4CFF CJK UNIFIED IDEOGRAPH-#4CFF, IRGKangXi=1500.230, Def{a kind of bird}
4D00 CJK UNIFIED IDEOGRAPH-#4D00, IRGKangXi=1500.250, Def{a kind of water bird}
4D01 CJK UNIFIED IDEOGRAPH-#4D01, IRGKangXi=1500.270, Def{a kind of rat-like bird, a vulture or a condor-like bird}
4D02 CJK UNIFIED IDEOGRAPH-#4D02, IRGKangXi=1500.290, Def{a kind of water bird}
4D03 CJK UNIFIED IDEOGRAPH-#4D03, IRGKangXi=1500.440, Def{wren; the tailorbird, the golden oriole}
4D04 CJK UNIFIED IDEOGRAPH-#4D04, IRGKangXi=1501.080, Def{a kind of bird}
4D05 CJK UNIFIED IDEOGRAPH-#4D05, IRGKangXi=1502.010, Def{a legendary bird; like magpie; with white body, red tail and six feet}
4D06 CJK UNIFIED IDEOGRAPH-#4D06, IRGKangXi=1502.020, Def{a kind of bird, a kind of bird good at casting lots or divining}
4D07 CJK UNIFIED IDEOGRAPH-#4D07, IRGKangXi=1502.170, Def{crane; small swan; non-classical form of U+9D12 鴒, wagtail}
4D08 CJK UNIFIED IDEOGRAPH-#4D08, IRGKangXi=1502.260, Def{(non-classical form) a kind of water bird}
4D09 CJK UNIFIED IDEOGRAPH-#4D09, IRGKangXi=1502.320, Def{general term for a group of bird (looks like egret), to fly in a circle}
4D0A CJK UNIFIED IDEOGRAPH-#4D0A, IRGKangXi=1503.161, Def{(same as 鸃) the crow-pheasant}
4D0B CJK UNIFIED IDEOGRAPH-#4D0B, IRGKangXi=1503.161, Def{a kind of water bird; deep eyed, general term for a group of bird}
4D0C CJK UNIFIED IDEOGRAPH-#4D0C, IRGKangXi=1503.391, Def{a kind of water bird; a big gray-white colored body with hairy tail}
4D0D CJK UNIFIED IDEOGRAPH-#4D0D, IRGKangXi=1503.220, Def{a kind of strange and weird bird}
4D0E CJK UNIFIED IDEOGRAPH-#4D0E, IRGKangXi=1504.131, Def{(same as 鸓) flying squirrel; bats}
4D0F CJK UNIFIED IDEOGRAPH-#4D0F, IRGKangXi=1504.271, Def{(same as 燕) a swallow}
4D10 CJK UNIFIED IDEOGRAPH-#4D10, IRGKangXi=1505.060, Def{a kind of bird, (same as 鴇) a bird resembling the wild goose; Otis dybowskii}
4D11 CJK UNIFIED IDEOGRAPH-#4D11, IRGKangXi=1505.110, Def{a legendary weird bird; resembling the magpie; dark red color; with two heads and four feet, (corrupted form of 鸓) flying squirrel; bats}
4D12 CJK UNIFIED IDEOGRAPH-#4D12, IRGKangXi=1505.120, Def{(same as 鴒) wagtail}
4D13 CJK UNIFIED IDEOGRAPH-#4D13, IRGKangXi=1505.141, Def{general term for a group of small birds}
4D14 CJK UNIFIED IDEOGRAPH-#4D14, IRGKangXi=1505.141, Def{the fishing cormorant}
4D15 CJK UNIFIED IDEOGRAPH-#4D15, IRGKangXi=1505.141, Def{a woodpecker}
4D16 CJK UNIFIED IDEOGRAPH-#4D16, IRGKangXi=1505.141, Def{a kind of water bird}
4D17 CJK UNIFIED IDEOGRAPH-#4D17, IRGKangXi=1505.141, Def{a shrike}
4D18 CJK UNIFIED IDEOGRAPH-#4D18, IRGKangXi=1505.141, Def{a kind of bird}
4D19 CJK UNIFIED IDEOGRAPH-#4D19, IRGKangXi=1505.141, Def{a kind of bird resembling the duck; much smaller}
4D1A CJK UNIFIED IDEOGRAPH-#4D1A, IRGKangXi=1507.050, Def{saltpond; salty marshes}
4D1B CJK UNIFIED IDEOGRAPH-#4D1B, IRGKangXi=1507.130, Def{to make decoction of salt}
4D1C CJK UNIFIED IDEOGRAPH-#4D1C, IRGKangXi=1507.260, Def{salt}
4D1D CJK UNIFIED IDEOGRAPH-#4D1D, IRGKangXi=1508.020, Def{salt, soybean sauce; soy}
4D1E CJK UNIFIED IDEOGRAPH-#4D1E, IRGKangXi=1508.090, Def{salty; briny; salted}
4D1F CJK UNIFIED IDEOGRAPH-#4D1F, IRGKangXi=1509.050, Def{an one-year old deer, a three-year old deer}
4D20 CJK UNIFIED IDEOGRAPH-#4D20, IRGKangXi=1509.060, Def{a young tailed deer}
4D21 CJK UNIFIED IDEOGRAPH-#4D21, IRGKangXi=1509.171, Def{(same as 麗) beautiful; elegant; fair; fine}
4D22 CJK UNIFIED IDEOGRAPH-#4D22, IRGKangXi=1509.171, Def{(same as 麋) a kind of deer; Alces machlis}
4D23 CJK UNIFIED IDEOGRAPH-#4D23, IRGKangXi=1509.180, Def{a kind of animal}
4D24 CJK UNIFIED IDEOGRAPH-#4D24, IRGKangXi=1509.230, Def{an animal as big as a rabbit, a two-year old deer}
4D25 CJK UNIFIED IDEOGRAPH-#4D25, IRGKangXi=1509.240, Def{(same as 麚) a stag}
4D26 CJK UNIFIED IDEOGRAPH-#4D26, IRGKangXi=1510.120, Def{a legendary animal; a fox-like animal and with a man's eyes}
4D27 CJK UNIFIED IDEOGRAPH-#4D27, IRGKangXi=1510.210, Def{venison}
4D28 CJK UNIFIED IDEOGRAPH-#4D28, IRGKangXi=1511.151
4D29 CJK UNIFIED IDEOGRAPH-#4D29, IRGKangXi=1511.180, Def{a kind of deer}
4D2A CJK UNIFIED IDEOGRAPH-#4D2A, IRGKangXi=1511.280, Def{a fabulous creature, something like a deer, with a single horn}
4D2B CJK UNIFIED IDEOGRAPH-#4D2B, IRGKangXi=1511.281, Def{(same as U+9EA2 羚) antelope}
4D2C CJK UNIFIED IDEOGRAPH-#4D2C, IRGKangXi=1512.140, Def{crumbs of barley; bran; chaff}
4D2D CJK UNIFIED IDEOGRAPH-#4D2D, IRGKangXi=1512.150, Def{distiller's grains or yeast; ferment for brewing}
4D2E CJK UNIFIED IDEOGRAPH-#4D2E, IRGKangXi=1512.170, Def{cakes pf leaven; yeast, ferment for brewing, crumbs of barley}
4D2F CJK UNIFIED IDEOGRAPH-#4D2F, IRGKangXi=1512.230, Def{a kind of cake}
4D30 CJK UNIFIED IDEOGRAPH-#4D30, IRGKangXi=1512.260, Def{a family name, (same as 䴬) crumbs of barley; bran; chaff}
4D31 CJK UNIFIED IDEOGRAPH-#4D31, IRGKangXi=1513.030, Def{cakes and biscuits}
4D32 CJK UNIFIED IDEOGRAPH-#4D32, IRGKangXi=1513.070, Def{flour, rice flour}
4D33 CJK UNIFIED IDEOGRAPH-#4D33, IRGKangXi=1513.120, Def{distiller's grains or yeast}
4D34 CJK UNIFIED IDEOGRAPH-#4D34, IRGKangXi=1513.130, Def{a kind of cake, a kind of herb medicine, (same as 黏) to stick, glutinous; adhesive}
4D35 CJK UNIFIED IDEOGRAPH-#4D35, IRGKangXi=1513.170, Def{(same as 餅) cakes; biscuits; pastry}
4D36 CJK UNIFIED IDEOGRAPH-#4D36, IRGKangXi=1513.250, Def{(same as 麷) to boil or stew wheat, to simmer ferment for brewing}
4D37 CJK UNIFIED IDEOGRAPH-#4D37, IRGKangXi=1513.330, Def{use the whole piece of barley to ferment for brewing}
4D38 CJK UNIFIED IDEOGRAPH-#4D38, IRGKangXi=1513.340, Def{(non-classical form of 麩) bran; refuse}
4D39 CJK UNIFIED IDEOGRAPH-#4D39, IRGKangXi=1513.360, Def{cakes; biscuits; pastry, distiller's grains or yeast, (interchangeable 稞) grains ready for grinding; healthy grains, flour, (same as 䴷) use the whole piece of barley to ferment for brewing}
4D3A CJK UNIFIED IDEOGRAPH-#4D3A, IRGKangXi=1513.450, Def{cakes; cookies; biscuits; pastries; dumplings}
4D3B CJK UNIFIED IDEOGRAPH-#4D3B, IRGKangXi=1513.460, Def{dry food}
4D3C CJK UNIFIED IDEOGRAPH-#4D3C, IRGKangXi=1513.500, Def{to extirpate; to level off; to pare barley}
4D3D CJK UNIFIED IDEOGRAPH-#4D3D, IRGKangXi=1513.510, Def{a small round piece of distiller's grains or yeast}
4D3E CJK UNIFIED IDEOGRAPH-#4D3E, IRGKangXi=1514.140, Def{to grind barley}
4D3F CJK UNIFIED IDEOGRAPH-#4D3F, IRGKangXi=1514.160, Def{grains from the distillery, crumbs of barley, crumbs of rice}
4D40 CJK UNIFIED IDEOGRAPH-#4D40, IRGKangXi=1514.200, Def{coarse crumbs of barley, unrefined or unpolished wheat}
4D41 CJK UNIFIED IDEOGRAPH-#4D41, IRGKangXi=1514.290, Def{decayed dough; rotten noodle}
4D42 CJK UNIFIED IDEOGRAPH-#4D42, IRGKangXi=1514.310, Def{to grind wheat to powder; with bran and flour mixed together}
4D43 CJK UNIFIED IDEOGRAPH-#4D43, IRGKangXi=1514.420, Def{a kind of barley, dust of ferment for brewing; small crumbs of grains from the distillery}
4D44 CJK UNIFIED IDEOGRAPH-#4D44, IRGKangXi=1514.430, Def{(same as 麷) to boil or stew wheat, to simmer ferment for brewing, (interchangeable 豐) various kinds of rush from which mats, bags, etc. are made; vines of the rushes}
4D45 CJK UNIFIED IDEOGRAPH-#4D45, IRGKangXi=1514.320, Def{(same as 熬) to extract by applying heat, to cook; to stew or simmer}
4D46 CJK UNIFIED IDEOGRAPH-#4D46, IRGKangXi=1514.490, Def{(same as 䴿) grains from the distillery, crumbs of barley, crumbs of rice}
4D47 CJK UNIFIED IDEOGRAPH-#4D47, IRGKangXi=1515.090, Def{to dislike; to reject; to hate, a house; a building}
4D48 CJK UNIFIED IDEOGRAPH-#4D48, IRGKangXi=1515.280, Def{unspun/raw hemp/silk}
4D49 CJK UNIFIED IDEOGRAPH-#4D49, IRGKangXi=1515.281, Def{Abutilon, grassy plant with fibres from which cloth is made}
4D4A CJK UNIFIED IDEOGRAPH-#4D4A, IRGKangXi=1516.080, Def{(same as 䵍) yellow, used in person's name}
4D4B CJK UNIFIED IDEOGRAPH-#4D4B, IRGKangXi=1516.130, Def{yellow, greenish yellow}
4D4C CJK UNIFIED IDEOGRAPH-#4D4C, IRGKangXi=1516.200, Def{reddish yellow}
4D4D CJK UNIFIED IDEOGRAPH-#4D4D, IRGKangXi=1517.070, Def{yellow, used in person's name}
4D4E CJK UNIFIED IDEOGRAPH-#4D4E, IRGKangXi=1517.090, Def{dark yellow, yellow, bright; well-illuminated}
4D4F CJK UNIFIED IDEOGRAPH-#4D4F, IRGKangXi=1517.180, Def{yellow; straw colored}
4D50 CJK UNIFIED IDEOGRAPH-#4D50, IRGKangXi=1517.190, Def{yellow, (dialect) yellowish black; dark yellow}
4D51 CJK UNIFIED IDEOGRAPH-#4D51, IRGKangXi=1517.270, Def{(same as 䵒 U+4D52) glue, a kind of cement made of hemp, lime and oil}
4D52 CJK UNIFIED IDEOGRAPH-#4D52, IRGKangXi=1517.320, Def{glue, a kind of cement made of hemp, lime and oil}
4D53 CJK UNIFIED IDEOGRAPH-#4D53, IRGKangXi=1517.360, Def{the mole}
4D54 CJK UNIFIED IDEOGRAPH-#4D54, IRGKangXi=1518.110, Def{to turn on the heel, not moving forward}
4D55 CJK UNIFIED IDEOGRAPH-#4D55, IRGKangXi=1518.140, Def{a varietyof millet, to stick, sticky; glutinous}
4D56 CJK UNIFIED IDEOGRAPH-#4D56, IRGKangXi=1518.150, Def{panicled millet, congee; porridge; rice gruel, ripening of paddy or rice; a harvest}
4D57 CJK UNIFIED IDEOGRAPH-#4D57, IRGKangXi=1518.180, Def{to clean the withered; dried and decayed leaves of the bottom part of millets, grains, beans or peas, a variety of millet, beans and peas collectively, to paste up, to attach to, to stick up; to glue}
4D58 CJK UNIFIED IDEOGRAPH-#4D58, IRGKangXi=1518.200, Def{not sticking together, non-adherent; (same as 曬) to dry in the sun; to expose to sunlight}
4D59 CJK UNIFIED IDEOGRAPH-#4D59, IRGKangXi=1518.210, Def{sticky; to append; padding; cushioning, to paste on something}
4D5A CJK UNIFIED IDEOGRAPH-#4D5A, IRGKangXi=1518.240, Def{(dialect) kaoliang; sorghum}
4D5B CJK UNIFIED IDEOGRAPH-#4D5B, IRGKangXi=1518.300, Def{(non-classical form of 䵖) panicled millet, congee; porridge; rice gruel, ripening of paddy or rice; a harvest}
4D5C CJK UNIFIED IDEOGRAPH-#4D5C, IRGKangXi=1518.310, Def{to plough and sow, a kind of fruit}
4D5D CJK UNIFIED IDEOGRAPH-#4D5D, IRGKangXi=1518.380, Def{dark black, black}
4D5E CJK UNIFIED IDEOGRAPH-#4D5E, IRGKangXi=1518.400, Def{(ancient form of 黥) ancient punishment of tattooing the face}
4D5F CJK UNIFIED IDEOGRAPH-#4D5F, IRGKangXi=1518.430, Def{(same as 皯) black, black moles or black birthmarks on the face}
4D60 CJK UNIFIED IDEOGRAPH-#4D60, IRGKangXi=1518.460, RSKangXi=203.3, Def{rushes used form making mats, face decorations (for women), to ornament on the face of a woman}
4D61 CJK UNIFIED IDEOGRAPH-#4D61, IRGKangXi=1519.090, Def{(non-classical form of U+4D64 䵤) to crack or chap; (cracked) black skin}
4D62 CJK UNIFIED IDEOGRAPH-#4D62, IRGKangXi=1519.220, Def{light black, dark black}
4D63 CJK UNIFIED IDEOGRAPH-#4D63, IRGKangXi=1519.230, Def{white with black; black and beautiful, name of a county in ancient times}
4D64 CJK UNIFIED IDEOGRAPH-#4D64, IRGKangXi=1519.290, Def{to crack or chap; (cracked) black skin}
4D65 CJK UNIFIED IDEOGRAPH-#4D65, IRGKangXi=1519.340, Def{black, dark; deep}
4D66 CJK UNIFIED IDEOGRAPH-#4D66, IRGKangXi=1520.020, Def{(non-classical form of 汙 污) to stain; to mess up, dirty; filthy}
4D67 CJK UNIFIED IDEOGRAPH-#4D67, IRGKangXi=1520.040, Def{to dye}
4D68 CJK UNIFIED IDEOGRAPH-#4D68, IRGKangXi=1520.090, Def{dark; dim; obscure, personal secrets}
4D69 CJK UNIFIED IDEOGRAPH-#4D69, IRGKangXi=1520.150, Def{(non-classical form of 黧) dark yellow, black mark, light yellow; sallow}
4D6A CJK UNIFIED IDEOGRAPH-#4D6A, IRGKangXi=1520.190, Def{pure black, to omit, to forget, to wonder about doing nothing}
4D6B CJK UNIFIED IDEOGRAPH-#4D6B, IRGKangXi=1520.300, Def{(same as 纁) light red (same as 黦) yellowish black}
4D6C CJK UNIFIED IDEOGRAPH-#4D6C, IRGKangXi=1520.370, Def{black (corrupted form of 濌) sound of the flowing water}
4D6D CJK UNIFIED IDEOGRAPH-#4D6D, IRGKangXi=1521.020, Def{black}
4D6E CJK UNIFIED IDEOGRAPH-#4D6E, IRGKangXi=1521.170, Def{red-and-black color, light green; light blue}
4D6F CJK UNIFIED IDEOGRAPH-#4D6F, IRGKangXi=1521.180, Def{(same as 畽) a village; a farmstead, a hamlet, the land outside a city}
4D70 CJK UNIFIED IDEOGRAPH-#4D70, IRGKangXi=1522.010, Def{black color, red-and-black color}
4D71 CJK UNIFIED IDEOGRAPH-#4D71, IRGKangXi=1522.100, Def{red-and-black color, blue-and-black color, black color}
4D72 CJK UNIFIED IDEOGRAPH-#4D72, IRGKangXi=1522.230, Def{raw hemp, mildewed hemp; freckles}
4D73 CJK UNIFIED IDEOGRAPH-#4D73, IRGKangXi=1522.250, Def{light black}
4D74 CJK UNIFIED IDEOGRAPH-#4D74, IRGKangXi=1522.260, Def{black color, black specks; mottles on the face, black face, (same as 暈) to faint; giddy and dizzy}
4D75 CJK UNIFIED IDEOGRAPH-#4D75, IRGKangXi=1522.300, Def{yellowish black and white, short and black, over-fatigued; weary; tired}
4D76 CJK UNIFIED IDEOGRAPH-#4D76, IRGKangXi=1524.030, Def{a kind of frog; a kind of sea turtle; with two horns; and pattern on the tortoise shell}
4D77 CJK UNIFIED IDEOGRAPH-#4D77, IRGKangXi=1524.090, Def{(same as 鼃 蛙) frog, (interchangeable 哇) retch, noise of vomiting}
4D78 CJK UNIFIED IDEOGRAPH-#4D78, IRGKangXi=1524.170, Def{(same as 鼀) the toad that lives in the moon}
4D79 CJK UNIFIED IDEOGRAPH-#4D79, IRGKangXi=1524.260, Def{(standard form 鼅) insects that are injurious to crops, spider}
4D7A CJK UNIFIED IDEOGRAPH-#4D7A, IRGKangXi=1525.180, Def{(same as 圢 町) boundary between agricultural lands, (in Japan) a street; a city block, ant hill; formicary, vacant land by the side of a house; a paddock, deer trace; deer track}
4D7B CJK UNIFIED IDEOGRAPH-#4D7B, IRGKangXi=1525.210, Def{a small tripod of bronze with two ears (standard form 鏏) tripod of bronze with two ears; heavy three-legged caldron or sacrificial vessel}
4D7C CJK UNIFIED IDEOGRAPH-#4D7C, IRGKangXi=1525.220, Def{to boil; to cook; to stew}
4D7D CJK UNIFIED IDEOGRAPH-#4D7D, IRGKangXi=1526.070, Def{sound of drums, to beat the side of a drum}
4D7E CJK UNIFIED IDEOGRAPH-#4D7E, IRGKangXi=1526.110, Def{sound of drums, loud noise of the military drums, (same as 拊) to pat; to touch with hand lightly or tenderly, to slap; to tap; to clap hands}
4D7F CJK UNIFIED IDEOGRAPH-#4D7F, IRGKangXi=1526.120, Def{a silent drum, spacious}
4D80 CJK UNIFIED IDEOGRAPH-#4D80, IRGKangXi=1526.160, Def{sound of drums; image of the sound}
4D81 CJK UNIFIED IDEOGRAPH-#4D81, IRGKangXi=1526.250, Def{noises; disorderly or confused sound of the drums}
4D82 CJK UNIFIED IDEOGRAPH-#4D82, IRGKangXi=1527.170, Def{a squirrel-like animal, a flying squirrel, a rat-like animal; much smaller}
4D83 CJK UNIFIED IDEOGRAPH-#4D83, IRGKangXi=1527.210, Def{a kind of rat, lizard}
4D84 CJK UNIFIED IDEOGRAPH-#4D84, IRGKangXi=1527.320, Def{striped mottled rat; mountain rat; short and red-brown colored with spots}
4D85 CJK UNIFIED IDEOGRAPH-#4D85, IRGKangXi=1528.180, Def{a marmot-like rat with a big head}
4D86 CJK UNIFIED IDEOGRAPH-#4D86, IRGKangXi=1528.330, Def{(dialect) a rat; a mouse}
4D87 CJK UNIFIED IDEOGRAPH-#4D87, IRGKangXi=1529.030, Def{a rat}
4D88 CJK UNIFIED IDEOGRAPH-#4D88, IRGKangXi=1529.190, Def{a kind of rat, known together as the kangaroo}
4D89 CJK UNIFIED IDEOGRAPH-#4D89, IRGKangXi=1529.210, Def{guinea pig; a kind of big rat; living in the bamboo grove}
4D8A CJK UNIFIED IDEOGRAPH-#4D8A, IRGKangXi=1530.110, Def{(corrupted form) (interchangeable with 衄) to bleed at the nose, a check in battle, to damp ardour, to shrink from; to treat harshly, to be damped; to suffer defeat}
4D8B CJK UNIFIED IDEOGRAPH-#4D8B, IRGKangXi=1530.120, Def{sound; sound of the breath}
4D8C CJK UNIFIED IDEOGRAPH-#4D8C, IRGKangXi=1530.210, Def{(same as 皰) a pustule or pimple}
4D8D CJK UNIFIED IDEOGRAPH-#4D8D, IRGKangXi=1530.230, Def{(same as 嚏) to sneeze}
4D8E CJK UNIFIED IDEOGRAPH-#4D8E, IRGKangXi=1530.250, Def{sound of breath; snoring; snorting}
4D8F CJK UNIFIED IDEOGRAPH-#4D8F, IRGKangXi=1530.280, Def{(same as 洟) tears; snivel; nasal mucus, (same as 挮) to weep; to snivel}
4D90 CJK UNIFIED IDEOGRAPH-#4D90, IRGKangXi=1530.460, Def{to take breath; snoring; snorting}
4D91 CJK UNIFIED IDEOGRAPH-#4D91, IRGKangXi=1531.030, Def{(standard form 嚏) to sneeze; a running at the nose}
4D92 CJK UNIFIED IDEOGRAPH-#4D92, IRGKangXi=1531.130, Def{outstanding ability, exquisite; fine}
4D93 CJK UNIFIED IDEOGRAPH-#4D93, IRGKangXi=1531.110, Def{ramie; linen sackcloth, to twist and join (cords); to continue, to order the arrest of; to capture}
4D94 CJK UNIFIED IDEOGRAPH-#4D94, IRGKangXi=1532.200, Def{prominent gums (of the teeth)}
4D95 CJK UNIFIED IDEOGRAPH-#4D95, IRGKangXi=1532.230, Def{irregular and prominent teeth}
4D96 CJK UNIFIED IDEOGRAPH-#4D96, IRGKangXi=1533.010, Def{disease of tongue (said of an ox), to keep the mouth shut}
4D97 CJK UNIFIED IDEOGRAPH-#4D97, IRGKangXi=1533.110, Def{to bite; use all the strength to bite; to gnaw, bones squeeze between teeth (could not be picked out)}
4D98 CJK UNIFIED IDEOGRAPH-#4D98, IRGKangXi=1533.150, Def{the sound of chewing something dry and hard, sound of gnawing or biting}
4D99 CJK UNIFIED IDEOGRAPH-#4D99, IRGKangXi=1533.190, Def{swelling of the gums (of the teeth)}
4D9A CJK UNIFIED IDEOGRAPH-#4D9A, IRGKangXi=1533.350, Def{(non-classical form of 齲) decayed tooth; carious tooth}
4D9B CJK UNIFIED IDEOGRAPH-#4D9B, IRGKangXi=1534.070, Def{to separate the meat from the bones with teeth, the sound of using teeth to separate the meat from the bones}
4D9C CJK UNIFIED IDEOGRAPH-#4D9C, IRGKangXi=1534.110, Def{the process to whiten the ivory or elephant tusk; sound of gnawing}
4D9D CJK UNIFIED IDEOGRAPH-#4D9D, IRGKangXi=1534.170, Def{growing irregular teeth; crooked teeth, cleft tooth; sound of gnawing}
4D9E CJK UNIFIED IDEOGRAPH-#4D9E, IRGKangXi=1534.310, Def{to gnaw; to bite}
4D9F CJK UNIFIED IDEOGRAPH-#4D9F, IRGKangXi=1534.330, Def{to gnash the teeth (in anger)}
4DA0 CJK UNIFIED IDEOGRAPH-#4DA0, IRGKangXi=1535.040, Def{(same as 䶢) to gnaw; to bite, to hold in the mouth}
4DA1 CJK UNIFIED IDEOGRAPH-#4DA1, IRGKangXi=1535.130, Def{sound of biting, (same as 齰) to chew; to gnaw}
4DA2 CJK UNIFIED IDEOGRAPH-#4DA2, IRGKangXi=1535.210, Def{to gnaw; to bite, to hold in the mouth}
4DA3 CJK UNIFIED IDEOGRAPH-#4DA3, IRGKangXi=1535.300, Def{to grind the teeth, teeth}
4DA4 CJK UNIFIED IDEOGRAPH-#4DA4, IRGKangXi=1535.381, Def{sound of chewing bones}
4DA5 CJK UNIFIED IDEOGRAPH-#4DA5, IRGKangXi=1535.400, Def{(same as 齟) unevenly-fitting teeth, irregular teeth, resplendent with variegated coloration; bright and colorful}
4DA6 CJK UNIFIED IDEOGRAPH-#4DA6, IRGKangXi=1536.040, Def{upper and lower teeth in order and corresponding each other, to gnaw; to bite}
4DA7 CJK UNIFIED IDEOGRAPH-#4DA7, IRGKangXi=1536.080, Def{(same as U+9F69 咬) to gnaw; to bite}
4DA8 CJK UNIFIED IDEOGRAPH-#4DA8, IRGKangXi=1536.170, Def{in the manner a toothless person chewing food}
4DA9 CJK UNIFIED IDEOGRAPH-#4DA9, IRGKangXi=1536.210, Def{to gnaw; to bite, well-arranged teeth}
4DAA CJK UNIFIED IDEOGRAPH-#4DAA, IRGKangXi=1536.220, Def{sharp teeth; to break something hard like a knife, sand (in food), ugly}
4DAB CJK UNIFIED IDEOGRAPH-#4DAB, IRGKangXi=1536.300, Def{fine teeth, irregular teeth}
4DAC CJK UNIFIED IDEOGRAPH-#4DAC, IRGKangXi=1537.120, Def{hard fins on the back of a dragon}
4DAD CJK UNIFIED IDEOGRAPH-#4DAD, IRGKangXi=1537.251
4DAE CJK UNIFIED IDEOGRAPH-#4DAE, IRGKangXi=1537.251, Def{(simplified form) clever; wise; superior, a person's name (in Earlier Five Dynasties, South Han, meaning flying dragon over the sky)}
4DAF CJK UNIFIED IDEOGRAPH-#4DAF, IRGKangXi=1538.030, Def{used in girl's name}
4DB0 CJK UNIFIED IDEOGRAPH-#4DB0, IRGKangXi=1538.040, Def{feather ornaments}
4DB1 CJK UNIFIED IDEOGRAPH-#4DB1, IRGKangXi=1538.110, Def{a kind of turtle}
4DB2 CJK UNIFIED IDEOGRAPH-#4DB2, IRGKangXi=1538.191, Def{the edge; the hem or the margin of the tortoise shell}
4DB3 CJK UNIFIED IDEOGRAPH-#4DB3, IRGKangXi=1538.260, Def{to lookup, to adore, to rely upon}
4DB4 CJK UNIFIED IDEOGRAPH-#4DB4, IRGKangXi=1538.310, Def{(same as 吹) to blow}
4DB5 CJK UNIFIED IDEOGRAPH-#4DB5, IRGKangXi=1538.400, Def{(same as U+7B8E 箎) a bamboo flute with seven holes}
4DC0 HEXAGRAM FOR THE CREATIVE HEAVEN
4DC1 HEXAGRAM FOR THE RECEPTIVE EARTH
4DC2 HEXAGRAM FOR DIFFICULTY AT THE BEGINNING
4DC3 HEXAGRAM FOR YOUTHFUL FOLLY
4DC4 HEXAGRAM FOR WAITING
4DC5 HEXAGRAM FOR CONFLICT
4DC6 HEXAGRAM FOR THE ARMY
4DC7 HEXAGRAM FOR HOLDING TOGETHER
4DC8 HEXAGRAM FOR SMALL TAMING
4DC9 HEXAGRAM FOR TREADING
4DCA HEXAGRAM FOR PEACE
4DCB HEXAGRAM FOR STANDSTILL
4DCC HEXAGRAM FOR FELLOWSHIP
4DCD HEXAGRAM FOR GREAT POSSESSION
4DCE HEXAGRAM FOR MODESTY
4DCF HEXAGRAM FOR ENTHUSIASM
4DD0 HEXAGRAM FOR FOLLOWING
4DD1 HEXAGRAM FOR WORK ON THE DECAYED
4DD2 HEXAGRAM FOR APPROACH
4DD3 HEXAGRAM FOR CONTEMPLATION
4DD4 HEXAGRAM FOR BITING THROUGH
4DD5 HEXAGRAM FOR GRACE
4DD6 HEXAGRAM FOR SPLITTING APART
4DD7 HEXAGRAM FOR RETURN
4DD8 HEXAGRAM FOR INNOCENCE
4DD9 HEXAGRAM FOR GREAT TAMING
4DDA HEXAGRAM FOR MOUTH CORNERS
4DDB HEXAGRAM FOR GREAT PREPONDERANCE
4DDC HEXAGRAM FOR THE ABYSMAL WATER
4DDD HEXAGRAM FOR THE CLINGING FIRE
4DDE HEXAGRAM FOR INFLUENCE
4DDF HEXAGRAM FOR DURATION
4DE0 HEXAGRAM FOR RETREAT
4DE1 HEXAGRAM FOR GREAT POWER
4DE2 HEXAGRAM FOR PROGRESS
4DE3 HEXAGRAM FOR DARKENING OF THE LIGHT
4DE4 HEXAGRAM FOR THE FAMILY
4DE5 HEXAGRAM FOR OPPOSITION
4DE6 HEXAGRAM FOR OBSTRUCTION
4DE7 HEXAGRAM FOR DELIVERANCE
4DE8 HEXAGRAM FOR DECREASE
4DE9 HEXAGRAM FOR INCREASE
4DEA HEXAGRAM FOR BREAKTHROUGH
4DEB HEXAGRAM FOR COMING TO MEET
4DEC HEXAGRAM FOR GATHERING TOGETHER
4DED HEXAGRAM FOR PUSHING UPWARD
4DEE HEXAGRAM FOR OPPRESSION
4DEF HEXAGRAM FOR THE WELL
4DF0 HEXAGRAM FOR REVOLUTION
4DF1 HEXAGRAM FOR THE CAULDRON
4DF2 HEXAGRAM FOR THE AROUSING THUNDER
4DF3 HEXAGRAM FOR THE KEEPING STILL MOUNTAIN
4DF4 HEXAGRAM FOR DEVELOPMENT
4DF5 HEXAGRAM FOR THE MARRYING MAIDEN
4DF6 HEXAGRAM FOR ABUNDANCE
4DF7 HEXAGRAM FOR THE WANDERER
4DF8 HEXAGRAM FOR THE GENTLE WIND
4DF9 HEXAGRAM FOR THE JOYOUS LAKE
4DFA HEXAGRAM FOR DISPERSION
4DFB HEXAGRAM FOR LIMITATION
4DFC HEXAGRAM FOR INNER TRUTH
4DFD HEXAGRAM FOR SMALL PREPONDERANCE
4DFE HEXAGRAM FOR AFTER COMPLETION
4DFF HEXAGRAM FOR BEFORE COMPLETION
4E00 CJK UNIFIED IDEOGRAPH-#4E00, IRGKangXi=0075.010, RSKangXi=1.0, PrimaryNumeric=1, Def{one; a, an; alone}
4E01 CJK UNIFIED IDEOGRAPH-#4E01, IRGKangXi=0075.030, RSKangXi=1.1, Def{male adult; robust, vigorous; 4th heavenly stem}
4E02 CJK UNIFIED IDEOGRAPH-#4E02, IRGKangXi=0075.050, RSKangXi=1.1, Def{obstruction of breath (qi) as it seeks release; variant of other characters}
4E03 CJK UNIFIED IDEOGRAPH-#4E03, IRGKangXi=0075.070, RSKangXi=1.1, PrimaryNumeric=7, Def{seven}
4E04 CJK UNIFIED IDEOGRAPH-#4E04, IRGKangXi=0076.010, RSKangXi=1.1, Def{above}
4E05 CJK UNIFIED IDEOGRAPH-#4E05, IRGKangXi=0076.020, RSKangXi=1.1, Def{under, underneath, below; down; inferior; bring down; used to transliterate the Latin letter 'T'}
4E06 CJK UNIFIED IDEOGRAPH-#4E06, IRGKangXi=0076.021, RSKangXi=1.1, Def{kwukyel}
4E07 CJK UNIFIED IDEOGRAPH-#4E07, IRGKangXi=0076.030, RSKangXi=1.2, PrimaryNumeric=10000, Def{ten thousand; innumerable}
4E08 CJK UNIFIED IDEOGRAPH-#4E08, IRGKangXi=0076.040, RSKangXi=1.2, Def{unit of length equal 3.3 meters; gentleman, man, husband}
4E09 CJK UNIFIED IDEOGRAPH-#4E09, IRGKangXi=0076.050, RSKangXi=1.2, PrimaryNumeric=3, Def{three}
4E0A CJK UNIFIED IDEOGRAPH-#4E0A, IRGKangXi=0076.070, RSKangXi=1.2, Def{top; superior, highest; go up, send up}
4E0B CJK UNIFIED IDEOGRAPH-#4E0B, IRGKangXi=0076.100, RSKangXi=1.2, Def{under, underneath, below; down; inferior; bring down}
4E0C CJK UNIFIED IDEOGRAPH-#4E0C, IRGKangXi=0076.130, RSKangXi=1.2, Def{table}
4E0D CJK UNIFIED IDEOGRAPH-#4E0D, IRGKangXi=0076.150, RSKangXi=1.3, Def{no, not; un-; negative prefix}
4E0E CJK UNIFIED IDEOGRAPH-#4E0E, IRGKangXi=0077.010, RSKangXi=1.3, Def{and; with; to; for; give, grant}
4E0F CJK UNIFIED IDEOGRAPH-#4E0F, IRGKangXi=0077.020, RSKangXi=1.3, Def{parapet; invisible}
4E10 CJK UNIFIED IDEOGRAPH-#4E10, IRGKangXi=0077.030, RSKangXi=1.3, Def{beggar; beg; give}
4E11 CJK UNIFIED IDEOGRAPH-#4E11, IRGKangXi=0077.040, RSKangXi=1.3, Def{clown, comedian; 2nd terrestrial branch}
4E12 CJK UNIFIED IDEOGRAPH-#4E12, IRGKangXi=0077.061, RSKangXi=1.3, Def{the period from 1 to 3 a.m.; 2nd character of the 'branches'}
4E13 CJK UNIFIED IDEOGRAPH-#4E13, IRGKangXi=0077.061, RSKangXi=1.3, Def{monopolize, take sole possession}
4E14 CJK UNIFIED IDEOGRAPH-#4E14, IRGKangXi=0077.070, RSKangXi=1.4, Def{moreover, also (post-subject); about to, will soon (pre-verb)}
4E15 CJK UNIFIED IDEOGRAPH-#4E15, IRGKangXi=0077.100, RSKangXi=1.4, Def{great, grand, glorious, distinguished}
4E16 CJK UNIFIED IDEOGRAPH-#4E16, IRGKangXi=0077.110, RSKangXi=1.4, Def{generation; world; era}
4E17 CJK UNIFIED IDEOGRAPH-#4E17, IRGKangXi=0078.021, RSKangXi=1.3, Def{thirty, thirtieth}
4E18 CJK UNIFIED IDEOGRAPH-#4E18, IRGKangXi=0077.140, RSKangXi=1.4, Def{hill; elder; empty; a name}
4E19 CJK UNIFIED IDEOGRAPH-#4E19, IRGKangXi=0078.020, RSKangXi=1.4, Def{third; 3rd heavenly stem}
4E1A CJK UNIFIED IDEOGRAPH-#4E1A, IRGKangXi=0078.021, RSKangXi=1.4, Def{profession, business; GB radical 111}
4E1B CJK UNIFIED IDEOGRAPH-#4E1B, IRGKangXi=0078.021, RSKangXi=1.4, Def{bush, shrub; thicket; collection}
4E1C CJK UNIFIED IDEOGRAPH-#4E1C, IRGKangXi=0078.021, RSKangXi=1.4, Def{east, eastern, eastward}
4E1D CJK UNIFIED IDEOGRAPH-#4E1D, IRGKangXi=0078.021, RSKangXi=1.4, Def{silk; fine thread; wire; strings}
4E1E CJK UNIFIED IDEOGRAPH-#4E1E, IRGKangXi=0078.050, RSKangXi=1.5, Def{assist, aid, rescue}
4E1F CJK UNIFIED IDEOGRAPH-#4E1F, IRGKangXi=0078.060, RSKangXi=1.5, Def{discard, reject, lose}
4E20 CJK UNIFIED IDEOGRAPH-#4E20, IRGKangXi=0078.100, Def{hill; elder; empty; a name}
4E21 CJK UNIFIED IDEOGRAPH-#4E21, IRGKangXi=0078.101, RSKangXi=1.5, Def{two, both, pair, couple; a tael, ounce}
4E22 CJK UNIFIED IDEOGRAPH-#4E22, IRGKangXi=0078.101, RSKangXi=1.5, Def{discard}
4E23 CJK UNIFIED IDEOGRAPH-#4E23, IRGKangXi=0078.110, RSKangXi=1.6, Def{ancient form of the tenth of the twelve Terrestrial Branches, U+9149 酉}
4E24 CJK UNIFIED IDEOGRAPH-#4E24, IRGKangXi=0078.131, RSKangXi=1.6, Def{two, both, pair, couple; ounce}
4E25 CJK UNIFIED IDEOGRAPH-#4E25, IRGKangXi=0078.131, RSKangXi=1.6, Def{strict, rigorous, rigid; stern}
4E26 CJK UNIFIED IDEOGRAPH-#4E26, IRGKangXi=0078.140, RSKangXi=1.7, Def{equal to; side by side; also, what is more; both}
4E27 CJK UNIFIED IDEOGRAPH-#4E27, IRGKangXi=0078.171, RSKangXi=24.6, Def{mourning; mourn; funeral}
4E28 CJK UNIFIED IDEOGRAPH-#4E28, IRGKangXi=0078.200, RSKangXi=2.0, Def{(same as U+3021 HANGZHOU NUMERAL ONE 〡) number one; line; KangXi radical 2}
4E29 CJK UNIFIED IDEOGRAPH-#4E29, IRGKangXi=0078.210, Def{to join or connect the vine}
4E2A CJK UNIFIED IDEOGRAPH-#4E2A, IRGKangXi=0078.230, RSKangXi=2.2, Def{numerary adjunct, piece; single}
4E2B CJK UNIFIED IDEOGRAPH-#4E2B, IRGKangXi=0079.010, RSKangXi=2.2, Def{forked; bifurcation}
4E2C CJK UNIFIED IDEOGRAPH-#4E2C, IRGKangXi=0079.021, RSKangXi=90.0, Def{half of tree trunk; rad. no. 90}
4E2D CJK UNIFIED IDEOGRAPH-#4E2D, IRGKangXi=0079.030, RSKangXi=2.3, Def{central; center, middle; in the midst of; hit (target); attain}
4E2E CJK UNIFIED IDEOGRAPH-#4E2E, IRGKangXi=0079.060, RSKangXi=2.3, Def{catch}
4E2F CJK UNIFIED IDEOGRAPH-#4E2F, IRGKangXi=0079.070, RSKangXi=2.3, Def{dense}
4E30 CJK UNIFIED IDEOGRAPH-#4E30, IRGKangXi=0079.080, RSKangXi=2.3, Def{abundant, lush, bountiful, plenty}
4E31 CJK UNIFIED IDEOGRAPH-#4E31, IRGKangXi=0079.100, RSKangXi=2.4, Def{child's hairstyle bound in two tufts; ore}
4E32 CJK UNIFIED IDEOGRAPH-#4E32, IRGKangXi=0080.020, RSKangXi=2.6, Def{string; relatives; conspire}
4E33 CJK UNIFIED IDEOGRAPH-#4E33, IRGKangXi=0080.040, RSKangXi=2.7, Def{spit, grill; a skewer}
4E34 CJK UNIFIED IDEOGRAPH-#4E34, IRGKangXi=0080.071, RSKangXi=2.8, Def{draw near, approach; descend}
4E35 CJK UNIFIED IDEOGRAPH-#4E35, IRGKangXi=0080.080, RSKangXi=2.9, Def{thick (grass)}
4E36 CJK UNIFIED IDEOGRAPH-#4E36, IRGKangXi=0080.120, RSKangXi=3.0, Def{dot; KangXi radical 3}
4E37 CJK UNIFIED IDEOGRAPH-#4E37, IRGKangXi=0080.121, RSKangXi=3.1, Def{kwukyel}
4E38 CJK UNIFIED IDEOGRAPH-#4E38, IRGKangXi=0080.150, RSKangXi=3.2, Def{small round object; pellet, pill}
4E39 CJK UNIFIED IDEOGRAPH-#4E39, IRGKangXi=0080.160, RSKangXi=3.3, Def{cinnabar (native HgS); vermilion (artificial HgS used as pigment)}
4E3A CJK UNIFIED IDEOGRAPH-#4E3A, IRGKangXi=0080.191, RSKangXi=3.3, Def{do, handle, govern, act; be}
4E3B CJK UNIFIED IDEOGRAPH-#4E3B, IRGKangXi=0080.200, RSKangXi=3.4, Def{master, chief owner; host; lord}
4E3C CJK UNIFIED IDEOGRAPH-#4E3C, IRGKangXi=0081.010, RSKangXi=3.4, Def{bowl of food; well}
4E3D CJK UNIFIED IDEOGRAPH-#4E3D, IRGKangXi=0081.040, RSKangXi=3.7, Def{beautiful, magnificent, elegant}
4E3E CJK UNIFIED IDEOGRAPH-#4E3E, IRGKangXi=0081.041, RSKangXi=3.8, Def{raise, lift up; recommend}
4E3F CJK UNIFIED IDEOGRAPH-#4E3F, IRGKangXi=0081.060, RSKangXi=4.0, Def{line; KangXi radical 4}
4E40 CJK UNIFIED IDEOGRAPH-#4E40, IRGKangXi=0081.070, RSKangXi=4.0, Def{stretch}
4E41 CJK UNIFIED IDEOGRAPH-#4E41, IRGKangXi=0081.090, RSKangXi=4.0
4E42 CJK UNIFIED IDEOGRAPH-#4E42, IRGKangXi=0081.100, RSKangXi=4.1, Def{govern, control, manage; nurture}
4E43 CJK UNIFIED IDEOGRAPH-#4E43, IRGKangXi=0081.120, RSKangXi=4.1, Def{then; really, indeed; as it turned out, after all; namely}
4E44 CJK UNIFIED IDEOGRAPH-#4E44, IRGKangXi=0081.181, RSKangXi=4.1, Def{SHIME: to find a place to dwell; sum; a measurement of paper; SHITE to do; (not to be confused with U3024 HANGZHOU NUMERAL FIVE)}
4E45 CJK UNIFIED IDEOGRAPH-#4E45, IRGKangXi=0081.190, RSKangXi=4.2, Def{long time (ago); time passage, grow late}
4E46 CJK UNIFIED IDEOGRAPH-#4E46, IRGKangXi=0082.010, Def{long time (ago); time passage, grow late}
4E47 CJK UNIFIED IDEOGRAPH-#4E47, IRGKangXi=0082.020, RSKangXi=4.2, Def{to depend on, to entrust with}
4E48 CJK UNIFIED IDEOGRAPH-#4E48, IRGKangXi=0082.030, RSKangXi=4.2, Def{interrogative particle; repetition of a tune small; tender}
4E49 CJK UNIFIED IDEOGRAPH-#4E49, IRGKangXi=0082.031, RSKangXi=4.2, Def{right conduct, righteousness}
4E4A CJK UNIFIED IDEOGRAPH-#4E4A, IRGKangXi=0082.031, RSKangXi=4.2, Def{kwukyel}
4E4B CJK UNIFIED IDEOGRAPH-#4E4B, IRGKangXi=0082.040, RSKangXi=4.3, Def{marks preceding phrase as modifier of following phrase; it, him her, them; go to}
4E4C CJK UNIFIED IDEOGRAPH-#4E4C, IRGKangXi=0082.051, RSKangXi=4.3, Def{crow, rook, raven; black, dark}
4E4D CJK UNIFIED IDEOGRAPH-#4E4D, IRGKangXi=0082.060, RSKangXi=4.4, Def{first time, for the first time}
4E4E CJK UNIFIED IDEOGRAPH-#4E4E, IRGKangXi=0082.070, RSKangXi=4.4, Def{interrogative or exclamatory final particle}
4E4F CJK UNIFIED IDEOGRAPH-#4E4F, IRGKangXi=0082.100, RSKangXi=4.4, Def{lack; poor}
4E50 CJK UNIFIED IDEOGRAPH-#4E50, IRGKangXi=0082.131, RSKangXi=4.4, Def{happy, glad; enjoyable; music}
4E51 CJK UNIFIED IDEOGRAPH-#4E51, IRGKangXi=0082.150, RSKangXi=4.5, Def{stand side by side}
4E52 CJK UNIFIED IDEOGRAPH-#4E52, IRGKangXi=0083.011, RSKangXi=4.5, Def{used with pong for ping pong}
4E53 CJK UNIFIED IDEOGRAPH-#4E53, IRGKangXi=0083.011, RSKangXi=4.5, Def{used with ping for ping pong}
4E54 CJK UNIFIED IDEOGRAPH-#4E54, IRGKangXi=0083.011, RSKangXi=37.3, Def{tall, lofty; proud, stately}
4E55 CJK UNIFIED IDEOGRAPH-#4E55, IRGKangXi=0083.021, RSKangXi=4.6, Def{tiger; brave, fierce; surname}
4E56 CJK UNIFIED IDEOGRAPH-#4E56, IRGKangXi=0083.030, RSKangXi=4.7, Def{rebel; crafty, shrewd}
4E57 CJK UNIFIED IDEOGRAPH-#4E57, IRGKangXi=0083.081, RSKangXi=4.8, Def{ride, ascend; avail oneself of; numerary adjunct for vehicles}
4E58 CJK UNIFIED IDEOGRAPH-#4E58, IRGKangXi=0083.090, RSKangXi=4.9, Def{ride, ascend; avail oneself of; numerary adjunct for vehicles}
4E59 CJK UNIFIED IDEOGRAPH-#4E59, IRGKangXi=0083.150, RSKangXi=5.0, Def{second; 2nd heavenly stem}
4E5A CJK UNIFIED IDEOGRAPH-#4E5A, IRGKangXi=0083.170, RSKangXi=5.0, Def{hidden, mysterious, secret; to conceal; small; minute}
4E5B CJK UNIFIED IDEOGRAPH-#4E5B, IRGKangXi=0083.171, RSKangXi=5.0, Def{kwukyel}
4E5C CJK UNIFIED IDEOGRAPH-#4E5C, IRGKangXi=0083.180, RSKangXi=5.1, Def{to squint; (Cant.) what? huh?}
4E5D CJK UNIFIED IDEOGRAPH-#4E5D, IRGKangXi=0083.190, RSKangXi=5.1, PrimaryNumeric=9, Def{nine}
4E5E CJK UNIFIED IDEOGRAPH-#4E5E, IRGKangXi=0084.030, RSKangXi=5.2, Def{beg; request}
4E5F CJK UNIFIED IDEOGRAPH-#4E5F, IRGKangXi=0084.040, RSKangXi=5.2, Def{also; classical final particle of strong affirmation or identity}
4E60 CJK UNIFIED IDEOGRAPH-#4E60, IRGKangXi=0084.051, RSKangXi=15.1, Def{practice; flapping wings}
4E61 CJK UNIFIED IDEOGRAPH-#4E61, IRGKangXi=0084.051, RSKangXi=52.0, Def{country; rural; village}
4E62 CJK UNIFIED IDEOGRAPH-#4E62, IRGKangXi=0307.021, RSKangXi=5.3, Def{lid, to cover; to hide; a cover; an umbrella}
4E63 CJK UNIFIED IDEOGRAPH-#4E63, IRGKangXi=0084.071, RSKangXi=5.3
4E64 CJK UNIFIED IDEOGRAPH-#4E64, IRGKangXi=0084.071, RSKangXi=5.3, Def{first character of Korean place name 'Halpho'}
4E65 CJK UNIFIED IDEOGRAPH-#4E65, IRGKangXi=0084.071, RSKangXi=5.3, Def{kwukyel}
4E66 CJK UNIFIED IDEOGRAPH-#4E66, IRGKangXi=0084.071, RSKangXi=2.3, Def{book, letter, document; writings}
4E67 CJK UNIFIED IDEOGRAPH-#4E67, IRGKangXi=0084.101, RSKangXi=5.4
4E68 CJK UNIFIED IDEOGRAPH-#4E68, IRGKangXi=0084.110, RSKangXi=5.5, Def{the beginning; to start, to begin, to be the first}
4E69 CJK UNIFIED IDEOGRAPH-#4E69, IRGKangXi=0084.120, RSKangXi=5.5, Def{to divine}
4E6A CJK UNIFIED IDEOGRAPH-#4E6A, IRGKangXi=0084.141, RSKangXi=5.5, Def{(Cant.) a bend in a river}
4E6B CJK UNIFIED IDEOGRAPH-#4E6B, IRGKangXi=0084.141, RSKangXi=5.5, Def{used in Korean place names}
4E6C CJK UNIFIED IDEOGRAPH-#4E6C, IRGKangXi=0084.141, RSKangXi=5.5, Def{to hang}
4E6D CJK UNIFIED IDEOGRAPH-#4E6D, IRGKangXi=0084.141, RSKangXi=5.5, Def{rock; used in Korean names}
4E6E CJK UNIFIED IDEOGRAPH-#4E6E, IRGKangXi=0084.141, RSKangXi=5.5
4E6F CJK UNIFIED IDEOGRAPH-#4E6F, IRGKangXi=0084.141, RSKangXi=5.5
4E70 CJK UNIFIED IDEOGRAPH-#4E70, IRGKangXi=0084.141, RSKangXi=37.3, Def{buy, purchase; bribe, persuade}
4E71 CJK UNIFIED IDEOGRAPH-#4E71, IRGKangXi=0084.150, RSKangXi=5.6, Def{confusion, state of chaos, revolt}
4E72 CJK UNIFIED IDEOGRAPH-#4E72, IRGKangXi=0084.161, RSKangXi=5.6
4E73 CJK UNIFIED IDEOGRAPH-#4E73, IRGKangXi=0084.170, RSKangXi=5.7, Def{breast, nipples; milk, suckle}
4E74 CJK UNIFIED IDEOGRAPH-#4E74, IRGKangXi=0084.180, RSKangXi=5.7
4E75 CJK UNIFIED IDEOGRAPH-#4E75, IRGKangXi=0084.190, RSKangXi=5.7, Def{to enter; to make progress to advance; to urge forward}
4E76 CJK UNIFIED IDEOGRAPH-#4E76, IRGKangXi=0084.201, RSKangXi=5.7, Def{Korean place name Pholha}
4E77 CJK UNIFIED IDEOGRAPH-#4E77, IRGKangXi=0084.201, RSKangXi=5.7
4E78 CJK UNIFIED IDEOGRAPH-#4E78, IRGKangXi=0084.201, RSKangXi=80.3, Def{(Cant.) feminine suffix}
4E79 CJK UNIFIED IDEOGRAPH-#4E79, IRGKangXi=0084.210, RSKangXi=5.8, Def{(Cant.) to clean; dried up}
4E7A CJK UNIFIED IDEOGRAPH-#4E7A, IRGKangXi=0084.241, RSKangXi=5.8, Def{painting tool place name}
4E7B CJK UNIFIED IDEOGRAPH-#4E7B, IRGKangXi=0084.241, RSKangXi=5.8
4E7C CJK UNIFIED IDEOGRAPH-#4E7C, IRGKangXi=0084.241, RSKangXi=5.8, Def{rope}
4E7D CJK UNIFIED IDEOGRAPH-#4E7D, IRGKangXi=0084.241, RSKangXi=5.9
4E7E CJK UNIFIED IDEOGRAPH-#4E7E, IRGKangXi=0084.250, RSKangXi=5.10, Def{dry; first hexagram; warming principle of the sun, penetrating and fertilizing, heavenly generative principle (male)}
4E7F CJK UNIFIED IDEOGRAPH-#4E7F, IRGKangXi=0084.280, RSKangXi=5.10, Def{to cure, to heal}
4E80 CJK UNIFIED IDEOGRAPH-#4E80, IRGKangXi=0142.281, RSKangXi=213.0, Def{turtle or tortoise; cuckold}
4E81 CJK UNIFIED IDEOGRAPH-#4E81, IRGKangXi=0084.321, RSKangXi=5.11, Def{dry; dried, as opposed to fresh}
4E82 CJK UNIFIED IDEOGRAPH-#4E82, IRGKangXi=0084.330, RSKangXi=5.12, Def{confusion, state of chaos; create chaos, revolt}
4E83 CJK UNIFIED IDEOGRAPH-#4E83, IRGKangXi=0085.010, RSKangXi=5.12, Def{name of a kind of animal}
4E84 CJK UNIFIED IDEOGRAPH-#4E84, IRGKangXi=0085.020, RSKangXi=5.12, Def{greedy, stingy}
4E85 CJK UNIFIED IDEOGRAPH-#4E85, IRGKangXi=0085.090, RSKangXi=6.0, Def{hook; KangXi radical 6}
4E86 CJK UNIFIED IDEOGRAPH-#4E86, IRGKangXi=0085.110, RSKangXi=6.1, Def{to finish; particle of completed action}
4E87 CJK UNIFIED IDEOGRAPH-#4E87, IRGKangXi=0085.151, RSKangXi=4.2, Def{kwukyel hammer}
4E88 CJK UNIFIED IDEOGRAPH-#4E88, IRGKangXi=0085.160, RSKangXi=6.3, Def{I, me; to give}
4E89 CJK UNIFIED IDEOGRAPH-#4E89, IRGKangXi=0137.301, RSKangXi=6.5, Def{dispute, fight, contend, strive}
4E8A CJK UNIFIED IDEOGRAPH-#4E8A, IRGKangXi=0085.221, RSKangXi=6.6, Def{affair, matter, business; to serve; accident, incident}
4E8B CJK UNIFIED IDEOGRAPH-#4E8B, IRGKangXi=0085.240, RSKangXi=6.7, Def{affair, matter, business; to serve; accident, incident}
4E8C CJK UNIFIED IDEOGRAPH-#4E8C, IRGKangXi=0086.010, RSKangXi=7.0, PrimaryNumeric=2, Def{two; twice}
4E8D CJK UNIFIED IDEOGRAPH-#4E8D, IRGKangXi=0086.050, RSKangXi=7.1, Def{to take small steps; Korean place name}
4E8E CJK UNIFIED IDEOGRAPH-#4E8E, IRGKangXi=0086.060, RSKangXi=7.1, Def{in, on, at; go to; surname}
4E8F CJK UNIFIED IDEOGRAPH-#4E8F, IRGKangXi=0086.070, RSKangXi=7.1, Def{lose, fail; damage; deficient}
4E90 CJK UNIFIED IDEOGRAPH-#4E90, IRGKangXi=0086.071, RSKangXi=7.1
4E91 CJK UNIFIED IDEOGRAPH-#4E91, IRGKangXi=0086.080, RSKangXi=7.2, Def{say, speak; clouds}
4E92 CJK UNIFIED IDEOGRAPH-#4E92, IRGKangXi=0086.090, RSKangXi=7.2, Def{mutually, reciprocally}
4E93 CJK UNIFIED IDEOGRAPH-#4E93, IRGKangXi=0086.100, RSKangXi=7.2, Def{(archaic form) his, her, its, their; that}
4E94 CJK UNIFIED IDEOGRAPH-#4E94, IRGKangXi=0086.110, RSKangXi=7.2, PrimaryNumeric=5, Def{five; surname}
4E95 CJK UNIFIED IDEOGRAPH-#4E95, IRGKangXi=0086.140, RSKangXi=7.2, Def{well, mine shaft, pit}
4E96 CJK UNIFIED IDEOGRAPH-#4E96, IRGKangXi=0087.010, RSKangXi=7.2, Def{four}
4E97 CJK UNIFIED IDEOGRAPH-#4E97, IRGKangXi=0087.030, RSKangXi=7.3, Def{harvest; year; age}
4E98 CJK UNIFIED IDEOGRAPH-#4E98, IRGKangXi=0087.040, RSKangXi=7.4, Def{extend across, through; from}
4E99 CJK UNIFIED IDEOGRAPH-#4E99, IRGKangXi=0087.070, RSKangXi=7.4, Def{extend across, through; from}
4E9A CJK UNIFIED IDEOGRAPH-#4E9A, IRGKangXi=0087.081, RSKangXi=1.5, Def{Asia; second}
4E9B CJK UNIFIED IDEOGRAPH-#4E9B, IRGKangXi=0087.100, RSKangXi=7.5, Def{little, few; rather, somewhat}
4E9C CJK UNIFIED IDEOGRAPH-#4E9C, IRGKangXi=0087.111, RSKangXi=7.5, Def{Asia; second}
4E9D CJK UNIFIED IDEOGRAPH-#4E9D, IRGKangXi=0087.120, RSKangXi=7.6, Def{even, regular, uniform all alike; to arrange}
4E9E CJK UNIFIED IDEOGRAPH-#4E9E, IRGKangXi=0087.130, RSKangXi=7.6, Def{Asia; second; used as a prefix to names}
4E9F CJK UNIFIED IDEOGRAPH-#4E9F, IRGKangXi=0087.140, RSKangXi=7.6, Def{urgently, immediately, extremely}
4EA0 CJK UNIFIED IDEOGRAPH-#4EA0, IRGKangXi=0088.020, RSKangXi=8.0, Def{head; KangXi radical 8}
4EA1 CJK UNIFIED IDEOGRAPH-#4EA1, IRGKangXi=0088.030, RSKangXi=8.1, Def{death, destroyed; lose, perish}
4EA2 CJK UNIFIED IDEOGRAPH-#4EA2, IRGKangXi=0088.040, RSKangXi=8.2, Def{high, proud; violent, excessive; skilled; name}
4EA3 CJK UNIFIED IDEOGRAPH-#4EA3, IRGKangXi=0088.050, RSKangXi=8.2
4EA4 CJK UNIFIED IDEOGRAPH-#4EA4, IRGKangXi=0088.060, RSKangXi=8.4, Def{mix; intersect; exchange, communicate; deliver}
4EA5 CJK UNIFIED IDEOGRAPH-#4EA5, IRGKangXi=0088.080, RSKangXi=8.4, Def{12th terrestrial branch}
4EA6 CJK UNIFIED IDEOGRAPH-#4EA6, IRGKangXi=0088.090, RSKangXi=8.4, Def{also, too; likewise}
4EA7 CJK UNIFIED IDEOGRAPH-#4EA7, IRGKangXi=0088.111, RSKangXi=117.1, Def{give birth, bring forth, produce}
4EA8 CJK UNIFIED IDEOGRAPH-#4EA8, IRGKangXi=0088.120, RSKangXi=8.5, Def{smoothly, progressing, no trouble}
4EA9 CJK UNIFIED IDEOGRAPH-#4EA9, IRGKangXi=0088.161, RSKangXi=8.5, Def{Chinese land measure; fields}
4EAA CJK UNIFIED IDEOGRAPH-#4EAA, IRGKangXi=0088.161, RSKangXi=8.5, Def{kwukyel}
4EAB CJK UNIFIED IDEOGRAPH-#4EAB, IRGKangXi=0088.170, RSKangXi=8.6, Def{enjoy}
4EAC CJK UNIFIED IDEOGRAPH-#4EAC, IRGKangXi=0088.190, RSKangXi=8.6, Def{capital city}
4EAD CJK UNIFIED IDEOGRAPH-#4EAD, IRGKangXi=0089.030, RSKangXi=8.7, Def{pavilion; erect}
4EAE CJK UNIFIED IDEOGRAPH-#4EAE, IRGKangXi=0089.040, RSKangXi=8.7, Def{bright, brilliant, radiant, light}
4EAF CJK UNIFIED IDEOGRAPH-#4EAF, IRGKangXi=0089.050, RSKangXi=8.7, Def{to receive; to enjoy}
4EB0 CJK UNIFIED IDEOGRAPH-#4EB0, IRGKangXi=0089.070, RSKangXi=8.7, Def{capital city}
4EB1 CJK UNIFIED IDEOGRAPH-#4EB1, IRGKangXi=0089.081, Def{night, dark; in night; by night}
4EB2 CJK UNIFIED IDEOGRAPH-#4EB2, IRGKangXi=0089.081, RSKangXi=117.4, Def{relatives, parents; intimate the hazel nut or filbert tree a thorny tree}
4EB3 CJK UNIFIED IDEOGRAPH-#4EB3, IRGKangXi=0089.090, RSKangXi=8.8, Def{name of district in Anhui; capital of Yin}
4EB4 CJK UNIFIED IDEOGRAPH-#4EB4, IRGKangXi=0089.190, RSKangXi=8.10
4EB5 CJK UNIFIED IDEOGRAPH-#4EB5, IRGKangXi=1116.341, RSKangXi=8.10, Def{slight, insult, treat with disrespect}
4EB6 CJK UNIFIED IDEOGRAPH-#4EB6, IRGKangXi=0089.200, RSKangXi=8.11, Def{sincere; real, true; truth}
4EB7 CJK UNIFIED IDEOGRAPH-#4EB7, IRGKangXi=0089.201, Def{upright, honorable, honest}
4EB8 CJK UNIFIED IDEOGRAPH-#4EB8, IRGKangXi=0089.241, RSKangXi=30.13, Def{read aloud, recite, chant; droop}
4EB9 CJK UNIFIED IDEOGRAPH-#4EB9, IRGKangXi=0090.010, RSKangXi=8.19, Def{progress; busy, untiring; exert}
4EBA CJK UNIFIED IDEOGRAPH-#4EBA, IRGKangXi=0091.010, RSKangXi=9.0, Def{man; people; mankind; someone else}
4EBB CJK UNIFIED IDEOGRAPH-#4EBB, IRGKangXi=0091.011, RSKangXi=9.0, Def{radical number 9}
4EBC CJK UNIFIED IDEOGRAPH-#4EBC, IRGKangXi=0091.030, RSKangXi=9.1, Def{to assemble. to gather together}
4EBD CJK UNIFIED IDEOGRAPH-#4EBD, IRGKangXi=0091.051, RSKangXi=9.1, Def{kwukyel}
4EBE CJK UNIFIED IDEOGRAPH-#4EBE, IRGKangXi=0091.051, Def{death, destroyed; lose, perish}
4EBF CJK UNIFIED IDEOGRAPH-#4EBF, IRGKangXi=0091.051, RSKangXi=9.1, PrimaryNumeric=100000000, Def{hundred million; many}
4EC0 CJK UNIFIED IDEOGRAPH-#4EC0, IRGKangXi=0091.060, RSKangXi=9.2, Def{file of ten soldiers; mixed, miscellaneous}
4EC1 CJK UNIFIED IDEOGRAPH-#4EC1, IRGKangXi=0091.070, RSKangXi=9.2, Def{humaneness, benevolence, kindness}
4EC2 CJK UNIFIED IDEOGRAPH-#4EC2, IRGKangXi=0091.100, RSKangXi=9.2, Def{surplus or excess; remainder}
4EC3 CJK UNIFIED IDEOGRAPH-#4EC3, IRGKangXi=0091.110, RSKangXi=9.2, Def{lonely, solitary}
4EC4 CJK UNIFIED IDEOGRAPH-#4EC4, IRGKangXi=0091.120, RSKangXi=9.2, Def{slanting, oblique; oblique tones}
4EC5 CJK UNIFIED IDEOGRAPH-#4EC5, IRGKangXi=0091.130, RSKangXi=9.2, Def{only, merely, solely, just}
4EC6 CJK UNIFIED IDEOGRAPH-#4EC6, IRGKangXi=0091.140, RSKangXi=9.2, Def{fall forward; lie prostrate, prone; servant}
4EC7 CJK UNIFIED IDEOGRAPH-#4EC7, IRGKangXi=0091.150, RSKangXi=9.2, Def{enemy, hate, hatred, enmity}
4EC8 CJK UNIFIED IDEOGRAPH-#4EC8, IRGKangXi=0091.160, RSKangXi=9.2
4EC9 CJK UNIFIED IDEOGRAPH-#4EC9, IRGKangXi=0091.170, RSKangXi=9.2, Def{surname of the mother of Mencius}
4ECA CJK UNIFIED IDEOGRAPH-#4ECA, IRGKangXi=0091.180, RSKangXi=9.2, Def{now, today, modern era}
4ECB CJK UNIFIED IDEOGRAPH-#4ECB, IRGKangXi=0091.190, RSKangXi=9.2, Def{forerunner, herald, harbinger; to lie between; sea shell; to wear armor}
4ECC CJK UNIFIED IDEOGRAPH-#4ECC, IRGKangXi=0092.010, RSKangXi=9.2
4ECD CJK UNIFIED IDEOGRAPH-#4ECD, IRGKangXi=0092.020, RSKangXi=9.2, Def{yet, still, as ever; again; keep -ing, continuing}
4ECE CJK UNIFIED IDEOGRAPH-#4ECE, IRGKangXi=0092.030, RSKangXi=9.2, Def{from, by, since, whence, through}
4ECF CJK UNIFIED IDEOGRAPH-#4ECF, IRGKangXi=0092.050, RSKangXi=9.2, Def{Buddha}
4ED0 CJK UNIFIED IDEOGRAPH-#4ED0, IRGKangXi=0092.051, RSKangXi=9.2, Def{(J) non-standard form of 傘 U+5098, umbrella, parasol, parachute}
4ED1 CJK UNIFIED IDEOGRAPH-#4ED1, IRGKangXi=0092.051, RSKangXi=9.2, Def{logical reasons, logical order}
4ED2 CJK UNIFIED IDEOGRAPH-#4ED2, IRGKangXi=0092.051, RSKangXi=9.2, Def{kwukyel}
4ED3 CJK UNIFIED IDEOGRAPH-#4ED3, IRGKangXi=0092.051, RSKangXi=9.2, Def{granary; berth; sea}
4ED4 CJK UNIFIED IDEOGRAPH-#4ED4, IRGKangXi=0092.060, RSKangXi=9.3, Def{small thing, child; young animal}
4ED5 CJK UNIFIED IDEOGRAPH-#4ED5, IRGKangXi=0092.070, RSKangXi=9.3, Def{official; serve government}
4ED6 CJK UNIFIED IDEOGRAPH-#4ED6, IRGKangXi=0092.090, RSKangXi=9.3, Def{other, another; he, she, it}
4ED7 CJK UNIFIED IDEOGRAPH-#4ED7, IRGKangXi=0092.100, RSKangXi=9.3, Def{rely upon; protector; fight; war, weaponry}
4ED8 CJK UNIFIED IDEOGRAPH-#4ED8, IRGKangXi=0092.120, RSKangXi=9.3, Def{give, deliver, pay, hand over; entrust}
4ED9 CJK UNIFIED IDEOGRAPH-#4ED9, IRGKangXi=0092.130, RSKangXi=9.3, Def{Taoist super-being, transcendent, immortal}
4EDA CJK UNIFIED IDEOGRAPH-#4EDA, IRGKangXi=0092.140, RSKangXi=9.3, Def{to fly}
4EDB CJK UNIFIED IDEOGRAPH-#4EDB, IRGKangXi=0093.010, RSKangXi=9.3, Def{young girl; strange, different}
4EDC CJK UNIFIED IDEOGRAPH-#4EDC, IRGKangXi=0093.020, RSKangXi=9.3
4EDD CJK UNIFIED IDEOGRAPH-#4EDD, IRGKangXi=0093.030, RSKangXi=9.3, Def{together, same; surname}
4EDE CJK UNIFIED IDEOGRAPH-#4EDE, IRGKangXi=0093.040, RSKangXi=9.3, Def{ancient unit of measure (8 feet); 'fathom'}
4EDF CJK UNIFIED IDEOGRAPH-#4EDF, IRGKangXi=0093.050, RSKangXi=9.3, AccountingNumeric=1000, Def{one thousand; leader of one thousand men}
4EE0 CJK UNIFIED IDEOGRAPH-#4EE0, IRGKangXi=0093.060, RSKangXi=9.3
4EE1 CJK UNIFIED IDEOGRAPH-#4EE1, IRGKangXi=0093.070, RSKangXi=9.3, Def{strong; valiant}
4EE2 CJK UNIFIED IDEOGRAPH-#4EE2, IRGKangXi=0093.100, RSKangXi=9.3
4EE3 CJK UNIFIED IDEOGRAPH-#4EE3, IRGKangXi=0093.110, RSKangXi=9.3, Def{replace, replacement (of person or generation); era, generation}
4EE4 CJK UNIFIED IDEOGRAPH-#4EE4, IRGKangXi=0093.120, RSKangXi=9.3, Def{command, order; 'commandant', magistrate; allow, cause}
4EE5 CJK UNIFIED IDEOGRAPH-#4EE5, IRGKangXi=0094.010, RSKangXi=9.3, Def{by means of; thereby, therefore; consider as; in order to}
4EE6 CJK UNIFIED IDEOGRAPH-#4EE6, IRGKangXi=0094.051, RSKangXi=9.3
4EE7 CJK UNIFIED IDEOGRAPH-#4EE7, IRGKangXi=0094.051, RSKangXi=9.3
4EE8 CJK UNIFIED IDEOGRAPH-#4EE8, IRGKangXi=0094.051, RSKangXi=9.3, Def{(coll.) three (cannot be followed by a measure word)}
4EE9 CJK UNIFIED IDEOGRAPH-#4EE9, IRGKangXi=0094.051, RSKangXi=9.3
4EEA CJK UNIFIED IDEOGRAPH-#4EEA, IRGKangXi=0094.051, RSKangXi=9.3, Def{ceremony, rites gifts; admire}
4EEB CJK UNIFIED IDEOGRAPH-#4EEB, IRGKangXi=0094.051, RSKangXi=9.3, Def{tribe}
4EEC CJK UNIFIED IDEOGRAPH-#4EEC, IRGKangXi=0094.051, RSKangXi=9.3, Def{adjunct pronoun indicate plural}
4EED CJK UNIFIED IDEOGRAPH-#4EED, IRGKangXi=0094.051, RSKangXi=9.3, Def{ancient unit of measure (8 feet); 'fathom'}
4EEE CJK UNIFIED IDEOGRAPH-#4EEE, IRGKangXi=0094.060, RSKangXi=9.4, Def{falsehood, deception; vacation}
4EEF CJK UNIFIED IDEOGRAPH-#4EEF, IRGKangXi=0094.070, RSKangXi=9.4
4EF0 CJK UNIFIED IDEOGRAPH-#4EF0, IRGKangXi=0094.080, RSKangXi=9.4, Def{raise the head to look; look up to, rely on, admire}
4EF1 CJK UNIFIED IDEOGRAPH-#4EF1, IRGKangXi=0094.090, RSKangXi=9.4
4EF2 CJK UNIFIED IDEOGRAPH-#4EF2, IRGKangXi=0094.110, RSKangXi=9.4, Def{middle brother; go between, mediator; surname}
4EF3 CJK UNIFIED IDEOGRAPH-#4EF3, IRGKangXi=0094.120, RSKangXi=9.4, Def{separate, part company}
4EF4 CJK UNIFIED IDEOGRAPH-#4EF4, IRGKangXi=0094.160, RSKangXi=9.4
4EF5 CJK UNIFIED IDEOGRAPH-#4EF5, IRGKangXi=0094.170, RSKangXi=9.4, Def{similar}
4EF6 CJK UNIFIED IDEOGRAPH-#4EF6, IRGKangXi=0094.180, RSKangXi=9.4, Def{numerary adjunct for article; matter}
4EF7 CJK UNIFIED IDEOGRAPH-#4EF7, IRGKangXi=0094.200, RSKangXi=9.4, Def{price, value}
4EF8 CJK UNIFIED IDEOGRAPH-#4EF8, IRGKangXi=0094.210, RSKangXi=9.4, Def{bent, distorted, crooked; feeble}
4EF9 CJK UNIFIED IDEOGRAPH-#4EF9, IRGKangXi=0094.220, RSKangXi=9.4
4EFA CJK UNIFIED IDEOGRAPH-#4EFA, IRGKangXi=0094.230, RSKangXi=9.4
4EFB CJK UNIFIED IDEOGRAPH-#4EFB, IRGKangXi=0094.240, RSKangXi=9.4, Def{trust to, rely on, appoint; to bear, duty, office; allow}
4EFC CJK UNIFIED IDEOGRAPH-#4EFC, IRGKangXi=0094.250, RSKangXi=9.4
4EFD CJK UNIFIED IDEOGRAPH-#4EFD, IRGKangXi=0094.260, RSKangXi=9.4, Def{portion, part; duty}
4EFE CJK UNIFIED IDEOGRAPH-#4EFE, IRGKangXi=0095.010, RSKangXi=9.4, Def{to hang or bow the head, to droop, to lower; low, beneath}
4EFF CJK UNIFIED IDEOGRAPH-#4EFF, IRGKangXi=0095.020, RSKangXi=9.4, Def{imitate, copy; as if}
4F00 CJK UNIFIED IDEOGRAPH-#4F00, IRGKangXi=0095.030, RSKangXi=9.4, Def{excited}
4F01 CJK UNIFIED IDEOGRAPH-#4F01, IRGKangXi=0095.040, RSKangXi=9.4, Def{plan a project; stand on tiptoe}
4F02 CJK UNIFIED IDEOGRAPH-#4F02, IRGKangXi=0095.070, RSKangXi=9.4
4F03 CJK UNIFIED IDEOGRAPH-#4F03, IRGKangXi=0095.080, RSKangXi=9.4, Def{handsome}
4F04 CJK UNIFIED IDEOGRAPH-#4F04, IRGKangXi=0095.090, RSKangXi=9.4
4F05 CJK UNIFIED IDEOGRAPH-#4F05, IRGKangXi=0095.100, RSKangXi=9.4
4F06 CJK UNIFIED IDEOGRAPH-#4F06, IRGKangXi=0095.110, RSKangXi=9.4
4F07 CJK UNIFIED IDEOGRAPH-#4F07, IRGKangXi=0095.120, RSKangXi=9.4
4F08 CJK UNIFIED IDEOGRAPH-#4F08, IRGKangXi=0095.130, RSKangXi=9.4, Def{nervous, fearful}
4F09 CJK UNIFIED IDEOGRAPH-#4F09, IRGKangXi=0095.140, RSKangXi=9.4, Def{compare, match; pair; spouse}
4F0A CJK UNIFIED IDEOGRAPH-#4F0A, IRGKangXi=0095.150, RSKangXi=9.4, Def{third person pronoun; he, she, this, that}
4F0B CJK UNIFIED IDEOGRAPH-#4F0B, IRGKangXi=0095.180, RSKangXi=9.4, Def{deceptive}
4F0C CJK UNIFIED IDEOGRAPH-#4F0C, IRGKangXi=0095.190, RSKangXi=9.4
4F0D CJK UNIFIED IDEOGRAPH-#4F0D, IRGKangXi=0095.200, RSKangXi=9.4, AccountingNumeric=5, Def{five, company of five; troops}
4F0E CJK UNIFIED IDEOGRAPH-#4F0E, IRGKangXi=0095.210, RSKangXi=9.4, Def{talent, skill, ability}
4F0F CJK UNIFIED IDEOGRAPH-#4F0F, IRGKangXi=0095.230, RSKangXi=9.4, Def{crouch, crawl, lie hidden, conceal}
4F10 CJK UNIFIED IDEOGRAPH-#4F10, IRGKangXi=0096.010, RSKangXi=9.4, Def{cut down, subjugate, attack}
4F11 CJK UNIFIED IDEOGRAPH-#4F11, IRGKangXi=0096.020, RSKangXi=9.4, Def{rest, stop; retire; do not!}
4F12 CJK UNIFIED IDEOGRAPH-#4F12, IRGKangXi=0096.060, RSKangXi=9.4
4F13 CJK UNIFIED IDEOGRAPH-#4F13, IRGKangXi=0096.080, RSKangXi=9.4
4F14 CJK UNIFIED IDEOGRAPH-#4F14, IRGKangXi=0096.100, RSKangXi=9.4
4F15 CJK UNIFIED IDEOGRAPH-#4F15, IRGKangXi=0096.121, RSKangXi=9.4, Def{common laborer}
4F16 CJK UNIFIED IDEOGRAPH-#4F16, IRGKangXi=0096.121, RSKangXi=9.4
4F17 CJK UNIFIED IDEOGRAPH-#4F17, IRGKangXi=0096.121, RSKangXi=9.4, Def{multitude, crowd; masses, public}
4F18 CJK UNIFIED IDEOGRAPH-#4F18, IRGKangXi=0096.121, RSKangXi=9.4, Def{superior, excellent; actor}
4F19 CJK UNIFIED IDEOGRAPH-#4F19, IRGKangXi=0096.121, RSKangXi=9.4, Def{companion, colleague; utensils}
4F1A CJK UNIFIED IDEOGRAPH-#4F1A, IRGKangXi=0096.121, RSKangXi=9.4, Def{assemble, meet together; meeting}
4F1B CJK UNIFIED IDEOGRAPH-#4F1B, IRGKangXi=0096.121, RSKangXi=9.4, Def{humpback; stoop}
4F1C CJK UNIFIED IDEOGRAPH-#4F1C, IRGKangXi=0096.121, RSKangXi=9.4, Def{deputy, vice-}
4F1D CJK UNIFIED IDEOGRAPH-#4F1D, IRGKangXi=0096.121, RSKangXi=9.4, Def{summon; propagate, transmit}
4F1E CJK UNIFIED IDEOGRAPH-#4F1E, IRGKangXi=0096.121, RSKangXi=9.4, Def{umbrella, parasol, parachute}
4F1F CJK UNIFIED IDEOGRAPH-#4F1F, IRGKangXi=0096.121, RSKangXi=9.4, Def{great, robust; extraordinary}
4F20 CJK UNIFIED IDEOGRAPH-#4F20, IRGKangXi=0096.121, RSKangXi=9.4, Def{summon; propagate, transmit}
4F21 CJK UNIFIED IDEOGRAPH-#4F21, IRGKangXi=0096.121, RSKangXi=9.4
4F22 CJK UNIFIED IDEOGRAPH-#4F22, IRGKangXi=0096.121, RSKangXi=9.4, Def{child}
4F23 CJK UNIFIED IDEOGRAPH-#4F23, IRGKangXi=0096.121, RSKangXi=9.4, Def{like}
4F24 CJK UNIFIED IDEOGRAPH-#4F24, IRGKangXi=0096.121, RSKangXi=9.4, Def{wound, injury; fall ill from}
4F25 CJK UNIFIED IDEOGRAPH-#4F25, IRGKangXi=0096.121, RSKangXi=9.5, Def{ghost of one devoured by tiger}
4F26 CJK UNIFIED IDEOGRAPH-#4F26, IRGKangXi=0096.121, RSKangXi=9.4, Def{normal human relationships}
4F27 CJK UNIFIED IDEOGRAPH-#4F27, IRGKangXi=0096.121, RSKangXi=9.4, Def{vulgar person, country man}
4F28 CJK UNIFIED IDEOGRAPH-#4F28, IRGKangXi=0096.121, RSKangXi=9.4
4F29 CJK UNIFIED IDEOGRAPH-#4F29, IRGKangXi=0096.121, Def{trust, believe; letter; (Cant.) small}
4F2A CJK UNIFIED IDEOGRAPH-#4F2A, IRGKangXi=0096.121, RSKangXi=9.4, Def{false, counterfeit, bogus}
4F2B CJK UNIFIED IDEOGRAPH-#4F2B, IRGKangXi=0096.121, RSKangXi=9.4, Def{look towards; turn one's back on}
4F2C CJK UNIFIED IDEOGRAPH-#4F2C, IRGKangXi=0096.121, RSKangXi=9.4
4F2D CJK UNIFIED IDEOGRAPH-#4F2D, IRGKangXi=0096.130, RSKangXi=9.5, Def{dark, somber; deep, profound}
4F2E CJK UNIFIED IDEOGRAPH-#4F2E, IRGKangXi=0096.140, RSKangXi=9.5, Def{to make a great effort}
4F2F CJK UNIFIED IDEOGRAPH-#4F2F, IRGKangXi=0096.160, RSKangXi=9.5, Def{older brother; father's elder brother; senior male 'sire'; feudal rank 'count'}
4F30 CJK UNIFIED IDEOGRAPH-#4F30, IRGKangXi=0096.170, RSKangXi=9.5, Def{merchant; estimate, guess, presume}
4F31 CJK UNIFIED IDEOGRAPH-#4F31, IRGKangXi=0096.200, RSKangXi=9.5, Def{thou, you}
4F32 CJK UNIFIED IDEOGRAPH-#4F32, IRGKangXi=0096.210, RSKangXi=9.5, Def{we (Shanghai dialect)}
4F33 CJK UNIFIED IDEOGRAPH-#4F33, IRGKangXi=0096.220, RSKangXi=9.5
4F34 CJK UNIFIED IDEOGRAPH-#4F34, IRGKangXi=0096.230, RSKangXi=9.5, Def{companion, comrade, partner; accompany}
4F35 CJK UNIFIED IDEOGRAPH-#4F35, IRGKangXi=0097.020, RSKangXi=9.5
4F36 CJK UNIFIED IDEOGRAPH-#4F36, IRGKangXi=0097.030, RSKangXi=9.5, Def{lonely, solitary; actor}
4F37 CJK UNIFIED IDEOGRAPH-#4F37, IRGKangXi=0097.040, RSKangXi=9.5, Def{descendent}
4F38 CJK UNIFIED IDEOGRAPH-#4F38, IRGKangXi=0097.060, RSKangXi=9.5, Def{extend, stretch out, open up; trust}
4F39 CJK UNIFIED IDEOGRAPH-#4F39, IRGKangXi=0097.070, RSKangXi=9.5, Def{dull, slow, unskillful}
4F3A CJK UNIFIED IDEOGRAPH-#4F3A, IRGKangXi=0097.080, RSKangXi=9.5, Def{serve, wait upon, attend; examine}
4F3B CJK UNIFIED IDEOGRAPH-#4F3B, IRGKangXi=0097.090, RSKangXi=9.5, Def{messenger, emissary; send emissary}
4F3C CJK UNIFIED IDEOGRAPH-#4F3C, IRGKangXi=0097.100, RSKangXi=9.5, Def{resemble, similar to; as if, seem}
4F3D CJK UNIFIED IDEOGRAPH-#4F3D, IRGKangXi=0097.120, RSKangXi=9.5, Def{transcription of sanskrit 'gha' in buddhist texts ('samgha', etc.); (nursing; attending; entertainer) (Jap.); tample; in Chinese this character is not used alone}
4F3E CJK UNIFIED IDEOGRAPH-#4F3E, IRGKangXi=0097.130, RSKangXi=9.5, Def{mighty}
4F3F CJK UNIFIED IDEOGRAPH-#4F3F, IRGKangXi=0097.140, RSKangXi=9.5
4F40 CJK UNIFIED IDEOGRAPH-#4F40, IRGKangXi=0097.150, RSKangXi=9.5, Def{resemble}
4F41 CJK UNIFIED IDEOGRAPH-#4F41, IRGKangXi=0097.160, RSKangXi=9.5
4F42 CJK UNIFIED IDEOGRAPH-#4F42, IRGKangXi=0097.170, RSKangXi=9.5
4F43 CJK UNIFIED IDEOGRAPH-#4F43, IRGKangXi=0097.180, RSKangXi=9.5, Def{tenant farmer; be a tenant farmer}
4F44 CJK UNIFIED IDEOGRAPH-#4F44, IRGKangXi=0097.190, RSKangXi=9.5
4F45 CJK UNIFIED IDEOGRAPH-#4F45, IRGKangXi=0097.200, RSKangXi=9.5
4F46 CJK UNIFIED IDEOGRAPH-#4F46, IRGKangXi=0097.210, RSKangXi=9.5, Def{only; but, however, yet, still}
4F47 CJK UNIFIED IDEOGRAPH-#4F47, IRGKangXi=0097.220, RSKangXi=9.5, Def{wait; look towards; turn one's back on}
4F48 CJK UNIFIED IDEOGRAPH-#4F48, IRGKangXi=0098.010, RSKangXi=9.5, Def{spread, publicize, announce}
4F49 CJK UNIFIED IDEOGRAPH-#4F49, IRGKangXi=0098.030, RSKangXi=9.5, Def{surname; name of a divine being; transliteration of Sanskrit 'kh'}
4F4A CJK UNIFIED IDEOGRAPH-#4F4A, IRGKangXi=0098.040, RSKangXi=9.5
4F4B CJK UNIFIED IDEOGRAPH-#4F4B, IRGKangXi=0098.050, RSKangXi=9.5, Def{continue, carry on; hand down; to join}
4F4C CJK UNIFIED IDEOGRAPH-#4F4C, IRGKangXi=0098.060, RSKangXi=9.5, Def{small}
4F4D CJK UNIFIED IDEOGRAPH-#4F4D, IRGKangXi=0098.070, RSKangXi=9.5, Def{throne; position, post; rank, status; seat}
4F4E CJK UNIFIED IDEOGRAPH-#4F4E, IRGKangXi=0098.080, RSKangXi=9.5, Def{low; to lower, hang, bend, bow}
4F4F CJK UNIFIED IDEOGRAPH-#4F4F, IRGKangXi=0098.090, RSKangXi=9.5, Def{reside, live at, dwell, lodge; stop}
4F50 CJK UNIFIED IDEOGRAPH-#4F50, IRGKangXi=0098.100, RSKangXi=9.5, Def{assist, aid, second; subordinate}
4F51 CJK UNIFIED IDEOGRAPH-#4F51, IRGKangXi=0098.110, RSKangXi=9.5, Def{help, protect, bless}
4F52 CJK UNIFIED IDEOGRAPH-#4F52, IRGKangXi=0098.120, RSKangXi=9.5
4F53 CJK UNIFIED IDEOGRAPH-#4F53, IRGKangXi=0098.130, RSKangXi=9.5, Def{body; group, class, body, unit; inferior}
4F54 CJK UNIFIED IDEOGRAPH-#4F54, IRGKangXi=0098.140, RSKangXi=9.5, Def{occupy by force, usurp; possess}
4F55 CJK UNIFIED IDEOGRAPH-#4F55, IRGKangXi=0098.150, RSKangXi=9.5, Def{what, why, where, which, how}
4F56 CJK UNIFIED IDEOGRAPH-#4F56, IRGKangXi=0098.160, RSKangXi=9.5
4F57 CJK UNIFIED IDEOGRAPH-#4F57, IRGKangXi=0098.170, RSKangXi=9.5, Def{other, he; surname; a load}
4F58 CJK UNIFIED IDEOGRAPH-#4F58, IRGKangXi=0099.010, RSKangXi=9.5, Def{surname}
4F59 CJK UNIFIED IDEOGRAPH-#4F59, IRGKangXi=0099.020, RSKangXi=9.5, Def{I, my, me; surname; surplus}
4F5A CJK UNIFIED IDEOGRAPH-#4F5A, IRGKangXi=0099.030, RSKangXi=9.5, Def{indulge in pleasures; flee}
4F5B CJK UNIFIED IDEOGRAPH-#4F5B, IRGKangXi=0099.040, RSKangXi=9.5, Def{Buddha; of Buddhism; merciful person; Buddhist image; the dead (Jap.)}
4F5C CJK UNIFIED IDEOGRAPH-#4F5C, IRGKangXi=0099.070, RSKangXi=9.5, Def{make; work; compose, write; act, perform}
4F5D CJK UNIFIED IDEOGRAPH-#4F5D, IRGKangXi=0099.100, RSKangXi=9.5, Def{rickets}
4F5E CJK UNIFIED IDEOGRAPH-#4F5E, IRGKangXi=0099.110, RSKangXi=9.5, Def{flattery; glib}
4F5F CJK UNIFIED IDEOGRAPH-#4F5F, IRGKangXi=0099.120, RSKangXi=9.5, Def{a name}
4F60 CJK UNIFIED IDEOGRAPH-#4F60, IRGKangXi=0100.021, RSKangXi=9.5, Def{you, second person pronoun}
4F61 CJK UNIFIED IDEOGRAPH-#4F61, IRGKangXi=0100.021, RSKangXi=9.5, Def{make effort, endeavor}
4F62 CJK UNIFIED IDEOGRAPH-#4F62, IRGKangXi=0100.021, RSKangXi=9.5, Def{(Cant.) he, she, it}
4F63 CJK UNIFIED IDEOGRAPH-#4F63, IRGKangXi=0100.021, RSKangXi=9.5, Def{commission fee}
4F64 CJK UNIFIED IDEOGRAPH-#4F64, IRGKangXi=0100.021, RSKangXi=9.5, Def{the Va (Wa) nationality, living in Yunnan}
4F65 CJK UNIFIED IDEOGRAPH-#4F65, IRGKangXi=0100.021, RSKangXi=9.5, Def{all, together, unanimous}
4F66 CJK UNIFIED IDEOGRAPH-#4F66, IRGKangXi=0100.021, RSKangXi=9.5
4F67 CJK UNIFIED IDEOGRAPH-#4F67, IRGKangXi=0100.021, RSKangXi=9.5
4F68 CJK UNIFIED IDEOGRAPH-#4F68, IRGKangXi=0100.021, RSKangXi=9.5
4F69 CJK UNIFIED IDEOGRAPH-#4F69, IRGKangXi=0100.040, RSKangXi=9.6, Def{belt ornament, pendant; wear at waist, tie to the belt; respect}
4F6A CJK UNIFIED IDEOGRAPH-#4F6A, IRGKangXi=0100.060, RSKangXi=9.6, Def{hesitate}
4F6B CJK UNIFIED IDEOGRAPH-#4F6B, IRGKangXi=0100.080, RSKangXi=9.6
4F6C CJK UNIFIED IDEOGRAPH-#4F6C, IRGKangXi=0100.090, RSKangXi=9.6, Def{(Cant.) man, person; mature}
4F6D CJK UNIFIED IDEOGRAPH-#4F6D, IRGKangXi=0100.100, RSKangXi=9.6, Def{unsubmissive; obstreperous}
4F6E CJK UNIFIED IDEOGRAPH-#4F6E, IRGKangXi=0100.120, RSKangXi=9.6, Def{(Cant.) intensive particle}
4F6F CJK UNIFIED IDEOGRAPH-#4F6F, IRGKangXi=0100.130, RSKangXi=9.6, Def{pretend, feign; false, deceitful}
4F70 CJK UNIFIED IDEOGRAPH-#4F70, IRGKangXi=0100.140, RSKangXi=9.6, AccountingNumeric=100, Def{hundred}
4F71 CJK UNIFIED IDEOGRAPH-#4F71, IRGKangXi=0100.150, RSKangXi=9.6
4F72 CJK UNIFIED IDEOGRAPH-#4F72, IRGKangXi=0100.170, RSKangXi=9.6
4F73 CJK UNIFIED IDEOGRAPH-#4F73, IRGKangXi=0100.180, RSKangXi=9.6, Def{good, auspicious; beautiful; delightful}
4F74 CJK UNIFIED IDEOGRAPH-#4F74, IRGKangXi=0100.210, RSKangXi=9.6, Def{a second, an assistant}
4F75 CJK UNIFIED IDEOGRAPH-#4F75, IRGKangXi=0100.220, RSKangXi=9.6, Def{combine, annex}
4F76 CJK UNIFIED IDEOGRAPH-#4F76, IRGKangXi=0100.230, RSKangXi=9.6, Def{strong, robust; exact, correct}
4F77 CJK UNIFIED IDEOGRAPH-#4F77, IRGKangXi=0100.240, RSKangXi=9.6, Def{to act contrary to}
4F78 CJK UNIFIED IDEOGRAPH-#4F78, IRGKangXi=0100.250, RSKangXi=9.6, Def{meet}
4F79 CJK UNIFIED IDEOGRAPH-#4F79, IRGKangXi=0100.270, RSKangXi=9.6, Def{depend upon; support; go against; (variant deceive)}
4F7A CJK UNIFIED IDEOGRAPH-#4F7A, IRGKangXi=0100.290, RSKangXi=9.6, Def{fairy}
4F7B CJK UNIFIED IDEOGRAPH-#4F7B, IRGKangXi=0100.300, RSKangXi=9.6, Def{frivolous; unsteady; delay}
4F7C CJK UNIFIED IDEOGRAPH-#4F7C, IRGKangXi=0101.010, RSKangXi=9.6, Def{beautiful, handsome, good-looking}
4F7D CJK UNIFIED IDEOGRAPH-#4F7D, IRGKangXi=0101.020, RSKangXi=9.6, Def{aid; help}
4F7E CJK UNIFIED IDEOGRAPH-#4F7E, IRGKangXi=0101.030, RSKangXi=9.6, Def{a row or file of dancers}
4F7F CJK UNIFIED IDEOGRAPH-#4F7F, IRGKangXi=0101.050, RSKangXi=9.6, Def{cause, send on a mission, order; envoy, messenger, ambassador}
4F80 CJK UNIFIED IDEOGRAPH-#4F80, IRGKangXi=0101.080, RSKangXi=9.6, Def{form}
4F81 CJK UNIFIED IDEOGRAPH-#4F81, IRGKangXi=0101.090, RSKangXi=9.6, Def{crowd}
4F82 CJK UNIFIED IDEOGRAPH-#4F82, IRGKangXi=0101.100, RSKangXi=9.6, Def{to commission, to entrust to, to depute; to request, to ask}
4F83 CJK UNIFIED IDEOGRAPH-#4F83, IRGKangXi=0101.110, RSKangXi=9.6, Def{upright and strong; amiable}
4F84 CJK UNIFIED IDEOGRAPH-#4F84, IRGKangXi=0101.140, RSKangXi=9.6, Def{nephew}
4F85 CJK UNIFIED IDEOGRAPH-#4F85, IRGKangXi=0101.150, RSKangXi=9.6, Def{to give; prepared for included in; embraced in}
4F86 CJK UNIFIED IDEOGRAPH-#4F86, IRGKangXi=0101.160, RSKangXi=9.6, Def{come, coming; return, returning}
4F87 CJK UNIFIED IDEOGRAPH-#4F87, IRGKangXi=0101.180, RSKangXi=9.6, Def{a class, a category a corpse}
4F88 CJK UNIFIED IDEOGRAPH-#4F88, IRGKangXi=0101.190, RSKangXi=9.6, Def{luxurious, extravagant}
4F89 CJK UNIFIED IDEOGRAPH-#4F89, IRGKangXi=0101.220, RSKangXi=9.6, Def{to speak with an accent; big and clumsy}
4F8A CJK UNIFIED IDEOGRAPH-#4F8A, IRGKangXi=0101.230, RSKangXi=9.6, Def{big}
4F8B CJK UNIFIED IDEOGRAPH-#4F8B, IRGKangXi=0101.240, RSKangXi=9.6, Def{precedent, example; regulation}
4F8C CJK UNIFIED IDEOGRAPH-#4F8C, IRGKangXi=0101.250, RSKangXi=9.6
4F8D CJK UNIFIED IDEOGRAPH-#4F8D, IRGKangXi=0101.260, RSKangXi=9.6, Def{serve, attend upon; attendant, servant; samurai}
4F8E CJK UNIFIED IDEOGRAPH-#4F8E, IRGKangXi=0102.020, RSKangXi=9.6, Def{to soothe, to pacify; to settle, to establish}
4F8F CJK UNIFIED IDEOGRAPH-#4F8F, IRGKangXi=0102.030, RSKangXi=9.6, Def{small, little, tiny, dwarf}
4F90 CJK UNIFIED IDEOGRAPH-#4F90, IRGKangXi=0102.040, RSKangXi=9.6, Def{quiet}
4F91 CJK UNIFIED IDEOGRAPH-#4F91, IRGKangXi=0102.050, RSKangXi=9.6, Def{help, assist, repay kindness}
4F92 CJK UNIFIED IDEOGRAPH-#4F92, IRGKangXi=0102.060, RSKangXi=9.6
4F93 CJK UNIFIED IDEOGRAPH-#4F93, IRGKangXi=0102.070, RSKangXi=9.6
4F94 CJK UNIFIED IDEOGRAPH-#4F94, IRGKangXi=0102.080, RSKangXi=9.6, Def{equal}
4F95 CJK UNIFIED IDEOGRAPH-#4F95, IRGKangXi=0102.090, RSKangXi=9.6
4F96 CJK UNIFIED IDEOGRAPH-#4F96, IRGKangXi=0102.100, RSKangXi=9.6, Def{logical reasons, logical order}
4F97 CJK UNIFIED IDEOGRAPH-#4F97, IRGKangXi=0102.120, RSKangXi=9.6, Def{big; ignorant; rude, rustic}
4F98 CJK UNIFIED IDEOGRAPH-#4F98, IRGKangXi=0102.130, RSKangXi=9.6, Def{disappointed, forlorn}
4F99 CJK UNIFIED IDEOGRAPH-#4F99, IRGKangXi=0102.140, RSKangXi=9.6
4F9A CJK UNIFIED IDEOGRAPH-#4F9A, IRGKangXi=0102.150, RSKangXi=9.6, Def{fast}
4F9B CJK UNIFIED IDEOGRAPH-#4F9B, IRGKangXi=0102.160, RSKangXi=9.6, Def{supply, provide for; offer in worship}
4F9C CJK UNIFIED IDEOGRAPH-#4F9C, IRGKangXi=0102.170, RSKangXi=9.6, Def{lies}
4F9D CJK UNIFIED IDEOGRAPH-#4F9D, IRGKangXi=0102.180, RSKangXi=9.6, Def{rely on, be set in; consent, obey a wish}
4F9E CJK UNIFIED IDEOGRAPH-#4F9E, IRGKangXi=0102.210, RSKangXi=9.6
4F9F CJK UNIFIED IDEOGRAPH-#4F9F, IRGKangXi=0102.250, RSKangXi=9.6
4FA0 CJK UNIFIED IDEOGRAPH-#4FA0, IRGKangXi=0102.291, RSKangXi=9.6, Def{chivalrous person; knight-errant}
4FA1 CJK UNIFIED IDEOGRAPH-#4FA1, IRGKangXi=0102.291, RSKangXi=9.6, Def{price, value}
4FA2 CJK UNIFIED IDEOGRAPH-#4FA2, IRGKangXi=0102.291, RSKangXi=9.6, Def{load}
4FA3 CJK UNIFIED IDEOGRAPH-#4FA3, IRGKangXi=0102.291, RSKangXi=9.6, Def{companion; associate with}
4FA4 CJK UNIFIED IDEOGRAPH-#4FA4, IRGKangXi=0102.291, RSKangXi=9.6
4FA5 CJK UNIFIED IDEOGRAPH-#4FA5, IRGKangXi=0102.291, RSKangXi=9.6, Def{be lucky; by chance, by luck}
4FA6 CJK UNIFIED IDEOGRAPH-#4FA6, IRGKangXi=0102.291, RSKangXi=9.6, Def{spy, reconnoiter; detective}
4FA7 CJK UNIFIED IDEOGRAPH-#4FA7, IRGKangXi=0102.291, RSKangXi=9.6, Def{side; incline, slant, lean}
4FA8 CJK UNIFIED IDEOGRAPH-#4FA8, IRGKangXi=0102.291, RSKangXi=9.6, Def{sojourn, lodge}
4FA9 CJK UNIFIED IDEOGRAPH-#4FA9, IRGKangXi=0102.291, RSKangXi=9.6, Def{go-between, broker, proxy}
4FAA CJK UNIFIED IDEOGRAPH-#4FAA, IRGKangXi=0102.291, RSKangXi=9.6, Def{a company, companion; together}
4FAB CJK UNIFIED IDEOGRAPH-#4FAB, IRGKangXi=0102.291, RSKangXi=9.6, Def{flattery; glib}
4FAC CJK UNIFIED IDEOGRAPH-#4FAC, IRGKangXi=0102.291, RSKangXi=9.6, Def{I; you; family name}
4FAD CJK UNIFIED IDEOGRAPH-#4FAD, IRGKangXi=0102.291, RSKangXi=9.6, Def{complete, utmost}
4FAE CJK UNIFIED IDEOGRAPH-#4FAE, IRGKangXi=0103.010, RSKangXi=9.7, Def{insult, ridicule, disgrace}
4FAF CJK UNIFIED IDEOGRAPH-#4FAF, IRGKangXi=0103.070, RSKangXi=9.7, Def{marquis, lord; target in archery}
4FB0 CJK UNIFIED IDEOGRAPH-#4FB0, IRGKangXi=0103.090, RSKangXi=9.7
4FB1 CJK UNIFIED IDEOGRAPH-#4FB1, IRGKangXi=0103.110, RSKangXi=9.7
4FB2 CJK UNIFIED IDEOGRAPH-#4FB2, IRGKangXi=0103.140, RSKangXi=9.7
4FB3 CJK UNIFIED IDEOGRAPH-#4FB3, IRGKangXi=0103.170, RSKangXi=9.7
4FB4 CJK UNIFIED IDEOGRAPH-#4FB4, IRGKangXi=0103.180, RSKangXi=9.7, Def{surname}
4FB5 CJK UNIFIED IDEOGRAPH-#4FB5, IRGKangXi=0103.190, RSKangXi=9.7, Def{invade, encroach upon, raid}
4FB6 CJK UNIFIED IDEOGRAPH-#4FB6, IRGKangXi=0103.200, RSKangXi=9.7, Def{companion; associate with}
4FB7 CJK UNIFIED IDEOGRAPH-#4FB7, IRGKangXi=0103.210, RSKangXi=9.7, Def{narrow, cramped, confined}
4FB8 CJK UNIFIED IDEOGRAPH-#4FB8, IRGKangXi=0103.220, RSKangXi=9.7
4FB9 CJK UNIFIED IDEOGRAPH-#4FB9, IRGKangXi=0103.230, RSKangXi=9.7
4FBA CJK UNIFIED IDEOGRAPH-#4FBA, IRGKangXi=0103.250, RSKangXi=9.7
4FBB CJK UNIFIED IDEOGRAPH-#4FBB, IRGKangXi=0103.260, RSKangXi=9.7
4FBC CJK UNIFIED IDEOGRAPH-#4FBC, IRGKangXi=0103.270, RSKangXi=9.7
4FBD CJK UNIFIED IDEOGRAPH-#4FBD, IRGKangXi=0103.280, RSKangXi=9.7
4FBE CJK UNIFIED IDEOGRAPH-#4FBE, IRGKangXi=0103.310, RSKangXi=9.7
4FBF CJK UNIFIED IDEOGRAPH-#4FBF, IRGKangXi=0103.320, RSKangXi=9.7, Def{convenience, ease; expedient}
4FC0 CJK UNIFIED IDEOGRAPH-#4FC0, IRGKangXi=0104.010, RSKangXi=9.7
4FC1 CJK UNIFIED IDEOGRAPH-#4FC1, IRGKangXi=0104.030, RSKangXi=9.7, Def{big}
4FC2 CJK UNIFIED IDEOGRAPH-#4FC2, IRGKangXi=0104.040, RSKangXi=9.7, Def{bind, tie up; involve, relation}
4FC3 CJK UNIFIED IDEOGRAPH-#4FC3, IRGKangXi=0104.050, RSKangXi=9.7, Def{urge, press, hurry; close}
4FC4 CJK UNIFIED IDEOGRAPH-#4FC4, IRGKangXi=0104.060, RSKangXi=9.7, Def{sudden(ly), soon; Russian}
4FC5 CJK UNIFIED IDEOGRAPH-#4FC5, IRGKangXi=0104.090, RSKangXi=9.7, Def{ornamental cap}
4FC6 CJK UNIFIED IDEOGRAPH-#4FC6, IRGKangXi=0104.100, RSKangXi=9.7
4FC7 CJK UNIFIED IDEOGRAPH-#4FC7, IRGKangXi=0104.110, RSKangXi=9.7
4FC8 CJK UNIFIED IDEOGRAPH-#4FC8, IRGKangXi=0104.130, RSKangXi=9.7, Def{to inform quickly; an urgent communication}
4FC9 CJK UNIFIED IDEOGRAPH-#4FC9, IRGKangXi=0104.140, RSKangXi=9.7
4FCA CJK UNIFIED IDEOGRAPH-#4FCA, IRGKangXi=0104.150, RSKangXi=9.7, Def{talented, capable; handsome}
4FCB CJK UNIFIED IDEOGRAPH-#4FCB, IRGKangXi=0104.160, RSKangXi=9.7
4FCC CJK UNIFIED IDEOGRAPH-#4FCC, IRGKangXi=0104.180, RSKangXi=9.7
4FCD CJK UNIFIED IDEOGRAPH-#4FCD, IRGKangXi=0104.200, RSKangXi=9.7
4FCE CJK UNIFIED IDEOGRAPH-#4FCE, IRGKangXi=0104.210, RSKangXi=9.7, Def{chopping board or block; painted}
4FCF CJK UNIFIED IDEOGRAPH-#4FCF, IRGKangXi=0104.220, RSKangXi=9.7, Def{like, similar; resemble; pretty}
4FD0 CJK UNIFIED IDEOGRAPH-#4FD0, IRGKangXi=0104.240, RSKangXi=9.7, Def{smooth; active; clever, sharp}
4FD1 CJK UNIFIED IDEOGRAPH-#4FD1, IRGKangXi=0104.250, RSKangXi=9.7, Def{wooden figure buried with dead}
4FD2 CJK UNIFIED IDEOGRAPH-#4FD2, IRGKangXi=0104.260, RSKangXi=9.7
4FD3 CJK UNIFIED IDEOGRAPH-#4FD3, IRGKangXi=0104.270, RSKangXi=9.7, Def{straight; pass}
4FD4 CJK UNIFIED IDEOGRAPH-#4FD4, IRGKangXi=0104.280, RSKangXi=9.7, Def{like}
4FD5 CJK UNIFIED IDEOGRAPH-#4FD5, IRGKangXi=0105.050, RSKangXi=9.7
4FD6 CJK UNIFIED IDEOGRAPH-#4FD6, IRGKangXi=0105.080, RSKangXi=9.7
4FD7 CJK UNIFIED IDEOGRAPH-#4FD7, IRGKangXi=0105.090, RSKangXi=9.7, Def{social customs; vulgar, unrefined}
4FD8 CJK UNIFIED IDEOGRAPH-#4FD8, IRGKangXi=0105.120, RSKangXi=9.7, Def{prisoner of war; take as prisoner}
4FD9 CJK UNIFIED IDEOGRAPH-#4FD9, IRGKangXi=0105.130, RSKangXi=9.7, Def{to pretend, appear as if}
4FDA CJK UNIFIED IDEOGRAPH-#4FDA, IRGKangXi=0105.140, RSKangXi=9.7, Def{rustic, vulgar, unpolished; mean}
4FDB CJK UNIFIED IDEOGRAPH-#4FDB, IRGKangXi=0105.150, RSKangXi=9.7, Def{make effort, endeavor; to lower the head}
4FDC CJK UNIFIED IDEOGRAPH-#4FDC, IRGKangXi=0105.160, RSKangXi=9.7, Def{to trust to; send a message}
4FDD CJK UNIFIED IDEOGRAPH-#4FDD, IRGKangXi=0105.170, RSKangXi=9.7, Def{protect, safeguard, defend, care}
4FDE CJK UNIFIED IDEOGRAPH-#4FDE, IRGKangXi=0105.210, RSKangXi=9.7, Def{surname; consent, approve}
4FDF CJK UNIFIED IDEOGRAPH-#4FDF, IRGKangXi=0105.230, RSKangXi=9.7, Def{wait for, wait until, as soon as}
4FE0 CJK UNIFIED IDEOGRAPH-#4FE0, IRGKangXi=0105.240, RSKangXi=9.7, Def{chivalrous person; knight-errant}
4FE1 CJK UNIFIED IDEOGRAPH-#4FE1, IRGKangXi=0105.250, RSKangXi=9.7, Def{trust, believe; letter}
4FE2 CJK UNIFIED IDEOGRAPH-#4FE2, IRGKangXi=0106.041, RSKangXi=9.7
4FE3 CJK UNIFIED IDEOGRAPH-#4FE3, IRGKangXi=0106.041, RSKangXi=9.7, Def{big}
4FE4 CJK UNIFIED IDEOGRAPH-#4FE4, IRGKangXi=0106.041, RSKangXi=9.7, Def{(J) same as 面影 U+9762 U+5F71, visage, face; trace, shadow; memory}
4FE5 CJK UNIFIED IDEOGRAPH-#4FE5, IRGKangXi=0106.041, RSKangXi=9.7, Def{rickshaw, cart, vehicle; name of piece in Chinese chess}
4FE6 CJK UNIFIED IDEOGRAPH-#4FE6, IRGKangXi=0106.041, RSKangXi=9.7, Def{companion, mate, colleague}
4FE7 CJK UNIFIED IDEOGRAPH-#4FE7, IRGKangXi=0106.041, RSKangXi=9.7
4FE8 CJK UNIFIED IDEOGRAPH-#4FE8, IRGKangXi=0106.041, RSKangXi=9.7, Def{grave, respectful, majestic}
4FE9 CJK UNIFIED IDEOGRAPH-#4FE9, IRGKangXi=0106.041, RSKangXi=9.7, Def{two, pair}
4FEA CJK UNIFIED IDEOGRAPH-#4FEA, IRGKangXi=0106.041, RSKangXi=9.7, Def{spouse, couple, pair}
4FEB CJK UNIFIED IDEOGRAPH-#4FEB, IRGKangXi=0106.041, RSKangXi=9.7, Def{to induce to come; to encourage}
4FEC CJK UNIFIED IDEOGRAPH-#4FEC, IRGKangXi=0106.041, RSKangXi=9.7, Def{(Cant.) 傢俬, furniture}
4FED CJK UNIFIED IDEOGRAPH-#4FED, IRGKangXi=0106.041, RSKangXi=9.7, Def{temperate, frugal, economical}
4FEE CJK UNIFIED IDEOGRAPH-#4FEE, IRGKangXi=0106.050, RSKangXi=9.8, Def{study; repair; cultivate}
4FEF CJK UNIFIED IDEOGRAPH-#4FEF, IRGKangXi=0106.060, RSKangXi=9.8, Def{bow down, face down, look down}
4FF0 CJK UNIFIED IDEOGRAPH-#4FF0, IRGKangXi=0106.070, RSKangXi=9.8
4FF1 CJK UNIFIED IDEOGRAPH-#4FF1, IRGKangXi=0106.080, RSKangXi=9.8, Def{all, together; accompany}
4FF2 CJK UNIFIED IDEOGRAPH-#4FF2, IRGKangXi=0106.090, RSKangXi=9.8, Def{same as 傚 U+509A, imitate, mimic}
4FF3 CJK UNIFIED IDEOGRAPH-#4FF3, IRGKangXi=0106.100, RSKangXi=9.8, Def{actor; vaudeville show; insincere}
4FF4 CJK UNIFIED IDEOGRAPH-#4FF4, IRGKangXi=0106.110, RSKangXi=9.8, Def{thin}
4FF5 CJK UNIFIED IDEOGRAPH-#4FF5, IRGKangXi=0106.140, RSKangXi=9.8, Def{divide, distribute}
4FF6 CJK UNIFIED IDEOGRAPH-#4FF6, IRGKangXi=0106.170, RSKangXi=9.8, Def{start, begin; beginning; arrange}
4FF7 CJK UNIFIED IDEOGRAPH-#4FF7, IRGKangXi=0106.180, RSKangXi=9.8
4FF8 CJK UNIFIED IDEOGRAPH-#4FF8, IRGKangXi=0106.190, RSKangXi=9.8, Def{wages, salary, official emolument}
4FF9 CJK UNIFIED IDEOGRAPH-#4FF9, IRGKangXi=0106.200, RSKangXi=9.8
4FFA CJK UNIFIED IDEOGRAPH-#4FFA, IRGKangXi=0106.210, RSKangXi=9.8, Def{personal pronoun, I}
4FFB CJK UNIFIED IDEOGRAPH-#4FFB, IRGKangXi=0106.220, RSKangXi=9.8, Def{to prepare; to provide; to put in order; to complete perfection; completeness}
4FFC CJK UNIFIED IDEOGRAPH-#4FFC, IRGKangXi=0106.230, RSKangXi=9.8
4FFD CJK UNIFIED IDEOGRAPH-#4FFD, IRGKangXi=0106.240, RSKangXi=9.8
4FFE CJK UNIFIED IDEOGRAPH-#4FFE, IRGKangXi=0106.250, RSKangXi=9.8, Def{so that, in order that; to cause; (Cant.) to give (synonymous with Mandarin 給)}
4FFF CJK UNIFIED IDEOGRAPH-#4FFF, IRGKangXi=0106.260, RSKangXi=9.8
5000 CJK UNIFIED IDEOGRAPH-#5000, IRGKangXi=0106.270, RSKangXi=9.8, Def{bewildered; rash, wildly}
5001 CJK UNIFIED IDEOGRAPH-#5001, IRGKangXi=0107.010, RSKangXi=9.8
5002 CJK UNIFIED IDEOGRAPH-#5002, IRGKangXi=0107.040, RSKangXi=9.8, Def{combine}
5003 CJK UNIFIED IDEOGRAPH-#5003, IRGKangXi=0107.050, RSKangXi=9.8, Def{damage, destroy}
5004 CJK UNIFIED IDEOGRAPH-#5004, IRGKangXi=0107.070, RSKangXi=9.8
5005 CJK UNIFIED IDEOGRAPH-#5005, IRGKangXi=0107.080, RSKangXi=9.8, Def{deputy, vice-}
5006 CJK UNIFIED IDEOGRAPH-#5006, IRGKangXi=0107.090, RSKangXi=9.8, Def{clever, skilled; two, pair}
5007 CJK UNIFIED IDEOGRAPH-#5007, IRGKangXi=0107.120, RSKangXi=9.8
5008 CJK UNIFIED IDEOGRAPH-#5008, IRGKangXi=0107.130, RSKangXi=9.8, Def{to induce to come; to encourage}
5009 CJK UNIFIED IDEOGRAPH-#5009, IRGKangXi=0107.140, RSKangXi=9.8, Def{granary; berth; sea}
500A CJK UNIFIED IDEOGRAPH-#500A, IRGKangXi=0107.160, RSKangXi=9.8
500B CJK UNIFIED IDEOGRAPH-#500B, IRGKangXi=0107.170, RSKangXi=9.8, Def{numerary adjunct, piece; single}
500C CJK UNIFIED IDEOGRAPH-#500C, IRGKangXi=0107.180, RSKangXi=9.8, Def{assistant in wine shop, groom}
500D CJK UNIFIED IDEOGRAPH-#500D, IRGKangXi=0107.190, RSKangXi=9.8, Def{times, fold, multiple times}
500E CJK UNIFIED IDEOGRAPH-#500E, IRGKangXi=0107.210, RSKangXi=9.8
500F CJK UNIFIED IDEOGRAPH-#500F, IRGKangXi=0107.220, RSKangXi=9.8, Def{hastily, suddenly, abruptly}
5010 CJK UNIFIED IDEOGRAPH-#5010, IRGKangXi=0107.230, RSKangXi=9.8, Def{hastily; suddenly}
5011 CJK UNIFIED IDEOGRAPH-#5011, IRGKangXi=0107.260, RSKangXi=9.8, Def{adjunct pronoun indicate plural}
5012 CJK UNIFIED IDEOGRAPH-#5012, IRGKangXi=0107.270, RSKangXi=9.8, Def{fall over; lie down; take turns}
5013 CJK UNIFIED IDEOGRAPH-#5013, IRGKangXi=0107.280, RSKangXi=9.8
5014 CJK UNIFIED IDEOGRAPH-#5014, IRGKangXi=0107.290, RSKangXi=9.8, Def{stubborn, obstinate, intransigent; firm}
5015 CJK UNIFIED IDEOGRAPH-#5015, IRGKangXi=0107.300, RSKangXi=9.8
5016 CJK UNIFIED IDEOGRAPH-#5016, IRGKangXi=0107.310, RSKangXi=9.8, Def{lucky, fortunate; dote on, spoil}
5017 CJK UNIFIED IDEOGRAPH-#5017, IRGKangXi=0108.010, RSKangXi=9.8
5018 CJK UNIFIED IDEOGRAPH-#5018, IRGKangXi=0108.030, RSKangXi=9.8, Def{if, supposing, in event of}
5019 CJK UNIFIED IDEOGRAPH-#5019, IRGKangXi=0108.040, RSKangXi=9.8, Def{wait; expect; visit; greet}
501A CJK UNIFIED IDEOGRAPH-#501A, IRGKangXi=0108.050, RSKangXi=9.8, Def{rely on, depend on; lean heavily}
501B CJK UNIFIED IDEOGRAPH-#501B, IRGKangXi=0108.060, RSKangXi=9.8
501C CJK UNIFIED IDEOGRAPH-#501C, IRGKangXi=0108.070, RSKangXi=9.8, Def{raise high; unrestrained}
501D CJK UNIFIED IDEOGRAPH-#501D, IRGKangXi=0108.080, RSKangXi=9.8, Def{sunrise; dawn}
501E CJK UNIFIED IDEOGRAPH-#501E, IRGKangXi=0108.090, RSKangXi=9.8, Def{far}
501F CJK UNIFIED IDEOGRAPH-#501F, IRGKangXi=0108.100, RSKangXi=9.8, Def{borrow; lend; make pretext of}
5020 CJK UNIFIED IDEOGRAPH-#5020, IRGKangXi=0108.110, RSKangXi=9.8
5021 CJK UNIFIED IDEOGRAPH-#5021, IRGKangXi=0108.120, RSKangXi=9.8, Def{guide, leader; lead, introduce}
5022 CJK UNIFIED IDEOGRAPH-#5022, IRGKangXi=0108.130, RSKangXi=9.8, Def{beautiful, handsome; woman}
5023 CJK UNIFIED IDEOGRAPH-#5023, IRGKangXi=0108.140, RSKangXi=9.8, Def{imitate}
5024 CJK UNIFIED IDEOGRAPH-#5024, IRGKangXi=0108.150, RSKangXi=9.8, Def{price, cost, worth}
5025 CJK UNIFIED IDEOGRAPH-#5025, IRGKangXi=0108.160, RSKangXi=9.8, Def{boorish, ignorant; urgent, pressing}
5026 CJK UNIFIED IDEOGRAPH-#5026, IRGKangXi=0108.170, RSKangXi=9.8, Def{be tired of, weary}
5027 CJK UNIFIED IDEOGRAPH-#5027, IRGKangXi=0108.180, RSKangXi=9.8
5028 CJK UNIFIED IDEOGRAPH-#5028, IRGKangXi=0108.190, RSKangXi=9.8, Def{arrogant, haughty, rude}
5029 CJK UNIFIED IDEOGRAPH-#5029, IRGKangXi=0109.010, RSKangXi=9.8, Def{beautiful, lovely; son-in-law}
502A CJK UNIFIED IDEOGRAPH-#502A, IRGKangXi=0109.020, RSKangXi=9.8, Def{feeble, tiny, young and weak}
502B CJK UNIFIED IDEOGRAPH-#502B, IRGKangXi=0109.030, RSKangXi=9.8, Def{normal human relationships}
502C CJK UNIFIED IDEOGRAPH-#502C, IRGKangXi=0109.040, RSKangXi=9.8, Def{noticeable, large; clear, distinct}
502D CJK UNIFIED IDEOGRAPH-#502D, IRGKangXi=0109.060, RSKangXi=9.8, Def{dwarf; dwarfish, short}
502E CJK UNIFIED IDEOGRAPH-#502E, IRGKangXi=0109.070, RSKangXi=9.8, Def{bare, naked, uncovered}
502F CJK UNIFIED IDEOGRAPH-#502F, IRGKangXi=0109.080, RSKangXi=9.8
5030 CJK UNIFIED IDEOGRAPH-#5030, IRGKangXi=0109.090, RSKangXi=9.8
5031 CJK UNIFIED IDEOGRAPH-#5031, IRGKangXi=0109.100, RSKangXi=9.8
5032 CJK UNIFIED IDEOGRAPH-#5032, IRGKangXi=0109.110, RSKangXi=9.8
5033 CJK UNIFIED IDEOGRAPH-#5033, IRGKangXi=0109.120, RSKangXi=9.8, Def{to stick in, to stab; to erect}
5034 CJK UNIFIED IDEOGRAPH-#5034, IRGKangXi=0109.160
5035 CJK UNIFIED IDEOGRAPH-#5035, IRGKangXi=0109.170, RSKangXi=9.8
5036 CJK UNIFIED IDEOGRAPH-#5036, IRGKangXi=0109.171, RSKangXi=9.8, Def{all}
5037 CJK UNIFIED IDEOGRAPH-#5037, IRGKangXi=0109.171, RSKangXi=9.8
5038 CJK UNIFIED IDEOGRAPH-#5038, IRGKangXi=0109.171, RSKangXi=9.8
5039 CJK UNIFIED IDEOGRAPH-#5039, IRGKangXi=0109.171, RSKangXi=9.8, Def{temperate, frugal, economical}
503A CJK UNIFIED IDEOGRAPH-#503A, IRGKangXi=0109.171, RSKangXi=9.8, Def{debt, loan, liabilities}
503B CJK UNIFIED IDEOGRAPH-#503B, IRGKangXi=0112.071, RSKangXi=9.9, Def{phonetic used in Korean place names}
503C CJK UNIFIED IDEOGRAPH-#503C, IRGKangXi=0109.171, RSKangXi=9.8, Def{price}
503D CJK UNIFIED IDEOGRAPH-#503D, IRGKangXi=0109.171, RSKangXi=9.8, Def{what; which; who; why}
503E CJK UNIFIED IDEOGRAPH-#503E, IRGKangXi=0109.171, RSKangXi=9.8, Def{upset, pour out, overflow}
503F CJK UNIFIED IDEOGRAPH-#503F, IRGKangXi=0109.171, RSKangXi=9.8
5040 CJK UNIFIED IDEOGRAPH-#5040, IRGKangXi=0109.190, RSKangXi=9.9
5041 CJK UNIFIED IDEOGRAPH-#5041, IRGKangXi=0109.200, RSKangXi=9.9, Def{state}
5042 CJK UNIFIED IDEOGRAPH-#5042, IRGKangXi=0109.210, RSKangXi=9.9
5043 CJK UNIFIED IDEOGRAPH-#5043, IRGKangXi=0109.220, RSKangXi=9.9, Def{cease, lay off, lay down}
5044 CJK UNIFIED IDEOGRAPH-#5044, IRGKangXi=0109.230, RSKangXi=9.9, Def{weak}
5045 CJK UNIFIED IDEOGRAPH-#5045, IRGKangXi=0109.240, RSKangXi=9.9
5046 CJK UNIFIED IDEOGRAPH-#5046, IRGKangXi=0110.010, RSKangXi=9.9
5047 CJK UNIFIED IDEOGRAPH-#5047, IRGKangXi=0110.030, RSKangXi=9.9, Def{falsehood, deception; vacation}
5048 CJK UNIFIED IDEOGRAPH-#5048, IRGKangXi=0110.040, RSKangXi=9.9, Def{brave; martial; hasty; scudding}
5049 CJK UNIFIED IDEOGRAPH-#5049, IRGKangXi=0110.050, RSKangXi=9.9, Def{great, robust; extraordinary}
504A CJK UNIFIED IDEOGRAPH-#504A, IRGKangXi=0110.060, RSKangXi=9.9, Def{to walk alone; self-reliant}
504B CJK UNIFIED IDEOGRAPH-#504B, IRGKangXi=0110.070, RSKangXi=9.9
504C CJK UNIFIED IDEOGRAPH-#504C, IRGKangXi=0110.080, RSKangXi=9.9, Def{thus, so, like, such}
504D CJK UNIFIED IDEOGRAPH-#504D, IRGKangXi=0110.090, RSKangXi=9.9
504E CJK UNIFIED IDEOGRAPH-#504E, IRGKangXi=0110.110, RSKangXi=9.9, Def{cling to, cuddle, embrace, fondle}
504F CJK UNIFIED IDEOGRAPH-#504F, IRGKangXi=0110.160, RSKangXi=9.9, Def{inclined one side; slanting}
5050 CJK UNIFIED IDEOGRAPH-#5050, IRGKangXi=0110.180, RSKangXi=9.9, Def{false, counterfeit, spurious}
5051 CJK UNIFIED IDEOGRAPH-#5051, IRGKangXi=0110.190, RSKangXi=9.9
5052 CJK UNIFIED IDEOGRAPH-#5052, IRGKangXi=0110.200, RSKangXi=9.9
5053 CJK UNIFIED IDEOGRAPH-#5053, IRGKangXi=0110.210, RSKangXi=9.9, Def{to fuss}
5054 CJK UNIFIED IDEOGRAPH-#5054, IRGKangXi=0110.220, RSKangXi=9.9
5055 CJK UNIFIED IDEOGRAPH-#5055, IRGKangXi=0110.230, RSKangXi=9.9, Def{together; be in order}
5056 CJK UNIFIED IDEOGRAPH-#5056, IRGKangXi=0110.240, RSKangXi=9.9, Def{rip up, tear down; raise; haul}
5057 CJK UNIFIED IDEOGRAPH-#5057, IRGKangXi=0110.250, RSKangXi=9.9
5058 CJK UNIFIED IDEOGRAPH-#5058, IRGKangXi=0110.260, RSKangXi=9.9, Def{ancient family name}
5059 CJK UNIFIED IDEOGRAPH-#5059, IRGKangXi=0110.280, RSKangXi=9.9
505A CJK UNIFIED IDEOGRAPH-#505A, IRGKangXi=0110.290, RSKangXi=9.9, Def{work, make; act}
505B CJK UNIFIED IDEOGRAPH-#505B, IRGKangXi=0110.310, RSKangXi=9.9
505C CJK UNIFIED IDEOGRAPH-#505C, IRGKangXi=0110.320, RSKangXi=9.9, Def{stop, suspend, delay; suitable}
505D CJK UNIFIED IDEOGRAPH-#505D, IRGKangXi=0111.010, RSKangXi=9.9, Def{not facing; desert}
505E CJK UNIFIED IDEOGRAPH-#505E, IRGKangXi=0111.030, RSKangXi=9.9
505F CJK UNIFIED IDEOGRAPH-#505F, IRGKangXi=0111.040, RSKangXi=9.9, Def{agitated; alarmed}
5060 CJK UNIFIED IDEOGRAPH-#5060, IRGKangXi=0111.050, RSKangXi=9.9
5061 CJK UNIFIED IDEOGRAPH-#5061, IRGKangXi=0111.060, RSKangXi=9.9
5062 CJK UNIFIED IDEOGRAPH-#5062, IRGKangXi=0111.070, RSKangXi=9.9, Def{to stare at}
5063 CJK UNIFIED IDEOGRAPH-#5063, IRGKangXi=0111.090, RSKangXi=9.9
5064 CJK UNIFIED IDEOGRAPH-#5064, IRGKangXi=0111.100, RSKangXi=9.9
5065 CJK UNIFIED IDEOGRAPH-#5065, IRGKangXi=0111.110, RSKangXi=9.9, Def{strong, robust, healthy; strength}
5066 CJK UNIFIED IDEOGRAPH-#5066, IRGKangXi=0111.150, RSKangXi=9.9
5067 CJK UNIFIED IDEOGRAPH-#5067, IRGKangXi=0111.170, RSKangXi=9.9
5068 CJK UNIFIED IDEOGRAPH-#5068, IRGKangXi=0111.190, RSKangXi=9.9, Def{uneven}
5069 CJK UNIFIED IDEOGRAPH-#5069, IRGKangXi=0111.220, RSKangXi=9.9, Def{follow}
506A CJK UNIFIED IDEOGRAPH-#506A, IRGKangXi=0111.230, RSKangXi=9.9, Def{compel, pressure, force; bother}
506B CJK UNIFIED IDEOGRAPH-#506B, IRGKangXi=0111.240, RSKangXi=9.9, Def{wait for; lay in}
506C CJK UNIFIED IDEOGRAPH-#506C, IRGKangXi=0111.250, RSKangXi=9.9, Def{urgent}
506D CJK UNIFIED IDEOGRAPH-#506D, IRGKangXi=0111.260, RSKangXi=9.9, Def{transgress}
506E CJK UNIFIED IDEOGRAPH-#506E, IRGKangXi=0111.270, RSKangXi=9.9
506F CJK UNIFIED IDEOGRAPH-#506F, IRGKangXi=0111.280, RSKangXi=9.9, Def{sob}
5070 CJK UNIFIED IDEOGRAPH-#5070, IRGKangXi=0111.290, RSKangXi=9.9
5071 CJK UNIFIED IDEOGRAPH-#5071, IRGKangXi=0111.310, RSKangXi=9.9
5072 CJK UNIFIED IDEOGRAPH-#5072, IRGKangXi=0111.320, RSKangXi=9.9, Def{talented; urgent}
5073 CJK UNIFIED IDEOGRAPH-#5073, IRGKangXi=0111.330, RSKangXi=9.9
5074 CJK UNIFIED IDEOGRAPH-#5074, IRGKangXi=0111.340, RSKangXi=9.9, Def{side; incline, slant, lean}
5075 CJK UNIFIED IDEOGRAPH-#5075, IRGKangXi=0111.350, RSKangXi=9.9, Def{spy, reconnoiter; detective}
5076 CJK UNIFIED IDEOGRAPH-#5076, IRGKangXi=0112.010, RSKangXi=9.9, Def{accidentally, coincidently; an idol}
5077 CJK UNIFIED IDEOGRAPH-#5077, IRGKangXi=0112.030, RSKangXi=9.9, Def{to steal, burglar, thief}
5078 CJK UNIFIED IDEOGRAPH-#5078, IRGKangXi=0112.071, RSKangXi=9.9, Def{to steal}
5079 CJK UNIFIED IDEOGRAPH-#5079, IRGKangXi=0112.071, Def{prepare, ready, perfect}
507A CJK UNIFIED IDEOGRAPH-#507A, IRGKangXi=0112.071, RSKangXi=9.9, Def{(same as U+54B1 咱) we, us}
507B CJK UNIFIED IDEOGRAPH-#507B, IRGKangXi=0112.071, RSKangXi=9.9, Def{humpback; surname}
507C CJK UNIFIED IDEOGRAPH-#507C, IRGKangXi=0112.071, RSKangXi=9.9
507D CJK UNIFIED IDEOGRAPH-#507D, IRGKangXi=0112.071, RSKangXi=9.9, Def{false, counterfeit, bogus}
507E CJK UNIFIED IDEOGRAPH-#507E, IRGKangXi=0112.071, RSKangXi=9.9, Def{ruin, cause fail; overthrown}
507F CJK UNIFIED IDEOGRAPH-#507F, IRGKangXi=0112.071, RSKangXi=9.9, Def{repay, recompense; restitution}
5080 CJK UNIFIED IDEOGRAPH-#5080, IRGKangXi=0112.080, RSKangXi=9.10, Def{great, gigantic; puppet}
5081 CJK UNIFIED IDEOGRAPH-#5081, IRGKangXi=0112.090, RSKangXi=9.10, Def{old man}
5082 CJK UNIFIED IDEOGRAPH-#5082, IRGKangXi=0112.110, RSKangXi=9.10
5083 CJK UNIFIED IDEOGRAPH-#5083, IRGKangXi=0112.130, RSKangXi=9.10
5084 CJK UNIFIED IDEOGRAPH-#5084, IRGKangXi=0112.140, RSKangXi=9.10
5085 CJK UNIFIED IDEOGRAPH-#5085, IRGKangXi=0112.190, RSKangXi=9.10, Def{tutor, teacher; assist; surname}
5086 CJK UNIFIED IDEOGRAPH-#5086, IRGKangXi=0112.200, RSKangXi=9.10
5087 CJK UNIFIED IDEOGRAPH-#5087, IRGKangXi=0112.210, RSKangXi=9.10
5088 CJK UNIFIED IDEOGRAPH-#5088, IRGKangXi=0112.220, RSKangXi=9.10, Def{tribe}
5089 CJK UNIFIED IDEOGRAPH-#5089, IRGKangXi=0112.230, RSKangXi=9.10
508A CJK UNIFIED IDEOGRAPH-#508A, IRGKangXi=0112.240, RSKangXi=9.10
508B CJK UNIFIED IDEOGRAPH-#508B, IRGKangXi=0112.260, RSKangXi=9.10
508C CJK UNIFIED IDEOGRAPH-#508C, IRGKangXi=0113.010, RSKangXi=9.10, Def{to curse, to revile, to abuse; to scold}
508D CJK UNIFIED IDEOGRAPH-#508D, IRGKangXi=0113.020, RSKangXi=9.10, Def{by side of, beside, near, close}
508E CJK UNIFIED IDEOGRAPH-#508E, IRGKangXi=0113.050, RSKangXi=9.10, Def{topple}
508F CJK UNIFIED IDEOGRAPH-#508F, IRGKangXi=0113.070, RSKangXi=9.10, Def{to ward off; to parry; to keep out, as wind, rain, or cold}
5090 CJK UNIFIED IDEOGRAPH-#5090, IRGKangXi=0113.080, RSKangXi=9.10
5091 CJK UNIFIED IDEOGRAPH-#5091, IRGKangXi=0113.090, RSKangXi=9.10, Def{hero; outstanding, remarkable}
5092 CJK UNIFIED IDEOGRAPH-#5092, IRGKangXi=0113.130, RSKangXi=9.10, Def{personal name; servant}
5093 CJK UNIFIED IDEOGRAPH-#5093, IRGKangXi=0113.150, RSKangXi=9.10
5094 CJK UNIFIED IDEOGRAPH-#5094, IRGKangXi=0113.160, RSKangXi=9.10, Def{servant}
5095 CJK UNIFIED IDEOGRAPH-#5095, IRGKangXi=0113.170, RSKangXi=9.10, Def{used in old names}
5096 CJK UNIFIED IDEOGRAPH-#5096, IRGKangXi=0113.180, RSKangXi=9.10, Def{vulgar person, country man}
5097 CJK UNIFIED IDEOGRAPH-#5097, IRGKangXi=0113.190, RSKangXi=9.10
5098 CJK UNIFIED IDEOGRAPH-#5098, IRGKangXi=0113.200, RSKangXi=9.10, Def{umbrella, parasol, parachute}
5099 CJK UNIFIED IDEOGRAPH-#5099, IRGKangXi=0113.210, RSKangXi=9.10, Def{prepare, ready, perfect}
509A CJK UNIFIED IDEOGRAPH-#509A, IRGKangXi=0113.240, RSKangXi=9.10, Def{imitate, mimic}
509B CJK UNIFIED IDEOGRAPH-#509B, IRGKangXi=0113.250, RSKangXi=9.10
509C CJK UNIFIED IDEOGRAPH-#509C, IRGKangXi=0113.260, RSKangXi=9.10, Def{a minority tribe}
509D CJK UNIFIED IDEOGRAPH-#509D, IRGKangXi=0113.270, RSKangXi=9.10
509E CJK UNIFIED IDEOGRAPH-#509E, IRGKangXi=0113.280, RSKangXi=9.10, Def{unsteady}
509F CJK UNIFIED IDEOGRAPH-#509F, IRGKangXi=0113.290, RSKangXi=9.10
50A0 CJK UNIFIED IDEOGRAPH-#50A0, IRGKangXi=0113.310, RSKangXi=9.10
50A1 CJK UNIFIED IDEOGRAPH-#50A1, IRGKangXi=0114.051, RSKangXi=9.10
50A2 CJK UNIFIED IDEOGRAPH-#50A2, IRGKangXi=0114.051, RSKangXi=9.10, Def{stubborn, obstinate, intransigent}
50A3 CJK UNIFIED IDEOGRAPH-#50A3, IRGKangXi=0114.051, RSKangXi=9.10, Def{the Dai minority living in South China}
50A4 CJK UNIFIED IDEOGRAPH-#50A4, IRGKangXi=0114.051, RSKangXi=9.13
50A5 CJK UNIFIED IDEOGRAPH-#50A5, IRGKangXi=0114.051, RSKangXi=9.10, Def{if, supposing, in case}
50A6 CJK UNIFIED IDEOGRAPH-#50A6, IRGKangXi=0114.051, RSKangXi=9.10
50A7 CJK UNIFIED IDEOGRAPH-#50A7, IRGKangXi=0114.051, RSKangXi=9.10, Def{entertain guests}
50A8 CJK UNIFIED IDEOGRAPH-#50A8, IRGKangXi=0114.051, RSKangXi=9.10, Def{save money, store, reserve; heir}
50A9 CJK UNIFIED IDEOGRAPH-#50A9, IRGKangXi=0114.051, RSKangXi=9.10, Def{rich}
50AA CJK UNIFIED IDEOGRAPH-#50AA, IRGKangXi=0114.060, RSKangXi=9.11
50AB CJK UNIFIED IDEOGRAPH-#50AB, IRGKangXi=0114.070, RSKangXi=9.11, Def{tired, exhausted; surname}
50AC CJK UNIFIED IDEOGRAPH-#50AC, IRGKangXi=0114.090, RSKangXi=9.11, Def{press, urge}
50AD CJK UNIFIED IDEOGRAPH-#50AD, IRGKangXi=0114.110, RSKangXi=9.11, Def{hire, employ, charter; servant}
50AE CJK UNIFIED IDEOGRAPH-#50AE, IRGKangXi=0114.120, RSKangXi=9.11, Def{finish, to go around}
50AF CJK UNIFIED IDEOGRAPH-#50AF, IRGKangXi=0114.150, RSKangXi=9.11, Def{urgent}
50B0 CJK UNIFIED IDEOGRAPH-#50B0, IRGKangXi=0114.160, RSKangXi=9.11
50B1 CJK UNIFIED IDEOGRAPH-#50B1, IRGKangXi=0114.170, RSKangXi=9.11
50B2 CJK UNIFIED IDEOGRAPH-#50B2, IRGKangXi=0114.190, RSKangXi=9.11, Def{proud, haughty, overbearing}
50B3 CJK UNIFIED IDEOGRAPH-#50B3, IRGKangXi=0114.230, RSKangXi=9.11, Def{summon; propagate, transmit}
50B4 CJK UNIFIED IDEOGRAPH-#50B4, IRGKangXi=0114.240, RSKangXi=9.11, Def{humpback; stoop}
50B5 CJK UNIFIED IDEOGRAPH-#50B5, IRGKangXi=0114.260, RSKangXi=9.11, Def{debt, loan, liabilities}
50B6 CJK UNIFIED IDEOGRAPH-#50B6, IRGKangXi=0114.280, RSKangXi=9.11
50B7 CJK UNIFIED IDEOGRAPH-#50B7, IRGKangXi=0115.010, RSKangXi=9.11, Def{wound, injury; fall ill from}
50B8 CJK UNIFIED IDEOGRAPH-#50B8, IRGKangXi=0115.030, RSKangXi=9.11
50B9 CJK UNIFIED IDEOGRAPH-#50B9, IRGKangXi=0115.040, RSKangXi=9.11
50BA CJK UNIFIED IDEOGRAPH-#50BA, IRGKangXi=0115.050, RSKangXi=9.11, Def{to hinder; to detain}
50BB CJK UNIFIED IDEOGRAPH-#50BB, IRGKangXi=0115.060, RSKangXi=9.11, Def{foolish, silly, stupid; an imbecile}
50BC CJK UNIFIED IDEOGRAPH-#50BC, IRGKangXi=0115.070, RSKangXi=9.11, Def{surname}
50BD CJK UNIFIED IDEOGRAPH-#50BD, IRGKangXi=0115.090, RSKangXi=9.11, Def{terror-stricken}
50BE CJK UNIFIED IDEOGRAPH-#50BE, IRGKangXi=0115.100, RSKangXi=9.11, Def{upset, pour out, overflow}
50BF CJK UNIFIED IDEOGRAPH-#50BF, IRGKangXi=0115.110, RSKangXi=9.11
50C0 CJK UNIFIED IDEOGRAPH-#50C0, IRGKangXi=0115.140, RSKangXi=9.11
50C1 CJK UNIFIED IDEOGRAPH-#50C1, IRGKangXi=0115.160, RSKangXi=9.11
50C2 CJK UNIFIED IDEOGRAPH-#50C2, IRGKangXi=0115.170, RSKangXi=9.11, Def{humpback; surname}
50C3 CJK UNIFIED IDEOGRAPH-#50C3, IRGKangXi=0115.180, RSKangXi=9.11, Def{prepared}
50C4 CJK UNIFIED IDEOGRAPH-#50C4, IRGKangXi=0115.190, RSKangXi=9.11, Def{light; airy}
50C5 CJK UNIFIED IDEOGRAPH-#50C5, IRGKangXi=0115.200, RSKangXi=9.11, Def{only, merely, solely, just}
50C6 CJK UNIFIED IDEOGRAPH-#50C6, IRGKangXi=0115.210, RSKangXi=9.11
50C7 CJK UNIFIED IDEOGRAPH-#50C7, IRGKangXi=0115.230, RSKangXi=9.11, Def{humiliate; treat with contempt}
50C8 CJK UNIFIED IDEOGRAPH-#50C8, IRGKangXi=0115.240, RSKangXi=9.11, Def{negligent, remiss}
50C9 CJK UNIFIED IDEOGRAPH-#50C9, IRGKangXi=0115.270, RSKangXi=9.11, Def{all, together, unanimous}
50CA CJK UNIFIED IDEOGRAPH-#50CA, IRGKangXi=0115.290, RSKangXi=9.11, Def{Taoist super-being, transcendent, immortal}
50CB CJK UNIFIED IDEOGRAPH-#50CB, IRGKangXi=0115.300, RSKangXi=9.11
50CC CJK UNIFIED IDEOGRAPH-#50CC, IRGKangXi=0115.340, RSKangXi=9.11
50CD CJK UNIFIED IDEOGRAPH-#50CD, IRGKangXi=0116.041, RSKangXi=9.11, Def{labor; work}
50CE CJK UNIFIED IDEOGRAPH-#50CE, IRGKangXi=0116.070, RSKangXi=9.12, Def{collect}
50CF CJK UNIFIED IDEOGRAPH-#50CF, IRGKangXi=0116.080, RSKangXi=9.12, Def{a picture, image, figure; to resemble}
50D0 CJK UNIFIED IDEOGRAPH-#50D0, IRGKangXi=0116.110, RSKangXi=9.12
50D1 CJK UNIFIED IDEOGRAPH-#50D1, IRGKangXi=0116.120, RSKangXi=9.12, Def{sojourn, lodge}
50D2 CJK UNIFIED IDEOGRAPH-#50D2, IRGKangXi=0116.130, RSKangXi=9.12
50D3 CJK UNIFIED IDEOGRAPH-#50D3, IRGKangXi=0116.140, RSKangXi=9.12
50D4 CJK UNIFIED IDEOGRAPH-#50D4, IRGKangXi=0116.170, RSKangXi=9.12
50D5 CJK UNIFIED IDEOGRAPH-#50D5, IRGKangXi=0116.180, RSKangXi=9.12, Def{slave, servant, I}
50D6 CJK UNIFIED IDEOGRAPH-#50D6, IRGKangXi=0116.200, RSKangXi=9.12, Def{joy, gladness, delight; surname}
50D7 CJK UNIFIED IDEOGRAPH-#50D7, IRGKangXi=0116.210, RSKangXi=9.12
50D8 CJK UNIFIED IDEOGRAPH-#50D8, IRGKangXi=0116.220, RSKangXi=9.12
50D9 CJK UNIFIED IDEOGRAPH-#50D9, IRGKangXi=0116.230, RSKangXi=9.12
50DA CJK UNIFIED IDEOGRAPH-#50DA, IRGKangXi=0116.250, RSKangXi=9.12, Def{companion, colleague; officials; bureaucracy; a pretty face}
50DB CJK UNIFIED IDEOGRAPH-#50DB, IRGKangXi=0116.260, RSKangXi=9.12
50DC CJK UNIFIED IDEOGRAPH-#50DC, IRGKangXi=0116.270, RSKangXi=9.12
50DD CJK UNIFIED IDEOGRAPH-#50DD, IRGKangXi=0116.280, RSKangXi=9.12, Def{to revile; to abuse}
50DE CJK UNIFIED IDEOGRAPH-#50DE, IRGKangXi=0117.020, RSKangXi=9.12, Def{false, counterfeit, bogus}
50DF CJK UNIFIED IDEOGRAPH-#50DF, IRGKangXi=0117.030, RSKangXi=9.12
50E0 CJK UNIFIED IDEOGRAPH-#50E0, IRGKangXi=0117.040, RSKangXi=9.12
50E1 CJK UNIFIED IDEOGRAPH-#50E1, IRGKangXi=0117.050, RSKangXi=9.12
50E2 CJK UNIFIED IDEOGRAPH-#50E2, IRGKangXi=0117.070, RSKangXi=9.12
50E3 CJK UNIFIED IDEOGRAPH-#50E3, IRGKangXi=0117.080, RSKangXi=9.12, Def{assume, usurp}
50E4 CJK UNIFIED IDEOGRAPH-#50E4, IRGKangXi=0117.090, RSKangXi=9.12, Def{sincere}
50E5 CJK UNIFIED IDEOGRAPH-#50E5, IRGKangXi=0117.100, RSKangXi=9.12, Def{be lucky; by chance, by luck}
50E6 CJK UNIFIED IDEOGRAPH-#50E6, IRGKangXi=0117.120, RSKangXi=9.12, Def{to heir; to rent}
50E7 CJK UNIFIED IDEOGRAPH-#50E7, IRGKangXi=0117.140, RSKangXi=9.12, Def{Buddhist priest, monk; san of Sanskrit sangha}
50E8 CJK UNIFIED IDEOGRAPH-#50E8, IRGKangXi=0117.160, RSKangXi=9.12, Def{ruin, cause fail; overthrown}
50E9 CJK UNIFIED IDEOGRAPH-#50E9, IRGKangXi=0117.190, RSKangXi=9.12, Def{courageous; martial; dignified}
50EA CJK UNIFIED IDEOGRAPH-#50EA, IRGKangXi=0117.200, RSKangXi=9.12
50EB CJK UNIFIED IDEOGRAPH-#50EB, IRGKangXi=0117.230, RSKangXi=9.12
50EC CJK UNIFIED IDEOGRAPH-#50EC, IRGKangXi=0117.240, RSKangXi=9.12, Def{clever; alert in mind pigmies}
50ED CJK UNIFIED IDEOGRAPH-#50ED, IRGKangXi=0117.260, RSKangXi=9.12, Def{assume, usurp}
50EE CJK UNIFIED IDEOGRAPH-#50EE, IRGKangXi=0117.300, RSKangXi=9.12, Def{page, boy servant}
50EF CJK UNIFIED IDEOGRAPH-#50EF, IRGKangXi=0117.310, RSKangXi=9.12, Def{ashamed}
50F0 CJK UNIFIED IDEOGRAPH-#50F0, IRGKangXi=0118.010, RSKangXi=9.12, Def{ancient aboriginal tribe}
50F1 CJK UNIFIED IDEOGRAPH-#50F1, IRGKangXi=0118.051, RSKangXi=9.12, Def{employ, hire}
50F2 CJK UNIFIED IDEOGRAPH-#50F2, IRGKangXi=0118.051, RSKangXi=9.13
50F3 CJK UNIFIED IDEOGRAPH-#50F3, IRGKangXi=0118.051, RSKangXi=9.12, Def{minority name}
50F4 CJK UNIFIED IDEOGRAPH-#50F4, IRGKangXi=0118.051, RSKangXi=9.12
50F5 CJK UNIFIED IDEOGRAPH-#50F5, IRGKangXi=0118.060, RSKangXi=9.13, Def{stiff and motionless, stock still}
50F6 CJK UNIFIED IDEOGRAPH-#50F6, IRGKangXi=0118.070, RSKangXi=9.13, Def{forcefully}
50F7 CJK UNIFIED IDEOGRAPH-#50F7, IRGKangXi=0118.080, RSKangXi=9.13
50F8 CJK UNIFIED IDEOGRAPH-#50F8, IRGKangXi=0118.090, RSKangXi=9.13
50F9 CJK UNIFIED IDEOGRAPH-#50F9, IRGKangXi=0118.110, RSKangXi=9.13, Def{price, value}
50FA CJK UNIFIED IDEOGRAPH-#50FA, IRGKangXi=0118.130, RSKangXi=9.13
50FB CJK UNIFIED IDEOGRAPH-#50FB, IRGKangXi=0118.140, RSKangXi=9.13, Def{out-of-the-way, remote; unorthodox}
50FC CJK UNIFIED IDEOGRAPH-#50FC, IRGKangXi=0118.160, RSKangXi=9.13
50FD CJK UNIFIED IDEOGRAPH-#50FD, IRGKangXi=0118.170, RSKangXi=9.13
50FE CJK UNIFIED IDEOGRAPH-#50FE, IRGKangXi=0119.231, RSKangXi=9.13, Def{like}
50FF CJK UNIFIED IDEOGRAPH-#50FF, IRGKangXi=0118.200, RSKangXi=9.13, Def{small, minute; lacking sincerity}
5100 CJK UNIFIED IDEOGRAPH-#5100, IRGKangXi=0118.210, RSKangXi=9.13, Def{ceremony, rites gifts; admire}
5101 CJK UNIFIED IDEOGRAPH-#5101, IRGKangXi=0118.240, RSKangXi=9.13, Def{outstanding, fine; superior; talented, capable; handsome}
5102 CJK UNIFIED IDEOGRAPH-#5102, IRGKangXi=0118.250, RSKangXi=9.13, Def{I; you; family name}
5103 CJK UNIFIED IDEOGRAPH-#5103, IRGKangXi=0118.260, RSKangXi=9.13
5104 CJK UNIFIED IDEOGRAPH-#5104, IRGKangXi=0118.270, RSKangXi=9.13, PrimaryNumeric=100000000, Def{hundred million; many}
5105 CJK UNIFIED IDEOGRAPH-#5105, IRGKangXi=0119.020, RSKangXi=9.13, Def{stop}
5106 CJK UNIFIED IDEOGRAPH-#5106, IRGKangXi=0119.090, RSKangXi=9.13, Def{warn; warning}
5107 CJK UNIFIED IDEOGRAPH-#5107, IRGKangXi=0119.100, RSKangXi=9.13, Def{clever, nimble}
5108 CJK UNIFIED IDEOGRAPH-#5108, IRGKangXi=0119.110, RSKangXi=9.13, Def{go-between, broker, proxy}
5109 CJK UNIFIED IDEOGRAPH-#5109, IRGKangXi=0119.120, RSKangXi=9.13, Def{temperate, frugal, economical}
510A CJK UNIFIED IDEOGRAPH-#510A, IRGKangXi=0119.160, RSKangXi=9.13, Def{rough and rugged}
510B CJK UNIFIED IDEOGRAPH-#510B, IRGKangXi=0119.180, RSKangXi=9.13, Def{a small jar; to bear a burden; a load of two}
510C CJK UNIFIED IDEOGRAPH-#510C, IRGKangXi=0119.190, RSKangXi=9.13, Def{lucky, fortunate}
510D CJK UNIFIED IDEOGRAPH-#510D, IRGKangXi=0119.231, RSKangXi=9.13, Def{foolish, silly, an imbecile}
510E CJK UNIFIED IDEOGRAPH-#510E, IRGKangXi=0119.231, RSKangXi=9.13, Def{carry, contain, load}
510F CJK UNIFIED IDEOGRAPH-#510F, IRGKangXi=0119.231, RSKangXi=9.13
5110 CJK UNIFIED IDEOGRAPH-#5110, IRGKangXi=0119.240, RSKangXi=9.14, Def{entertain guests}
5111 CJK UNIFIED IDEOGRAPH-#5111, IRGKangXi=0119.260, RSKangXi=9.14
5112 CJK UNIFIED IDEOGRAPH-#5112, IRGKangXi=0119.300, RSKangXi=9.14, Def{Confucian scholar}
5113 CJK UNIFIED IDEOGRAPH-#5113, IRGKangXi=0119.330, RSKangXi=9.14, Def{servant}
5114 CJK UNIFIED IDEOGRAPH-#5114, IRGKangXi=0119.340, RSKangXi=9.14, Def{companion, mate, colleague}
5115 CJK UNIFIED IDEOGRAPH-#5115, IRGKangXi=0119.380, RSKangXi=9.14, Def{a company, companion; together}
5116 CJK UNIFIED IDEOGRAPH-#5116, IRGKangXi=0120.010, RSKangXi=9.14
5117 CJK UNIFIED IDEOGRAPH-#5117, IRGKangXi=0120.050, RSKangXi=9.14, Def{compare with, draw analogy with}
5118 CJK UNIFIED IDEOGRAPH-#5118, IRGKangXi=0120.060, RSKangXi=9.14, Def{utmost}
5119 CJK UNIFIED IDEOGRAPH-#5119, IRGKangXi=0120.070, RSKangXi=9.14
511A CJK UNIFIED IDEOGRAPH-#511A, IRGKangXi=0120.080, RSKangXi=9.14, Def{(J) equivalent to 果敢 U+679C U+6562, fleeting, momentary, ephemeral; vain, empty; fickle}
511B CJK UNIFIED IDEOGRAPH-#511B, IRGKangXi=0120.090, RSKangXi=9.14, Def{to skip about, to dance for joy}
511C CJK UNIFIED IDEOGRAPH-#511C, IRGKangXi=0120.100, RSKangXi=9.14, Def{weak; wearied; in distress}
511D CJK UNIFIED IDEOGRAPH-#511D, IRGKangXi=0120.111, RSKangXi=9.14
511E CJK UNIFIED IDEOGRAPH-#511E, IRGKangXi=0120.111, RSKangXi=9.14
511F CJK UNIFIED IDEOGRAPH-#511F, IRGKangXi=0120.120, RSKangXi=9.15, Def{repay, recompense; restitution}
5120 CJK UNIFIED IDEOGRAPH-#5120, IRGKangXi=0120.130, RSKangXi=9.15
5121 CJK UNIFIED IDEOGRAPH-#5121, IRGKangXi=0120.160, RSKangXi=9.15, Def{puppet, dummy}
5122 CJK UNIFIED IDEOGRAPH-#5122, IRGKangXi=0120.180, RSKangXi=9.15
5123 CJK UNIFIED IDEOGRAPH-#5123, IRGKangXi=0120.200, RSKangXi=9.15
5124 CJK UNIFIED IDEOGRAPH-#5124, IRGKangXi=0120.210, RSKangXi=9.15, Def{on duty}
5125 CJK UNIFIED IDEOGRAPH-#5125, IRGKangXi=0120.220, RSKangXi=9.15
5126 CJK UNIFIED IDEOGRAPH-#5126, IRGKangXi=0120.240, RSKangXi=9.15, Def{milling}
5127 CJK UNIFIED IDEOGRAPH-#5127, IRGKangXi=0120.250, RSKangXi=9.15
5128 CJK UNIFIED IDEOGRAPH-#5128, IRGKangXi=0120.260, RSKangXi=9.15
5129 CJK UNIFIED IDEOGRAPH-#5129, IRGKangXi=0120.270, RSKangXi=9.15, Def{complete}
512A CJK UNIFIED IDEOGRAPH-#512A, IRGKangXi=0120.280, RSKangXi=9.15, Def{superior, excellent; actor}
512B CJK UNIFIED IDEOGRAPH-#512B, IRGKangXi=0121.040, RSKangXi=9.15
512C CJK UNIFIED IDEOGRAPH-#512C, IRGKangXi=0121.061, RSKangXi=9.15
512D CJK UNIFIED IDEOGRAPH-#512D, IRGKangXi=0121.100, RSKangXi=9.16, Def{to assist; to give alms}
512E CJK UNIFIED IDEOGRAPH-#512E, IRGKangXi=0121.110, RSKangXi=9.16
512F CJK UNIFIED IDEOGRAPH-#512F, IRGKangXi=0121.130, RSKangXi=9.16
5130 CJK UNIFIED IDEOGRAPH-#5130, IRGKangXi=0121.160, RSKangXi=9.16
5131 CJK UNIFIED IDEOGRAPH-#5131, IRGKangXi=0121.170, RSKangXi=9.16, Def{rude; barbarous}
5132 CJK UNIFIED IDEOGRAPH-#5132, IRGKangXi=0121.200, RSKangXi=9.16, Def{to save money, store, reserve; an heir}
5133 CJK UNIFIED IDEOGRAPH-#5133, IRGKangXi=0121.260, RSKangXi=9.17, Def{obstinate; stupid; uneven; mix}
5134 CJK UNIFIED IDEOGRAPH-#5134, IRGKangXi=0121.270, RSKangXi=9.17
5135 CJK UNIFIED IDEOGRAPH-#5135, IRGKangXi=0121.290, RSKangXi=9.17
5136 CJK UNIFIED IDEOGRAPH-#5136, IRGKangXi=0121.320, RSKangXi=9.18, Def{valiant, brave; eminent}
5137 CJK UNIFIED IDEOGRAPH-#5137, IRGKangXi=0121.360, RSKangXi=9.19, Def{spouse, couple, pair}
5138 CJK UNIFIED IDEOGRAPH-#5138, IRGKangXi=0121.380, RSKangXi=9.19, Def{bandit, daredevil}
5139 CJK UNIFIED IDEOGRAPH-#5139, IRGKangXi=0121.400, RSKangXi=9.19, Def{to accumulate, to hoard, to store up}
513A CJK UNIFIED IDEOGRAPH-#513A, IRGKangXi=0121.420, RSKangXi=9.19, Def{rich}
513B CJK UNIFIED IDEOGRAPH-#513B, IRGKangXi=0122.040, RSKangXi=9.20, Def{if, supposing, in case}
513C CJK UNIFIED IDEOGRAPH-#513C, IRGKangXi=0122.050, RSKangXi=9.20, Def{grave, respectful, majestic}
513D CJK UNIFIED IDEOGRAPH-#513D, IRGKangXi=0122.080, RSKangXi=9.21, Def{lazy; tired out, worn fatigued}
513E CJK UNIFIED IDEOGRAPH-#513E, IRGKangXi=0122.110, RSKangXi=9.22, Def{slow, dull; irresolute}
513F CJK UNIFIED IDEOGRAPH-#513F, IRGKangXi=0123.010, RSKangXi=10.0, Def{son, child; KangXi radical 10}
5140 CJK UNIFIED IDEOGRAPH-#5140, IRGKangXi=0123.020, RSKangXi=10.1, Def{to cut off the feet}
5141 CJK UNIFIED IDEOGRAPH-#5141, IRGKangXi=0123.030, RSKangXi=10.2, Def{to grant, to allow, to consent}
5142 CJK UNIFIED IDEOGRAPH-#5142, IRGKangXi=0123.050, RSKangXi=10.2, Def{hairpin, clasp; wear in hair}
5143 CJK UNIFIED IDEOGRAPH-#5143, IRGKangXi=0123.060, RSKangXi=10.2, Def{first; dollar; origin; head}
5144 CJK UNIFIED IDEOGRAPH-#5144, IRGKangXi=0123.090, RSKangXi=10.3, Def{elder brother}
5145 CJK UNIFIED IDEOGRAPH-#5145, IRGKangXi=0124.010, RSKangXi=10.4, Def{fill, be full, supply}
5146 CJK UNIFIED IDEOGRAPH-#5146, IRGKangXi=0124.030, RSKangXi=10.4, PrimaryNumeric=1000000000000, Def{omen; million; mega; also trillion. China = million; Japan and Taiwan = trillion}
5147 CJK UNIFIED IDEOGRAPH-#5147, IRGKangXi=0124.040, RSKangXi=10.4, Def{atrocious, ferocious, brutal}
5148 CJK UNIFIED IDEOGRAPH-#5148, IRGKangXi=0124.050, RSKangXi=10.4, Def{first, former, previous}
5149 CJK UNIFIED IDEOGRAPH-#5149, IRGKangXi=0124.060, RSKangXi=10.4, Def{light, brilliant, shine; only}
514A CJK UNIFIED IDEOGRAPH-#514A, IRGKangXi=0124.110, RSKangXi=10.4
514B CJK UNIFIED IDEOGRAPH-#514B, IRGKangXi=0124.150, RSKangXi=10.5, Def{gram; overcome; transliteration}
514C CJK UNIFIED IDEOGRAPH-#514C, IRGKangXi=0124.210, RSKangXi=10.5, Def{cash; exchange, barter; weight}
514D CJK UNIFIED IDEOGRAPH-#514D, IRGKangXi=0124.230, RSKangXi=10.5, Def{spare; excuse from; evade}
514E CJK UNIFIED IDEOGRAPH-#514E, IRGKangXi=0124.240, RSKangXi=10.5, Def{rabbit, hare}
514F CJK UNIFIED IDEOGRAPH-#514F, IRGKangXi=0125.010, RSKangXi=10.5
5150 CJK UNIFIED IDEOGRAPH-#5150, IRGKangXi=0125.021, RSKangXi=10.5, Def{son, child, oneself; final part}
5151 CJK UNIFIED IDEOGRAPH-#5151, IRGKangXi=0125.021, RSKangXi=10.5, Def{cash; exchange}
5152 CJK UNIFIED IDEOGRAPH-#5152, IRGKangXi=0125.030, RSKangXi=10.6, Def{son, child, oneself; final part}
5153 CJK UNIFIED IDEOGRAPH-#5153, IRGKangXi=0125.050, RSKangXi=10.6
5154 CJK UNIFIED IDEOGRAPH-#5154, IRGKangXi=0125.060, RSKangXi=10.6, Def{rabbit, hare}
5155 CJK UNIFIED IDEOGRAPH-#5155, IRGKangXi=0125.070, RSKangXi=10.6, Def{a female rhinoceros}
5156 CJK UNIFIED IDEOGRAPH-#5156, IRGKangXi=0125.131, RSKangXi=10.6, Def{establish; one of nine empire divisions}
5157 CJK UNIFIED IDEOGRAPH-#5157, IRGKangXi=0125.150, RSKangXi=10.7, Def{establish; one of nine empire divisions}
5158 CJK UNIFIED IDEOGRAPH-#5158, IRGKangXi=0125.170, RSKangXi=10.7
5159 CJK UNIFIED IDEOGRAPH-#5159, IRGKangXi=0125.171, RSKangXi=10.7, Def{decagram}
515A CJK UNIFIED IDEOGRAPH-#515A, IRGKangXi=0125.180, RSKangXi=10.8, Def{political party, gang, faction}
515B CJK UNIFIED IDEOGRAPH-#515B, IRGKangXi=0125.191, RSKangXi=10.8, Def{kilogram}
515C CJK UNIFIED IDEOGRAPH-#515C, IRGKangXi=0125.200, RSKangXi=10.9, Def{pouch}
515D CJK UNIFIED IDEOGRAPH-#515D, IRGKangXi=0125.201, RSKangXi=10.9, Def{decigram}
515E CJK UNIFIED IDEOGRAPH-#515E, IRGKangXi=0125.201, RSKangXi=10.9, Def{milligram}
515F CJK UNIFIED IDEOGRAPH-#515F, IRGKangXi=0125.210, RSKangXi=10.10, Def{to advance}
5160 CJK UNIFIED IDEOGRAPH-#5160, IRGKangXi=0125.211, RSKangXi=16.10
5161 CJK UNIFIED IDEOGRAPH-#5161, IRGKangXi=0125.211, RSKangXi=10.11, Def{mercury (chemical element)}
5162 CJK UNIFIED IDEOGRAPH-#5162, IRGKangXi=0125.220, RSKangXi=10.12, Def{fearful, cautious, wary}
5163 CJK UNIFIED IDEOGRAPH-#5163, IRGKangXi=0125.281, RSKangXi=10.14, Def{decigram; centigram}
5164 CJK UNIFIED IDEOGRAPH-#5164, IRGKangXi=0125.300, RSKangXi=10.19
5165 CJK UNIFIED IDEOGRAPH-#5165, IRGKangXi=0125.320, RSKangXi=11.0, Def{enter, come in(to), join}
5166 CJK UNIFIED IDEOGRAPH-#5166, IRGKangXi=0125.340, RSKangXi=11.1, Def{destruction}
5167 CJK UNIFIED IDEOGRAPH-#5167, IRGKangXi=0125.350, RSKangXi=11.2, Def{inside, interior; domestic}
5168 CJK UNIFIED IDEOGRAPH-#5168, IRGKangXi=0126.050, RSKangXi=11.4, Def{maintain, keep whole or intact}
5169 CJK UNIFIED IDEOGRAPH-#5169, IRGKangXi=0126.130, RSKangXi=11.6, Def{two, both, pair, couple; ounce}
516A CJK UNIFIED IDEOGRAPH-#516A, IRGKangXi=0126.150, RSKangXi=11.7, Def{surname; consent}
516B CJK UNIFIED IDEOGRAPH-#516B, IRGKangXi=0126.260, RSKangXi=12.0, PrimaryNumeric=8, Def{eight; all around, all sides}
516C CJK UNIFIED IDEOGRAPH-#516C, IRGKangXi=0126.280, RSKangXi=12.2, Def{fair, equitable; public; duke}
516D CJK UNIFIED IDEOGRAPH-#516D, IRGKangXi=0127.010, RSKangXi=12.2, PrimaryNumeric=6, Def{number six}
516E CJK UNIFIED IDEOGRAPH-#516E, IRGKangXi=0127.030, RSKangXi=12.2, Def{exclamatory particle}
516F CJK UNIFIED IDEOGRAPH-#516F, IRGKangXi=0079.091, RSKangXi=26.2, Def{kwukyel}
5170 CJK UNIFIED IDEOGRAPH-#5170, IRGKangXi=0078.021, RSKangXi=12.3, Def{orchid; elegant, graceful}
5171 CJK UNIFIED IDEOGRAPH-#5171, IRGKangXi=0127.050, RSKangXi=12.4, Def{together with, all, total; to share}
5172 CJK UNIFIED IDEOGRAPH-#5172, IRGKangXi=0127.090, RSKangXi=12.4, Def{heaven; sky}
5173 CJK UNIFIED IDEOGRAPH-#5173, IRGKangXi=0250.071, RSKangXi=12.4, Def{frontier pass; close; relation}
5174 CJK UNIFIED IDEOGRAPH-#5174, IRGKangXi=0127.091, RSKangXi=12.4, Def{thrive, prosper, flourish}
5175 CJK UNIFIED IDEOGRAPH-#5175, IRGKangXi=0127.100, RSKangXi=12.5, Def{soldier, troops}
5176 CJK UNIFIED IDEOGRAPH-#5176, IRGKangXi=0127.180, RSKangXi=12.6, Def{his, her, its, their; that}
5177 CJK UNIFIED IDEOGRAPH-#5177, IRGKangXi=0128.010, RSKangXi=12.6, Def{tool, implement; draw up, write}
5178 CJK UNIFIED IDEOGRAPH-#5178, IRGKangXi=0128.020, RSKangXi=12.6, Def{law, canon; documentation; classic, scripture}
5179 CJK UNIFIED IDEOGRAPH-#5179, IRGKangXi=1031.381, RSKangXi=140.6, Def{now, here; this; time, year}
517A CJK UNIFIED IDEOGRAPH-#517A, IRGKangXi=0128.101, RSKangXi=12.8
517B CJK UNIFIED IDEOGRAPH-#517B, IRGKangXi=0951.151, RSKangXi=12.7, Def{raise, rear, bring up; support}
517C CJK UNIFIED IDEOGRAPH-#517C, IRGKangXi=0128.110, RSKangXi=12.8, Def{unite, combine; connect; and}
517D CJK UNIFIED IDEOGRAPH-#517D, IRGKangXi=0196.261, RSKangXi=12.9, Def{beast, animal; bestial}
517E CJK UNIFIED IDEOGRAPH-#517E, IRGKangXi=0128.200, RSKangXi=12.11, Def{same as 冀 U+5180 to hope for; to wish}
517F CJK UNIFIED IDEOGRAPH-#517F, IRGKangXi=1052.051, RSKangXi=28.11
5180 CJK UNIFIED IDEOGRAPH-#5180, IRGKangXi=0128.240, RSKangXi=12.14, Def{hope for; wish; Hebei province}
5181 CJK UNIFIED IDEOGRAPH-#5181, IRGKangXi=0157.201, RSKangXi=12.16, Def{smile}
5182 CJK UNIFIED IDEOGRAPH-#5182, IRGKangXi=0128.300, RSKangXi=13.0, Def{wide; KangXi radical 13}
5183 CJK UNIFIED IDEOGRAPH-#5183, IRGKangXi=0128.320, RSKangXi=13.2
5184 CJK UNIFIED IDEOGRAPH-#5184, IRGKangXi=0128.330, RSKangXi=13.2, Def{tender; weak; gradually alternating}
5185 CJK UNIFIED IDEOGRAPH-#5185, IRGKangXi=0128.351, RSKangXi=11.2, Def{inside}
5186 CJK UNIFIED IDEOGRAPH-#5186, IRGKangXi=0128.351, RSKangXi=13.2, Def{yen}
5187 CJK UNIFIED IDEOGRAPH-#5187, IRGKangXi=0128.351, RSKangXi=1.3, Def{(Cant.) have not}
5188 CJK UNIFIED IDEOGRAPH-#5188, IRGKangXi=0128.351, RSKangXi=13.2, Def{ridge or crest of hill}
5189 CJK UNIFIED IDEOGRAPH-#5189, IRGKangXi=0128.360, RSKangXi=13.3, Def{tender; weak; proceed gradually}
518A CJK UNIFIED IDEOGRAPH-#518A, IRGKangXi=0129.051, RSKangXi=13.3, Def{book, volume}
518B CJK UNIFIED IDEOGRAPH-#518B, IRGKangXi=0129.020, RSKangXi=13.3, Def{a desert, a border}
518C CJK UNIFIED IDEOGRAPH-#518C, IRGKangXi=0129.051, RSKangXi=13.3, Def{book, volume, register, list}
518D CJK UNIFIED IDEOGRAPH-#518D, IRGKangXi=0129.080, RSKangXi=13.4, Def{again, twice, re-}
518E CJK UNIFIED IDEOGRAPH-#518E, IRGKangXi=0129.090, RSKangXi=13.4
518F CJK UNIFIED IDEOGRAPH-#518F, IRGKangXi=0129.120, RSKangXi=13.5, Def{(archaic form of U+70AF 炯) light, bright}
5190 CJK UNIFIED IDEOGRAPH-#5190, IRGKangXi=0129.170, RSKangXi=13.6, Def{risk, brave, dare}
5191 CJK UNIFIED IDEOGRAPH-#5191, IRGKangXi=0129.200, RSKangXi=13.7, Def{helmet}
5192 CJK UNIFIED IDEOGRAPH-#5192, IRGKangXi=0129.210, RSKangXi=13.7, Def{risk, brave, dare}
5193 CJK UNIFIED IDEOGRAPH-#5193, IRGKangXi=0129.250, RSKangXi=13.8, Def{a secluded place; secret cabinet}
5194 CJK UNIFIED IDEOGRAPH-#5194, IRGKangXi=0129.270, RSKangXi=13.8, Def{cap worn during the Yin dynasty}
5195 CJK UNIFIED IDEOGRAPH-#5195, IRGKangXi=0129.300, RSKangXi=13.9, Def{crown; ceremonial cap}
5196 CJK UNIFIED IDEOGRAPH-#5196, IRGKangXi=0130.120, RSKangXi=14.0, Def{cover; KangXi radical 14}
5197 CJK UNIFIED IDEOGRAPH-#5197, IRGKangXi=0130.130, RSKangXi=14.2, Def{excessive; superfluous}
5198 CJK UNIFIED IDEOGRAPH-#5198, IRGKangXi=0130.140, RSKangXi=14.2, Def{to move on; coubtful}
5199 CJK UNIFIED IDEOGRAPH-#5199, IRGKangXi=0130.161, RSKangXi=14.3, Def{write; draw, sketch; compose}
519A CJK UNIFIED IDEOGRAPH-#519A, IRGKangXi=0130.161, RSKangXi=14.3, Def{(Cant.) cover, lid}
519B CJK UNIFIED IDEOGRAPH-#519B, IRGKangXi=0130.191, RSKangXi=159.2, Def{army, military; soldiers, troops}
519C CJK UNIFIED IDEOGRAPH-#519C, IRGKangXi=0130.191, RSKangXi=14.4, Def{agriculture, farming; farmer}
519D CJK UNIFIED IDEOGRAPH-#519D, IRGKangXi=0130.191, RSKangXi=14.5, Def{suitable, right, fitting, proper}
519E CJK UNIFIED IDEOGRAPH-#519E, IRGKangXi=0130.210, RSKangXi=14.6, Def{far}
519F CJK UNIFIED IDEOGRAPH-#519F, IRGKangXi=0130.220, RSKangXi=14.7
51A0 CJK UNIFIED IDEOGRAPH-#51A0, IRGKangXi=0130.230, RSKangXi=14.7, Def{cap, crown, headgear}
51A1 CJK UNIFIED IDEOGRAPH-#51A1, IRGKangXi=0130.240, RSKangXi=14.8
51A2 CJK UNIFIED IDEOGRAPH-#51A2, IRGKangXi=0130.250, RSKangXi=14.8, Def{burial mound, mausoleum; grand}
51A3 CJK UNIFIED IDEOGRAPH-#51A3, IRGKangXi=0130.260, RSKangXi=14.8
51A4 CJK UNIFIED IDEOGRAPH-#51A4, IRGKangXi=0130.270, RSKangXi=14.8, Def{grievance, injustice, wrong}
51A5 CJK UNIFIED IDEOGRAPH-#51A5, IRGKangXi=0130.280, RSKangXi=14.8, Def{dark, gloomy, night; deep}
51A6 CJK UNIFIED IDEOGRAPH-#51A6, IRGKangXi=0131.011, RSKangXi=14.8, Def{bandits, thieves; enemy; invade}
51A7 CJK UNIFIED IDEOGRAPH-#51A7, IRGKangXi=0131.011, RSKangXi=14.8, Def{(Cant.) a bud; to bend; phonetic 'num' as in 'number'}
51A8 CJK UNIFIED IDEOGRAPH-#51A8, IRGKangXi=0131.030, RSKangXi=14.9, Def{abundant, ample; rich, wealthy}
51A9 CJK UNIFIED IDEOGRAPH-#51A9, IRGKangXi=0131.071, RSKangXi=14.12, Def{write; draw, sketch; compose}
51AA CJK UNIFIED IDEOGRAPH-#51AA, IRGKangXi=0131.090, RSKangXi=14.14, Def{cover-cloth, cover with cloth}
51AB CJK UNIFIED IDEOGRAPH-#51AB, IRGKangXi=0131.150, RSKangXi=15.0, Def{ice; KangXi radical 15}
51AC CJK UNIFIED IDEOGRAPH-#51AC, IRGKangXi=0131.170, RSKangXi=15.3, Def{winter, 11th lunar month}
51AD CJK UNIFIED IDEOGRAPH-#51AD, IRGKangXi=0131.230, RSKangXi=15.3
51AE CJK UNIFIED IDEOGRAPH-#51AE, IRGKangXi=0131.231
51AF CJK UNIFIED IDEOGRAPH-#51AF, IRGKangXi=0131.231, RSKangXi=187.2, Def{surname; gallop; by dint of}
51B0 CJK UNIFIED IDEOGRAPH-#51B0, IRGKangXi=0131.240, RSKangXi=15.4, Def{ice; ice-cold}
51B1 CJK UNIFIED IDEOGRAPH-#51B1, IRGKangXi=0131.260, RSKangXi=15.4, Def{freezing; stopped up, closed off}
51B2 CJK UNIFIED IDEOGRAPH-#51B2, IRGKangXi=0131.280, RSKangXi=15.4, Def{soar; pour boiling water over}
51B3 CJK UNIFIED IDEOGRAPH-#51B3, IRGKangXi=0131.290, RSKangXi=15.4, Def{decide, determine, judge}
51B4 CJK UNIFIED IDEOGRAPH-#51B4, IRGKangXi=0131.291, RSKangXi=15.4, Def{freezing; stopped up, closed off}
51B5 CJK UNIFIED IDEOGRAPH-#51B5, IRGKangXi=0131.300, RSKangXi=15.5, Def{condition, situation; furthermore}
51B6 CJK UNIFIED IDEOGRAPH-#51B6, IRGKangXi=0131.310, RSKangXi=15.5, Def{smelt, fuse metals; cast, found}
51B7 CJK UNIFIED IDEOGRAPH-#51B7, IRGKangXi=0132.010, RSKangXi=15.5, Def{cold, cool; lonely}
51B8 CJK UNIFIED IDEOGRAPH-#51B8, IRGKangXi=0132.020, RSKangXi=15.5
51B9 CJK UNIFIED IDEOGRAPH-#51B9, IRGKangXi=0132.030, RSKangXi=15.5
51BA CJK UNIFIED IDEOGRAPH-#51BA, IRGKangXi=0132.071, RSKangXi=15.5
51BB CJK UNIFIED IDEOGRAPH-#51BB, IRGKangXi=0132.071, RSKangXi=15.5, Def{freeze; cold, congeal; jelly}
51BC CJK UNIFIED IDEOGRAPH-#51BC, IRGKangXi=0132.110, RSKangXi=15.6, Def{a surname}
51BD CJK UNIFIED IDEOGRAPH-#51BD, IRGKangXi=0132.150, RSKangXi=15.6, Def{cold and raw; pure, clear}
51BE CJK UNIFIED IDEOGRAPH-#51BE, IRGKangXi=0132.170, RSKangXi=15.6
51BF CJK UNIFIED IDEOGRAPH-#51BF, IRGKangXi=0132.180, RSKangXi=15.6
51C0 CJK UNIFIED IDEOGRAPH-#51C0, IRGKangXi=0132.201, RSKangXi=15.6, Def{clean, pure; cleanse}
51C1 CJK UNIFIED IDEOGRAPH-#51C1, IRGKangXi=0132.280, RSKangXi=15.7
51C2 CJK UNIFIED IDEOGRAPH-#51C2, IRGKangXi=0132.311, RSKangXi=15.7, Def{to request; to ask a favour of}
51C3 CJK UNIFIED IDEOGRAPH-#51C3, IRGKangXi=0132.311, RSKangXi=15.7, Def{mud; surname}
51C4 CJK UNIFIED IDEOGRAPH-#51C4, IRGKangXi=0132.330, RSKangXi=15.8, Def{bitter cold, miserable, dreary}
51C5 CJK UNIFIED IDEOGRAPH-#51C5, IRGKangXi=0132.350, RSKangXi=15.8, Def{dried up; exhausted, tired; dry}
51C6 CJK UNIFIED IDEOGRAPH-#51C6, IRGKangXi=0132.370, RSKangXi=15.8, Def{approve, allow, permit; in accord}
51C7 CJK UNIFIED IDEOGRAPH-#51C7, IRGKangXi=0132.390, RSKangXi=15.8, Def{dewdrop; icicle}
51C8 CJK UNIFIED IDEOGRAPH-#51C8, IRGKangXi=0132.400, RSKangXi=15.8, Def{clean, pure; cleanse}
51C9 CJK UNIFIED IDEOGRAPH-#51C9, IRGKangXi=0132.410, RSKangXi=15.8, Def{cool, cold; disheartened}
51CA CJK UNIFIED IDEOGRAPH-#51CA, IRGKangXi=0132.420, RSKangXi=15.8, Def{surname}
51CB CJK UNIFIED IDEOGRAPH-#51CB, IRGKangXi=0132.440, RSKangXi=15.8, Def{be withered, fallen; exhausted}
51CC CJK UNIFIED IDEOGRAPH-#51CC, IRGKangXi=0132.450, RSKangXi=15.8, Def{pure; virtuous; insult; maltreat}
51CD CJK UNIFIED IDEOGRAPH-#51CD, IRGKangXi=0132.460, RSKangXi=15.8, Def{freeze; cold, congeal; jelly}
51CE CJK UNIFIED IDEOGRAPH-#51CE, IRGKangXi=0133.011, RSKangXi=15.8
51CF CJK UNIFIED IDEOGRAPH-#51CF, IRGKangXi=0133.020, RSKangXi=15.9, Def{decrease, subtract, diminish}
51D0 CJK UNIFIED IDEOGRAPH-#51D0, IRGKangXi=0133.050, RSKangXi=15.9
51D1 CJK UNIFIED IDEOGRAPH-#51D1, IRGKangXi=0133.091, RSKangXi=15.9, Def{piece together, assemble}
51D2 CJK UNIFIED IDEOGRAPH-#51D2, IRGKangXi=0133.100, RSKangXi=15.10
51D3 CJK UNIFIED IDEOGRAPH-#51D3, IRGKangXi=0133.130, RSKangXi=15.10, Def{shiver; severe cold}
51D4 CJK UNIFIED IDEOGRAPH-#51D4, IRGKangXi=0133.140, RSKangXi=15.10, Def{cold}
51D5 CJK UNIFIED IDEOGRAPH-#51D5, IRGKangXi=0133.190, RSKangXi=15.10
51D6 CJK UNIFIED IDEOGRAPH-#51D6, IRGKangXi=0133.211, RSKangXi=15.10, Def{rule, guideline, standard}
51D7 CJK UNIFIED IDEOGRAPH-#51D7, IRGKangXi=0133.250, RSKangXi=15.11
51D8 CJK UNIFIED IDEOGRAPH-#51D8, IRGKangXi=0133.310, RSKangXi=15.12
51D9 CJK UNIFIED IDEOGRAPH-#51D9, IRGKangXi=0133.410, RSKangXi=15.13, Def{an icicle}
51DA CJK UNIFIED IDEOGRAPH-#51DA, IRGKangXi=0133.420, RSKangXi=15.13, Def{cold; chilly}
51DB CJK UNIFIED IDEOGRAPH-#51DB, IRGKangXi=0133.430, RSKangXi=15.13, Def{to shiver with cold or fear}
51DC CJK UNIFIED IDEOGRAPH-#51DC, IRGKangXi=0133.441, RSKangXi=15.13, Def{shiver with cold or fear, fearful}
51DD CJK UNIFIED IDEOGRAPH-#51DD, IRGKangXi=0133.450, RSKangXi=15.14, Def{coagulate; congeal; freeze}
51DE CJK UNIFIED IDEOGRAPH-#51DE, IRGKangXi=0133.460, RSKangXi=15.14, Def{bright, splendid, glorious}
51DF CJK UNIFIED IDEOGRAPH-#51DF, IRGKangXi=0133.491, RSKangXi=15.15, Def{to be rude to, to annoy, to profane; to trouble, to harass}
51E0 CJK UNIFIED IDEOGRAPH-#51E0, IRGKangXi=0133.570, RSKangXi=16.0, Def{small table}
51E1 CJK UNIFIED IDEOGRAPH-#51E1, IRGKangXi=0134.020, RSKangXi=16.1, Def{all, any, every; ordinary, common}
51E2 CJK UNIFIED IDEOGRAPH-#51E2, IRGKangXi=0134.021, RSKangXi=4.2, Def{all, any, every; ordinary, common}
51E3 CJK UNIFIED IDEOGRAPH-#51E3, IRGKangXi=0134.021, RSKangXi=16.1, Def{all; common; general; every, whenever; generally}
51E4 CJK UNIFIED IDEOGRAPH-#51E4, IRGKangXi=0134.031, RSKangXi=16.2, Def{male phoenix; symbol of joy}
51E5 CJK UNIFIED IDEOGRAPH-#51E5, IRGKangXi=0134.040, RSKangXi=16.3, Def{to dwell}
51E6 CJK UNIFIED IDEOGRAPH-#51E6, IRGKangXi=0134.050, RSKangXi=34.2, Def{place, locale; department}
51E7 CJK UNIFIED IDEOGRAPH-#51E7, IRGKangXi=0134.081, RSKangXi=16.3, Def{kite}
51E8 CJK UNIFIED IDEOGRAPH-#51E8, IRGKangXi=0134.121, Def{wind; air; manners, atmosphere}
51E9 CJK UNIFIED IDEOGRAPH-#51E9, IRGKangXi=0134.121, RSKangXi=16.4, Def{wintry wind}
51EA CJK UNIFIED IDEOGRAPH-#51EA, IRGKangXi=0134.121, RSKangXi=16.4, Def{calm, lull}
51EB CJK UNIFIED IDEOGRAPH-#51EB, IRGKangXi=0134.121, RSKangXi=16.4, Def{wild duck, teal; swim}
51EC CJK UNIFIED IDEOGRAPH-#51EC, IRGKangXi=1411.070, RSKangXi=182.0
51ED CJK UNIFIED IDEOGRAPH-#51ED, IRGKangXi=0134.160, RSKangXi=16.6, Def{lean on, depend on, rely on}
51EE CJK UNIFIED IDEOGRAPH-#51EE, IRGKangXi=0134.221, RSKangXi=16.6, Def{wind}
51EF CJK UNIFIED IDEOGRAPH-#51EF, IRGKangXi=0134.221, RSKangXi=16.6, Def{triumphant; triumph, victory}
51F0 CJK UNIFIED IDEOGRAPH-#51F0, IRGKangXi=0134.270, RSKangXi=16.9, Def{female phoenix}
51F1 CJK UNIFIED IDEOGRAPH-#51F1, IRGKangXi=0134.310, RSKangXi=16.10, Def{triumphant; triumph, victory}
51F2 CJK UNIFIED IDEOGRAPH-#51F2, IRGKangXi=0134.330, RSKangXi=16.10
51F3 CJK UNIFIED IDEOGRAPH-#51F3, IRGKangXi=0134.360, RSKangXi=16.12, Def{bench; stool}
51F4 CJK UNIFIED IDEOGRAPH-#51F4, IRGKangXi=0134.370, RSKangXi=16.12, Def{to rely on, depend on; evidence, proof}
51F5 CJK UNIFIED IDEOGRAPH-#51F5, IRGKangXi=0134.390, RSKangXi=17.0, Def{receptacle; KangXi radical 17}
51F6 CJK UNIFIED IDEOGRAPH-#51F6, IRGKangXi=0135.020, RSKangXi=17.2, Def{culprit; murder; bad, sad}
51F7 CJK UNIFIED IDEOGRAPH-#51F7, IRGKangXi=0135.070, RSKangXi=17.3, Def{dirt clod; piece}
51F8 CJK UNIFIED IDEOGRAPH-#51F8, IRGKangXi=0135.090, RSKangXi=17.3, Def{protrude, bulge out, convex}
51F9 CJK UNIFIED IDEOGRAPH-#51F9, IRGKangXi=0135.100, RSKangXi=17.3, Def{concave, hollow, depressed; a pass, valley}
51FA CJK UNIFIED IDEOGRAPH-#51FA, IRGKangXi=0135.110, RSKangXi=17.3, Def{go out, send out; stand; produce}
51FB CJK UNIFIED IDEOGRAPH-#51FB, IRGKangXi=0135.121, RSKangXi=17.3, Def{strike, hit, beat; attack, fight}
51FC CJK UNIFIED IDEOGRAPH-#51FC, IRGKangXi=0135.151, RSKangXi=85.2, Def{ditch; pool}
51FD CJK UNIFIED IDEOGRAPH-#51FD, IRGKangXi=0135.160, RSKangXi=17.6, Def{correspondence; a case; a box}
51FE CJK UNIFIED IDEOGRAPH-#51FE, IRGKangXi=0135.170, RSKangXi=17.7, Def{correspondence; a case; a box}
51FF CJK UNIFIED IDEOGRAPH-#51FF, IRGKangXi=0135.211, RSKangXi=17.10, Def{chisel; bore, pierce}
5200 CJK UNIFIED IDEOGRAPH-#5200, IRGKangXi=0135.240, RSKangXi=18.0, Def{knife; old coin; measure}
5201 CJK UNIFIED IDEOGRAPH-#5201, IRGKangXi=0135.250, RSKangXi=18.0, Def{tricky, sly, crafty, cunning}
5202 CJK UNIFIED IDEOGRAPH-#5202, IRGKangXi=0136.010, RSKangXi=18.0, Def{knife; radical number 18}
5203 CJK UNIFIED IDEOGRAPH-#5203, IRGKangXi=0136.020, RSKangXi=18.1, Def{edged tool, cutlery, knife edge}
5204 CJK UNIFIED IDEOGRAPH-#5204, IRGKangXi=0136.021, RSKangXi=18.1, Def{edged tool, cutlery, knife edge}
5205 CJK UNIFIED IDEOGRAPH-#5205, IRGKangXi=0136.030, RSKangXi=18.2, Def{to create, to make to invent; to begin}
5206 CJK UNIFIED IDEOGRAPH-#5206, IRGKangXi=0136.040, RSKangXi=18.2, Def{divide; small unit of time etc.}
5207 CJK UNIFIED IDEOGRAPH-#5207, IRGKangXi=0136.090, RSKangXi=18.2, Def{cut, mince, slice, carve}
5208 CJK UNIFIED IDEOGRAPH-#5208, IRGKangXi=0136.100, RSKangXi=18.2, Def{cut off, reap, mow; sickle}
5209 CJK UNIFIED IDEOGRAPH-#5209, IRGKangXi=0136.140, RSKangXi=18.3
520A CJK UNIFIED IDEOGRAPH-#520A, IRGKangXi=0136.160, RSKangXi=18.3, Def{publication, periodical; publish}
520B CJK UNIFIED IDEOGRAPH-#520B, IRGKangXi=0136.170, RSKangXi=18.3, Def{publication, periodical; publish}
520C CJK UNIFIED IDEOGRAPH-#520C, IRGKangXi=0136.210, RSKangXi=18.3
520D CJK UNIFIED IDEOGRAPH-#520D, IRGKangXi=0137.021, RSKangXi=58.2, Def{mow, cut grass; hay, fodder}
520E CJK UNIFIED IDEOGRAPH-#520E, IRGKangXi=0137.030, RSKangXi=18.4, Def{behead, cut throat}
520F CJK UNIFIED IDEOGRAPH-#520F, IRGKangXi=0137.060, RSKangXi=18.4
5210 CJK UNIFIED IDEOGRAPH-#5210, IRGKangXi=0137.100, RSKangXi=18.4
5211 CJK UNIFIED IDEOGRAPH-#5211, IRGKangXi=0137.110, RSKangXi=18.4, Def{punishment, penalty; law}
5212 CJK UNIFIED IDEOGRAPH-#5212, IRGKangXi=0137.180, RSKangXi=18.4, Def{to row or paddle boat; to scratch}
5213 CJK UNIFIED IDEOGRAPH-#5213, IRGKangXi=0137.200, RSKangXi=18.4, Def{trim}
5214 CJK UNIFIED IDEOGRAPH-#5214, IRGKangXi=0137.220, RSKangXi=18.4, Def{scoop out; gouge}
5215 CJK UNIFIED IDEOGRAPH-#5215, IRGKangXi=0137.240, RSKangXi=18.4
5216 CJK UNIFIED IDEOGRAPH-#5216, IRGKangXi=0137.250, RSKangXi=18.4, Def{cutting off feet as form of punishment}
5217 CJK UNIFIED IDEOGRAPH-#5217, IRGKangXi=0137.260, RSKangXi=18.4, Def{a line; to arrange in order, classify}
5218 CJK UNIFIED IDEOGRAPH-#5218, IRGKangXi=0137.301, RSKangXi=18.4, Def{surname; kill, destroy}
5219 CJK UNIFIED IDEOGRAPH-#5219, IRGKangXi=0137.301, RSKangXi=18.4, Def{rule, law, regulation; grades}
521A CJK UNIFIED IDEOGRAPH-#521A, IRGKangXi=0137.301, RSKangXi=18.4, Def{hard, tough, rigid, strong}
521B CJK UNIFIED IDEOGRAPH-#521B, IRGKangXi=0137.301, RSKangXi=18.4, Def{establish, create; knife cut}
521C CJK UNIFIED IDEOGRAPH-#521C, IRGKangXi=0137.320, RSKangXi=18.5, Def{chop}
521D CJK UNIFIED IDEOGRAPH-#521D, IRGKangXi=0137.330, RSKangXi=18.5, Def{beginning, initial, primary}
521E CJK UNIFIED IDEOGRAPH-#521E, IRGKangXi=0137.350, RSKangXi=18.5
521F CJK UNIFIED IDEOGRAPH-#521F, IRGKangXi=0138.030, RSKangXi=18.5
5220 CJK UNIFIED IDEOGRAPH-#5220, IRGKangXi=0138.040, RSKangXi=18.5, Def{to cut; delete}
5221 CJK UNIFIED IDEOGRAPH-#5221, IRGKangXi=0138.060, RSKangXi=18.5, Def{to scrape; to pare}
5222 CJK UNIFIED IDEOGRAPH-#5222, IRGKangXi=0138.070, RSKangXi=18.5
5223 CJK UNIFIED IDEOGRAPH-#5223, IRGKangXi=0138.100, RSKangXi=18.5
5224 CJK UNIFIED IDEOGRAPH-#5224, IRGKangXi=0138.110, RSKangXi=18.5, Def{judge; discriminate; conclude}
5225 CJK UNIFIED IDEOGRAPH-#5225, IRGKangXi=0138.120, RSKangXi=18.5, Def{separate, other; do not}
5226 CJK UNIFIED IDEOGRAPH-#5226, IRGKangXi=0138.140, RSKangXi=18.5, Def{take by force, coerce; disaster}
5227 CJK UNIFIED IDEOGRAPH-#5227, IRGKangXi=0138.150, RSKangXi=18.5, Def{disaster, misfortune; coerce}
5228 CJK UNIFIED IDEOGRAPH-#5228, IRGKangXi=0138.160, RSKangXi=18.5, Def{carpenter's plane; plane, level}
5229 CJK UNIFIED IDEOGRAPH-#5229, IRGKangXi=0138.190, RSKangXi=18.5, Def{gains, advantage, profit, merit}
522A CJK UNIFIED IDEOGRAPH-#522A, IRGKangXi=0138.281, RSKangXi=18.5, Def{to cut; delete, erase; to geld}
522B CJK UNIFIED IDEOGRAPH-#522B, IRGKangXi=0138.281, RSKangXi=18.5, Def{separate, other; do not}
522C CJK UNIFIED IDEOGRAPH-#522C, IRGKangXi=0138.281, RSKangXi=18.5, Def{to level off; to trim; to pare down}
522D CJK UNIFIED IDEOGRAPH-#522D, IRGKangXi=0138.281, RSKangXi=18.5, Def{cut throat}
522E CJK UNIFIED IDEOGRAPH-#522E, IRGKangXi=0138.290, RSKangXi=18.6, Def{shave, pare off, scrape}
522F CJK UNIFIED IDEOGRAPH-#522F, IRGKangXi=0138.350, RSKangXi=18.6
5230 CJK UNIFIED IDEOGRAPH-#5230, IRGKangXi=0138.360, RSKangXi=18.6, Def{go to, arrive, been to}
5231 CJK UNIFIED IDEOGRAPH-#5231, IRGKangXi=0138.390, RSKangXi=18.6, Def{establish, create; knife cut}
5232 CJK UNIFIED IDEOGRAPH-#5232, IRGKangXi=0138.410, RSKangXi=18.6, Def{cut, slice off}
5233 CJK UNIFIED IDEOGRAPH-#5233, IRGKangXi=0138.420, RSKangXi=18.6, Def{cut out, dig, rip up, scoop out}
5234 CJK UNIFIED IDEOGRAPH-#5234, IRGKangXi=0138.430, Def{chop by pounding, mince, hash}
5235 CJK UNIFIED IDEOGRAPH-#5235, IRGKangXi=0139.010, RSKangXi=18.6, Def{punishment by cutting off ears}
5236 CJK UNIFIED IDEOGRAPH-#5236, IRGKangXi=0139.020, RSKangXi=18.6, Def{system; establish; overpower}
5237 CJK UNIFIED IDEOGRAPH-#5237, IRGKangXi=0139.090, RSKangXi=18.6, Def{brush; clean with brush, scrub}
5238 CJK UNIFIED IDEOGRAPH-#5238, IRGKangXi=0139.110, RSKangXi=18.6, Def{certificate, ticket; title deeds}
5239 CJK UNIFIED IDEOGRAPH-#5239, IRGKangXi=0139.120, RSKangXi=18.6, Def{temple, shrine, monastary}
523A CJK UNIFIED IDEOGRAPH-#523A, IRGKangXi=0139.130, RSKangXi=18.6, Def{stab; prick, irritate; prod}
523B CJK UNIFIED IDEOGRAPH-#523B, IRGKangXi=0139.140, RSKangXi=18.6, Def{carve, engrave; quarter hour}
523C CJK UNIFIED IDEOGRAPH-#523C, IRGKangXi=0139.251, RSKangXi=18.6, Def{to plunder; to rob openly}
523D CJK UNIFIED IDEOGRAPH-#523D, IRGKangXi=0139.251, RSKangXi=18.6, Def{amputate, cut off}
523E CJK UNIFIED IDEOGRAPH-#523E, IRGKangXi=0139.251, RSKangXi=18.6, Def{stab; prick, irritate; prod}
523F CJK UNIFIED IDEOGRAPH-#523F, IRGKangXi=0139.251, RSKangXi=18.6, Def{to cut, injure, stab, stick on}
5240 CJK UNIFIED IDEOGRAPH-#5240, IRGKangXi=0139.251, RSKangXi=18.6, Def{sharpen; carefully, thorough}
5241 CJK UNIFIED IDEOGRAPH-#5241, IRGKangXi=0139.251, RSKangXi=18.6, Def{chop by pounding, mince, hash}
5242 CJK UNIFIED IDEOGRAPH-#5242, IRGKangXi=0139.251, RSKangXi=18.6, Def{medicinal preparation}
5243 CJK UNIFIED IDEOGRAPH-#5243, IRGKangXi=0139.260, RSKangXi=18.7, Def{shave}
5244 CJK UNIFIED IDEOGRAPH-#5244, IRGKangXi=0139.270, RSKangXi=18.7, Def{cut throat}
5245 CJK UNIFIED IDEOGRAPH-#5245, IRGKangXi=0139.280, RSKangXi=18.7
5246 CJK UNIFIED IDEOGRAPH-#5246, IRGKangXi=0139.290, RSKangXi=18.7
5247 CJK UNIFIED IDEOGRAPH-#5247, IRGKangXi=0139.310, RSKangXi=18.7, Def{rule, law, regulation; grades}
5248 CJK UNIFIED IDEOGRAPH-#5248, IRGKangXi=0140.020, RSKangXi=18.7
5249 CJK UNIFIED IDEOGRAPH-#5249, IRGKangXi=0140.040, RSKangXi=18.7, Def{cut, file, trim; file}
524A CJK UNIFIED IDEOGRAPH-#524A, IRGKangXi=0140.050, RSKangXi=18.7, Def{scrape off, pare, trim}
524B CJK UNIFIED IDEOGRAPH-#524B, IRGKangXi=0140.130, RSKangXi=18.7, Def{subdue, overcome; cut down}
524C CJK UNIFIED IDEOGRAPH-#524C, IRGKangXi=0140.140, RSKangXi=18.7, Def{slash, cut in two; contradict}
524D CJK UNIFIED IDEOGRAPH-#524D, IRGKangXi=0140.150, RSKangXi=18.7, Def{in front, forward; preceding}
524E CJK UNIFIED IDEOGRAPH-#524E, IRGKangXi=0140.291, RSKangXi=18.7, Def{temple}
524F CJK UNIFIED IDEOGRAPH-#524F, IRGKangXi=0140.291, RSKangXi=18.7, Def{establish, create; knife cut}
5250 CJK UNIFIED IDEOGRAPH-#5250, IRGKangXi=0140.291, RSKangXi=18.7, Def{cut, cut flesh from bones}
5251 CJK UNIFIED IDEOGRAPH-#5251, IRGKangXi=0140.291, RSKangXi=18.7, Def{sword, dagger, saber}
5252 CJK UNIFIED IDEOGRAPH-#5252, IRGKangXi=0140.300, RSKangXi=18.8, Def{(Cant.) to jerk}
5253 CJK UNIFIED IDEOGRAPH-#5253, IRGKangXi=0140.320, RSKangXi=18.8
5254 CJK UNIFIED IDEOGRAPH-#5254, IRGKangXi=0140.350, RSKangXi=18.8, Def{pick out; scrape off; scrape meat}
5255 CJK UNIFIED IDEOGRAPH-#5255, IRGKangXi=0141.020, RSKangXi=18.8
5256 CJK UNIFIED IDEOGRAPH-#5256, IRGKangXi=0141.030, RSKangXi=18.8, Def{split in two, slice; dissect}
5257 CJK UNIFIED IDEOGRAPH-#5257, IRGKangXi=0141.050, RSKangXi=18.8, Def{to level off; to trim; to pare down}
5258 CJK UNIFIED IDEOGRAPH-#5258, IRGKangXi=0141.060, RSKangXi=18.8
5259 CJK UNIFIED IDEOGRAPH-#5259, IRGKangXi=0141.090, Def{establish, create; knife cut}
525A CJK UNIFIED IDEOGRAPH-#525A, IRGKangXi=0141.100, RSKangXi=18.8, Def{stab}
525B CJK UNIFIED IDEOGRAPH-#525B, IRGKangXi=0141.110, RSKangXi=18.8, Def{hard, tough, rigid, strong}
525C CJK UNIFIED IDEOGRAPH-#525C, IRGKangXi=0141.160, RSKangXi=18.8, Def{cut, cut out, pick out, scoop out}
525D CJK UNIFIED IDEOGRAPH-#525D, IRGKangXi=0141.210, RSKangXi=18.8, Def{peel, peel off, to shell, strip}
525E CJK UNIFIED IDEOGRAPH-#525E, IRGKangXi=0141.270, RSKangXi=18.8, Def{carving or engraving knife; grave}
525F CJK UNIFIED IDEOGRAPH-#525F, IRGKangXi=0141.280, RSKangXi=18.8, Def{to prick; to cut blocks, to engrave}
5260 CJK UNIFIED IDEOGRAPH-#5260, IRGKangXi=0141.310, RSKangXi=18.8, Def{brand}
5261 CJK UNIFIED IDEOGRAPH-#5261, IRGKangXi=0141.320, RSKangXi=18.8, Def{sharp, sharp-pointed; sharpen}
5262 CJK UNIFIED IDEOGRAPH-#5262, IRGKangXi=0141.350, RSKangXi=18.8
5263 CJK UNIFIED IDEOGRAPH-#5263, IRGKangXi=0141.411, RSKangXi=18.8, Def{sword, dagger, saber}
5264 CJK UNIFIED IDEOGRAPH-#5264, IRGKangXi=0141.411, RSKangXi=18.8, Def{medicinal preparation}
5265 CJK UNIFIED IDEOGRAPH-#5265, IRGKangXi=0141.411, RSKangXi=18.8, Def{peel}
5266 CJK UNIFIED IDEOGRAPH-#5266, IRGKangXi=0141.411, RSKangXi=18.8, Def{to castrate}
5267 CJK UNIFIED IDEOGRAPH-#5267, IRGKangXi=0141.411, RSKangXi=18.8, Def{theatrical plays, opera, drama}
5268 CJK UNIFIED IDEOGRAPH-#5268, IRGKangXi=0142.020, RSKangXi=18.9, Def{sound of something being smashed}
5269 CJK UNIFIED IDEOGRAPH-#5269, IRGKangXi=0142.040, RSKangXi=18.10, Def{leftovers, residue, remains}
526A CJK UNIFIED IDEOGRAPH-#526A, IRGKangXi=0142.130, RSKangXi=18.9, Def{scissors; cut, divide, separate}
526B CJK UNIFIED IDEOGRAPH-#526B, IRGKangXi=0142.160, RSKangXi=18.9
526C CJK UNIFIED IDEOGRAPH-#526C, IRGKangXi=0142.170, RSKangXi=18.9
526D CJK UNIFIED IDEOGRAPH-#526D, IRGKangXi=0142.180, RSKangXi=18.9
526E CJK UNIFIED IDEOGRAPH-#526E, IRGKangXi=0142.200, RSKangXi=18.9, Def{cut, cut flesh from bones}
526F CJK UNIFIED IDEOGRAPH-#526F, IRGKangXi=0142.230, RSKangXi=18.9, Def{assist; supplement; assistant}
5270 CJK UNIFIED IDEOGRAPH-#5270, IRGKangXi=0142.281, RSKangXi=18.9, Def{leftovers, residue, remains}
5271 CJK UNIFIED IDEOGRAPH-#5271, IRGKangXi=0142.281, RSKangXi=18.9, Def{sword, dagger, saber}
5272 CJK UNIFIED IDEOGRAPH-#5272, IRGKangXi=0142.320, RSKangXi=18.10, Def{cut, divide, partition; cede}
5273 CJK UNIFIED IDEOGRAPH-#5273, IRGKangXi=0142.360, RSKangXi=18.10, Def{brief note; official communique}
5274 CJK UNIFIED IDEOGRAPH-#5274, IRGKangXi=0142.450, RSKangXi=18.10, Def{sharpen; carefully, thorough}
5275 CJK UNIFIED IDEOGRAPH-#5275, IRGKangXi=0143.020, RSKangXi=18.10, Def{establish, create; knife cut}
5276 CJK UNIFIED IDEOGRAPH-#5276, IRGKangXi=0143.140, RSKangXi=18.9
5277 CJK UNIFIED IDEOGRAPH-#5277, IRGKangXi=0143.150, RSKangXi=18.11, Def{to level off, cut off, pare down, raze}
5278 CJK UNIFIED IDEOGRAPH-#5278, IRGKangXi=0143.190, RSKangXi=18.11, Def{cut}
5279 CJK UNIFIED IDEOGRAPH-#5279, IRGKangXi=0143.210, RSKangXi=18.11
527A CJK UNIFIED IDEOGRAPH-#527A, IRGKangXi=0143.240, RSKangXi=18.11, Def{mark}
527B CJK UNIFIED IDEOGRAPH-#527B, IRGKangXi=0143.310, RSKangXi=18.11
527C CJK UNIFIED IDEOGRAPH-#527C, IRGKangXi=0143.320, RSKangXi=18.11
527D CJK UNIFIED IDEOGRAPH-#527D, IRGKangXi=0143.330, RSKangXi=18.11, Def{rob, plunder; slice off; fast}
527E CJK UNIFIED IDEOGRAPH-#527E, IRGKangXi=0143.360, RSKangXi=18.11, Def{to pick up with knife}
527F CJK UNIFIED IDEOGRAPH-#527F, IRGKangXi=0143.381, RSKangXi=18.14, Def{destroy, exterminate, annihilate}
5280 CJK UNIFIED IDEOGRAPH-#5280, IRGKangXi=0143.460, RSKangXi=18.12
5281 CJK UNIFIED IDEOGRAPH-#5281, IRGKangXi=0143.480, RSKangXi=18.12
5282 CJK UNIFIED IDEOGRAPH-#5282, IRGKangXi=0144.080, RSKangXi=18.12, Def{chisel for engraving; engrave}
5283 CJK UNIFIED IDEOGRAPH-#5283, IRGKangXi=0144.100, RSKangXi=18.12, Def{divide, mark off, lay boundary}
5284 CJK UNIFIED IDEOGRAPH-#5284, IRGKangXi=0144.261, RSKangXi=118.8, Def{brief note; official communique}
5285 CJK UNIFIED IDEOGRAPH-#5285, IRGKangXi=0144.280, RSKangXi=18.13
5286 CJK UNIFIED IDEOGRAPH-#5286, IRGKangXi=0144.310, Def{sickle}
5287 CJK UNIFIED IDEOGRAPH-#5287, IRGKangXi=0144.340, RSKangXi=18.13, Def{theatrical plays, opera, drama}
5288 CJK UNIFIED IDEOGRAPH-#5288, IRGKangXi=0144.380, RSKangXi=18.13, Def{cut apart, split, chop}
5289 CJK UNIFIED IDEOGRAPH-#5289, IRGKangXi=0144.390, RSKangXi=18.13, Def{surname; kill, destroy}
528A CJK UNIFIED IDEOGRAPH-#528A, IRGKangXi=0144.420, RSKangXi=18.13, Def{amputate, cut off}
528B CJK UNIFIED IDEOGRAPH-#528B, IRGKangXi=0144.430, RSKangXi=18.13
528C CJK UNIFIED IDEOGRAPH-#528C, IRGKangXi=0144.440, RSKangXi=18.13, Def{to cut, injure, stab, stick on}
528D CJK UNIFIED IDEOGRAPH-#528D, IRGKangXi=0144.450, RSKangXi=18.13, Def{sword, dagger, saber}
528E CJK UNIFIED IDEOGRAPH-#528E, IRGKangXi=0144.501, Def{sword, dagger}
528F CJK UNIFIED IDEOGRAPH-#528F, IRGKangXi=0144.501, RSKangXi=18.13, Def{to butcher}
5290 CJK UNIFIED IDEOGRAPH-#5290, IRGKangXi=0145.020, RSKangXi=18.14, Def{destroy}
5291 CJK UNIFIED IDEOGRAPH-#5291, IRGKangXi=0145.060, RSKangXi=18.14, Def{medicinal preparation}
5292 CJK UNIFIED IDEOGRAPH-#5292, IRGKangXi=0145.090, RSKangXi=18.14, Def{sword, dagger, saber}
5293 CJK UNIFIED IDEOGRAPH-#5293, IRGKangXi=0145.130, RSKangXi=18.14, Def{cut off nose}
5294 CJK UNIFIED IDEOGRAPH-#5294, IRGKangXi=0145.211, RSKangXi=18.14, Def{sword, dagger, saber}
5295 CJK UNIFIED IDEOGRAPH-#5295, IRGKangXi=0145.250, RSKangXi=18.15
5296 CJK UNIFIED IDEOGRAPH-#5296, IRGKangXi=0145.380, RSKangXi=18.17, Def{make into mince; cut}
5297 CJK UNIFIED IDEOGRAPH-#5297, IRGKangXi=0145.420, RSKangXi=18.19
5298 CJK UNIFIED IDEOGRAPH-#5298, IRGKangXi=0145.440, RSKangXi=18.19, Def{make into mince}
5299 CJK UNIFIED IDEOGRAPH-#5299, IRGKangXi=0145.460, RSKangXi=18.21, Def{a divide, to partition}
529A CJK UNIFIED IDEOGRAPH-#529A, IRGKangXi=0146.010, RSKangXi=18.21, Def{cut}
529B CJK UNIFIED IDEOGRAPH-#529B, IRGKangXi=0146.050, RSKangXi=19.0, Def{power, capability, influence}
529C CJK UNIFIED IDEOGRAPH-#529C, IRGKangXi=0146.070, RSKangXi=19.1
529D CJK UNIFIED IDEOGRAPH-#529D, IRGKangXi=0146.101, RSKangXi=19.2, Def{recommend, advise, urge}
529E CJK UNIFIED IDEOGRAPH-#529E, IRGKangXi=0146.101, RSKangXi=19.2, Def{manage, do, handle; deal with}
529F CJK UNIFIED IDEOGRAPH-#529F, IRGKangXi=0146.110, RSKangXi=19.3, Def{achievement, merit, good result}
52A0 CJK UNIFIED IDEOGRAPH-#52A0, IRGKangXi=0146.130, RSKangXi=19.3, Def{add to, increase, augment}
52A1 CJK UNIFIED IDEOGRAPH-#52A1, IRGKangXi=0146.161, RSKangXi=34.2, Def{affairs, business; must, should}
52A2 CJK UNIFIED IDEOGRAPH-#52A2, IRGKangXi=0146.161, RSKangXi=19.3, Def{put forth effort, strive forward}
52A3 CJK UNIFIED IDEOGRAPH-#52A3, IRGKangXi=0146.170, RSKangXi=19.4, Def{bad, inferior; slightly}
52A4 CJK UNIFIED IDEOGRAPH-#52A4, IRGKangXi=0146.190, RSKangXi=19.4, Def{strong}
52A5 CJK UNIFIED IDEOGRAPH-#52A5, IRGKangXi=0146.210, RSKangXi=19.4
52A6 CJK UNIFIED IDEOGRAPH-#52A6, IRGKangXi=0146.220, RSKangXi=19.4, Def{variant of U+5354 協; cooperate; combined labor}
52A7 CJK UNIFIED IDEOGRAPH-#52A7, IRGKangXi=0146.240, RSKangXi=19.4
52A8 CJK UNIFIED IDEOGRAPH-#52A8, IRGKangXi=0146.241, RSKangXi=19.4, Def{move, happen; movement, action}
52A9 CJK UNIFIED IDEOGRAPH-#52A9, IRGKangXi=0146.270, RSKangXi=19.5, Def{help, aid, assist}
52AA CJK UNIFIED IDEOGRAPH-#52AA, IRGKangXi=0146.280, RSKangXi=19.5, Def{to exert, strive, make an effort; to pout}
52AB CJK UNIFIED IDEOGRAPH-#52AB, IRGKangXi=0146.300, RSKangXi=19.5, Def{take by force, coerce; disaster}
52AC CJK UNIFIED IDEOGRAPH-#52AC, IRGKangXi=0147.010, RSKangXi=19.5, Def{be diligent, toil, endeavor}
52AD CJK UNIFIED IDEOGRAPH-#52AD, IRGKangXi=0147.020, RSKangXi=19.5, Def{encourage; to excel; excellent}
52AE CJK UNIFIED IDEOGRAPH-#52AE, IRGKangXi=0147.030, RSKangXi=19.5
52AF CJK UNIFIED IDEOGRAPH-#52AF, IRGKangXi=0147.060, RSKangXi=19.5
52B0 CJK UNIFIED IDEOGRAPH-#52B0, IRGKangXi=0147.070, RSKangXi=19.5
52B1 CJK UNIFIED IDEOGRAPH-#52B1, IRGKangXi=0147.071, RSKangXi=19.5, Def{strive; encourage}
52B2 CJK UNIFIED IDEOGRAPH-#52B2, IRGKangXi=0147.071, RSKangXi=19.5, Def{strong, unyielding, tough, power}
52B3 CJK UNIFIED IDEOGRAPH-#52B3, IRGKangXi=0147.071, RSKangXi=19.5, Def{labor, toil, do manual work}
52B4 CJK UNIFIED IDEOGRAPH-#52B4, IRGKangXi=0147.071, RSKangXi=19.5, Def{labor, toil, do manual work}
52B5 CJK UNIFIED IDEOGRAPH-#52B5, IRGKangXi=0147.080, RSKangXi=19.6, Def{certificate, ticket; title deeds}
52B6 CJK UNIFIED IDEOGRAPH-#52B6, IRGKangXi=0147.090, RSKangXi=19.6
52B7 CJK UNIFIED IDEOGRAPH-#52B7, IRGKangXi=0147.100, RSKangXi=19.6
52B8 CJK UNIFIED IDEOGRAPH-#52B8, IRGKangXi=0147.110, RSKangXi=19.6
52B9 CJK UNIFIED IDEOGRAPH-#52B9, IRGKangXi=0147.120, RSKangXi=19.6, Def{efficacious, effectiveness; to toil, to serve in the army}
52BA CJK UNIFIED IDEOGRAPH-#52BA, IRGKangXi=0147.130, RSKangXi=19.6
52BB CJK UNIFIED IDEOGRAPH-#52BB, IRGKangXi=0147.140, RSKangXi=19.6, Def{flurried, be in flurry, zealous}
52BC CJK UNIFIED IDEOGRAPH-#52BC, IRGKangXi=0147.160, RSKangXi=19.6, Def{be discreet, prudent, cautious}
52BD CJK UNIFIED IDEOGRAPH-#52BD, IRGKangXi=0147.170, RSKangXi=19.6
52BE CJK UNIFIED IDEOGRAPH-#52BE, IRGKangXi=0147.200, RSKangXi=19.6, Def{examine into, impeach, charge}
52BF CJK UNIFIED IDEOGRAPH-#52BF, IRGKangXi=0147.231, RSKangXi=19.6, Def{power, force; tendency}
52C0 CJK UNIFIED IDEOGRAPH-#52C0, IRGKangXi=0147.240, RSKangXi=19.7
52C1 CJK UNIFIED IDEOGRAPH-#52C1, IRGKangXi=0147.250, RSKangXi=19.7, Def{strong, unyielding, tough, powerful}
52C2 CJK UNIFIED IDEOGRAPH-#52C2, IRGKangXi=0147.260, RSKangXi=19.7
52C3 CJK UNIFIED IDEOGRAPH-#52C3, IRGKangXi=0147.270, RSKangXi=19.7, Def{suddenly, sudden, quick}
52C4 CJK UNIFIED IDEOGRAPH-#52C4, IRGKangXi=0147.280, RSKangXi=19.7, Def{active; clever; prompt witty; smart; earnest; diligent; to hasten}
52C5 CJK UNIFIED IDEOGRAPH-#52C5, IRGKangXi=0147.290, RSKangXi=19.7, Def{imperial decree; daoist magic}
52C6 CJK UNIFIED IDEOGRAPH-#52C6, IRGKangXi=0147.340, RSKangXi=19.7
52C7 CJK UNIFIED IDEOGRAPH-#52C7, IRGKangXi=0147.350, RSKangXi=19.7, Def{brave, courageous, fierce}
52C8 CJK UNIFIED IDEOGRAPH-#52C8, IRGKangXi=0147.360, RSKangXi=19.7
52C9 CJK UNIFIED IDEOGRAPH-#52C9, IRGKangXi=0147.370, RSKangXi=19.7, Def{endeavor, make effort; urge}
52CA CJK UNIFIED IDEOGRAPH-#52CA, IRGKangXi=0147.381, RSKangXi=19.7
52CB CJK UNIFIED IDEOGRAPH-#52CB, IRGKangXi=0147.381, RSKangXi=19.7, Def{meritorious deed; merits; rank}
52CC CJK UNIFIED IDEOGRAPH-#52CC, IRGKangXi=0147.390, RSKangXi=19.8, Def{to labor; tired}
52CD CJK UNIFIED IDEOGRAPH-#52CD, IRGKangXi=0147.430, RSKangXi=19.8, Def{strong, powerful, mighty; violent}
52CE CJK UNIFIED IDEOGRAPH-#52CE, IRGKangXi=0147.440, RSKangXi=19.8
52CF CJK UNIFIED IDEOGRAPH-#52CF, IRGKangXi=0148.030, RSKangXi=19.8
52D0 CJK UNIFIED IDEOGRAPH-#52D0, IRGKangXi=0148.060, RSKangXi=19.8, Def{imperial degree; daoist magic}
52D1 CJK UNIFIED IDEOGRAPH-#52D1, IRGKangXi=0148.070, RSKangXi=19.8, Def{reward; sincere}
52D2 CJK UNIFIED IDEOGRAPH-#52D2, IRGKangXi=0148.100, RSKangXi=19.9, Def{strangle, tighten}
52D3 CJK UNIFIED IDEOGRAPH-#52D3, IRGKangXi=0148.110, RSKangXi=19.9
52D4 CJK UNIFIED IDEOGRAPH-#52D4, IRGKangXi=0148.120, RSKangXi=19.9, Def{endeavor, make effort; urge}
52D5 CJK UNIFIED IDEOGRAPH-#52D5, IRGKangXi=0148.140, RSKangXi=19.9, Def{move, happen; movement, action}
52D6 CJK UNIFIED IDEOGRAPH-#52D6, IRGKangXi=0148.170, RSKangXi=19.9, Def{enjoin, advise, preach to}
52D7 CJK UNIFIED IDEOGRAPH-#52D7, IRGKangXi=0148.180, RSKangXi=19.9, Def{enjoin, advise, excite}
52D8 CJK UNIFIED IDEOGRAPH-#52D8, IRGKangXi=0148.190, RSKangXi=19.9, Def{investigate; compare; collate}
52D9 CJK UNIFIED IDEOGRAPH-#52D9, IRGKangXi=0148.200, RSKangXi=19.9, Def{affairs, business; must, should}
52DA CJK UNIFIED IDEOGRAPH-#52DA, IRGKangXi=0148.241, RSKangXi=19.12, Def{work hard; belabored; toil}
52DB CJK UNIFIED IDEOGRAPH-#52DB, IRGKangXi=0148.250, RSKangXi=19.10, Def{meritorious deed; merits; rank}
52DC CJK UNIFIED IDEOGRAPH-#52DC, IRGKangXi=0148.300, RSKangXi=19.10
52DD CJK UNIFIED IDEOGRAPH-#52DD, IRGKangXi=0148.310, RSKangXi=19.10, Def{victory; excel, be better than}
52DE CJK UNIFIED IDEOGRAPH-#52DE, IRGKangXi=0148.350, RSKangXi=19.10, Def{labor, toil, do manual work}
52DF CJK UNIFIED IDEOGRAPH-#52DF, IRGKangXi=0148.400, RSKangXi=19.11, Def{levy, raise; summon; recruit}
52E0 CJK UNIFIED IDEOGRAPH-#52E0, IRGKangXi=0148.420, RSKangXi=19.11, Def{join forces, unite}
52E1 CJK UNIFIED IDEOGRAPH-#52E1, IRGKangXi=0149.030, RSKangXi=19.11
52E2 CJK UNIFIED IDEOGRAPH-#52E2, IRGKangXi=0149.040, RSKangXi=19.11, Def{power, force; tendency}
52E3 CJK UNIFIED IDEOGRAPH-#52E3, IRGKangXi=0149.050, RSKangXi=19.11, Def{achievements, conduct deserving}
52E4 CJK UNIFIED IDEOGRAPH-#52E4, IRGKangXi=0149.060, RSKangXi=19.11, Def{industrious, diligent, attentive}
52E5 CJK UNIFIED IDEOGRAPH-#52E5, IRGKangXi=0149.080, RSKangXi=19.11
52E6 CJK UNIFIED IDEOGRAPH-#52E6, IRGKangXi=0149.090, RSKangXi=19.11, Def{destroy, exterminate, annihilate}
52E7 CJK UNIFIED IDEOGRAPH-#52E7, IRGKangXi=0149.111, RSKangXi=19.11, Def{recommend, advise, urge}
52E8 CJK UNIFIED IDEOGRAPH-#52E8, IRGKangXi=0149.160, RSKangXi=19.12
52E9 CJK UNIFIED IDEOGRAPH-#52E9, IRGKangXi=0149.180, RSKangXi=19.12, Def{work hard; belabored; toil}
52EA CJK UNIFIED IDEOGRAPH-#52EA, IRGKangXi=0149.190, RSKangXi=19.12
52EB CJK UNIFIED IDEOGRAPH-#52EB, IRGKangXi=0149.210, RSKangXi=19.12
52EC CJK UNIFIED IDEOGRAPH-#52EC, IRGKangXi=0149.230, RSKangXi=19.12
52ED CJK UNIFIED IDEOGRAPH-#52ED, IRGKangXi=0149.240, RSKangXi=19.12
52EE CJK UNIFIED IDEOGRAPH-#52EE, IRGKangXi=0149.280, RSKangXi=19.13
52EF CJK UNIFIED IDEOGRAPH-#52EF, IRGKangXi=0149.290, RSKangXi=19.13, Def{exhausted}
52F0 CJK UNIFIED IDEOGRAPH-#52F0, IRGKangXi=0149.310, RSKangXi=19.13, Def{peaceful, harmonious}
52F1 CJK UNIFIED IDEOGRAPH-#52F1, IRGKangXi=0149.320, RSKangXi=19.13, Def{put forth effort, strive forward}
52F2 CJK UNIFIED IDEOGRAPH-#52F2, IRGKangXi=0149.351, RSKangXi=86.11, Def{meritorious deed; merits; rank}
52F3 CJK UNIFIED IDEOGRAPH-#52F3, IRGKangXi=0149.370, RSKangXi=19.14, Def{meritorious deed; merits; rank}
52F4 CJK UNIFIED IDEOGRAPH-#52F4, IRGKangXi=0149.400, RSKangXi=19.15
52F5 CJK UNIFIED IDEOGRAPH-#52F5, IRGKangXi=0149.440, RSKangXi=19.15, Def{strive; encourage}
52F6 CJK UNIFIED IDEOGRAPH-#52F6, IRGKangXi=0150.030, RSKangXi=19.15
52F7 CJK UNIFIED IDEOGRAPH-#52F7, IRGKangXi=0150.110, RSKangXi=19.17, Def{urgent; in haste, hurriedly; help}
52F8 CJK UNIFIED IDEOGRAPH-#52F8, IRGKangXi=0150.120, RSKangXi=19.17, Def{recommend, advise, urge}
52F9 CJK UNIFIED IDEOGRAPH-#52F9, IRGKangXi=0150.180, RSKangXi=20.0, Def{wrap; KangXi radical 20}
52FA CJK UNIFIED IDEOGRAPH-#52FA, IRGKangXi=0150.190, RSKangXi=20.1, Def{spoon, ladle; unit of volume}
52FB CJK UNIFIED IDEOGRAPH-#52FB, IRGKangXi=0150.200, RSKangXi=20.2, Def{equal, impartially, uniform, even}
52FC CJK UNIFIED IDEOGRAPH-#52FC, IRGKangXi=0150.210, RSKangXi=20.2
52FD CJK UNIFIED IDEOGRAPH-#52FD, IRGKangXi=0150.220, Def{to incubate; to brood; to hatch}
52FE CJK UNIFIED IDEOGRAPH-#52FE, IRGKangXi=0150.230, RSKangXi=20.2, Def{hook, join, connect; entice}
52FF CJK UNIFIED IDEOGRAPH-#52FF, IRGKangXi=0150.240, RSKangXi=20.2, Def{must not, do not; without, never}
5300 CJK UNIFIED IDEOGRAPH-#5300, IRGKangXi=0150.241, RSKangXi=20.2, Def{equal}
5301 CJK UNIFIED IDEOGRAPH-#5301, IRGKangXi=0150.241, RSKangXi=20.2, Def{Japanese unit of weight (1/1000 of a kan)}
5302 CJK UNIFIED IDEOGRAPH-#5302, IRGKangXi=0150.241, RSKangXi=20.2, Def{fragrance, smell}
5303 CJK UNIFIED IDEOGRAPH-#5303, IRGKangXi=0150.250, RSKangXi=20.3, Def{beggar; beg; give}
5304 CJK UNIFIED IDEOGRAPH-#5304, IRGKangXi=0150.260, RSKangXi=20.3, Def{to beg for alms; a beggar}
5305 CJK UNIFIED IDEOGRAPH-#5305, IRGKangXi=0150.270, RSKangXi=20.3, Def{wrap, pack, bundle; package}
5306 CJK UNIFIED IDEOGRAPH-#5306, IRGKangXi=0151.031, RSKangXi=20.3, Def{hastily, in haste, hurriedly}
5307 CJK UNIFIED IDEOGRAPH-#5307, IRGKangXi=0151.031, RSKangXi=20.3
5308 CJK UNIFIED IDEOGRAPH-#5308, IRGKangXi=0151.040, RSKangXi=20.4, Def{breast, chest, thorax; clamor; the Hsiung Nu 'Huns'}
5309 CJK UNIFIED IDEOGRAPH-#5309, IRGKangXi=0151.070, RSKangXi=20.5, Def{noise of waters}
530A CJK UNIFIED IDEOGRAPH-#530A, IRGKangXi=0151.120, RSKangXi=20.6, Def{handful}
530B CJK UNIFIED IDEOGRAPH-#530B, IRGKangXi=0151.140, RSKangXi=20.6, Def{pottery}
530C CJK UNIFIED IDEOGRAPH-#530C, IRGKangXi=0151.150, RSKangXi=20.6
530D CJK UNIFIED IDEOGRAPH-#530D, IRGKangXi=0151.170, RSKangXi=20.7, Def{crawl; lie prostrate}
530E CJK UNIFIED IDEOGRAPH-#530E, IRGKangXi=0151.210, RSKangXi=20.8
530F CJK UNIFIED IDEOGRAPH-#530F, IRGKangXi=0151.330, RSKangXi=20.9, Def{gourd; musical instrument}
5310 CJK UNIFIED IDEOGRAPH-#5310, IRGKangXi=0151.340, RSKangXi=20.9, Def{fall prostrate; crawl}
5311 CJK UNIFIED IDEOGRAPH-#5311, IRGKangXi=0151.370, RSKangXi=20.10
5312 CJK UNIFIED IDEOGRAPH-#5312, IRGKangXi=0152.010, RSKangXi=20.10
5313 CJK UNIFIED IDEOGRAPH-#5313, IRGKangXi=0152.050, RSKangXi=20.11
5314 CJK UNIFIED IDEOGRAPH-#5314, IRGKangXi=0152.120, RSKangXi=20.13
5315 CJK UNIFIED IDEOGRAPH-#5315, IRGKangXi=0152.180, RSKangXi=21.0, Def{spoon, ladle; knife, dirk}
5316 CJK UNIFIED IDEOGRAPH-#5316, IRGKangXi=0152.200, RSKangXi=21.2, Def{change, convert, reform; -ize}
5317 CJK UNIFIED IDEOGRAPH-#5317, IRGKangXi=0152.250, RSKangXi=21.3, Def{north; northern; northward}
5318 CJK UNIFIED IDEOGRAPH-#5318, IRGKangXi=0153.040, RSKangXi=21.9, Def{the brain}
5319 CJK UNIFIED IDEOGRAPH-#5319, IRGKangXi=0153.050, RSKangXi=21.9, Def{spoon; surname}
531A CJK UNIFIED IDEOGRAPH-#531A, IRGKangXi=0153.100, RSKangXi=22.0, Def{box; KangXi radical 22}
531B CJK UNIFIED IDEOGRAPH-#531B, IRGKangXi=0153.130, RSKangXi=22.3
531C CJK UNIFIED IDEOGRAPH-#531C, IRGKangXi=0153.140, RSKangXi=22.3, Def{basin; container for wine}
531D CJK UNIFIED IDEOGRAPH-#531D, IRGKangXi=0153.160, RSKangXi=22.3, Def{full circle; encircle}
531E CJK UNIFIED IDEOGRAPH-#531E, IRGKangXi=0153.170, RSKangXi=22.3
531F CJK UNIFIED IDEOGRAPH-#531F, IRGKangXi=0153.200, RSKangXi=22.4, Def{divan for two persons}
5320 CJK UNIFIED IDEOGRAPH-#5320, IRGKangXi=0153.220, RSKangXi=22.4, Def{craftsman, artisan; workman}
5321 CJK UNIFIED IDEOGRAPH-#5321, IRGKangXi=0153.230, RSKangXi=22.4, Def{correct, restore, revise}
5322 CJK UNIFIED IDEOGRAPH-#5322, IRGKangXi=0153.250, RSKangXi=22.4
5323 CJK UNIFIED IDEOGRAPH-#5323, IRGKangXi=0153.270, RSKangXi=22.5, Def{small box, case, coffer}
5324 CJK UNIFIED IDEOGRAPH-#5324, IRGKangXi=0153.300, RSKangXi=22.5
5325 CJK UNIFIED IDEOGRAPH-#5325, IRGKangXi=0153.310, RSKangXi=22.5
5326 CJK UNIFIED IDEOGRAPH-#5326, IRGKangXi=0153.341, RSKangXi=22.6, Def{small box; chest, casket}
5327 CJK UNIFIED IDEOGRAPH-#5327, IRGKangXi=0153.370, RSKangXi=22.7, Def{a trunk; a portfolio}
5328 CJK UNIFIED IDEOGRAPH-#5328, IRGKangXi=0153.400, RSKangXi=22.7
5329 CJK UNIFIED IDEOGRAPH-#5329, IRGKangXi=0153.420, RSKangXi=22.7
532A CJK UNIFIED IDEOGRAPH-#532A, IRGKangXi=0153.450, RSKangXi=22.8, Def{bandits, robbers, gangsters}
532B CJK UNIFIED IDEOGRAPH-#532B, IRGKangXi=0154.020, RSKangXi=22.8
532C CJK UNIFIED IDEOGRAPH-#532C, IRGKangXi=0154.070, RSKangXi=22.9
532D CJK UNIFIED IDEOGRAPH-#532D, IRGKangXi=0154.090, RSKangXi=22.9, Def{small box; chest, casket}
532E CJK UNIFIED IDEOGRAPH-#532E, IRGKangXi=0154.091, RSKangXi=22.9, Def{to lack}
532F CJK UNIFIED IDEOGRAPH-#532F, IRGKangXi=0154.150, RSKangXi=22.11, Def{a concourse; to flow together, gather together; (same as U+6ED9 滙) to remit money}
5330 CJK UNIFIED IDEOGRAPH-#5330, IRGKangXi=0154.190, RSKangXi=22.12
5331 CJK UNIFIED IDEOGRAPH-#5331, IRGKangXi=0154.200, RSKangXi=22.12, Def{to lack}
5332 CJK UNIFIED IDEOGRAPH-#5332, IRGKangXi=0154.210, RSKangXi=22.12
5333 CJK UNIFIED IDEOGRAPH-#5333, IRGKangXi=0154.230, RSKangXi=22.13, Def{ladies toilet case with mirror}
5334 CJK UNIFIED IDEOGRAPH-#5334, IRGKangXi=0154.270, RSKangXi=22.14
5335 CJK UNIFIED IDEOGRAPH-#5335, IRGKangXi=0154.300, RSKangXi=22.15, Def{case; casket}
5336 CJK UNIFIED IDEOGRAPH-#5336, IRGKangXi=0154.310, RSKangXi=22.17
5337 CJK UNIFIED IDEOGRAPH-#5337, IRGKangXi=0154.330, RSKangXi=22.18
5338 CJK UNIFIED IDEOGRAPH-#5338, IRGKangXi=0154.350, RSKangXi=23.0, Def{box; KangXi radical 23}
5339 CJK UNIFIED IDEOGRAPH-#5339, IRGKangXi=0154.360, RSKangXi=23.2, Def{bolt of cloth; counter for horses}
533A CJK UNIFIED IDEOGRAPH-#533A, IRGKangXi=0154.361, RSKangXi=23.2, Def{area, district, region, ward}
533B CJK UNIFIED IDEOGRAPH-#533B, IRGKangXi=0155.050, RSKangXi=23.5, Def{cure, heal; doctor, medical}
533C CJK UNIFIED IDEOGRAPH-#533C, IRGKangXi=0155.070, RSKangXi=23.6
533D CJK UNIFIED IDEOGRAPH-#533D, IRGKangXi=0155.080, RSKangXi=23.7, Def{to hide, to secrete, to repress; to bend}
533E CJK UNIFIED IDEOGRAPH-#533E, IRGKangXi=0155.110, RSKangXi=23.9, Def{flat, round split-bamboo contain}
533F CJK UNIFIED IDEOGRAPH-#533F, IRGKangXi=0155.120, RSKangXi=23.9, Def{hide; go into hiding}
5340 CJK UNIFIED IDEOGRAPH-#5340, IRGKangXi=0155.130, RSKangXi=23.9, Def{area, district, region, ward; surname}
5341 CJK UNIFIED IDEOGRAPH-#5341, IRGKangXi=0155.170, RSKangXi=24.0, PrimaryNumeric=10, Def{ten, tenth; complete; perfect}
5342 CJK UNIFIED IDEOGRAPH-#5342, IRGKangXi=0155.180, RSKangXi=24.1, Def{to fly rapidly}
5343 CJK UNIFIED IDEOGRAPH-#5343, IRGKangXi=0155.190, RSKangXi=24.1, PrimaryNumeric=1000, Def{thousand; many, numerous; very; (Cant.) a cheater, swindler}
5344 CJK UNIFIED IDEOGRAPH-#5344, IRGKangXi=0155.200, RSKangXi=24.1, Def{twenty, twentieth}
5345 CJK UNIFIED IDEOGRAPH-#5345, IRGKangXi=0156.010, RSKangXi=24.2, Def{thirty, thirtieth}
5346 CJK UNIFIED IDEOGRAPH-#5346, IRGKangXi=0156.020, RSKangXi=24.2, Def{soldier; servant; at last, finally}
5347 CJK UNIFIED IDEOGRAPH-#5347, IRGKangXi=0156.030, RSKangXi=24.2, Def{arise, go up; hoist; advance}
5348 CJK UNIFIED IDEOGRAPH-#5348, IRGKangXi=0156.040, RSKangXi=24.2, Def{noon; 7th terrestrial branch}
5349 CJK UNIFIED IDEOGRAPH-#5349, IRGKangXi=0156.060, RSKangXi=24.3, Def{general term for plants; myriads}
534A CJK UNIFIED IDEOGRAPH-#534A, IRGKangXi=0156.070, RSKangXi=24.3, Def{half}
534B CJK UNIFIED IDEOGRAPH-#534B, IRGKangXi=0156.120, RSKangXi=1.5, Def{same as 世 U+4E16, generation; world; era}
534C CJK UNIFIED IDEOGRAPH-#534C, IRGKangXi=0156.140, RSKangXi=24.4, Def{forty, fortieth}
534D CJK UNIFIED IDEOGRAPH-#534D, IRGKangXi=0156.210, RSKangXi=24.4, Def{swastika, one of the auspicious signs recognized (e.g. in Chinese Tathagata Buddhism) as being on the chest of Buddha (and variously seen in statuary on the chest, soles of the feet, or palms of the hands)}
534E CJK UNIFIED IDEOGRAPH-#534E, IRGKangXi=0156.221, RSKangXi=24.4, Def{flowery; illustrious; Chinese}
534F CJK UNIFIED IDEOGRAPH-#534F, IRGKangXi=0156.221, RSKangXi=24.4, Def{be united; cooperate}
5350 CJK UNIFIED IDEOGRAPH-#5350, IRGKangXi=0156.221, Def{swastika, one of the auspicious signs recognized (e.g. in Chinese Tathagata Buddhism) as being on the chest of Buddha (and variously seen in statuary on the chest, soles of the feet, or palms of the hands)}
5351 CJK UNIFIED IDEOGRAPH-#5351, IRGKangXi=0156.270, RSKangXi=24.6, Def{humble, low, inferior; despise}
5352 CJK UNIFIED IDEOGRAPH-#5352, IRGKangXi=0156.280, RSKangXi=24.6, Def{soldier; servant; at last, finally}
5353 CJK UNIFIED IDEOGRAPH-#5353, IRGKangXi=0156.290, RSKangXi=24.6, Def{profound, brilliant, lofty}
5354 CJK UNIFIED IDEOGRAPH-#5354, IRGKangXi=0156.340, RSKangXi=24.6, Def{be united; cooperate}
5355 CJK UNIFIED IDEOGRAPH-#5355, IRGKangXi=0157.041, RSKangXi=12.6, Def{single, individual, only; lone}
5356 CJK UNIFIED IDEOGRAPH-#5356, IRGKangXi=0157.041, RSKangXi=24.6, Def{sell; betray; show off}
5357 CJK UNIFIED IDEOGRAPH-#5357, IRGKangXi=0157.050, RSKangXi=24.7, Def{south; southern part; southward}
5358 CJK UNIFIED IDEOGRAPH-#5358, IRGKangXi=0157.051, RSKangXi=24.7, Def{same as 單 U+55AE, single, individual, only; lone}
5359 CJK UNIFIED IDEOGRAPH-#5359, IRGKangXi=0157.090, RSKangXi=24.9
535A CJK UNIFIED IDEOGRAPH-#535A, IRGKangXi=0157.130, RSKangXi=24.10, Def{gamble, play games; wide, broad}
535B CJK UNIFIED IDEOGRAPH-#535B, IRGKangXi=0157.230, RSKangXi=24.19
535C CJK UNIFIED IDEOGRAPH-#535C, IRGKangXi=0157.250, RSKangXi=25.0, Def{fortune telling; prophesy}
535D CJK UNIFIED IDEOGRAPH-#535D, IRGKangXi=0157.270, RSKangXi=25.2, Def{hair style; ore}
535E CJK UNIFIED IDEOGRAPH-#535E, IRGKangXi=0157.280, RSKangXi=25.2, Def{to be impatient, in a hurry; excitable}
535F CJK UNIFIED IDEOGRAPH-#535F, IRGKangXi=0157.290, RSKangXi=30.2, Def{a chemical compound; divination; to consider}
5360 CJK UNIFIED IDEOGRAPH-#5360, IRGKangXi=0157.300, RSKangXi=25.3, Def{divine; observe; versify}
5361 CJK UNIFIED IDEOGRAPH-#5361, IRGKangXi=0158.010, RSKangXi=25.3, Def{card, punch card; calorie}
5362 CJK UNIFIED IDEOGRAPH-#5362, IRGKangXi=0158.021, RSKangXi=25.3, Def{cottage, hut; surname; black}
5363 CJK UNIFIED IDEOGRAPH-#5363, IRGKangXi=0158.060, RSKangXi=25.5, Def{wine pot}
5364 CJK UNIFIED IDEOGRAPH-#5364, IRGKangXi=0158.100, RSKangXi=25.5, Def{salt}
5365 CJK UNIFIED IDEOGRAPH-#5365, IRGKangXi=0158.110, RSKangXi=25.6
5366 CJK UNIFIED IDEOGRAPH-#5366, IRGKangXi=0158.130, RSKangXi=25.6, Def{fortune telling; tell fortunes}
5367 CJK UNIFIED IDEOGRAPH-#5367, IRGKangXi=0158.221, RSKangXi=131.2, Def{lie down; crouch}
5368 CJK UNIFIED IDEOGRAPH-#5368, IRGKangXi=0158.320, RSKangXi=25.9, Def{used in old names; phonetic seol used in Korean names}
5369 CJK UNIFIED IDEOGRAPH-#5369, IRGKangXi=0158.450, RSKangXi=26.0, Def{seal; KangXi radical 26}
536A CJK UNIFIED IDEOGRAPH-#536A, IRGKangXi=0158.470, RSKangXi=26.1, Def{kwukyel}
536B CJK UNIFIED IDEOGRAPH-#536B, IRGKangXi=0076.141, RSKangXi=5.2, Def{guard, protect, defend}
536C CJK UNIFIED IDEOGRAPH-#536C, IRGKangXi=0158.490, RSKangXi=26.2, Def{lofty; high; raise; high-priced}
536D CJK UNIFIED IDEOGRAPH-#536D, IRGKangXi=0159.030, RSKangXi=26.3, Def{high. to raise}
536E CJK UNIFIED IDEOGRAPH-#536E, IRGKangXi=0159.040, RSKangXi=26.3, Def{measuring cup; wine container}
536F CJK UNIFIED IDEOGRAPH-#536F, IRGKangXi=0159.050, RSKangXi=26.3, Def{4th terrestrial branch; period from 5-7 a.m.}
5370 CJK UNIFIED IDEOGRAPH-#5370, IRGKangXi=0159.100, RSKangXi=26.4, Def{print, seal, stamp, chop, mark}
5371 CJK UNIFIED IDEOGRAPH-#5371, IRGKangXi=0159.120, RSKangXi=26.4, Def{dangerous, precarious; high}
5372 CJK UNIFIED IDEOGRAPH-#5372, IRGKangXi=0159.170, RSKangXi=26.5, Def{eminent, lofty; beautiful; surname}
5373 CJK UNIFIED IDEOGRAPH-#5373, IRGKangXi=0159.180, RSKangXi=26.5, Def{promptly, quickly, immediately}
5374 CJK UNIFIED IDEOGRAPH-#5374, IRGKangXi=0159.190, RSKangXi=26.5, Def{still, but; decline; retreat}
5375 CJK UNIFIED IDEOGRAPH-#5375, IRGKangXi=0159.200, RSKangXi=26.5, Def{egg; ovum; roe; spawn}
5376 CJK UNIFIED IDEOGRAPH-#5376, IRGKangXi=0159.220, RSKangXi=26.6
5377 CJK UNIFIED IDEOGRAPH-#5377, IRGKangXi=0159.230, RSKangXi=26.6, Def{scroll; curl; make a comeback}
5378 CJK UNIFIED IDEOGRAPH-#5378, IRGKangXi=0159.240, RSKangXi=26.6, Def{lay down; retire from office}
5379 CJK UNIFIED IDEOGRAPH-#5379, IRGKangXi=0159.250, RSKangXi=26.6, Def{sympathy, pity; comfort}
537A CJK UNIFIED IDEOGRAPH-#537A, IRGKangXi=0159.270, RSKangXi=26.6, Def{(nuptial) winecups}
537B CJK UNIFIED IDEOGRAPH-#537B, IRGKangXi=0159.280, RSKangXi=26.7, Def{still, but; decline; retreat}
537C CJK UNIFIED IDEOGRAPH-#537C, IRGKangXi=0298.291, RSKangXi=26.7, Def{unsteady; dangerous}
537D CJK UNIFIED IDEOGRAPH-#537D, IRGKangXi=0160.030, RSKangXi=26.7, Def{promptly}
537E CJK UNIFIED IDEOGRAPH-#537E, IRGKangXi=0160.070, RSKangXi=26.9
537F CJK UNIFIED IDEOGRAPH-#537F, IRGKangXi=0160.080, RSKangXi=26.9, Def{noble, high officer}
5380 CJK UNIFIED IDEOGRAPH-#5380, IRGKangXi=0160.110, RSKangXi=26.11
5381 CJK UNIFIED IDEOGRAPH-#5381, IRGKangXi=0478.211, RSKangXi=26.11
5382 CJK UNIFIED IDEOGRAPH-#5382, IRGKangXi=0160.150, RSKangXi=27.0, Def{factory, workshop; radical 27}
5383 CJK UNIFIED IDEOGRAPH-#5383, IRGKangXi=0160.170, RSKangXi=27.2, Def{to look upward}
5384 CJK UNIFIED IDEOGRAPH-#5384, IRGKangXi=0160.180, RSKangXi=27.2, Def{adversity, difficulty, distress}
5385 CJK UNIFIED IDEOGRAPH-#5385, IRGKangXi=0160.181, RSKangXi=27.2, Def{hall, central room}
5386 CJK UNIFIED IDEOGRAPH-#5386, IRGKangXi=0160.181, RSKangXi=27.2, Def{history; calendar}
5387 CJK UNIFIED IDEOGRAPH-#5387, IRGKangXi=0160.200, RSKangXi=27.3
5388 CJK UNIFIED IDEOGRAPH-#5388, IRGKangXi=0160.210, RSKangXi=27.3
5389 CJK UNIFIED IDEOGRAPH-#5389, IRGKangXi=0160.251, RSKangXi=27.3, Def{whetstone; grind, sharpen; whet}
538A CJK UNIFIED IDEOGRAPH-#538A, IRGKangXi=0160.300, RSKangXi=27.4
538B CJK UNIFIED IDEOGRAPH-#538B, IRGKangXi=0160.371, RSKangXi=27.4, Def{press; oppress; crush; pressure}
538C CJK UNIFIED IDEOGRAPH-#538C, IRGKangXi=0160.371, RSKangXi=27.4, Def{dislike, detest, reject; satiate}
538D CJK UNIFIED IDEOGRAPH-#538D, IRGKangXi=0160.371, RSKangXi=27.4, Def{surname}
538E CJK UNIFIED IDEOGRAPH-#538E, IRGKangXi=0160.400, RSKangXi=27.5, Def{settle}
538F CJK UNIFIED IDEOGRAPH-#538F, IRGKangXi=0161.010, RSKangXi=27.5
5390 CJK UNIFIED IDEOGRAPH-#5390, IRGKangXi=0161.061, RSKangXi=212.2, Def{disorderly, messy; huge, big}
5391 CJK UNIFIED IDEOGRAPH-#5391, IRGKangXi=0161.061, RSKangXi=27.5
5392 CJK UNIFIED IDEOGRAPH-#5392, IRGKangXi=0161.070, RSKangXi=27.6
5393 CJK UNIFIED IDEOGRAPH-#5393, IRGKangXi=0161.080, RSKangXi=27.6, Def{precipice, shore, bank; surname}
5394 CJK UNIFIED IDEOGRAPH-#5394, IRGKangXi=0161.110, RSKangXi=27.6, Def{stop, hinder; place near water}
5395 CJK UNIFIED IDEOGRAPH-#5395, IRGKangXi=0161.171, RSKangXi=27.6, Def{mingle with; toilet, lavatory}
5396 CJK UNIFIED IDEOGRAPH-#5396, IRGKangXi=0161.190, RSKangXi=27.7, Def{bulky; thick and large; confused}
5397 CJK UNIFIED IDEOGRAPH-#5397, IRGKangXi=0161.200, RSKangXi=27.7
5398 CJK UNIFIED IDEOGRAPH-#5398, IRGKangXi=0161.230, RSKangXi=27.7, Def{thousandth part of tael}
5399 CJK UNIFIED IDEOGRAPH-#5399, IRGKangXi=0161.250, RSKangXi=27.7, Def{surname}
539A CJK UNIFIED IDEOGRAPH-#539A, IRGKangXi=0161.260, RSKangXi=27.7, Def{thick; substantial; greatly}
539B CJK UNIFIED IDEOGRAPH-#539B, IRGKangXi=0161.351, RSKangXi=27.7
539C CJK UNIFIED IDEOGRAPH-#539C, IRGKangXi=0161.360, RSKangXi=27.8, Def{a mountain peak}
539D CJK UNIFIED IDEOGRAPH-#539D, IRGKangXi=0161.370, RSKangXi=27.8, Def{cut or engrave; a grave or tombstone}
539E CJK UNIFIED IDEOGRAPH-#539E, IRGKangXi=0161.460, RSKangXi=27.8
539F CJK UNIFIED IDEOGRAPH-#539F, IRGKangXi=0162.030, RSKangXi=27.8, Def{source, origin, beginning}
53A0 CJK UNIFIED IDEOGRAPH-#53A0, IRGKangXi=0162.130, RSKangXi=27.9, Def{mingle with; toilet, lavatory}
53A1 CJK UNIFIED IDEOGRAPH-#53A1, IRGKangXi=0162.150, RSKangXi=27.9
53A2 CJK UNIFIED IDEOGRAPH-#53A2, IRGKangXi=0162.191, RSKangXi=27.9, Def{side-room, wing; theatre box}
53A3 CJK UNIFIED IDEOGRAPH-#53A3, IRGKangXi=0162.191, RSKangXi=27.9, Def{shell}
53A4 CJK UNIFIED IDEOGRAPH-#53A4, IRGKangXi=0162.200, RSKangXi=27.10, Def{to calculate; the calendar}
53A5 CJK UNIFIED IDEOGRAPH-#53A5, IRGKangXi=0162.220, RSKangXi=27.10, Def{personal pronoun he, she, it}
53A6 CJK UNIFIED IDEOGRAPH-#53A6, IRGKangXi=0162.280, RSKangXi=27.10, Def{big building, mansion}
53A7 CJK UNIFIED IDEOGRAPH-#53A7, IRGKangXi=0162.330, RSKangXi=27.10
53A8 CJK UNIFIED IDEOGRAPH-#53A8, IRGKangXi=0162.371, RSKangXi=27.10, Def{kitchen; closet; cupboard}
53A9 CJK UNIFIED IDEOGRAPH-#53A9, IRGKangXi=0162.380, RSKangXi=27.9, Def{stable; barnyard}
53AA CJK UNIFIED IDEOGRAPH-#53AA, IRGKangXi=0162.390, RSKangXi=27.11, Def{a hut; careful}
53AB CJK UNIFIED IDEOGRAPH-#53AB, IRGKangXi=0162.400, RSKangXi=27.11, Def{granary}
53AC CJK UNIFIED IDEOGRAPH-#53AC, IRGKangXi=0162.470, RSKangXi=27.12
53AD CJK UNIFIED IDEOGRAPH-#53AD, IRGKangXi=0162.510, RSKangXi=27.12, Def{dislike, detest, reject; satiate}
53AE CJK UNIFIED IDEOGRAPH-#53AE, IRGKangXi=0163.010, RSKangXi=27.12, Def{servant; to make a disturbance}
53AF CJK UNIFIED IDEOGRAPH-#53AF, IRGKangXi=0162.441, RSKangXi=61.10
53B0 CJK UNIFIED IDEOGRAPH-#53B0, IRGKangXi=0163.041, RSKangXi=27.12, Def{factory, plant, workshop, mill}
53B1 CJK UNIFIED IDEOGRAPH-#53B1, IRGKangXi=0163.080, RSKangXi=27.13
53B2 CJK UNIFIED IDEOGRAPH-#53B2, IRGKangXi=0163.090, RSKangXi=27.13, Def{whetstone; grind, sharpen; whet}
53B3 CJK UNIFIED IDEOGRAPH-#53B3, IRGKangXi=0163.131, RSKangXi=27.15, Def{strict, rigorous, rigid; stern}
53B4 CJK UNIFIED IDEOGRAPH-#53B4, IRGKangXi=0163.140, RSKangXi=27.17, Def{shell}
53B5 CJK UNIFIED IDEOGRAPH-#53B5, IRGKangXi=0163.190, RSKangXi=27.28, Def{a spring; source}
53B6 CJK UNIFIED IDEOGRAPH-#53B6, IRGKangXi=0163.200, RSKangXi=28.0, Def{private, secret; KangXi radical 28}
53B7 CJK UNIFIED IDEOGRAPH-#53B7, IRGKangXi=0164.040, RSKangXi=28.2, Def{the fore-arm; most Chinese-English dictionaries give the upper-arm; round}
53B8 CJK UNIFIED IDEOGRAPH-#53B8, IRGKangXi=0164.060, RSKangXi=28.2
53B9 CJK UNIFIED IDEOGRAPH-#53B9, IRGKangXi=0164.070, RSKangXi=28.2, Def{spear; tribe}
53BA CJK UNIFIED IDEOGRAPH-#53BA, IRGKangXi=0164.090, RSKangXi=28.3, Def{to go; depart}
53BB CJK UNIFIED IDEOGRAPH-#53BB, IRGKangXi=0164.100, RSKangXi=28.3, Def{go away, leave, depart}
53BC CJK UNIFIED IDEOGRAPH-#53BC, IRGKangXi=0164.111, RSKangXi=42.2, Def{kwukyel}
53BD CJK UNIFIED IDEOGRAPH-#53BD, IRGKangXi=0164.130, RSKangXi=28.4
53BE CJK UNIFIED IDEOGRAPH-#53BE, IRGKangXi=0164.151, RSKangXi=5.5, Def{lightly tap; through away; drop; sentence final particle}
53BF CJK UNIFIED IDEOGRAPH-#53BF, IRGKangXi=0164.161, RSKangXi=28.5, Def{county, district, subdivision}
53C0 CJK UNIFIED IDEOGRAPH-#53C0, IRGKangXi=0164.170, RSKangXi=28.6
53C1 CJK UNIFIED IDEOGRAPH-#53C1, IRGKangXi=0164.211, RSKangXi=28.6, AccountingNumeric=3, Def{bank form of numeral 'three'}
53C2 CJK UNIFIED IDEOGRAPH-#53C2, IRGKangXi=0164.211, RSKangXi=28.6, AccountingNumeric=3, Def{take part in, intervene; ginseng}
53C3 CJK UNIFIED IDEOGRAPH-#53C3, IRGKangXi=0164.280, RSKangXi=28.9, AccountingNumeric=3, Def{take part in, intervene; ginseng}
53C4 CJK UNIFIED IDEOGRAPH-#53C4, IRGKangXi=0164.301, Def{take part in, intervene; ginseng}
53C5 CJK UNIFIED IDEOGRAPH-#53C5, IRGKangXi=0164.310, RSKangXi=28.10, Def{to counsel, to consult together; to take part in; to intervene}
53C6 CJK UNIFIED IDEOGRAPH-#53C6, IRGKangXi=0088.011, RSKangXi=28.12, Def{cloudy sky; dark, obscure}
53C7 CJK UNIFIED IDEOGRAPH-#53C7, IRGKangXi=0088.011, RSKangXi=28.13
53C8 CJK UNIFIED IDEOGRAPH-#53C8, IRGKangXi=0164.430, RSKangXi=29.0, Def{and, also, again, in addition}
53C9 CJK UNIFIED IDEOGRAPH-#53C9, IRGKangXi=0165.010, RSKangXi=29.1, Def{crotch; fork, prong}
53CA CJK UNIFIED IDEOGRAPH-#53CA, IRGKangXi=0165.030, RSKangXi=29.2, Def{extend; reach; come up to; and}
53CB CJK UNIFIED IDEOGRAPH-#53CB, IRGKangXi=0165.060, RSKangXi=29.2, Def{friend, companion; fraternity}
53CC CJK UNIFIED IDEOGRAPH-#53CC, IRGKangXi=0165.170, RSKangXi=29.2, Def{set of two, pair, couple; both}
53CD CJK UNIFIED IDEOGRAPH-#53CD, IRGKangXi=0165.190, RSKangXi=29.2, Def{reverse, opposite, contrary, anti}
53CE CJK UNIFIED IDEOGRAPH-#53CE, IRGKangXi=0165.210, RSKangXi=29.2, Def{gather together, collect; harvest}
53CF CJK UNIFIED IDEOGRAPH-#53CF, IRGKangXi=0165.230, RSKangXi=29.3
53D0 CJK UNIFIED IDEOGRAPH-#53D0, IRGKangXi=0165.250, RSKangXi=29.3, Def{to prick a dog to make him go}
53D1 CJK UNIFIED IDEOGRAPH-#53D1, IRGKangXi=0165.271, RSKangXi=29.3, Def{issue, dispatch, send out; hair}
53D2 CJK UNIFIED IDEOGRAPH-#53D2, IRGKangXi=0165.290, RSKangXi=29.4, Def{obedient; united}
53D3 CJK UNIFIED IDEOGRAPH-#53D3, IRGKangXi=0165.360, RSKangXi=29.5, Def{affair, matter; work}
53D4 CJK UNIFIED IDEOGRAPH-#53D4, IRGKangXi=0165.420, RSKangXi=29.6, Def{father's younger brother}
53D5 CJK UNIFIED IDEOGRAPH-#53D5, IRGKangXi=0166.030, RSKangXi=29.6, Def{to connect}
53D6 CJK UNIFIED IDEOGRAPH-#53D6, IRGKangXi=0166.040, RSKangXi=29.6, Def{take, receive, obtain; select}
53D7 CJK UNIFIED IDEOGRAPH-#53D7, IRGKangXi=0166.050, RSKangXi=29.6, Def{receive, accept, get; bear, stand}
53D8 CJK UNIFIED IDEOGRAPH-#53D8, IRGKangXi=0166.071, RSKangXi=29.6, Def{change, transform, alter; rebel}
53D9 CJK UNIFIED IDEOGRAPH-#53D9, IRGKangXi=0166.090, RSKangXi=29.7, Def{express, state, relate, narrate}
53DA CJK UNIFIED IDEOGRAPH-#53DA, IRGKangXi=0166.110, RSKangXi=29.7, Def{false}
53DB CJK UNIFIED IDEOGRAPH-#53DB, IRGKangXi=0166.120, RSKangXi=29.7, Def{rebel; rebellion; rebellious}
53DC CJK UNIFIED IDEOGRAPH-#53DC, IRGKangXi=0166.130, RSKangXi=29.7, Def{old man}
53DD CJK UNIFIED IDEOGRAPH-#53DD, IRGKangXi=0166.160, RSKangXi=29.7, Def{to respectfully inform}
53DE CJK UNIFIED IDEOGRAPH-#53DE, IRGKangXi=0166.180, RSKangXi=29.8
53DF CJK UNIFIED IDEOGRAPH-#53DF, IRGKangXi=0166.210, RSKangXi=29.8, Def{old man; elder}
53E0 CJK UNIFIED IDEOGRAPH-#53E0, IRGKangXi=0166.461, RSKangXi=29.11, Def{pile; be piled up; fold up}
53E1 CJK UNIFIED IDEOGRAPH-#53E1, IRGKangXi=0167.040, RSKangXi=29.14, Def{astute, profound, shrewd}
53E2 CJK UNIFIED IDEOGRAPH-#53E2, IRGKangXi=0167.120, RSKangXi=29.16, Def{bush, shrub; thicket; collection}
53E3 CJK UNIFIED IDEOGRAPH-#53E3, IRGKangXi=0171.010, RSKangXi=30.0, Def{mouth; open end; entrance, gate}
53E4 CJK UNIFIED IDEOGRAPH-#53E4, IRGKangXi=0171.080, RSKangXi=30.2, Def{old, classic, ancient}
53E5 CJK UNIFIED IDEOGRAPH-#53E5, IRGKangXi=0171.110, RSKangXi=30.2, Def{sentence}
53E6 CJK UNIFIED IDEOGRAPH-#53E6, IRGKangXi=0172.010, RSKangXi=30.2, Def{another, separate, other}
53E7 CJK UNIFIED IDEOGRAPH-#53E7, IRGKangXi=0172.020, RSKangXi=30.2, Def{to cut meat off away from bones; ancient torture}
53E8 CJK UNIFIED IDEOGRAPH-#53E8, IRGKangXi=0172.030, RSKangXi=30.2, Def{talkative; quarrelous}
53E9 CJK UNIFIED IDEOGRAPH-#53E9, IRGKangXi=0172.040, RSKangXi=30.2, Def{knock, ask; kowtow, bow}
53EA CJK UNIFIED IDEOGRAPH-#53EA, IRGKangXi=0172.050, RSKangXi=30.2, Def{only, just, simply}
53EB CJK UNIFIED IDEOGRAPH-#53EB, IRGKangXi=0172.060, RSKangXi=30.2, Def{cry, shout; hail, greet, call}
53EC CJK UNIFIED IDEOGRAPH-#53EC, IRGKangXi=0172.070, RSKangXi=30.2, Def{imperial decree; summon}
53ED CJK UNIFIED IDEOGRAPH-#53ED, IRGKangXi=0172.080, RSKangXi=30.2, Def{trumpet}
53EE CJK UNIFIED IDEOGRAPH-#53EE, IRGKangXi=0172.110, RSKangXi=30.2, Def{exhort or enjoin repeatedly}
53EF CJK UNIFIED IDEOGRAPH-#53EF, IRGKangXi=0172.120, RSKangXi=30.2, Def{may, can, -able; possibly}
53F0 CJK UNIFIED IDEOGRAPH-#53F0, IRGKangXi=0172.130, RSKangXi=30.2, Def{platform; unit; term of address}
53F1 CJK UNIFIED IDEOGRAPH-#53F1, IRGKangXi=0173.020, RSKangXi=30.2, Def{scold, shout at, bawl out}
53F2 CJK UNIFIED IDEOGRAPH-#53F2, IRGKangXi=0173.030, RSKangXi=30.2, Def{history, chronicle, annals}
53F3 CJK UNIFIED IDEOGRAPH-#53F3, IRGKangXi=0173.050, RSKangXi=30.2, Def{right; west; right-wing}
53F4 CJK UNIFIED IDEOGRAPH-#53F4, IRGKangXi=0173.070, RSKangXi=30.2, Def{a three-edged spear}
53F5 CJK UNIFIED IDEOGRAPH-#53F5, IRGKangXi=0173.090, RSKangXi=30.2, Def{cannot, be unable do, improbable; thereupon}
53F6 CJK UNIFIED IDEOGRAPH-#53F6, IRGKangXi=0174.010, RSKangXi=30.2, Def{to harmonize, to rhyme; to unite; (borrowed for) leaf}
53F7 CJK UNIFIED IDEOGRAPH-#53F7, IRGKangXi=0174.020, RSKangXi=30.2, Def{mark, sign; symbol; number}
53F8 CJK UNIFIED IDEOGRAPH-#53F8, IRGKangXi=0174.030, RSKangXi=30.2, Def{take charge of, control, manage; officer}
53F9 CJK UNIFIED IDEOGRAPH-#53F9, IRGKangXi=0174.091, RSKangXi=30.2, Def{sigh, admire}
53FA CJK UNIFIED IDEOGRAPH-#53FA, IRGKangXi=0174.091, RSKangXi=30.2, Def{a straw bag; a tobacco pouch}
53FB CJK UNIFIED IDEOGRAPH-#53FB, IRGKangXi=0174.091, RSKangXi=30.2, Def{used in place names; (Cant.) smart, clever}
53FC CJK UNIFIED IDEOGRAPH-#53FC, IRGKangXi=0174.091, RSKangXi=30.2, Def{holding in mouth}
53FD CJK UNIFIED IDEOGRAPH-#53FD, IRGKangXi=0173.060, RSKangXi=30.2, Def{sigh in disapproval; take small}
53FE CJK UNIFIED IDEOGRAPH-#53FE, IRGKangXi=0174.091, RSKangXi=30.2, Def{西貢叾, a place in Hong Kong}
53FF CJK UNIFIED IDEOGRAPH-#53FF, IRGKangXi=0174.100, RSKangXi=30.3
5400 CJK UNIFIED IDEOGRAPH-#5400, IRGKangXi=0174.130, RSKangXi=30.3
5401 CJK UNIFIED IDEOGRAPH-#5401, IRGKangXi=0174.140, RSKangXi=30.3, Def{interjection 'Alas!'; to sigh}
5402 CJK UNIFIED IDEOGRAPH-#5402, IRGKangXi=0174.160, RSKangXi=30.3
5403 CJK UNIFIED IDEOGRAPH-#5403, IRGKangXi=0174.170, RSKangXi=30.3, Def{eat; drink; suffer, endure, bear}
5404 CJK UNIFIED IDEOGRAPH-#5404, IRGKangXi=0174.180, RSKangXi=30.3, Def{each, individually, every, all}
5405 CJK UNIFIED IDEOGRAPH-#5405, IRGKangXi=0174.190, RSKangXi=30.3
5406 CJK UNIFIED IDEOGRAPH-#5406, IRGKangXi=0174.200, RSKangXi=30.3, Def{bawl, yell, shout, cry out}
5407 CJK UNIFIED IDEOGRAPH-#5407, IRGKangXi=0174.220, RSKangXi=30.3
5408 CJK UNIFIED IDEOGRAPH-#5408, IRGKangXi=0174.240, RSKangXi=30.3, Def{combine, unite, join; gather}
5409 CJK UNIFIED IDEOGRAPH-#5409, IRGKangXi=0175.020, RSKangXi=30.3, Def{lucky, propitious, good}
540A CJK UNIFIED IDEOGRAPH-#540A, IRGKangXi=0175.030, RSKangXi=30.3, Def{condole, mourn, pity; hang}
540B CJK UNIFIED IDEOGRAPH-#540B, IRGKangXi=0175.040, RSKangXi=30.3, Def{English inch (unlike U+5BF8 寸, which can be either the English or the Chinese inch)}
540C CJK UNIFIED IDEOGRAPH-#540C, IRGKangXi=0175.060, RSKangXi=30.3, Def{same, similar; together with}
540D CJK UNIFIED IDEOGRAPH-#540D, IRGKangXi=0175.090, RSKangXi=30.3, Def{name, rank, title, position}
540E CJK UNIFIED IDEOGRAPH-#540E, IRGKangXi=0176.010, RSKangXi=30.3, Def{queen, empress, sovereign; (simp. for 後) behind, rear, after}
540F CJK UNIFIED IDEOGRAPH-#540F, IRGKangXi=0176.020, RSKangXi=30.3, Def{government official, magistrate}
5410 CJK UNIFIED IDEOGRAPH-#5410, IRGKangXi=0176.030, RSKangXi=30.3, Def{vomit, spew out, cough up}
5411 CJK UNIFIED IDEOGRAPH-#5411, IRGKangXi=0176.040, RSKangXi=30.3, Def{toward, direction, trend}
5412 CJK UNIFIED IDEOGRAPH-#5412, IRGKangXi=0176.050, RSKangXi=30.3, Def{shout, roar, bellow; scold}
5413 CJK UNIFIED IDEOGRAPH-#5413, IRGKangXi=0177.021, RSKangXi=30.3, Def{scare, frighten; intimidate}
5414 CJK UNIFIED IDEOGRAPH-#5414, IRGKangXi=0177.021, RSKangXi=30.3, Def{(Cant.) an interjection; phonetic}
5415 CJK UNIFIED IDEOGRAPH-#5415, IRGKangXi=0177.021, RSKangXi=30.3, Def{surname; a musical note}
5416 CJK UNIFIED IDEOGRAPH-#5416, IRGKangXi=0177.021, RSKangXi=30.3, Def{used in translation; (Cant.) final particle}
5417 CJK UNIFIED IDEOGRAPH-#5417, IRGKangXi=0177.021, RSKangXi=30.3, Def{final interrogative particle}
5418 CJK UNIFIED IDEOGRAPH-#5418, IRGKangXi=0177.030, RSKangXi=30.4
5419 CJK UNIFIED IDEOGRAPH-#5419, IRGKangXi=0177.050, RSKangXi=30.4
541A CJK UNIFIED IDEOGRAPH-#541A, IRGKangXi=0177.060, RSKangXi=30.4, Def{used to represent sound}
541B CJK UNIFIED IDEOGRAPH-#541B, IRGKangXi=0177.070, RSKangXi=30.4, Def{sovereign, monarch, ruler, chief, prince}
541C CJK UNIFIED IDEOGRAPH-#541C, IRGKangXi=0177.100, RSKangXi=30.4
541D CJK UNIFIED IDEOGRAPH-#541D, IRGKangXi=0177.130, RSKangXi=30.4, Def{stingy, miserly, parsimonious}
541E CJK UNIFIED IDEOGRAPH-#541E, IRGKangXi=0177.180, RSKangXi=30.4, Def{swallow; absorb, annex, engulf}
541F CJK UNIFIED IDEOGRAPH-#541F, IRGKangXi=0177.190, RSKangXi=30.4, Def{sing, hum; recite; type of poetry}
5420 CJK UNIFIED IDEOGRAPH-#5420, IRGKangXi=0177.220, RSKangXi=30.4, Def{bark}
5421 CJK UNIFIED IDEOGRAPH-#5421, IRGKangXi=0177.240, RSKangXi=30.4, Def{blame}
5422 CJK UNIFIED IDEOGRAPH-#5422, IRGKangXi=0177.260, RSKangXi=30.4, Def{vomiting of a dog}
5423 CJK UNIFIED IDEOGRAPH-#5423, IRGKangXi=0177.270, RSKangXi=30.4, Def{vomit}
5424 CJK UNIFIED IDEOGRAPH-#5424, IRGKangXi=0177.280, RSKangXi=30.4
5425 CJK UNIFIED IDEOGRAPH-#5425, IRGKangXi=0177.290, RSKangXi=30.4
5426 CJK UNIFIED IDEOGRAPH-#5426, IRGKangXi=0178.020, RSKangXi=30.4, Def{not, no, negative; final particle}
5427 CJK UNIFIED IDEOGRAPH-#5427, IRGKangXi=0178.040, RSKangXi=30.4, Def{emphatic final particle}
5428 CJK UNIFIED IDEOGRAPH-#5428, IRGKangXi=0178.060, RSKangXi=30.4, Def{metric ton; (Cant.) to babble, gibberish}
5429 CJK UNIFIED IDEOGRAPH-#5429, IRGKangXi=0178.110, RSKangXi=30.4, Def{order, command, instruct}
542A CJK UNIFIED IDEOGRAPH-#542A, IRGKangXi=0178.120, RSKangXi=30.4, Def{move}
542B CJK UNIFIED IDEOGRAPH-#542B, IRGKangXi=0178.140, RSKangXi=30.4, Def{hold in mouth; cherish; contain}
542C CJK UNIFIED IDEOGRAPH-#542C, IRGKangXi=0178.160, RSKangXi=30.4, Def{hear; understand; obey, comply}
542D CJK UNIFIED IDEOGRAPH-#542D, IRGKangXi=0178.170, RSKangXi=30.4, Def{throat}
542E CJK UNIFIED IDEOGRAPH-#542E, IRGKangXi=0178.200, RSKangXi=30.4, Def{suck with mouth, sip, lick}
542F CJK UNIFIED IDEOGRAPH-#542F, IRGKangXi=0178.210, RSKangXi=30.4, Def{open; begin, commence; explain}
5430 CJK UNIFIED IDEOGRAPH-#5430, IRGKangXi=0178.240, RSKangXi=30.4, Def{clang}
5431 CJK UNIFIED IDEOGRAPH-#5431, IRGKangXi=0179.010, RSKangXi=30.4, Def{chirping, squeaking, hissing}
5432 CJK UNIFIED IDEOGRAPH-#5432, IRGKangXi=0179.030, RSKangXi=30.4, Def{smile at; sneer at}
5433 CJK UNIFIED IDEOGRAPH-#5433, IRGKangXi=0179.040, RSKangXi=30.4, Def{one of warring states; surname}
5434 CJK UNIFIED IDEOGRAPH-#5434, IRGKangXi=0179.070, RSKangXi=30.4, Def{name of warring state; surname}
5435 CJK UNIFIED IDEOGRAPH-#5435, IRGKangXi=0179.080, RSKangXi=30.4, Def{argue, dispute; disturb, annoy}
5436 CJK UNIFIED IDEOGRAPH-#5436, IRGKangXi=0179.100, RSKangXi=30.4, Def{raise voice, yell out loud, shout; stammer}
5437 CJK UNIFIED IDEOGRAPH-#5437, IRGKangXi=0179.110, RSKangXi=30.4
5438 CJK UNIFIED IDEOGRAPH-#5438, IRGKangXi=0179.120, RSKangXi=30.4, Def{inhale, suck in; absorb; attract}
5439 CJK UNIFIED IDEOGRAPH-#5439, IRGKangXi=0179.130, RSKangXi=30.4, Def{blow; puff; brag, boast}
543A CJK UNIFIED IDEOGRAPH-#543A, IRGKangXi=0179.140, RSKangXi=30.4
543B CJK UNIFIED IDEOGRAPH-#543B, IRGKangXi=0179.150, RSKangXi=30.4, Def{kiss; the lips; coinciding}
543C CJK UNIFIED IDEOGRAPH-#543C, IRGKangXi=0180.010, RSKangXi=30.4, Def{roar, shout; bark, howl}
543D CJK UNIFIED IDEOGRAPH-#543D, IRGKangXi=0180.020, RSKangXi=30.4, Def{'OM'; bellow; (Cant.) dull, stupid}
543E CJK UNIFIED IDEOGRAPH-#543E, IRGKangXi=0180.030, RSKangXi=30.4, Def{i, my, our; resist, impede}
543F CJK UNIFIED IDEOGRAPH-#543F, IRGKangXi=0180.060, Def{tell, announce, inform; accuse}
5440 CJK UNIFIED IDEOGRAPH-#5440, IRGKangXi=0180.080, RSKangXi=30.4, Def{particle used to express surprise or mild emphasis; (Cant.) slurred form of the number ten}
5441 CJK UNIFIED IDEOGRAPH-#5441, IRGKangXi=0181.010, RSKangXi=30.4
5442 CJK UNIFIED IDEOGRAPH-#5442, IRGKangXi=0181.030, RSKangXi=30.4, Def{surname; a musical note}
5443 CJK UNIFIED IDEOGRAPH-#5443, IRGKangXi=0181.040, RSKangXi=30.4, Def{belch; hiccup}
5444 CJK UNIFIED IDEOGRAPH-#5444, IRGKangXi=0181.060, RSKangXi=30.4
5445 CJK UNIFIED IDEOGRAPH-#5445, IRGKangXi=0181.080, RSKangXi=30.4, Def{(Cant.) a dollar}
5446 CJK UNIFIED IDEOGRAPH-#5446, IRGKangXi=0181.110, RSKangXi=30.4, Def{dull; dull-minded, simple, stupid}
5447 CJK UNIFIED IDEOGRAPH-#5447, IRGKangXi=0181.160, RSKangXi=30.4, Def{star}
5448 CJK UNIFIED IDEOGRAPH-#5448, IRGKangXi=0181.170, RSKangXi=30.4, Def{submit, show; appear; petition}
5449 CJK UNIFIED IDEOGRAPH-#5449, IRGKangXi=0181.191, RSKangXi=30.4, Def{one of warring states; surname}
544A CJK UNIFIED IDEOGRAPH-#544A, IRGKangXi=0181.191, RSKangXi=30.4, Def{tell, announce, inform; accuse}
544B CJK UNIFIED IDEOGRAPH-#544B, IRGKangXi=0181.191, RSKangXi=30.4
544C CJK UNIFIED IDEOGRAPH-#544C, IRGKangXi=0181.191, RSKangXi=30.4, Def{to call; to summon}
544D CJK UNIFIED IDEOGRAPH-#544D, IRGKangXi=0181.191, RSKangXi=30.4, Def{(Cant.) phonetic}
544E CJK UNIFIED IDEOGRAPH-#544E, IRGKangXi=0181.191, RSKangXi=30.4, Def{foot}
544F CJK UNIFIED IDEOGRAPH-#544F, IRGKangXi=0181.191, RSKangXi=30.4, Def{gallon; quart}
5450 CJK UNIFIED IDEOGRAPH-#5450, IRGKangXi=0181.191, RSKangXi=30.4, Def{raise voice, yell out loud, shout; stammer}
5451 CJK UNIFIED IDEOGRAPH-#5451, IRGKangXi=0181.191, RSKangXi=30.4, Def{swallow; absorb}
5452 CJK UNIFIED IDEOGRAPH-#5452, IRGKangXi=0181.191, RSKangXi=30.4, Def{unclear; an expletive}
5453 CJK UNIFIED IDEOGRAPH-#5453, IRGKangXi=0181.191, RSKangXi=30.4, Def{talk in one's sleep, somniloquy}
5454 CJK UNIFIED IDEOGRAPH-#5454, IRGKangXi=0181.191, RSKangXi=30.4, Def{(Cant.) a necktie, a tire}
5455 CJK UNIFIED IDEOGRAPH-#5455, IRGKangXi=0181.191, RSKangXi=30.4, Def{vomit; annoy, enrage}
5456 CJK UNIFIED IDEOGRAPH-#5456, IRGKangXi=0181.191, RSKangXi=30.4, Def{used in onomatopoetic expressions}
5457 CJK UNIFIED IDEOGRAPH-#5457, IRGKangXi=0181.191, RSKangXi=30.4, Def{final particle of assertion}
5458 CJK UNIFIED IDEOGRAPH-#5458, IRGKangXi=0181.191, RSKangXi=30.4, Def{member; personnel, staff member}
5459 CJK UNIFIED IDEOGRAPH-#5459, IRGKangXi=0181.191, RSKangXi=30.4, Def{chat, jaw, gossip, talk; mouth}
545A CJK UNIFIED IDEOGRAPH-#545A, IRGKangXi=0181.191, RSKangXi=30.4
545B CJK UNIFIED IDEOGRAPH-#545B, IRGKangXi=0181.191, RSKangXi=30.4, Def{choke by smoke; irritates nose}
545C CJK UNIFIED IDEOGRAPH-#545C, IRGKangXi=0181.191, RSKangXi=30.4, Def{sound of crying, sobbing}
545D CJK UNIFIED IDEOGRAPH-#545D, IRGKangXi=0181.200, RSKangXi=30.5
545E CJK UNIFIED IDEOGRAPH-#545E, IRGKangXi=0181.210, RSKangXi=30.5
545F CJK UNIFIED IDEOGRAPH-#545F, IRGKangXi=0181.220, RSKangXi=30.5, Def{to mutter, grumble, murmur}
5460 CJK UNIFIED IDEOGRAPH-#5460, IRGKangXi=0181.230, RSKangXi=30.5, Def{to spurt; to blow out; to puff out; to snort}
5461 CJK UNIFIED IDEOGRAPH-#5461, IRGKangXi=0181.240, RSKangXi=30.5, Def{the corners of the mouth the lips}
5462 CJK UNIFIED IDEOGRAPH-#5462, IRGKangXi=0181.250, RSKangXi=30.5, Def{interrogative or emphatic final; (Cant.) this}
5463 CJK UNIFIED IDEOGRAPH-#5463, IRGKangXi=0181.280, RSKangXi=30.5
5464 CJK UNIFIED IDEOGRAPH-#5464, IRGKangXi=0181.290, RSKangXi=30.5, Def{purine}
5465 CJK UNIFIED IDEOGRAPH-#5465, IRGKangXi=0181.300, RSKangXi=30.5, Def{(Cant.) intensifying particle}
5466 CJK UNIFIED IDEOGRAPH-#5466, IRGKangXi=0181.320, RSKangXi=30.5, Def{the bleating of the deer}
5467 CJK UNIFIED IDEOGRAPH-#5467, IRGKangXi=0181.330, RSKangXi=30.5, Def{to rebuke; to scold; slander}
5468 CJK UNIFIED IDEOGRAPH-#5468, IRGKangXi=0181.360, RSKangXi=30.5, Def{Zhou dynasty; circumference}
5469 CJK UNIFIED IDEOGRAPH-#5469, IRGKangXi=0182.010, RSKangXi=30.5
546A CJK UNIFIED IDEOGRAPH-#546A, IRGKangXi=0182.020, RSKangXi=30.5, Def{curse, damn, incantation}
546B CJK UNIFIED IDEOGRAPH-#546B, IRGKangXi=0182.040, RSKangXi=30.5, Def{whisper; lick, taste; petty}
546C CJK UNIFIED IDEOGRAPH-#546C, IRGKangXi=0182.050, RSKangXi=30.5, Def{to rest}
546D CJK UNIFIED IDEOGRAPH-#546D, IRGKangXi=0182.060, RSKangXi=30.5, Def{final particle expressing consent; talkative}
546E CJK UNIFIED IDEOGRAPH-#546E, IRGKangXi=0182.070, RSKangXi=30.5, Def{to sit; (Cant.) only, merely; a final particle of intimacy}
546F CJK UNIFIED IDEOGRAPH-#546F, IRGKangXi=0182.080, RSKangXi=30.5, Def{(Cant.) onomatopoetic, the sound of a gong}
5470 CJK UNIFIED IDEOGRAPH-#5470, IRGKangXi=0182.090, RSKangXi=30.5, Def{to slander, revile}
5471 CJK UNIFIED IDEOGRAPH-#5471, IRGKangXi=0182.100, RSKangXi=30.5, Def{wail, crying of child; swear at}
5472 CJK UNIFIED IDEOGRAPH-#5472, IRGKangXi=0182.110, RSKangXi=30.5, Def{give a talking-to}
5473 CJK UNIFIED IDEOGRAPH-#5473, IRGKangXi=0182.130, RSKangXi=30.5, Def{taste, smell, odor; delicacy}
5474 CJK UNIFIED IDEOGRAPH-#5474, IRGKangXi=0182.140, RSKangXi=30.5, Def{breathe on; yawn; roar}
5475 CJK UNIFIED IDEOGRAPH-#5475, IRGKangXi=0183.020, RSKangXi=30.5, Def{scold; laughing sound; yawn}
5476 CJK UNIFIED IDEOGRAPH-#5476, IRGKangXi=0183.030, RSKangXi=30.5, Def{talkative; clamour; hubbub}
5477 CJK UNIFIED IDEOGRAPH-#5477, IRGKangXi=0183.040, RSKangXi=30.5, Def{suck, swallow, drink}
5478 CJK UNIFIED IDEOGRAPH-#5478, IRGKangXi=0183.050, RSKangXi=30.5, Def{expression of reprimand}
5479 CJK UNIFIED IDEOGRAPH-#5479, IRGKangXi=0183.080, RSKangXi=30.5, Def{(of animals) to eat grass}
547A CJK UNIFIED IDEOGRAPH-#547A, IRGKangXi=0183.090, RSKangXi=30.5, Def{voice of anger vast, spacious}
547B CJK UNIFIED IDEOGRAPH-#547B, IRGKangXi=0183.130, RSKangXi=30.5, Def{groan, moan; recite with intonation}
547C CJK UNIFIED IDEOGRAPH-#547C, IRGKangXi=0183.140, RSKangXi=30.5, Def{breathe sigh, exhale; call, shout}
547D CJK UNIFIED IDEOGRAPH-#547D, IRGKangXi=0183.180, RSKangXi=30.5, Def{life; destiny, fate, luck; an order, instruction}
547E CJK UNIFIED IDEOGRAPH-#547E, IRGKangXi=0184.010, RSKangXi=30.5
547F CJK UNIFIED IDEOGRAPH-#547F, IRGKangXi=0184.020, RSKangXi=30.5, Def{to yawn}
5480 CJK UNIFIED IDEOGRAPH-#5480, IRGKangXi=0184.030, RSKangXi=30.5, Def{suck; chew, masticate}
5481 CJK UNIFIED IDEOGRAPH-#5481, IRGKangXi=0184.040, RSKangXi=30.5, Def{(Cant.) like this, in this way; so, to such an extent}
5482 CJK UNIFIED IDEOGRAPH-#5482, IRGKangXi=0184.050, RSKangXi=30.5, Def{to suck, to smack the lips; (Cant.) to cheat}
5483 CJK UNIFIED IDEOGRAPH-#5483, IRGKangXi=0184.060, RSKangXi=30.5
5484 CJK UNIFIED IDEOGRAPH-#5484, IRGKangXi=0184.070, RSKangXi=30.5, Def{noise of rage, cry out in anger}
5485 CJK UNIFIED IDEOGRAPH-#5485, IRGKangXi=0184.100, RSKangXi=30.5, Def{to spit out}
5486 CJK UNIFIED IDEOGRAPH-#5486, IRGKangXi=0184.110, RSKangXi=30.5, Def{roar}
5487 CJK UNIFIED IDEOGRAPH-#5487, IRGKangXi=0184.120, RSKangXi=30.5, Def{fragrant; (Cant.) to eject}
5488 CJK UNIFIED IDEOGRAPH-#5488, IRGKangXi=0184.130, RSKangXi=30.5, Def{oppose}
5489 CJK UNIFIED IDEOGRAPH-#5489, IRGKangXi=0184.140, RSKangXi=30.5, Def{an echo, a sound to vomit, as an infant}
548A CJK UNIFIED IDEOGRAPH-#548A, IRGKangXi=0184.150, RSKangXi=30.5, Def{harmony; peace; conciliation; to be on good terms with; kindly; mild}
548B CJK UNIFIED IDEOGRAPH-#548B, IRGKangXi=0184.160, RSKangXi=30.5, Def{question-forming particle, why? how? what?; to bite; loud}
548C CJK UNIFIED IDEOGRAPH-#548C, IRGKangXi=0185.010, RSKangXi=30.5, Def{harmony, peace; peaceful, calm}
548D CJK UNIFIED IDEOGRAPH-#548D, IRGKangXi=0185.050, RSKangXi=30.5, Def{laugh}
548E CJK UNIFIED IDEOGRAPH-#548E, IRGKangXi=0185.060, RSKangXi=30.5, Def{fault, defect; error, mistake}
548F CJK UNIFIED IDEOGRAPH-#548F, IRGKangXi=0185.070, RSKangXi=30.5, Def{sing song or poem, hum, chant}
5490 CJK UNIFIED IDEOGRAPH-#5490, IRGKangXi=0185.100, RSKangXi=30.5, Def{instruct, order}
5491 CJK UNIFIED IDEOGRAPH-#5491, IRGKangXi=0185.160, RSKangXi=30.5, Def{(Cant.) 啲咑, a trumpet}
5492 CJK UNIFIED IDEOGRAPH-#5492, IRGKangXi=0185.211, RSKangXi=30.5, Def{curse, damn, incantation}
5493 CJK UNIFIED IDEOGRAPH-#5493, IRGKangXi=0185.211, RSKangXi=30.5, Def{(Cant.) final particle}
5494 CJK UNIFIED IDEOGRAPH-#5494, IRGKangXi=0185.211, RSKangXi=30.5, Def{used in translation}
5495 CJK UNIFIED IDEOGRAPH-#5495, IRGKangXi=0185.211, RSKangXi=30.5, Def{mumble, mutter, murmur; rumble}
5496 CJK UNIFIED IDEOGRAPH-#5496, IRGKangXi=0185.211, RSKangXi=30.5, Def{coffee; a phonetic}
5497 CJK UNIFIED IDEOGRAPH-#5497, IRGKangXi=0185.211, RSKangXi=30.5, Def{(Cant.) verbal particle of perfective aspect}
5498 CJK UNIFIED IDEOGRAPH-#5498, IRGKangXi=0185.211, RSKangXi=30.5
5499 CJK UNIFIED IDEOGRAPH-#5499, IRGKangXi=0185.211, RSKangXi=30.5, Def{throat}
549A CJK UNIFIED IDEOGRAPH-#549A, IRGKangXi=0185.211, RSKangXi=30.5, Def{onomatopoetic, a thumping sound}
549B CJK UNIFIED IDEOGRAPH-#549B, IRGKangXi=0185.211, RSKangXi=30.5, Def{enjoin, instruct; charge}
549C CJK UNIFIED IDEOGRAPH-#549C, IRGKangXi=0185.211, RSKangXi=30.5, Def{to scold}
549D CJK UNIFIED IDEOGRAPH-#549D, IRGKangXi=0185.211, RSKangXi=30.5, Def{hiss; call to come; syllable}
549E CJK UNIFIED IDEOGRAPH-#549E, IRGKangXi=0181.020, RSKangXi=30.6
549F CJK UNIFIED IDEOGRAPH-#549F, IRGKangXi=0185.230, RSKangXi=30.6
54A0 CJK UNIFIED IDEOGRAPH-#54A0, IRGKangXi=0185.240, RSKangXi=30.6, Def{to whisper. to blame to slander}
54A1 CJK UNIFIED IDEOGRAPH-#54A1, IRGKangXi=0186.010, RSKangXi=30.6, Def{side of mouth}
54A2 CJK UNIFIED IDEOGRAPH-#54A2, IRGKangXi=0186.020, RSKangXi=30.6, Def{sound; drumming}
54A3 CJK UNIFIED IDEOGRAPH-#54A3, IRGKangXi=0186.030, RSKangXi=30.6, Def{the sound of large door closing}
54A4 CJK UNIFIED IDEOGRAPH-#54A4, IRGKangXi=0186.060, RSKangXi=30.6, Def{scold, bellow, shout at, roar}
54A5 CJK UNIFIED IDEOGRAPH-#54A5, IRGKangXi=0186.070, RSKangXi=30.6, Def{sound of a cat; bite; laugh}
54A6 CJK UNIFIED IDEOGRAPH-#54A6, IRGKangXi=0186.080, RSKangXi=30.6, Def{exclamation of surprise}
54A7 CJK UNIFIED IDEOGRAPH-#54A7, IRGKangXi=0186.090, RSKangXi=30.6, Def{stretch mouth, grimace, grin}
54A8 CJK UNIFIED IDEOGRAPH-#54A8, IRGKangXi=0186.110, RSKangXi=30.6, Def{inquire, consult, discuss; plan}
54A9 CJK UNIFIED IDEOGRAPH-#54A9, IRGKangXi=0186.130, RSKangXi=30.6, Def{the bleating of sheep; (Cant.) an interrogative particle}
54AA CJK UNIFIED IDEOGRAPH-#54AA, IRGKangXi=0186.140, RSKangXi=30.6, Def{sound of cat, cat's meow; meter; (Cant.) don't!}
54AB CJK UNIFIED IDEOGRAPH-#54AB, IRGKangXi=0186.150, RSKangXi=30.6, Def{foot measure of Zhou dynasty}
54AC CJK UNIFIED IDEOGRAPH-#54AC, IRGKangXi=0186.160, RSKangXi=30.6, Def{bite, gnaw}
54AD CJK UNIFIED IDEOGRAPH-#54AD, IRGKangXi=0186.170, RSKangXi=30.6, Def{(Cant.) to guard (from Engl. 'guard'); a card (from Engl. 'card'); young and pretty (from Engl. 'kid')}
54AE CJK UNIFIED IDEOGRAPH-#54AE, IRGKangXi=0186.180, RSKangXi=30.6, Def{a beak; to peck}
54AF CJK UNIFIED IDEOGRAPH-#54AF, IRGKangXi=0187.050, RSKangXi=30.6, Def{final particle}
54B0 CJK UNIFIED IDEOGRAPH-#54B0, IRGKangXi=0187.060, RSKangXi=30.6
54B1 CJK UNIFIED IDEOGRAPH-#54B1, IRGKangXi=0187.070, RSKangXi=30.6, Def{we, us}
54B2 CJK UNIFIED IDEOGRAPH-#54B2, IRGKangXi=0187.090, RSKangXi=30.6, Def{smile, laugh, giggle; snicker}
54B3 CJK UNIFIED IDEOGRAPH-#54B3, IRGKangXi=0187.100, RSKangXi=30.6, Def{cough}
54B4 CJK UNIFIED IDEOGRAPH-#54B4, IRGKangXi=0187.120, RSKangXi=30.6
54B5 CJK UNIFIED IDEOGRAPH-#54B5, IRGKangXi=0187.130, RSKangXi=30.6, Def{to revile}
54B6 CJK UNIFIED IDEOGRAPH-#54B6, IRGKangXi=0187.140, RSKangXi=30.6
54B7 CJK UNIFIED IDEOGRAPH-#54B7, IRGKangXi=0187.150, RSKangXi=30.6, Def{howl, cry loudly}
54B8 CJK UNIFIED IDEOGRAPH-#54B8, IRGKangXi=0187.190, RSKangXi=30.6, Def{together; all, completely; united}
54B9 CJK UNIFIED IDEOGRAPH-#54B9, IRGKangXi=0187.200, RSKangXi=30.6, Def{(Cant.) sound of an automobile horn}
54BA CJK UNIFIED IDEOGRAPH-#54BA, IRGKangXi=0187.250, RSKangXi=30.6, Def{majestic}
54BB CJK UNIFIED IDEOGRAPH-#54BB, IRGKangXi=0188.010, RSKangXi=30.6, Def{shout}
54BC CJK UNIFIED IDEOGRAPH-#54BC, IRGKangXi=0188.040, RSKangXi=30.6, Def{chat, jaw, gossip, talk; mouth}
54BD CJK UNIFIED IDEOGRAPH-#54BD, IRGKangXi=0188.080, RSKangXi=30.6, Def{throat; pharynx}
54BE CJK UNIFIED IDEOGRAPH-#54BE, IRGKangXi=0188.090, RSKangXi=30.6, Def{a noise; a sound}
54BF CJK UNIFIED IDEOGRAPH-#54BF, IRGKangXi=0188.100, RSKangXi=30.6, Def{descriptive of creaking; laugh}
54C0 CJK UNIFIED IDEOGRAPH-#54C0, IRGKangXi=0188.110, RSKangXi=30.6, Def{sad, mournful, pitiful; pity}
54C1 CJK UNIFIED IDEOGRAPH-#54C1, IRGKangXi=0188.120, RSKangXi=30.6, Def{article, product, commodity}
54C2 CJK UNIFIED IDEOGRAPH-#54C2, IRGKangXi=0188.140, RSKangXi=30.6, Def{smile, laugh at, sneer at; (Cant.) a final particle indicating doing something to the full extent possible}
54C3 CJK UNIFIED IDEOGRAPH-#54C3, IRGKangXi=0188.170, RSKangXi=30.6
54C4 CJK UNIFIED IDEOGRAPH-#54C4, IRGKangXi=0188.200, RSKangXi=30.6, Def{coax; beguile, cheat, deceive}
54C5 CJK UNIFIED IDEOGRAPH-#54C5, IRGKangXi=0189.010, RSKangXi=30.6
54C6 CJK UNIFIED IDEOGRAPH-#54C6, IRGKangXi=0189.020, RSKangXi=30.6, Def{tremble, shiver, shudder, quiver}
54C7 CJK UNIFIED IDEOGRAPH-#54C7, IRGKangXi=0189.050, RSKangXi=30.6, Def{vomit; cry of an infant}
54C8 CJK UNIFIED IDEOGRAPH-#54C8, IRGKangXi=0189.060, RSKangXi=30.6, Def{sound of laughter}
54C9 CJK UNIFIED IDEOGRAPH-#54C9, IRGKangXi=0189.080, RSKangXi=30.6, Def{final exclamatory particle}
54CA CJK UNIFIED IDEOGRAPH-#54CA, IRGKangXi=0189.100, RSKangXi=30.6
54CB CJK UNIFIED IDEOGRAPH-#54CB, IRGKangXi=0189.271, RSKangXi=30.6, Def{(Cant.) plural; adverb}
54CC CJK UNIFIED IDEOGRAPH-#54CC, IRGKangXi=0189.271, RSKangXi=30.6, Def{used in translation}
54CD CJK UNIFIED IDEOGRAPH-#54CD, IRGKangXi=0189.271, RSKangXi=30.6, Def{make sound, make noise; sound}
54CE CJK UNIFIED IDEOGRAPH-#54CE, IRGKangXi=0189.271, RSKangXi=30.6, Def{interjection of surprise}
54CF CJK UNIFIED IDEOGRAPH-#54CF, IRGKangXi=0189.271, RSKangXi=30.6
54D0 CJK UNIFIED IDEOGRAPH-#54D0, IRGKangXi=0189.271, RSKangXi=30.6, Def{syllable}
54D1 CJK UNIFIED IDEOGRAPH-#54D1, IRGKangXi=0189.271, RSKangXi=30.6, Def{dumb, mute; become hoarse}
54D2 CJK UNIFIED IDEOGRAPH-#54D2, IRGKangXi=0193.051, RSKangXi=30.6, Def{a sound made to get a horse to move forward}
54D3 CJK UNIFIED IDEOGRAPH-#54D3, IRGKangXi=0189.271, RSKangXi=30.6, Def{garrulous; disturbed; restless}
54D4 CJK UNIFIED IDEOGRAPH-#54D4, IRGKangXi=0189.271, RSKangXi=30.6, Def{used in transliterations}
54D5 CJK UNIFIED IDEOGRAPH-#54D5, IRGKangXi=0189.271, RSKangXi=30.6, Def{belch; vomit}
54D6 CJK UNIFIED IDEOGRAPH-#54D6, IRGKangXi=0189.271, RSKangXi=30.6
54D7 CJK UNIFIED IDEOGRAPH-#54D7, IRGKangXi=0189.271, RSKangXi=30.6, Def{rushing sound; gush forward}
54D8 CJK UNIFIED IDEOGRAPH-#54D8, IRGKangXi=0189.271, RSKangXi=30.6
54D9 CJK UNIFIED IDEOGRAPH-#54D9, IRGKangXi=0189.271, RSKangXi=30.6, Def{swallow, gulp down; greedy}
54DA CJK UNIFIED IDEOGRAPH-#54DA, IRGKangXi=0189.271, RSKangXi=30.6, Def{chemical element; (Cant.) backing, support of someone powerful; a little}
54DB CJK UNIFIED IDEOGRAPH-#54DB, IRGKangXi=0189.271, RSKangXi=30.6
54DC CJK UNIFIED IDEOGRAPH-#54DC, IRGKangXi=0189.271, RSKangXi=30.6, Def{sip}
54DD CJK UNIFIED IDEOGRAPH-#54DD, IRGKangXi=0189.271, RSKangXi=30.6, Def{whisper}
54DE CJK UNIFIED IDEOGRAPH-#54DE, IRGKangXi=0189.271, RSKangXi=30.6, Def{moo}
54DF CJK UNIFIED IDEOGRAPH-#54DF, IRGKangXi=0189.271, RSKangXi=30.6, Def{ah, final particle}
54E0 CJK UNIFIED IDEOGRAPH-#54E0, IRGKangXi=0189.280, RSKangXi=30.7
54E1 CJK UNIFIED IDEOGRAPH-#54E1, IRGKangXi=0189.310, RSKangXi=30.7, Def{member; personnel, staff member}
54E2 CJK UNIFIED IDEOGRAPH-#54E2, IRGKangXi=0190.020, RSKangXi=30.7, Def{syllable}
54E3 CJK UNIFIED IDEOGRAPH-#54E3, IRGKangXi=0190.050, RSKangXi=30.7, Def{(Cant.) sick, unwell}
54E4 CJK UNIFIED IDEOGRAPH-#54E4, IRGKangXi=0190.070, RSKangXi=30.7, Def{jargon}
54E5 CJK UNIFIED IDEOGRAPH-#54E5, IRGKangXi=0190.080, RSKangXi=30.7, Def{elder brother}
54E6 CJK UNIFIED IDEOGRAPH-#54E6, IRGKangXi=0190.090, RSKangXi=30.7, Def{oh? really? is that so?}
54E7 CJK UNIFIED IDEOGRAPH-#54E7, IRGKangXi=0190.120, RSKangXi=30.7, Def{sound of ripping or giggling}
54E8 CJK UNIFIED IDEOGRAPH-#54E8, IRGKangXi=0190.130, RSKangXi=30.7, Def{whistle, blow whistle; chirp}
54E9 CJK UNIFIED IDEOGRAPH-#54E9, IRGKangXi=0190.160, RSKangXi=30.7, Def{mile}
54EA CJK UNIFIED IDEOGRAPH-#54EA, IRGKangXi=0190.180, RSKangXi=30.7, Def{which? where? how?}
54EB CJK UNIFIED IDEOGRAPH-#54EB, IRGKangXi=0190.200, RSKangXi=30.7, Def{to cajole}
54EC CJK UNIFIED IDEOGRAPH-#54EC, IRGKangXi=0190.240, RSKangXi=30.7
54ED CJK UNIFIED IDEOGRAPH-#54ED, IRGKangXi=0190.250, RSKangXi=30.7, Def{weep, cry, wail}
54EE CJK UNIFIED IDEOGRAPH-#54EE, IRGKangXi=0190.260, RSKangXi=30.7, Def{cough; pant; roar}
54EF CJK UNIFIED IDEOGRAPH-#54EF, IRGKangXi=0190.280, RSKangXi=30.7
54F0 CJK UNIFIED IDEOGRAPH-#54F0, IRGKangXi=0190.290, RSKangXi=30.7, Def{incoherent chatter}
54F1 CJK UNIFIED IDEOGRAPH-#54F1, IRGKangXi=0190.310, RSKangXi=30.7
54F2 CJK UNIFIED IDEOGRAPH-#54F2, IRGKangXi=0191.010, RSKangXi=30.7, Def{wise, sagacious; wise man, sage}
54F3 CJK UNIFIED IDEOGRAPH-#54F3, IRGKangXi=0191.030, RSKangXi=30.7
54F4 CJK UNIFIED IDEOGRAPH-#54F4, IRGKangXi=0191.050, RSKangXi=30.7, Def{crying of infants}
54F5 CJK UNIFIED IDEOGRAPH-#54F5, IRGKangXi=0191.060, RSKangXi=30.7, Def{the cry of a bird}
54F6 CJK UNIFIED IDEOGRAPH-#54F6, IRGKangXi=0191.070, RSKangXi=30.7, Def{bleat}
54F7 CJK UNIFIED IDEOGRAPH-#54F7, IRGKangXi=0191.080, RSKangXi=30.7
54F8 CJK UNIFIED IDEOGRAPH-#54F8, IRGKangXi=0191.090, RSKangXi=30.7
54F9 CJK UNIFIED IDEOGRAPH-#54F9, IRGKangXi=0191.100, RSKangXi=30.7
54FA CJK UNIFIED IDEOGRAPH-#54FA, IRGKangXi=0191.110, RSKangXi=30.7, Def{chew food; feed}
54FB CJK UNIFIED IDEOGRAPH-#54FB, IRGKangXi=0191.130, RSKangXi=30.7
54FC CJK UNIFIED IDEOGRAPH-#54FC, IRGKangXi=0191.140, RSKangXi=30.7, Def{hum; sing softly; groan, moan; (Cant.) an interjecting indicating disapproval}
54FD CJK UNIFIED IDEOGRAPH-#54FD, IRGKangXi=0191.150, RSKangXi=30.7, Def{choke (with grief)}
54FE CJK UNIFIED IDEOGRAPH-#54FE, IRGKangXi=0191.190, RSKangXi=30.7
54FF CJK UNIFIED IDEOGRAPH-#54FF, IRGKangXi=0191.200, RSKangXi=30.7, Def{excellent; to commend to be able to}
5500 CJK UNIFIED IDEOGRAPH-#5500, IRGKangXi=0191.230, RSKangXi=30.7
5501 CJK UNIFIED IDEOGRAPH-#5501, IRGKangXi=0191.240, RSKangXi=30.7, Def{express condolence}
5502 CJK UNIFIED IDEOGRAPH-#5502, IRGKangXi=0191.270, RSKangXi=30.7, Def{(Cant.) phonetic; in a bad mood}
5503 CJK UNIFIED IDEOGRAPH-#5503, IRGKangXi=0191.280, RSKangXi=30.7
5504 CJK UNIFIED IDEOGRAPH-#5504, IRGKangXi=0191.290, RSKangXi=30.7, Def{final particle of assertion pathaka}
5505 CJK UNIFIED IDEOGRAPH-#5505, IRGKangXi=0191.300, RSKangXi=30.7, Def{a sound; to put in the mouth; (Cant.) to grunt, grumble}
5506 CJK UNIFIED IDEOGRAPH-#5506, IRGKangXi=0191.310, RSKangXi=30.7, Def{make mischief, incite, instigate}
5507 CJK UNIFIED IDEOGRAPH-#5507, IRGKangXi=0191.320, RSKangXi=30.7, Def{lips}
5508 CJK UNIFIED IDEOGRAPH-#5508, IRGKangXi=0192.030, RSKangXi=30.7, Def{to sob}
5509 CJK UNIFIED IDEOGRAPH-#5509, IRGKangXi=0192.040, RSKangXi=30.7, Def{alas, exclamation of surprise or pain}
550A CJK UNIFIED IDEOGRAPH-#550A, IRGKangXi=0192.050, RSKangXi=30.7, Def{(Cant.) to hold fast, press}
550B CJK UNIFIED IDEOGRAPH-#550B, IRGKangXi=0192.060, RSKangXi=30.7
550C CJK UNIFIED IDEOGRAPH-#550C, IRGKangXi=0192.070, RSKangXi=30.7
550D CJK UNIFIED IDEOGRAPH-#550D, IRGKangXi=0192.080, RSKangXi=30.7
550E CJK UNIFIED IDEOGRAPH-#550E, IRGKangXi=0192.090, RSKangXi=30.7, Def{sound, noise; final particle}
550F CJK UNIFIED IDEOGRAPH-#550F, IRGKangXi=0192.100, RSKangXi=30.7, Def{weep or sob; grieve}
5510 CJK UNIFIED IDEOGRAPH-#5510, IRGKangXi=0192.120, RSKangXi=30.7, Def{Tang dynasty; Chinese}
5511 CJK UNIFIED IDEOGRAPH-#5511, IRGKangXi=0192.230, RSKangXi=30.7, Def{(chem.) azole}
5512 CJK UNIFIED IDEOGRAPH-#5512, IRGKangXi=0193.051, RSKangXi=30.7
5513 CJK UNIFIED IDEOGRAPH-#5513, IRGKangXi=0193.051, RSKangXi=30.7, Def{(Cant.) interjection}
5514 CJK UNIFIED IDEOGRAPH-#5514, IRGKangXi=0193.051, RSKangXi=30.7, Def{hold in mouth; bite; (Cant.) not, negation}
5515 CJK UNIFIED IDEOGRAPH-#5515, IRGKangXi=0193.051, RSKangXi=30.7
5516 CJK UNIFIED IDEOGRAPH-#5516, IRGKangXi=0193.051, RSKangXi=30.7, Def{dumb, mute; become hoarse}
5517 CJK UNIFIED IDEOGRAPH-#5517, IRGKangXi=0193.051, RSKangXi=30.7
5518 CJK UNIFIED IDEOGRAPH-#5518, IRGKangXi=0193.051, RSKangXi=30.7
5519 CJK UNIFIED IDEOGRAPH-#5519, IRGKangXi=0193.051
551A CJK UNIFIED IDEOGRAPH-#551A, IRGKangXi=0193.051, RSKangXi=30.7, Def{vomiting of animals; to use bad language}
551B CJK UNIFIED IDEOGRAPH-#551B, IRGKangXi=0193.051, RSKangXi=30.7, Def{mark}
551C CJK UNIFIED IDEOGRAPH-#551C, IRGKangXi=0193.051, RSKangXi=75.6
551D CJK UNIFIED IDEOGRAPH-#551D, IRGKangXi=0193.051, RSKangXi=30.10
551E CJK UNIFIED IDEOGRAPH-#551E, IRGKangXi=0193.051, RSKangXi=30.7, Def{(Cant.) to gasp; to breathe; to rest}
551F CJK UNIFIED IDEOGRAPH-#551F, IRGKangXi=0193.051, RSKangXi=30.7, Def{place name}
5520 CJK UNIFIED IDEOGRAPH-#5520, IRGKangXi=0193.051, RSKangXi=30.7, Def{chat, jaw, gossip, talk}
5521 CJK UNIFIED IDEOGRAPH-#5521, IRGKangXi=0193.051, RSKangXi=30.7, Def{ounce}
5522 CJK UNIFIED IDEOGRAPH-#5522, IRGKangXi=0193.051, RSKangXi=30.7, Def{flute-like musical instrument}
5523 CJK UNIFIED IDEOGRAPH-#5523, IRGKangXi=0193.051, RSKangXi=30.7, Def{chatter}
5524 CJK UNIFIED IDEOGRAPH-#5524, IRGKangXi=0193.051, RSKangXi=30.7, Def{call}
5525 CJK UNIFIED IDEOGRAPH-#5525, IRGKangXi=0193.051, RSKangXi=30.7, Def{(Cant.) a bundle; onomatopoetic; round, circular; guys (slang)}
5526 CJK UNIFIED IDEOGRAPH-#5526, IRGKangXi=0193.051, RSKangXi=30.7
5527 CJK UNIFIED IDEOGRAPH-#5527, IRGKangXi=0201.121, RSKangXi=30.7, Def{chirping of insects; pump; (Cant.) a final particle}
5528 CJK UNIFIED IDEOGRAPH-#5528, IRGKangXi=0196.261, Def{(Cant.) particle indicating past tense}
5529 CJK UNIFIED IDEOGRAPH-#5529, IRGKangXi=0193.090, RSKangXi=30.8
552A CJK UNIFIED IDEOGRAPH-#552A, IRGKangXi=0193.100, RSKangXi=30.8, Def{to recite, to intone or chant}
552B CJK UNIFIED IDEOGRAPH-#552B, IRGKangXi=0193.110, RSKangXi=30.8, Def{to hum, to intone, etc. to close, to shut}
552C CJK UNIFIED IDEOGRAPH-#552C, IRGKangXi=0193.120, RSKangXi=30.8, Def{to intimidate; to scare}
552D CJK UNIFIED IDEOGRAPH-#552D, IRGKangXi=0193.140, RSKangXi=30.8
552E CJK UNIFIED IDEOGRAPH-#552E, IRGKangXi=0193.150, RSKangXi=30.8, Def{sell}
552F CJK UNIFIED IDEOGRAPH-#552F, IRGKangXi=0193.170, RSKangXi=30.8, Def{only; yes}
5530 CJK UNIFIED IDEOGRAPH-#5530, IRGKangXi=0193.180, RSKangXi=30.8, Def{swish, rustle}
5531 CJK UNIFIED IDEOGRAPH-#5531, IRGKangXi=0193.210, RSKangXi=30.8, Def{sing, chant, call; ditty, song}
5532 CJK UNIFIED IDEOGRAPH-#5532, IRGKangXi=0193.230, RSKangXi=30.8, Def{forced laughter}
5533 CJK UNIFIED IDEOGRAPH-#5533, IRGKangXi=0193.240, RSKangXi=30.8, Def{cry of bird; cry}
5534 CJK UNIFIED IDEOGRAPH-#5534, IRGKangXi=0193.260, RSKangXi=30.8
5535 CJK UNIFIED IDEOGRAPH-#5535, IRGKangXi=0193.270, RSKangXi=30.8, Def{used in Buddhist texts to transliterate non-Chinese sounds; to eat with the hand}
5536 CJK UNIFIED IDEOGRAPH-#5536, IRGKangXi=0193.280, RSKangXi=30.8, Def{sigh, groan; loud laughter}
5537 CJK UNIFIED IDEOGRAPH-#5537, IRGKangXi=0194.010, RSKangXi=30.8, Def{final particle}
5538 CJK UNIFIED IDEOGRAPH-#5538, IRGKangXi=0194.020, RSKangXi=30.8, Def{recite, read, chant}
5539 CJK UNIFIED IDEOGRAPH-#5539, IRGKangXi=0194.030, RSKangXi=30.8, Def{to smile at}
553A CJK UNIFIED IDEOGRAPH-#553A, IRGKangXi=0194.060, RSKangXi=30.8
553B CJK UNIFIED IDEOGRAPH-#553B, IRGKangXi=0194.080, RSKangXi=30.8
553C CJK UNIFIED IDEOGRAPH-#553C, IRGKangXi=0194.090, RSKangXi=30.8, Def{speaking evil. gobbling sound made by ducks}
553D CJK UNIFIED IDEOGRAPH-#553D, IRGKangXi=0194.110, RSKangXi=30.8, Def{to twitter}
553E CJK UNIFIED IDEOGRAPH-#553E, IRGKangXi=0194.140, RSKangXi=30.8, Def{spit, spit on; saliva}
553F CJK UNIFIED IDEOGRAPH-#553F, IRGKangXi=0194.170, RSKangXi=30.8, Def{sad; (Cant.) a bit, part}
5540 CJK UNIFIED IDEOGRAPH-#5540, IRGKangXi=0194.180, RSKangXi=30.8, Def{gnaw; (Cant.) to shout, yell, scold}
5541 CJK UNIFIED IDEOGRAPH-#5541, IRGKangXi=0194.190, RSKangXi=30.8, Def{chirp, twitter, twittering}
5542 CJK UNIFIED IDEOGRAPH-#5542, IRGKangXi=0194.220, RSKangXi=30.8
5543 CJK UNIFIED IDEOGRAPH-#5543, IRGKangXi=0194.270, RSKangXi=30.8, Def{gnaw, chew, bite}
5544 CJK UNIFIED IDEOGRAPH-#5544, IRGKangXi=0194.300, RSKangXi=30.8, Def{to peck; (Cant.) to slander}
5545 CJK UNIFIED IDEOGRAPH-#5545, IRGKangXi=0194.310, RSKangXi=30.8
5546 CJK UNIFIED IDEOGRAPH-#5546, IRGKangXi=0194.320, RSKangXi=30.8, Def{commerce, business, trade}
5547 CJK UNIFIED IDEOGRAPH-#5547, IRGKangXi=0195.010, RSKangXi=30.8, Def{to stalk; the stem; the foot; the base}
5548 CJK UNIFIED IDEOGRAPH-#5548, IRGKangXi=0195.020, RSKangXi=30.8
5549 CJK UNIFIED IDEOGRAPH-#5549, IRGKangXi=0195.030, RSKangXi=30.8, Def{stupid; slow}
554A CJK UNIFIED IDEOGRAPH-#554A, IRGKangXi=0195.040, RSKangXi=30.8, Def{exclamatory particle}
554B CJK UNIFIED IDEOGRAPH-#554B, IRGKangXi=0195.050, RSKangXi=30.8, Def{(Cant.) an interjection used to berate someone}
554C CJK UNIFIED IDEOGRAPH-#554C, IRGKangXi=0195.060, RSKangXi=30.8, Def{animal disease}
554D CJK UNIFIED IDEOGRAPH-#554D, IRGKangXi=0195.080, RSKangXi=30.8, Def{creak; (Cant.) to babble, gibberish}
554E CJK UNIFIED IDEOGRAPH-#554E, IRGKangXi=0195.090, RSKangXi=30.8, Def{obstinate, disobedient, intractable}
554F CJK UNIFIED IDEOGRAPH-#554F, IRGKangXi=0195.100, RSKangXi=30.8, Def{ask (about), inquire after}
5550 CJK UNIFIED IDEOGRAPH-#5550, IRGKangXi=0195.130, RSKangXi=30.8, Def{to taste, to sip; to spit; the sound of sipping; to surprise}
5551 CJK UNIFIED IDEOGRAPH-#5551, IRGKangXi=0195.150, RSKangXi=30.8
5552 CJK UNIFIED IDEOGRAPH-#5552, IRGKangXi=0195.160, RSKangXi=30.8
5553 CJK UNIFIED IDEOGRAPH-#5553, IRGKangXi=0195.170, RSKangXi=30.8, Def{open; begin, commence; explain}
5554 CJK UNIFIED IDEOGRAPH-#5554, IRGKangXi=0196.010, RSKangXi=30.8
5555 CJK UNIFIED IDEOGRAPH-#5555, IRGKangXi=0196.020, RSKangXi=30.8, Def{wail}
5556 CJK UNIFIED IDEOGRAPH-#5556, IRGKangXi=0196.030, RSKangXi=30.8, Def{eat, feed; chew, bite; entice}
5557 CJK UNIFIED IDEOGRAPH-#5557, IRGKangXi=0196.040, RSKangXi=30.8, Def{eat, chew, bite; entice, lure}
5558 CJK UNIFIED IDEOGRAPH-#5558, IRGKangXi=0196.050, RSKangXi=30.8
5559 CJK UNIFIED IDEOGRAPH-#5559, IRGKangXi=0196.070, RSKangXi=30.9, Def{poor}
555A CJK UNIFIED IDEOGRAPH-#555A, IRGKangXi=0196.080, RSKangXi=30.8, Def{low, mean}
555B CJK UNIFIED IDEOGRAPH-#555B, IRGKangXi=0196.100, RSKangXi=30.8, Def{(Cant.) interjection (used by men)}
555C CJK UNIFIED IDEOGRAPH-#555C, IRGKangXi=0196.120, RSKangXi=30.8, Def{sip, suck up; sob, weep}
555D CJK UNIFIED IDEOGRAPH-#555D, IRGKangXi=0196.130, RSKangXi=30.8, Def{(Cant.) final partical expressing surprise}
555E CJK UNIFIED IDEOGRAPH-#555E, IRGKangXi=0196.150, RSKangXi=30.8, Def{dumb, mute; become hoarse}
555F CJK UNIFIED IDEOGRAPH-#555F, IRGKangXi=0196.261, RSKangXi=30.8, Def{open; begin}
5560 CJK UNIFIED IDEOGRAPH-#5560, IRGKangXi=0196.261, RSKangXi=30.8
5561 CJK UNIFIED IDEOGRAPH-#5561, IRGKangXi=1382.170, RSKangXi=30.8, Def{morphine; coffee}
5562 CJK UNIFIED IDEOGRAPH-#5562, IRGKangXi=0196.261, RSKangXi=30.8, Def{ounce}
5563 CJK UNIFIED IDEOGRAPH-#5563, IRGKangXi=0196.261, RSKangXi=30.8, Def{hold in mouth; harbor, cherish}
5564 CJK UNIFIED IDEOGRAPH-#5564, IRGKangXi=0196.261, RSKangXi=30.8, Def{beer}
5565 CJK UNIFIED IDEOGRAPH-#5565, IRGKangXi=0196.261, RSKangXi=30.8, Def{what?}
5566 CJK UNIFIED IDEOGRAPH-#5566, IRGKangXi=0196.261, RSKangXi=30.8, Def{final particle of assertion}
5567 CJK UNIFIED IDEOGRAPH-#5567, IRGKangXi=0196.261, RSKangXi=30.8, Def{interjection of approval or admiration}
5568 CJK UNIFIED IDEOGRAPH-#5568, IRGKangXi=1381.260, RSKangXi=30.8
5569 CJK UNIFIED IDEOGRAPH-#5569, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) particle implying probability}
556A CJK UNIFIED IDEOGRAPH-#556A, IRGKangXi=0196.261, RSKangXi=30.8, Def{syllable}
556B CJK UNIFIED IDEOGRAPH-#556B, IRGKangXi=0201.121, Def{(Cant.) interjection of warning; phonetic; penis}
556C CJK UNIFIED IDEOGRAPH-#556C, IRGKangXi=0196.261, RSKangXi=24.9, Def{miserly, thrifty; stingy}
556D CJK UNIFIED IDEOGRAPH-#556D, IRGKangXi=0196.261, RSKangXi=30.8, Def{sing, chirp, warble, twitter}
556E CJK UNIFIED IDEOGRAPH-#556E, IRGKangXi=0196.261, RSKangXi=30.8, Def{bite, gnaw}
556F CJK UNIFIED IDEOGRAPH-#556F, IRGKangXi=0196.261, RSKangXi=30.11
5570 CJK UNIFIED IDEOGRAPH-#5570, IRGKangXi=0196.261, RSKangXi=122.3, Def{phonetic}
5571 CJK UNIFIED IDEOGRAPH-#5571, IRGKangXi=0196.261, Def{(Cant.) correct, right}
5572 CJK UNIFIED IDEOGRAPH-#5572, IRGKangXi=0196.261, Def{(Cant.) a few}
5573 CJK UNIFIED IDEOGRAPH-#5573, IRGKangXi=0196.261, RSKangXi=30.8
5574 CJK UNIFIED IDEOGRAPH-#5574, IRGKangXi=0196.261, RSKangXi=30.8, Def{pant; many}
5575 CJK UNIFIED IDEOGRAPH-#5575, IRGKangXi=0196.261, RSKangXi=30.8, Def{phonetic}
5576 CJK UNIFIED IDEOGRAPH-#5576, IRGKangXi=0196.261, RSKangXi=30.8, Def{phonetic used in pyridine and pyrimidine}
5577 CJK UNIFIED IDEOGRAPH-#5577, IRGKangXi=0204.111, RSKangXi=30.8, Def{a clanging or rattling sound}
5578 CJK UNIFIED IDEOGRAPH-#5578, IRGKangXi=0196.261, RSKangXi=30.8, Def{roar, howl, scream; whistle}
5579 CJK UNIFIED IDEOGRAPH-#5579, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) stupid, idiotic; to kill, slaughter; to roll or crumple into a ball; phonetic}
557A CJK UNIFIED IDEOGRAPH-#557A, IRGKangXi=0196.270, RSKangXi=30.9
557B CJK UNIFIED IDEOGRAPH-#557B, IRGKangXi=0196.290, RSKangXi=30.9, Def{only, merely; just like; stop at}
557C CJK UNIFIED IDEOGRAPH-#557C, IRGKangXi=0197.010, RSKangXi=30.9, Def{weep, whimper; howl, twitter}
557D CJK UNIFIED IDEOGRAPH-#557D, IRGKangXi=0197.040, RSKangXi=30.9, Def{(Cant.) to speak}
557E CJK UNIFIED IDEOGRAPH-#557E, IRGKangXi=0197.070, RSKangXi=30.9, Def{wailing of child; chirp}
557F CJK UNIFIED IDEOGRAPH-#557F, IRGKangXi=0197.080, RSKangXi=30.9
5580 CJK UNIFIED IDEOGRAPH-#5580, IRGKangXi=0197.100, RSKangXi=30.9, Def{vomit; used in transliterations}
5581 CJK UNIFIED IDEOGRAPH-#5581, IRGKangXi=0197.120, RSKangXi=30.9, Def{the mouth of a fish at the surface of the water, gasping for breath}
5582 CJK UNIFIED IDEOGRAPH-#5582, IRGKangXi=0197.140, RSKangXi=30.9, Def{interjection to call attention}
5583 CJK UNIFIED IDEOGRAPH-#5583, IRGKangXi=0197.170, RSKangXi=30.9, Def{keep talking, chattering; mumble}
5584 CJK UNIFIED IDEOGRAPH-#5584, IRGKangXi=0197.180, RSKangXi=30.9, Def{good, virtuous, charitable, kind}
5585 CJK UNIFIED IDEOGRAPH-#5585, IRGKangXi=0197.240, RSKangXi=30.9
5586 CJK UNIFIED IDEOGRAPH-#5586, IRGKangXi=0197.260, RSKangXi=30.9, Def{a sage; wise; sagacious}
5587 CJK UNIFIED IDEOGRAPH-#5587, IRGKangXi=0197.270, RSKangXi=30.9, Def{horn, bugle; lama; final particle}
5588 CJK UNIFIED IDEOGRAPH-#5588, IRGKangXi=0197.280, RSKangXi=30.9, Def{music; melody}
5589 CJK UNIFIED IDEOGRAPH-#5589, IRGKangXi=0197.310, RSKangXi=30.9, Def{throat, gullet, larynx; guttural}
558A CJK UNIFIED IDEOGRAPH-#558A, IRGKangXi=0197.330, RSKangXi=30.9, Def{shout, call out, yell; howl; cry}
558B CJK UNIFIED IDEOGRAPH-#558B, IRGKangXi=0198.010, RSKangXi=30.9, Def{nag; chatter, babble, twitter}
558C CJK UNIFIED IDEOGRAPH-#558C, IRGKangXi=0198.020, RSKangXi=30.9, Def{syllable}
558D CJK UNIFIED IDEOGRAPH-#558D, IRGKangXi=0198.040, RSKangXi=30.10
558E CJK UNIFIED IDEOGRAPH-#558E, IRGKangXi=0198.090, RSKangXi=30.9, Def{a wry mouth; (Cant.) a final particle expressing contradiction, quotation, etc.}
558F CJK UNIFIED IDEOGRAPH-#558F, IRGKangXi=0198.100, RSKangXi=30.9, Def{respectful reply of assent to superiors}
5590 CJK UNIFIED IDEOGRAPH-#5590, IRGKangXi=0198.140, RSKangXi=30.9, Def{(Cant.) to move, touch, hit}
5591 CJK UNIFIED IDEOGRAPH-#5591, IRGKangXi=0198.180, RSKangXi=30.9, Def{to be dumb; the sobbing of infants}
5592 CJK UNIFIED IDEOGRAPH-#5592, IRGKangXi=0198.200, RSKangXi=30.9, Def{a dual pronoun, I, you and me, we two}
5593 CJK UNIFIED IDEOGRAPH-#5593, IRGKangXi=0198.230, RSKangXi=30.9, Def{chirping, buzzing; (Cant.) to call out}
5594 CJK UNIFIED IDEOGRAPH-#5594, IRGKangXi=0198.240, RSKangXi=30.9, Def{descriptive of crying or of crowing}
5595 CJK UNIFIED IDEOGRAPH-#5595, IRGKangXi=0198.260, RSKangXi=30.9
5596 CJK UNIFIED IDEOGRAPH-#5596, IRGKangXi=0198.280, RSKangXi=30.9
5597 CJK UNIFIED IDEOGRAPH-#5597, IRGKangXi=0198.290, RSKangXi=30.9
5598 CJK UNIFIED IDEOGRAPH-#5598, IRGKangXi=0198.300, RSKangXi=30.9, Def{pant, gasp, breathe heavily}
5599 CJK UNIFIED IDEOGRAPH-#5599, IRGKangXi=0198.350, RSKangXi=30.9, Def{beak, bill, snout; pant}
559A CJK UNIFIED IDEOGRAPH-#559A, IRGKangXi=0199.010, RSKangXi=30.9, Def{call, summon; invite; be called}
559B CJK UNIFIED IDEOGRAPH-#559B, IRGKangXi=0199.020, RSKangXi=30.9
559C CJK UNIFIED IDEOGRAPH-#559C, IRGKangXi=0199.050, RSKangXi=30.9, Def{like, love, enjoy; joyful thing}
559D CJK UNIFIED IDEOGRAPH-#559D, IRGKangXi=0199.110, RSKangXi=30.9, Def{drink; shout, call out}
559E CJK UNIFIED IDEOGRAPH-#559E, IRGKangXi=0199.120, RSKangXi=30.9, Def{chirping of insects; pump}
559F CJK UNIFIED IDEOGRAPH-#559F, IRGKangXi=0199.140, RSKangXi=30.9, Def{heave sigh, sigh}
55A0 CJK UNIFIED IDEOGRAPH-#55A0, IRGKangXi=0199.160, RSKangXi=30.9
55A1 CJK UNIFIED IDEOGRAPH-#55A1, IRGKangXi=0199.190, RSKangXi=30.9
55A2 CJK UNIFIED IDEOGRAPH-#55A2, IRGKangXi=0199.200, RSKangXi=30.9
55A3 CJK UNIFIED IDEOGRAPH-#55A3, IRGKangXi=0199.220, RSKangXi=30.9, Def{to breathe upon}
55A4 CJK UNIFIED IDEOGRAPH-#55A4, IRGKangXi=0199.250, RSKangXi=30.9, Def{ah; harmony}
55A5 CJK UNIFIED IDEOGRAPH-#55A5, IRGKangXi=0200.010, RSKangXi=30.9, Def{(Cant.) a place}
55A6 CJK UNIFIED IDEOGRAPH-#55A6, IRGKangXi=0200.020, RSKangXi=30.9, Def{talkative}
55A7 CJK UNIFIED IDEOGRAPH-#55A7, IRGKangXi=0200.030, RSKangXi=30.9, Def{lively, noisy; clamor, talk loudly}
55A8 CJK UNIFIED IDEOGRAPH-#55A8, IRGKangXi=0200.050, RSKangXi=30.9, Def{wail, cry, yell; neigh}
55A9 CJK UNIFIED IDEOGRAPH-#55A9, IRGKangXi=0200.060, RSKangXi=30.9, Def{metaphor}
55AA CJK UNIFIED IDEOGRAPH-#55AA, IRGKangXi=0200.120, RSKangXi=30.9, Def{mourning; mourn; funeral}
55AB CJK UNIFIED IDEOGRAPH-#55AB, IRGKangXi=0200.190, RSKangXi=30.9, Def{eat; drink; suffer, endure, bear}
55AC CJK UNIFIED IDEOGRAPH-#55AC, IRGKangXi=0200.220, RSKangXi=30.9, Def{tall, lofty; proud, stately}
55AD CJK UNIFIED IDEOGRAPH-#55AD, IRGKangXi=0200.230, RSKangXi=30.9, Def{condole with; coarse}
55AE CJK UNIFIED IDEOGRAPH-#55AE, IRGKangXi=0200.250, RSKangXi=30.9, Def{single, individual, only; lone}
55AF CJK UNIFIED IDEOGRAPH-#55AF, IRGKangXi=0201.010, RSKangXi=30.9
55B0 CJK UNIFIED IDEOGRAPH-#55B0, IRGKangXi=0201.121, RSKangXi=30.9, Def{to eat, drink}
55B1 CJK UNIFIED IDEOGRAPH-#55B1, IRGKangXi=0201.121, RSKangXi=30.9, Def{gramme; syllable}
55B2 CJK UNIFIED IDEOGRAPH-#55B2, IRGKangXi=0201.121, RSKangXi=30.9, Def{ah, final particle}
55B3 CJK UNIFIED IDEOGRAPH-#55B3, IRGKangXi=0201.121, RSKangXi=30.9, Def{whispering}
55B4 CJK UNIFIED IDEOGRAPH-#55B4, IRGKangXi=0201.121, RSKangXi=30.9, Def{hello; (Cant.) phonetic}
55B5 CJK UNIFIED IDEOGRAPH-#55B5, IRGKangXi=0201.121, RSKangXi=30.9, Def{the mew of the cat}
55B6 CJK UNIFIED IDEOGRAPH-#55B6, IRGKangXi=0201.121, RSKangXi=42.9, Def{encampment, barracks; manage}
55B7 CJK UNIFIED IDEOGRAPH-#55B7, IRGKangXi=0201.121, RSKangXi=30.9, Def{spurt, blow out, puff out}
55B8 CJK UNIFIED IDEOGRAPH-#55B8, IRGKangXi=0201.121, RSKangXi=30.9, Def{place name}
55B9 CJK UNIFIED IDEOGRAPH-#55B9, IRGKangXi=0201.121, RSKangXi=30.9, Def{chemical compound}
55BA CJK UNIFIED IDEOGRAPH-#55BA, IRGKangXi=0201.121, Def{(Cant.) to be located at}
55BB CJK UNIFIED IDEOGRAPH-#55BB, IRGKangXi=0201.121, RSKangXi=30.9, Def{metaphor, analogy; example; like}
55BC CJK UNIFIED IDEOGRAPH-#55BC, IRGKangXi=0201.121, RSKangXi=30.9, Def{(Cant.) used phonetically in English loan-words (e.g., cap, keep)}
55BD CJK UNIFIED IDEOGRAPH-#55BD, IRGKangXi=0201.121, RSKangXi=30.9, Def{used in onomatopoetic expressions}
55BE CJK UNIFIED IDEOGRAPH-#55BE, IRGKangXi=0201.121, RSKangXi=30.9, Def{emperor}
55BF CJK UNIFIED IDEOGRAPH-#55BF, IRGKangXi=0201.160, RSKangXi=30.10, Def{chirping of birds}
55C0 CJK UNIFIED IDEOGRAPH-#55C0, IRGKangXi=0201.200, RSKangXi=30.10
55C1 CJK UNIFIED IDEOGRAPH-#55C1, IRGKangXi=0201.220, RSKangXi=30.10, Def{give forth sound, make noise}
55C2 CJK UNIFIED IDEOGRAPH-#55C2, IRGKangXi=0201.240, RSKangXi=30.10
55C3 CJK UNIFIED IDEOGRAPH-#55C3, IRGKangXi=0201.280, RSKangXi=30.10, Def{to flute}
55C4 CJK UNIFIED IDEOGRAPH-#55C4, IRGKangXi=0201.340, RSKangXi=30.10, Def{hoarse of voice}
55C5 CJK UNIFIED IDEOGRAPH-#55C5, IRGKangXi=0201.360, RSKangXi=30.10, Def{smell, scent, sniff; olfactive}
55C6 CJK UNIFIED IDEOGRAPH-#55C6, IRGKangXi=0202.030, RSKangXi=30.10, Def{choke by smoke; irritates nose}
55C7 CJK UNIFIED IDEOGRAPH-#55C7, IRGKangXi=0202.050, RSKangXi=30.10, Def{miserly, thrifty, stingy; stopped up, constipated}
55C8 CJK UNIFIED IDEOGRAPH-#55C8, IRGKangXi=0202.100, RSKangXi=30.10, Def{the call of a bird}
55C9 CJK UNIFIED IDEOGRAPH-#55C9, IRGKangXi=0202.130, RSKangXi=30.10, Def{bird's crop; wine pot}
55CA CJK UNIFIED IDEOGRAPH-#55CA, IRGKangXi=0202.140, RSKangXi=30.10
55CB CJK UNIFIED IDEOGRAPH-#55CB, IRGKangXi=0202.150, RSKangXi=30.10
55CC CJK UNIFIED IDEOGRAPH-#55CC, IRGKangXi=0202.190, RSKangXi=30.10, Def{the throat; to quarrel, choke}
55CD CJK UNIFIED IDEOGRAPH-#55CD, IRGKangXi=0202.200, RSKangXi=30.10
55CE CJK UNIFIED IDEOGRAPH-#55CE, IRGKangXi=0202.210, RSKangXi=30.10, Def{final interrogative particle}
55CF CJK UNIFIED IDEOGRAPH-#55CF, IRGKangXi=0202.220, RSKangXi=30.10, Def{(Cant.) imperative final particle}
55D0 CJK UNIFIED IDEOGRAPH-#55D0, IRGKangXi=0202.230, RSKangXi=30.10, Def{alas!}
55D1 CJK UNIFIED IDEOGRAPH-#55D1, IRGKangXi=0202.240, RSKangXi=30.10, Def{eat seeds; reproach; loquacious}
55D2 CJK UNIFIED IDEOGRAPH-#55D2, IRGKangXi=0202.250, RSKangXi=30.10, Def{absent-minded}
55D3 CJK UNIFIED IDEOGRAPH-#55D3, IRGKangXi=0202.260, RSKangXi=30.10, Def{voice; throat}
55D4 CJK UNIFIED IDEOGRAPH-#55D4, IRGKangXi=0202.300, RSKangXi=30.10, Def{be angry at, scold, rebuke}
55D5 CJK UNIFIED IDEOGRAPH-#55D5, IRGKangXi=0202.310, RSKangXi=30.10
55D6 CJK UNIFIED IDEOGRAPH-#55D6, IRGKangXi=0202.350, RSKangXi=30.10, Def{whizzing sound}
55D7 CJK UNIFIED IDEOGRAPH-#55D7, IRGKangXi=0202.360, RSKangXi=30.10, Def{(Cant.) quarter of an hour}
55D8 CJK UNIFIED IDEOGRAPH-#55D8, IRGKangXi=0202.370, RSKangXi=30.10
55D9 CJK UNIFIED IDEOGRAPH-#55D9, IRGKangXi=0202.390, RSKangXi=30.10, Def{boast}
55DA CJK UNIFIED IDEOGRAPH-#55DA, IRGKangXi=0203.010, RSKangXi=30.10, Def{sound of crying, sobbing}
55DB CJK UNIFIED IDEOGRAPH-#55DB, IRGKangXi=0203.050, RSKangXi=30.10, Def{pouch; hold; content}
55DC CJK UNIFIED IDEOGRAPH-#55DC, IRGKangXi=0203.060, RSKangXi=30.10, Def{be fond of, have weakness for}
55DD CJK UNIFIED IDEOGRAPH-#55DD, IRGKangXi=0203.150, RSKangXi=30.10, Def{cackling of fowls to gag, to vomit}
55DE CJK UNIFIED IDEOGRAPH-#55DE, IRGKangXi=0203.180, RSKangXi=30.10, Def{to consult about, to plan; to report in writing to an equal; a despatch}
55DF CJK UNIFIED IDEOGRAPH-#55DF, IRGKangXi=0203.210, RSKangXi=30.10, Def{sigh, alas}
55E0 CJK UNIFIED IDEOGRAPH-#55E0, IRGKangXi=0203.250, RSKangXi=30.10
55E1 CJK UNIFIED IDEOGRAPH-#55E1, IRGKangXi=0203.270, RSKangXi=30.10, Def{sound of flying bees, airplanes}
55E2 CJK UNIFIED IDEOGRAPH-#55E2, IRGKangXi=0203.280, RSKangXi=30.10
55E3 CJK UNIFIED IDEOGRAPH-#55E3, IRGKangXi=0203.300, RSKangXi=30.10, Def{to connect, inherit; descendants, heirs}
55E4 CJK UNIFIED IDEOGRAPH-#55E4, IRGKangXi=0203.330, RSKangXi=30.10, Def{laugh at, ridicule, sneer; snort}
55E5 CJK UNIFIED IDEOGRAPH-#55E5, IRGKangXi=0204.111, RSKangXi=30.10, Def{roar, call out, wail; bark, yelp}
55E6 CJK UNIFIED IDEOGRAPH-#55E6, IRGKangXi=0204.111, RSKangXi=30.10, Def{suck}
55E7 CJK UNIFIED IDEOGRAPH-#55E7, IRGKangXi=0204.111, RSKangXi=30.10
55E8 CJK UNIFIED IDEOGRAPH-#55E8, IRGKangXi=0204.111, RSKangXi=30.10, Def{an exclamation}
55E9 CJK UNIFIED IDEOGRAPH-#55E9, IRGKangXi=0204.111, RSKangXi=30.10, Def{flute-like musical instrument}
55EA CJK UNIFIED IDEOGRAPH-#55EA, IRGKangXi=0204.111, RSKangXi=30.10, Def{character used in translation}
55EB CJK UNIFIED IDEOGRAPH-#55EB, IRGKangXi=0204.111, RSKangXi=30.10, Def{move lips as when speaking; hesitation}
55EC CJK UNIFIED IDEOGRAPH-#55EC, IRGKangXi=0206.201, RSKangXi=30.10, Def{(Cant.) interrogative particle}
55ED CJK UNIFIED IDEOGRAPH-#55ED, IRGKangXi=0204.111, RSKangXi=30.10, Def{place name}
55EE CJK UNIFIED IDEOGRAPH-#55EE, IRGKangXi=0204.111, Def{(Cant.) verbal aspect marker for full extent}
55EF CJK UNIFIED IDEOGRAPH-#55EF, IRGKangXi=0204.111, RSKangXi=30.10, Def{final particle}
55F0 CJK UNIFIED IDEOGRAPH-#55F0, IRGKangXi=0204.111, Def{(Cant.) that}
55F1 CJK UNIFIED IDEOGRAPH-#55F1, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) exclamation, there! now!}
55F2 CJK UNIFIED IDEOGRAPH-#55F2, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) saliva; intensifying particle; inviting, coquettish; 嗲哋. 'daddy'}
55F3 CJK UNIFIED IDEOGRAPH-#55F3, IRGKangXi=0204.111, RSKangXi=30.10, Def{interjection; exclamation}
55F4 CJK UNIFIED IDEOGRAPH-#55F4, IRGKangXi=0204.111, RSKangXi=30.10
55F5 CJK UNIFIED IDEOGRAPH-#55F5, IRGKangXi=0206.201, RSKangXi=30.10, Def{used for sound}
55F6 CJK UNIFIED IDEOGRAPH-#55F6, IRGKangXi=0204.120, RSKangXi=30.11, Def{used in transliterations}
55F7 CJK UNIFIED IDEOGRAPH-#55F7, IRGKangXi=0204.150, RSKangXi=30.11, Def{loud clamor; sound of wailing}
55F8 CJK UNIFIED IDEOGRAPH-#55F8, IRGKangXi=0204.160, RSKangXi=30.11, Def{same as 嗷 U+55F7, noisy}
55F9 CJK UNIFIED IDEOGRAPH-#55F9, IRGKangXi=0204.210, RSKangXi=30.11, Def{chatter}
55FA CJK UNIFIED IDEOGRAPH-#55FA, IRGKangXi=0204.220, RSKangXi=30.11
55FB CJK UNIFIED IDEOGRAPH-#55FB, IRGKangXi=0204.240, RSKangXi=30.11, Def{to screen. loquacious; (Cant.) final particle used to defend oneself or protest against others}
55FC CJK UNIFIED IDEOGRAPH-#55FC, IRGKangXi=0204.250, RSKangXi=30.11
55FD CJK UNIFIED IDEOGRAPH-#55FD, IRGKangXi=0204.270, RSKangXi=30.11, Def{cough, gargle, clear throat}
55FE CJK UNIFIED IDEOGRAPH-#55FE, IRGKangXi=0204.280, RSKangXi=30.11, Def{to set a dog on; incite, instigate}
55FF CJK UNIFIED IDEOGRAPH-#55FF, IRGKangXi=0204.290, RSKangXi=30.11, Def{gobble}
5600 CJK UNIFIED IDEOGRAPH-#5600, IRGKangXi=0204.370, RSKangXi=30.11, Def{backbite}
5601 CJK UNIFIED IDEOGRAPH-#5601, IRGKangXi=0204.380, RSKangXi=30.11, Def{to be grieved; ashamed; used to imitate sounds}
5602 CJK UNIFIED IDEOGRAPH-#5602, IRGKangXi=0204.390, RSKangXi=30.11, Def{cry loudly, yell, scream}
5603 CJK UNIFIED IDEOGRAPH-#5603, IRGKangXi=0204.400, RSKangXi=30.11
5604 CJK UNIFIED IDEOGRAPH-#5604, IRGKangXi=0204.410, RSKangXi=30.11
5605 CJK UNIFIED IDEOGRAPH-#5605, IRGKangXi=0204.430, RSKangXi=30.11, Def{sound of sighing; (Cant.) possessive}
5606 CJK UNIFIED IDEOGRAPH-#5606, IRGKangXi=0205.010, RSKangXi=30.11, Def{sigh, admire}
5607 CJK UNIFIED IDEOGRAPH-#5607, IRGKangXi=0205.030, RSKangXi=30.11
5608 CJK UNIFIED IDEOGRAPH-#5608, IRGKangXi=0205.060, RSKangXi=30.11, Def{noisy}
5609 CJK UNIFIED IDEOGRAPH-#5609, IRGKangXi=0205.070, RSKangXi=30.11, Def{excellent; joyful; auspicious}
560A CJK UNIFIED IDEOGRAPH-#560A, IRGKangXi=0205.090, RSKangXi=30.11
560B CJK UNIFIED IDEOGRAPH-#560B, IRGKangXi=0205.110, RSKangXi=30.11, Def{howl, roar}
560C CJK UNIFIED IDEOGRAPH-#560C, IRGKangXi=0205.130, RSKangXi=30.11, Def{fast, speedy}
560D CJK UNIFIED IDEOGRAPH-#560D, IRGKangXi=0205.140, RSKangXi=30.11, Def{used in onomatopoetic expressions}
560E CJK UNIFIED IDEOGRAPH-#560E, IRGKangXi=0205.150, RSKangXi=30.11, Def{sound of laughter; bad, malevolent}
560F CJK UNIFIED IDEOGRAPH-#560F, IRGKangXi=0205.210, RSKangXi=30.11, Def{felicity, prosperity; large and strong}
5610 CJK UNIFIED IDEOGRAPH-#5610, IRGKangXi=0205.250, RSKangXi=30.11, Def{final exclamatory particle}
5611 CJK UNIFIED IDEOGRAPH-#5611, IRGKangXi=0205.260, RSKangXi=30.11, Def{to menace; to howl at; to bawl; (Cant.) final particle}
5612 CJK UNIFIED IDEOGRAPH-#5612, IRGKangXi=0205.270, RSKangXi=30.11, Def{sharp}
5613 CJK UNIFIED IDEOGRAPH-#5613, IRGKangXi=0206.010, RSKangXi=30.11, Def{gurgling sound, chattering}
5614 CJK UNIFIED IDEOGRAPH-#5614, IRGKangXi=0206.040, RSKangXi=30.11, Def{to vomit; annoy, enrage}
5615 CJK UNIFIED IDEOGRAPH-#5615, IRGKangXi=0206.060, RSKangXi=30.11
5616 CJK UNIFIED IDEOGRAPH-#5616, IRGKangXi=0206.080, RSKangXi=30.11, Def{interjection of approval or admiration}
5617 CJK UNIFIED IDEOGRAPH-#5617, IRGKangXi=0206.090, RSKangXi=30.11, Def{taste; experience, experiment}
5618 CJK UNIFIED IDEOGRAPH-#5618, IRGKangXi=0206.100, RSKangXi=30.11, Def{exhale; blow out; deep sigh; hiss; praise}
5619 CJK UNIFIED IDEOGRAPH-#5619, IRGKangXi=0206.140, RSKangXi=30.11
561A CJK UNIFIED IDEOGRAPH-#561A, IRGKangXi=0206.201, RSKangXi=30.11
561B CJK UNIFIED IDEOGRAPH-#561B, IRGKangXi=0206.201, RSKangXi=30.11, Def{final exclamatory particle}
561C CJK UNIFIED IDEOGRAPH-#561C, IRGKangXi=0206.201, RSKangXi=30.11, Def{mark}
561D CJK UNIFIED IDEOGRAPH-#561D, IRGKangXi=0206.201, RSKangXi=30.11
561E CJK UNIFIED IDEOGRAPH-#561E, IRGKangXi=0206.201, RSKangXi=30.11, Def{(Cant.) final particle used for polite refusal}
561F CJK UNIFIED IDEOGRAPH-#561F, IRGKangXi=0209.151, RSKangXi=30.12, Def{sound of horn tooting}
5620 CJK UNIFIED IDEOGRAPH-#5620, IRGKangXi=0209.151, RSKangXi=30.12, Def{the chirping of birds loud laughter}
5621 CJK UNIFIED IDEOGRAPH-#5621, IRGKangXi=0206.201, RSKangXi=30.11
5622 CJK UNIFIED IDEOGRAPH-#5622, IRGKangXi=0206.201, Def{(Cant.) thing}
5623 CJK UNIFIED IDEOGRAPH-#5623, IRGKangXi=0206.201, RSKangXi=30.11, Def{syllable}
5624 CJK UNIFIED IDEOGRAPH-#5624, IRGKangXi=0206.201, RSKangXi=30.11, Def{seek friends; also used in onomatopoetic expressions}
5625 CJK UNIFIED IDEOGRAPH-#5625, IRGKangXi=0206.201, RSKangXi=30.11, Def{(Cant.) to waste; all, entirely}
5626 CJK UNIFIED IDEOGRAPH-#5626, IRGKangXi=0206.201, RSKangXi=38.10
5627 CJK UNIFIED IDEOGRAPH-#5627, IRGKangXi=0206.201, RSKangXi=30.11, Def{pyrimidine}
5628 CJK UNIFIED IDEOGRAPH-#5628, IRGKangXi=0206.201, Def{roar, howl, scream; whistle}
5629 CJK UNIFIED IDEOGRAPH-#5629, IRGKangXi=0206.210, RSKangXi=30.12, Def{rushing sound; gush forward}
562A CJK UNIFIED IDEOGRAPH-#562A, IRGKangXi=0206.220, RSKangXi=30.12
562B CJK UNIFIED IDEOGRAPH-#562B, IRGKangXi=0206.230, RSKangXi=30.12
562C CJK UNIFIED IDEOGRAPH-#562C, IRGKangXi=0206.240, RSKangXi=30.12, Def{to lap; to suck}
562D CJK UNIFIED IDEOGRAPH-#562D, IRGKangXi=0206.270, RSKangXi=30.12, Def{syllable; (Cant.) to chase, drive away}
562E CJK UNIFIED IDEOGRAPH-#562E, IRGKangXi=0206.280, RSKangXi=30.12, Def{chat, jaw, gossip, talk}
562F CJK UNIFIED IDEOGRAPH-#562F, IRGKangXi=0206.320, RSKangXi=30.12, Def{roar, howl, scream; whistle}
5630 CJK UNIFIED IDEOGRAPH-#5630, IRGKangXi=0207.010, RSKangXi=30.12, Def{sigh in disapproval; take small}
5631 CJK UNIFIED IDEOGRAPH-#5631, IRGKangXi=0207.030, RSKangXi=30.12, Def{order, tell, instruct, leave word}
5632 CJK UNIFIED IDEOGRAPH-#5632, IRGKangXi=0207.080, RSKangXi=30.12, Def{ridicule, deride, scorn, jeer at}
5633 CJK UNIFIED IDEOGRAPH-#5633, IRGKangXi=0207.090, RSKangXi=30.12
5634 CJK UNIFIED IDEOGRAPH-#5634, IRGKangXi=0207.100, RSKangXi=30.12, Def{mouth, lips}
5635 CJK UNIFIED IDEOGRAPH-#5635, IRGKangXi=0207.130, RSKangXi=30.12, Def{garrulous; disturbed; restless}
5636 CJK UNIFIED IDEOGRAPH-#5636, IRGKangXi=0207.140, RSKangXi=30.12, Def{neighing of a horse; gravel voiced, husky throated; (Cant.) to hiccough}
5637 CJK UNIFIED IDEOGRAPH-#5637, IRGKangXi=0207.180, RSKangXi=30.12, Def{the roaring of wild beasts; to howl, to wail, to bawl}
5638 CJK UNIFIED IDEOGRAPH-#5638, IRGKangXi=0207.230, RSKangXi=30.12, Def{unclear; an expletive; not}
5639 CJK UNIFIED IDEOGRAPH-#5639, IRGKangXi=0207.240, RSKangXi=30.12, Def{used describe clarity of voice; resonant}
563A CJK UNIFIED IDEOGRAPH-#563A, IRGKangXi=0207.290, RSKangXi=30.12, Def{(Cant.) coincidental}
563B CJK UNIFIED IDEOGRAPH-#563B, IRGKangXi=0207.300, RSKangXi=30.12, Def{mirthful, happy; interjection}
563C CJK UNIFIED IDEOGRAPH-#563C, IRGKangXi=0207.330, RSKangXi=30.12
563D CJK UNIFIED IDEOGRAPH-#563D, IRGKangXi=0207.340, RSKangXi=30.12, Def{pant; many}
563E CJK UNIFIED IDEOGRAPH-#563E, IRGKangXi=0208.010, RSKangXi=30.12
563F CJK UNIFIED IDEOGRAPH-#563F, IRGKangXi=0208.030, RSKangXi=30.12, Def{be silent, be quiet}
5640 CJK UNIFIED IDEOGRAPH-#5640, IRGKangXi=0208.040, RSKangXi=30.12, Def{spirt out of the mouth}
5641 CJK UNIFIED IDEOGRAPH-#5641, IRGKangXi=0208.050, RSKangXi=30.12, Def{nastiness; nauseate: sickening}
5642 CJK UNIFIED IDEOGRAPH-#5642, IRGKangXi=0208.060, RSKangXi=30.12, Def{meet}
5643 CJK UNIFIED IDEOGRAPH-#5643, IRGKangXi=0208.070, RSKangXi=30.12, Def{(Cant.) emphatic final particle}
5644 CJK UNIFIED IDEOGRAPH-#5644, IRGKangXi=0208.100, RSKangXi=30.12
5645 CJK UNIFIED IDEOGRAPH-#5645, IRGKangXi=0208.140, RSKangXi=30.12, Def{to speak falsely or wrongly; ugly}
5646 CJK UNIFIED IDEOGRAPH-#5646, IRGKangXi=0208.160, RSKangXi=30.12
5647 CJK UNIFIED IDEOGRAPH-#5647, IRGKangXi=0208.170, RSKangXi=30.12
5648 CJK UNIFIED IDEOGRAPH-#5648, IRGKangXi=0208.180, RSKangXi=30.12
5649 CJK UNIFIED IDEOGRAPH-#5649, IRGKangXi=0208.190, RSKangXi=30.12, Def{bite, chew; (Cant.) like this, in this way}
564A CJK UNIFIED IDEOGRAPH-#564A, IRGKangXi=0208.200, RSKangXi=30.12
564B CJK UNIFIED IDEOGRAPH-#564B, IRGKangXi=0208.210, RSKangXi=30.12, Def{to swallow hastily; to gobble up}
564C CJK UNIFIED IDEOGRAPH-#564C, IRGKangXi=0208.240, RSKangXi=30.12, Def{scold, shout at}
564D CJK UNIFIED IDEOGRAPH-#564D, IRGKangXi=0208.270, RSKangXi=30.12, Def{chew; eat; munch}
564E CJK UNIFIED IDEOGRAPH-#564E, IRGKangXi=0208.280, RSKangXi=30.12, Def{choke; hiccup}
564F CJK UNIFIED IDEOGRAPH-#564F, IRGKangXi=0208.310, RSKangXi=30.12, Def{inhale, absorb, imbibe; compress; (Cant.) to talk, say, tell}
5650 CJK UNIFIED IDEOGRAPH-#5650, IRGKangXi=0209.010, RSKangXi=30.12, Def{receptacle, vessel; instrument}
5651 CJK UNIFIED IDEOGRAPH-#5651, IRGKangXi=0209.120, RSKangXi=30.11, Def{the roar of beasts; to howl, wail}
5652 CJK UNIFIED IDEOGRAPH-#5652, IRGKangXi=0209.140, RSKangXi=30.12, Def{(Cant.) to suck and gnaw on bones}
5653 CJK UNIFIED IDEOGRAPH-#5653, IRGKangXi=0209.151, RSKangXi=30.11, Def{exhale; blow out; deep sigh; hiss; praise, flatter; lie}
5654 CJK UNIFIED IDEOGRAPH-#5654, IRGKangXi=0209.151, RSKangXi=30.12, Def{syllable; (Cant.) for (a recipient of pity or sympathy)}
5655 CJK UNIFIED IDEOGRAPH-#5655, IRGKangXi=0209.151, RSKangXi=30.12, Def{to speak falsely or wrongly; ugly}
5656 CJK UNIFIED IDEOGRAPH-#5656, IRGKangXi=0209.151, RSKangXi=30.12
5657 CJK UNIFIED IDEOGRAPH-#5657, IRGKangXi=0209.151, RSKangXi=30.12, Def{burst}
5658 CJK UNIFIED IDEOGRAPH-#5658, IRGKangXi=0209.151, RSKangXi=30.12, Def{pouting}
5659 CJK UNIFIED IDEOGRAPH-#5659, IRGKangXi=0211.121, RSKangXi=30.12, Def{hold in mouth; bite}
565A CJK UNIFIED IDEOGRAPH-#565A, IRGKangXi=0209.151, RSKangXi=30.12, Def{fathom}
565B CJK UNIFIED IDEOGRAPH-#565B, IRGKangXi=0209.151, RSKangXi=30.12, Def{bite, gnaw}
565C CJK UNIFIED IDEOGRAPH-#565C, IRGKangXi=0209.151, RSKangXi=30.12, Def{verbose, talkative; mumbling}
565D CJK UNIFIED IDEOGRAPH-#565D, IRGKangXi=0209.151, RSKangXi=30.12, Def{hiss; a call to come}
565E CJK UNIFIED IDEOGRAPH-#565E, IRGKangXi=0209.160, RSKangXi=30.13, Def{the movement of a fish's mouth at the surface of the water}
565F CJK UNIFIED IDEOGRAPH-#565F, IRGKangXi=0209.180, RSKangXi=30.13
5660 CJK UNIFIED IDEOGRAPH-#5660, IRGKangXi=0209.190, RSKangXi=30.13, Def{sound made to get a horse to move forward}
5661 CJK UNIFIED IDEOGRAPH-#5661, IRGKangXi=0209.210, RSKangXi=30.13
5662 CJK UNIFIED IDEOGRAPH-#5662, IRGKangXi=0209.250, RSKangXi=30.13, Def{moan; interjection for pain, sad}
5663 CJK UNIFIED IDEOGRAPH-#5663, IRGKangXi=0209.290, RSKangXi=30.13, Def{a beak; to peck; to order, enjoin upon}
5664 CJK UNIFIED IDEOGRAPH-#5664, IRGKangXi=0209.300, RSKangXi=30.13, Def{close; be silent, be unable speak}
5665 CJK UNIFIED IDEOGRAPH-#5665, IRGKangXi=0209.340, RSKangXi=30.13, Def{whisper}
5666 CJK UNIFIED IDEOGRAPH-#5666, IRGKangXi=0209.380, RSKangXi=30.13, Def{belch; vomit}
5667 CJK UNIFIED IDEOGRAPH-#5667, IRGKangXi=0209.400, RSKangXi=30.13
5668 CJK UNIFIED IDEOGRAPH-#5668, IRGKangXi=0210.020, RSKangXi=30.13, Def{receptacle, vessel; instrument}
5669 CJK UNIFIED IDEOGRAPH-#5669, IRGKangXi=0210.040, RSKangXi=30.13, Def{bad, ill-omened, unlucky}
566A CJK UNIFIED IDEOGRAPH-#566A, IRGKangXi=0210.070, RSKangXi=30.13, Def{be noisy; chirp loudly}
566B CJK UNIFIED IDEOGRAPH-#566B, IRGKangXi=0210.080, RSKangXi=30.13, Def{belch; alas}
566C CJK UNIFIED IDEOGRAPH-#566C, IRGKangXi=0210.100, RSKangXi=30.13, Def{bite; gnaw; snap at}
566D CJK UNIFIED IDEOGRAPH-#566D, IRGKangXi=0210.200, RSKangXi=30.13, Def{shout}
566E CJK UNIFIED IDEOGRAPH-#566E, IRGKangXi=0210.210, RSKangXi=30.13
566F CJK UNIFIED IDEOGRAPH-#566F, IRGKangXi=0210.220, RSKangXi=30.13, Def{interjection; exclamation}
5670 CJK UNIFIED IDEOGRAPH-#5670, IRGKangXi=0210.280, RSKangXi=30.13
5671 CJK UNIFIED IDEOGRAPH-#5671, IRGKangXi=0210.310, RSKangXi=30.13, Def{laugh heartily, laugh aloud}
5672 CJK UNIFIED IDEOGRAPH-#5672, IRGKangXi=0211.040, RSKangXi=30.13, Def{swallow, gulp down; greedy}
5673 CJK UNIFIED IDEOGRAPH-#5673, IRGKangXi=0211.050, RSKangXi=30.13, Def{many}
5674 CJK UNIFIED IDEOGRAPH-#5674, IRGKangXi=0211.060, RSKangXi=30.12, Def{spurt, blow out, puff out}
5675 CJK UNIFIED IDEOGRAPH-#5675, IRGKangXi=0211.110, RSKangXi=30.13
5676 CJK UNIFIED IDEOGRAPH-#5676, IRGKangXi=0211.121, RSKangXi=30.13, Def{used in transliterations}
5677 CJK UNIFIED IDEOGRAPH-#5677, IRGKangXi=0211.121, RSKangXi=30.13
5678 CJK UNIFIED IDEOGRAPH-#5678, IRGKangXi=0211.121, RSKangXi=30.13, Def{ton (metric or English)}
5679 CJK UNIFIED IDEOGRAPH-#5679, IRGKangXi=0211.121, RSKangXi=30.13, Def{sound of bells}
567A CJK UNIFIED IDEOGRAPH-#567A, IRGKangXi=0211.121, RSKangXi=30.13, Def{story, talk}
567B CJK UNIFIED IDEOGRAPH-#567B, IRGKangXi=0211.121, RSKangXi=30.13, Def{character used in translation}
567C CJK UNIFIED IDEOGRAPH-#567C, IRGKangXi=0211.121, RSKangXi=30.13, Def{sound; (Cant.) a child's buttocks}
567D CJK UNIFIED IDEOGRAPH-#567D, IRGKangXi=0211.160, RSKangXi=30.14
567E CJK UNIFIED IDEOGRAPH-#567E, IRGKangXi=0211.200, RSKangXi=30.14
567F CJK UNIFIED IDEOGRAPH-#567F, IRGKangXi=0211.220, RSKangXi=30.14
5680 CJK UNIFIED IDEOGRAPH-#5680, IRGKangXi=0211.230, RSKangXi=30.14, Def{enjoin, instruct; charge}
5681 CJK UNIFIED IDEOGRAPH-#5681, IRGKangXi=0211.240, RSKangXi=30.14
5682 CJK UNIFIED IDEOGRAPH-#5682, IRGKangXi=0211.250, RSKangXi=30.14
5683 CJK UNIFIED IDEOGRAPH-#5683, IRGKangXi=0211.290, RSKangXi=30.14, Def{gobble}
5684 CJK UNIFIED IDEOGRAPH-#5684, IRGKangXi=0211.300, RSKangXi=30.14, Def{roar}
5685 CJK UNIFIED IDEOGRAPH-#5685, IRGKangXi=0211.330, RSKangXi=30.14, Def{talk indistinctly and falteringly}
5686 CJK UNIFIED IDEOGRAPH-#5686, IRGKangXi=0211.360, RSKangXi=30.14, Def{give forth sound, make noise}
5687 CJK UNIFIED IDEOGRAPH-#5687, IRGKangXi=0211.370, RSKangXi=30.14, Def{scare, frighten; intimidate}
5688 CJK UNIFIED IDEOGRAPH-#5688, IRGKangXi=0211.410, RSKangXi=30.14
5689 CJK UNIFIED IDEOGRAPH-#5689, IRGKangXi=0212.010, RSKangXi=30.14, Def{(Cant.) to swell}
568A CJK UNIFIED IDEOGRAPH-#568A, IRGKangXi=0212.020, RSKangXi=30.14, Def{to pant; wife; (Cant.) particle indicating doubt}
568B CJK UNIFIED IDEOGRAPH-#568B, IRGKangXi=0212.050, RSKangXi=30.14
568C CJK UNIFIED IDEOGRAPH-#568C, IRGKangXi=0212.090, RSKangXi=30.14, Def{to sip; (Cant.) aspect marker of excessive extent}
568D CJK UNIFIED IDEOGRAPH-#568D, IRGKangXi=0212.140, RSKangXi=30.14
568E CJK UNIFIED IDEOGRAPH-#568E, IRGKangXi=0212.170, RSKangXi=30.14, Def{cry loudly, yell, scream}
568F CJK UNIFIED IDEOGRAPH-#568F, IRGKangXi=0212.191, RSKangXi=30.14, Def{sneeze}
5690 CJK UNIFIED IDEOGRAPH-#5690, IRGKangXi=0212.191, RSKangXi=30.14, Def{taste}
5691 CJK UNIFIED IDEOGRAPH-#5691, IRGKangXi=0212.191, RSKangXi=30.14
5692 CJK UNIFIED IDEOGRAPH-#5692, IRGKangXi=0212.191
5693 CJK UNIFIED IDEOGRAPH-#5693, IRGKangXi=0212.191, RSKangXi=30.14, Def{a cracking or snapping sound}
5694 CJK UNIFIED IDEOGRAPH-#5694, IRGKangXi=0212.260, RSKangXi=30.15, Def{sneeze}
5695 CJK UNIFIED IDEOGRAPH-#5695, IRGKangXi=0212.270, RSKangXi=30.15, Def{verbose, talkative; mumbling}
5696 CJK UNIFIED IDEOGRAPH-#5696, IRGKangXi=0212.350, RSKangXi=30.15
5697 CJK UNIFIED IDEOGRAPH-#5697, IRGKangXi=0212.370, RSKangXi=30.15
5698 CJK UNIFIED IDEOGRAPH-#5698, IRGKangXi=0212.400, RSKangXi=30.15
5699 CJK UNIFIED IDEOGRAPH-#5699, IRGKangXi=0212.410, RSKangXi=30.15, Def{bite, gnaw}
569A CJK UNIFIED IDEOGRAPH-#569A, IRGKangXi=0212.430, RSKangXi=30.15, Def{argumentative, talkative}
569B CJK UNIFIED IDEOGRAPH-#569B, IRGKangXi=0213.020, RSKangXi=30.15
569C CJK UNIFIED IDEOGRAPH-#569C, IRGKangXi=0213.040, RSKangXi=30.15, Def{be silent; final particle}
569D CJK UNIFIED IDEOGRAPH-#569D, IRGKangXi=0213.050, RSKangXi=30.15
569E CJK UNIFIED IDEOGRAPH-#569E, IRGKangXi=0213.060, RSKangXi=30.15
569F CJK UNIFIED IDEOGRAPH-#569F, IRGKangXi=0213.110, RSKangXi=30.15, Def{(Cant.) to come, arrive}
56A0 CJK UNIFIED IDEOGRAPH-#56A0, IRGKangXi=0213.171, RSKangXi=30.15, Def{a clear sound}
56A1 CJK UNIFIED IDEOGRAPH-#56A1, IRGKangXi=0213.171, RSKangXi=30.15, Def{(Cant.) rough; interjection}
56A2 CJK UNIFIED IDEOGRAPH-#56A2, IRGKangXi=0213.171, RSKangXi=30.15, Def{bag, purse, sack; put in bag}
56A3 CJK UNIFIED IDEOGRAPH-#56A3, IRGKangXi=0213.171, RSKangXi=30.15, Def{be noisy; treat with contempt}
56A4 CJK UNIFIED IDEOGRAPH-#56A4, IRGKangXi=0213.171, RSKangXi=30.15, Def{(Cant.) slow; late}
56A5 CJK UNIFIED IDEOGRAPH-#56A5, IRGKangXi=0213.180, RSKangXi=30.16, Def{swallow, gulp}
56A6 CJK UNIFIED IDEOGRAPH-#56A6, IRGKangXi=0213.190, RSKangXi=30.16, Def{used in onomatopoetic expressions}
56A7 CJK UNIFIED IDEOGRAPH-#56A7, IRGKangXi=0213.210, RSKangXi=30.16
56A8 CJK UNIFIED IDEOGRAPH-#56A8, IRGKangXi=0213.230, RSKangXi=30.16, Def{throat}
56A9 CJK UNIFIED IDEOGRAPH-#56A9, IRGKangXi=0213.280, RSKangXi=30.16
56AA CJK UNIFIED IDEOGRAPH-#56AA, IRGKangXi=0213.310, RSKangXi=30.16
56AB CJK UNIFIED IDEOGRAPH-#56AB, IRGKangXi=0213.340, RSKangXi=30.16, Def{(Cant.) aspect marker of injury}
56AC CJK UNIFIED IDEOGRAPH-#56AC, IRGKangXi=0213.350, RSKangXi=30.16, Def{frown}
56AD CJK UNIFIED IDEOGRAPH-#56AD, IRGKangXi=0213.370, RSKangXi=30.16, Def{mound, lump; stealthily}
56AE CJK UNIFIED IDEOGRAPH-#56AE, IRGKangXi=0213.380, RSKangXi=30.16, Def{guide, direct; incline to, favor}
56AF CJK UNIFIED IDEOGRAPH-#56AF, IRGKangXi=0213.471, RSKangXi=30.16
56B0 CJK UNIFIED IDEOGRAPH-#56B0, IRGKangXi=0213.471, RSKangXi=30.16
56B1 CJK UNIFIED IDEOGRAPH-#56B1, IRGKangXi=0213.480, RSKangXi=30.17, Def{a shrill noise; alas!}
56B2 CJK UNIFIED IDEOGRAPH-#56B2, IRGKangXi=0214.030, RSKangXi=30.17, Def{read aloud, recite, chant; droop}
56B3 CJK UNIFIED IDEOGRAPH-#56B3, IRGKangXi=0214.040, RSKangXi=30.17, Def{mythical emperor; to inform quickly; an urgent communication}
56B4 CJK UNIFIED IDEOGRAPH-#56B4, IRGKangXi=0214.070, RSKangXi=30.17, Def{strict, rigorous, rigid; stern}
56B5 CJK UNIFIED IDEOGRAPH-#56B5, IRGKangXi=0214.100, RSKangXi=30.17, Def{gluttonous; greedy}
56B6 CJK UNIFIED IDEOGRAPH-#56B6, IRGKangXi=0214.110, RSKangXi=30.17, Def{seek friends; also used in names; the call of a bird}
56B7 CJK UNIFIED IDEOGRAPH-#56B7, IRGKangXi=0214.151, RSKangXi=30.17, Def{shout, brawl, make uproar, cry}
56B8 CJK UNIFIED IDEOGRAPH-#56B8, IRGKangXi=0214.151
56B9 CJK UNIFIED IDEOGRAPH-#56B9, IRGKangXi=0214.151, Def{(Cant.) a particle implying completion, certainty, or urgency}
56BA CJK UNIFIED IDEOGRAPH-#56BA, IRGKangXi=0215.051, RSKangXi=30.14
56BB CJK UNIFIED IDEOGRAPH-#56BB, IRGKangXi=0214.160, Def{be noisy; treat with contempt}
56BC CJK UNIFIED IDEOGRAPH-#56BC, IRGKangXi=0214.180, RSKangXi=30.18, Def{prattle, be glib}
56BD CJK UNIFIED IDEOGRAPH-#56BD, IRGKangXi=0214.240, RSKangXi=30.18
56BE CJK UNIFIED IDEOGRAPH-#56BE, IRGKangXi=0214.270, RSKangXi=30.18
56BF CJK UNIFIED IDEOGRAPH-#56BF, IRGKangXi=0214.280, RSKangXi=30.18, Def{(Cant.) a lump; measure word}
56C0 CJK UNIFIED IDEOGRAPH-#56C0, IRGKangXi=0214.300, RSKangXi=30.18, Def{sing, chirp, warble, twitter}
56C1 CJK UNIFIED IDEOGRAPH-#56C1, IRGKangXi=0214.310, RSKangXi=30.18, Def{move lips as when speaking; hesitation}
56C2 CJK UNIFIED IDEOGRAPH-#56C2, IRGKangXi=0214.320, RSKangXi=30.18, Def{be noisy; treat with contempt}
56C3 CJK UNIFIED IDEOGRAPH-#56C3, IRGKangXi=0215.020, RSKangXi=30.18, Def{to play (on an instrument); to accompany; to banter, jeer}
56C4 CJK UNIFIED IDEOGRAPH-#56C4, IRGKangXi=0215.221, Def{(Cant.) to come}
56C5 CJK UNIFIED IDEOGRAPH-#56C5, IRGKangXi=0215.060, RSKangXi=30.19, Def{smile}
56C6 CJK UNIFIED IDEOGRAPH-#56C6, IRGKangXi=0215.070, RSKangXi=30.19
56C7 CJK UNIFIED IDEOGRAPH-#56C7, IRGKangXi=0215.090, RSKangXi=30.19
56C8 CJK UNIFIED IDEOGRAPH-#56C8, IRGKangXi=0215.100, RSKangXi=30.19, Def{talk in one's sleep, somniloquy}
56C9 CJK UNIFIED IDEOGRAPH-#56C9, IRGKangXi=0215.120, RSKangXi=30.19, Def{exclamatory final particle, nag}
56CA CJK UNIFIED IDEOGRAPH-#56CA, IRGKangXi=0215.140, RSKangXi=30.19, Def{bag, purse, sack; put in bag}
56CB CJK UNIFIED IDEOGRAPH-#56CB, IRGKangXi=0215.160, RSKangXi=30.19
56CC CJK UNIFIED IDEOGRAPH-#56CC, IRGKangXi=0215.271, RSKangXi=30.20, Def{loquacious; nag}
56CD CJK UNIFIED IDEOGRAPH-#56CD, IRGKangXi=0216.051, RSKangXi=30.18, Def{double happiness}
56CE CJK UNIFIED IDEOGRAPH-#56CE, IRGKangXi=0215.221, RSKangXi=30.19
56CF CJK UNIFIED IDEOGRAPH-#56CF, IRGKangXi=0215.240, RSKangXi=30.20
56D0 CJK UNIFIED IDEOGRAPH-#56D0, IRGKangXi=0215.250, RSKangXi=30.20
56D1 CJK UNIFIED IDEOGRAPH-#56D1, IRGKangXi=0215.290, RSKangXi=30.21, Def{order, tell, instruct, leave word}
56D2 CJK UNIFIED IDEOGRAPH-#56D2, IRGKangXi=0215.320, RSKangXi=30.21, Def{confused talk}
56D3 CJK UNIFIED IDEOGRAPH-#56D3, IRGKangXi=0216.010, RSKangXi=30.21, Def{gnaw}
56D4 CJK UNIFIED IDEOGRAPH-#56D4, IRGKangXi=0216.071, RSKangXi=30.22, Def{muttering, indistinct speech}
56D5 CJK UNIFIED IDEOGRAPH-#56D5, IRGKangXi=0216.051, RSKangXi=30.22
56D6 CJK UNIFIED IDEOGRAPH-#56D6, IRGKangXi=0216.131, RSKangXi=30.25, Def{(Cant.) final particle for pointing out the obvious}
56D7 CJK UNIFIED IDEOGRAPH-#56D7, IRGKangXi=0216.140, RSKangXi=31.0, Def{erect, proud; upright; bald}
56D8 CJK UNIFIED IDEOGRAPH-#56D8, IRGKangXi=0216.170, RSKangXi=13.3, Def{return, turn around; a time}
56D9 CJK UNIFIED IDEOGRAPH-#56D9, IRGKangXi=0216.180, RSKangXi=31.2
56DA CJK UNIFIED IDEOGRAPH-#56DA, IRGKangXi=0216.200, RSKangXi=31.2, Def{prisoner, convict; confine}
56DB CJK UNIFIED IDEOGRAPH-#56DB, IRGKangXi=0216.220, RSKangXi=31.2, PrimaryNumeric=4, Def{four}
56DC CJK UNIFIED IDEOGRAPH-#56DC, IRGKangXi=0216.231, RSKangXi=31.2
56DD CJK UNIFIED IDEOGRAPH-#56DD, IRGKangXi=0216.240, RSKangXi=31.3, Def{baby, infant}
56DE CJK UNIFIED IDEOGRAPH-#56DE, IRGKangXi=0216.260, RSKangXi=31.3, Def{return, turn around; a time}
56DF CJK UNIFIED IDEOGRAPH-#56DF, IRGKangXi=0216.270, RSKangXi=31.3, Def{top of the head; skull}
56E0 CJK UNIFIED IDEOGRAPH-#56E0, IRGKangXi=0217.020, RSKangXi=31.3, Def{cause, reason; by; because (of)}
56E1 CJK UNIFIED IDEOGRAPH-#56E1, IRGKangXi=0217.060, RSKangXi=31.3, Def{one's daughter; to filch; to secrete}
56E2 CJK UNIFIED IDEOGRAPH-#56E2, IRGKangXi=0217.061, RSKangXi=31.3, Def{sphere, ball, circle; mass, lump}
56E3 CJK UNIFIED IDEOGRAPH-#56E3, IRGKangXi=0217.061, RSKangXi=31.3, Def{sphere, ball, circle; mass, lump}
56E4 CJK UNIFIED IDEOGRAPH-#56E4, IRGKangXi=0217.070, RSKangXi=31.4, Def{grain basket, bin for grain}
56E5 CJK UNIFIED IDEOGRAPH-#56E5, IRGKangXi=0217.080, RSKangXi=31.4, Def{hide}
56E6 CJK UNIFIED IDEOGRAPH-#56E6, IRGKangXi=0217.090, RSKangXi=31.4
56E7 CJK UNIFIED IDEOGRAPH-#56E7, IRGKangXi=0217.100, RSKangXi=31.4
56E8 CJK UNIFIED IDEOGRAPH-#56E8, IRGKangXi=0217.110, RSKangXi=31.4
56E9 CJK UNIFIED IDEOGRAPH-#56E9, IRGKangXi=0217.120, RSKangXi=31.4
56EA CJK UNIFIED IDEOGRAPH-#56EA, IRGKangXi=0217.130, RSKangXi=31.4, Def{chimney, funnel}
56EB CJK UNIFIED IDEOGRAPH-#56EB, IRGKangXi=0217.140, RSKangXi=31.4, Def{entire, whole}
56EC CJK UNIFIED IDEOGRAPH-#56EC, IRGKangXi=0217.160, RSKangXi=31.4, Def{to return to or from}
56ED CJK UNIFIED IDEOGRAPH-#56ED, IRGKangXi=0217.170, RSKangXi=31.4, Def{garden; park, orchard}
56EE CJK UNIFIED IDEOGRAPH-#56EE, IRGKangXi=0217.180, RSKangXi=31.4, Def{inveigle, decoy; cheat}
56EF CJK UNIFIED IDEOGRAPH-#56EF, IRGKangXi=0217.190, RSKangXi=31.4, Def{variant of U+56FD 国, nation, country, nation-state}
56F0 CJK UNIFIED IDEOGRAPH-#56F0, IRGKangXi=0217.200, RSKangXi=31.4, Def{to surround, beseige; to be surrounded; difficult}
56F1 CJK UNIFIED IDEOGRAPH-#56F1, IRGKangXi=0217.251, RSKangXi=31.4, Def{chimney}
56F2 CJK UNIFIED IDEOGRAPH-#56F2, IRGKangXi=0217.251, RSKangXi=31.4, Def{surround, encircle, corral; whip}
56F3 CJK UNIFIED IDEOGRAPH-#56F3, IRGKangXi=0217.251, RSKangXi=31.4, Def{diagram; chart, map, picture}
56F4 CJK UNIFIED IDEOGRAPH-#56F4, IRGKangXi=0217.251, RSKangXi=31.4, Def{surround, encircle, corral}
56F5 CJK UNIFIED IDEOGRAPH-#56F5, IRGKangXi=0217.251, RSKangXi=31.4, Def{all, complete, entire}
56F6 CJK UNIFIED IDEOGRAPH-#56F6, IRGKangXi=0217.260, RSKangXi=31.5
56F7 CJK UNIFIED IDEOGRAPH-#56F7, IRGKangXi=0217.320, RSKangXi=31.5, Def{round-shaped storage bin for grain}
56F8 CJK UNIFIED IDEOGRAPH-#56F8, IRGKangXi=0218.010, RSKangXi=31.5
56F9 CJK UNIFIED IDEOGRAPH-#56F9, IRGKangXi=0218.020, RSKangXi=31.5, Def{prison, enclosure}
56FA CJK UNIFIED IDEOGRAPH-#56FA, IRGKangXi=0218.030, RSKangXi=31.5, Def{to become solid, solidify; strength}
56FB CJK UNIFIED IDEOGRAPH-#56FB, IRGKangXi=0218.041, RSKangXi=31.5
56FC CJK UNIFIED IDEOGRAPH-#56FC, IRGKangXi=0218.041, RSKangXi=31.5
56FD CJK UNIFIED IDEOGRAPH-#56FD, IRGKangXi=0218.041, RSKangXi=31.5, Def{nation, country, nation-state}
56FE CJK UNIFIED IDEOGRAPH-#56FE, IRGKangXi=0218.041, RSKangXi=31.5, Def{diagram; chart, map, picture}
56FF CJK UNIFIED IDEOGRAPH-#56FF, IRGKangXi=0218.080, RSKangXi=31.6, Def{pen up; limit, constrain}
5700 CJK UNIFIED IDEOGRAPH-#5700, IRGKangXi=0218.110, RSKangXi=31.6, Def{nation, country, nation-state}
5701 CJK UNIFIED IDEOGRAPH-#5701, IRGKangXi=0218.180, RSKangXi=31.7
5702 CJK UNIFIED IDEOGRAPH-#5702, IRGKangXi=0218.200, RSKangXi=31.7, Def{pig-sty; privy}
5703 CJK UNIFIED IDEOGRAPH-#5703, IRGKangXi=0218.210, RSKangXi=31.7, Def{garden, cultivated field}
5704 CJK UNIFIED IDEOGRAPH-#5704, IRGKangXi=0219.010, RSKangXi=31.7, Def{prison, jail}
5705 CJK UNIFIED IDEOGRAPH-#5705, IRGKangXi=0219.020, RSKangXi=31.7, Def{correspondence; a case; a box}
5706 CJK UNIFIED IDEOGRAPH-#5706, IRGKangXi=0219.041, RSKangXi=31.7, Def{circle; round, circular; complete}
5707 CJK UNIFIED IDEOGRAPH-#5707, IRGKangXi=0219.060, RSKangXi=31.8, Def{all, complete, entire}
5708 CJK UNIFIED IDEOGRAPH-#5708, IRGKangXi=0219.070, RSKangXi=31.8, Def{to circle; a circle; corral}
5709 CJK UNIFIED IDEOGRAPH-#5709, IRGKangXi=0219.110, RSKangXi=31.8, Def{stable, corral, enclosure; frontier, border}
570A CJK UNIFIED IDEOGRAPH-#570A, IRGKangXi=0219.150, RSKangXi=31.8, Def{rest room}
570B CJK UNIFIED IDEOGRAPH-#570B, IRGKangXi=0219.160, RSKangXi=31.8, Def{nation, country, nation-state}
570C CJK UNIFIED IDEOGRAPH-#570C, IRGKangXi=0219.240, RSKangXi=31.9, Def{fence}
570D CJK UNIFIED IDEOGRAPH-#570D, IRGKangXi=0220.010, RSKangXi=31.9, Def{surround, encircle, corral}
570E CJK UNIFIED IDEOGRAPH-#570E, IRGKangXi=0220.051, Def{circle; round, circular; complete}
570F CJK UNIFIED IDEOGRAPH-#570F, IRGKangXi=0220.051, RSKangXi=31.8, Def{to circle; a circle; corral}
5710 CJK UNIFIED IDEOGRAPH-#5710, IRGKangXi=0220.051
5711 CJK UNIFIED IDEOGRAPH-#5711, IRGKangXi=0220.060, RSKangXi=31.10
5712 CJK UNIFIED IDEOGRAPH-#5712, IRGKangXi=0220.080, RSKangXi=31.10, Def{garden; park, orchard}
5713 CJK UNIFIED IDEOGRAPH-#5713, IRGKangXi=0220.090, RSKangXi=31.10, Def{circle; round, circular; complete}
5714 CJK UNIFIED IDEOGRAPH-#5714, IRGKangXi=0220.100, RSKangXi=31.10
5715 CJK UNIFIED IDEOGRAPH-#5715, IRGKangXi=0220.151, RSKangXi=31.10, Def{library}
5716 CJK UNIFIED IDEOGRAPH-#5716, IRGKangXi=0220.180, RSKangXi=31.11, Def{diagram; chart, map, picture}
5717 CJK UNIFIED IDEOGRAPH-#5717, IRGKangXi=0221.010, Def{diagram; chart, map, picture}
5718 CJK UNIFIED IDEOGRAPH-#5718, IRGKangXi=0221.020, RSKangXi=31.11, Def{sphere, ball, circle; mass, lump}
5719 CJK UNIFIED IDEOGRAPH-#5719, IRGKangXi=0221.071
571A CJK UNIFIED IDEOGRAPH-#571A, IRGKangXi=0221.080, RSKangXi=31.12
571B CJK UNIFIED IDEOGRAPH-#571B, IRGKangXi=0221.110, RSKangXi=31.13, Def{used in place names; stratus}
571C CJK UNIFIED IDEOGRAPH-#571C, IRGKangXi=0221.120, RSKangXi=31.13, Def{circle, surround; encircle}
571D CJK UNIFIED IDEOGRAPH-#571D, IRGKangXi=0221.190, RSKangXi=31.19, Def{entire}
571E CJK UNIFIED IDEOGRAPH-#571E, IRGKangXi=0221.191, RSKangXi=31.23, Def{entire, complete; round}
571F CJK UNIFIED IDEOGRAPH-#571F, IRGKangXi=0223.010, RSKangXi=32.0, Def{soil, earth; items made of earth}
5720 CJK UNIFIED IDEOGRAPH-#5720, IRGKangXi=0223.020, RSKangXi=32.1
5721 CJK UNIFIED IDEOGRAPH-#5721, IRGKangXi=0223.031, RSKangXi=32.1
5722 CJK UNIFIED IDEOGRAPH-#5722, IRGKangXi=0223.040, RSKangXi=32.2, Def{paths between fields}
5723 CJK UNIFIED IDEOGRAPH-#5723, IRGKangXi=0223.060, RSKangXi=32.2, Def{holy, sacred}
5724 CJK UNIFIED IDEOGRAPH-#5724, IRGKangXi=0223.090, RSKangXi=32.2
5725 CJK UNIFIED IDEOGRAPH-#5725, IRGKangXi=0223.091, RSKangXi=32.2, Def{mushroom}
5726 CJK UNIFIED IDEOGRAPH-#5726, IRGKangXi=0223.091, RSKangXi=32.2, Def{(kokuji) water gate, spout}
5727 CJK UNIFIED IDEOGRAPH-#5727, IRGKangXi=0223.091, RSKangXi=32.2, Def{same as 壓 U+58D3, to press; to oppress; to crush; pressure}
5728 CJK UNIFIED IDEOGRAPH-#5728, IRGKangXi=0224.181, RSKangXi=32.3, Def{be at, in, on; consist in, rest}
5729 CJK UNIFIED IDEOGRAPH-#5729, IRGKangXi=0223.110, RSKangXi=32.3, Def{dike, embankment}
572A CJK UNIFIED IDEOGRAPH-#572A, IRGKangXi=0223.120, RSKangXi=32.3
572B CJK UNIFIED IDEOGRAPH-#572B, IRGKangXi=0223.130
572C CJK UNIFIED IDEOGRAPH-#572C, IRGKangXi=0223.140, RSKangXi=32.3, Def{plaster over with layer of mud}
572D CJK UNIFIED IDEOGRAPH-#572D, IRGKangXi=0224.020, RSKangXi=32.3, Def{jade pointed at top}
572E CJK UNIFIED IDEOGRAPH-#572E, IRGKangXi=0224.040, RSKangXi=32.3, Def{destroyed, ruined; to subvert to injure}
572F CJK UNIFIED IDEOGRAPH-#572F, IRGKangXi=0224.050, RSKangXi=32.3, Def{bridge, bank}
5730 CJK UNIFIED IDEOGRAPH-#5730, IRGKangXi=0224.060, RSKangXi=32.3, Def{earth; soil, ground; region}
5731 CJK UNIFIED IDEOGRAPH-#5731, IRGKangXi=0224.120, RSKangXi=32.3
5732 CJK UNIFIED IDEOGRAPH-#5732, IRGKangXi=0224.130, RSKangXi=32.3
5733 CJK UNIFIED IDEOGRAPH-#5733, IRGKangXi=0224.150, RSKangXi=32.3, Def{furrow in field, small drainage ditch}
5734 CJK UNIFIED IDEOGRAPH-#5734, IRGKangXi=0224.160, RSKangXi=32.3
5735 CJK UNIFIED IDEOGRAPH-#5735, IRGKangXi=0224.170, RSKangXi=32.3
5736 CJK UNIFIED IDEOGRAPH-#5736, IRGKangXi=0224.180, RSKangXi=32.3
5737 CJK UNIFIED IDEOGRAPH-#5737, IRGKangXi=0224.181, RSKangXi=32.3
5738 CJK UNIFIED IDEOGRAPH-#5738, IRGKangXi=0224.181, RSKangXi=32.3
5739 CJK UNIFIED IDEOGRAPH-#5739, IRGKangXi=0224.181, RSKangXi=32.3, Def{tomb, grave: prairie; open wilderness}
573A CJK UNIFIED IDEOGRAPH-#573A, IRGKangXi=0224.181, RSKangXi=32.3, Def{open space, field, market}
573B CJK UNIFIED IDEOGRAPH-#573B, IRGKangXi=0224.190, RSKangXi=32.4, Def{border, boundary}
573C CJK UNIFIED IDEOGRAPH-#573C, IRGKangXi=0224.200, RSKangXi=32.4
573D CJK UNIFIED IDEOGRAPH-#573D, IRGKangXi=0224.210, RSKangXi=32.4
573E CJK UNIFIED IDEOGRAPH-#573E, IRGKangXi=0224.220, RSKangXi=32.4, Def{garbage, rubbish; shaking; danger}
573F CJK UNIFIED IDEOGRAPH-#573F, IRGKangXi=0224.230, RSKangXi=32.4
5740 CJK UNIFIED IDEOGRAPH-#5740, IRGKangXi=0224.240, RSKangXi=32.4, Def{site, location, land for house}
5741 CJK UNIFIED IDEOGRAPH-#5741, IRGKangXi=0224.250, RSKangXi=32.4
5742 CJK UNIFIED IDEOGRAPH-#5742, IRGKangXi=0224.260, RSKangXi=32.4, Def{hillside, inconvenient places}
5743 CJK UNIFIED IDEOGRAPH-#5743, IRGKangXi=0224.270, RSKangXi=32.4
5744 CJK UNIFIED IDEOGRAPH-#5744, IRGKangXi=0224.280, RSKangXi=32.4
5745 CJK UNIFIED IDEOGRAPH-#5745, IRGKangXi=0224.290, RSKangXi=32.4
5746 CJK UNIFIED IDEOGRAPH-#5746, IRGKangXi=0224.300, RSKangXi=32.4, Def{a grave, tomb}
5747 CJK UNIFIED IDEOGRAPH-#5747, IRGKangXi=0224.310, RSKangXi=32.4, Def{equal, even, fair; all, also}
5748 CJK UNIFIED IDEOGRAPH-#5748, IRGKangXi=0225.040, RSKangXi=32.4
5749 CJK UNIFIED IDEOGRAPH-#5749, IRGKangXi=0225.060, RSKangXi=32.4
574A CJK UNIFIED IDEOGRAPH-#574A, IRGKangXi=0225.070, RSKangXi=32.4, Def{neighborhood, urban subdivision; (J) priest's residence; (Buddhist) priest; boy}
574B CJK UNIFIED IDEOGRAPH-#574B, IRGKangXi=0225.080, RSKangXi=32.4, Def{dust, earth; a bank of earth; to dig; to bring together}
574C CJK UNIFIED IDEOGRAPH-#574C, IRGKangXi=0225.090, RSKangXi=32.4, Def{dust, earth; a bank of earth; to dig; to bring together}
574D CJK UNIFIED IDEOGRAPH-#574D, IRGKangXi=0225.100, RSKangXi=32.4, Def{collapse; landslide}
574E CJK UNIFIED IDEOGRAPH-#574E, IRGKangXi=0225.120, RSKangXi=32.4, Def{pit, hole; snare, trap; crisis}
574F CJK UNIFIED IDEOGRAPH-#574F, IRGKangXi=0225.140, RSKangXi=32.4, Def{rotten, spoilt, bad, broken down}
5750 CJK UNIFIED IDEOGRAPH-#5750, IRGKangXi=0225.150, RSKangXi=32.4, Def{sit; seat; ride, travel by}
5751 CJK UNIFIED IDEOGRAPH-#5751, IRGKangXi=0226.010, RSKangXi=32.4, Def{pit, hole; bury, trap; harry}
5752 CJK UNIFIED IDEOGRAPH-#5752, IRGKangXi=0226.020, RSKangXi=32.4, Def{to compare; to match; to equal}
5753 CJK UNIFIED IDEOGRAPH-#5753, IRGKangXi=0226.050, RSKangXi=32.4
5754 CJK UNIFIED IDEOGRAPH-#5754, IRGKangXi=0226.070, RSKangXi=32.4
5755 CJK UNIFIED IDEOGRAPH-#5755, IRGKangXi=0226.090, RSKangXi=32.4
5756 CJK UNIFIED IDEOGRAPH-#5756, IRGKangXi=0226.100, RSKangXi=32.4
5757 CJK UNIFIED IDEOGRAPH-#5757, IRGKangXi=0226.101, RSKangXi=32.4, Def{piece, lump; dollar}
5758 CJK UNIFIED IDEOGRAPH-#5758, IRGKangXi=0226.101, RSKangXi=32.4
5759 CJK UNIFIED IDEOGRAPH-#5759, IRGKangXi=0226.101, RSKangXi=32.4
575A CJK UNIFIED IDEOGRAPH-#575A, IRGKangXi=0226.101, RSKangXi=32.4, Def{hard, strong, firm; resolute}
575B CJK UNIFIED IDEOGRAPH-#575B, IRGKangXi=0226.101, RSKangXi=32.4, Def{altar; arena, examination hall}
575C CJK UNIFIED IDEOGRAPH-#575C, IRGKangXi=0226.101, RSKangXi=32.4, Def{a hole, pit}
575D CJK UNIFIED IDEOGRAPH-#575D, IRGKangXi=0226.101, RSKangXi=32.4, Def{embankment; dam}
575E CJK UNIFIED IDEOGRAPH-#575E, IRGKangXi=0226.101, RSKangXi=32.4, Def{entrenchment, bank, low wall}
575F CJK UNIFIED IDEOGRAPH-#575F, IRGKangXi=0226.101, RSKangXi=32.4, Def{grave, mound; bulge; bulging}
5760 CJK UNIFIED IDEOGRAPH-#5760, IRGKangXi=0227.271, RSKangXi=32.4, Def{fall down, drop, sink, go to ruin}
5761 CJK UNIFIED IDEOGRAPH-#5761, IRGKangXi=0226.110, RSKangXi=32.5, Def{slope, bank, hillside}
5762 CJK UNIFIED IDEOGRAPH-#5762, IRGKangXi=0226.120, RSKangXi=32.5
5763 CJK UNIFIED IDEOGRAPH-#5763, IRGKangXi=0226.130, RSKangXi=32.5
5764 CJK UNIFIED IDEOGRAPH-#5764, IRGKangXi=0226.140, RSKangXi=32.5, Def{earth; feminine, female}
5765 CJK UNIFIED IDEOGRAPH-#5765, IRGKangXi=0226.170, RSKangXi=32.5
5766 CJK UNIFIED IDEOGRAPH-#5766, IRGKangXi=0226.180, RSKangXi=32.5, Def{flat, smooth; self-possessed}
5767 CJK UNIFIED IDEOGRAPH-#5767, IRGKangXi=0226.190, RSKangXi=32.5
5768 CJK UNIFIED IDEOGRAPH-#5768, IRGKangXi=0226.200, RSKangXi=32.5, Def{a lump, heap}
5769 CJK UNIFIED IDEOGRAPH-#5769, IRGKangXi=0226.210, RSKangXi=32.5, Def{earthenware, earthenware vessel}
576A CJK UNIFIED IDEOGRAPH-#576A, IRGKangXi=0226.220, RSKangXi=32.5, Def{level ground; Japanese measure}
576B CJK UNIFIED IDEOGRAPH-#576B, IRGKangXi=0226.240, RSKangXi=32.5, Def{a stand on which to replace goblets after drinking}
576C CJK UNIFIED IDEOGRAPH-#576C, IRGKangXi=0226.250
576D CJK UNIFIED IDEOGRAPH-#576D, IRGKangXi=0226.260, RSKangXi=32.5, Def{mud, mire; to paste, to plaster}
576E CJK UNIFIED IDEOGRAPH-#576E, IRGKangXi=0226.270, RSKangXi=32.5, Def{platform; unit; term of address}
576F CJK UNIFIED IDEOGRAPH-#576F, IRGKangXi=0226.280, RSKangXi=32.5, Def{dam, embankment; weir}
5770 CJK UNIFIED IDEOGRAPH-#5770, IRGKangXi=0226.290, RSKangXi=32.5, Def{wilds}
5771 CJK UNIFIED IDEOGRAPH-#5771, IRGKangXi=0226.310, RSKangXi=32.5, Def{dust}
5772 CJK UNIFIED IDEOGRAPH-#5772, IRGKangXi=0226.320, RSKangXi=32.5
5773 CJK UNIFIED IDEOGRAPH-#5773, IRGKangXi=0226.330, RSKangXi=32.5, Def{a hollow in the ground, a cavity, depression; undulating, depressed}
5774 CJK UNIFIED IDEOGRAPH-#5774, IRGKangXi=0226.340, RSKangXi=32.5, Def{a clod of earth; land}
5775 CJK UNIFIED IDEOGRAPH-#5775, IRGKangXi=0226.350, RSKangXi=32.5, Def{earthenware, earthenware vessel}
5776 CJK UNIFIED IDEOGRAPH-#5776, IRGKangXi=0226.370, RSKangXi=32.5
5777 CJK UNIFIED IDEOGRAPH-#5777, IRGKangXi=0226.380, RSKangXi=32.5, Def{clod of earth, lump of soil}
5778 CJK UNIFIED IDEOGRAPH-#5778, IRGKangXi=0227.020, RSKangXi=32.5
5779 CJK UNIFIED IDEOGRAPH-#5779, IRGKangXi=0227.030, RSKangXi=32.5
577A CJK UNIFIED IDEOGRAPH-#577A, IRGKangXi=0227.040, RSKangXi=32.5, Def{(Cant.) classifier for soft masses}
577B CJK UNIFIED IDEOGRAPH-#577B, IRGKangXi=0227.050, RSKangXi=32.5, Def{an islet, a rock in a river; an embankment; to stop}
577C CJK UNIFIED IDEOGRAPH-#577C, IRGKangXi=0227.100, RSKangXi=32.5, Def{split, tear, open}
577D CJK UNIFIED IDEOGRAPH-#577D, IRGKangXi=0227.110, RSKangXi=32.5
577E CJK UNIFIED IDEOGRAPH-#577E, IRGKangXi=0227.120, RSKangXi=32.5
577F CJK UNIFIED IDEOGRAPH-#577F, IRGKangXi=0227.130, RSKangXi=32.5, Def{mound; used in place names}
5780 CJK UNIFIED IDEOGRAPH-#5780, IRGKangXi=0227.140, RSKangXi=32.5
5781 CJK UNIFIED IDEOGRAPH-#5781, IRGKangXi=0227.150, RSKangXi=32.5
5782 CJK UNIFIED IDEOGRAPH-#5782, IRGKangXi=0227.160, RSKangXi=32.5, Def{let down; suspend, hand; down}
5783 CJK UNIFIED IDEOGRAPH-#5783, IRGKangXi=0227.271, RSKangXi=32.5, Def{garbage, refuse, waste}
5784 CJK UNIFIED IDEOGRAPH-#5784, IRGKangXi=0227.271, RSKangXi=212.3, Def{grave, mound; ridge in field}
5785 CJK UNIFIED IDEOGRAPH-#5785, IRGKangXi=0227.271, RSKangXi=32.5, Def{mound, grave; ridge in field}
5786 CJK UNIFIED IDEOGRAPH-#5786, IRGKangXi=0227.271, RSKangXi=32.5, Def{black clods of earth; shop, hut}
5787 CJK UNIFIED IDEOGRAPH-#5787, IRGKangXi=0227.271, RSKangXi=32.5
5788 CJK UNIFIED IDEOGRAPH-#5788, IRGKangXi=0227.271, RSKangXi=32.5, Def{used in place names; Japanese -nuta; Korean -dae}
5789 CJK UNIFIED IDEOGRAPH-#5789, IRGKangXi=0227.271, RSKangXi=32.5
578A CJK UNIFIED IDEOGRAPH-#578A, IRGKangXi=0227.271, RSKangXi=32.5
578B CJK UNIFIED IDEOGRAPH-#578B, IRGKangXi=0227.280, RSKangXi=32.6, Def{pattern, model, type; law; mold}
578C CJK UNIFIED IDEOGRAPH-#578C, IRGKangXi=0227.300, RSKangXi=32.6, Def{a field; used in place names}
578D CJK UNIFIED IDEOGRAPH-#578D, IRGKangXi=0227.310, RSKangXi=32.6
578E CJK UNIFIED IDEOGRAPH-#578E, IRGKangXi=0227.320, RSKangXi=32.6
578F CJK UNIFIED IDEOGRAPH-#578F, IRGKangXi=0227.330, RSKangXi=32.6
5790 CJK UNIFIED IDEOGRAPH-#5790, IRGKangXi=0227.360, RSKangXi=32.6
5791 CJK UNIFIED IDEOGRAPH-#5791, IRGKangXi=0227.380, RSKangXi=32.6
5792 CJK UNIFIED IDEOGRAPH-#5792, IRGKangXi=0227.390, RSKangXi=32.6, Def{rampart, military wall}
5793 CJK UNIFIED IDEOGRAPH-#5793, IRGKangXi=0227.400, RSKangXi=32.6, Def{border, boundary, frontier}
5794 CJK UNIFIED IDEOGRAPH-#5794, IRGKangXi=0228.291, RSKangXi=32.6, Def{to restrain; to dam a stream and change its direction; a mound}
5795 CJK UNIFIED IDEOGRAPH-#5795, IRGKangXi=0228.010, RSKangXi=32.6, Def{used in place names}
5796 CJK UNIFIED IDEOGRAPH-#5796, IRGKangXi=0228.020, RSKangXi=32.6
5797 CJK UNIFIED IDEOGRAPH-#5797, IRGKangXi=0228.030, RSKangXi=32.6, Def{sacrifice}
5798 CJK UNIFIED IDEOGRAPH-#5798, IRGKangXi=0228.040, RSKangXi=32.6
5799 CJK UNIFIED IDEOGRAPH-#5799, IRGKangXi=0228.050, RSKangXi=32.6
579A CJK UNIFIED IDEOGRAPH-#579A, IRGKangXi=0228.070, RSKangXi=32.6, Def{mound, roundish mass}
579B CJK UNIFIED IDEOGRAPH-#579B, IRGKangXi=0228.080, RSKangXi=32.6, Def{heap, pile; pile up, heap up}
579C CJK UNIFIED IDEOGRAPH-#579C, IRGKangXi=0228.090, RSKangXi=32.6, Def{heap; buttress; battlements}
579D CJK UNIFIED IDEOGRAPH-#579D, IRGKangXi=0228.100, RSKangXi=32.6, Def{dilapidated, ruined}
579E CJK UNIFIED IDEOGRAPH-#579E, IRGKangXi=0228.110, RSKangXi=32.6, Def{small mound; place name; hillock}
579F CJK UNIFIED IDEOGRAPH-#579F, IRGKangXi=0228.130, RSKangXi=32.6
57A0 CJK UNIFIED IDEOGRAPH-#57A0, IRGKangXi=0228.140, RSKangXi=32.6, Def{boundary, bank of stream or river}
57A1 CJK UNIFIED IDEOGRAPH-#57A1, IRGKangXi=0228.180, RSKangXi=32.6, Def{plow soil; place name}
57A2 CJK UNIFIED IDEOGRAPH-#57A2, IRGKangXi=0228.190, RSKangXi=32.6, Def{dirt, filth, stains; dirty}
57A3 CJK UNIFIED IDEOGRAPH-#57A3, IRGKangXi=0228.200, RSKangXi=32.6, Def{low wall}
57A4 CJK UNIFIED IDEOGRAPH-#57A4, IRGKangXi=0228.220, RSKangXi=32.6, Def{ant-hill, small mound; hill}
57A5 CJK UNIFIED IDEOGRAPH-#57A5, IRGKangXi=0228.240, RSKangXi=32.6
57A6 CJK UNIFIED IDEOGRAPH-#57A6, IRGKangXi=0228.291, RSKangXi=32.6, Def{cultivate, reclaim, to farm land}
57A7 CJK UNIFIED IDEOGRAPH-#57A7, IRGKangXi=0228.291, RSKangXi=32.6, Def{variable unit of land measure}
57A8 CJK UNIFIED IDEOGRAPH-#57A8, IRGKangXi=0228.291, RSKangXi=32.6
57A9 CJK UNIFIED IDEOGRAPH-#57A9, IRGKangXi=0228.291, RSKangXi=32.6, Def{holy, sacred, sage; simplification of 堊 chalk; daub with chalk}
57AA CJK UNIFIED IDEOGRAPH-#57AA, IRGKangXi=0228.291, RSKangXi=32.6
57AB CJK UNIFIED IDEOGRAPH-#57AB, IRGKangXi=0228.291, RSKangXi=32.6, Def{advance money, pay for another}
57AC CJK UNIFIED IDEOGRAPH-#57AC, IRGKangXi=0228.291, RSKangXi=32.6
57AD CJK UNIFIED IDEOGRAPH-#57AD, IRGKangXi=0228.291, RSKangXi=32.6, Def{character used in place names}
57AE CJK UNIFIED IDEOGRAPH-#57AE, IRGKangXi=0228.291, RSKangXi=32.6, Def{be defeated, fail, collapse}
57AF CJK UNIFIED IDEOGRAPH-#57AF, IRGKangXi=0230.121, RSKangXi=32.6
57B0 CJK UNIFIED IDEOGRAPH-#57B0, IRGKangXi=0228.291, RSKangXi=32.6
57B1 CJK UNIFIED IDEOGRAPH-#57B1, IRGKangXi=0228.291
57B2 CJK UNIFIED IDEOGRAPH-#57B2, IRGKangXi=0228.291, RSKangXi=32.6, Def{high and dry place}
57B3 CJK UNIFIED IDEOGRAPH-#57B3, IRGKangXi=0228.291, RSKangXi=32.6
57B4 CJK UNIFIED IDEOGRAPH-#57B4, IRGKangXi=0228.291, RSKangXi=32.6, Def{small, head shaped hill, used in place names}
57B5 CJK UNIFIED IDEOGRAPH-#57B5, IRGKangXi=0228.291, RSKangXi=32.6, Def{cover with earth; a pit; a hole}
57B6 CJK UNIFIED IDEOGRAPH-#57B6, IRGKangXi=0228.310, RSKangXi=32.7
57B7 CJK UNIFIED IDEOGRAPH-#57B7, IRGKangXi=0228.320, RSKangXi=32.7
57B8 CJK UNIFIED IDEOGRAPH-#57B8, IRGKangXi=0229.010, RSKangXi=32.7, Def{a dyke, embankment}
57B9 CJK UNIFIED IDEOGRAPH-#57B9, IRGKangXi=0229.060, RSKangXi=32.7
57BA CJK UNIFIED IDEOGRAPH-#57BA, IRGKangXi=0229.080, RSKangXi=32.7
57BB CJK UNIFIED IDEOGRAPH-#57BB, IRGKangXi=0229.100, RSKangXi=32.7, Def{an embankment; a slope over which boat pass}
57BC CJK UNIFIED IDEOGRAPH-#57BC, IRGKangXi=0229.110, RSKangXi=32.7
57BD CJK UNIFIED IDEOGRAPH-#57BD, IRGKangXi=0229.120, RSKangXi=32.7, Def{(Cant.) sediment, precipitate}
57BE CJK UNIFIED IDEOGRAPH-#57BE, IRGKangXi=0229.130, RSKangXi=32.7
57BF CJK UNIFIED IDEOGRAPH-#57BF, IRGKangXi=0229.150, RSKangXi=32.7
57C0 CJK UNIFIED IDEOGRAPH-#57C0, IRGKangXi=0229.160, RSKangXi=32.7, Def{let down; suspend, hand; down}
57C1 CJK UNIFIED IDEOGRAPH-#57C1, IRGKangXi=0229.170, RSKangXi=32.7
57C2 CJK UNIFIED IDEOGRAPH-#57C2, IRGKangXi=0229.180, RSKangXi=32.7, Def{ditches for irrigation; hole}
57C3 CJK UNIFIED IDEOGRAPH-#57C3, IRGKangXi=0229.190, RSKangXi=32.7, Def{fine dust, dirt}
57C4 CJK UNIFIED IDEOGRAPH-#57C4, IRGKangXi=0229.200, RSKangXi=32.7, Def{whirling of dust in the wind}
57C5 CJK UNIFIED IDEOGRAPH-#57C5, IRGKangXi=0229.210, RSKangXi=32.7
57C6 CJK UNIFIED IDEOGRAPH-#57C6, IRGKangXi=0229.230, RSKangXi=32.7, Def{stony}
57C7 CJK UNIFIED IDEOGRAPH-#57C7, IRGKangXi=0229.240, RSKangXi=32.7, Def{name of bridge}
57C8 CJK UNIFIED IDEOGRAPH-#57C8, IRGKangXi=0229.250, RSKangXi=32.7, Def{high, steep, towering; stern}
57C9 CJK UNIFIED IDEOGRAPH-#57C9, IRGKangXi=0229.260, RSKangXi=32.7
57CA CJK UNIFIED IDEOGRAPH-#57CA, IRGKangXi=0229.270, RSKangXi=46.7
57CB CJK UNIFIED IDEOGRAPH-#57CB, IRGKangXi=0229.280, RSKangXi=32.7, Def{bury, secrete, conceal}
57CC CJK UNIFIED IDEOGRAPH-#57CC, IRGKangXi=0229.290, RSKangXi=32.7, Def{waste}
57CD CJK UNIFIED IDEOGRAPH-#57CD, IRGKangXi=0229.310, RSKangXi=32.7
57CE CJK UNIFIED IDEOGRAPH-#57CE, IRGKangXi=0229.320, RSKangXi=32.7, Def{castle; city, town; municipality}
57CF CJK UNIFIED IDEOGRAPH-#57CF, IRGKangXi=0230.010, RSKangXi=32.7, Def{a boundary, a limit}
57D0 CJK UNIFIED IDEOGRAPH-#57D0, IRGKangXi=0230.020, RSKangXi=32.7
57D1 CJK UNIFIED IDEOGRAPH-#57D1, IRGKangXi=0230.080, RSKangXi=32.7
57D2 CJK UNIFIED IDEOGRAPH-#57D2, IRGKangXi=0230.030, RSKangXi=32.7, Def{enclosure, dike, embankment}
57D3 CJK UNIFIED IDEOGRAPH-#57D3, IRGKangXi=0230.121, RSKangXi=32.6, Def{enclosure, dike, embankment}
57D4 CJK UNIFIED IDEOGRAPH-#57D4, IRGKangXi=0230.121, RSKangXi=32.7, Def{plain, arena; port, market}
57D5 CJK UNIFIED IDEOGRAPH-#57D5, IRGKangXi=0230.121, RSKangXi=32.7, Def{a large, pear-shaped earthenware jar}
57D6 CJK UNIFIED IDEOGRAPH-#57D6, IRGKangXi=0232.181, RSKangXi=32.7
57D7 CJK UNIFIED IDEOGRAPH-#57D7, IRGKangXi=0230.121, RSKangXi=32.7, Def{(same as U+5E70 埠) a wharf, dock, jetty; a trading center, port; place name (e.g., 深水埗 in Hong Kong)}
57D8 CJK UNIFIED IDEOGRAPH-#57D8, IRGKangXi=0230.121, RSKangXi=32.7, Def{roost}
57D9 CJK UNIFIED IDEOGRAPH-#57D9, IRGKangXi=0230.121, RSKangXi=32.7, Def{instrument}
57DA CJK UNIFIED IDEOGRAPH-#57DA, IRGKangXi=0230.121, RSKangXi=32.7, Def{crucible}
57DB CJK UNIFIED IDEOGRAPH-#57DB, IRGKangXi=0230.121, RSKangXi=32.7
57DC CJK UNIFIED IDEOGRAPH-#57DC, IRGKangXi=0230.130, RSKangXi=32.8, Def{open country, field; wilderness}
57DD CJK UNIFIED IDEOGRAPH-#57DD, IRGKangXi=0230.150, RSKangXi=32.8, Def{bank, dike; purtuberance from}
57DE CJK UNIFIED IDEOGRAPH-#57DE, IRGKangXi=0230.160, RSKangXi=32.8, Def{(Cant.) place}
57DF CJK UNIFIED IDEOGRAPH-#57DF, IRGKangXi=0230.170, RSKangXi=32.8, Def{district, region, boundary; land}
57E0 CJK UNIFIED IDEOGRAPH-#57E0, IRGKangXi=0230.220, RSKangXi=32.8, Def{port city}
57E1 CJK UNIFIED IDEOGRAPH-#57E1, IRGKangXi=0230.250, RSKangXi=32.8, Def{character used in place names}
57E2 CJK UNIFIED IDEOGRAPH-#57E2, IRGKangXi=0230.260, RSKangXi=32.8
57E3 CJK UNIFIED IDEOGRAPH-#57E3, IRGKangXi=0230.280, RSKangXi=32.8
57E4 CJK UNIFIED IDEOGRAPH-#57E4, IRGKangXi=0230.290, RSKangXi=32.8, Def{add, increase, attach; low fence}
57E5 CJK UNIFIED IDEOGRAPH-#57E5, IRGKangXi=0230.300, RSKangXi=32.8
57E6 CJK UNIFIED IDEOGRAPH-#57E6, IRGKangXi=0230.310, RSKangXi=32.8, Def{a bowl}
57E7 CJK UNIFIED IDEOGRAPH-#57E7, IRGKangXi=0230.320, RSKangXi=32.8, Def{dam}
57E8 CJK UNIFIED IDEOGRAPH-#57E8, IRGKangXi=0230.330, RSKangXi=32.8
57E9 CJK UNIFIED IDEOGRAPH-#57E9, IRGKangXi=0230.340, RSKangXi=32.8
57EA CJK UNIFIED IDEOGRAPH-#57EA, IRGKangXi=0230.350, RSKangXi=32.9
57EB CJK UNIFIED IDEOGRAPH-#57EB, IRGKangXi=0230.360, RSKangXi=32.8
57EC CJK UNIFIED IDEOGRAPH-#57EC, IRGKangXi=0230.390, RSKangXi=32.8
57ED CJK UNIFIED IDEOGRAPH-#57ED, IRGKangXi=0230.400, RSKangXi=32.8, Def{a dam, a jock; inclined plane on a canal, where boats can be hauled up or down}
57EE CJK UNIFIED IDEOGRAPH-#57EE, IRGKangXi=0230.410, RSKangXi=32.8
57EF CJK UNIFIED IDEOGRAPH-#57EF, IRGKangXi=0230.420, RSKangXi=32.8, Def{cover with earth; a pit; a hole}
57F0 CJK UNIFIED IDEOGRAPH-#57F0, IRGKangXi=0230.430, RSKangXi=32.8, Def{fief}
57F1 CJK UNIFIED IDEOGRAPH-#57F1, IRGKangXi=0231.020, RSKangXi=32.8
57F2 CJK UNIFIED IDEOGRAPH-#57F2, IRGKangXi=0231.030, RSKangXi=32.8, Def{(Cant.) classifier for walls}
57F3 CJK UNIFIED IDEOGRAPH-#57F3, IRGKangXi=0231.040, RSKangXi=32.8, Def{a pit, a hole, a snare, a danger; a crisis; a mortar}
57F4 CJK UNIFIED IDEOGRAPH-#57F4, IRGKangXi=0231.050, RSKangXi=32.8, Def{soil with large clay content}
57F5 CJK UNIFIED IDEOGRAPH-#57F5, IRGKangXi=0231.060, RSKangXi=32.8, Def{hardened dirt or clay; cluster}
57F6 CJK UNIFIED IDEOGRAPH-#57F6, IRGKangXi=0231.080, RSKangXi=32.8, Def{art}
57F7 CJK UNIFIED IDEOGRAPH-#57F7, IRGKangXi=0231.090, RSKangXi=32.8, Def{hold in hand; keep; carry out}
57F8 CJK UNIFIED IDEOGRAPH-#57F8, IRGKangXi=0231.100, RSKangXi=32.8, Def{a border; a limit; a dike; a frontier; a boundary}
57F9 CJK UNIFIED IDEOGRAPH-#57F9, IRGKangXi=0231.110, RSKangXi=32.8, Def{bank up with dirt; cultivate}
57FA CJK UNIFIED IDEOGRAPH-#57FA, IRGKangXi=0231.120, RSKangXi=32.8, Def{foundation, base}
57FB CJK UNIFIED IDEOGRAPH-#57FB, IRGKangXi=0231.160, RSKangXi=32.8
57FC CJK UNIFIED IDEOGRAPH-#57FC, IRGKangXi=0231.170, RSKangXi=32.8, Def{headland}
57FD CJK UNIFIED IDEOGRAPH-#57FD, IRGKangXi=0231.180, RSKangXi=32.8, Def{broom; to sweep, clear away}
57FE CJK UNIFIED IDEOGRAPH-#57FE, IRGKangXi=0231.190, RSKangXi=32.8
57FF CJK UNIFIED IDEOGRAPH-#57FF, IRGKangXi=0231.200, RSKangXi=32.8
5800 CJK UNIFIED IDEOGRAPH-#5800, IRGKangXi=0231.210, RSKangXi=32.8, Def{cave, hole}
5801 CJK UNIFIED IDEOGRAPH-#5801, IRGKangXi=0231.220, RSKangXi=32.8
5802 CJK UNIFIED IDEOGRAPH-#5802, IRGKangXi=0231.230, RSKangXi=32.8, Def{hall; government office}
5803 CJK UNIFIED IDEOGRAPH-#5803, IRGKangXi=0232.010, RSKangXi=32.8, Def{compliance; obedience; female}
5804 CJK UNIFIED IDEOGRAPH-#5804, IRGKangXi=0232.020, RSKangXi=32.8, Def{parapet}
5805 CJK UNIFIED IDEOGRAPH-#5805, IRGKangXi=0232.030, RSKangXi=32.8, Def{hard, strong, firm; resolute}
5806 CJK UNIFIED IDEOGRAPH-#5806, IRGKangXi=0232.040, RSKangXi=32.8, Def{heap, pile, crowd; pile up}
5807 CJK UNIFIED IDEOGRAPH-#5807, IRGKangXi=0232.050, RSKangXi=32.8, Def{yellow loam; clay; season; few}
5808 CJK UNIFIED IDEOGRAPH-#5808, IRGKangXi=0232.060, RSKangXi=32.8, Def{earthen jug, crock, cistern}
5809 CJK UNIFIED IDEOGRAPH-#5809, IRGKangXi=0232.070, RSKangXi=32.8, Def{ground, fertile land}
580A CJK UNIFIED IDEOGRAPH-#580A, IRGKangXi=0232.080, RSKangXi=32.8, Def{white earth; to daub with white mud}
580B CJK UNIFIED IDEOGRAPH-#580B, IRGKangXi=0232.090, RSKangXi=32.8, Def{bury}
580C CJK UNIFIED IDEOGRAPH-#580C, IRGKangXi=0232.100, RSKangXi=32.8, Def{dam, dike; used in place names}
580D CJK UNIFIED IDEOGRAPH-#580D, IRGKangXi=0232.181, RSKangXi=32.8
580E CJK UNIFIED IDEOGRAPH-#580E, IRGKangXi=0232.181, RSKangXi=32.8, Def{character used for place names}
580F CJK UNIFIED IDEOGRAPH-#580F, IRGKangXi=0232.181, RSKangXi=32.8
5810 CJK UNIFIED IDEOGRAPH-#5810, IRGKangXi=0232.181, RSKangXi=32.8
5811 CJK UNIFIED IDEOGRAPH-#5811, IRGKangXi=0232.181, RSKangXi=32.8, Def{moat, trench, pit, cavity}
5812 CJK UNIFIED IDEOGRAPH-#5812, IRGKangXi=0232.181, RSKangXi=32.8
5813 CJK UNIFIED IDEOGRAPH-#5813, IRGKangXi=0232.181, RSKangXi=32.8
5814 CJK UNIFIED IDEOGRAPH-#5814, IRGKangXi=0232.181, RSKangXi=32.8
5815 CJK UNIFIED IDEOGRAPH-#5815, IRGKangXi=0234.271, RSKangXi=32.9, Def{fall, sink, let fall; degenerate}
5816 CJK UNIFIED IDEOGRAPH-#5816, IRGKangXi=0234.271, RSKangXi=32.9, Def{small, head shaped hill, used in place names}
5817 CJK UNIFIED IDEOGRAPH-#5817, IRGKangXi=0232.190, RSKangXi=32.9
5818 CJK UNIFIED IDEOGRAPH-#5818, IRGKangXi=0232.210, RSKangXi=32.9, Def{a raised path between field which acts as a dyke}
5819 CJK UNIFIED IDEOGRAPH-#5819, IRGKangXi=0232.230, RSKangXi=32.9, Def{bury; dam, block up}
581A CJK UNIFIED IDEOGRAPH-#581A, IRGKangXi=0233.010, RSKangXi=32.9
581B CJK UNIFIED IDEOGRAPH-#581B, IRGKangXi=0233.030, RSKangXi=32.9
581C CJK UNIFIED IDEOGRAPH-#581C, IRGKangXi=0233.060, RSKangXi=32.9
581D CJK UNIFIED IDEOGRAPH-#581D, IRGKangXi=0233.080, RSKangXi=32.9, Def{crucible}
581E CJK UNIFIED IDEOGRAPH-#581E, IRGKangXi=0233.090, RSKangXi=32.9, Def{plate}
581F CJK UNIFIED IDEOGRAPH-#581F, IRGKangXi=0233.130, RSKangXi=32.9
5820 CJK UNIFIED IDEOGRAPH-#5820, IRGKangXi=0233.140, RSKangXi=32.9, Def{battlements, battlemented walls}
5821 CJK UNIFIED IDEOGRAPH-#5821, IRGKangXi=0233.150, RSKangXi=32.9, Def{fort, fortress; town, village}
5822 CJK UNIFIED IDEOGRAPH-#5822, IRGKangXi=0233.160, RSKangXi=32.9
5823 CJK UNIFIED IDEOGRAPH-#5823, IRGKangXi=0233.180, RSKangXi=32.9
5824 CJK UNIFIED IDEOGRAPH-#5824, IRGKangXi=0233.200, RSKangXi=32.9, Def{dike}
5825 CJK UNIFIED IDEOGRAPH-#5825, IRGKangXi=0233.210, RSKangXi=32.9
5826 CJK UNIFIED IDEOGRAPH-#5826, IRGKangXi=0233.220, RSKangXi=32.9, Def{stairs; a flight of steps; a degree, a class, a rank or step}
5827 CJK UNIFIED IDEOGRAPH-#5827, IRGKangXi=0233.240, RSKangXi=32.9, Def{adjoin}
5828 CJK UNIFIED IDEOGRAPH-#5828, IRGKangXi=0233.250, RSKangXi=32.9, Def{daub}
5829 CJK UNIFIED IDEOGRAPH-#5829, IRGKangXi=0233.260, RSKangXi=32.9
582A CJK UNIFIED IDEOGRAPH-#582A, IRGKangXi=0233.270, RSKangXi=32.9, Def{adequately capable of, worthy of}
582B CJK UNIFIED IDEOGRAPH-#582B, IRGKangXi=0233.280, RSKangXi=32.9
582C CJK UNIFIED IDEOGRAPH-#582C, IRGKangXi=0233.300, RSKangXi=32.9
582D CJK UNIFIED IDEOGRAPH-#582D, IRGKangXi=0233.310, RSKangXi=32.9, Def{a dry moat outside a city wall; a dry ditch}
582E CJK UNIFIED IDEOGRAPH-#582E, IRGKangXi=0233.320, RSKangXi=32.9, Def{a boundary; a border}
582F CJK UNIFIED IDEOGRAPH-#582F, IRGKangXi=0234.010, RSKangXi=32.9, Def{a legendary ancient emperor-sage}
5830 CJK UNIFIED IDEOGRAPH-#5830, IRGKangXi=0234.040, RSKangXi=32.9, Def{dam; embankment, dike, bank}
5831 CJK UNIFIED IDEOGRAPH-#5831, IRGKangXi=0234.050, RSKangXi=32.9, Def{report, tell, announce}
5832 CJK UNIFIED IDEOGRAPH-#5832, IRGKangXi=0234.060, RSKangXi=32.9, Def{hate}
5833 CJK UNIFIED IDEOGRAPH-#5833, IRGKangXi=0234.070, RSKangXi=32.9, Def{land allotment feudal noble; alta}
5834 CJK UNIFIED IDEOGRAPH-#5834, IRGKangXi=0234.080, RSKangXi=32.9, Def{open space, field, market}
5835 CJK UNIFIED IDEOGRAPH-#5835, IRGKangXi=0234.090, RSKangXi=32.9, Def{wall; stop, prevent; stop up}
5836 CJK UNIFIED IDEOGRAPH-#5836, IRGKangXi=0234.100, RSKangXi=32.9
5837 CJK UNIFIED IDEOGRAPH-#5837, IRGKangXi=0234.120, RSKangXi=32.9
5838 CJK UNIFIED IDEOGRAPH-#5838, IRGKangXi=0234.160, RSKangXi=32.9
5839 CJK UNIFIED IDEOGRAPH-#5839, IRGKangXi=0234.170, RSKangXi=32.9
583A CJK UNIFIED IDEOGRAPH-#583A, IRGKangXi=0234.190, RSKangXi=32.9, Def{person's name}
583B CJK UNIFIED IDEOGRAPH-#583B, IRGKangXi=0234.220, RSKangXi=32.9
583C CJK UNIFIED IDEOGRAPH-#583C, IRGKangXi=0234.240
583D CJK UNIFIED IDEOGRAPH-#583D, IRGKangXi=0234.270, RSKangXi=32.9, Def{mound; used in place names}
583E CJK UNIFIED IDEOGRAPH-#583E, IRGKangXi=0234.271, RSKangXi=32.9
583F CJK UNIFIED IDEOGRAPH-#583F, IRGKangXi=0234.271, RSKangXi=32.9, Def{salty}
5840 CJK UNIFIED IDEOGRAPH-#5840, IRGKangXi=0234.271, RSKangXi=32.9, Def{wall, fence}
5841 CJK UNIFIED IDEOGRAPH-#5841, IRGKangXi=0234.271, RSKangXi=102.7, Def{rampart, military wall}
5842 CJK UNIFIED IDEOGRAPH-#5842, IRGKangXi=0234.271, RSKangXi=32.8
5843 CJK UNIFIED IDEOGRAPH-#5843, IRGKangXi=0236.341
5844 CJK UNIFIED IDEOGRAPH-#5844, IRGKangXi=0234.271, RSKangXi=32.9, Def{elevated bank in field}
5845 CJK UNIFIED IDEOGRAPH-#5845, IRGKangXi=0234.271
5846 CJK UNIFIED IDEOGRAPH-#5846, IRGKangXi=0234.271, RSKangXi=32.9
5847 CJK UNIFIED IDEOGRAPH-#5847, IRGKangXi=0234.271, RSKangXi=32.9
5848 CJK UNIFIED IDEOGRAPH-#5848, IRGKangXi=0234.271, RSKangXi=32.9, Def{paint, decorate}
5849 CJK UNIFIED IDEOGRAPH-#5849, IRGKangXi=0234.280, RSKangXi=32.10
584A CJK UNIFIED IDEOGRAPH-#584A, IRGKangXi=0235.010, RSKangXi=32.10, Def{piece, lump; dollar}
584B CJK UNIFIED IDEOGRAPH-#584B, IRGKangXi=0235.020, RSKangXi=32.10, Def{grave, tomb, cemetery}
584C CJK UNIFIED IDEOGRAPH-#584C, IRGKangXi=0235.040, RSKangXi=32.10, Def{fall in ruins, collapse}
584D CJK UNIFIED IDEOGRAPH-#584D, IRGKangXi=0235.050, RSKangXi=32.10, Def{a raised path between fields, a dike}
584E CJK UNIFIED IDEOGRAPH-#584E, IRGKangXi=0235.070, RSKangXi=32.10
584F CJK UNIFIED IDEOGRAPH-#584F, IRGKangXi=0235.080, RSKangXi=32.10, Def{high and dry place}
5850 CJK UNIFIED IDEOGRAPH-#5850, IRGKangXi=0235.090, RSKangXi=32.10, Def{model in clay, sculpt; plastics}
5851 CJK UNIFIED IDEOGRAPH-#5851, IRGKangXi=0235.100, RSKangXi=32.10, Def{model in clay, sculpt; plastics}
5852 CJK UNIFIED IDEOGRAPH-#5852, IRGKangXi=0235.110, RSKangXi=32.10, Def{roost}
5853 CJK UNIFIED IDEOGRAPH-#5853, IRGKangXi=0235.120, RSKangXi=32.10, Def{plaster}
5854 CJK UNIFIED IDEOGRAPH-#5854, IRGKangXi=0235.140, RSKangXi=32.10, Def{tower, spire, tall building}
5855 CJK UNIFIED IDEOGRAPH-#5855, IRGKangXi=0235.150, RSKangXi=32.10, Def{a gust of wind}
5856 CJK UNIFIED IDEOGRAPH-#5856, IRGKangXi=0235.170, RSKangXi=32.10
5857 CJK UNIFIED IDEOGRAPH-#5857, IRGKangXi=0235.200, RSKangXi=32.10, Def{smear, daub, apply, spread; paint}
5858 CJK UNIFIED IDEOGRAPH-#5858, IRGKangXi=0235.220, RSKangXi=32.10, Def{pond; tank; dike, embankment}
5859 CJK UNIFIED IDEOGRAPH-#5859, IRGKangXi=0236.010, RSKangXi=32.10, Def{truly}
585A CJK UNIFIED IDEOGRAPH-#585A, IRGKangXi=0236.020, RSKangXi=32.10, Def{cemetery; tomb, burial mound}
585B CJK UNIFIED IDEOGRAPH-#585B, IRGKangXi=0236.030, RSKangXi=32.10
585C CJK UNIFIED IDEOGRAPH-#585C, IRGKangXi=0236.050, Def{dusty, dirt}
585D CJK UNIFIED IDEOGRAPH-#585D, IRGKangXi=0236.070, RSKangXi=32.10, Def{flat bank, plateau}
585E CJK UNIFIED IDEOGRAPH-#585E, IRGKangXi=0236.090, RSKangXi=32.10, Def{stop up, block, seal, cork; pass, frontier; fortress}
585F CJK UNIFIED IDEOGRAPH-#585F, IRGKangXi=0236.100, RSKangXi=32.10, Def{to bury}
5860 CJK UNIFIED IDEOGRAPH-#5860, IRGKangXi=0236.140, RSKangXi=32.10
5861 CJK UNIFIED IDEOGRAPH-#5861, IRGKangXi=0236.150, RSKangXi=32.10, Def{fill in, fill up; make good}
5862 CJK UNIFIED IDEOGRAPH-#5862, IRGKangXi=0236.180, RSKangXi=32.10, Def{entrenchment, bank, low wall}
5863 CJK UNIFIED IDEOGRAPH-#5863, IRGKangXi=0236.190, RSKangXi=32.10
5864 CJK UNIFIED IDEOGRAPH-#5864, IRGKangXi=0236.210, RSKangXi=32.10, Def{instrument}
5865 CJK UNIFIED IDEOGRAPH-#5865, IRGKangXi=0236.230, RSKangXi=32.10
5866 CJK UNIFIED IDEOGRAPH-#5866, IRGKangXi=0236.260, RSKangXi=32.10
5867 CJK UNIFIED IDEOGRAPH-#5867, IRGKangXi=0236.341, RSKangXi=32.10
5868 CJK UNIFIED IDEOGRAPH-#5868, IRGKangXi=0236.341, RSKangXi=32.10
5869 CJK UNIFIED IDEOGRAPH-#5869, IRGKangXi=0236.341, RSKangXi=32.10, Def{salt}
586A CJK UNIFIED IDEOGRAPH-#586A, IRGKangXi=0236.341, RSKangXi=32.10
586B CJK UNIFIED IDEOGRAPH-#586B, IRGKangXi=0236.341, RSKangXi=32.10, Def{fill in, fill up; make good}
586C CJK UNIFIED IDEOGRAPH-#586C, IRGKangXi=0236.341, RSKangXi=32.10, Def{plateau}
586D CJK UNIFIED IDEOGRAPH-#586D, IRGKangXi=0236.341, RSKangXi=32.10, Def{fish farm}
586E CJK UNIFIED IDEOGRAPH-#586E, IRGKangXi=0236.341, RSKangXi=32.10
586F CJK UNIFIED IDEOGRAPH-#586F, IRGKangXi=0236.341, RSKangXi=32.10
5870 CJK UNIFIED IDEOGRAPH-#5870, IRGKangXi=0236.341, RSKangXi=32.10
5871 CJK UNIFIED IDEOGRAPH-#5871, IRGKangXi=0238.191, RSKangXi=32.10, Def{place name in Guangdong province}
5872 CJK UNIFIED IDEOGRAPH-#5872, IRGKangXi=0236.350, RSKangXi=32.11, Def{open space, field, market}
5873 CJK UNIFIED IDEOGRAPH-#5873, IRGKangXi=0236.360, RSKangXi=32.11, Def{(Cant.) classifier for walls; covered (with dust); to scatter (like dust)}
5874 CJK UNIFIED IDEOGRAPH-#5874, IRGKangXi=0236.370, RSKangXi=32.11
5875 CJK UNIFIED IDEOGRAPH-#5875, IRGKangXi=0236.380, RSKangXi=32.11, Def{dust, dirt, ashes, cinders}
5876 CJK UNIFIED IDEOGRAPH-#5876, IRGKangXi=0236.420, RSKangXi=32.11
5877 CJK UNIFIED IDEOGRAPH-#5877, IRGKangXi=0236.430, RSKangXi=32.11
5878 CJK UNIFIED IDEOGRAPH-#5878, IRGKangXi=0237.020, RSKangXi=32.11
5879 CJK UNIFIED IDEOGRAPH-#5879, IRGKangXi=0237.030, RSKangXi=32.11, Def{moat, trench, pit, cavity}
587A CJK UNIFIED IDEOGRAPH-#587A, IRGKangXi=0237.050, RSKangXi=32.11
587B CJK UNIFIED IDEOGRAPH-#587B, IRGKangXi=0237.060, RSKangXi=32.11
587C CJK UNIFIED IDEOGRAPH-#587C, IRGKangXi=0237.080, RSKangXi=32.11, Def{brick}
587D CJK UNIFIED IDEOGRAPH-#587D, IRGKangXi=0237.090, RSKangXi=32.11, Def{plateau}
587E CJK UNIFIED IDEOGRAPH-#587E, IRGKangXi=0237.100, RSKangXi=32.11, Def{village school; private tutorage}
587F CJK UNIFIED IDEOGRAPH-#587F, IRGKangXi=0237.110, RSKangXi=32.11, Def{small mound}
5880 CJK UNIFIED IDEOGRAPH-#5880, IRGKangXi=0237.120, RSKangXi=32.11, Def{porch; courtyard; steps leading}
5881 CJK UNIFIED IDEOGRAPH-#5881, IRGKangXi=0237.130, RSKangXi=32.11, Def{to plaster; to pave}
5882 CJK UNIFIED IDEOGRAPH-#5882, IRGKangXi=0237.140, RSKangXi=32.11
5883 CJK UNIFIED IDEOGRAPH-#5883, IRGKangXi=0237.170, RSKangXi=32.11, Def{boundary, frontier; area, region}
5884 CJK UNIFIED IDEOGRAPH-#5884, IRGKangXi=0237.180, Def{the steps of a stairway}
5885 CJK UNIFIED IDEOGRAPH-#5885, IRGKangXi=0237.200, RSKangXi=32.11, Def{villa, country house}
5886 CJK UNIFIED IDEOGRAPH-#5886, IRGKangXi=0237.220, RSKangXi=32.11
5887 CJK UNIFIED IDEOGRAPH-#5887, IRGKangXi=0237.240, RSKangXi=32.11
5888 CJK UNIFIED IDEOGRAPH-#5888, IRGKangXi=0237.260, RSKangXi=32.11, Def{cliff}
5889 CJK UNIFIED IDEOGRAPH-#5889, IRGKangXi=0237.270, RSKangXi=32.11, Def{wall; fortified wall; small wall}
588A CJK UNIFIED IDEOGRAPH-#588A, IRGKangXi=0237.300, RSKangXi=32.11, Def{advance money, pay for another}
588B CJK UNIFIED IDEOGRAPH-#588B, IRGKangXi=0237.310, RSKangXi=32.11
588C CJK UNIFIED IDEOGRAPH-#588C, IRGKangXi=0238.010, RSKangXi=32.11
588D CJK UNIFIED IDEOGRAPH-#588D, IRGKangXi=0238.020, RSKangXi=32.11, Def{paint, decorate}
588E CJK UNIFIED IDEOGRAPH-#588E, IRGKangXi=0238.060, RSKangXi=32.11
588F CJK UNIFIED IDEOGRAPH-#588F, IRGKangXi=0238.070, RSKangXi=32.11
5890 CJK UNIFIED IDEOGRAPH-#5890, IRGKangXi=0238.080, RSKangXi=32.11, Def{to build with soil, plaster over with mud}
5891 CJK UNIFIED IDEOGRAPH-#5891, IRGKangXi=0238.100, RSKangXi=32.11
5892 CJK UNIFIED IDEOGRAPH-#5892, IRGKangXi=0238.110, RSKangXi=32.11, Def{wet tilth}
5893 CJK UNIFIED IDEOGRAPH-#5893, IRGKangXi=0238.120, RSKangXi=32.11, Def{grave, tomb}
5894 CJK UNIFIED IDEOGRAPH-#5894, IRGKangXi=0238.140, RSKangXi=32.11
5895 CJK UNIFIED IDEOGRAPH-#5895, IRGKangXi=0238.191
5896 CJK UNIFIED IDEOGRAPH-#5896, IRGKangXi=0238.191, RSKangXi=32.11, Def{pagoda, dagoba, tower}
5897 CJK UNIFIED IDEOGRAPH-#5897, IRGKangXi=0238.191, RSKangXi=32.11, Def{increase}
5898 CJK UNIFIED IDEOGRAPH-#5898, IRGKangXi=0238.191, RSKangXi=32.11, Def{(Cant.) halfway}
5899 CJK UNIFIED IDEOGRAPH-#5899, IRGKangXi=0238.191, RSKangXi=32.11, Def{wall}
589A CJK UNIFIED IDEOGRAPH-#589A, IRGKangXi=0238.191, RSKangXi=32.11, Def{mountain range}
589B CJK UNIFIED IDEOGRAPH-#589B, IRGKangXi=0238.191, RSKangXi=32.11
589C CJK UNIFIED IDEOGRAPH-#589C, IRGKangXi=0238.220, RSKangXi=32.12, Def{fall down, drop, sink, go to ruin}
589D CJK UNIFIED IDEOGRAPH-#589D, IRGKangXi=0238.230, RSKangXi=32.12, Def{stony}
589E CJK UNIFIED IDEOGRAPH-#589E, IRGKangXi=0238.250, RSKangXi=32.12, Def{increase, add to, augment}
589F CJK UNIFIED IDEOGRAPH-#589F, IRGKangXi=0238.280, RSKangXi=32.12, Def{high mound; hilly countryside; wasteland}
58A0 CJK UNIFIED IDEOGRAPH-#58A0, IRGKangXi=0238.290, RSKangXi=32.12, Def{smooth, hard spot made level for sacrificial altar}
58A1 CJK UNIFIED IDEOGRAPH-#58A1, IRGKangXi=0238.320, RSKangXi=32.12, Def{chalk}
58A2 CJK UNIFIED IDEOGRAPH-#58A2, IRGKangXi=0238.340, RSKangXi=32.12
58A3 CJK UNIFIED IDEOGRAPH-#58A3, IRGKangXi=0238.350, RSKangXi=32.12
58A4 CJK UNIFIED IDEOGRAPH-#58A4, IRGKangXi=0238.360, RSKangXi=32.12, Def{to fall in ruins, to collapse, to overthrow; decayed, ruined, lost}
58A5 CJK UNIFIED IDEOGRAPH-#58A5, IRGKangXi=0238.370, RSKangXi=32.12
58A6 CJK UNIFIED IDEOGRAPH-#58A6, IRGKangXi=0238.380, RSKangXi=32.12, Def{tomb}
58A7 CJK UNIFIED IDEOGRAPH-#58A7, IRGKangXi=0238.390, RSKangXi=32.12
58A8 CJK UNIFIED IDEOGRAPH-#58A8, IRGKangXi=0238.400, RSKangXi=32.12, Def{ink; writing}
58A9 CJK UNIFIED IDEOGRAPH-#58A9, IRGKangXi=0239.010, RSKangXi=32.12, Def{heap, mound, block of stone}
58AA CJK UNIFIED IDEOGRAPH-#58AA, IRGKangXi=0239.020, RSKangXi=32.12
58AB CJK UNIFIED IDEOGRAPH-#58AB, IRGKangXi=0239.030, RSKangXi=32.12, Def{cup}
58AC CJK UNIFIED IDEOGRAPH-#58AC, IRGKangXi=0239.040, RSKangXi=32.12, Def{to fall, sink}
58AD CJK UNIFIED IDEOGRAPH-#58AD, IRGKangXi=0239.050, RSKangXi=32.12
58AE CJK UNIFIED IDEOGRAPH-#58AE, IRGKangXi=0239.110, RSKangXi=32.12, Def{fall, sink, let fall; degenerate}
58AF CJK UNIFIED IDEOGRAPH-#58AF, IRGKangXi=0239.130, RSKangXi=32.12
58B0 CJK UNIFIED IDEOGRAPH-#58B0, IRGKangXi=0239.241, RSKangXi=32.12, Def{an earthenware jar; a jug}
58B1 CJK UNIFIED IDEOGRAPH-#58B1, IRGKangXi=0239.150, RSKangXi=32.12
58B2 CJK UNIFIED IDEOGRAPH-#58B2, IRGKangXi=0239.160, RSKangXi=32.12
58B3 CJK UNIFIED IDEOGRAPH-#58B3, IRGKangXi=0239.180, RSKangXi=32.12, Def{grave, mound; bulge; bulging}
58B4 CJK UNIFIED IDEOGRAPH-#58B4, IRGKangXi=0239.220, RSKangXi=32.12
58B5 CJK UNIFIED IDEOGRAPH-#58B5, IRGKangXi=0239.241, RSKangXi=32.12
58B6 CJK UNIFIED IDEOGRAPH-#58B6, IRGKangXi=0240.301, RSKangXi=32.12
58B7 CJK UNIFIED IDEOGRAPH-#58B7, IRGKangXi=0239.241, RSKangXi=32.12
58B8 CJK UNIFIED IDEOGRAPH-#58B8, IRGKangXi=0240.301, RSKangXi=32.12
58B9 CJK UNIFIED IDEOGRAPH-#58B9, IRGKangXi=0239.241, RSKangXi=32.12
58BA CJK UNIFIED IDEOGRAPH-#58BA, IRGKangXi=0239.250, RSKangXi=32.13, Def{four walls}
58BB CJK UNIFIED IDEOGRAPH-#58BB, IRGKangXi=0239.300, RSKangXi=32.13, Def{wall}
58BC CJK UNIFIED IDEOGRAPH-#58BC, IRGKangXi=0239.310, RSKangXi=32.13
58BD CJK UNIFIED IDEOGRAPH-#58BD, IRGKangXi=0240.020, RSKangXi=32.13
58BE CJK UNIFIED IDEOGRAPH-#58BE, IRGKangXi=0240.030, RSKangXi=32.13, Def{cultivate, reclaim, to farm land}
58BF CJK UNIFIED IDEOGRAPH-#58BF, IRGKangXi=0240.050, RSKangXi=32.13
58C0 CJK UNIFIED IDEOGRAPH-#58C0, IRGKangXi=0240.060, RSKangXi=32.13
58C1 CJK UNIFIED IDEOGRAPH-#58C1, IRGKangXi=0240.100, RSKangXi=32.13, Def{partition wall; walls of a house}
58C2 CJK UNIFIED IDEOGRAPH-#58C2, IRGKangXi=0240.110, RSKangXi=32.13
58C3 CJK UNIFIED IDEOGRAPH-#58C3, IRGKangXi=0240.140, RSKangXi=32.13
58C4 CJK UNIFIED IDEOGRAPH-#58C4, IRGKangXi=0240.170, RSKangXi=32.13
58C5 CJK UNIFIED IDEOGRAPH-#58C5, IRGKangXi=0240.180, RSKangXi=32.13, Def{to obstruct}
58C6 CJK UNIFIED IDEOGRAPH-#58C6, IRGKangXi=0240.210, RSKangXi=32.13, Def{stiff, hard clay or rocky strata; crack in a jar}
58C7 CJK UNIFIED IDEOGRAPH-#58C7, IRGKangXi=0240.220, RSKangXi=32.13, Def{altar; arena, examination hall}
58C8 CJK UNIFIED IDEOGRAPH-#58C8, IRGKangXi=0240.250, RSKangXi=32.13, Def{disappointed}
58C9 CJK UNIFIED IDEOGRAPH-#58C9, IRGKangXi=0240.280, RSKangXi=32.13
58CA CJK UNIFIED IDEOGRAPH-#58CA, IRGKangXi=0240.301, RSKangXi=32.13, Def{bad, spoil(ed), ruin, destroy}
58CB CJK UNIFIED IDEOGRAPH-#58CB, IRGKangXi=0240.301
58CC CJK UNIFIED IDEOGRAPH-#58CC, IRGKangXi=0240.301, RSKangXi=32.13, Def{soil, loam, earth; rich}
58CD CJK UNIFIED IDEOGRAPH-#58CD, IRGKangXi=0240.310, RSKangXi=32.14, Def{moat around a city. a channel}
58CE CJK UNIFIED IDEOGRAPH-#58CE, IRGKangXi=0240.340, RSKangXi=32.14, Def{instrument}
58CF CJK UNIFIED IDEOGRAPH-#58CF, IRGKangXi=0241.040, RSKangXi=32.14
58D0 CJK UNIFIED IDEOGRAPH-#58D0, IRGKangXi=0241.050, RSKangXi=32.14, Def{the Imperial signet; the great seal}
58D1 CJK UNIFIED IDEOGRAPH-#58D1, IRGKangXi=0241.070, RSKangXi=32.14, Def{bed of torrent, narrow ravine}
58D2 CJK UNIFIED IDEOGRAPH-#58D2, IRGKangXi=0241.080, RSKangXi=32.14, Def{dust}
58D3 CJK UNIFIED IDEOGRAPH-#58D3, IRGKangXi=0241.100, RSKangXi=32.14, Def{press; oppress; crush; pressure}
58D4 CJK UNIFIED IDEOGRAPH-#58D4, IRGKangXi=0241.110, RSKangXi=32.14, Def{a mound, a tumulus}
58D5 CJK UNIFIED IDEOGRAPH-#58D5, IRGKangXi=0241.120, RSKangXi=32.14, Def{trench, ditch, channel, moat}
58D6 CJK UNIFIED IDEOGRAPH-#58D6, IRGKangXi=0241.130, RSKangXi=32.14, Def{open space along water}
58D7 CJK UNIFIED IDEOGRAPH-#58D7, IRGKangXi=0241.211, RSKangXi=32.14
58D8 CJK UNIFIED IDEOGRAPH-#58D8, IRGKangXi=0241.240, RSKangXi=32.15, Def{rampart, military wall}
58D9 CJK UNIFIED IDEOGRAPH-#58D9, IRGKangXi=0241.250, RSKangXi=32.15, Def{tomb, grave: prairie; open wilderness}
58DA CJK UNIFIED IDEOGRAPH-#58DA, IRGKangXi=0241.290, RSKangXi=32.16, Def{black clods of earth; shop, hut}
58DB CJK UNIFIED IDEOGRAPH-#58DB, IRGKangXi=0241.300, RSKangXi=32.16
58DC CJK UNIFIED IDEOGRAPH-#58DC, IRGKangXi=0242.010, RSKangXi=32.16, Def{earthen jar or jug}
58DD CJK UNIFIED IDEOGRAPH-#58DD, IRGKangXi=0242.020, RSKangXi=32.16, Def{a mound, an embankment the earthen altar to the god of the soil}
58DE CJK UNIFIED IDEOGRAPH-#58DE, IRGKangXi=0242.030, RSKangXi=32.16, Def{bad, spoil(ed), ruin, destroy}
58DF CJK UNIFIED IDEOGRAPH-#58DF, IRGKangXi=0242.050, RSKangXi=32.16, Def{grave, mound; ridge in field}
58E0 CJK UNIFIED IDEOGRAPH-#58E0, IRGKangXi=0242.060, RSKangXi=32.16, Def{mound, grave; ridge in field}
58E1 CJK UNIFIED IDEOGRAPH-#58E1, IRGKangXi=0242.090, RSKangXi=32.16
58E2 CJK UNIFIED IDEOGRAPH-#58E2, IRGKangXi=0242.130, RSKangXi=32.16, Def{a hole, pit}
58E3 CJK UNIFIED IDEOGRAPH-#58E3, IRGKangXi=0242.160, RSKangXi=32.17
58E4 CJK UNIFIED IDEOGRAPH-#58E4, IRGKangXi=0242.170, RSKangXi=32.17, Def{soil, loam, earth; rich}
58E5 CJK UNIFIED IDEOGRAPH-#58E5, IRGKangXi=0242.191, RSKangXi=32.17
58E6 CJK UNIFIED IDEOGRAPH-#58E6, IRGKangXi=0242.240, RSKangXi=32.18
58E7 CJK UNIFIED IDEOGRAPH-#58E7, IRGKangXi=0242.290, RSKangXi=32.20
58E8 CJK UNIFIED IDEOGRAPH-#58E8, IRGKangXi=0242.320, RSKangXi=32.20
58E9 CJK UNIFIED IDEOGRAPH-#58E9, IRGKangXi=0242.330, RSKangXi=32.21, Def{embankment; dam}
58EA CJK UNIFIED IDEOGRAPH-#58EA, IRGKangXi=0242.361, RSKangXi=32.22
58EB CJK UNIFIED IDEOGRAPH-#58EB, IRGKangXi=0242.380, RSKangXi=33.0, Def{scholar, gentleman; soldier}
58EC CJK UNIFIED IDEOGRAPH-#58EC, IRGKangXi=0243.010, RSKangXi=33.1, Def{9th heavenly stem}
58ED CJK UNIFIED IDEOGRAPH-#58ED, IRGKangXi=0243.011, RSKangXi=33.2, Def{kwukyel}
58EE CJK UNIFIED IDEOGRAPH-#58EE, IRGKangXi=0243.011, RSKangXi=33.3, Def{big, large; robust; name of tribe}
58EF CJK UNIFIED IDEOGRAPH-#58EF, IRGKangXi=0243.020, RSKangXi=33.4, Def{big, large; robust; name of tribe}
58F0 CJK UNIFIED IDEOGRAPH-#58F0, IRGKangXi=0243.040, RSKangXi=33.4, Def{sound, voice, noise; tone; music}
58F1 CJK UNIFIED IDEOGRAPH-#58F1, IRGKangXi=0243.041, RSKangXi=33.4, AccountingNumeric=1, Def{number one}
58F2 CJK UNIFIED IDEOGRAPH-#58F2, IRGKangXi=0243.041, RSKangXi=33.4, Def{sell; [NOT casing, shell, husk]}
58F3 CJK UNIFIED IDEOGRAPH-#58F3, IRGKangXi=0243.041, RSKangXi=33.4, Def{casing, shell, husk}
58F4 CJK UNIFIED IDEOGRAPH-#58F4, IRGKangXi=0243.050, RSKangXi=33.6
58F5 CJK UNIFIED IDEOGRAPH-#58F5, IRGKangXi=0243.051, RSKangXi=33.6
58F6 CJK UNIFIED IDEOGRAPH-#58F6, IRGKangXi=0243.071, RSKangXi=33.7, Def{jar, pot, jug, vase; surname}
58F7 CJK UNIFIED IDEOGRAPH-#58F7, IRGKangXi=0243.080, RSKangXi=33.8, Def{jar, pot, jug, vase; surname}
58F8 CJK UNIFIED IDEOGRAPH-#58F8, IRGKangXi=0243.091, RSKangXi=33.10, Def{palace corridor or passageway}
58F9 CJK UNIFIED IDEOGRAPH-#58F9, IRGKangXi=0243.100, RSKangXi=33.9, AccountingNumeric=1, Def{number one}
58FA CJK UNIFIED IDEOGRAPH-#58FA, IRGKangXi=0243.150, RSKangXi=33.9, Def{jar, pot, jug, vase; surname}
58FB CJK UNIFIED IDEOGRAPH-#58FB, IRGKangXi=0243.170, RSKangXi=33.9, Def{son-in-law; husband}
58FC CJK UNIFIED IDEOGRAPH-#58FC, IRGKangXi=0244.010, RSKangXi=33.10, Def{palace corridor or passageway}
58FD CJK UNIFIED IDEOGRAPH-#58FD, IRGKangXi=0244.040, RSKangXi=33.11, Def{old age, long life; lifespan}
58FE CJK UNIFIED IDEOGRAPH-#58FE, IRGKangXi=0244.090, RSKangXi=33.11
58FF CJK UNIFIED IDEOGRAPH-#58FF, IRGKangXi=0244.100, RSKangXi=33.12
5900 CJK UNIFIED IDEOGRAPH-#5900, IRGKangXi=0244.111, RSKangXi=33.12, Def{life; length of life; longevity}
5901 CJK UNIFIED IDEOGRAPH-#5901, IRGKangXi=0244.120, RSKangXi=33.13
5902 CJK UNIFIED IDEOGRAPH-#5902, IRGKangXi=0244.170, RSKangXi=34.0, Def{go; KangXi radical 34}
5903 CJK UNIFIED IDEOGRAPH-#5903, IRGKangXi=0244.190, RSKangXi=34.1
5904 CJK UNIFIED IDEOGRAPH-#5904, IRGKangXi=0158.021, RSKangXi=34.2, Def{place, locale; department}
5905 CJK UNIFIED IDEOGRAPH-#5905, IRGKangXi=0244.200, RSKangXi=34.3, Def{to descend; to come down from heaven. to send down}
5906 CJK UNIFIED IDEOGRAPH-#5906, IRGKangXi=0244.220, RSKangXi=34.4, Def{resist}
5907 CJK UNIFIED IDEOGRAPH-#5907, IRGKangXi=0244.231, RSKangXi=34.5, Def{prepare, ready, perfect}
5908 CJK UNIFIED IDEOGRAPH-#5908, IRGKangXi=0244.241, RSKangXi=34.6
5909 CJK UNIFIED IDEOGRAPH-#5909, IRGKangXi=0245.101, RSKangXi=35.6, Def{change, transform, alter; rebel}
590A CJK UNIFIED IDEOGRAPH-#590A, IRGKangXi=0245.010, RSKangXi=35.0, Def{KangXi radical 35; go slowly}
590B CJK UNIFIED IDEOGRAPH-#590B, IRGKangXi=0245.030, RSKangXi=35.4, Def{to dawdle; the emperor Yao's father}
590C CJK UNIFIED IDEOGRAPH-#590C, IRGKangXi=0245.050, RSKangXi=35.5, Def{to dawdle; the name of the father of the Emperor Yao}
590D CJK UNIFIED IDEOGRAPH-#590D, IRGKangXi=0245.101, RSKangXi=35.6, Def{return; repeat; repeatedly}
590E CJK UNIFIED IDEOGRAPH-#590E, IRGKangXi=0245.110, RSKangXi=35.7
590F CJK UNIFIED IDEOGRAPH-#590F, IRGKangXi=0245.120, RSKangXi=35.7, Def{summer; great, grand, big}
5910 CJK UNIFIED IDEOGRAPH-#5910, IRGKangXi=0245.220, RSKangXi=35.11, Def{long, faraway; pre-eminent}
5911 CJK UNIFIED IDEOGRAPH-#5911, IRGKangXi=0245.271, RSKangXi=86.15
5912 CJK UNIFIED IDEOGRAPH-#5912, IRGKangXi=0245.280, RSKangXi=35.16
5913 CJK UNIFIED IDEOGRAPH-#5913, IRGKangXi=0245.281, RSKangXi=35.15
5914 CJK UNIFIED IDEOGRAPH-#5914, IRGKangXi=0245.281, RSKangXi=35.19, Def{one-legged monster; walrus}
5915 CJK UNIFIED IDEOGRAPH-#5915, IRGKangXi=0246.010, RSKangXi=36.0, Def{evening, night, dusk; slanted}
5916 CJK UNIFIED IDEOGRAPH-#5916, IRGKangXi=0246.020, RSKangXi=36.2, Def{out, outside, external; foreign}
5917 CJK UNIFIED IDEOGRAPH-#5917, IRGKangXi=0246.040, RSKangXi=36.2, Def{to turn over when asleep}
5918 CJK UNIFIED IDEOGRAPH-#5918, IRGKangXi=0246.050, RSKangXi=36.2, Def{4th of Earth Branches; period from 5-7 a.m.}
5919 CJK UNIFIED IDEOGRAPH-#5919, IRGKangXi=0246.070, RSKangXi=36.3, Def{early in morning, dawn; previous}
591A CJK UNIFIED IDEOGRAPH-#591A, IRGKangXi=0246.110, RSKangXi=36.3, Def{much, many; more than, over}
591B CJK UNIFIED IDEOGRAPH-#591B, IRGKangXi=0246.151, RSKangXi=36.3, Def{much, many; more than, over}
591C CJK UNIFIED IDEOGRAPH-#591C, IRGKangXi=0246.180, RSKangXi=36.5, Def{night, dark; in night; by night}
591D CJK UNIFIED IDEOGRAPH-#591D, IRGKangXi=0247.010, RSKangXi=36.5
591E CJK UNIFIED IDEOGRAPH-#591E, IRGKangXi=0247.071, RSKangXi=21.8
591F CJK UNIFIED IDEOGRAPH-#591F, IRGKangXi=0247.090, RSKangXi=36.8, Def{enough, adequate}
5920 CJK UNIFIED IDEOGRAPH-#5920, IRGKangXi=0247.100, RSKangXi=36.8, Def{enough, adequate}
5921 CJK UNIFIED IDEOGRAPH-#5921, IRGKangXi=0247.130, RSKangXi=36.9
5922 CJK UNIFIED IDEOGRAPH-#5922, IRGKangXi=0247.160, RSKangXi=36.11, Def{dream; visionary; wishful}
5923 CJK UNIFIED IDEOGRAPH-#5923, IRGKangXi=0247.170, RSKangXi=36.11, Def{a dream; to dream visionary; stupid}
5924 CJK UNIFIED IDEOGRAPH-#5924, IRGKangXi=0247.190, RSKangXi=36.11, Def{distant place; remote; deep}
5925 CJK UNIFIED IDEOGRAPH-#5925, IRGKangXi=0247.220, RSKangXi=36.11, Def{companion; partner; assistant}
5926 CJK UNIFIED IDEOGRAPH-#5926, IRGKangXi=0247.241, RSKangXi=36.12
5927 CJK UNIFIED IDEOGRAPH-#5927, IRGKangXi=0248.010, RSKangXi=37.0, Def{big, great, vast, large, high}
5928 CJK UNIFIED IDEOGRAPH-#5928, IRGKangXi=0248.030, RSKangXi=37.0
5929 CJK UNIFIED IDEOGRAPH-#5929, IRGKangXi=0248.040, RSKangXi=37.1, Def{sky, heaven; god, celestial}
592A CJK UNIFIED IDEOGRAPH-#592A, IRGKangXi=0248.100, RSKangXi=37.1, Def{very, too, much; big; extreme}
592B CJK UNIFIED IDEOGRAPH-#592B, IRGKangXi=0248.110, RSKangXi=37.1, Def{man, male adult, husband; those}
592C CJK UNIFIED IDEOGRAPH-#592C, IRGKangXi=0249.010, RSKangXi=37.1, Def{parted; fork; certain}
592D CJK UNIFIED IDEOGRAPH-#592D, IRGKangXi=0249.030, RSKangXi=37.1, Def{young, fresh-looking; die young}
592E CJK UNIFIED IDEOGRAPH-#592E, IRGKangXi=0249.050, RSKangXi=37.2, Def{center, conclude, run out; beg}
592F CJK UNIFIED IDEOGRAPH-#592F, IRGKangXi=0249.060, RSKangXi=37.2, Def{heavy load, burden; lift up}
5930 CJK UNIFIED IDEOGRAPH-#5930, IRGKangXi=0249.080, RSKangXi=37.2
5931 CJK UNIFIED IDEOGRAPH-#5931, IRGKangXi=0249.090, RSKangXi=37.2, Def{lose; make mistake, neglect}
5932 CJK UNIFIED IDEOGRAPH-#5932, IRGKangXi=0249.100, RSKangXi=37.2, Def{advance quickly; to go back and forth; origin, source}
5933 CJK UNIFIED IDEOGRAPH-#5933, IRGKangXi=0249.110, RSKangXi=37.2
5934 CJK UNIFIED IDEOGRAPH-#5934, IRGKangXi=0249.111, RSKangXi=37.2, Def{head; top; chief, first; boss}
5935 CJK UNIFIED IDEOGRAPH-#5935, IRGKangXi=0249.130, RSKangXi=37.3
5936 CJK UNIFIED IDEOGRAPH-#5936, IRGKangXi=0249.140, RSKangXi=37.3
5937 CJK UNIFIED IDEOGRAPH-#5937, IRGKangXi=0249.150, RSKangXi=37.3, Def{ancient barbarian tribes}
5938 CJK UNIFIED IDEOGRAPH-#5938, IRGKangXi=0250.020, RSKangXi=37.3, Def{extravagant, luxurious; handsome}
5939 CJK UNIFIED IDEOGRAPH-#5939, IRGKangXi=0250.071, RSKangXi=1.5, Def{be wedged or inserted between}
593A CJK UNIFIED IDEOGRAPH-#593A, IRGKangXi=0250.071, RSKangXi=37.3, Def{take by force, rob, snatch}
593B CJK UNIFIED IDEOGRAPH-#593B, IRGKangXi=0250.071, RSKangXi=30.3, Def{fish name}
593C CJK UNIFIED IDEOGRAPH-#593C, IRGKangXi=0250.071, RSKangXi=37.3
593D CJK UNIFIED IDEOGRAPH-#593D, IRGKangXi=0250.080, RSKangXi=37.4
593E CJK UNIFIED IDEOGRAPH-#593E, IRGKangXi=0250.100, RSKangXi=37.4, Def{be wedged or inserted between}
593F CJK UNIFIED IDEOGRAPH-#593F, IRGKangXi=0250.130, RSKangXi=37.4
5940 CJK UNIFIED IDEOGRAPH-#5940, IRGKangXi=0250.161, RSKangXi=37.4, Def{(Cant.) skinny, tiny; to jerk, dangle}
5941 CJK UNIFIED IDEOGRAPH-#5941, IRGKangXi=0250.161, RSKangXi=37.4, Def{lady's vanity case; trousseau}
5942 CJK UNIFIED IDEOGRAPH-#5942, IRGKangXi=0250.161, RSKangXi=37.4, Def{be numerous, brilliant}
5943 CJK UNIFIED IDEOGRAPH-#5943, IRGKangXi=0250.200, RSKangXi=37.5
5944 CJK UNIFIED IDEOGRAPH-#5944, IRGKangXi=0250.210, RSKangXi=37.5, Def{ere long; remain, tarry; feeble}
5945 CJK UNIFIED IDEOGRAPH-#5945, IRGKangXi=0250.230, RSKangXi=37.5
5946 CJK UNIFIED IDEOGRAPH-#5946, IRGKangXi=0250.270, RSKangXi=37.5
5947 CJK UNIFIED IDEOGRAPH-#5947, IRGKangXi=0250.310, RSKangXi=37.5, Def{strange, unusual, uncanny, occult}
5948 CJK UNIFIED IDEOGRAPH-#5948, IRGKangXi=0251.010, RSKangXi=37.5, Def{but, how; bear, stand, endure}
5949 CJK UNIFIED IDEOGRAPH-#5949, IRGKangXi=0251.020, RSKangXi=37.5, Def{offer; receive; serve; respect}
594A CJK UNIFIED IDEOGRAPH-#594A, IRGKangXi=0251.060, RSKangXi=37.7
594B CJK UNIFIED IDEOGRAPH-#594B, IRGKangXi=0251.091, RSKangXi=37.5, Def{strive, exert effort; arouse}
594C CJK UNIFIED IDEOGRAPH-#594C, IRGKangXi=0251.091, Def{dot, speck, spot; point, degree}
594D CJK UNIFIED IDEOGRAPH-#594D, IRGKangXi=0251.091, RSKangXi=37.5
594E CJK UNIFIED IDEOGRAPH-#594E, IRGKangXi=0251.110, RSKangXi=37.6, Def{stride of man; one of the twenty-eight lunar mansions}
594F CJK UNIFIED IDEOGRAPH-#594F, IRGKangXi=0251.150, RSKangXi=37.6, Def{memorialize emperor; report}
5950 CJK UNIFIED IDEOGRAPH-#5950, IRGKangXi=0251.200, RSKangXi=37.6, Def{be numerous, brilliant}
5951 CJK UNIFIED IDEOGRAPH-#5951, IRGKangXi=0251.210, RSKangXi=37.6, Def{deed, contract, bond; engrave}
5952 CJK UNIFIED IDEOGRAPH-#5952, IRGKangXi=0251.220, RSKangXi=37.6
5953 CJK UNIFIED IDEOGRAPH-#5953, IRGKangXi=0252.020, RSKangXi=37.6, Def{extravagant}
5954 CJK UNIFIED IDEOGRAPH-#5954, IRGKangXi=0252.030, RSKangXi=37.6, Def{run fast, flee; rush about; run}
5955 CJK UNIFIED IDEOGRAPH-#5955, IRGKangXi=0252.050, RSKangXi=37.6, Def{in sequence, orderly; abundant}
5956 CJK UNIFIED IDEOGRAPH-#5956, IRGKangXi=0252.051, RSKangXi=37.6, Def{prize, reward; give award to}
5957 CJK UNIFIED IDEOGRAPH-#5957, IRGKangXi=0252.060, RSKangXi=37.7, Def{case, cover, wrapper, envelope}
5958 CJK UNIFIED IDEOGRAPH-#5958, IRGKangXi=0252.080, RSKangXi=37.7, Def{large, powerful, stout, thick}
5959 CJK UNIFIED IDEOGRAPH-#5959, IRGKangXi=0252.090, RSKangXi=37.7
595A CJK UNIFIED IDEOGRAPH-#595A, IRGKangXi=0252.100, RSKangXi=37.7, Def{where? what? how? why?; servant}
595B CJK UNIFIED IDEOGRAPH-#595B, IRGKangXi=0252.140, RSKangXi=37.8, Def{opening, radiant}
595C CJK UNIFIED IDEOGRAPH-#595C, IRGKangXi=0252.180, RSKangXi=37.8, Def{big}
595D CJK UNIFIED IDEOGRAPH-#595D, IRGKangXi=0252.190, RSKangXi=37.8, Def{large}
595E CJK UNIFIED IDEOGRAPH-#595E, IRGKangXi=0252.200, RSKangXi=37.8, Def{the stride made by a man}
595F CJK UNIFIED IDEOGRAPH-#595F, IRGKangXi=0253.010, RSKangXi=37.9
5960 CJK UNIFIED IDEOGRAPH-#5960, IRGKangXi=0253.050, RSKangXi=37.9, Def{pay respect; settle}
5961 CJK UNIFIED IDEOGRAPH-#5961, IRGKangXi=0253.070, RSKangXi=37.9, Def{arrogant}
5962 CJK UNIFIED IDEOGRAPH-#5962, IRGKangXi=0253.090, RSKangXi=37.9, Def{extravagant, wasteful; exaggerate}
5963 CJK UNIFIED IDEOGRAPH-#5963, IRGKangXi=0253.110, RSKangXi=37.9
5964 CJK UNIFIED IDEOGRAPH-#5964, IRGKangXi=0253.150, RSKangXi=37.9
5965 CJK UNIFIED IDEOGRAPH-#5965, IRGKangXi=0253.151, RSKangXi=37.9, Def{mysterious, obscure, profound}
5966 CJK UNIFIED IDEOGRAPH-#5966, IRGKangXi=0253.180, RSKangXi=37.10
5967 CJK UNIFIED IDEOGRAPH-#5967, IRGKangXi=0253.190, RSKangXi=37.10, Def{mysterious, obscure, profound}
5968 CJK UNIFIED IDEOGRAPH-#5968, IRGKangXi=0253.211, RSKangXi=37.10, Def{prize, reward; give award to}
5969 CJK UNIFIED IDEOGRAPH-#5969, IRGKangXi=0253.220, RSKangXi=37.11, Def{lady's vanity case; trousseau}
596A CJK UNIFIED IDEOGRAPH-#596A, IRGKangXi=0253.250, RSKangXi=37.11, Def{take by force, rob, snatch}
596B CJK UNIFIED IDEOGRAPH-#596B, IRGKangXi=0253.280, RSKangXi=37.11, Def{deep and broad (expanse of water); abyss}
596C CJK UNIFIED IDEOGRAPH-#596C, IRGKangXi=0254.010, RSKangXi=37.11, Def{prize, reward; give award to}
596D CJK UNIFIED IDEOGRAPH-#596D, IRGKangXi=0254.020, RSKangXi=37.12, Def{red; anger; ire; surname}
596E CJK UNIFIED IDEOGRAPH-#596E, IRGKangXi=0254.090, RSKangXi=37.13, Def{strive, exert effort; arouse}
596F CJK UNIFIED IDEOGRAPH-#596F, IRGKangXi=0254.100, RSKangXi=37.13
5970 CJK UNIFIED IDEOGRAPH-#5970, IRGKangXi=0254.180, RSKangXi=37.15, Def{anger}
5971 CJK UNIFIED IDEOGRAPH-#5971, IRGKangXi=0254.191, RSKangXi=37.19
5972 CJK UNIFIED IDEOGRAPH-#5972, IRGKangXi=0254.210, RSKangXi=37.21
5973 CJK UNIFIED IDEOGRAPH-#5973, IRGKangXi=0254.220, RSKangXi=38.0, Def{woman, girl; feminine; rad. 38}
5974 CJK UNIFIED IDEOGRAPH-#5974, IRGKangXi=0254.260, RSKangXi=38.2, Def{slave, servant}
5975 CJK UNIFIED IDEOGRAPH-#5975, IRGKangXi=0255.020, RSKangXi=38.2
5976 CJK UNIFIED IDEOGRAPH-#5976, IRGKangXi=0255.021, RSKangXi=38.2, Def{milk; woman's breasts; nurse}
5977 CJK UNIFIED IDEOGRAPH-#5977, IRGKangXi=0255.030, RSKangXi=38.3
5978 CJK UNIFIED IDEOGRAPH-#5978, IRGKangXi=0255.040, RSKangXi=38.3, Def{crafty, villainous, false}
5979 CJK UNIFIED IDEOGRAPH-#5979, IRGKangXi=0255.050, RSKangXi=38.3, Def{she, her}
597A CJK UNIFIED IDEOGRAPH-#597A, IRGKangXi=0256.041, RSKangXi=38.3
597B CJK UNIFIED IDEOGRAPH-#597B, IRGKangXi=0255.080, RSKangXi=38.3
597C CJK UNIFIED IDEOGRAPH-#597C, IRGKangXi=0255.090, RSKangXi=38.3, Def{beautiful, colorful; girl}
597D CJK UNIFIED IDEOGRAPH-#597D, IRGKangXi=0255.110, RSKangXi=38.3, Def{good, excellent, fine; well}
597E CJK UNIFIED IDEOGRAPH-#597E, IRGKangXi=0255.150, RSKangXi=38.3
597F CJK UNIFIED IDEOGRAPH-#597F, IRGKangXi=0255.160, RSKangXi=38.3
5980 CJK UNIFIED IDEOGRAPH-#5980, IRGKangXi=0255.170, RSKangXi=38.3
5981 CJK UNIFIED IDEOGRAPH-#5981, IRGKangXi=0255.190, RSKangXi=38.3, Def{act as go-between}
5982 CJK UNIFIED IDEOGRAPH-#5982, IRGKangXi=0255.210, RSKangXi=38.3, Def{if, supposing; as if; like, as}
5983 CJK UNIFIED IDEOGRAPH-#5983, IRGKangXi=0255.220, RSKangXi=38.3, Def{wife, spouse; imperial concubine}
5984 CJK UNIFIED IDEOGRAPH-#5984, IRGKangXi=0256.010, RSKangXi=38.3, Def{absurd, foolish, reckless; false}
5985 CJK UNIFIED IDEOGRAPH-#5985, IRGKangXi=0256.020, RSKangXi=38.3
5986 CJK UNIFIED IDEOGRAPH-#5986, IRGKangXi=0256.041, RSKangXi=38.3, Def{to adorn oneself, dress up, use make-up}
5987 CJK UNIFIED IDEOGRAPH-#5987, IRGKangXi=0256.041, RSKangXi=38.3, Def{married women; woman; wife}
5988 CJK UNIFIED IDEOGRAPH-#5988, IRGKangXi=0256.041, RSKangXi=38.3, Def{mother, mama}
5989 CJK UNIFIED IDEOGRAPH-#5989, IRGKangXi=0256.050, RSKangXi=38.4
598A CJK UNIFIED IDEOGRAPH-#598A, IRGKangXi=0256.060, RSKangXi=38.4, Def{conceive, be pregnant}
598B CJK UNIFIED IDEOGRAPH-#598B, IRGKangXi=0256.070, RSKangXi=38.4
598C CJK UNIFIED IDEOGRAPH-#598C, IRGKangXi=0256.080, RSKangXi=38.4
598D CJK UNIFIED IDEOGRAPH-#598D, IRGKangXi=0256.090, RSKangXi=38.6, Def{beautiful, handsome; seductive}
598E CJK UNIFIED IDEOGRAPH-#598E, IRGKangXi=0256.100, RSKangXi=38.4
598F CJK UNIFIED IDEOGRAPH-#598F, IRGKangXi=0256.120, RSKangXi=38.4
5990 CJK UNIFIED IDEOGRAPH-#5990, IRGKangXi=0256.140, RSKangXi=38.4
5991 CJK UNIFIED IDEOGRAPH-#5991, IRGKangXi=0256.150, RSKangXi=38.4
5992 CJK UNIFIED IDEOGRAPH-#5992, IRGKangXi=0256.160, RSKangXi=38.4, Def{jealous, envious}
5993 CJK UNIFIED IDEOGRAPH-#5993, IRGKangXi=0256.170, RSKangXi=38.4, Def{prostitute}
5994 CJK UNIFIED IDEOGRAPH-#5994, IRGKangXi=0256.180, RSKangXi=38.4
5995 CJK UNIFIED IDEOGRAPH-#5995, IRGKangXi=0256.190, RSKangXi=38.4
5996 CJK UNIFIED IDEOGRAPH-#5996, IRGKangXi=0256.200, RSKangXi=38.4, Def{strange, weird, supernatural}
5997 CJK UNIFIED IDEOGRAPH-#5997, IRGKangXi=0256.210, RSKangXi=38.4, Def{wife of mother's brother}
5998 CJK UNIFIED IDEOGRAPH-#5998, IRGKangXi=0256.220, RSKangXi=38.4
5999 CJK UNIFIED IDEOGRAPH-#5999, IRGKangXi=0256.240, RSKangXi=38.4, Def{mysterious, subtle; exquisite}
599A CJK UNIFIED IDEOGRAPH-#599A, IRGKangXi=0256.260, RSKangXi=38.4
599B CJK UNIFIED IDEOGRAPH-#599B, IRGKangXi=0256.280, RSKangXi=46.4
599C CJK UNIFIED IDEOGRAPH-#599C, IRGKangXi=0256.290, RSKangXi=38.4
599D CJK UNIFIED IDEOGRAPH-#599D, IRGKangXi=0256.300, RSKangXi=38.4, Def{to adorn oneself, dress up, use make-up}
599E CJK UNIFIED IDEOGRAPH-#599E, IRGKangXi=0256.320, RSKangXi=38.4, Def{girl}
599F CJK UNIFIED IDEOGRAPH-#599F, IRGKangXi=0256.330, RSKangXi=38.4
59A0 CJK UNIFIED IDEOGRAPH-#59A0, IRGKangXi=0256.340, RSKangXi=38.4, Def{(Cant.) to collect, seize, grab}
59A1 CJK UNIFIED IDEOGRAPH-#59A1, IRGKangXi=0257.010, RSKangXi=38.4
59A2 CJK UNIFIED IDEOGRAPH-#59A2, IRGKangXi=0257.020, RSKangXi=38.4
59A3 CJK UNIFIED IDEOGRAPH-#59A3, IRGKangXi=0257.030, RSKangXi=38.4, Def{one's deceased mother}
59A4 CJK UNIFIED IDEOGRAPH-#59A4, IRGKangXi=0257.040, RSKangXi=38.4, Def{beautiful, fair, handsome}
59A5 CJK UNIFIED IDEOGRAPH-#59A5, IRGKangXi=0257.060, RSKangXi=38.4, Def{satisfactory, appropriate}
59A6 CJK UNIFIED IDEOGRAPH-#59A6, IRGKangXi=0257.070, RSKangXi=38.4
59A7 CJK UNIFIED IDEOGRAPH-#59A7, IRGKangXi=0257.080, RSKangXi=38.4
59A8 CJK UNIFIED IDEOGRAPH-#59A8, IRGKangXi=0257.100, RSKangXi=38.4, Def{interfere with, impede, obstruct}
59A9 CJK UNIFIED IDEOGRAPH-#59A9, IRGKangXi=0257.101, RSKangXi=38.4, Def{charming, enchanting}
59AA CJK UNIFIED IDEOGRAPH-#59AA, IRGKangXi=0257.101, RSKangXi=38.4, Def{old woman, hag}
59AB CJK UNIFIED IDEOGRAPH-#59AB, IRGKangXi=0257.101, RSKangXi=38.4, Def{family name}
59AC CJK UNIFIED IDEOGRAPH-#59AC, IRGKangXi=0257.120, RSKangXi=38.5, Def{jealous, envious}
59AD CJK UNIFIED IDEOGRAPH-#59AD, IRGKangXi=0257.130, RSKangXi=38.5
59AE CJK UNIFIED IDEOGRAPH-#59AE, IRGKangXi=0257.140, RSKangXi=38.5, Def{maid, servant girl; cute girl}
59AF CJK UNIFIED IDEOGRAPH-#59AF, IRGKangXi=0257.160, RSKangXi=38.5, Def{wives of one's brothers; sister-i}
59B0 CJK UNIFIED IDEOGRAPH-#59B0, IRGKangXi=0257.170, RSKangXi=38.5
59B1 CJK UNIFIED IDEOGRAPH-#59B1, IRGKangXi=0257.180, RSKangXi=38.5
59B2 CJK UNIFIED IDEOGRAPH-#59B2, IRGKangXi=0257.190, RSKangXi=38.5, Def{concubine of last ruler of the Shang dynasty}
59B3 CJK UNIFIED IDEOGRAPH-#59B3, IRGKangXi=0257.200, RSKangXi=38.5, Def{you (female)}
59B4 CJK UNIFIED IDEOGRAPH-#59B4, IRGKangXi=0257.210, RSKangXi=38.5
59B5 CJK UNIFIED IDEOGRAPH-#59B5, IRGKangXi=0257.230, RSKangXi=38.5, Def{person's name}
59B6 CJK UNIFIED IDEOGRAPH-#59B6, IRGKangXi=0257.240, RSKangXi=38.5
59B7 CJK UNIFIED IDEOGRAPH-#59B7, IRGKangXi=0257.250, RSKangXi=38.5
59B8 CJK UNIFIED IDEOGRAPH-#59B8, IRGKangXi=0257.270, RSKangXi=38.5, Def{person}
59B9 CJK UNIFIED IDEOGRAPH-#59B9, IRGKangXi=0257.280, RSKangXi=38.5, Def{younger sister}
59BA CJK UNIFIED IDEOGRAPH-#59BA, IRGKangXi=0257.290, RSKangXi=38.5, Def{wife of the last ruler of the Xia dynasty}
59BB CJK UNIFIED IDEOGRAPH-#59BB, IRGKangXi=0257.300, RSKangXi=38.5, Def{wife}
59BC CJK UNIFIED IDEOGRAPH-#59BC, IRGKangXi=0257.330, RSKangXi=38.5
59BD CJK UNIFIED IDEOGRAPH-#59BD, IRGKangXi=0257.350, RSKangXi=38.5
59BE CJK UNIFIED IDEOGRAPH-#59BE, IRGKangXi=0257.390, RSKangXi=38.5, Def{concubine}
59BF CJK UNIFIED IDEOGRAPH-#59BF, IRGKangXi=0257.400, RSKangXi=38.5
59C0 CJK UNIFIED IDEOGRAPH-#59C0, IRGKangXi=0258.010, RSKangXi=38.5
59C1 CJK UNIFIED IDEOGRAPH-#59C1, IRGKangXi=0258.020, RSKangXi=38.5, Def{beauty}
59C2 CJK UNIFIED IDEOGRAPH-#59C2, IRGKangXi=0258.030, RSKangXi=38.5
59C3 CJK UNIFIED IDEOGRAPH-#59C3, IRGKangXi=0258.040, RSKangXi=38.5
59C4 CJK UNIFIED IDEOGRAPH-#59C4, IRGKangXi=0258.050, RSKangXi=38.5
59C5 CJK UNIFIED IDEOGRAPH-#59C5, IRGKangXi=0258.070, RSKangXi=38.5, Def{woman at time of menstruation}
59C6 CJK UNIFIED IDEOGRAPH-#59C6, IRGKangXi=0258.090, RSKangXi=38.5, Def{child's governess; matron}
59C7 CJK UNIFIED IDEOGRAPH-#59C7, IRGKangXi=0258.110, RSKangXi=38.5
59C8 CJK UNIFIED IDEOGRAPH-#59C8, IRGKangXi=0258.130, RSKangXi=38.5
59C9 CJK UNIFIED IDEOGRAPH-#59C9, IRGKangXi=0258.140, RSKangXi=38.5, Def{elder sister}
59CA CJK UNIFIED IDEOGRAPH-#59CA, IRGKangXi=0258.150, RSKangXi=38.5, Def{elder sister}
59CB CJK UNIFIED IDEOGRAPH-#59CB, IRGKangXi=0258.160, RSKangXi=38.5, Def{begin, start; then, only then}
59CC CJK UNIFIED IDEOGRAPH-#59CC, IRGKangXi=0258.210, RSKangXi=38.5
59CD CJK UNIFIED IDEOGRAPH-#59CD, IRGKangXi=0258.230, RSKangXi=38.5, Def{slander; ridicule; proceed slowly}
59CE CJK UNIFIED IDEOGRAPH-#59CE, IRGKangXi=0258.250, RSKangXi=38.5
59CF CJK UNIFIED IDEOGRAPH-#59CF, IRGKangXi=0258.260, RSKangXi=38.5
59D0 CJK UNIFIED IDEOGRAPH-#59D0, IRGKangXi=0258.270, RSKangXi=38.5, Def{elder sister, young lady}
59D1 CJK UNIFIED IDEOGRAPH-#59D1, IRGKangXi=0258.320, RSKangXi=38.5, Def{father's sister; husband's mother}
59D2 CJK UNIFIED IDEOGRAPH-#59D2, IRGKangXi=0259.030, RSKangXi=38.5, Def{wife of elder brother}
59D3 CJK UNIFIED IDEOGRAPH-#59D3, IRGKangXi=0259.050, RSKangXi=38.5, Def{one's family name; clan, people}
59D4 CJK UNIFIED IDEOGRAPH-#59D4, IRGKangXi=0259.100, RSKangXi=38.5, Def{appoint, send, commission}
59D5 CJK UNIFIED IDEOGRAPH-#59D5, IRGKangXi=0259.120, RSKangXi=38.5
59D6 CJK UNIFIED IDEOGRAPH-#59D6, IRGKangXi=0259.140, RSKangXi=38.5
59D7 CJK UNIFIED IDEOGRAPH-#59D7, IRGKangXi=0259.151, RSKangXi=38.5, Def{slander; ridicule; proceed slowly}
59D8 CJK UNIFIED IDEOGRAPH-#59D8, IRGKangXi=0259.160, RSKangXi=38.6, Def{illicit sexual relations}
59D9 CJK UNIFIED IDEOGRAPH-#59D9, IRGKangXi=0259.170, RSKangXi=38.6, Def{conceive, be pregnant}
59DA CJK UNIFIED IDEOGRAPH-#59DA, IRGKangXi=0259.180, RSKangXi=38.6, Def{handsome, elegant; surname}
59DB CJK UNIFIED IDEOGRAPH-#59DB, IRGKangXi=0259.190, RSKangXi=38.6
59DC CJK UNIFIED IDEOGRAPH-#59DC, IRGKangXi=0259.200, RSKangXi=38.6, Def{surname; ginger}
59DD CJK UNIFIED IDEOGRAPH-#59DD, IRGKangXi=0259.210, RSKangXi=38.6, Def{a beautiful girl}
59DE CJK UNIFIED IDEOGRAPH-#59DE, IRGKangXi=0259.220, RSKangXi=38.6, Def{concubine}
59DF CJK UNIFIED IDEOGRAPH-#59DF, IRGKangXi=0260.010, RSKangXi=38.6
59E0 CJK UNIFIED IDEOGRAPH-#59E0, IRGKangXi=0260.020, RSKangXi=38.6
59E1 CJK UNIFIED IDEOGRAPH-#59E1, IRGKangXi=0260.040, RSKangXi=38.6
59E2 CJK UNIFIED IDEOGRAPH-#59E2, IRGKangXi=0260.050, Def{beautiful, graceful}
59E3 CJK UNIFIED IDEOGRAPH-#59E3, IRGKangXi=0260.060, RSKangXi=38.6, Def{beautiful, handsome, pretty}
59E4 CJK UNIFIED IDEOGRAPH-#59E4, IRGKangXi=0260.080, RSKangXi=38.6, Def{mate; copulate; good}
59E5 CJK UNIFIED IDEOGRAPH-#59E5, IRGKangXi=0260.090, RSKangXi=38.6, Def{maternal grandmother; midwife}
59E6 CJK UNIFIED IDEOGRAPH-#59E6, IRGKangXi=0260.100, RSKangXi=38.6, Def{adultery, debauchery; debauch}
59E7 CJK UNIFIED IDEOGRAPH-#59E7, IRGKangXi=0260.120, RSKangXi=38.6
59E8 CJK UNIFIED IDEOGRAPH-#59E8, IRGKangXi=0260.150, RSKangXi=38.6, Def{mother/wife's sister; concubine}
59E9 CJK UNIFIED IDEOGRAPH-#59E9, IRGKangXi=0260.180, RSKangXi=38.6, Def{(Cant.) breast}
59EA CJK UNIFIED IDEOGRAPH-#59EA, IRGKangXi=0260.190, RSKangXi=38.6, Def{niece}
59EB CJK UNIFIED IDEOGRAPH-#59EB, IRGKangXi=0260.220, RSKangXi=38.6, Def{beauty; imperial concubine}
59EC CJK UNIFIED IDEOGRAPH-#59EC, IRGKangXi=0260.230, RSKangXi=38.7, Def{beauty; imperial concubine}
59ED CJK UNIFIED IDEOGRAPH-#59ED, IRGKangXi=0260.250, RSKangXi=38.6
59EE CJK UNIFIED IDEOGRAPH-#59EE, IRGKangXi=0260.260, RSKangXi=38.6, Def{lady}
59EF CJK UNIFIED IDEOGRAPH-#59EF, IRGKangXi=0260.270, RSKangXi=38.6
59F0 CJK UNIFIED IDEOGRAPH-#59F0, IRGKangXi=0260.280, RSKangXi=38.6
59F1 CJK UNIFIED IDEOGRAPH-#59F1, IRGKangXi=0260.290, RSKangXi=38.6, Def{beautiful, handsome, elegant}
59F2 CJK UNIFIED IDEOGRAPH-#59F2, IRGKangXi=0261.010, RSKangXi=38.6
59F3 CJK UNIFIED IDEOGRAPH-#59F3, IRGKangXi=0261.020, RSKangXi=38.6
59F4 CJK UNIFIED IDEOGRAPH-#59F4, IRGKangXi=0261.040, RSKangXi=38.6
59F5 CJK UNIFIED IDEOGRAPH-#59F5, IRGKangXi=0261.060, RSKangXi=38.6
59F6 CJK UNIFIED IDEOGRAPH-#59F6, IRGKangXi=0261.070, RSKangXi=38.6
59F7 CJK UNIFIED IDEOGRAPH-#59F7, IRGKangXi=0261.090, RSKangXi=38.6
59F8 CJK UNIFIED IDEOGRAPH-#59F8, IRGKangXi=0261.130, RSKangXi=38.6, Def{beautiful}
59F9 CJK UNIFIED IDEOGRAPH-#59F9, IRGKangXi=0261.140, RSKangXi=38.6, Def{beautiful, colorful; girl}
59FA CJK UNIFIED IDEOGRAPH-#59FA, IRGKangXi=0261.150, RSKangXi=38.6, Def{name of an ancient state}
59FB CJK UNIFIED IDEOGRAPH-#59FB, IRGKangXi=0261.160, RSKangXi=38.6, Def{relatives by marriage}
59FC CJK UNIFIED IDEOGRAPH-#59FC, IRGKangXi=0261.180, RSKangXi=38.6
59FD CJK UNIFIED IDEOGRAPH-#59FD, IRGKangXi=0261.190, RSKangXi=38.6, Def{good}
59FE CJK UNIFIED IDEOGRAPH-#59FE, IRGKangXi=0261.200, RSKangXi=38.6
59FF CJK UNIFIED IDEOGRAPH-#59FF, IRGKangXi=0261.220, RSKangXi=38.6, Def{one's manner, carriage, bearing}
5A00 CJK UNIFIED IDEOGRAPH-#5A00, IRGKangXi=0261.230, RSKangXi=38.6, Def{name of a concubine of Di Ku, father of the mythical Yao}
5A01 CJK UNIFIED IDEOGRAPH-#5A01, IRGKangXi=0261.240, RSKangXi=38.6, Def{pomp, power; powerful; dominate}
5A02 CJK UNIFIED IDEOGRAPH-#5A02, IRGKangXi=0261.280, RSKangXi=38.6
5A03 CJK UNIFIED IDEOGRAPH-#5A03, IRGKangXi=0261.290, RSKangXi=38.6, Def{baby; doll; pretty girl}
5A04 CJK UNIFIED IDEOGRAPH-#5A04, IRGKangXi=0261.321, RSKangXi=38.6, Def{surname; a constellation; to wear}
5A05 CJK UNIFIED IDEOGRAPH-#5A05, IRGKangXi=0261.321, RSKangXi=38.6, Def{mutual term of address used by sons-in-law; a brother-in-law}
5A06 CJK UNIFIED IDEOGRAPH-#5A06, IRGKangXi=0261.321, RSKangXi=38.6, Def{graceful, charming, fascinating}
5A07 CJK UNIFIED IDEOGRAPH-#5A07, IRGKangXi=0261.321, RSKangXi=38.6, Def{seductive and loveable; tender}
5A08 CJK UNIFIED IDEOGRAPH-#5A08, IRGKangXi=0261.321, RSKangXi=38.6, Def{lovely, beautiful; docile, obedie}
5A09 CJK UNIFIED IDEOGRAPH-#5A09, IRGKangXi=0261.360, RSKangXi=38.7, Def{beautiful, attractive, charming, graceful}
5A0A CJK UNIFIED IDEOGRAPH-#5A0A, IRGKangXi=0261.370, RSKangXi=38.7
5A0B CJK UNIFIED IDEOGRAPH-#5A0B, IRGKangXi=0261.380, RSKangXi=38.7
5A0C CJK UNIFIED IDEOGRAPH-#5A0C, IRGKangXi=0261.410, RSKangXi=38.7, Def{brother's wife}
5A0D CJK UNIFIED IDEOGRAPH-#5A0D, IRGKangXi=0262.010, RSKangXi=38.7
5A0E CJK UNIFIED IDEOGRAPH-#5A0E, IRGKangXi=0262.020, RSKangXi=38.7
5A0F CJK UNIFIED IDEOGRAPH-#5A0F, IRGKangXi=0262.030, RSKangXi=38.7
5A10 CJK UNIFIED IDEOGRAPH-#5A10, IRGKangXi=0262.040, RSKangXi=38.7
5A11 CJK UNIFIED IDEOGRAPH-#5A11, IRGKangXi=0262.060, RSKangXi=38.7, Def{dance, frolic; lounge; saunter}
5A12 CJK UNIFIED IDEOGRAPH-#5A12, IRGKangXi=0262.080, RSKangXi=38.7, Def{matron}
5A13 CJK UNIFIED IDEOGRAPH-#5A13, IRGKangXi=0262.090, RSKangXi=38.7, Def{comply; complying, agreeable}
5A14 CJK UNIFIED IDEOGRAPH-#5A14, IRGKangXi=0262.100, RSKangXi=38.7
5A15 CJK UNIFIED IDEOGRAPH-#5A15, IRGKangXi=0262.130, RSKangXi=38.7
5A16 CJK UNIFIED IDEOGRAPH-#5A16, IRGKangXi=0262.140, RSKangXi=38.7
5A17 CJK UNIFIED IDEOGRAPH-#5A17, IRGKangXi=0262.150, RSKangXi=38.7
5A18 CJK UNIFIED IDEOGRAPH-#5A18, IRGKangXi=0262.160, RSKangXi=38.7, Def{mother; young girl; woman; wife}
5A19 CJK UNIFIED IDEOGRAPH-#5A19, IRGKangXi=0262.170, RSKangXi=38.7
5A1A CJK UNIFIED IDEOGRAPH-#5A1A, IRGKangXi=0262.180, RSKangXi=38.7
5A1B CJK UNIFIED IDEOGRAPH-#5A1B, IRGKangXi=0262.190, RSKangXi=38.7, Def{pleasure, enjoyment, amusement}
5A1C CJK UNIFIED IDEOGRAPH-#5A1C, IRGKangXi=0262.230, RSKangXi=38.7, Def{elegant, graceful, delicate}
5A1D CJK UNIFIED IDEOGRAPH-#5A1D, IRGKangXi=0262.270, RSKangXi=38.7
5A1E CJK UNIFIED IDEOGRAPH-#5A1E, IRGKangXi=0262.290, RSKangXi=38.7
5A1F CJK UNIFIED IDEOGRAPH-#5A1F, IRGKangXi=0262.330, RSKangXi=38.7, Def{beautiful, graceful}
5A20 CJK UNIFIED IDEOGRAPH-#5A20, IRGKangXi=0263.010, RSKangXi=38.7, Def{pregnant}
5A21 CJK UNIFIED IDEOGRAPH-#5A21, IRGKangXi=0263.040, RSKangXi=38.7
5A22 CJK UNIFIED IDEOGRAPH-#5A22, IRGKangXi=0263.060, RSKangXi=38.7
5A23 CJK UNIFIED IDEOGRAPH-#5A23, IRGKangXi=0263.080, RSKangXi=38.7, Def{younger sister, sister-in-law}
5A24 CJK UNIFIED IDEOGRAPH-#5A24, IRGKangXi=0263.090, RSKangXi=38.7
5A25 CJK UNIFIED IDEOGRAPH-#5A25, IRGKangXi=0263.100, RSKangXi=38.7, Def{be beautiful; good; surname}
5A26 CJK UNIFIED IDEOGRAPH-#5A26, IRGKangXi=0263.110, RSKangXi=38.7
5A27 CJK UNIFIED IDEOGRAPH-#5A27, IRGKangXi=0263.120, RSKangXi=38.7
5A28 CJK UNIFIED IDEOGRAPH-#5A28, IRGKangXi=0263.130, RSKangXi=38.7
5A29 CJK UNIFIED IDEOGRAPH-#5A29, IRGKangXi=0263.150, RSKangXi=38.7, Def{give birth child; complaisant}
5A2A CJK UNIFIED IDEOGRAPH-#5A2A, IRGKangXi=0263.160, RSKangXi=38.7
5A2B CJK UNIFIED IDEOGRAPH-#5A2B, IRGKangXi=0263.170, RSKangXi=38.7
5A2C CJK UNIFIED IDEOGRAPH-#5A2C, IRGKangXi=0263.180, RSKangXi=38.8, Def{lovely; attractive}
5A2D CJK UNIFIED IDEOGRAPH-#5A2D, IRGKangXi=0263.200, RSKangXi=38.7
5A2E CJK UNIFIED IDEOGRAPH-#5A2E, IRGKangXi=0263.220, RSKangXi=38.7
5A2F CJK UNIFIED IDEOGRAPH-#5A2F, IRGKangXi=0263.251, RSKangXi=38.7, Def{pleasure, enjoyment, amusement}
5A30 CJK UNIFIED IDEOGRAPH-#5A30, IRGKangXi=0263.251, RSKangXi=38.7
5A31 CJK UNIFIED IDEOGRAPH-#5A31, IRGKangXi=0263.251, RSKangXi=38.7, Def{pleasure, enjoyment, amusement}
5A32 CJK UNIFIED IDEOGRAPH-#5A32, IRGKangXi=0263.251, RSKangXi=38.7, Def{a goddess, the mythological sister and successor to Fuxi}
5A33 CJK UNIFIED IDEOGRAPH-#5A33, IRGKangXi=0263.251, RSKangXi=38.7
5A34 CJK UNIFIED IDEOGRAPH-#5A34, IRGKangXi=0263.251, RSKangXi=38.7, Def{elegant, refined; skillful}
5A35 CJK UNIFIED IDEOGRAPH-#5A35, IRGKangXi=0263.290, RSKangXi=38.8, Def{star}
5A36 CJK UNIFIED IDEOGRAPH-#5A36, IRGKangXi=0263.300, RSKangXi=38.8, Def{marry, take wife}
5A37 CJK UNIFIED IDEOGRAPH-#5A37, IRGKangXi=0263.320, RSKangXi=38.8
5A38 CJK UNIFIED IDEOGRAPH-#5A38, IRGKangXi=0263.330, RSKangXi=38.8, Def{ugly}
5A39 CJK UNIFIED IDEOGRAPH-#5A39, IRGKangXi=0263.340, RSKangXi=38.8
5A3A CJK UNIFIED IDEOGRAPH-#5A3A, IRGKangXi=0263.370, RSKangXi=38.8
5A3B CJK UNIFIED IDEOGRAPH-#5A3B, IRGKangXi=0263.390, RSKangXi=38.8
5A3C CJK UNIFIED IDEOGRAPH-#5A3C, IRGKangXi=0263.400, RSKangXi=38.8, Def{prostitute, harlot}
5A3D CJK UNIFIED IDEOGRAPH-#5A3D, IRGKangXi=0263.430, RSKangXi=38.7
5A3E CJK UNIFIED IDEOGRAPH-#5A3E, IRGKangXi=0263.450, RSKangXi=38.8
5A3F CJK UNIFIED IDEOGRAPH-#5A3F, IRGKangXi=0263.460, RSKangXi=38.8
5A40 CJK UNIFIED IDEOGRAPH-#5A40, IRGKangXi=0263.470, RSKangXi=38.8, Def{be beautiful, be graceful}
5A41 CJK UNIFIED IDEOGRAPH-#5A41, IRGKangXi=0263.480, RSKangXi=38.8, Def{surname; a constellation; to wear}
5A42 CJK UNIFIED IDEOGRAPH-#5A42, IRGKangXi=0264.020, RSKangXi=38.8
5A43 CJK UNIFIED IDEOGRAPH-#5A43, IRGKangXi=0264.030, RSKangXi=38.8
5A44 CJK UNIFIED IDEOGRAPH-#5A44, IRGKangXi=0264.040, RSKangXi=38.8, Def{(Cant.) soft, weak; to soak; unreliable}
5A45 CJK UNIFIED IDEOGRAPH-#5A45, IRGKangXi=0264.050, RSKangXi=38.8
5A46 CJK UNIFIED IDEOGRAPH-#5A46, IRGKangXi=0264.060, RSKangXi=38.8, Def{old woman; grandmother}
5A47 CJK UNIFIED IDEOGRAPH-#5A47, IRGKangXi=0264.080, RSKangXi=38.8
5A48 CJK UNIFIED IDEOGRAPH-#5A48, IRGKangXi=0264.110, RSKangXi=38.8
5A49 CJK UNIFIED IDEOGRAPH-#5A49, IRGKangXi=0264.120, RSKangXi=38.8, Def{amiable, congenial; restrained}
5A4A CJK UNIFIED IDEOGRAPH-#5A4A, IRGKangXi=0264.130, RSKangXi=38.8, Def{whore, prostitute}
5A4B CJK UNIFIED IDEOGRAPH-#5A4B, IRGKangXi=0264.140, RSKangXi=38.8
5A4C CJK UNIFIED IDEOGRAPH-#5A4C, IRGKangXi=0264.160, RSKangXi=38.8
5A4D CJK UNIFIED IDEOGRAPH-#5A4D, IRGKangXi=0264.170, RSKangXi=38.8
5A4E CJK UNIFIED IDEOGRAPH-#5A4E, IRGKangXi=0264.180, RSKangXi=38.8
5A4F CJK UNIFIED IDEOGRAPH-#5A4F, IRGKangXi=0264.190, RSKangXi=38.8
5A50 CJK UNIFIED IDEOGRAPH-#5A50, IRGKangXi=0264.200, RSKangXi=38.8, Def{maid}
5A51 CJK UNIFIED IDEOGRAPH-#5A51, IRGKangXi=0264.210, RSKangXi=38.8
5A52 CJK UNIFIED IDEOGRAPH-#5A52, IRGKangXi=0264.220, RSKangXi=38.8
5A53 CJK UNIFIED IDEOGRAPH-#5A53, IRGKangXi=0264.260, RSKangXi=38.8
5A54 CJK UNIFIED IDEOGRAPH-#5A54, IRGKangXi=0264.270, RSKangXi=38.8
5A55 CJK UNIFIED IDEOGRAPH-#5A55, IRGKangXi=0264.280, RSKangXi=38.8, Def{handsome}
5A56 CJK UNIFIED IDEOGRAPH-#5A56, IRGKangXi=0264.290, RSKangXi=38.8
5A57 CJK UNIFIED IDEOGRAPH-#5A57, IRGKangXi=0264.300, RSKangXi=38.8, Def{a new-born child the whimper of an infant}
5A58 CJK UNIFIED IDEOGRAPH-#5A58, IRGKangXi=0264.310, RSKangXi=38.8
5A59 CJK UNIFIED IDEOGRAPH-#5A59, IRGKangXi=0264.330, RSKangXi=38.8
5A5A CJK UNIFIED IDEOGRAPH-#5A5A, IRGKangXi=0264.340, RSKangXi=38.8, Def{get married; marriage, wedding}
5A5B CJK UNIFIED IDEOGRAPH-#5A5B, IRGKangXi=0265.020, RSKangXi=38.8
5A5C CJK UNIFIED IDEOGRAPH-#5A5C, IRGKangXi=0265.030, RSKangXi=38.8
5A5D CJK UNIFIED IDEOGRAPH-#5A5D, IRGKangXi=0265.040, RSKangXi=38.8
5A5E CJK UNIFIED IDEOGRAPH-#5A5E, IRGKangXi=0265.050, RSKangXi=38.8, Def{hate}
5A5F CJK UNIFIED IDEOGRAPH-#5A5F, IRGKangXi=0265.060, RSKangXi=38.8
5A60 CJK UNIFIED IDEOGRAPH-#5A60, IRGKangXi=0265.070, RSKangXi=38.8
5A61 CJK UNIFIED IDEOGRAPH-#5A61, IRGKangXi=0265.090, RSKangXi=38.8
5A62 CJK UNIFIED IDEOGRAPH-#5A62, IRGKangXi=0265.100, RSKangXi=38.8, Def{servant girl; your servant}
5A63 CJK UNIFIED IDEOGRAPH-#5A63, IRGKangXi=0265.110, RSKangXi=38.8, Def{marriage connections, a bride}
5A64 CJK UNIFIED IDEOGRAPH-#5A64, IRGKangXi=0265.120, RSKangXi=38.8, Def{lovely}
5A65 CJK UNIFIED IDEOGRAPH-#5A65, IRGKangXi=0265.130, RSKangXi=38.8, Def{beautiful}
5A66 CJK UNIFIED IDEOGRAPH-#5A66, IRGKangXi=0265.140, RSKangXi=38.8, Def{married women; woman; wife}
5A67 CJK UNIFIED IDEOGRAPH-#5A67, IRGKangXi=0265.160, RSKangXi=38.8, Def{modest; supple}
5A68 CJK UNIFIED IDEOGRAPH-#5A68, IRGKangXi=0265.170, RSKangXi=38.8
5A69 CJK UNIFIED IDEOGRAPH-#5A69, IRGKangXi=0265.180, RSKangXi=38.8
5A6A CJK UNIFIED IDEOGRAPH-#5A6A, IRGKangXi=0265.190, RSKangXi=38.8, Def{covet; covetous, avaricious}
5A6B CJK UNIFIED IDEOGRAPH-#5A6B, IRGKangXi=0265.200, RSKangXi=38.8
5A6C CJK UNIFIED IDEOGRAPH-#5A6C, IRGKangXi=0265.220, RSKangXi=38.8, Def{obscene, licentious, lewd}
5A6D CJK UNIFIED IDEOGRAPH-#5A6D, IRGKangXi=0265.230, RSKangXi=38.8, Def{mutual term of address used by sons-in-law; a brother-in-law}
5A6E CJK UNIFIED IDEOGRAPH-#5A6E, IRGKangXi=0265.250, RSKangXi=38.8
5A6F CJK UNIFIED IDEOGRAPH-#5A6F, IRGKangXi=0265.260, RSKangXi=38.8
5A70 CJK UNIFIED IDEOGRAPH-#5A70, IRGKangXi=0265.270, RSKangXi=38.8
5A71 CJK UNIFIED IDEOGRAPH-#5A71, IRGKangXi=0265.281, RSKangXi=38.8
5A72 CJK UNIFIED IDEOGRAPH-#5A72, IRGKangXi=0265.281, RSKangXi=38.8
5A73 CJK UNIFIED IDEOGRAPH-#5A73, IRGKangXi=0265.281, RSKangXi=38.7, Def{tranquil}
5A74 CJK UNIFIED IDEOGRAPH-#5A74, IRGKangXi=0265.281, RSKangXi=38.8, Def{baby, infant; bother}
5A75 CJK UNIFIED IDEOGRAPH-#5A75, IRGKangXi=0265.281, RSKangXi=38.8, Def{beautiful, lovely, pretty, graceful}
5A76 CJK UNIFIED IDEOGRAPH-#5A76, IRGKangXi=0265.281, RSKangXi=38.8, Def{wife of father's younger brother}
5A77 CJK UNIFIED IDEOGRAPH-#5A77, IRGKangXi=0265.290, RSKangXi=38.9, Def{pretty; attractive; graceful}
5A78 CJK UNIFIED IDEOGRAPH-#5A78, IRGKangXi=0265.300, RSKangXi=38.9
5A79 CJK UNIFIED IDEOGRAPH-#5A79, IRGKangXi=0265.320, RSKangXi=38.9
5A7A CJK UNIFIED IDEOGRAPH-#5A7A, IRGKangXi=0265.330, RSKangXi=38.9, Def{name of a star}
5A7B CJK UNIFIED IDEOGRAPH-#5A7B, IRGKangXi=0266.010, RSKangXi=38.9
5A7C CJK UNIFIED IDEOGRAPH-#5A7C, IRGKangXi=0266.030, RSKangXi=38.9, Def{person}
5A7D CJK UNIFIED IDEOGRAPH-#5A7D, IRGKangXi=0266.060, RSKangXi=38.9
5A7E CJK UNIFIED IDEOGRAPH-#5A7E, IRGKangXi=0266.080, RSKangXi=38.9, Def{handsome}
5A7F CJK UNIFIED IDEOGRAPH-#5A7F, IRGKangXi=0266.090, RSKangXi=38.9, Def{son-in-law; husband}
5A80 CJK UNIFIED IDEOGRAPH-#5A80, IRGKangXi=0266.100, RSKangXi=38.9
5A81 CJK UNIFIED IDEOGRAPH-#5A81, IRGKangXi=0266.120, RSKangXi=38.9
5A82 CJK UNIFIED IDEOGRAPH-#5A82, IRGKangXi=0266.140, RSKangXi=38.9
5A83 CJK UNIFIED IDEOGRAPH-#5A83, IRGKangXi=0266.160, RSKangXi=38.9
5A84 CJK UNIFIED IDEOGRAPH-#5A84, IRGKangXi=0266.170, RSKangXi=38.9, Def{beautiful}
5A85 CJK UNIFIED IDEOGRAPH-#5A85, IRGKangXi=0266.180, RSKangXi=38.9
5A86 CJK UNIFIED IDEOGRAPH-#5A86, IRGKangXi=0266.210, RSKangXi=38.9, Def{young, tender, soft, delicate}
5A87 CJK UNIFIED IDEOGRAPH-#5A87, IRGKangXi=0266.220, RSKangXi=38.9
5A88 CJK UNIFIED IDEOGRAPH-#5A88, IRGKangXi=0266.230, RSKangXi=38.9
5A89 CJK UNIFIED IDEOGRAPH-#5A89, IRGKangXi=0266.240, RSKangXi=38.9
5A8A CJK UNIFIED IDEOGRAPH-#5A8A, IRGKangXi=0266.250, RSKangXi=38.9, Def{star}
5A8B CJK UNIFIED IDEOGRAPH-#5A8B, IRGKangXi=0266.260, RSKangXi=38.9
5A8C CJK UNIFIED IDEOGRAPH-#5A8C, IRGKangXi=0266.270, RSKangXi=38.9
5A8D CJK UNIFIED IDEOGRAPH-#5A8D, IRGKangXi=0266.290, RSKangXi=38.9, Def{woman, wife}
5A8E CJK UNIFIED IDEOGRAPH-#5A8E, IRGKangXi=0266.300, RSKangXi=38.9
5A8F CJK UNIFIED IDEOGRAPH-#5A8F, IRGKangXi=0266.310, RSKangXi=38.9
5A90 CJK UNIFIED IDEOGRAPH-#5A90, IRGKangXi=0266.340, RSKangXi=38.10
5A91 CJK UNIFIED IDEOGRAPH-#5A91, IRGKangXi=0266.360, RSKangXi=38.9
5A92 CJK UNIFIED IDEOGRAPH-#5A92, IRGKangXi=0266.370, RSKangXi=38.9, Def{go-between, matchmaker; medium}
5A93 CJK UNIFIED IDEOGRAPH-#5A93, IRGKangXi=0266.390, RSKangXi=38.9
5A94 CJK UNIFIED IDEOGRAPH-#5A94, IRGKangXi=0266.400, RSKangXi=38.9
5A95 CJK UNIFIED IDEOGRAPH-#5A95, IRGKangXi=0266.440, RSKangXi=38.9, Def{undecided}
5A96 CJK UNIFIED IDEOGRAPH-#5A96, IRGKangXi=0267.010, RSKangXi=38.9, Def{beauty; beautiful}
5A97 CJK UNIFIED IDEOGRAPH-#5A97, IRGKangXi=0267.020, RSKangXi=38.9
5A98 CJK UNIFIED IDEOGRAPH-#5A98, IRGKangXi=0267.040, RSKangXi=38.9
5A99 CJK UNIFIED IDEOGRAPH-#5A99, IRGKangXi=0267.050, RSKangXi=38.9
5A9A CJK UNIFIED IDEOGRAPH-#5A9A, IRGKangXi=0267.070, RSKangXi=38.9, Def{charming, attractive; flatter}
5A9B CJK UNIFIED IDEOGRAPH-#5A9B, IRGKangXi=0267.110, RSKangXi=38.9, Def{beauty, beautiful woman}
5A9C CJK UNIFIED IDEOGRAPH-#5A9C, IRGKangXi=0267.140, RSKangXi=38.9
5A9D CJK UNIFIED IDEOGRAPH-#5A9D, IRGKangXi=0267.160, RSKangXi=38.9
5A9E CJK UNIFIED IDEOGRAPH-#5A9E, IRGKangXi=0267.170, RSKangXi=38.9, Def{at ease}
5A9F CJK UNIFIED IDEOGRAPH-#5A9F, IRGKangXi=0267.190, RSKangXi=38.9, Def{lust after, act indecently; lewd}
5AA0 CJK UNIFIED IDEOGRAPH-#5AA0, IRGKangXi=0267.200, RSKangXi=38.9
5AA1 CJK UNIFIED IDEOGRAPH-#5AA1, IRGKangXi=0267.210, RSKangXi=38.9
5AA2 CJK UNIFIED IDEOGRAPH-#5AA2, IRGKangXi=0267.220, RSKangXi=38.9, Def{be jealous of, be envious}
5AA3 CJK UNIFIED IDEOGRAPH-#5AA3, IRGKangXi=0267.230, RSKangXi=38.9
5AA4 CJK UNIFIED IDEOGRAPH-#5AA4, IRGKangXi=0267.240, RSKangXi=38.9, Def{husband's family}
5AA5 CJK UNIFIED IDEOGRAPH-#5AA5, IRGKangXi=0267.250, RSKangXi=38.9
5AA6 CJK UNIFIED IDEOGRAPH-#5AA6, IRGKangXi=0267.270, RSKangXi=38.9
5AA7 CJK UNIFIED IDEOGRAPH-#5AA7, IRGKangXi=0267.280, RSKangXi=38.9, Def{mythological snail goddess}
5AA8 CJK UNIFIED IDEOGRAPH-#5AA8, IRGKangXi=0267.350, RSKangXi=38.9
5AA9 CJK UNIFIED IDEOGRAPH-#5AA9, IRGKangXi=0267.361, RSKangXi=38.9
5AAA CJK UNIFIED IDEOGRAPH-#5AAA, IRGKangXi=0267.361, RSKangXi=38.9, Def{old woman; lower-class woman}
5AAB CJK UNIFIED IDEOGRAPH-#5AAB, IRGKangXi=0267.361, RSKangXi=38.9
5AAC CJK UNIFIED IDEOGRAPH-#5AAC, IRGKangXi=0267.361, RSKangXi=38.9, Def{governess; nurse}
5AAD CJK UNIFIED IDEOGRAPH-#5AAD, IRGKangXi=0267.361, RSKangXi=38.12
5AAE CJK UNIFIED IDEOGRAPH-#5AAE, IRGKangXi=0267.361, RSKangXi=38.9, Def{handsome, cheerful; steal}
5AAF CJK UNIFIED IDEOGRAPH-#5AAF, IRGKangXi=0267.361, RSKangXi=38.9, Def{family name}
5AB0 CJK UNIFIED IDEOGRAPH-#5AB0, IRGKangXi=0267.370, RSKangXi=38.10
5AB1 CJK UNIFIED IDEOGRAPH-#5AB1, IRGKangXi=0267.390, RSKangXi=38.10
5AB2 CJK UNIFIED IDEOGRAPH-#5AB2, IRGKangXi=0268.030, RSKangXi=38.10, Def{marry off, pair, match; compare}
5AB3 CJK UNIFIED IDEOGRAPH-#5AB3, IRGKangXi=0268.050, RSKangXi=38.10, Def{daughter-in-law}
5AB4 CJK UNIFIED IDEOGRAPH-#5AB4, IRGKangXi=0268.060, RSKangXi=38.10
5AB5 CJK UNIFIED IDEOGRAPH-#5AB5, IRGKangXi=0268.070, RSKangXi=38.10, Def{a maid who accompanies bride to her new home; to escort; a concubine}
5AB6 CJK UNIFIED IDEOGRAPH-#5AB6, IRGKangXi=0268.080, RSKangXi=38.10
5AB7 CJK UNIFIED IDEOGRAPH-#5AB7, IRGKangXi=0268.100, RSKangXi=38.10
5AB8 CJK UNIFIED IDEOGRAPH-#5AB8, IRGKangXi=0268.110, RSKangXi=38.10, Def{an ugly woman}
5AB9 CJK UNIFIED IDEOGRAPH-#5AB9, IRGKangXi=0268.120, RSKangXi=38.10
5ABA CJK UNIFIED IDEOGRAPH-#5ABA, IRGKangXi=0268.140, RSKangXi=38.10, Def{beautiful}
5ABB CJK UNIFIED IDEOGRAPH-#5ABB, IRGKangXi=0268.150, RSKangXi=38.10, Def{to move}
5ABC CJK UNIFIED IDEOGRAPH-#5ABC, IRGKangXi=0268.190, RSKangXi=38.10, Def{old woman; lower-class woman}
5ABD CJK UNIFIED IDEOGRAPH-#5ABD, IRGKangXi=0268.210, RSKangXi=38.10, Def{mother, mama}
5ABE CJK UNIFIED IDEOGRAPH-#5ABE, IRGKangXi=0268.280, RSKangXi=38.10, Def{marry; be on friendly terms with}
5ABF CJK UNIFIED IDEOGRAPH-#5ABF, IRGKangXi=0268.310, RSKangXi=38.10, Def{ashamed, conscience-stricken}
5AC0 CJK UNIFIED IDEOGRAPH-#5AC0, IRGKangXi=0268.320, RSKangXi=38.10
5AC1 CJK UNIFIED IDEOGRAPH-#5AC1, IRGKangXi=0268.330, RSKangXi=38.10, Def{to marry, give a daughter in marriage}
5AC2 CJK UNIFIED IDEOGRAPH-#5AC2, IRGKangXi=0268.340, RSKangXi=38.10, Def{sister-in-law, elder brother's wife}
5AC3 CJK UNIFIED IDEOGRAPH-#5AC3, IRGKangXi=0268.350, RSKangXi=38.10
5AC4 CJK UNIFIED IDEOGRAPH-#5AC4, IRGKangXi=0268.370, RSKangXi=38.10, Def{an ancient emperor's mother's name, Qiang Yuan, consort to Gu}
5AC5 CJK UNIFIED IDEOGRAPH-#5AC5, IRGKangXi=0268.380, RSKangXi=38.10
5AC6 CJK UNIFIED IDEOGRAPH-#5AC6, IRGKangXi=0268.390, RSKangXi=38.10
5AC7 CJK UNIFIED IDEOGRAPH-#5AC7, IRGKangXi=0268.400, RSKangXi=38.10
5AC8 CJK UNIFIED IDEOGRAPH-#5AC8, IRGKangXi=0269.010, RSKangXi=38.10, Def{lady}
5AC9 CJK UNIFIED IDEOGRAPH-#5AC9, IRGKangXi=0269.020, RSKangXi=38.10, Def{jealousy; be jealous of}
5ACA CJK UNIFIED IDEOGRAPH-#5ACA, IRGKangXi=0269.040, RSKangXi=38.10
5ACB CJK UNIFIED IDEOGRAPH-#5ACB, IRGKangXi=0269.050, RSKangXi=38.10, Def{slender and delicate}
5ACC CJK UNIFIED IDEOGRAPH-#5ACC, IRGKangXi=0269.090, RSKangXi=38.10, Def{hate, detest; suspect; criticize}
5ACD CJK UNIFIED IDEOGRAPH-#5ACD, IRGKangXi=0269.120, RSKangXi=38.10
5ACE CJK UNIFIED IDEOGRAPH-#5ACE, IRGKangXi=0269.150, RSKangXi=38.10
5ACF CJK UNIFIED IDEOGRAPH-#5ACF, IRGKangXi=0269.160, RSKangXi=38.9, Def{the place where the supreme stores his books; library}
5AD0 CJK UNIFIED IDEOGRAPH-#5AD0, IRGKangXi=0269.170, RSKangXi=38.10, Def{frolic, play with; flirt with}
5AD1 CJK UNIFIED IDEOGRAPH-#5AD1, IRGKangXi=0269.181, RSKangXi=38.10
5AD2 CJK UNIFIED IDEOGRAPH-#5AD2, IRGKangXi=0269.181, RSKangXi=38.10, Def{(your) daughter}
5AD3 CJK UNIFIED IDEOGRAPH-#5AD3, IRGKangXi=0269.181, RSKangXi=38.10
5AD4 CJK UNIFIED IDEOGRAPH-#5AD4, IRGKangXi=0269.181, RSKangXi=38.10, Def{court lady; palace maid}
5AD5 CJK UNIFIED IDEOGRAPH-#5AD5, IRGKangXi=0269.200, RSKangXi=38.11, Def{compliant, yielding; easy-going}
5AD6 CJK UNIFIED IDEOGRAPH-#5AD6, IRGKangXi=0269.210, RSKangXi=38.11, Def{patronize prostitutes, frequent}
5AD7 CJK UNIFIED IDEOGRAPH-#5AD7, IRGKangXi=0269.230, RSKangXi=38.11, Def{old woman, hag}
5AD8 CJK UNIFIED IDEOGRAPH-#5AD8, IRGKangXi=0269.240, RSKangXi=38.11, Def{surname}
5AD9 CJK UNIFIED IDEOGRAPH-#5AD9, IRGKangXi=0269.250, RSKangXi=38.11
5ADA CJK UNIFIED IDEOGRAPH-#5ADA, IRGKangXi=0269.260, RSKangXi=38.11, Def{scorn, despise; be rude, affront}
5ADB CJK UNIFIED IDEOGRAPH-#5ADB, IRGKangXi=0269.290, RSKangXi=38.11, Def{compliant, yielding; easy-going a newborn child}
5ADC CJK UNIFIED IDEOGRAPH-#5ADC, IRGKangXi=0269.310, RSKangXi=38.11
5ADD CJK UNIFIED IDEOGRAPH-#5ADD, IRGKangXi=0269.320, RSKangXi=38.11
5ADE CJK UNIFIED IDEOGRAPH-#5ADE, IRGKangXi=0269.330, RSKangXi=38.11
5ADF CJK UNIFIED IDEOGRAPH-#5ADF, IRGKangXi=0269.340, RSKangXi=38.11
5AE0 CJK UNIFIED IDEOGRAPH-#5AE0, IRGKangXi=0269.360, RSKangXi=38.11, Def{a widow}
5AE1 CJK UNIFIED IDEOGRAPH-#5AE1, IRGKangXi=0270.010, RSKangXi=38.11, Def{legal wife, child of legal wife}
5AE2 CJK UNIFIED IDEOGRAPH-#5AE2, IRGKangXi=0270.030, RSKangXi=38.11
5AE3 CJK UNIFIED IDEOGRAPH-#5AE3, IRGKangXi=0270.040, RSKangXi=38.11, Def{charming, fascinating; gay}
5AE4 CJK UNIFIED IDEOGRAPH-#5AE4, IRGKangXi=0270.050, RSKangXi=38.11
5AE5 CJK UNIFIED IDEOGRAPH-#5AE5, IRGKangXi=0270.070, RSKangXi=38.11
5AE6 CJK UNIFIED IDEOGRAPH-#5AE6, IRGKangXi=0270.080, RSKangXi=38.11, Def{name of a moon goddess}
5AE7 CJK UNIFIED IDEOGRAPH-#5AE7, IRGKangXi=0270.090, RSKangXi=38.11
5AE8 CJK UNIFIED IDEOGRAPH-#5AE8, IRGKangXi=0270.100, RSKangXi=38.11
5AE9 CJK UNIFIED IDEOGRAPH-#5AE9, IRGKangXi=0270.110, RSKangXi=38.11, Def{soft, tender, delicate; young}
5AEA CJK UNIFIED IDEOGRAPH-#5AEA, IRGKangXi=0270.130, RSKangXi=38.11, Def{hanker}
5AEB CJK UNIFIED IDEOGRAPH-#5AEB, IRGKangXi=0270.160, RSKangXi=38.11, Def{Huangdi's ugly concubine; nurse}
5AEC CJK UNIFIED IDEOGRAPH-#5AEC, IRGKangXi=0270.180, RSKangXi=38.11
5AED CJK UNIFIED IDEOGRAPH-#5AED, IRGKangXi=0270.220, RSKangXi=38.11
5AEE CJK UNIFIED IDEOGRAPH-#5AEE, IRGKangXi=0270.230, RSKangXi=38.11
5AEF CJK UNIFIED IDEOGRAPH-#5AEF, IRGKangXi=0270.240, RSKangXi=38.11
5AF0 CJK UNIFIED IDEOGRAPH-#5AF0, IRGKangXi=0270.311, RSKangXi=38.11, Def{tender, delicate, soft}
5AF1 CJK UNIFIED IDEOGRAPH-#5AF1, IRGKangXi=0270.311, RSKangXi=38.11, Def{lady}
5AF2 CJK UNIFIED IDEOGRAPH-#5AF2, IRGKangXi=0270.311, RSKangXi=38.11, Def{(Cant.) paternal grandmother}
5AF3 CJK UNIFIED IDEOGRAPH-#5AF3, IRGKangXi=0270.320, RSKangXi=38.12
5AF4 CJK UNIFIED IDEOGRAPH-#5AF4, IRGKangXi=0270.330, RSKangXi=38.12
5AF5 CJK UNIFIED IDEOGRAPH-#5AF5, IRGKangXi=0270.340, RSKangXi=38.12, Def{charming, enchanting}
5AF6 CJK UNIFIED IDEOGRAPH-#5AF6, IRGKangXi=0270.380, RSKangXi=38.12
5AF7 CJK UNIFIED IDEOGRAPH-#5AF7, IRGKangXi=0270.390, RSKangXi=38.12
5AF8 CJK UNIFIED IDEOGRAPH-#5AF8, IRGKangXi=0271.010, RSKangXi=38.12
5AF9 CJK UNIFIED IDEOGRAPH-#5AF9, IRGKangXi=0271.020, RSKangXi=38.12
5AFA CJK UNIFIED IDEOGRAPH-#5AFA, IRGKangXi=0271.030, RSKangXi=38.12, Def{refined, elegant, gracious}
5AFB CJK UNIFIED IDEOGRAPH-#5AFB, IRGKangXi=0271.040, RSKangXi=38.12, Def{elegant, refined; skillful}
5AFC CJK UNIFIED IDEOGRAPH-#5AFC, IRGKangXi=0271.050, RSKangXi=38.12
5AFD CJK UNIFIED IDEOGRAPH-#5AFD, IRGKangXi=0271.100, RSKangXi=38.12, Def{play with; (Cant.) to provoke}
5AFE CJK UNIFIED IDEOGRAPH-#5AFE, IRGKangXi=0271.110, RSKangXi=38.12
5AFF CJK UNIFIED IDEOGRAPH-#5AFF, IRGKangXi=0271.120, RSKangXi=38.12, Def{tranquil}
5B00 CJK UNIFIED IDEOGRAPH-#5B00, IRGKangXi=0271.130, RSKangXi=38.12, Def{name of a river in Shanxi; crafty}
5B01 CJK UNIFIED IDEOGRAPH-#5B01, IRGKangXi=0271.140, RSKangXi=38.12
5B02 CJK UNIFIED IDEOGRAPH-#5B02, IRGKangXi=0271.150, RSKangXi=38.12
5B03 CJK UNIFIED IDEOGRAPH-#5B03, IRGKangXi=0271.160, RSKangXi=38.12, Def{sister}
5B04 CJK UNIFIED IDEOGRAPH-#5B04, IRGKangXi=0271.190, RSKangXi=38.12
5B05 CJK UNIFIED IDEOGRAPH-#5B05, IRGKangXi=0271.220, RSKangXi=38.12, Def{beautiful; used in girls' names}
5B06 CJK UNIFIED IDEOGRAPH-#5B06, IRGKangXi=0271.240, RSKangXi=38.12
5B07 CJK UNIFIED IDEOGRAPH-#5B07, IRGKangXi=0271.250, RSKangXi=38.12
5B08 CJK UNIFIED IDEOGRAPH-#5B08, IRGKangXi=0271.260, RSKangXi=38.12, Def{graceful, charming, fascinating}
5B09 CJK UNIFIED IDEOGRAPH-#5B09, IRGKangXi=0271.280, RSKangXi=38.12, Def{enjoy; play, amuse oneself}
5B0A CJK UNIFIED IDEOGRAPH-#5B0A, IRGKangXi=0271.290, RSKangXi=38.12
5B0B CJK UNIFIED IDEOGRAPH-#5B0B, IRGKangXi=0271.300, RSKangXi=38.12, Def{beautiful, lovely, pretty, graceful}
5B0C CJK UNIFIED IDEOGRAPH-#5B0C, IRGKangXi=0271.310, RSKangXi=38.12, Def{seductive and loveable; tender}
5B0D CJK UNIFIED IDEOGRAPH-#5B0D, IRGKangXi=0271.330, RSKangXi=38.12
5B0E CJK UNIFIED IDEOGRAPH-#5B0E, IRGKangXi=0271.351, RSKangXi=38.12, Def{to bear multiple, identical, offspring}
5B0F CJK UNIFIED IDEOGRAPH-#5B0F, IRGKangXi=0271.351, RSKangXi=38.12
5B10 CJK UNIFIED IDEOGRAPH-#5B10, IRGKangXi=0272.010, RSKangXi=38.13
5B11 CJK UNIFIED IDEOGRAPH-#5B11, IRGKangXi=0272.020, RSKangXi=38.13
5B12 CJK UNIFIED IDEOGRAPH-#5B12, IRGKangXi=0272.030, RSKangXi=38.13
5B13 CJK UNIFIED IDEOGRAPH-#5B13, IRGKangXi=0272.040, RSKangXi=38.13, Def{used in names}
5B14 CJK UNIFIED IDEOGRAPH-#5B14, IRGKangXi=0272.050, RSKangXi=38.13, Def{baby rabbit}
5B15 CJK UNIFIED IDEOGRAPH-#5B15, IRGKangXi=0272.060, RSKangXi=38.13
5B16 CJK UNIFIED IDEOGRAPH-#5B16, IRGKangXi=0272.070, RSKangXi=38.13, Def{favorite; a minion}
5B17 CJK UNIFIED IDEOGRAPH-#5B17, IRGKangXi=0272.080, RSKangXi=38.13, Def{succession to the throne}
5B18 CJK UNIFIED IDEOGRAPH-#5B18, IRGKangXi=0272.090, RSKangXi=38.13
5B19 CJK UNIFIED IDEOGRAPH-#5B19, IRGKangXi=0272.130, RSKangXi=38.13, Def{lady}
5B1A CJK UNIFIED IDEOGRAPH-#5B1A, IRGKangXi=0272.150, RSKangXi=38.13
5B1B CJK UNIFIED IDEOGRAPH-#5B1B, IRGKangXi=0272.170, RSKangXi=38.13, Def{apt, clever; sycophant, flatterer}
5B1C CJK UNIFIED IDEOGRAPH-#5B1C, IRGKangXi=0272.200, RSKangXi=38.13
5B1D CJK UNIFIED IDEOGRAPH-#5B1D, IRGKangXi=0272.220, RSKangXi=38.13, Def{delicate; graceful}
5B1E CJK UNIFIED IDEOGRAPH-#5B1E, IRGKangXi=0272.251, RSKangXi=38.13
5B1F CJK UNIFIED IDEOGRAPH-#5B1F, IRGKangXi=0272.251, RSKangXi=38.13
5B20 CJK UNIFIED IDEOGRAPH-#5B20, IRGKangXi=0272.251, RSKangXi=38.13
5B21 CJK UNIFIED IDEOGRAPH-#5B21, IRGKangXi=0272.251, RSKangXi=38.13, Def{(your) daughter}
5B22 CJK UNIFIED IDEOGRAPH-#5B22, IRGKangXi=0272.251, RSKangXi=38.13, Def{troubled, oppressed; fat; mother}
5B23 CJK UNIFIED IDEOGRAPH-#5B23, IRGKangXi=0272.260, RSKangXi=38.14
5B24 CJK UNIFIED IDEOGRAPH-#5B24, IRGKangXi=0272.270, RSKangXi=38.14, Def{mother}
5B25 CJK UNIFIED IDEOGRAPH-#5B25, IRGKangXi=0272.310, RSKangXi=38.14
5B26 CJK UNIFIED IDEOGRAPH-#5B26, IRGKangXi=0272.320, RSKangXi=38.14
5B27 CJK UNIFIED IDEOGRAPH-#5B27, IRGKangXi=0272.330, RSKangXi=38.14
5B28 CJK UNIFIED IDEOGRAPH-#5B28, IRGKangXi=0272.340, RSKangXi=38.14
5B29 CJK UNIFIED IDEOGRAPH-#5B29, IRGKangXi=0272.350, RSKangXi=38.14
5B2A CJK UNIFIED IDEOGRAPH-#5B2A, IRGKangXi=0272.370, RSKangXi=38.14, Def{court lady; palace maid}
5B2B CJK UNIFIED IDEOGRAPH-#5B2B, IRGKangXi=0272.430, RSKangXi=38.14
5B2C CJK UNIFIED IDEOGRAPH-#5B2C, IRGKangXi=0272.440, RSKangXi=38.14, Def{mistress, concubine; weak}
5B2D CJK UNIFIED IDEOGRAPH-#5B2D, IRGKangXi=0272.470, RSKangXi=38.14, Def{milk; suckle; breasts}
5B2E CJK UNIFIED IDEOGRAPH-#5B2E, IRGKangXi=0273.010, RSKangXi=38.14
5B2F CJK UNIFIED IDEOGRAPH-#5B2F, IRGKangXi=0273.030, RSKangXi=38.14
5B30 CJK UNIFIED IDEOGRAPH-#5B30, IRGKangXi=0273.040, RSKangXi=38.14, Def{baby, infant; bother}
5B31 CJK UNIFIED IDEOGRAPH-#5B31, IRGKangXi=0273.060, RSKangXi=38.14
5B32 CJK UNIFIED IDEOGRAPH-#5B32, IRGKangXi=0273.070, RSKangXi=38.14, Def{frolic, play with; flirt with; (Cant.) angry}
5B33 CJK UNIFIED IDEOGRAPH-#5B33, IRGKangXi=0273.080, RSKangXi=38.14
5B34 CJK UNIFIED IDEOGRAPH-#5B34, IRGKangXi=0272.251, RSKangXi=38.14, Def{to win; to have a surplus; surname}
5B35 CJK UNIFIED IDEOGRAPH-#5B35, IRGKangXi=0273.130, RSKangXi=38.14
5B36 CJK UNIFIED IDEOGRAPH-#5B36, IRGKangXi=0273.171, RSKangXi=38.14, Def{a wife (vulgar)}
5B37 CJK UNIFIED IDEOGRAPH-#5B37, IRGKangXi=0273.171, RSKangXi=38.14, Def{mother}
5B38 CJK UNIFIED IDEOGRAPH-#5B38, IRGKangXi=0273.190, RSKangXi=38.15, Def{wife of father's younger brother}
5B39 CJK UNIFIED IDEOGRAPH-#5B39, IRGKangXi=0273.200, RSKangXi=38.16
5B3A CJK UNIFIED IDEOGRAPH-#5B3A, IRGKangXi=0273.210, RSKangXi=38.15
5B3B CJK UNIFIED IDEOGRAPH-#5B3B, IRGKangXi=0273.280, RSKangXi=38.15
5B3C CJK UNIFIED IDEOGRAPH-#5B3C, IRGKangXi=0273.300, RSKangXi=38.15
5B3D CJK UNIFIED IDEOGRAPH-#5B3D, IRGKangXi=0273.421, RSKangXi=38.15
5B3E CJK UNIFIED IDEOGRAPH-#5B3E, IRGKangXi=0273.360, RSKangXi=38.16, Def{lazy, languid, listless}
5B3F CJK UNIFIED IDEOGRAPH-#5B3F, IRGKangXi=0273.380, RSKangXi=38.16, Def{lovely}
5B40 CJK UNIFIED IDEOGRAPH-#5B40, IRGKangXi=0273.430, RSKangXi=38.17, Def{widow}
5B41 CJK UNIFIED IDEOGRAPH-#5B41, IRGKangXi=0274.020, RSKangXi=38.17
5B42 CJK UNIFIED IDEOGRAPH-#5B42, IRGKangXi=0274.050, RSKangXi=38.17
5B43 CJK UNIFIED IDEOGRAPH-#5B43, IRGKangXi=0274.070, RSKangXi=38.17, Def{troubled, oppressed; fat; mother}
5B44 CJK UNIFIED IDEOGRAPH-#5B44, IRGKangXi=0274.080, RSKangXi=38.17
5B45 CJK UNIFIED IDEOGRAPH-#5B45, IRGKangXi=0274.090, RSKangXi=38.17, Def{slender, thin; sharp-pointed}
5B46 CJK UNIFIED IDEOGRAPH-#5B46, IRGKangXi=0274.091, RSKangXi=38.17
5B47 CJK UNIFIED IDEOGRAPH-#5B47, IRGKangXi=0274.110, RSKangXi=38.18
5B48 CJK UNIFIED IDEOGRAPH-#5B48, IRGKangXi=0274.120, RSKangXi=38.18
5B49 CJK UNIFIED IDEOGRAPH-#5B49, IRGKangXi=0274.140, RSKangXi=38.18
5B4A CJK UNIFIED IDEOGRAPH-#5B4A, IRGKangXi=0274.210, RSKangXi=38.19
5B4B CJK UNIFIED IDEOGRAPH-#5B4B, IRGKangXi=0274.220, RSKangXi=38.19
5B4C CJK UNIFIED IDEOGRAPH-#5B4C, IRGKangXi=0274.230, RSKangXi=38.19, Def{lovely, beautiful; docile, obedient}
5B4D CJK UNIFIED IDEOGRAPH-#5B4D, IRGKangXi=0274.270, RSKangXi=38.20
5B4E CJK UNIFIED IDEOGRAPH-#5B4E, IRGKangXi=0274.300, RSKangXi=38.21
5B4F CJK UNIFIED IDEOGRAPH-#5B4F, IRGKangXi=0274.310, RSKangXi=38.21
5B50 CJK UNIFIED IDEOGRAPH-#5B50, IRGKangXi=0277.010, RSKangXi=39.0, Def{offspring, child; fruit, seed of; 1st terrestrial branch}
5B51 CJK UNIFIED IDEOGRAPH-#5B51, IRGKangXi=0277.070, RSKangXi=39.0, Def{remaining, left-over; lonely}
5B52 CJK UNIFIED IDEOGRAPH-#5B52, IRGKangXi=0277.080, RSKangXi=39.0, Def{larvae of the mosquito}
5B53 CJK UNIFIED IDEOGRAPH-#5B53, IRGKangXi=0277.081, RSKangXi=39.0, Def{beautiful}
5B54 CJK UNIFIED IDEOGRAPH-#5B54, IRGKangXi=0277.090, RSKangXi=39.1, Def{opening, hole, orifice; great}
5B55 CJK UNIFIED IDEOGRAPH-#5B55, IRGKangXi=0277.140, RSKangXi=39.2, Def{be pregnant, pregnancy}
5B56 CJK UNIFIED IDEOGRAPH-#5B56, IRGKangXi=0277.170, RSKangXi=39.3, Def{twins}
5B57 CJK UNIFIED IDEOGRAPH-#5B57, IRGKangXi=0277.180, RSKangXi=39.3, Def{letter, character, word}
5B58 CJK UNIFIED IDEOGRAPH-#5B58, IRGKangXi=0278.020, RSKangXi=39.3, Def{exist, live, be; survive; remain}
5B59 CJK UNIFIED IDEOGRAPH-#5B59, IRGKangXi=0278.041, RSKangXi=39.3, Def{grandchild, descendent; surname}
5B5A CJK UNIFIED IDEOGRAPH-#5B5A, IRGKangXi=0278.060, RSKangXi=39.4, Def{brood over eggs; have confidence}
5B5B CJK UNIFIED IDEOGRAPH-#5B5B, IRGKangXi=0278.080, RSKangXi=39.4, Def{comet}
5B5C CJK UNIFIED IDEOGRAPH-#5B5C, IRGKangXi=0278.100, RSKangXi=39.4, Def{be as diligent as possible}
5B5D CJK UNIFIED IDEOGRAPH-#5B5D, IRGKangXi=0278.110, RSKangXi=39.4, Def{filial piety, obedience; mourning}
5B5E CJK UNIFIED IDEOGRAPH-#5B5E, IRGKangXi=0278.151, RSKangXi=39.4
5B5F CJK UNIFIED IDEOGRAPH-#5B5F, IRGKangXi=0278.160, RSKangXi=39.5, Def{first in series; great, eminent}
5B60 CJK UNIFIED IDEOGRAPH-#5B60, IRGKangXi=0278.170, RSKangXi=39.5
5B61 CJK UNIFIED IDEOGRAPH-#5B61, IRGKangXi=0278.180, RSKangXi=39.5
5B62 CJK UNIFIED IDEOGRAPH-#5B62, IRGKangXi=0279.020, RSKangXi=39.5, Def{spore}
5B63 CJK UNIFIED IDEOGRAPH-#5B63, IRGKangXi=0279.030, RSKangXi=39.5, Def{quarter of year; season; surname}
5B64 CJK UNIFIED IDEOGRAPH-#5B64, IRGKangXi=0279.080, RSKangXi=39.5, Def{orphan, fatherless; solitary}
5B65 CJK UNIFIED IDEOGRAPH-#5B65, IRGKangXi=0279.090, RSKangXi=39.5, Def{one's children}
5B66 CJK UNIFIED IDEOGRAPH-#5B66, IRGKangXi=0279.121, RSKangXi=39.5, Def{learning, knowledge; school}
5B67 CJK UNIFIED IDEOGRAPH-#5B67, IRGKangXi=0279.121, RSKangXi=39.5
5B68 CJK UNIFIED IDEOGRAPH-#5B68, IRGKangXi=0279.140, RSKangXi=39.6
5B69 CJK UNIFIED IDEOGRAPH-#5B69, IRGKangXi=0279.150, RSKangXi=39.6, Def{baby, child; children}
5B6A CJK UNIFIED IDEOGRAPH-#5B6A, IRGKangXi=0279.191, RSKangXi=39.6, Def{twins}
5B6B CJK UNIFIED IDEOGRAPH-#5B6B, IRGKangXi=0279.230, RSKangXi=39.7, Def{grandchild, descendent; surname}
5B6C CJK UNIFIED IDEOGRAPH-#5B6C, IRGKangXi=0280.010, RSKangXi=39.7, Def{bad; cowardly}
5B6D CJK UNIFIED IDEOGRAPH-#5B6D, IRGKangXi=0280.021, RSKangXi=39.7, Def{(Cant.) to carry on the back}
5B6E CJK UNIFIED IDEOGRAPH-#5B6E, IRGKangXi=0280.030, RSKangXi=39.8
5B6F CJK UNIFIED IDEOGRAPH-#5B6F, IRGKangXi=0280.040, RSKangXi=39.8
5B70 CJK UNIFIED IDEOGRAPH-#5B70, IRGKangXi=0280.050, RSKangXi=39.8, Def{who? which? what? which one?}
5B71 CJK UNIFIED IDEOGRAPH-#5B71, IRGKangXi=0280.080, RSKangXi=39.9, Def{weak, unfit, frail, feeble}
5B72 CJK UNIFIED IDEOGRAPH-#5B72, IRGKangXi=0280.110, RSKangXi=39.9
5B73 CJK UNIFIED IDEOGRAPH-#5B73, IRGKangXi=0280.170, RSKangXi=39.10, Def{breed in large numbers}
5B74 CJK UNIFIED IDEOGRAPH-#5B74, IRGKangXi=0280.200, RSKangXi=39.10
5B75 CJK UNIFIED IDEOGRAPH-#5B75, IRGKangXi=0280.210, RSKangXi=39.11, Def{sit on eggs, hatch}
5B76 CJK UNIFIED IDEOGRAPH-#5B76, IRGKangXi=0280.211, RSKangXi=39.11, Def{variant of 孳 U+5B73, to breed in large numbers}
5B77 CJK UNIFIED IDEOGRAPH-#5B77, IRGKangXi=0280.220, RSKangXi=39.11
5B78 CJK UNIFIED IDEOGRAPH-#5B78, IRGKangXi=0280.280, RSKangXi=39.13, Def{learning, knowledge; school}
5B79 CJK UNIFIED IDEOGRAPH-#5B79, IRGKangXi=0281.011, RSKangXi=39.13
5B7A CJK UNIFIED IDEOGRAPH-#5B7A, IRGKangXi=0281.020, RSKangXi=39.14, Def{child; blood relation; affection}
5B7B CJK UNIFIED IDEOGRAPH-#5B7B, IRGKangXi=0281.030, RSKangXi=39.14, Def{last}
5B7C CJK UNIFIED IDEOGRAPH-#5B7C, IRGKangXi=0281.050, RSKangXi=39.16, Def{misfortune; sin, evil}
5B7D CJK UNIFIED IDEOGRAPH-#5B7D, IRGKangXi=0281.060, RSKangXi=39.17, Def{evil; son of concubine; ghost}
5B7E CJK UNIFIED IDEOGRAPH-#5B7E, IRGKangXi=0281.070, RSKangXi=39.17, Def{a baby, especially a girl, an infant}
5B7F CJK UNIFIED IDEOGRAPH-#5B7F, IRGKangXi=0281.090, RSKangXi=39.19, Def{twins}
5B80 CJK UNIFIED IDEOGRAPH-#5B80, IRGKangXi=0281.110, RSKangXi=40.0, Def{roof; KangXi radical 40}
5B81 CJK UNIFIED IDEOGRAPH-#5B81, IRGKangXi=0281.120, RSKangXi=40.2, Def{calm, peaceful, serene; healthy}
5B82 CJK UNIFIED IDEOGRAPH-#5B82, IRGKangXi=0281.130, RSKangXi=40.2, Def{scattered, mixed affairs; duties; occupation business}
5B83 CJK UNIFIED IDEOGRAPH-#5B83, IRGKangXi=0281.140, RSKangXi=40.2, Def{it; other}
5B84 CJK UNIFIED IDEOGRAPH-#5B84, IRGKangXi=0281.150, RSKangXi=40.2, Def{a traitor; a villain}
5B85 CJK UNIFIED IDEOGRAPH-#5B85, IRGKangXi=0281.200, RSKangXi=40.3, Def{residence, dwelling, home; grave}
5B86 CJK UNIFIED IDEOGRAPH-#5B86, IRGKangXi=0282.010, RSKangXi=40.3
5B87 CJK UNIFIED IDEOGRAPH-#5B87, IRGKangXi=0282.020, RSKangXi=40.3, Def{house; building, structure; eaves}
5B88 CJK UNIFIED IDEOGRAPH-#5B88, IRGKangXi=0282.050, RSKangXi=40.3, Def{defend, protect, guard, conserve}
5B89 CJK UNIFIED IDEOGRAPH-#5B89, IRGKangXi=0282.080, RSKangXi=40.3, Def{peaceful, tranquil, quiet}
5B8A CJK UNIFIED IDEOGRAPH-#5B8A, IRGKangXi=0282.110, RSKangXi=40.4
5B8B CJK UNIFIED IDEOGRAPH-#5B8B, IRGKangXi=0282.120, RSKangXi=40.4, Def{Song dynasty; surname}
5B8C CJK UNIFIED IDEOGRAPH-#5B8C, IRGKangXi=0282.130, RSKangXi=40.4, Def{complete, finish, settle; whole}
5B8D CJK UNIFIED IDEOGRAPH-#5B8D, IRGKangXi=0282.180, RSKangXi=40.4, Def{flesh; meat; KangXi radical 130}
5B8E CJK UNIFIED IDEOGRAPH-#5B8E, IRGKangXi=0282.190, RSKangXi=40.4
5B8F CJK UNIFIED IDEOGRAPH-#5B8F, IRGKangXi=0282.200, RSKangXi=40.4, Def{wide, spacious, great, vast}
5B90 CJK UNIFIED IDEOGRAPH-#5B90, IRGKangXi=0283.020, RSKangXi=40.4, Def{right, fitting, seemly}
5B91 CJK UNIFIED IDEOGRAPH-#5B91, IRGKangXi=0283.050, RSKangXi=40.4
5B92 CJK UNIFIED IDEOGRAPH-#5B92, IRGKangXi=0283.051, RSKangXi=40.4
5B93 CJK UNIFIED IDEOGRAPH-#5B93, IRGKangXi=0283.060, RSKangXi=40.5, Def{quiet, silent; in good health}
5B94 CJK UNIFIED IDEOGRAPH-#5B94, IRGKangXi=0283.100, RSKangXi=40.5
5B95 CJK UNIFIED IDEOGRAPH-#5B95, IRGKangXi=0283.110, RSKangXi=40.5, Def{stone quarry; cave dwelling}
5B96 CJK UNIFIED IDEOGRAPH-#5B96, IRGKangXi=0283.120, RSKangXi=40.5
5B97 CJK UNIFIED IDEOGRAPH-#5B97, IRGKangXi=0283.140, RSKangXi=40.5, Def{lineage, ancestry; ancestor, clan}
5B98 CJK UNIFIED IDEOGRAPH-#5B98, IRGKangXi=0283.150, RSKangXi=40.5, Def{official, public servant}
5B99 CJK UNIFIED IDEOGRAPH-#5B99, IRGKangXi=0283.170, RSKangXi=40.5, Def{time as concept; infinite time}
5B9A CJK UNIFIED IDEOGRAPH-#5B9A, IRGKangXi=0283.180, RSKangXi=40.5, Def{decide, settle, fix}
5B9B CJK UNIFIED IDEOGRAPH-#5B9B, IRGKangXi=0284.010, RSKangXi=40.5, Def{seem, as if, crooked}
5B9C CJK UNIFIED IDEOGRAPH-#5B9C, IRGKangXi=0284.030, RSKangXi=40.5, Def{suitable, right, fitting, proper}
5B9D CJK UNIFIED IDEOGRAPH-#5B9D, IRGKangXi=0284.081, RSKangXi=40.5, Def{treasure, jewel; precious, rare}
5B9E CJK UNIFIED IDEOGRAPH-#5B9E, IRGKangXi=0284.081, RSKangXi=40.5, Def{real, true; honest, sincere}
5B9F CJK UNIFIED IDEOGRAPH-#5B9F, IRGKangXi=0284.081, RSKangXi=40.5, Def{real, true; honest, sincere}
5BA0 CJK UNIFIED IDEOGRAPH-#5BA0, IRGKangXi=0284.081, RSKangXi=40.5, Def{favorite, concubine; favor}
5BA1 CJK UNIFIED IDEOGRAPH-#5BA1, IRGKangXi=0284.081, RSKangXi=40.5, Def{examine, investigate; judge}
5BA2 CJK UNIFIED IDEOGRAPH-#5BA2, IRGKangXi=0284.120, RSKangXi=40.6, Def{guest, traveller; customer}
5BA3 CJK UNIFIED IDEOGRAPH-#5BA3, IRGKangXi=0284.160, RSKangXi=40.6, Def{declare, announce, proclaim}
5BA4 CJK UNIFIED IDEOGRAPH-#5BA4, IRGKangXi=0285.020, RSKangXi=40.6, Def{room, home, house, chamber}
5BA5 CJK UNIFIED IDEOGRAPH-#5BA5, IRGKangXi=0285.030, RSKangXi=40.6, Def{forgive, pardon, indulge}
5BA6 CJK UNIFIED IDEOGRAPH-#5BA6, IRGKangXi=0285.040, RSKangXi=40.6, Def{officialdom, government official}
5BA7 CJK UNIFIED IDEOGRAPH-#5BA7, IRGKangXi=0285.050, RSKangXi=40.7, Def{corner}
5BA8 CJK UNIFIED IDEOGRAPH-#5BA8, IRGKangXi=0285.060, RSKangXi=40.6
5BA9 CJK UNIFIED IDEOGRAPH-#5BA9, IRGKangXi=0285.101, RSKangXi=40.6
5BAA CJK UNIFIED IDEOGRAPH-#5BAA, IRGKangXi=0285.101, RSKangXi=40.6, Def{constitution, statute, law}
5BAB CJK UNIFIED IDEOGRAPH-#5BAB, IRGKangXi=0285.101, RSKangXi=40.6, Def{palace}
5BAC CJK UNIFIED IDEOGRAPH-#5BAC, IRGKangXi=0285.110, RSKangXi=40.7, Def{archives; surname}
5BAD CJK UNIFIED IDEOGRAPH-#5BAD, IRGKangXi=0285.150, RSKangXi=40.7
5BAE CJK UNIFIED IDEOGRAPH-#5BAE, IRGKangXi=0285.160, RSKangXi=40.7, Def{palace, temple, dwelling, enclose}
5BAF CJK UNIFIED IDEOGRAPH-#5BAF, IRGKangXi=0286.020, RSKangXi=40.7
5BB0 CJK UNIFIED IDEOGRAPH-#5BB0, IRGKangXi=0286.040, RSKangXi=40.7, Def{to slaughter; to rule}
5BB1 CJK UNIFIED IDEOGRAPH-#5BB1, IRGKangXi=0286.090, RSKangXi=40.7
5BB2 CJK UNIFIED IDEOGRAPH-#5BB2, IRGKangXi=0286.110, RSKangXi=40.7
5BB3 CJK UNIFIED IDEOGRAPH-#5BB3, IRGKangXi=0286.120, RSKangXi=40.7, Def{injure, harm; destroy, kill}
5BB4 CJK UNIFIED IDEOGRAPH-#5BB4, IRGKangXi=0286.130, RSKangXi=40.7, Def{to entertain, feast; a feast, banquet}
5BB5 CJK UNIFIED IDEOGRAPH-#5BB5, IRGKangXi=0286.150, RSKangXi=40.7, Def{night, evening, dark}
5BB6 CJK UNIFIED IDEOGRAPH-#5BB6, IRGKangXi=0286.170, RSKangXi=40.7, Def{house, home, residence; family}
5BB7 CJK UNIFIED IDEOGRAPH-#5BB7, IRGKangXi=0287.010, RSKangXi=40.7
5BB8 CJK UNIFIED IDEOGRAPH-#5BB8, IRGKangXi=0287.020, RSKangXi=40.7, Def{imperial; imperial palace}
5BB9 CJK UNIFIED IDEOGRAPH-#5BB9, IRGKangXi=0287.030, RSKangXi=40.7, Def{looks, appearance; figure, form}
5BBA CJK UNIFIED IDEOGRAPH-#5BBA, IRGKangXi=0287.101, RSKangXi=40.7
5BBB CJK UNIFIED IDEOGRAPH-#5BBB, IRGKangXi=0287.101, Def{dense, thick, close; intimate}
5BBC CJK UNIFIED IDEOGRAPH-#5BBC, IRGKangXi=0287.101, RSKangXi=40.7, Def{tyrannical, cruel; to rob to plunder; bandits, thieves, highwaymen}
5BBD CJK UNIFIED IDEOGRAPH-#5BBD, IRGKangXi=0287.101, RSKangXi=40.7, Def{broad, wide; spacious, vast}
5BBE CJK UNIFIED IDEOGRAPH-#5BBE, IRGKangXi=0287.101, RSKangXi=40.7, Def{guest, visitor; surname; submit}
5BBF CJK UNIFIED IDEOGRAPH-#5BBF, IRGKangXi=0287.130, RSKangXi=40.8, Def{stop, rest, lodge, stay overnight; constellation}
5BC0 CJK UNIFIED IDEOGRAPH-#5BC0, IRGKangXi=0287.180, RSKangXi=40.8, Def{feudal estate}
5BC1 CJK UNIFIED IDEOGRAPH-#5BC1, IRGKangXi=0287.190, RSKangXi=40.8, Def{quick, fast}
5BC2 CJK UNIFIED IDEOGRAPH-#5BC2, IRGKangXi=0288.010, RSKangXi=40.8, Def{still, silent, quiet, desolate}
5BC3 CJK UNIFIED IDEOGRAPH-#5BC3, IRGKangXi=0288.030, RSKangXi=40.8, Def{grievance, injustice, wrong}
5BC4 CJK UNIFIED IDEOGRAPH-#5BC4, IRGKangXi=0288.040, RSKangXi=40.8, Def{send, transmit, mail; rely on}
5BC5 CJK UNIFIED IDEOGRAPH-#5BC5, IRGKangXi=0288.050, RSKangXi=40.8, Def{to respect, reverence; respectfully; 3rd terrestrial branch}
5BC6 CJK UNIFIED IDEOGRAPH-#5BC6, IRGKangXi=0288.110, RSKangXi=40.8, Def{dense, thick, close; intimate}
5BC7 CJK UNIFIED IDEOGRAPH-#5BC7, IRGKangXi=0288.150, RSKangXi=40.8, Def{bandits, thieves; enemy; invade}
5BC8 CJK UNIFIED IDEOGRAPH-#5BC8, IRGKangXi=0288.170, RSKangXi=40.8
5BC9 CJK UNIFIED IDEOGRAPH-#5BC9, IRGKangXi=0288.201, RSKangXi=40.8
5BCA CJK UNIFIED IDEOGRAPH-#5BCA, IRGKangXi=0288.210, RSKangXi=40.9
5BCB CJK UNIFIED IDEOGRAPH-#5BCB, IRGKangXi=0288.230, RSKangXi=40.9
5BCC CJK UNIFIED IDEOGRAPH-#5BCC, IRGKangXi=0288.270, RSKangXi=40.9, Def{abundant, ample; rich, wealthy}
5BCD CJK UNIFIED IDEOGRAPH-#5BCD, IRGKangXi=0289.020, RSKangXi=40.9, Def{used as a term of comparison:-rather; it is better; would that}
5BCE CJK UNIFIED IDEOGRAPH-#5BCE, IRGKangXi=0289.030, RSKangXi=40.9, Def{drowsy}
5BCF CJK UNIFIED IDEOGRAPH-#5BCF, IRGKangXi=0289.040, RSKangXi=40.9
5BD0 CJK UNIFIED IDEOGRAPH-#5BD0, IRGKangXi=0289.060, RSKangXi=40.9, Def{sleep; be asleep}
5BD1 CJK UNIFIED IDEOGRAPH-#5BD1, IRGKangXi=0289.080, RSKangXi=40.9
5BD2 CJK UNIFIED IDEOGRAPH-#5BD2, IRGKangXi=0289.090, RSKangXi=40.9, Def{cold, wintry, chilly}
5BD3 CJK UNIFIED IDEOGRAPH-#5BD3, IRGKangXi=0289.150, RSKangXi=40.9, Def{residence; lodge; dwell}
5BD4 CJK UNIFIED IDEOGRAPH-#5BD4, IRGKangXi=0289.160, RSKangXi=40.9, Def{real, true, solid, honest}
5BD5 CJK UNIFIED IDEOGRAPH-#5BD5, IRGKangXi=0289.211, Def{repose, serenity, peace; peaceful}
5BD6 CJK UNIFIED IDEOGRAPH-#5BD6, IRGKangXi=0289.230, RSKangXi=40.10, Def{gradually, step by step, little}
5BD7 CJK UNIFIED IDEOGRAPH-#5BD7, IRGKangXi=0289.250, RSKangXi=40.10, Def{a surname; peaceful; rather}
5BD8 CJK UNIFIED IDEOGRAPH-#5BD8, IRGKangXi=0289.270, RSKangXi=40.10, Def{put aside, put down; discard}
5BD9 CJK UNIFIED IDEOGRAPH-#5BD9, IRGKangXi=0289.300, RSKangXi=40.10
5BDA CJK UNIFIED IDEOGRAPH-#5BDA, IRGKangXi=0290.050, RSKangXi=40.10, Def{precious; rear; valuable treasure; bullion a jewel}
5BDB CJK UNIFIED IDEOGRAPH-#5BDB, IRGKangXi=0290.121, RSKangXi=40.10, Def{broad}
5BDC CJK UNIFIED IDEOGRAPH-#5BDC, IRGKangXi=0290.121, Def{repose, serenity, peace; peaceful}
5BDD CJK UNIFIED IDEOGRAPH-#5BDD, IRGKangXi=0290.121, RSKangXi=40.10, Def{sleep, rest; bed chamber}
5BDE CJK UNIFIED IDEOGRAPH-#5BDE, IRGKangXi=0290.150, RSKangXi=40.11, Def{silent, still, lonely, solitary}
5BDF CJK UNIFIED IDEOGRAPH-#5BDF, IRGKangXi=0290.160, RSKangXi=40.11, Def{examine, investigate; notice}
5BE0 CJK UNIFIED IDEOGRAPH-#5BE0, IRGKangXi=0290.180, RSKangXi=40.11, Def{poor, impoverished}
5BE1 CJK UNIFIED IDEOGRAPH-#5BE1, IRGKangXi=0290.190, RSKangXi=40.11, Def{widowed; alone, friendless}
5BE2 CJK UNIFIED IDEOGRAPH-#5BE2, IRGKangXi=0290.220, RSKangXi=40.11, Def{sleep, rest; bed chamber}
5BE3 CJK UNIFIED IDEOGRAPH-#5BE3, IRGKangXi=0290.260, RSKangXi=40.11
5BE4 CJK UNIFIED IDEOGRAPH-#5BE4, IRGKangXi=0291.010, RSKangXi=40.11, Def{few, scarce; empty, deserted}
5BE5 CJK UNIFIED IDEOGRAPH-#5BE5, IRGKangXi=0291.020, RSKangXi=40.11, Def{few, scarce; empty, deserted}
5BE6 CJK UNIFIED IDEOGRAPH-#5BE6, IRGKangXi=0291.040, RSKangXi=40.11, Def{real, true, solid, honest}
5BE7 CJK UNIFIED IDEOGRAPH-#5BE7, IRGKangXi=0291.080, RSKangXi=40.11, Def{repose, serenity, peace; peaceful}
5BE8 CJK UNIFIED IDEOGRAPH-#5BE8, IRGKangXi=0291.110, RSKangXi=40.11, Def{stockade, stronghold, outpost; brothel}
5BE9 CJK UNIFIED IDEOGRAPH-#5BE9, IRGKangXi=0291.220, RSKangXi=40.12, Def{examine, investigate; judge}
5BEA CJK UNIFIED IDEOGRAPH-#5BEA, IRGKangXi=0292.030, RSKangXi=40.9, Def{surname}
5BEB CJK UNIFIED IDEOGRAPH-#5BEB, IRGKangXi=0292.040, RSKangXi=40.12, Def{write; draw, sketch; compose}
5BEC CJK UNIFIED IDEOGRAPH-#5BEC, IRGKangXi=0292.060, RSKangXi=40.12, Def{broad, wide; spacious, vast}
5BED CJK UNIFIED IDEOGRAPH-#5BED, IRGKangXi=0292.090, RSKangXi=40.12
5BEE CJK UNIFIED IDEOGRAPH-#5BEE, IRGKangXi=0292.100, RSKangXi=40.12, Def{shanty, hut, shack}
5BEF CJK UNIFIED IDEOGRAPH-#5BEF, IRGKangXi=0292.160, RSKangXi=40.13
5BF0 CJK UNIFIED IDEOGRAPH-#5BF0, IRGKangXi=0292.170, RSKangXi=40.13, Def{great domain, country, world}
5BF1 CJK UNIFIED IDEOGRAPH-#5BF1, IRGKangXi=0292.240, RSKangXi=40.14
5BF2 CJK UNIFIED IDEOGRAPH-#5BF2, IRGKangXi=0292.250, RSKangXi=40.14
5BF3 CJK UNIFIED IDEOGRAPH-#5BF3, IRGKangXi=0293.050, RSKangXi=40.16, Def{treasure, jewel; precious, rare}
5BF4 CJK UNIFIED IDEOGRAPH-#5BF4, IRGKangXi=0293.060, RSKangXi=40.16
5BF5 CJK UNIFIED IDEOGRAPH-#5BF5, IRGKangXi=0293.070, RSKangXi=40.16, Def{favorite, concubine; favor}
5BF6 CJK UNIFIED IDEOGRAPH-#5BF6, IRGKangXi=0293.120, RSKangXi=40.17, Def{treasure, jewel; precious, rare}
5BF7 CJK UNIFIED IDEOGRAPH-#5BF7, IRGKangXi=0293.160, RSKangXi=40.18
5BF8 CJK UNIFIED IDEOGRAPH-#5BF8, IRGKangXi=0293.320, RSKangXi=41.0, Def{inch; small, tiny; KangXi radical 41}
5BF9 CJK UNIFIED IDEOGRAPH-#5BF9, IRGKangXi=0293.321, RSKangXi=41.2, Def{correct, right; facing, opposed}
5BFA CJK UNIFIED IDEOGRAPH-#5BFA, IRGKangXi=0293.330, RSKangXi=41.3, Def{court, office; temple, monastery}
5BFB CJK UNIFIED IDEOGRAPH-#5BFB, IRGKangXi=0293.331, RSKangXi=58.3, Def{seek, search, look for; ancient}
5BFC CJK UNIFIED IDEOGRAPH-#5BFC, IRGKangXi=0293.331, RSKangXi=41.3, Def{direct, guide, lead, conduct}
5BFD CJK UNIFIED IDEOGRAPH-#5BFD, IRGKangXi=0294.010, RSKangXi=41.4, Def{a handful; a pinch}
5BFE CJK UNIFIED IDEOGRAPH-#5BFE, IRGKangXi=0294.021, RSKangXi=41.4, Def{correct, right; facing, opposed}
5BFF CJK UNIFIED IDEOGRAPH-#5BFF, IRGKangXi=0294.021, RSKangXi=41.4, Def{old age, long life; lifespan}
5C00 CJK UNIFIED IDEOGRAPH-#5C00, IRGKangXi=0294.050, RSKangXi=41.5, Def{cannot; thereupon}
5C01 CJK UNIFIED IDEOGRAPH-#5C01, IRGKangXi=0294.070, RSKangXi=41.6, Def{letter, envelope; feudal}
5C02 CJK UNIFIED IDEOGRAPH-#5C02, IRGKangXi=0294.111, RSKangXi=41.6, Def{monopolize, take sole possession}
5C03 CJK UNIFIED IDEOGRAPH-#5C03, IRGKangXi=0294.120, RSKangXi=41.7, Def{to state to, to announce}
5C04 CJK UNIFIED IDEOGRAPH-#5C04, IRGKangXi=0294.130, RSKangXi=41.7, Def{shoot, eject, issue forth, emit}
5C05 CJK UNIFIED IDEOGRAPH-#5C05, IRGKangXi=0294.140, RSKangXi=41.7, Def{subdue, destroy, overcome}
5C06 CJK UNIFIED IDEOGRAPH-#5C06, IRGKangXi=0294.111, RSKangXi=90.6, Def{will, going to, future; general}
5C07 CJK UNIFIED IDEOGRAPH-#5C07, IRGKangXi=0294.160, RSKangXi=41.8, Def{will, going to, future; general}
5C08 CJK UNIFIED IDEOGRAPH-#5C08, IRGKangXi=0295.010, RSKangXi=41.8, Def{monopolize, take sole possession}
5C09 CJK UNIFIED IDEOGRAPH-#5C09, IRGKangXi=0295.050, RSKangXi=41.8, Def{officer, military rank}
5C0A CJK UNIFIED IDEOGRAPH-#5C0A, IRGKangXi=0295.100, RSKangXi=41.9, Def{respect, revere, venerate; honor}
5C0B CJK UNIFIED IDEOGRAPH-#5C0B, IRGKangXi=0295.120, RSKangXi=41.9, Def{seek, search, look for; ancient}
5C0C CJK UNIFIED IDEOGRAPH-#5C0C, IRGKangXi=0295.140, RSKangXi=41.9, Def{standing (something) up}
5C0D CJK UNIFIED IDEOGRAPH-#5C0D, IRGKangXi=0296.070, RSKangXi=41.11, Def{correct, right; facing, opposed}
5C0E CJK UNIFIED IDEOGRAPH-#5C0E, IRGKangXi=0296.100, RSKangXi=41.12, Def{direct, guide, lead, conduct}
5C0F CJK UNIFIED IDEOGRAPH-#5C0F, IRGKangXi=0296.180, RSKangXi=42.0, Def{small, tiny, insignificant}
5C10 CJK UNIFIED IDEOGRAPH-#5C10, IRGKangXi=0296.190, RSKangXi=42.1
5C11 CJK UNIFIED IDEOGRAPH-#5C11, IRGKangXi=0296.200, RSKangXi=42.1, Def{few, less, inadequate}
5C12 CJK UNIFIED IDEOGRAPH-#5C12, IRGKangXi=0297.011, RSKangXi=42.2, Def{you, your}
5C13 CJK UNIFIED IDEOGRAPH-#5C13, IRGKangXi=0297.010, RSKangXi=42.2, Def{you; that}
5C14 CJK UNIFIED IDEOGRAPH-#5C14, IRGKangXi=0297.011, RSKangXi=42.2, Def{you; that, those; final particle}
5C15 CJK UNIFIED IDEOGRAPH-#5C15, IRGKangXi=0297.011, RSKangXi=42.2, Def{small (used in place names)}
5C16 CJK UNIFIED IDEOGRAPH-#5C16, IRGKangXi=0297.020, RSKangXi=42.3, Def{sharp, pointed, acute, keen}
5C17 CJK UNIFIED IDEOGRAPH-#5C17, IRGKangXi=0297.050, RSKangXi=42.3, Def{younger of brothers; father's younger brother younger brother of a husband}
5C18 CJK UNIFIED IDEOGRAPH-#5C18, IRGKangXi=0297.060, RSKangXi=42.3, Def{dust, dirt, ashes, cinders}
5C19 CJK UNIFIED IDEOGRAPH-#5C19, IRGKangXi=0297.110, RSKangXi=42.5, Def{still, yet; even; fairly, rather}
5C1A CJK UNIFIED IDEOGRAPH-#5C1A, IRGKangXi=0297.121, RSKangXi=42.5, Def{still, yet; even; fairly, rather}
5C1B CJK UNIFIED IDEOGRAPH-#5C1B, IRGKangXi=0297.140, RSKangXi=42.6
5C1C CJK UNIFIED IDEOGRAPH-#5C1C, IRGKangXi=0297.151, RSKangXi=42.6, Def{a child toy}
5C1D CJK UNIFIED IDEOGRAPH-#5C1D, IRGKangXi=0297.151, RSKangXi=42.6, Def{taste; experience, experiment}
5C1E CJK UNIFIED IDEOGRAPH-#5C1E, IRGKangXi=0297.240, RSKangXi=42.9, Def{fuel used for sacrifices}
5C1F CJK UNIFIED IDEOGRAPH-#5C1F, IRGKangXi=0297.260, RSKangXi=42.10, Def{surname; fresh}
5C20 CJK UNIFIED IDEOGRAPH-#5C20, IRGKangXi=0297.270, RSKangXi=42.10, Def{very few; seldom, rarely}
5C21 CJK UNIFIED IDEOGRAPH-#5C21, IRGKangXi=0125.251, RSKangXi=72.10
5C22 CJK UNIFIED IDEOGRAPH-#5C22, IRGKangXi=0298.020, RSKangXi=43.0, Def{weak; KangXi radical 43}
5C23 CJK UNIFIED IDEOGRAPH-#5C23, IRGKangXi=0298.021, RSKangXi=43.0, Def{lame; the first form is Radical 43}
5C24 CJK UNIFIED IDEOGRAPH-#5C24, IRGKangXi=0298.030, RSKangXi=43.1, Def{especially, particularly}
5C25 CJK UNIFIED IDEOGRAPH-#5C25, IRGKangXi=0298.060, RSKangXi=43.3
5C26 CJK UNIFIED IDEOGRAPH-#5C26, IRGKangXi=0298.080, RSKangXi=43.3
5C27 CJK UNIFIED IDEOGRAPH-#5C27, IRGKangXi=0298.081, RSKangXi=10.4, Def{a legendary ancient emperor-sage}
5C28 CJK UNIFIED IDEOGRAPH-#5C28, IRGKangXi=0298.090, RSKangXi=43.4, Def{shaggy haired dog; variegated}
5C29 CJK UNIFIED IDEOGRAPH-#5C29, IRGKangXi=0298.120, RSKangXi=43.4, Def{weak; a rickety person; emaciated}
5C2A CJK UNIFIED IDEOGRAPH-#5C2A, IRGKangXi=0298.130, RSKangXi=43.4, Def{lame}
5C2B CJK UNIFIED IDEOGRAPH-#5C2B, IRGKangXi=0298.140, RSKangXi=43.4, Def{lame}
5C2C CJK UNIFIED IDEOGRAPH-#5C2C, IRGKangXi=0298.150, RSKangXi=43.4, Def{limp, staggering gait; embarrass}
5C2D CJK UNIFIED IDEOGRAPH-#5C2D, IRGKangXi=0125.171, RSKangXi=10.6, Def{a legendary ancient emperor-sage}
5C2E CJK UNIFIED IDEOGRAPH-#5C2E, IRGKangXi=0298.230, RSKangXi=43.6
5C2F CJK UNIFIED IDEOGRAPH-#5C2F, IRGKangXi=0298.250, RSKangXi=43.6
5C30 CJK UNIFIED IDEOGRAPH-#5C30, IRGKangXi=0299.010, RSKangXi=43.9, Def{swell, swelling of the legs}
5C31 CJK UNIFIED IDEOGRAPH-#5C31, IRGKangXi=0299.050, RSKangXi=43.9, Def{just, simply; to come, go to; to approach, near}
5C32 CJK UNIFIED IDEOGRAPH-#5C32, IRGKangXi=0299.070, RSKangXi=43.10, Def{limp; be embarrassed}
5C33 CJK UNIFIED IDEOGRAPH-#5C33, IRGKangXi=0299.110, RSKangXi=43.10
5C34 CJK UNIFIED IDEOGRAPH-#5C34, IRGKangXi=0299.111, RSKangXi=43.10, Def{embarrassed; ill at ease}
5C35 CJK UNIFIED IDEOGRAPH-#5C35, IRGKangXi=0299.150, RSKangXi=43.12
5C36 CJK UNIFIED IDEOGRAPH-#5C36, IRGKangXi=0299.220, RSKangXi=43.14, Def{embarrassed; ill at ease}
5C37 CJK UNIFIED IDEOGRAPH-#5C37, IRGKangXi=0299.221, RSKangXi=43.14, Def{embarrassed; ill at ease}
5C38 CJK UNIFIED IDEOGRAPH-#5C38, IRGKangXi=0299.260, RSKangXi=44.0, Def{corpse; to impersonate the dead; to preside; KangXi radical 44}
5C39 CJK UNIFIED IDEOGRAPH-#5C39, IRGKangXi=0299.270, RSKangXi=44.1, Def{govern; oversee; director}
5C3A CJK UNIFIED IDEOGRAPH-#5C3A, IRGKangXi=0299.320, RSKangXi=44.1, Def{Chinese measure approx. 'foot'}
5C3B CJK UNIFIED IDEOGRAPH-#5C3B, IRGKangXi=0300.020, RSKangXi=44.2, Def{end of spine; buttocks, sacrum}
5C3C CJK UNIFIED IDEOGRAPH-#5C3C, IRGKangXi=0300.030, RSKangXi=44.2, Def{Buddhist nun; transliteration}
5C3D CJK UNIFIED IDEOGRAPH-#5C3D, IRGKangXi=0300.090, RSKangXi=44.3, Def{exhaust, use up; deplete}
5C3E CJK UNIFIED IDEOGRAPH-#5C3E, IRGKangXi=0300.160, RSKangXi=44.4, Def{tail, extremity; end, stern}
5C3F CJK UNIFIED IDEOGRAPH-#5C3F, IRGKangXi=0300.200, RSKangXi=44.4, Def{urine; urinate}
5C40 CJK UNIFIED IDEOGRAPH-#5C40, IRGKangXi=0300.220, RSKangXi=44.4, Def{bureau, office; circumstance}
5C41 CJK UNIFIED IDEOGRAPH-#5C41, IRGKangXi=0300.230, RSKangXi=44.4, Def{break wind; fart; buttocks}
5C42 CJK UNIFIED IDEOGRAPH-#5C42, IRGKangXi=0300.241, RSKangXi=44.4, Def{storey, layer, floor, stratum}
5C43 CJK UNIFIED IDEOGRAPH-#5C43, IRGKangXi=0300.241, RSKangXi=44.4, Def{gigantic strength; hercules}
5C44 CJK UNIFIED IDEOGRAPH-#5C44, IRGKangXi=0300.270, RSKangXi=44.5, Def{the vagina}
5C45 CJK UNIFIED IDEOGRAPH-#5C45, IRGKangXi=0300.300, RSKangXi=44.5, Def{live, dwell, reside, sit}
5C46 CJK UNIFIED IDEOGRAPH-#5C46, IRGKangXi=0301.030, RSKangXi=44.5, Def{numerary adjunct for time, term}
5C47 CJK UNIFIED IDEOGRAPH-#5C47, IRGKangXi=0301.060, RSKangXi=44.5, Def{cave; hole}
5C48 CJK UNIFIED IDEOGRAPH-#5C48, IRGKangXi=0301.070, RSKangXi=44.5, Def{bend, flex; bent, crooked; crouch}
5C49 CJK UNIFIED IDEOGRAPH-#5C49, IRGKangXi=0301.100, RSKangXi=44.5, Def{drawer; tray; pad; screen}
5C4A CJK UNIFIED IDEOGRAPH-#5C4A, IRGKangXi=0301.141, RSKangXi=44.5, Def{numerary adjunct for time, term}
5C4B CJK UNIFIED IDEOGRAPH-#5C4B, IRGKangXi=0301.190, RSKangXi=44.6, Def{house; room; building, shelter}
5C4C CJK UNIFIED IDEOGRAPH-#5C4C, IRGKangXi=0301.210, RSKangXi=44.6, Def{(Cant.) obscene exclamation}
5C4D CJK UNIFIED IDEOGRAPH-#5C4D, IRGKangXi=0301.240, RSKangXi=44.6, Def{corpse, carcass}
5C4E CJK UNIFIED IDEOGRAPH-#5C4E, IRGKangXi=0301.250, RSKangXi=44.6, Def{excrement, shit, dung}
5C4F CJK UNIFIED IDEOGRAPH-#5C4F, IRGKangXi=0301.280, RSKangXi=44.6, Def{folding screen, shield}
5C50 CJK UNIFIED IDEOGRAPH-#5C50, IRGKangXi=0302.030, RSKangXi=44.7, Def{wooden shoes, clogs}
5C51 CJK UNIFIED IDEOGRAPH-#5C51, IRGKangXi=0302.040, RSKangXi=44.7, Def{bits, scraps, crumbs, fragments}
5C52 CJK UNIFIED IDEOGRAPH-#5C52, IRGKangXi=0302.050, RSKangXi=44.7
5C53 CJK UNIFIED IDEOGRAPH-#5C53, IRGKangXi=0302.080, RSKangXi=44.7, Def{gigantic strength; hercules}
5C54 CJK UNIFIED IDEOGRAPH-#5C54, IRGKangXi=0302.090, RSKangXi=44.7
5C55 CJK UNIFIED IDEOGRAPH-#5C55, IRGKangXi=0302.100, RSKangXi=44.7, Def{open, unfold; stretch, extend}
5C56 CJK UNIFIED IDEOGRAPH-#5C56, IRGKangXi=0302.120, RSKangXi=44.7
5C57 CJK UNIFIED IDEOGRAPH-#5C57, IRGKangXi=0302.161, RSKangXi=41.7
5C58 CJK UNIFIED IDEOGRAPH-#5C58, IRGKangXi=0302.161, RSKangXi=39.7, Def{the youngest}
5C59 CJK UNIFIED IDEOGRAPH-#5C59, IRGKangXi=0302.180, RSKangXi=44.8, Def{to ease nature}
5C5A CJK UNIFIED IDEOGRAPH-#5C5A, IRGKangXi=0302.220, RSKangXi=44.8
5C5B CJK UNIFIED IDEOGRAPH-#5C5B, IRGKangXi=0302.250, RSKangXi=44.8, Def{folding screen}
5C5C CJK UNIFIED IDEOGRAPH-#5C5C, IRGKangXi=0302.260, RSKangXi=44.8, Def{drawer; tray; pad; screen}
5C5D CJK UNIFIED IDEOGRAPH-#5C5D, IRGKangXi=0302.290, RSKangXi=44.8, Def{straw shoes; straw door}
5C5E CJK UNIFIED IDEOGRAPH-#5C5E, IRGKangXi=0303.050, RSKangXi=44.9, Def{class, category, type; belong to}
5C5F CJK UNIFIED IDEOGRAPH-#5C5F, IRGKangXi=0303.060, RSKangXi=44.9
5C60 CJK UNIFIED IDEOGRAPH-#5C60, IRGKangXi=0303.120, RSKangXi=44.9, Def{butcher, slaughter, massacre}
5C61 CJK UNIFIED IDEOGRAPH-#5C61, IRGKangXi=0303.181, RSKangXi=44.9, Def{frequently, often, again and again}
5C62 CJK UNIFIED IDEOGRAPH-#5C62, IRGKangXi=0303.300, RSKangXi=44.11, Def{frequently, often, again and again}
5C63 CJK UNIFIED IDEOGRAPH-#5C63, IRGKangXi=0303.350, RSKangXi=44.11, Def{straw sandals or slippers that have no heel-backs}
5C64 CJK UNIFIED IDEOGRAPH-#5C64, IRGKangXi=0303.400, RSKangXi=44.12, Def{storey, layer, floor, stratum}
5C65 CJK UNIFIED IDEOGRAPH-#5C65, IRGKangXi=0303.410, RSKangXi=44.12, Def{footwear, shoes; walk on, tread}
5C66 CJK UNIFIED IDEOGRAPH-#5C66, IRGKangXi=0303.461, RSKangXi=44.12, Def{straw sandals; tread on}
5C67 CJK UNIFIED IDEOGRAPH-#5C67, IRGKangXi=0303.480, RSKangXi=44.12, Def{wooden shoes, clogs}
5C68 CJK UNIFIED IDEOGRAPH-#5C68, IRGKangXi=0304.010, RSKangXi=44.14, Def{straw sandals; tread on}
5C69 CJK UNIFIED IDEOGRAPH-#5C69, IRGKangXi=0304.020, RSKangXi=44.15, Def{straw sandals}
5C6A CJK UNIFIED IDEOGRAPH-#5C6A, IRGKangXi=0304.030, RSKangXi=44.15, Def{penis}
5C6B CJK UNIFIED IDEOGRAPH-#5C6B, IRGKangXi=0304.040
5C6C CJK UNIFIED IDEOGRAPH-#5C6C, IRGKangXi=0304.070, RSKangXi=44.18, Def{class, category, type; to belong to}
5C6D CJK UNIFIED IDEOGRAPH-#5C6D, IRGKangXi=0304.090, RSKangXi=44.21, Def{gigantic strength}
5C6E CJK UNIFIED IDEOGRAPH-#5C6E, IRGKangXi=0304.100, RSKangXi=45.0, Def{sprout; KangXi radical 45}
5C6F CJK UNIFIED IDEOGRAPH-#5C6F, IRGKangXi=0304.110, RSKangXi=45.1, Def{village, hamlet; camp; station}
5C70 CJK UNIFIED IDEOGRAPH-#5C70, IRGKangXi=0305.010, RSKangXi=45.3, Def{disobedient}
5C71 CJK UNIFIED IDEOGRAPH-#5C71, IRGKangXi=0307.010, RSKangXi=46.0, Def{mountain, hill, peak}
5C72 CJK UNIFIED IDEOGRAPH-#5C72, IRGKangXi=0307.021
5C73 CJK UNIFIED IDEOGRAPH-#5C73, IRGKangXi=0307.040, RSKangXi=46.2
5C74 CJK UNIFIED IDEOGRAPH-#5C74, IRGKangXi=0307.060, RSKangXi=46.2, Def{lofty}
5C75 CJK UNIFIED IDEOGRAPH-#5C75, IRGKangXi=0307.110, RSKangXi=46.2
5C76 CJK UNIFIED IDEOGRAPH-#5C76, IRGKangXi=0307.131, RSKangXi=46.2, Def{lofty}
5C77 CJK UNIFIED IDEOGRAPH-#5C77, IRGKangXi=0307.131, RSKangXi=46.2
5C78 CJK UNIFIED IDEOGRAPH-#5C78, IRGKangXi=0307.140, RSKangXi=46.3
5C79 CJK UNIFIED IDEOGRAPH-#5C79, IRGKangXi=0307.150, RSKangXi=46.3, Def{to rise high; to stand erect}
5C7A CJK UNIFIED IDEOGRAPH-#5C7A, IRGKangXi=0307.271, RSKangXi=46.3, Def{a hill with trees or grass-- some give the opposite meaning}
5C7B CJK UNIFIED IDEOGRAPH-#5C7B, IRGKangXi=0307.190, RSKangXi=46.3, Def{(Cant.) sharp}
5C7C CJK UNIFIED IDEOGRAPH-#5C7C, IRGKangXi=0307.220, RSKangXi=46.3, Def{mountain; a bare hill}
5C7D CJK UNIFIED IDEOGRAPH-#5C7D, IRGKangXi=0307.230, RSKangXi=46.3
5C7E CJK UNIFIED IDEOGRAPH-#5C7E, IRGKangXi=0307.240, RSKangXi=46.3
5C7F CJK UNIFIED IDEOGRAPH-#5C7F, IRGKangXi=0307.271, RSKangXi=46.3, Def{island}
5C80 CJK UNIFIED IDEOGRAPH-#5C80, IRGKangXi=0307.271, RSKangXi=46.3, Def{go out}
5C81 CJK UNIFIED IDEOGRAPH-#5C81, IRGKangXi=0307.271, RSKangXi=46.3, Def{year; age; harvest}
5C82 CJK UNIFIED IDEOGRAPH-#5C82, IRGKangXi=0307.271, RSKangXi=46.3, Def{how? what?}
5C83 CJK UNIFIED IDEOGRAPH-#5C83, IRGKangXi=0307.271, RSKangXi=46.3
5C84 CJK UNIFIED IDEOGRAPH-#5C84, IRGKangXi=0308.010, RSKangXi=46.4
5C85 CJK UNIFIED IDEOGRAPH-#5C85, IRGKangXi=0308.040
5C86 CJK UNIFIED IDEOGRAPH-#5C86, IRGKangXi=0308.060, RSKangXi=46.4
5C87 CJK UNIFIED IDEOGRAPH-#5C87, IRGKangXi=0308.100, RSKangXi=46.4
5C88 CJK UNIFIED IDEOGRAPH-#5C88, IRGKangXi=0308.110, RSKangXi=46.4
5C89 CJK UNIFIED IDEOGRAPH-#5C89, IRGKangXi=0308.120, RSKangXi=46.4
5C8A CJK UNIFIED IDEOGRAPH-#5C8A, IRGKangXi=0308.140, RSKangXi=46.4, Def{foothill}
5C8B CJK UNIFIED IDEOGRAPH-#5C8B, IRGKangXi=0308.170, RSKangXi=46.4
5C8C CJK UNIFIED IDEOGRAPH-#5C8C, IRGKangXi=0308.180, RSKangXi=46.4, Def{perilous, hazardous; high, steep}
5C8D CJK UNIFIED IDEOGRAPH-#5C8D, IRGKangXi=0308.190, RSKangXi=46.6
5C8E CJK UNIFIED IDEOGRAPH-#5C8E, IRGKangXi=0308.210, RSKangXi=46.4
5C8F CJK UNIFIED IDEOGRAPH-#5C8F, IRGKangXi=0308.230, RSKangXi=46.4
5C90 CJK UNIFIED IDEOGRAPH-#5C90, IRGKangXi=0308.240, RSKangXi=46.4, Def{high; majestic; fork in road}
5C91 CJK UNIFIED IDEOGRAPH-#5C91, IRGKangXi=0308.270, RSKangXi=46.4, Def{steep, precipitous; peak}
5C92 CJK UNIFIED IDEOGRAPH-#5C92, IRGKangXi=0308.280, RSKangXi=46.4
5C93 CJK UNIFIED IDEOGRAPH-#5C93, IRGKangXi=0308.290, RSKangXi=46.4
5C94 CJK UNIFIED IDEOGRAPH-#5C94, IRGKangXi=0308.330, RSKangXi=46.4, Def{diverge, branch off; fork in road}
5C95 CJK UNIFIED IDEOGRAPH-#5C95, IRGKangXi=0308.331, RSKangXi=46.4
5C96 CJK UNIFIED IDEOGRAPH-#5C96, IRGKangXi=0308.331, RSKangXi=46.4, Def{steep, sheer; rugged, rough}
5C97 CJK UNIFIED IDEOGRAPH-#5C97, IRGKangXi=0308.331, RSKangXi=46.4, Def{post; position}
5C98 CJK UNIFIED IDEOGRAPH-#5C98, IRGKangXi=0308.331, RSKangXi=46.4, Def{steep hill; mountain in Hubei}
5C99 CJK UNIFIED IDEOGRAPH-#5C99, IRGKangXi=0308.331, RSKangXi=46.4, Def{island}
5C9A CJK UNIFIED IDEOGRAPH-#5C9A, IRGKangXi=0308.331, RSKangXi=46.4, Def{mountain mist, mountain haze}
5C9B CJK UNIFIED IDEOGRAPH-#5C9B, IRGKangXi=0308.331, RSKangXi=46.4, Def{island}
5C9C CJK UNIFIED IDEOGRAPH-#5C9C, IRGKangXi=0308.331, RSKangXi=46.4, Def{rock mountain}
5C9D CJK UNIFIED IDEOGRAPH-#5C9D, IRGKangXi=0308.340, RSKangXi=46.5, Def{name of a mountain in Shandong}
5C9E CJK UNIFIED IDEOGRAPH-#5C9E, IRGKangXi=0308.350
5C9F CJK UNIFIED IDEOGRAPH-#5C9F, IRGKangXi=0308.360, RSKangXi=46.5
5CA0 CJK UNIFIED IDEOGRAPH-#5CA0, IRGKangXi=0308.380, RSKangXi=46.5
5CA1 CJK UNIFIED IDEOGRAPH-#5CA1, IRGKangXi=0308.390, RSKangXi=46.5, Def{ridge or crest of hill}
5CA2 CJK UNIFIED IDEOGRAPH-#5CA2, IRGKangXi=0309.020, RSKangXi=46.5
5CA3 CJK UNIFIED IDEOGRAPH-#5CA3, IRGKangXi=0309.040, RSKangXi=46.5, Def{a hill in Hunan}
5CA4 CJK UNIFIED IDEOGRAPH-#5CA4, IRGKangXi=0309.070, RSKangXi=46.5
5CA5 CJK UNIFIED IDEOGRAPH-#5CA5, IRGKangXi=0309.090, RSKangXi=46.5
5CA6 CJK UNIFIED IDEOGRAPH-#5CA6, IRGKangXi=0309.110, RSKangXi=46.5
5CA7 CJK UNIFIED IDEOGRAPH-#5CA7, IRGKangXi=0309.160, RSKangXi=46.5, Def{peak; cliff; precipice}
5CA8 CJK UNIFIED IDEOGRAPH-#5CA8, IRGKangXi=0309.180, RSKangXi=46.5, Def{uneven}
5CA9 CJK UNIFIED IDEOGRAPH-#5CA9, IRGKangXi=0309.190, RSKangXi=46.5, Def{cliff; rocks; mountain}
5CAA CJK UNIFIED IDEOGRAPH-#5CAA, IRGKangXi=0309.210, RSKangXi=46.5
5CAB CJK UNIFIED IDEOGRAPH-#5CAB, IRGKangXi=0309.220, RSKangXi=46.5, Def{mountain peak; cave, cavern}
5CAC CJK UNIFIED IDEOGRAPH-#5CAC, IRGKangXi=0309.230, RSKangXi=46.5, Def{cape; promontory, headland}
5CAD CJK UNIFIED IDEOGRAPH-#5CAD, IRGKangXi=0309.240, RSKangXi=46.5, Def{mountain ridge, mountain peak}
5CAE CJK UNIFIED IDEOGRAPH-#5CAE, IRGKangXi=0309.250, RSKangXi=46.5
5CAF CJK UNIFIED IDEOGRAPH-#5CAF, IRGKangXi=0309.260, RSKangXi=46.5
5CB0 CJK UNIFIED IDEOGRAPH-#5CB0, IRGKangXi=0309.270, RSKangXi=46.5
5CB1 CJK UNIFIED IDEOGRAPH-#5CB1, IRGKangXi=0309.280, RSKangXi=46.5, Def{Daishan, one of the Five Sacred Mountains in China}
5CB2 CJK UNIFIED IDEOGRAPH-#5CB2, IRGKangXi=0309.300, RSKangXi=46.5
5CB3 CJK UNIFIED IDEOGRAPH-#5CB3, IRGKangXi=0309.310, RSKangXi=46.5, Def{mountain peak; surname}
5CB4 CJK UNIFIED IDEOGRAPH-#5CB4, IRGKangXi=0309.320, RSKangXi=46.5
5CB5 CJK UNIFIED IDEOGRAPH-#5CB5, IRGKangXi=0309.330, RSKangXi=46.5, Def{hill}
5CB6 CJK UNIFIED IDEOGRAPH-#5CB6, IRGKangXi=0309.350, RSKangXi=46.5
5CB7 CJK UNIFIED IDEOGRAPH-#5CB7, IRGKangXi=0310.010, RSKangXi=46.5, Def{min mountain, min river}
5CB8 CJK UNIFIED IDEOGRAPH-#5CB8, IRGKangXi=0310.030, RSKangXi=46.5, Def{bank, shore; beach, coast}
5CB9 CJK UNIFIED IDEOGRAPH-#5CB9, IRGKangXi=0310.040, RSKangXi=46.5
5CBA CJK UNIFIED IDEOGRAPH-#5CBA, IRGKangXi=0310.050, RSKangXi=46.5, Def{mountain ridge, mountain peak}
5CBB CJK UNIFIED IDEOGRAPH-#5CBB, IRGKangXi=0310.071, RSKangXi=46.5
5CBC CJK UNIFIED IDEOGRAPH-#5CBC, IRGKangXi=0310.071, RSKangXi=46.5
5CBD CJK UNIFIED IDEOGRAPH-#5CBD, IRGKangXi=0310.071, RSKangXi=46.5, Def{place name in Guangxi province}
5CBE CJK UNIFIED IDEOGRAPH-#5CBE, IRGKangXi=0310.071, RSKangXi=46.5, Def{mountain pass (Korean)}
5CBF CJK UNIFIED IDEOGRAPH-#5CBF, IRGKangXi=0310.071, RSKangXi=46.5, Def{grand, stately; secure, lasting}
5CC0 CJK UNIFIED IDEOGRAPH-#5CC0, IRGKangXi=0310.071, RSKangXi=46.5, Def{mountain peak; cave, cavern}
5CC1 CJK UNIFIED IDEOGRAPH-#5CC1, IRGKangXi=0310.071, RSKangXi=46.5, Def{yellow dirt mount}
5CC2 CJK UNIFIED IDEOGRAPH-#5CC2, IRGKangXi=0310.071, RSKangXi=46.5, Def{name of place}
5CC3 CJK UNIFIED IDEOGRAPH-#5CC3, IRGKangXi=0310.071, RSKangXi=46.13
5CC4 CJK UNIFIED IDEOGRAPH-#5CC4, IRGKangXi=0310.071, RSKangXi=46.5, Def{a range of peaks in Shandong and Jiangsu; the name of a mountain}
5CC5 CJK UNIFIED IDEOGRAPH-#5CC5, IRGKangXi=0310.071, RSKangXi=46.5
5CC6 CJK UNIFIED IDEOGRAPH-#5CC6, IRGKangXi=0310.080, RSKangXi=46.6
5CC7 CJK UNIFIED IDEOGRAPH-#5CC7, IRGKangXi=0310.090, RSKangXi=46.6, Def{cave, cavern}
5CC8 CJK UNIFIED IDEOGRAPH-#5CC8, IRGKangXi=0310.100, RSKangXi=46.6
5CC9 CJK UNIFIED IDEOGRAPH-#5CC9, IRGKangXi=0310.110, RSKangXi=46.6
5CCA CJK UNIFIED IDEOGRAPH-#5CCA, IRGKangXi=0310.120, RSKangXi=46.6
5CCB CJK UNIFIED IDEOGRAPH-#5CCB, IRGKangXi=0310.170, RSKangXi=46.6, Def{ranges of hills stretching on beyond another irregular peaks}
5CCC CJK UNIFIED IDEOGRAPH-#5CCC, IRGKangXi=0310.180, RSKangXi=46.6
5CCD CJK UNIFIED IDEOGRAPH-#5CCD, IRGKangXi=0310.200, RSKangXi=46.6
5CCE CJK UNIFIED IDEOGRAPH-#5CCE, IRGKangXi=0310.220, RSKangXi=46.6
5CCF CJK UNIFIED IDEOGRAPH-#5CCF, IRGKangXi=0310.230, RSKangXi=46.6
5CD0 CJK UNIFIED IDEOGRAPH-#5CD0, IRGKangXi=0310.250, RSKangXi=46.6
5CD1 CJK UNIFIED IDEOGRAPH-#5CD1, IRGKangXi=0310.260, RSKangXi=46.6
5CD2 CJK UNIFIED IDEOGRAPH-#5CD2, IRGKangXi=0310.270, RSKangXi=46.6, Def{mountain in Gansu province}
5CD3 CJK UNIFIED IDEOGRAPH-#5CD3, IRGKangXi=0310.280, RSKangXi=46.6
5CD4 CJK UNIFIED IDEOGRAPH-#5CD4, IRGKangXi=0310.290, RSKangXi=46.6
5CD5 CJK UNIFIED IDEOGRAPH-#5CD5, IRGKangXi=0310.330, RSKangXi=46.6
5CD6 CJK UNIFIED IDEOGRAPH-#5CD6, IRGKangXi=0310.350, RSKangXi=46.6
5CD7 CJK UNIFIED IDEOGRAPH-#5CD7, IRGKangXi=0310.360, RSKangXi=46.6
5CD8 CJK UNIFIED IDEOGRAPH-#5CD8, IRGKangXi=0310.370, RSKangXi=46.6
5CD9 CJK UNIFIED IDEOGRAPH-#5CD9, IRGKangXi=0311.010, RSKangXi=46.6, Def{stand erect, stand up; pile up}
5CDA CJK UNIFIED IDEOGRAPH-#5CDA, IRGKangXi=0311.020, RSKangXi=46.6
5CDB CJK UNIFIED IDEOGRAPH-#5CDB, IRGKangXi=0311.030, RSKangXi=46.6
5CDC CJK UNIFIED IDEOGRAPH-#5CDC, IRGKangXi=0311.040, RSKangXi=46.6
5CDD CJK UNIFIED IDEOGRAPH-#5CDD, IRGKangXi=0311.050, RSKangXi=46.6, Def{Mountain in Gansu province}
5CDE CJK UNIFIED IDEOGRAPH-#5CDE, IRGKangXi=0311.060, RSKangXi=46.6, Def{high and uneven}
5CDF CJK UNIFIED IDEOGRAPH-#5CDF, IRGKangXi=0311.061, RSKangXi=46.6
5CE0 CJK UNIFIED IDEOGRAPH-#5CE0, IRGKangXi=0311.061, RSKangXi=46.6, Def{mountain pass; crisis, climax}
5CE1 CJK UNIFIED IDEOGRAPH-#5CE1, IRGKangXi=0311.061, RSKangXi=46.6, Def{gorge, strait, ravine; isthmus}
5CE2 CJK UNIFIED IDEOGRAPH-#5CE2, IRGKangXi=0311.061
5CE3 CJK UNIFIED IDEOGRAPH-#5CE3, IRGKangXi=0311.061, RSKangXi=46.12, Def{high or tall}
5CE4 CJK UNIFIED IDEOGRAPH-#5CE4, IRGKangXi=0311.061, RSKangXi=46.6, Def{high pointed mountain}
5CE5 CJK UNIFIED IDEOGRAPH-#5CE5, IRGKangXi=0311.061, RSKangXi=46.6, Def{high, lofty, noble; steep, perilous}
5CE6 CJK UNIFIED IDEOGRAPH-#5CE6, IRGKangXi=0311.061, RSKangXi=46.6, Def{mountain range; pointed mountain}
5CE7 CJK UNIFIED IDEOGRAPH-#5CE7, IRGKangXi=0311.061
5CE8 CJK UNIFIED IDEOGRAPH-#5CE8, IRGKangXi=0311.090, RSKangXi=46.7, Def{lofty}
5CE9 CJK UNIFIED IDEOGRAPH-#5CE9, IRGKangXi=0311.100, RSKangXi=46.7, Def{lofty}
5CEA CJK UNIFIED IDEOGRAPH-#5CEA, IRGKangXi=0311.110, RSKangXi=46.7, Def{valley, ravine}
5CEB CJK UNIFIED IDEOGRAPH-#5CEB, IRGKangXi=0311.160, RSKangXi=46.7, Def{mountain in Shandong province}
5CEC CJK UNIFIED IDEOGRAPH-#5CEC, IRGKangXi=0311.210, RSKangXi=46.7
5CED CJK UNIFIED IDEOGRAPH-#5CED, IRGKangXi=0311.230, RSKangXi=46.7, Def{steep, precipitous, rugged}
5CEE CJK UNIFIED IDEOGRAPH-#5CEE, IRGKangXi=0311.240, RSKangXi=46.7
5CEF CJK UNIFIED IDEOGRAPH-#5CEF, IRGKangXi=0311.300, RSKangXi=46.7, Def{peak, summit; hump of camel}
5CF0 CJK UNIFIED IDEOGRAPH-#5CF0, IRGKangXi=0311.310, RSKangXi=46.7, Def{peak, summit; hump of camel}
5CF1 CJK UNIFIED IDEOGRAPH-#5CF1, IRGKangXi=0311.330, RSKangXi=46.7, Def{name of a mountain}
5CF2 CJK UNIFIED IDEOGRAPH-#5CF2, IRGKangXi=0311.340, RSKangXi=46.7
5CF3 CJK UNIFIED IDEOGRAPH-#5CF3, IRGKangXi=0311.360, RSKangXi=46.7
5CF4 CJK UNIFIED IDEOGRAPH-#5CF4, IRGKangXi=0312.020, RSKangXi=46.7, Def{steep hill; mountain in Hubei}
5CF5 CJK UNIFIED IDEOGRAPH-#5CF5, IRGKangXi=0312.030, RSKangXi=46.7
5CF6 CJK UNIFIED IDEOGRAPH-#5CF6, IRGKangXi=0312.040, RSKangXi=46.7, Def{island}
5CF7 CJK UNIFIED IDEOGRAPH-#5CF7, IRGKangXi=0312.050, RSKangXi=46.7
5CF8 CJK UNIFIED IDEOGRAPH-#5CF8, IRGKangXi=0312.060, RSKangXi=46.7
5CF9 CJK UNIFIED IDEOGRAPH-#5CF9, IRGKangXi=0312.070, RSKangXi=46.7
5CFA CJK UNIFIED IDEOGRAPH-#5CFA, IRGKangXi=0312.110, RSKangXi=46.7
5CFB CJK UNIFIED IDEOGRAPH-#5CFB, IRGKangXi=0312.120, RSKangXi=46.7, Def{high, steep, towering; stern}
5CFC CJK UNIFIED IDEOGRAPH-#5CFC, IRGKangXi=0312.140, RSKangXi=46.7
5CFD CJK UNIFIED IDEOGRAPH-#5CFD, IRGKangXi=0312.180, RSKangXi=46.7, Def{gorge, strait, ravine; isthmus}
5CFE CJK UNIFIED IDEOGRAPH-#5CFE, IRGKangXi=0312.190, RSKangXi=46.7
5CFF CJK UNIFIED IDEOGRAPH-#5CFF, IRGKangXi=0312.210, RSKangXi=46.7, Def{mountain}
5D00 CJK UNIFIED IDEOGRAPH-#5D00, IRGKangXi=0312.240, RSKangXi=46.7, Def{place name in hunan province}
5D01 CJK UNIFIED IDEOGRAPH-#5D01, IRGKangXi=0312.301, RSKangXi=46.7, Def{a place in Taiwan Tainan}
5D02 CJK UNIFIED IDEOGRAPH-#5D02, IRGKangXi=0312.301, RSKangXi=46.7, Def{Laoshan, mountain in Shandong}
5D03 CJK UNIFIED IDEOGRAPH-#5D03, IRGKangXi=0312.301, RSKangXi=46.7, Def{mountain in Sichuan province}
5D04 CJK UNIFIED IDEOGRAPH-#5D04, IRGKangXi=0312.301, RSKangXi=46.13, Def{high, steep, precipitous}
5D05 CJK UNIFIED IDEOGRAPH-#5D05, IRGKangXi=0312.301, RSKangXi=46.7
5D06 CJK UNIFIED IDEOGRAPH-#5D06, IRGKangXi=0312.310, RSKangXi=46.8, Def{Kongtong mountain}
5D07 CJK UNIFIED IDEOGRAPH-#5D07, IRGKangXi=0313.010, RSKangXi=46.8, Def{esteem, honor, revere, venerate}
5D08 CJK UNIFIED IDEOGRAPH-#5D08, IRGKangXi=0313.020, RSKangXi=46.8
5D09 CJK UNIFIED IDEOGRAPH-#5D09, IRGKangXi=0313.030, RSKangXi=46.8
5D0A CJK UNIFIED IDEOGRAPH-#5D0A, IRGKangXi=0313.050, RSKangXi=46.8
5D0B CJK UNIFIED IDEOGRAPH-#5D0B, IRGKangXi=0313.100, RSKangXi=46.8, Def{flowery; illustrious; Chinese}
5D0C CJK UNIFIED IDEOGRAPH-#5D0C, IRGKangXi=0313.170, RSKangXi=46.8, Def{mountain name}
5D0D CJK UNIFIED IDEOGRAPH-#5D0D, IRGKangXi=0313.180, RSKangXi=46.8, Def{mountain in Sichuan province}
5D0E CJK UNIFIED IDEOGRAPH-#5D0E, IRGKangXi=0313.190, RSKangXi=46.8, Def{rough, uneven, jagged, rugged}
5D0F CJK UNIFIED IDEOGRAPH-#5D0F, IRGKangXi=0313.200, RSKangXi=46.8
5D10 CJK UNIFIED IDEOGRAPH-#5D10, IRGKangXi=0313.220, RSKangXi=46.8, Def{Kunlun mountains in Jiangsu}
5D11 CJK UNIFIED IDEOGRAPH-#5D11, IRGKangXi=0314.010, RSKangXi=46.8, Def{Kunlun mountains in Jiang Su province.}
5D12 CJK UNIFIED IDEOGRAPH-#5D12, IRGKangXi=0314.030, RSKangXi=46.8, Def{rocky peaks; lofty and dangerous}
5D13 CJK UNIFIED IDEOGRAPH-#5D13, IRGKangXi=0314.050, RSKangXi=46.8
5D14 CJK UNIFIED IDEOGRAPH-#5D14, IRGKangXi=0314.060, RSKangXi=46.8, Def{high, lofty, towering; surname}
5D15 CJK UNIFIED IDEOGRAPH-#5D15, IRGKangXi=0314.070, RSKangXi=46.8, Def{cliff, precipice; precipitous}
5D16 CJK UNIFIED IDEOGRAPH-#5D16, IRGKangXi=0314.080, RSKangXi=46.8, Def{cliff, precipice; precipitous}
5D17 CJK UNIFIED IDEOGRAPH-#5D17, IRGKangXi=0314.100, RSKangXi=46.8, Def{post; position}
5D18 CJK UNIFIED IDEOGRAPH-#5D18, IRGKangXi=0314.110, RSKangXi=46.8, Def{Kunlun mountains in Jiangsu}
5D19 CJK UNIFIED IDEOGRAPH-#5D19, IRGKangXi=0314.120, RSKangXi=46.8, Def{Kunlun mountains in Jiangsu}
5D1A CJK UNIFIED IDEOGRAPH-#5D1A, IRGKangXi=0314.130, RSKangXi=46.8, Def{hilly, steep, rugged}
5D1B CJK UNIFIED IDEOGRAPH-#5D1B, IRGKangXi=0314.140, RSKangXi=46.8, Def{towering, eminent; rise abruptly}
5D1C CJK UNIFIED IDEOGRAPH-#5D1C, IRGKangXi=0314.150, RSKangXi=46.8
5D1D CJK UNIFIED IDEOGRAPH-#5D1D, IRGKangXi=0314.250, RSKangXi=46.8
5D1E CJK UNIFIED IDEOGRAPH-#5D1E, IRGKangXi=0314.260, RSKangXi=46.8, Def{mountain in Shanxi}
5D1F CJK UNIFIED IDEOGRAPH-#5D1F, IRGKangXi=0314.280, RSKangXi=46.8, Def{cliffs}
5D20 CJK UNIFIED IDEOGRAPH-#5D20, IRGKangXi=0314.290, RSKangXi=46.8, Def{place name in Guangxi province}
5D21 CJK UNIFIED IDEOGRAPH-#5D21, IRGKangXi=0314.300, RSKangXi=46.8
5D22 CJK UNIFIED IDEOGRAPH-#5D22, IRGKangXi=0314.320, RSKangXi=46.8, Def{high, lofty, noble; steep, perilous}
5D23 CJK UNIFIED IDEOGRAPH-#5D23, IRGKangXi=0314.330, RSKangXi=46.8
5D24 CJK UNIFIED IDEOGRAPH-#5D24, IRGKangXi=0314.340, RSKangXi=46.8, Def{mountain in Henan}
5D25 CJK UNIFIED IDEOGRAPH-#5D25, IRGKangXi=0315.010, RSKangXi=46.8
5D26 CJK UNIFIED IDEOGRAPH-#5D26, IRGKangXi=0315.020, RSKangXi=46.8, Def{a mountain in Kansu, where there is a cave into which the sun is said to sink at night}
5D27 CJK UNIFIED IDEOGRAPH-#5D27, IRGKangXi=0315.030, RSKangXi=46.8, Def{high mountain; lofty, eminent}
5D28 CJK UNIFIED IDEOGRAPH-#5D28, IRGKangXi=0315.040, RSKangXi=46.8
5D29 CJK UNIFIED IDEOGRAPH-#5D29, IRGKangXi=0315.060, RSKangXi=46.8, Def{rupture, split apart, collapse}
5D2A CJK UNIFIED IDEOGRAPH-#5D2A, IRGKangXi=0315.151, RSKangXi=46.8, Def{rocky peaks; lofty and dangerous}
5D2B CJK UNIFIED IDEOGRAPH-#5D2B, IRGKangXi=0315.151, RSKangXi=46.8, Def{high and lofty (mountains)}
5D2C CJK UNIFIED IDEOGRAPH-#5D2C, IRGKangXi=0315.151, RSKangXi=46.8, Def{place name in Guangxi province}
5D2D CJK UNIFIED IDEOGRAPH-#5D2D, IRGKangXi=0315.151, RSKangXi=46.8, Def{high, steep, precipitous; new}
5D2E CJK UNIFIED IDEOGRAPH-#5D2E, IRGKangXi=0315.151, RSKangXi=46.8, Def{a mesa, hill with flat top and steep sides}
5D2F CJK UNIFIED IDEOGRAPH-#5D2F, IRGKangXi=0315.151, RSKangXi=46.8
5D30 CJK UNIFIED IDEOGRAPH-#5D30, IRGKangXi=0315.151, RSKangXi=46.8
5D31 CJK UNIFIED IDEOGRAPH-#5D31, IRGKangXi=0315.160, RSKangXi=46.9, Def{lofty}
5D32 CJK UNIFIED IDEOGRAPH-#5D32, IRGKangXi=0315.190, RSKangXi=46.9
5D33 CJK UNIFIED IDEOGRAPH-#5D33, IRGKangXi=0315.200, RSKangXi=46.9, Def{county in Shandong province}
5D34 CJK UNIFIED IDEOGRAPH-#5D34, IRGKangXi=0315.210, RSKangXi=46.9, Def{high, lofty; precipitous}
5D35 CJK UNIFIED IDEOGRAPH-#5D35, IRGKangXi=0315.220, RSKangXi=46.9
5D36 CJK UNIFIED IDEOGRAPH-#5D36, IRGKangXi=0315.260, RSKangXi=46.9
5D37 CJK UNIFIED IDEOGRAPH-#5D37, IRGKangXi=0315.270, RSKangXi=46.9
5D38 CJK UNIFIED IDEOGRAPH-#5D38, IRGKangXi=0315.280, RSKangXi=46.9
5D39 CJK UNIFIED IDEOGRAPH-#5D39, IRGKangXi=0315.290, RSKangXi=46.9
5D3A CJK UNIFIED IDEOGRAPH-#5D3A, IRGKangXi=0315.310, RSKangXi=46.9
5D3B CJK UNIFIED IDEOGRAPH-#5D3B, IRGKangXi=0315.340, RSKangXi=46.9
5D3C CJK UNIFIED IDEOGRAPH-#5D3C, IRGKangXi=0315.350, RSKangXi=46.9
5D3D CJK UNIFIED IDEOGRAPH-#5D3D, IRGKangXi=0315.360, RSKangXi=46.9, Def{a child, a servant; a diminutive}
5D3E CJK UNIFIED IDEOGRAPH-#5D3E, IRGKangXi=0315.370, RSKangXi=46.9, Def{place name in Shanxi province}
5D3F CJK UNIFIED IDEOGRAPH-#5D3F, IRGKangXi=0315.390, RSKangXi=46.9, Def{cliffs}
5D40 CJK UNIFIED IDEOGRAPH-#5D40, IRGKangXi=0316.020, RSKangXi=46.9
5D41 CJK UNIFIED IDEOGRAPH-#5D41, IRGKangXi=0316.030, RSKangXi=46.9, Def{rugged}
5D42 CJK UNIFIED IDEOGRAPH-#5D42, IRGKangXi=0316.040, RSKangXi=46.9, Def{lofty}
5D43 CJK UNIFIED IDEOGRAPH-#5D43, IRGKangXi=0316.050, RSKangXi=46.9
5D44 CJK UNIFIED IDEOGRAPH-#5D44, IRGKangXi=0316.060, RSKangXi=46.9
5D45 CJK UNIFIED IDEOGRAPH-#5D45, IRGKangXi=0316.080, RSKangXi=46.9
5D46 CJK UNIFIED IDEOGRAPH-#5D46, IRGKangXi=0316.090, RSKangXi=46.9, Def{mountain in Henan; surname}
5D47 CJK UNIFIED IDEOGRAPH-#5D47, IRGKangXi=0316.100, RSKangXi=46.9, Def{mountain in Henan; surname}
5D48 CJK UNIFIED IDEOGRAPH-#5D48, IRGKangXi=0316.120, RSKangXi=46.9
5D49 CJK UNIFIED IDEOGRAPH-#5D49, IRGKangXi=0316.130, RSKangXi=46.9
5D4A CJK UNIFIED IDEOGRAPH-#5D4A, IRGKangXi=0317.521, RSKangXi=46.10, Def{district in Shaohsing, Chekiang}
5D4B CJK UNIFIED IDEOGRAPH-#5D4B, IRGKangXi=0316.160, RSKangXi=46.9, Def{Omei mountain in Sichuan}
5D4C CJK UNIFIED IDEOGRAPH-#5D4C, IRGKangXi=0316.170, RSKangXi=46.9, Def{inlay, set in; fall into; rugged}
5D4D CJK UNIFIED IDEOGRAPH-#5D4D, IRGKangXi=0316.180, RSKangXi=46.9
5D4E CJK UNIFIED IDEOGRAPH-#5D4E, IRGKangXi=0316.190, RSKangXi=46.9, Def{mountain recess; canyon}
5D4F CJK UNIFIED IDEOGRAPH-#5D4F, IRGKangXi=0316.220, RSKangXi=46.9, Def{a mountain in Shenxi}
5D50 CJK UNIFIED IDEOGRAPH-#5D50, IRGKangXi=0316.250, RSKangXi=46.9, Def{mountain mist, mountain haze}
5D51 CJK UNIFIED IDEOGRAPH-#5D51, IRGKangXi=0316.270, RSKangXi=46.9
5D52 CJK UNIFIED IDEOGRAPH-#5D52, IRGKangXi=0316.290, RSKangXi=46.9, Def{cliff; soar}
5D53 CJK UNIFIED IDEOGRAPH-#5D53, IRGKangXi=0316.300, RSKangXi=46.9
5D54 CJK UNIFIED IDEOGRAPH-#5D54, IRGKangXi=0316.310, RSKangXi=46.9
5D55 CJK UNIFIED IDEOGRAPH-#5D55, IRGKangXi=0316.381, RSKangXi=46.9
5D56 CJK UNIFIED IDEOGRAPH-#5D56, IRGKangXi=0316.381, RSKangXi=46.9, Def{name of a mountain; (Cant.) to obstruct}
5D57 CJK UNIFIED IDEOGRAPH-#5D57, IRGKangXi=0316.381, RSKangXi=46.9, Def{year; age; harvest}
5D58 CJK UNIFIED IDEOGRAPH-#5D58, IRGKangXi=0316.381, RSKangXi=46.9, Def{high, steep; lofty, towering}
5D59 CJK UNIFIED IDEOGRAPH-#5D59, IRGKangXi=0316.381, RSKangXi=46.9, Def{place name}
5D5A CJK UNIFIED IDEOGRAPH-#5D5A, IRGKangXi=0316.381, RSKangXi=46.12, Def{lofty, towering}
5D5B CJK UNIFIED IDEOGRAPH-#5D5B, IRGKangXi=0316.381, RSKangXi=46.9, Def{county in Shandong province}
5D5C CJK UNIFIED IDEOGRAPH-#5D5C, IRGKangXi=0316.381, RSKangXi=46.9, Def{rough, uneven, jagged, rugged}
5D5D CJK UNIFIED IDEOGRAPH-#5D5D, IRGKangXi=0316.381, RSKangXi=46.9, Def{Goulou mountain peak in hunan}
5D5E CJK UNIFIED IDEOGRAPH-#5D5E, IRGKangXi=0316.390, RSKangXi=46.10
5D5F CJK UNIFIED IDEOGRAPH-#5D5F, IRGKangXi=0317.070, RSKangXi=46.10
5D60 CJK UNIFIED IDEOGRAPH-#5D60, IRGKangXi=0317.080, RSKangXi=46.10, Def{a valley with a stream in it; a gorge}
5D61 CJK UNIFIED IDEOGRAPH-#5D61, IRGKangXi=0317.100, RSKangXi=46.10
5D62 CJK UNIFIED IDEOGRAPH-#5D62, IRGKangXi=0317.110, RSKangXi=46.10
5D63 CJK UNIFIED IDEOGRAPH-#5D63, IRGKangXi=0317.140, RSKangXi=46.10
5D64 CJK UNIFIED IDEOGRAPH-#5D64, IRGKangXi=0317.160, RSKangXi=46.10
5D65 CJK UNIFIED IDEOGRAPH-#5D65, IRGKangXi=0317.170, RSKangXi=46.10
5D66 CJK UNIFIED IDEOGRAPH-#5D66, IRGKangXi=0317.220, RSKangXi=46.10, Def{a raised site; pleasant}
5D67 CJK UNIFIED IDEOGRAPH-#5D67, IRGKangXi=0317.250, RSKangXi=46.10
5D68 CJK UNIFIED IDEOGRAPH-#5D68, IRGKangXi=0317.260, RSKangXi=46.10
5D69 CJK UNIFIED IDEOGRAPH-#5D69, IRGKangXi=0317.270, RSKangXi=46.10, Def{high, lofty; one of the 5 peaks, situated in Hunan}
5D6A CJK UNIFIED IDEOGRAPH-#5D6A, IRGKangXi=0317.290, RSKangXi=46.10
5D6B CJK UNIFIED IDEOGRAPH-#5D6B, IRGKangXi=0317.340, RSKangXi=46.10, Def{a hill in Shantung}
5D6C CJK UNIFIED IDEOGRAPH-#5D6C, IRGKangXi=0317.350, RSKangXi=46.10, Def{high; rugged, rocky, precipitous}
5D6D CJK UNIFIED IDEOGRAPH-#5D6D, IRGKangXi=0317.390, RSKangXi=46.10
5D6E CJK UNIFIED IDEOGRAPH-#5D6E, IRGKangXi=0317.410, RSKangXi=46.10
5D6F CJK UNIFIED IDEOGRAPH-#5D6F, IRGKangXi=0317.420, RSKangXi=46.10, Def{high, towering; irregular, rugged}
5D70 CJK UNIFIED IDEOGRAPH-#5D70, IRGKangXi=0317.430, RSKangXi=46.10
5D71 CJK UNIFIED IDEOGRAPH-#5D71, IRGKangXi=0317.440, RSKangXi=46.10
5D72 CJK UNIFIED IDEOGRAPH-#5D72, IRGKangXi=0317.450, RSKangXi=46.10
5D73 CJK UNIFIED IDEOGRAPH-#5D73, IRGKangXi=0317.500, RSKangXi=46.10, Def{high, towering; irregular, rugged}
5D74 CJK UNIFIED IDEOGRAPH-#5D74, IRGKangXi=0317.510, RSKangXi=46.10, Def{mountain ridge}
5D75 CJK UNIFIED IDEOGRAPH-#5D75, IRGKangXi=0317.521, RSKangXi=46.10
5D76 CJK UNIFIED IDEOGRAPH-#5D76, IRGKangXi=0317.521, RSKangXi=46.10, Def{low part of a mountain}
5D77 CJK UNIFIED IDEOGRAPH-#5D77, IRGKangXi=0317.550, RSKangXi=46.11
5D78 CJK UNIFIED IDEOGRAPH-#5D78, IRGKangXi=0318.010, RSKangXi=46.11
5D79 CJK UNIFIED IDEOGRAPH-#5D79, IRGKangXi=0318.020, RSKangXi=46.11
5D7A CJK UNIFIED IDEOGRAPH-#5D7A, IRGKangXi=0318.030, RSKangXi=46.11
5D7B CJK UNIFIED IDEOGRAPH-#5D7B, IRGKangXi=0318.040, RSKangXi=46.11
5D7C CJK UNIFIED IDEOGRAPH-#5D7C, IRGKangXi=0318.070, RSKangXi=46.11
5D7D CJK UNIFIED IDEOGRAPH-#5D7D, IRGKangXi=0318.090, RSKangXi=46.11
5D7E CJK UNIFIED IDEOGRAPH-#5D7E, IRGKangXi=0318.160, RSKangXi=46.11, Def{uneven}
5D7F CJK UNIFIED IDEOGRAPH-#5D7F, IRGKangXi=0318.180, RSKangXi=46.11
5D80 CJK UNIFIED IDEOGRAPH-#5D80, IRGKangXi=0318.200, RSKangXi=46.11
5D81 CJK UNIFIED IDEOGRAPH-#5D81, IRGKangXi=0318.250, RSKangXi=46.11, Def{Goulou mountain peak in Hunan}
5D82 CJK UNIFIED IDEOGRAPH-#5D82, IRGKangXi=0318.270, RSKangXi=46.11, Def{cliff; mountain barrier}
5D83 CJK UNIFIED IDEOGRAPH-#5D83, IRGKangXi=0318.290, RSKangXi=46.11, Def{a cliff, a peak}
5D84 CJK UNIFIED IDEOGRAPH-#5D84, IRGKangXi=0318.300, RSKangXi=46.11, Def{high, steep, precipitous; new}
5D85 CJK UNIFIED IDEOGRAPH-#5D85, IRGKangXi=0318.310
5D86 CJK UNIFIED IDEOGRAPH-#5D86, IRGKangXi=0318.410, RSKangXi=46.11
5D87 CJK UNIFIED IDEOGRAPH-#5D87, IRGKangXi=0318.430, RSKangXi=46.11, Def{steep, sheer; rugged, rough}
5D88 CJK UNIFIED IDEOGRAPH-#5D88, IRGKangXi=0319.030, RSKangXi=46.11
5D89 CJK UNIFIED IDEOGRAPH-#5D89, IRGKangXi=0319.040, RSKangXi=46.11
5D8A CJK UNIFIED IDEOGRAPH-#5D8A, IRGKangXi=0319.050, RSKangXi=46.11
5D8B CJK UNIFIED IDEOGRAPH-#5D8B, IRGKangXi=0319.080, RSKangXi=46.11, Def{island}
5D8C CJK UNIFIED IDEOGRAPH-#5D8C, IRGKangXi=0319.111, RSKangXi=46.11, Def{island}
5D8D CJK UNIFIED IDEOGRAPH-#5D8D, IRGKangXi=0319.111, RSKangXi=46.11
5D8E CJK UNIFIED IDEOGRAPH-#5D8E, IRGKangXi=0319.111, RSKangXi=46.11, Def{luxuriant, elegant}
5D8F CJK UNIFIED IDEOGRAPH-#5D8F, IRGKangXi=0319.130, RSKangXi=46.12
5D90 CJK UNIFIED IDEOGRAPH-#5D90, IRGKangXi=0319.160, RSKangXi=46.12
5D91 CJK UNIFIED IDEOGRAPH-#5D91, IRGKangXi=0319.170, RSKangXi=46.12
5D92 CJK UNIFIED IDEOGRAPH-#5D92, IRGKangXi=0319.270, RSKangXi=46.12, Def{towering, lofty, steep}
5D93 CJK UNIFIED IDEOGRAPH-#5D93, IRGKangXi=0319.310, RSKangXi=46.12, Def{Boshan, mountain in Shaanxi}
5D94 CJK UNIFIED IDEOGRAPH-#5D94, IRGKangXi=0319.320, RSKangXi=46.12, Def{lofty, towering}
5D95 CJK UNIFIED IDEOGRAPH-#5D95, IRGKangXi=0319.350, RSKangXi=46.12
5D96 CJK UNIFIED IDEOGRAPH-#5D96, IRGKangXi=0319.420, RSKangXi=46.12
5D97 CJK UNIFIED IDEOGRAPH-#5D97, IRGKangXi=0319.430, RSKangXi=46.12, Def{Laoshan, mountain in Shandong}
5D98 CJK UNIFIED IDEOGRAPH-#5D98, IRGKangXi=0319.440, RSKangXi=46.12
5D99 CJK UNIFIED IDEOGRAPH-#5D99, IRGKangXi=0319.450, RSKangXi=46.12, Def{precipitous}
5D9A CJK UNIFIED IDEOGRAPH-#5D9A, IRGKangXi=0319.460, RSKangXi=46.12
5D9B CJK UNIFIED IDEOGRAPH-#5D9B, IRGKangXi=0319.470, RSKangXi=46.12
5D9C CJK UNIFIED IDEOGRAPH-#5D9C, IRGKangXi=0320.010, RSKangXi=46.12
5D9D CJK UNIFIED IDEOGRAPH-#5D9D, IRGKangXi=0320.020, RSKangXi=46.12, Def{path leading up a mountain}
5D9E CJK UNIFIED IDEOGRAPH-#5D9E, IRGKangXi=0320.060, RSKangXi=46.12, Def{ridge}
5D9F CJK UNIFIED IDEOGRAPH-#5D9F, IRGKangXi=0320.070, RSKangXi=46.12
5DA0 CJK UNIFIED IDEOGRAPH-#5DA0, IRGKangXi=0320.080, RSKangXi=46.12, Def{high pointed mountain}
5DA1 CJK UNIFIED IDEOGRAPH-#5DA1, IRGKangXi=0320.090, RSKangXi=46.12, Def{table}
5DA2 CJK UNIFIED IDEOGRAPH-#5DA2, IRGKangXi=0320.100, RSKangXi=46.12, Def{high or tall}
5DA3 CJK UNIFIED IDEOGRAPH-#5DA3, IRGKangXi=0320.131, RSKangXi=46.12
5DA4 CJK UNIFIED IDEOGRAPH-#5DA4, IRGKangXi=0320.131, RSKangXi=46.12
5DA5 CJK UNIFIED IDEOGRAPH-#5DA5, IRGKangXi=0320.131
5DA6 CJK UNIFIED IDEOGRAPH-#5DA6, IRGKangXi=0320.140, RSKangXi=46.13
5DA7 CJK UNIFIED IDEOGRAPH-#5DA7, IRGKangXi=0320.150, RSKangXi=46.13, Def{a range of peaks in Shandong and Jiangsu; the name of a mountain}
5DA8 CJK UNIFIED IDEOGRAPH-#5DA8, IRGKangXi=0320.160, RSKangXi=46.13, Def{big rocky mountain}
5DA9 CJK UNIFIED IDEOGRAPH-#5DA9, IRGKangXi=0320.180, RSKangXi=46.13
5DAA CJK UNIFIED IDEOGRAPH-#5DAA, IRGKangXi=0320.190, RSKangXi=46.13
5DAB CJK UNIFIED IDEOGRAPH-#5DAB, IRGKangXi=0320.200, RSKangXi=46.13
5DAC CJK UNIFIED IDEOGRAPH-#5DAC, IRGKangXi=0320.230, RSKangXi=46.13
5DAD CJK UNIFIED IDEOGRAPH-#5DAD, IRGKangXi=0320.280, RSKangXi=46.13, Def{elevated, lofty}
5DAE CJK UNIFIED IDEOGRAPH-#5DAE, IRGKangXi=0320.310, RSKangXi=46.13, Def{high, steep, precipitous}
5DAF CJK UNIFIED IDEOGRAPH-#5DAF, IRGKangXi=0320.370, RSKangXi=46.13
5DB0 CJK UNIFIED IDEOGRAPH-#5DB0, IRGKangXi=0320.380, RSKangXi=46.13, Def{gorge}
5DB1 CJK UNIFIED IDEOGRAPH-#5DB1, IRGKangXi=0321.030, RSKangXi=46.13
5DB2 CJK UNIFIED IDEOGRAPH-#5DB2, IRGKangXi=0321.050, RSKangXi=46.13, Def{a name of an old town in Sichuan; cuckoo; revolution of a wheel}
5DB3 CJK UNIFIED IDEOGRAPH-#5DB3, IRGKangXi=0321.080, RSKangXi=46.13
5DB4 CJK UNIFIED IDEOGRAPH-#5DB4, IRGKangXi=0321.081, RSKangXi=46.13, Def{island}
5DB5 CJK UNIFIED IDEOGRAPH-#5DB5, IRGKangXi=0321.081, RSKangXi=46.13
5DB6 CJK UNIFIED IDEOGRAPH-#5DB6, IRGKangXi=0321.081, RSKangXi=46.13
5DB7 CJK UNIFIED IDEOGRAPH-#5DB7, IRGKangXi=0321.090, RSKangXi=46.14, Def{a range of mountains in Hunan province}
5DB8 CJK UNIFIED IDEOGRAPH-#5DB8, IRGKangXi=0321.120, RSKangXi=46.14, Def{high, steep; lofty, towering}
5DB9 CJK UNIFIED IDEOGRAPH-#5DB9, IRGKangXi=0321.130, RSKangXi=46.14
5DBA CJK UNIFIED IDEOGRAPH-#5DBA, IRGKangXi=0321.170, RSKangXi=46.14, Def{mountain ridge, mountain peak}
5DBB CJK UNIFIED IDEOGRAPH-#5DBB, IRGKangXi=0321.210, RSKangXi=46.16
5DBC CJK UNIFIED IDEOGRAPH-#5DBC, IRGKangXi=0321.250, RSKangXi=46.14, Def{island}
5DBD CJK UNIFIED IDEOGRAPH-#5DBD, IRGKangXi=0321.280, RSKangXi=46.14, Def{mountain peak, summit}
5DBE CJK UNIFIED IDEOGRAPH-#5DBE, IRGKangXi=0321.330, RSKangXi=46.14
5DBF CJK UNIFIED IDEOGRAPH-#5DBF, IRGKangXi=0321.361, RSKangXi=46.14
5DC0 CJK UNIFIED IDEOGRAPH-#5DC0, IRGKangXi=0322.061, RSKangXi=46.15
5DC1 CJK UNIFIED IDEOGRAPH-#5DC1, IRGKangXi=0322.020, RSKangXi=46.15
5DC2 CJK UNIFIED IDEOGRAPH-#5DC2, IRGKangXi=0322.061, RSKangXi=46.15, Def{place name}
5DC3 CJK UNIFIED IDEOGRAPH-#5DC3, IRGKangXi=0322.090, RSKangXi=46.16, Def{lofty}
5DC4 CJK UNIFIED IDEOGRAPH-#5DC4, IRGKangXi=0322.181, RSKangXi=46.16
5DC5 CJK UNIFIED IDEOGRAPH-#5DC5, IRGKangXi=0322.181, RSKangXi=46.16, Def{summit of mountain, mountain top}
5DC6 CJK UNIFIED IDEOGRAPH-#5DC6, IRGKangXi=0322.190, RSKangXi=46.17
5DC7 CJK UNIFIED IDEOGRAPH-#5DC7, IRGKangXi=0322.200, RSKangXi=46.17, Def{a crack; hazardous}
5DC8 CJK UNIFIED IDEOGRAPH-#5DC8, IRGKangXi=0322.230, RSKangXi=46.17
5DC9 CJK UNIFIED IDEOGRAPH-#5DC9, IRGKangXi=0322.240, RSKangXi=46.17, Def{steep, rugged, jagged, precipitous}
5DCA CJK UNIFIED IDEOGRAPH-#5DCA, IRGKangXi=0322.270, RSKangXi=46.17
5DCB CJK UNIFIED IDEOGRAPH-#5DCB, IRGKangXi=0322.280, RSKangXi=46.17, Def{grand, stately; secure, lasting}
5DCC CJK UNIFIED IDEOGRAPH-#5DCC, IRGKangXi=0322.291, RSKangXi=46.17, Def{cliff, precipice; cave, grotto}
5DCD CJK UNIFIED IDEOGRAPH-#5DCD, IRGKangXi=0322.320, RSKangXi=46.18, Def{high, lofty, majestic, eminent}
5DCE CJK UNIFIED IDEOGRAPH-#5DCE, IRGKangXi=0322.340, RSKangXi=46.19
5DCF CJK UNIFIED IDEOGRAPH-#5DCF, IRGKangXi=0322.350, RSKangXi=46.18
5DD0 CJK UNIFIED IDEOGRAPH-#5DD0, IRGKangXi=0322.360, RSKangXi=46.18
5DD1 CJK UNIFIED IDEOGRAPH-#5DD1, IRGKangXi=0322.410, RSKangXi=46.19
5DD2 CJK UNIFIED IDEOGRAPH-#5DD2, IRGKangXi=0322.430, RSKangXi=46.19, Def{mountain range; pointed mountain}
5DD3 CJK UNIFIED IDEOGRAPH-#5DD3, IRGKangXi=0323.040, RSKangXi=46.19, Def{summit of mountain}
5DD4 CJK UNIFIED IDEOGRAPH-#5DD4, IRGKangXi=0323.061, RSKangXi=46.19, Def{summit of mountain, mountain top}
5DD5 CJK UNIFIED IDEOGRAPH-#5DD5, IRGKangXi=0323.061, RSKangXi=46.19
5DD6 CJK UNIFIED IDEOGRAPH-#5DD6, IRGKangXi=0323.070, RSKangXi=46.20, Def{cliff, precipice; cave, grotto}
5DD7 CJK UNIFIED IDEOGRAPH-#5DD7, IRGKangXi=0323.080, RSKangXi=46.20
5DD8 CJK UNIFIED IDEOGRAPH-#5DD8, IRGKangXi=0323.090, RSKangXi=46.20, Def{summit, peak}
5DD9 CJK UNIFIED IDEOGRAPH-#5DD9, IRGKangXi=0323.100, RSKangXi=46.20
5DDA CJK UNIFIED IDEOGRAPH-#5DDA, IRGKangXi=0323.101, RSKangXi=46.20
5DDB CJK UNIFIED IDEOGRAPH-#5DDB, IRGKangXi=0323.180, RSKangXi=47.0, Def{river; KangXi radical 47}
5DDC CJK UNIFIED IDEOGRAPH-#5DDC, IRGKangXi=0323.220, RSKangXi=47.-1
5DDD CJK UNIFIED IDEOGRAPH-#5DDD, IRGKangXi=0323.230, RSKangXi=47.0, Def{stream, river; flow; boil}
5DDE CJK UNIFIED IDEOGRAPH-#5DDE, IRGKangXi=0324.010, RSKangXi=47.3, Def{administrative division, state}
5DDF CJK UNIFIED IDEOGRAPH-#5DDF, IRGKangXi=0324.060, RSKangXi=47.3, Def{a watery waste; to reach}
5DE0 CJK UNIFIED IDEOGRAPH-#5DE0, IRGKangXi=0324.070, RSKangXi=47.4, Def{streams running underground; flowing water}
5DE1 CJK UNIFIED IDEOGRAPH-#5DE1, IRGKangXi=0324.110, RSKangXi=47.4, Def{patrol, go on circuit, cruise}
5DE2 CJK UNIFIED IDEOGRAPH-#5DE2, IRGKangXi=0324.170, RSKangXi=47.8, Def{nest, living quarter in tree}
5DE3 CJK UNIFIED IDEOGRAPH-#5DE3, IRGKangXi=0531.131, RSKangXi=47.8, Def{nest, living quarter in tree}
5DE4 CJK UNIFIED IDEOGRAPH-#5DE4, IRGKangXi=0324.220, RSKangXi=47.12, Def{a mane; bristles, as on a hog; dorsal fins}
5DE5 CJK UNIFIED IDEOGRAPH-#5DE5, IRGKangXi=0325.010, RSKangXi=48.0, Def{labor, work; worker, laborer}
5DE6 CJK UNIFIED IDEOGRAPH-#5DE6, IRGKangXi=0325.080, RSKangXi=48.2, Def{left; east; unorthodox, improper}
5DE7 CJK UNIFIED IDEOGRAPH-#5DE7, IRGKangXi=0325.090, RSKangXi=48.2, Def{skillful, ingenious, clever}
5DE8 CJK UNIFIED IDEOGRAPH-#5DE8, IRGKangXi=0325.120, RSKangXi=48.2, Def{large, great, enormous; chief}
5DE9 CJK UNIFIED IDEOGRAPH-#5DE9, IRGKangXi=0325.160, RSKangXi=48.3, Def{bind; firm, secure, strong}
5DEA CJK UNIFIED IDEOGRAPH-#5DEA, IRGKangXi=0325.171, RSKangXi=48.3, Def{person's name}
5DEB CJK UNIFIED IDEOGRAPH-#5DEB, IRGKangXi=0325.190, RSKangXi=48.4, Def{wizard, sorcerer, witch, shaman}
5DEC CJK UNIFIED IDEOGRAPH-#5DEC, IRGKangXi=0326.011, RSKangXi=16.7
5DED CJK UNIFIED IDEOGRAPH-#5DED, IRGKangXi=0326.011, RSKangXi=19.7, Def{study}
5DEE CJK UNIFIED IDEOGRAPH-#5DEE, IRGKangXi=0326.020, RSKangXi=48.7, Def{to differ; different, wrong; nearly, almost; an officer}
5DEF CJK UNIFIED IDEOGRAPH-#5DEF, IRGKangXi=0326.051, RSKangXi=48.9, Def{an atom group}
5DF0 CJK UNIFIED IDEOGRAPH-#5DF0, IRGKangXi=0326.051, RSKangXi=48.10, Def{an atom group}
5DF1 CJK UNIFIED IDEOGRAPH-#5DF1, IRGKangXi=0326.090, RSKangXi=49.0, Def{self, oneself; personal, private; 6th heavenly stem}
5DF2 CJK UNIFIED IDEOGRAPH-#5DF2, IRGKangXi=0326.110, RSKangXi=49.0, Def{already; finished; stop}
5DF3 CJK UNIFIED IDEOGRAPH-#5DF3, IRGKangXi=0326.120, RSKangXi=49.0, Def{the hours from 9 to 11; 6th terrestrial branch}
5DF4 CJK UNIFIED IDEOGRAPH-#5DF4, IRGKangXi=0327.010, RSKangXi=49.1, Def{greatly desire, anxiously hope}
5DF5 CJK UNIFIED IDEOGRAPH-#5DF5, IRGKangXi=0327.040, RSKangXi=49.4, Def{measuring cup; wine container}
5DF6 CJK UNIFIED IDEOGRAPH-#5DF6, IRGKangXi=0327.050, RSKangXi=49.5
5DF7 CJK UNIFIED IDEOGRAPH-#5DF7, IRGKangXi=0327.090, RSKangXi=49.6, Def{alley, lane}
5DF8 CJK UNIFIED IDEOGRAPH-#5DF8, IRGKangXi=0327.100, RSKangXi=49.6
5DF9 CJK UNIFIED IDEOGRAPH-#5DF9, IRGKangXi=0327.101, RSKangXi=49.6
5DFA CJK UNIFIED IDEOGRAPH-#5DFA, IRGKangXi=0327.101, Def{5th of the 8 trigrams; South-east; mild, modest, obedient}
5DFB CJK UNIFIED IDEOGRAPH-#5DFB, IRGKangXi=0327.101, RSKangXi=26.6, Def{scroll; curl; make a comeback}
5DFC CJK UNIFIED IDEOGRAPH-#5DFC, IRGKangXi=0327.101, RSKangXi=49.7, Def{place name}
5DFD CJK UNIFIED IDEOGRAPH-#5DFD, IRGKangXi=0327.160, RSKangXi=49.9, Def{5th of the 8 trigrams; south-east; mild, modest, obedient}
5DFE CJK UNIFIED IDEOGRAPH-#5DFE, IRGKangXi=0327.200, RSKangXi=50.0, Def{kerchief; towel; turban; KangXi radical number 50}
5DFF CJK UNIFIED IDEOGRAPH-#5DFF, IRGKangXi=0328.010, RSKangXi=50.1, Def{revolve, make circuit, turn}
5E00 CJK UNIFIED IDEOGRAPH-#5E00, IRGKangXi=0328.020, RSKangXi=50.1, Def{to go round, to make a circuit, to make a revolution, to turn round}
5E01 CJK UNIFIED IDEOGRAPH-#5E01, IRGKangXi=0328.021, RSKangXi=50.1, Def{currency, coins, legal tender}
5E02 CJK UNIFIED IDEOGRAPH-#5E02, IRGKangXi=0328.030, RSKangXi=50.2, Def{market, fair; city, town; trade}
5E03 CJK UNIFIED IDEOGRAPH-#5E03, IRGKangXi=0328.060, RSKangXi=50.2, Def{cotton cloth, textiles, linen}
5E04 CJK UNIFIED IDEOGRAPH-#5E04, IRGKangXi=0328.081, RSKangXi=50.2
5E05 CJK UNIFIED IDEOGRAPH-#5E05, IRGKangXi=0328.081, RSKangXi=50.2, Def{commander, commander-in-chief}
5E06 CJK UNIFIED IDEOGRAPH-#5E06, IRGKangXi=0328.140, RSKangXi=50.3, Def{sail; boat}
5E07 CJK UNIFIED IDEOGRAPH-#5E07, IRGKangXi=0329.020, RSKangXi=50.3
5E08 CJK UNIFIED IDEOGRAPH-#5E08, IRGKangXi=0329.051, RSKangXi=50.3, Def{teacher, master, specialist}
5E09 CJK UNIFIED IDEOGRAPH-#5E09, IRGKangXi=0329.070, RSKangXi=50.4
5E0A CJK UNIFIED IDEOGRAPH-#5E0A, IRGKangXi=0329.130, RSKangXi=50.4
5E0B CJK UNIFIED IDEOGRAPH-#5E0B, IRGKangXi=0329.140, RSKangXi=50.4, Def{paper; stationary; document}
5E0C CJK UNIFIED IDEOGRAPH-#5E0C, IRGKangXi=0329.180, RSKangXi=50.4, Def{rare; hope, expect, strive for}
5E0D CJK UNIFIED IDEOGRAPH-#5E0D, IRGKangXi=0329.210, RSKangXi=50.4
5E0E CJK UNIFIED IDEOGRAPH-#5E0E, IRGKangXi=0329.270, RSKangXi=50.4, Def{(Cant.) a way of playing snooker with the stick on top of one's thumb}
5E0F CJK UNIFIED IDEOGRAPH-#5E0F, IRGKangXi=0329.291, RSKangXi=50.4, Def{curtain that forms wall}
5E10 CJK UNIFIED IDEOGRAPH-#5E10, IRGKangXi=0329.291, RSKangXi=50.4, Def{tent; screen, mosquito net}
5E11 CJK UNIFIED IDEOGRAPH-#5E11, IRGKangXi=0329.340, RSKangXi=50.5, Def{a treasury; public funds}
5E12 CJK UNIFIED IDEOGRAPH-#5E12, IRGKangXi=0329.390, RSKangXi=50.5, Def{a bag, a sack; a case; a pocket, a pouch}
5E13 CJK UNIFIED IDEOGRAPH-#5E13, IRGKangXi=0329.400, RSKangXi=50.5
5E14 CJK UNIFIED IDEOGRAPH-#5E14, IRGKangXi=0329.420, RSKangXi=50.5, Def{a skirt; long robe for women, having no sleeves and fasten down the front}
5E15 CJK UNIFIED IDEOGRAPH-#5E15, IRGKangXi=0329.440, RSKangXi=50.5, Def{turban, kerchief, veil; wrap}
5E16 CJK UNIFIED IDEOGRAPH-#5E16, IRGKangXi=0330.010, RSKangXi=50.5, Def{invitation card; notice}
5E17 CJK UNIFIED IDEOGRAPH-#5E17, IRGKangXi=0330.020, RSKangXi=50.5, Def{a multicolored prop used in dancing}
5E18 CJK UNIFIED IDEOGRAPH-#5E18, IRGKangXi=0330.030, RSKangXi=50.5, Def{flag-sign of a tavern}
5E19 CJK UNIFIED IDEOGRAPH-#5E19, IRGKangXi=0330.040, RSKangXi=50.5, Def{book cover; satchel or bag}
5E1A CJK UNIFIED IDEOGRAPH-#5E1A, IRGKangXi=0330.060, RSKangXi=50.5, Def{broom, broomstick}
5E1B CJK UNIFIED IDEOGRAPH-#5E1B, IRGKangXi=0330.070, RSKangXi=50.5, Def{silks, fabrics; wealth, property}
5E1C CJK UNIFIED IDEOGRAPH-#5E1C, IRGKangXi=0330.131, RSKangXi=50.5, Def{flag, pennant; sign; fasten}
5E1D CJK UNIFIED IDEOGRAPH-#5E1D, IRGKangXi=0330.140, RSKangXi=50.6, Def{supreme ruler, emperor; god}
5E1E CJK UNIFIED IDEOGRAPH-#5E1E, IRGKangXi=0330.180, RSKangXi=50.6
5E1F CJK UNIFIED IDEOGRAPH-#5E1F, IRGKangXi=0330.230, RSKangXi=50.6, Def{tent}
5E20 CJK UNIFIED IDEOGRAPH-#5E20, IRGKangXi=0331.030, RSKangXi=50.6
5E21 CJK UNIFIED IDEOGRAPH-#5E21, IRGKangXi=0331.040, RSKangXi=50.6, Def{shelter, screen, awning}
5E22 CJK UNIFIED IDEOGRAPH-#5E22, IRGKangXi=0331.050, RSKangXi=50.6
5E23 CJK UNIFIED IDEOGRAPH-#5E23, IRGKangXi=0331.060, RSKangXi=50.6, Def{bag}
5E24 CJK UNIFIED IDEOGRAPH-#5E24, IRGKangXi=0331.090, RSKangXi=50.6
5E25 CJK UNIFIED IDEOGRAPH-#5E25, IRGKangXi=0331.110, RSKangXi=50.6, Def{commander, commander-in-chief}
5E26 CJK UNIFIED IDEOGRAPH-#5E26, IRGKangXi=0331.191, RSKangXi=50.6, Def{belt, girdle, band, strap, zone}
5E27 CJK UNIFIED IDEOGRAPH-#5E27, IRGKangXi=0331.191, RSKangXi=50.6, Def{picture, scroll; one of pair of}
5E28 CJK UNIFIED IDEOGRAPH-#5E28, IRGKangXi=0331.230, RSKangXi=50.7, Def{handkerchief, kerchief, shawl}
5E29 CJK UNIFIED IDEOGRAPH-#5E29, IRGKangXi=0331.290, RSKangXi=50.7
5E2A CJK UNIFIED IDEOGRAPH-#5E2A, IRGKangXi=0331.330, RSKangXi=50.7
5E2B CJK UNIFIED IDEOGRAPH-#5E2B, IRGKangXi=0331.350, RSKangXi=50.7, Def{teacher, master, specialist; multitude, troops}
5E2C CJK UNIFIED IDEOGRAPH-#5E2C, IRGKangXi=0332.030, RSKangXi=50.7, Def{the skirt of a lady's dress petticoat}
5E2D CJK UNIFIED IDEOGRAPH-#5E2D, IRGKangXi=0332.080, RSKangXi=50.7, Def{seat; mat; take seat; banquet}
5E2E CJK UNIFIED IDEOGRAPH-#5E2E, IRGKangXi=0332.121, RSKangXi=50.7, Def{help, assist; defend; shoe upper}
5E2F CJK UNIFIED IDEOGRAPH-#5E2F, IRGKangXi=0332.121, RSKangXi=50.7, Def{belt}
5E30 CJK UNIFIED IDEOGRAPH-#5E30, IRGKangXi=0332.121, RSKangXi=50.7, Def{return; return to, revert to}
5E31 CJK UNIFIED IDEOGRAPH-#5E31, IRGKangXi=0332.121, RSKangXi=50.7, Def{cover up; curtain}
5E32 CJK UNIFIED IDEOGRAPH-#5E32, IRGKangXi=0332.190, RSKangXi=50.8, Def{shelter}
5E33 CJK UNIFIED IDEOGRAPH-#5E33, IRGKangXi=0332.200, RSKangXi=50.8, Def{tent; screen, mosquito net}
5E34 CJK UNIFIED IDEOGRAPH-#5E34, IRGKangXi=0332.230, RSKangXi=50.8
5E35 CJK UNIFIED IDEOGRAPH-#5E35, IRGKangXi=0333.050, RSKangXi=50.8, Def{remnants, tailor's cutting}
5E36 CJK UNIFIED IDEOGRAPH-#5E36, IRGKangXi=0333.060, RSKangXi=50.8, Def{belt, girdle, band, strap, zone}
5E37 CJK UNIFIED IDEOGRAPH-#5E37, IRGKangXi=0333.100, RSKangXi=50.8, Def{tent; curtain, screen}
5E38 CJK UNIFIED IDEOGRAPH-#5E38, IRGKangXi=0333.120, RSKangXi=50.8, Def{common, normal, frequent, regular}
5E39 CJK UNIFIED IDEOGRAPH-#5E39, IRGKangXi=0333.150, RSKangXi=50.8
5E3A CJK UNIFIED IDEOGRAPH-#5E3A, IRGKangXi=0333.161, RSKangXi=50.8
5E3B CJK UNIFIED IDEOGRAPH-#5E3B, IRGKangXi=0333.161, RSKangXi=50.8, Def{turban; conical cap}
5E3C CJK UNIFIED IDEOGRAPH-#5E3C, IRGKangXi=0333.161, RSKangXi=50.8, Def{women's headgear; mourning cap}
5E3D CJK UNIFIED IDEOGRAPH-#5E3D, IRGKangXi=0333.190, RSKangXi=50.9, Def{hat, cap; cap-like tops}
5E3E CJK UNIFIED IDEOGRAPH-#5E3E, IRGKangXi=0333.220, RSKangXi=50.9
5E3F CJK UNIFIED IDEOGRAPH-#5E3F, IRGKangXi=0334.050, RSKangXi=50.9, Def{marquis, lord; target in archery}
5E40 CJK UNIFIED IDEOGRAPH-#5E40, IRGKangXi=0334.060, RSKangXi=50.9, Def{picture, scroll; one of pair of}
5E41 CJK UNIFIED IDEOGRAPH-#5E41, IRGKangXi=0334.080, RSKangXi=50.9
5E42 CJK UNIFIED IDEOGRAPH-#5E42, IRGKangXi=0334.100, RSKangXi=14.10, Def{cover-cloth, cover with cloth}
5E43 CJK UNIFIED IDEOGRAPH-#5E43, IRGKangXi=0334.180, RSKangXi=50.9, Def{curtain that forms wall}
5E44 CJK UNIFIED IDEOGRAPH-#5E44, IRGKangXi=0334.200, RSKangXi=50.9, Def{tent; mosquito net}
5E45 CJK UNIFIED IDEOGRAPH-#5E45, IRGKangXi=0334.210, RSKangXi=50.9, Def{piece, strip, breadth of, hem}
5E46 CJK UNIFIED IDEOGRAPH-#5E46, IRGKangXi=0334.220, RSKangXi=50.9
5E47 CJK UNIFIED IDEOGRAPH-#5E47, IRGKangXi=0334.250, RSKangXi=50.9, Def{help, assist; defend; shoe upper}
5E48 CJK UNIFIED IDEOGRAPH-#5E48, IRGKangXi=0334.291, RSKangXi=50.11
5E49 CJK UNIFIED IDEOGRAPH-#5E49, IRGKangXi=0334.291, RSKangXi=50.9
5E4A CJK UNIFIED IDEOGRAPH-#5E4A, IRGKangXi=0334.380, RSKangXi=50.10
5E4B CJK UNIFIED IDEOGRAPH-#5E4B, IRGKangXi=0334.390, RSKangXi=50.10, Def{belt}
5E4C CJK UNIFIED IDEOGRAPH-#5E4C, IRGKangXi=0335.020, RSKangXi=50.10, Def{curtain, cloth screen}
5E4D CJK UNIFIED IDEOGRAPH-#5E4D, IRGKangXi=0335.030, RSKangXi=50.10
5E4E CJK UNIFIED IDEOGRAPH-#5E4E, IRGKangXi=0335.040, RSKangXi=50.10, Def{cover-cloth, cover with cloth}
5E4F CJK UNIFIED IDEOGRAPH-#5E4F, IRGKangXi=0335.060, RSKangXi=50.10
5E50 CJK UNIFIED IDEOGRAPH-#5E50, IRGKangXi=0335.151, RSKangXi=50.10
5E51 CJK UNIFIED IDEOGRAPH-#5E51, IRGKangXi=0335.190, RSKangXi=50.11
5E52 CJK UNIFIED IDEOGRAPH-#5E52, IRGKangXi=0335.210, RSKangXi=50.11
5E53 CJK UNIFIED IDEOGRAPH-#5E53, IRGKangXi=0335.250, RSKangXi=50.11
5E54 CJK UNIFIED IDEOGRAPH-#5E54, IRGKangXi=0335.280, RSKangXi=50.11, Def{curtain, screen, tent}
5E55 CJK UNIFIED IDEOGRAPH-#5E55, IRGKangXi=0335.290, RSKangXi=50.11, Def{curtain, screen, tent}
5E56 CJK UNIFIED IDEOGRAPH-#5E56, IRGKangXi=0336.010, RSKangXi=50.11
5E57 CJK UNIFIED IDEOGRAPH-#5E57, IRGKangXi=0336.050, RSKangXi=50.11, Def{women's headgear; mourning cap}
5E58 CJK UNIFIED IDEOGRAPH-#5E58, IRGKangXi=0336.060, RSKangXi=50.11, Def{turban; conical cap}
5E59 CJK UNIFIED IDEOGRAPH-#5E59, IRGKangXi=0336.080, RSKangXi=50.11, Def{a curtain, a screen}
5E5A CJK UNIFIED IDEOGRAPH-#5E5A, IRGKangXi=0337.031, Def{help, assist; defend; shoe upper}
5E5B CJK UNIFIED IDEOGRAPH-#5E5B, IRGKangXi=0336.081, RSKangXi=50.11, Def{scroll of silk or cloth bearing a congratulatory message}
5E5C CJK UNIFIED IDEOGRAPH-#5E5C, IRGKangXi=0336.090, RSKangXi=50.12
5E5D CJK UNIFIED IDEOGRAPH-#5E5D, IRGKangXi=0336.150, RSKangXi=50.12
5E5E CJK UNIFIED IDEOGRAPH-#5E5E, IRGKangXi=0336.200, RSKangXi=50.12, Def{turban}
5E5F CJK UNIFIED IDEOGRAPH-#5E5F, IRGKangXi=0336.210, RSKangXi=50.12, Def{flag, pennant; sign; fasten}
5E60 CJK UNIFIED IDEOGRAPH-#5E60, IRGKangXi=0336.220, RSKangXi=50.12, Def{cover}
5E61 CJK UNIFIED IDEOGRAPH-#5E61, IRGKangXi=0336.260, RSKangXi=50.12, Def{pennant, banner, streamer, flag}
5E62 CJK UNIFIED IDEOGRAPH-#5E62, IRGKangXi=0337.010, RSKangXi=50.12, Def{carriage curtain; sun screen}
5E63 CJK UNIFIED IDEOGRAPH-#5E63, IRGKangXi=0337.020, RSKangXi=50.12, Def{currency, coins, legal tender}
5E64 CJK UNIFIED IDEOGRAPH-#5E64, IRGKangXi=0337.031, RSKangXi=50.12, Def{evil, wrong, bad; criminal}
5E65 CJK UNIFIED IDEOGRAPH-#5E65, IRGKangXi=0337.031, RSKangXi=50.12
5E66 CJK UNIFIED IDEOGRAPH-#5E66, IRGKangXi=0337.060, RSKangXi=50.13, Def{cover}
5E67 CJK UNIFIED IDEOGRAPH-#5E67, IRGKangXi=0337.080, RSKangXi=50.13
5E68 CJK UNIFIED IDEOGRAPH-#5E68, IRGKangXi=0337.090, RSKangXi=50.13, Def{curtain}
5E69 CJK UNIFIED IDEOGRAPH-#5E69, IRGKangXi=0337.150, RSKangXi=50.13, Def{trappings}
5E6A CJK UNIFIED IDEOGRAPH-#5E6A, IRGKangXi=0337.200, RSKangXi=50.14, Def{cover, shelter, screen; protect}
5E6B CJK UNIFIED IDEOGRAPH-#5E6B, IRGKangXi=0337.230, RSKangXi=50.14, Def{to help, assist; to defend; shoe upper}
5E6C CJK UNIFIED IDEOGRAPH-#5E6C, IRGKangXi=0338.010, RSKangXi=50.14, Def{cover up; curtain}
5E6D CJK UNIFIED IDEOGRAPH-#5E6D, IRGKangXi=0338.030, RSKangXi=50.15, Def{cover}
5E6E CJK UNIFIED IDEOGRAPH-#5E6E, IRGKangXi=0338.040, RSKangXi=50.15, Def{a screen used to make a temporary kitchen}
5E6F CJK UNIFIED IDEOGRAPH-#5E6F, IRGKangXi=0338.050, RSKangXi=50.15
5E70 CJK UNIFIED IDEOGRAPH-#5E70, IRGKangXi=0338.130, RSKangXi=50.16, Def{curtain at front of carriage}
5E71 CJK UNIFIED IDEOGRAPH-#5E71, IRGKangXi=0338.160, RSKangXi=50.17, Def{official dress}
5E72 CJK UNIFIED IDEOGRAPH-#5E72, IRGKangXi=0339.010, RSKangXi=51.0, Def{oppose, offend; invade; dried}
5E73 CJK UNIFIED IDEOGRAPH-#5E73, IRGKangXi=0339.030, RSKangXi=51.2, Def{flat, level, even; peaceful}
5E74 CJK UNIFIED IDEOGRAPH-#5E74, IRGKangXi=0340.010, RSKangXi=51.3, Def{year; new-years; person's age}
5E75 CJK UNIFIED IDEOGRAPH-#5E75, IRGKangXi=0340.030, RSKangXi=51.3, Def{even level. to raise in both hands}
5E76 CJK UNIFIED IDEOGRAPH-#5E76, IRGKangXi=0340.031, RSKangXi=51.5, Def{combine, annex; also, what's more}
5E77 CJK UNIFIED IDEOGRAPH-#5E77, IRGKangXi=0340.070, RSKangXi=51.5, Def{combine}
5E78 CJK UNIFIED IDEOGRAPH-#5E78, IRGKangXi=0341.010, RSKangXi=51.5, Def{luck(ily), favor, fortunately}
5E79 CJK UNIFIED IDEOGRAPH-#5E79, IRGKangXi=0341.090, RSKangXi=51.10, Def{trunk of tree or of human body}
5E7A CJK UNIFIED IDEOGRAPH-#5E7A, IRGKangXi=0341.120, RSKangXi=52.0, Def{one; tiny, small}
5E7B CJK UNIFIED IDEOGRAPH-#5E7B, IRGKangXi=0341.130, RSKangXi=52.1, Def{illusion, fantasy, mirage}
5E7C CJK UNIFIED IDEOGRAPH-#5E7C, IRGKangXi=0342.020, RSKangXi=52.2, Def{infant, young child; immature}
5E7D CJK UNIFIED IDEOGRAPH-#5E7D, IRGKangXi=0342.120, RSKangXi=52.6, Def{quiet, secluded, tranquil; dark}
5E7E CJK UNIFIED IDEOGRAPH-#5E7E, IRGKangXi=0342.140, RSKangXi=52.9, Def{how many? how much?; a few, some}
5E7F CJK UNIFIED IDEOGRAPH-#5E7F, IRGKangXi=0343.050, RSKangXi=53.0, Def{wide, extensive, broad; rad. 53}
5E80 CJK UNIFIED IDEOGRAPH-#5E80, IRGKangXi=0343.060, RSKangXi=53.2, Def{to prepare; to regulate to hand up}
5E81 CJK UNIFIED IDEOGRAPH-#5E81, IRGKangXi=0343.070, RSKangXi=53.2, Def{hall, central room}
5E82 CJK UNIFIED IDEOGRAPH-#5E82, IRGKangXi=0343.080, RSKangXi=53.2
5E83 CJK UNIFIED IDEOGRAPH-#5E83, IRGKangXi=0343.081, RSKangXi=53.2, Def{broad, wide, extensive}
5E84 CJK UNIFIED IDEOGRAPH-#5E84, IRGKangXi=0343.180, RSKangXi=53.3, Def{village, hamlet; villa, manor}
5E85 CJK UNIFIED IDEOGRAPH-#5E85, IRGKangXi=0343.201, RSKangXi=53.3, Def{an interrogative particle}
5E86 CJK UNIFIED IDEOGRAPH-#5E86, IRGKangXi=0343.201, RSKangXi=53.3, Def{congratulate, celebrate}
5E87 CJK UNIFIED IDEOGRAPH-#5E87, IRGKangXi=0343.210, RSKangXi=53.4, Def{cover, shield, shelter, protect}
5E88 CJK UNIFIED IDEOGRAPH-#5E88, IRGKangXi=0343.220, RSKangXi=53.4, Def{used in person's names}
5E89 CJK UNIFIED IDEOGRAPH-#5E89, IRGKangXi=0343.230, RSKangXi=53.4, Def{a village; to dwell together}
5E8A CJK UNIFIED IDEOGRAPH-#5E8A, IRGKangXi=0343.240, RSKangXi=53.4, Def{bed, couch; framework, chassis}
5E8B CJK UNIFIED IDEOGRAPH-#5E8B, IRGKangXi=0343.270, RSKangXi=53.4, Def{a cupboard or pantry to store}
5E8C CJK UNIFIED IDEOGRAPH-#5E8C, IRGKangXi=0343.280, RSKangXi=53.4
5E8D CJK UNIFIED IDEOGRAPH-#5E8D, IRGKangXi=0343.290, RSKangXi=53.4
5E8E CJK UNIFIED IDEOGRAPH-#5E8E, IRGKangXi=0343.300, RSKangXi=53.4
5E8F CJK UNIFIED IDEOGRAPH-#5E8F, IRGKangXi=0343.350, RSKangXi=53.4, Def{series, serial order, sequence}
5E90 CJK UNIFIED IDEOGRAPH-#5E90, IRGKangXi=0344.051, RSKangXi=53.4, Def{hut, cottage; name of a mountain}
5E91 CJK UNIFIED IDEOGRAPH-#5E91, IRGKangXi=0344.051, RSKangXi=53.4, Def{corridor, hallway; luxuriant}
5E92 CJK UNIFIED IDEOGRAPH-#5E92, IRGKangXi=0344.051, RSKangXi=53.4
5E93 CJK UNIFIED IDEOGRAPH-#5E93, IRGKangXi=0344.051, RSKangXi=53.4, Def{armory, treasury, storehouse}
5E94 CJK UNIFIED IDEOGRAPH-#5E94, IRGKangXi=0344.051, RSKangXi=53.4, Def{should, ought to, must}
5E95 CJK UNIFIED IDEOGRAPH-#5E95, IRGKangXi=0344.060, RSKangXi=53.5, Def{bottom, underneath, underside}
5E96 CJK UNIFIED IDEOGRAPH-#5E96, IRGKangXi=0344.100, RSKangXi=53.5, Def{kitchen; cooking, cuisine}
5E97 CJK UNIFIED IDEOGRAPH-#5E97, IRGKangXi=0344.110, RSKangXi=53.5, Def{shop, store; inn, hotel}
5E98 CJK UNIFIED IDEOGRAPH-#5E98, IRGKangXi=0344.180, RSKangXi=53.4
5E99 CJK UNIFIED IDEOGRAPH-#5E99, IRGKangXi=0344.200, RSKangXi=53.5, Def{temple, shrine; imperial court}
5E9A CJK UNIFIED IDEOGRAPH-#5E9A, IRGKangXi=0344.220, RSKangXi=53.5, Def{7th heavenly stem}
5E9B CJK UNIFIED IDEOGRAPH-#5E9B, IRGKangXi=0345.010, RSKangXi=53.5
5E9C CJK UNIFIED IDEOGRAPH-#5E9C, IRGKangXi=0345.020, RSKangXi=53.5, Def{prefecture; prefect; government}
5E9D CJK UNIFIED IDEOGRAPH-#5E9D, IRGKangXi=0345.040, RSKangXi=53.5
5E9E CJK UNIFIED IDEOGRAPH-#5E9E, IRGKangXi=0345.081, RSKangXi=53.5, Def{disorderly, messy; huge, big}
5E9F CJK UNIFIED IDEOGRAPH-#5E9F, IRGKangXi=0345.081, RSKangXi=53.5, Def{abrogate, terminate, discard}
5EA0 CJK UNIFIED IDEOGRAPH-#5EA0, IRGKangXi=0345.110, RSKangXi=53.6, Def{village school; teach}
5EA1 CJK UNIFIED IDEOGRAPH-#5EA1, IRGKangXi=0345.180, RSKangXi=53.6
5EA2 CJK UNIFIED IDEOGRAPH-#5EA2, IRGKangXi=0345.200, RSKangXi=53.6
5EA3 CJK UNIFIED IDEOGRAPH-#5EA3, IRGKangXi=0345.210, RSKangXi=53.6
5EA4 CJK UNIFIED IDEOGRAPH-#5EA4, IRGKangXi=0345.230, RSKangXi=53.6, Def{prepare}
5EA5 CJK UNIFIED IDEOGRAPH-#5EA5, IRGKangXi=0345.240, RSKangXi=53.6, Def{shade; shelter, protection}
5EA6 CJK UNIFIED IDEOGRAPH-#5EA6, IRGKangXi=0345.260, RSKangXi=53.6, Def{degree, system; manner; to consider}
5EA7 CJK UNIFIED IDEOGRAPH-#5EA7, IRGKangXi=0346.030, RSKangXi=53.7, Def{seat; stand, base}
5EA8 CJK UNIFIED IDEOGRAPH-#5EA8, IRGKangXi=0346.050, RSKangXi=53.7
5EA9 CJK UNIFIED IDEOGRAPH-#5EA9, IRGKangXi=0346.090, RSKangXi=53.7
5EAA CJK UNIFIED IDEOGRAPH-#5EAA, IRGKangXi=0346.130, RSKangXi=53.7
5EAB CJK UNIFIED IDEOGRAPH-#5EAB, IRGKangXi=0346.140, RSKangXi=53.7, Def{armory, treasury, storehouse}
5EAC CJK UNIFIED IDEOGRAPH-#5EAC, IRGKangXi=0346.170, RSKangXi=53.7, Def{abundant; mixed}
5EAD CJK UNIFIED IDEOGRAPH-#5EAD, IRGKangXi=0346.210, RSKangXi=53.7, Def{courtyard; spacious hall or yard}
5EAE CJK UNIFIED IDEOGRAPH-#5EAE, IRGKangXi=0346.220, RSKangXi=53.7
5EAF CJK UNIFIED IDEOGRAPH-#5EAF, IRGKangXi=0346.240, RSKangXi=53.7
5EB0 CJK UNIFIED IDEOGRAPH-#5EB0, IRGKangXi=0346.300, RSKangXi=53.8
5EB1 CJK UNIFIED IDEOGRAPH-#5EB1, IRGKangXi=0347.020, RSKangXi=53.8
5EB2 CJK UNIFIED IDEOGRAPH-#5EB2, IRGKangXi=0347.040, RSKangXi=53.8
5EB3 CJK UNIFIED IDEOGRAPH-#5EB3, IRGKangXi=0347.060, RSKangXi=53.8, Def{a low-built house}
5EB4 CJK UNIFIED IDEOGRAPH-#5EB4, IRGKangXi=0347.140, RSKangXi=53.8
5EB5 CJK UNIFIED IDEOGRAPH-#5EB5, IRGKangXi=0347.160, RSKangXi=53.8, Def{Buddhist monastery or nunnery}
5EB6 CJK UNIFIED IDEOGRAPH-#5EB6, IRGKangXi=0347.200, RSKangXi=53.8, Def{numerous, various; multitude}
5EB7 CJK UNIFIED IDEOGRAPH-#5EB7, IRGKangXi=0347.270, RSKangXi=53.8, Def{peaceful, quiet; happy, healthy}
5EB8 CJK UNIFIED IDEOGRAPH-#5EB8, IRGKangXi=0347.300, RSKangXi=53.8, Def{usual, common, ordinary, mediocre}
5EB9 CJK UNIFIED IDEOGRAPH-#5EB9, IRGKangXi=0348.030, RSKangXi=53.8, Def{the length of one's two outstretched arms}
5EBA CJK UNIFIED IDEOGRAPH-#5EBA, IRGKangXi=0348.050, RSKangXi=53.8
5EBB CJK UNIFIED IDEOGRAPH-#5EBB, IRGKangXi=0348.081, Def{numerous, various; multitude}
5EBC CJK UNIFIED IDEOGRAPH-#5EBC, IRGKangXi=0348.081, RSKangXi=53.11
5EBD CJK UNIFIED IDEOGRAPH-#5EBD, IRGKangXi=0348.110, RSKangXi=53.9
5EBE CJK UNIFIED IDEOGRAPH-#5EBE, IRGKangXi=0348.140, RSKangXi=53.9, Def{granary; storehouse}
5EBF CJK UNIFIED IDEOGRAPH-#5EBF, IRGKangXi=0348.160, RSKangXi=53.9
5EC0 CJK UNIFIED IDEOGRAPH-#5EC0, IRGKangXi=0348.220, Def{to conceal; to search into}
5EC1 CJK UNIFIED IDEOGRAPH-#5EC1, IRGKangXi=0348.260, RSKangXi=53.9, Def{toilet, lavatory; mingle with}
5EC2 CJK UNIFIED IDEOGRAPH-#5EC2, IRGKangXi=0348.320, RSKangXi=53.9, Def{side-room, wing; theatre box}
5EC3 CJK UNIFIED IDEOGRAPH-#5EC3, IRGKangXi=0348.361, RSKangXi=53.9, Def{abrogate, terminate, discard}
5EC4 CJK UNIFIED IDEOGRAPH-#5EC4, IRGKangXi=0348.361, RSKangXi=53.11, Def{stable; barnyard}
5EC5 CJK UNIFIED IDEOGRAPH-#5EC5, IRGKangXi=0349.010, RSKangXi=53.10
5EC6 CJK UNIFIED IDEOGRAPH-#5EC6, IRGKangXi=0349.030, RSKangXi=53.10, Def{a room; the wall of a house a man's name}
5EC7 CJK UNIFIED IDEOGRAPH-#5EC7, IRGKangXi=0349.060, RSKangXi=53.10
5EC8 CJK UNIFIED IDEOGRAPH-#5EC8, IRGKangXi=0349.070, RSKangXi=53.10, Def{big building, mansion}
5EC9 CJK UNIFIED IDEOGRAPH-#5EC9, IRGKangXi=0349.080, RSKangXi=53.10, Def{upright, honorable, honest}
5ECA CJK UNIFIED IDEOGRAPH-#5ECA, IRGKangXi=0349.130, RSKangXi=53.9, Def{corridor, porch, veranda}
5ECB CJK UNIFIED IDEOGRAPH-#5ECB, IRGKangXi=0349.140, RSKangXi=53.10, Def{conceal, hide; search for, seek}
5ECC CJK UNIFIED IDEOGRAPH-#5ECC, IRGKangXi=0349.201, RSKangXi=53.10, Def{unicorn}
5ECD CJK UNIFIED IDEOGRAPH-#5ECD, IRGKangXi=0350.141, RSKangXi=53.11
5ECE CJK UNIFIED IDEOGRAPH-#5ECE, IRGKangXi=0349.210, RSKangXi=53.11, Def{room}
5ECF CJK UNIFIED IDEOGRAPH-#5ECF, IRGKangXi=0349.250, RSKangXi=53.11, Def{stable; barnyard}
5ED0 CJK UNIFIED IDEOGRAPH-#5ED0, IRGKangXi=0349.270, RSKangXi=53.11, Def{stable; barnyard}
5ED1 CJK UNIFIED IDEOGRAPH-#5ED1, IRGKangXi=0349.290, RSKangXi=53.11, Def{a hut; careful}
5ED2 CJK UNIFIED IDEOGRAPH-#5ED2, IRGKangXi=0349.330, RSKangXi=53.11, Def{a granary}
5ED3 CJK UNIFIED IDEOGRAPH-#5ED3, IRGKangXi=0350.010, RSKangXi=53.11, Def{broad, wide, open, empty; to expand}
5ED4 CJK UNIFIED IDEOGRAPH-#5ED4, IRGKangXi=0350.030, RSKangXi=53.11
5ED5 CJK UNIFIED IDEOGRAPH-#5ED5, IRGKangXi=0350.040, RSKangXi=53.11, Def{shade; protect, shade, cover}
5ED6 CJK UNIFIED IDEOGRAPH-#5ED6, IRGKangXi=0350.050, RSKangXi=53.11, Def{surname; name of an ancient state}
5ED7 CJK UNIFIED IDEOGRAPH-#5ED7, IRGKangXi=0350.060, RSKangXi=53.11
5ED8 CJK UNIFIED IDEOGRAPH-#5ED8, IRGKangXi=0350.070, RSKangXi=53.11
5ED9 CJK UNIFIED IDEOGRAPH-#5ED9, IRGKangXi=0350.170, RSKangXi=53.12
5EDA CJK UNIFIED IDEOGRAPH-#5EDA, IRGKangXi=0350.180, RSKangXi=53.12, Def{kitchen; closet; cupboard}
5EDB CJK UNIFIED IDEOGRAPH-#5EDB, IRGKangXi=0350.220, RSKangXi=53.12, Def{a store, shop; ground alloted to a retainer}
5EDC CJK UNIFIED IDEOGRAPH-#5EDC, IRGKangXi=0350.230, RSKangXi=53.12
5EDD CJK UNIFIED IDEOGRAPH-#5EDD, IRGKangXi=0350.260, RSKangXi=53.12, Def{servant}
5EDE CJK UNIFIED IDEOGRAPH-#5EDE, IRGKangXi=0350.270, RSKangXi=53.12, Def{to prepare horses and chariots for battle}
5EDF CJK UNIFIED IDEOGRAPH-#5EDF, IRGKangXi=0350.280, RSKangXi=53.12, Def{temple, shrine; imperial court}
5EE0 CJK UNIFIED IDEOGRAPH-#5EE0, IRGKangXi=0350.300, RSKangXi=53.12, Def{factory, plant, workshop, mill}
5EE1 CJK UNIFIED IDEOGRAPH-#5EE1, IRGKangXi=0351.010, RSKangXi=53.12, Def{corridor, hallway; luxuriant}
5EE2 CJK UNIFIED IDEOGRAPH-#5EE2, IRGKangXi=0351.020, RSKangXi=53.12, Def{abrogate, terminate, discard}
5EE3 CJK UNIFIED IDEOGRAPH-#5EE3, IRGKangXi=0351.030, RSKangXi=53.12, Def{broad, wide, extensive}
5EE4 CJK UNIFIED IDEOGRAPH-#5EE4, IRGKangXi=0351.071, RSKangXi=53.12, Def{to place}
5EE5 CJK UNIFIED IDEOGRAPH-#5EE5, IRGKangXi=0351.110, RSKangXi=53.13
5EE6 CJK UNIFIED IDEOGRAPH-#5EE6, IRGKangXi=0351.140, RSKangXi=53.13
5EE7 CJK UNIFIED IDEOGRAPH-#5EE7, IRGKangXi=0351.150, RSKangXi=53.13, Def{wall}
5EE8 CJK UNIFIED IDEOGRAPH-#5EE8, IRGKangXi=0351.170, RSKangXi=53.13, Def{government office, public office}
5EE9 CJK UNIFIED IDEOGRAPH-#5EE9, IRGKangXi=0351.220, RSKangXi=53.13, Def{granary; stockpile, store}
5EEA CJK UNIFIED IDEOGRAPH-#5EEA, IRGKangXi=0351.231, RSKangXi=53.13, Def{granary; stockpile}
5EEB CJK UNIFIED IDEOGRAPH-#5EEB, IRGKangXi=0351.290, RSKangXi=53.15
5EEC CJK UNIFIED IDEOGRAPH-#5EEC, IRGKangXi=0352.050, RSKangXi=53.16, Def{hut, cottage; name of a mountain}
5EED CJK UNIFIED IDEOGRAPH-#5EED, IRGKangXi=0352.091, RSKangXi=53.16
5EEE CJK UNIFIED IDEOGRAPH-#5EEE, IRGKangXi=0352.120, RSKangXi=53.17
5EEF CJK UNIFIED IDEOGRAPH-#5EEF, IRGKangXi=0352.130, RSKangXi=53.17
5EF0 CJK UNIFIED IDEOGRAPH-#5EF0, IRGKangXi=0352.171, RSKangXi=53.17, Def{hall, central room}
5EF1 CJK UNIFIED IDEOGRAPH-#5EF1, IRGKangXi=0352.190, RSKangXi=53.18, Def{harmonious; pool; hall}
5EF2 CJK UNIFIED IDEOGRAPH-#5EF2, IRGKangXi=0352.220, RSKangXi=53.19
5EF3 CJK UNIFIED IDEOGRAPH-#5EF3, IRGKangXi=0352.240, RSKangXi=53.22, Def{hall, central room}
5EF4 CJK UNIFIED IDEOGRAPH-#5EF4, IRGKangXi=0352.280, RSKangXi=54.0, Def{go; KangXi radical 54}
5EF5 CJK UNIFIED IDEOGRAPH-#5EF5, IRGKangXi=0352.291, RSKangXi=54.3, Def{to go on circuit; to cruise to patrol}
5EF6 CJK UNIFIED IDEOGRAPH-#5EF6, IRGKangXi=0352.300, RSKangXi=54.4, Def{delay, postpone, defer}
5EF7 CJK UNIFIED IDEOGRAPH-#5EF7, IRGKangXi=0353.020, RSKangXi=54.4, Def{court}
5EF8 CJK UNIFIED IDEOGRAPH-#5EF8, IRGKangXi=0353.031, RSKangXi=54.5, Def{enlighten, advance; progress}
5EF9 CJK UNIFIED IDEOGRAPH-#5EF9, IRGKangXi=0353.031, Def{to persecute; to oppress in difficulties; embarrassed}
5EFA CJK UNIFIED IDEOGRAPH-#5EFA, IRGKangXi=0353.040, RSKangXi=54.6, Def{build, establish, erect, found}
5EFB CJK UNIFIED IDEOGRAPH-#5EFB, IRGKangXi=0353.050, RSKangXi=54.6, Def{circle around; return; curving}
5EFC CJK UNIFIED IDEOGRAPH-#5EFC, IRGKangXi=0353.051, RSKangXi=54.6, Def{then, thereupon, only then}
5EFD CJK UNIFIED IDEOGRAPH-#5EFD, IRGKangXi=0353.051, Def{return, turn around; a time}
5EFE CJK UNIFIED IDEOGRAPH-#5EFE, IRGKangXi=0353.080, RSKangXi=55.0, Def{two hands; KangXi radical 55}
5EFF CJK UNIFIED IDEOGRAPH-#5EFF, IRGKangXi=0353.100, RSKangXi=55.1, Def{twenty, twentieth}
5F00 CJK UNIFIED IDEOGRAPH-#5F00, IRGKangXi=0353.101, RSKangXi=55.1, Def{open; initiate, begin, start}
5F01 CJK UNIFIED IDEOGRAPH-#5F01, IRGKangXi=0353.110, RSKangXi=55.2, Def{conical cap worn during Zhou dynasty}
5F02 CJK UNIFIED IDEOGRAPH-#5F02, IRGKangXi=0353.120, RSKangXi=55.3, Def{different, unusual, strange}
5F03 CJK UNIFIED IDEOGRAPH-#5F03, IRGKangXi=0353.150, RSKangXi=55.4, Def{reject, abandon, discard}
5F04 CJK UNIFIED IDEOGRAPH-#5F04, IRGKangXi=0353.170, RSKangXi=55.4, Def{do, play or fiddle with; alley}
5F05 CJK UNIFIED IDEOGRAPH-#5F05, IRGKangXi=0354.010, RSKangXi=55.4
5F06 CJK UNIFIED IDEOGRAPH-#5F06, IRGKangXi=0354.070, RSKangXi=55.5
5F07 CJK UNIFIED IDEOGRAPH-#5F07, IRGKangXi=0354.080, RSKangXi=55.6, Def{cover over, hide; narrow-necked}
5F08 CJK UNIFIED IDEOGRAPH-#5F08, IRGKangXi=0354.110, RSKangXi=55.6, Def{Chinese chess}
5F09 CJK UNIFIED IDEOGRAPH-#5F09, IRGKangXi=0354.181, RSKangXi=55.7, Def{large, powerful, stout, thick}
5F0A CJK UNIFIED IDEOGRAPH-#5F0A, IRGKangXi=0354.340, RSKangXi=55.12, Def{evil, wrong, bad; criminal}
5F0B CJK UNIFIED IDEOGRAPH-#5F0B, IRGKangXi=0355.010, RSKangXi=56.0, Def{catch, arrest; shoot with bow}
5F0C CJK UNIFIED IDEOGRAPH-#5F0C, IRGKangXi=0355.020, RSKangXi=56.1, AccountingNumeric=1, Def{number one}
5F0D CJK UNIFIED IDEOGRAPH-#5F0D, IRGKangXi=0355.040, RSKangXi=56.2, AccountingNumeric=2, Def{number two}
5F0E CJK UNIFIED IDEOGRAPH-#5F0E, IRGKangXi=0355.050, RSKangXi=56.3, AccountingNumeric=3, Def{three}
5F0F CJK UNIFIED IDEOGRAPH-#5F0F, IRGKangXi=0355.060, RSKangXi=56.3, Def{style, system, formula, rule}
5F10 CJK UNIFIED IDEOGRAPH-#5F10, IRGKangXi=0355.061, RSKangXi=56.3, AccountingNumeric=2, Def{number two}
5F11 CJK UNIFIED IDEOGRAPH-#5F11, IRGKangXi=0355.140, RSKangXi=56.9, Def{to kill one's superior}
5F12 CJK UNIFIED IDEOGRAPH-#5F12, IRGKangXi=0355.141, RSKangXi=56.10, Def{to kill one's superior}
5F13 CJK UNIFIED IDEOGRAPH-#5F13, IRGKangXi=0356.010, RSKangXi=57.0, Def{bow; curved, arched; KangXi radical number 57}
5F14 CJK UNIFIED IDEOGRAPH-#5F14, IRGKangXi=0356.070, RSKangXi=57.1, Def{condole, mourn, pity; hang}
5F15 CJK UNIFIED IDEOGRAPH-#5F15, IRGKangXi=0356.080, RSKangXi=57.1, Def{to pull, draw out, attract; to stretch}
5F16 CJK UNIFIED IDEOGRAPH-#5F16, IRGKangXi=0356.121, RSKangXi=57.1, Def{phonetic for 'te' (Japanese)}
5F17 CJK UNIFIED IDEOGRAPH-#5F17, IRGKangXi=0356.160, RSKangXi=57.2, Def{not, negative}
5F18 CJK UNIFIED IDEOGRAPH-#5F18, IRGKangXi=0356.170, RSKangXi=57.2, Def{enlarge, expand; liberal, great}
5F19 CJK UNIFIED IDEOGRAPH-#5F19, IRGKangXi=0356.210, RSKangXi=57.3
5F1A CJK UNIFIED IDEOGRAPH-#5F1A, IRGKangXi=0357.050, RSKangXi=57.3
5F1B CJK UNIFIED IDEOGRAPH-#5F1B, IRGKangXi=0357.060, RSKangXi=57.3, Def{loosen, relax, unstring a bow}
5F1C CJK UNIFIED IDEOGRAPH-#5F1C, IRGKangXi=0357.070, RSKangXi=57.3
5F1D CJK UNIFIED IDEOGRAPH-#5F1D, IRGKangXi=0357.140, RSKangXi=57.4, Def{the part of a bow grasped when shooting}
5F1E CJK UNIFIED IDEOGRAPH-#5F1E, IRGKangXi=0357.160, RSKangXi=57.4
5F1F CJK UNIFIED IDEOGRAPH-#5F1F, IRGKangXi=0357.170, RSKangXi=57.4, Def{young brother; junior; i, me}
5F20 CJK UNIFIED IDEOGRAPH-#5F20, IRGKangXi=0357.211, RSKangXi=57.4, Def{stretch, extend, expand; sheet}
5F21 CJK UNIFIED IDEOGRAPH-#5F21, IRGKangXi=0357.220, RSKangXi=57.5
5F22 CJK UNIFIED IDEOGRAPH-#5F22, IRGKangXi=0357.250, RSKangXi=57.5, Def{bow case; scabbard; sheathe}
5F23 CJK UNIFIED IDEOGRAPH-#5F23, IRGKangXi=0357.260, RSKangXi=57.5, Def{middle}
5F24 CJK UNIFIED IDEOGRAPH-#5F24, IRGKangXi=0357.280, RSKangXi=57.5, Def{bow}
5F25 CJK UNIFIED IDEOGRAPH-#5F25, IRGKangXi=0357.300, RSKangXi=57.5, Def{extensive, full; fill; complete}
5F26 CJK UNIFIED IDEOGRAPH-#5F26, IRGKangXi=0357.310, RSKangXi=57.5, Def{string; hypotenuse, crescent}
5F27 CJK UNIFIED IDEOGRAPH-#5F27, IRGKangXi=0357.340, RSKangXi=57.5, Def{wooden bow; arc, crescent}
5F28 CJK UNIFIED IDEOGRAPH-#5F28, IRGKangXi=0358.010, RSKangXi=57.5, Def{bow}
5F29 CJK UNIFIED IDEOGRAPH-#5F29, IRGKangXi=0358.030, RSKangXi=57.5, Def{cross-bow, bow; downward stroke}
5F2A CJK UNIFIED IDEOGRAPH-#5F2A, IRGKangXi=0358.031, RSKangXi=57.5, Def{circular measure}
5F2B CJK UNIFIED IDEOGRAPH-#5F2B, IRGKangXi=0358.040, RSKangXi=57.6
5F2C CJK UNIFIED IDEOGRAPH-#5F2C, IRGKangXi=0358.050, RSKangXi=57.6
5F2D CJK UNIFIED IDEOGRAPH-#5F2D, IRGKangXi=0358.070, RSKangXi=57.6, Def{stop, desist, end, quell}
5F2E CJK UNIFIED IDEOGRAPH-#5F2E, IRGKangXi=0358.090, RSKangXi=57.6, Def{a crossbow which discharged several bolts in succession}
5F2F CJK UNIFIED IDEOGRAPH-#5F2F, IRGKangXi=0358.191, RSKangXi=57.6, Def{bend, curve}
5F30 CJK UNIFIED IDEOGRAPH-#5F30, IRGKangXi=0358.220, RSKangXi=57.7, Def{ends of bow}
5F31 CJK UNIFIED IDEOGRAPH-#5F31, IRGKangXi=0358.240, RSKangXi=57.7, Def{weak; fragile, delicate}
5F32 CJK UNIFIED IDEOGRAPH-#5F32, IRGKangXi=0359.010, RSKangXi=57.7
5F33 CJK UNIFIED IDEOGRAPH-#5F33, IRGKangXi=0359.061, RSKangXi=57.7, Def{circular measure}
5F34 CJK UNIFIED IDEOGRAPH-#5F34, IRGKangXi=0359.150, RSKangXi=57.8, Def{red lacquer bow}
5F35 CJK UNIFIED IDEOGRAPH-#5F35, IRGKangXi=0359.190, RSKangXi=57.8, Def{stretch, extend, expand; sheet}
5F36 CJK UNIFIED IDEOGRAPH-#5F36, IRGKangXi=0359.210, RSKangXi=57.8, Def{a snare}
5F37 CJK UNIFIED IDEOGRAPH-#5F37, IRGKangXi=0359.230, RSKangXi=57.8, Def{strong, powerful, energetic}
5F38 CJK UNIFIED IDEOGRAPH-#5F38, IRGKangXi=0360.020, RSKangXi=57.8, Def{a bow stretched to the full; tensely drawn}
5F39 CJK UNIFIED IDEOGRAPH-#5F39, IRGKangXi=0360.031, RSKangXi=57.8, Def{pellet, bullet, shot, shell}
5F3A CJK UNIFIED IDEOGRAPH-#5F3A, IRGKangXi=0360.040, RSKangXi=57.9, Def{strong, powerful, energetic}
5F3B CJK UNIFIED IDEOGRAPH-#5F3B, IRGKangXi=0360.060, RSKangXi=57.9
5F3C CJK UNIFIED IDEOGRAPH-#5F3C, IRGKangXi=0360.080, RSKangXi=57.9, Def{aid, assist, help; correct}
5F3D CJK UNIFIED IDEOGRAPH-#5F3D, IRGKangXi=0360.200, RSKangXi=57.9
5F3E CJK UNIFIED IDEOGRAPH-#5F3E, IRGKangXi=0360.221, RSKangXi=57.9, Def{variant of 彈 U+5F48, a pellet, bullet, shot, shell}
5F3F CJK UNIFIED IDEOGRAPH-#5F3F, IRGKangXi=0360.240, RSKangXi=57.10
5F40 CJK UNIFIED IDEOGRAPH-#5F40, IRGKangXi=0360.290, RSKangXi=57.10, Def{enough, adequate fully, quite}
5F41 CJK UNIFIED IDEOGRAPH-#5F41, IRGKangXi=0360.301, RSKangXi=57.10
5F42 CJK UNIFIED IDEOGRAPH-#5F42, IRGKangXi=0360.301, Def{issue, dispatch, send out, emit}
5F43 CJK UNIFIED IDEOGRAPH-#5F43, IRGKangXi=0360.310, RSKangXi=57.11
5F44 CJK UNIFIED IDEOGRAPH-#5F44, IRGKangXi=0360.360, RSKangXi=57.11, Def{nock at end of bow; stretch}
5F45 CJK UNIFIED IDEOGRAPH-#5F45, IRGKangXi=0360.381, RSKangXi=57.11
5F46 CJK UNIFIED IDEOGRAPH-#5F46, IRGKangXi=0360.390, RSKangXi=57.12, Def{awkward}
5F47 CJK UNIFIED IDEOGRAPH-#5F47, IRGKangXi=0360.410, RSKangXi=57.12
5F48 CJK UNIFIED IDEOGRAPH-#5F48, IRGKangXi=0360.450, RSKangXi=57.12, Def{pellet, bullet, shot, shell}
5F49 CJK UNIFIED IDEOGRAPH-#5F49, IRGKangXi=0361.020, RSKangXi=57.12
5F4A CJK UNIFIED IDEOGRAPH-#5F4A, IRGKangXi=0361.060, RSKangXi=57.13, Def{stubborn, uncompromising}
5F4B CJK UNIFIED IDEOGRAPH-#5F4B, IRGKangXi=0361.080, RSKangXi=57.13
5F4C CJK UNIFIED IDEOGRAPH-#5F4C, IRGKangXi=0361.110, RSKangXi=57.14, Def{extensive, full; fill; complete}
5F4D CJK UNIFIED IDEOGRAPH-#5F4D, IRGKangXi=0361.150, RSKangXi=57.15, Def{to draw a bow to the full}
5F4E CJK UNIFIED IDEOGRAPH-#5F4E, IRGKangXi=0361.280, RSKangXi=57.19, Def{bend, curve}
5F4F CJK UNIFIED IDEOGRAPH-#5F4F, IRGKangXi=0362.020, RSKangXi=57.20
5F50 CJK UNIFIED IDEOGRAPH-#5F50, IRGKangXi=0362.040, RSKangXi=58.0, Def{snout; KangXi radical 58}
5F51 CJK UNIFIED IDEOGRAPH-#5F51, IRGKangXi=0362.050, RSKangXi=58.0, Def{snout; KangXi radical 58}
5F52 CJK UNIFIED IDEOGRAPH-#5F52, IRGKangXi=0362.051, RSKangXi=58.2, Def{return; return to, revert to}
5F53 CJK UNIFIED IDEOGRAPH-#5F53, IRGKangXi=0297.061, RSKangXi=42.3, Def{bear, accept, undertake; just}
5F54 CJK UNIFIED IDEOGRAPH-#5F54, IRGKangXi=0362.111, RSKangXi=58.5, Def{to carve wood}
5F55 CJK UNIFIED IDEOGRAPH-#5F55, IRGKangXi=0362.111, RSKangXi=58.5, Def{copy, write down, record}
5F56 CJK UNIFIED IDEOGRAPH-#5F56, IRGKangXi=0362.120, RSKangXi=58.6, Def{a hog; a hedgehog; a porcupine}
5F57 CJK UNIFIED IDEOGRAPH-#5F57, IRGKangXi=0362.160, RSKangXi=58.8, Def{broomstick; comet}
5F58 CJK UNIFIED IDEOGRAPH-#5F58, IRGKangXi=0362.170, RSKangXi=58.9, Def{swine}
5F59 CJK UNIFIED IDEOGRAPH-#5F59, IRGKangXi=0362.210, RSKangXi=58.10, Def{collect, compile, assemble; hedgehog}
5F5A CJK UNIFIED IDEOGRAPH-#5F5A, IRGKangXi=0362.211, Def{collect, compile, assemble; hedgehog}
5F5B CJK UNIFIED IDEOGRAPH-#5F5B, IRGKangXi=0362.251, RSKangXi=58.13, Def{Yi (nationality); tripod, wine vessel; rule}
5F5C CJK UNIFIED IDEOGRAPH-#5F5C, IRGKangXi=0362.251, RSKangXi=58.13, Def{Yi (nationality); tripod, wine vessel; rule}
5F5D CJK UNIFIED IDEOGRAPH-#5F5D, IRGKangXi=0362.260, RSKangXi=58.15, Def{Yi (nationality); tripod, wine vessel; rule}
5F5E CJK UNIFIED IDEOGRAPH-#5F5E, IRGKangXi=0362.291, RSKangXi=58.15, Def{yi; tripod}
5F5F CJK UNIFIED IDEOGRAPH-#5F5F, IRGKangXi=0362.311, RSKangXi=58.23
5F60 CJK UNIFIED IDEOGRAPH-#5F60, IRGKangXi=0362.330, RSKangXi=58.23
5F61 CJK UNIFIED IDEOGRAPH-#5F61, IRGKangXi=0363.020, RSKangXi=59.0, Def{hair; KangXi radical 59}
5F62 CJK UNIFIED IDEOGRAPH-#5F62, IRGKangXi=0363.060, RSKangXi=59.4, Def{form, shape, appearance}
5F63 CJK UNIFIED IDEOGRAPH-#5F63, IRGKangXi=0363.070, RSKangXi=59.4
5F64 CJK UNIFIED IDEOGRAPH-#5F64, IRGKangXi=0363.080, RSKangXi=59.4, Def{red, vermilion; name of ancient}
5F65 CJK UNIFIED IDEOGRAPH-#5F65, IRGKangXi=0363.130, RSKangXi=59.6, Def{elegant, handsome; learned}
5F66 CJK UNIFIED IDEOGRAPH-#5F66, IRGKangXi=0363.131, RSKangXi=59.6, Def{elegant}
5F67 CJK UNIFIED IDEOGRAPH-#5F67, IRGKangXi=0363.140, RSKangXi=59.7, Def{refined, cultured, polished}
5F68 CJK UNIFIED IDEOGRAPH-#5F68, IRGKangXi=0363.171, RSKangXi=59.19
5F69 CJK UNIFIED IDEOGRAPH-#5F69, IRGKangXi=0363.210, RSKangXi=59.8, Def{hue, color; variegated colors}
5F6A CJK UNIFIED IDEOGRAPH-#5F6A, IRGKangXi=0363.220, RSKangXi=59.8, Def{tiger; tiger stripes; tiger-like}
5F6B CJK UNIFIED IDEOGRAPH-#5F6B, IRGKangXi=0363.230, RSKangXi=59.8, Def{carve, decorate; emaciated}
5F6C CJK UNIFIED IDEOGRAPH-#5F6C, IRGKangXi=0363.240, RSKangXi=59.8, Def{cultivated, well-bred}
5F6D CJK UNIFIED IDEOGRAPH-#5F6D, IRGKangXi=0364.050, RSKangXi=59.9, Def{name of ancient country; surname}
5F6E CJK UNIFIED IDEOGRAPH-#5F6E, IRGKangXi=0364.100, RSKangXi=59.10
5F6F CJK UNIFIED IDEOGRAPH-#5F6F, IRGKangXi=0364.140, RSKangXi=59.11
5F70 CJK UNIFIED IDEOGRAPH-#5F70, IRGKangXi=0364.150, RSKangXi=59.11, Def{clear, manifest, obvious}
5F71 CJK UNIFIED IDEOGRAPH-#5F71, IRGKangXi=0364.190, RSKangXi=59.12, Def{shadow; image, reflection; photograph}
5F72 CJK UNIFIED IDEOGRAPH-#5F72, IRGKangXi=0364.280, RSKangXi=59.19, Def{yellow dragon}
5F73 CJK UNIFIED IDEOGRAPH-#5F73, IRGKangXi=0365.010, RSKangXi=60.0, Def{step with left foot; rad. no 60}
5F74 CJK UNIFIED IDEOGRAPH-#5F74, IRGKangXi=0365.060, RSKangXi=60.3, Def{bridge}
5F75 CJK UNIFIED IDEOGRAPH-#5F75, IRGKangXi=0365.070, RSKangXi=60.3
5F76 CJK UNIFIED IDEOGRAPH-#5F76, IRGKangXi=0365.080, RSKangXi=60.4
5F77 CJK UNIFIED IDEOGRAPH-#5F77, IRGKangXi=0365.130, RSKangXi=60.4, Def{like, resembling; resemble}
5F78 CJK UNIFIED IDEOGRAPH-#5F78, IRGKangXi=0365.150, RSKangXi=60.4, Def{restless, agitated}
5F79 CJK UNIFIED IDEOGRAPH-#5F79, IRGKangXi=0365.180, RSKangXi=60.4, Def{service; a servant, laborer; to serve}
5F7A CJK UNIFIED IDEOGRAPH-#5F7A, IRGKangXi=0365.200, RSKangXi=60.4
5F7B CJK UNIFIED IDEOGRAPH-#5F7B, IRGKangXi=0365.211, RSKangXi=60.4, Def{penetrate, pervade; penetrating}
5F7C CJK UNIFIED IDEOGRAPH-#5F7C, IRGKangXi=0365.250, RSKangXi=60.5, Def{that, there, those}
5F7D CJK UNIFIED IDEOGRAPH-#5F7D, IRGKangXi=0365.280, RSKangXi=60.5, Def{variant of 低 U+4F4E, low; to lower, hang, bend, bow}
5F7E CJK UNIFIED IDEOGRAPH-#5F7E, IRGKangXi=0365.290, RSKangXi=60.5
5F7F CJK UNIFIED IDEOGRAPH-#5F7F, IRGKangXi=0365.300, RSKangXi=60.5, Def{resembling, like, as if}
5F80 CJK UNIFIED IDEOGRAPH-#5F80, IRGKangXi=0365.320, RSKangXi=60.5, Def{go, depart; past, formerly}
5F81 CJK UNIFIED IDEOGRAPH-#5F81, IRGKangXi=0365.370, RSKangXi=60.5, Def{invade, attack, conquer}
5F82 CJK UNIFIED IDEOGRAPH-#5F82, IRGKangXi=0365.390, RSKangXi=60.5, Def{go, advance; to; die}
5F83 CJK UNIFIED IDEOGRAPH-#5F83, IRGKangXi=0365.411, RSKangXi=60.5, Def{go, depart; past, formerly}
5F84 CJK UNIFIED IDEOGRAPH-#5F84, IRGKangXi=0365.411, RSKangXi=60.5, Def{narrow path; diameter; direct}
5F85 CJK UNIFIED IDEOGRAPH-#5F85, IRGKangXi=0366.050, RSKangXi=60.6, Def{treat, entertain, receive; wait}
5F86 CJK UNIFIED IDEOGRAPH-#5F86, IRGKangXi=0366.100, RSKangXi=60.6
5F87 CJK UNIFIED IDEOGRAPH-#5F87, IRGKangXi=0366.110, RSKangXi=60.6, Def{comply with, follow; display}
5F88 CJK UNIFIED IDEOGRAPH-#5F88, IRGKangXi=0366.130, RSKangXi=60.6, Def{very, quite, much}
5F89 CJK UNIFIED IDEOGRAPH-#5F89, IRGKangXi=0366.140, RSKangXi=60.6, Def{wonder, rove, stray; hesitating}
5F8A CJK UNIFIED IDEOGRAPH-#5F8A, IRGKangXi=0366.150, RSKangXi=60.6, Def{linger, walk to and fro, hesitain}
5F8B CJK UNIFIED IDEOGRAPH-#5F8B, IRGKangXi=0366.170, RSKangXi=60.6, Def{statute, principle, regulation}
5F8C CJK UNIFIED IDEOGRAPH-#5F8C, IRGKangXi=0366.180, RSKangXi=60.6, Def{behind, rear, after; descendents}
5F8D CJK UNIFIED IDEOGRAPH-#5F8D, IRGKangXi=0367.010, RSKangXi=60.6
5F8E CJK UNIFIED IDEOGRAPH-#5F8E, IRGKangXi=0367.060, RSKangXi=60.7
5F8F CJK UNIFIED IDEOGRAPH-#5F8F, IRGKangXi=0367.100, RSKangXi=60.7
5F90 CJK UNIFIED IDEOGRAPH-#5F90, IRGKangXi=0367.110, RSKangXi=60.7, Def{slowly, quietly, calmly; composed, dignified}
5F91 CJK UNIFIED IDEOGRAPH-#5F91, IRGKangXi=0367.190, RSKangXi=60.7, Def{narrow path; diameter; direct}
5F92 CJK UNIFIED IDEOGRAPH-#5F92, IRGKangXi=0367.220, RSKangXi=60.7, Def{disciple, follower; go on foot}
5F93 CJK UNIFIED IDEOGRAPH-#5F93, IRGKangXi=0367.271, RSKangXi=60.7, Def{from, by, since, whence, through}
5F94 CJK UNIFIED IDEOGRAPH-#5F94, IRGKangXi=0369.081, RSKangXi=60.6
5F95 CJK UNIFIED IDEOGRAPH-#5F95, IRGKangXi=0367.271, RSKangXi=60.7, Def{induce, encourage to come}
5F96 CJK UNIFIED IDEOGRAPH-#5F96, IRGKangXi=0367.300, RSKangXi=60.8
5F97 CJK UNIFIED IDEOGRAPH-#5F97, IRGKangXi=0367.310, RSKangXi=60.8, Def{obtain, get, gain, acquire}
5F98 CJK UNIFIED IDEOGRAPH-#5F98, IRGKangXi=0368.040, RSKangXi=60.8, Def{walk back and forth, hesitate}
5F99 CJK UNIFIED IDEOGRAPH-#5F99, IRGKangXi=0368.050, RSKangXi=60.8, Def{move one's abode, shift, migrate}
5F9A CJK UNIFIED IDEOGRAPH-#5F9A, IRGKangXi=0370.051, RSKangXi=60.9
5F9B CJK UNIFIED IDEOGRAPH-#5F9B, IRGKangXi=0368.140, RSKangXi=60.8, Def{to cross over}
5F9C CJK UNIFIED IDEOGRAPH-#5F9C, IRGKangXi=0368.150, RSKangXi=60.8, Def{walking and fro; lingering}
5F9D CJK UNIFIED IDEOGRAPH-#5F9D, IRGKangXi=0368.170, RSKangXi=60.8
5F9E CJK UNIFIED IDEOGRAPH-#5F9E, IRGKangXi=0368.180, RSKangXi=60.8, Def{from, by, since, whence, through}
5F9F CJK UNIFIED IDEOGRAPH-#5F9F, IRGKangXi=0368.190, RSKangXi=60.8
5FA0 CJK UNIFIED IDEOGRAPH-#5FA0, IRGKangXi=0368.210, RSKangXi=60.8, Def{induce, encourage to come}
5FA1 CJK UNIFIED IDEOGRAPH-#5FA1, IRGKangXi=0368.230, RSKangXi=60.8, Def{drive, ride; chariot; manage}
5FA2 CJK UNIFIED IDEOGRAPH-#5FA2, IRGKangXi=0369.040, RSKangXi=60.8
5FA3 CJK UNIFIED IDEOGRAPH-#5FA3, IRGKangXi=0369.081, RSKangXi=60.8
5FA4 CJK UNIFIED IDEOGRAPH-#5FA4, IRGKangXi=0370.051, RSKangXi=60.9, Def{strong, robust; to strengthen}
5FA5 CJK UNIFIED IDEOGRAPH-#5FA5, IRGKangXi=0369.090, RSKangXi=60.9
5FA6 CJK UNIFIED IDEOGRAPH-#5FA6, IRGKangXi=0369.120, RSKangXi=60.9
5FA7 CJK UNIFIED IDEOGRAPH-#5FA7, IRGKangXi=0369.130, RSKangXi=60.9, Def{everywhere, all over, all around}
5FA8 CJK UNIFIED IDEOGRAPH-#5FA8, IRGKangXi=0369.170, RSKangXi=60.9, Def{doubtful, irresolute, vacillating}
5FA9 CJK UNIFIED IDEOGRAPH-#5FA9, IRGKangXi=0369.220, RSKangXi=60.9, Def{return; repeat; repeatedly}
5FAA CJK UNIFIED IDEOGRAPH-#5FAA, IRGKangXi=0369.280, RSKangXi=60.9, Def{obey, comply with, follow}
5FAB CJK UNIFIED IDEOGRAPH-#5FAB, IRGKangXi=0370.050, RSKangXi=60.9
5FAC CJK UNIFIED IDEOGRAPH-#5FAC, IRGKangXi=0370.090, RSKangXi=60.10, Def{to wander about, walk along side of; to be next to}
5FAD CJK UNIFIED IDEOGRAPH-#5FAD, IRGKangXi=0370.100, RSKangXi=60.10, Def{conscript labor, compulsory labor}
5FAE CJK UNIFIED IDEOGRAPH-#5FAE, IRGKangXi=0370.120, RSKangXi=60.10, Def{small, prefix micro-, trifling}
5FAF CJK UNIFIED IDEOGRAPH-#5FAF, IRGKangXi=0370.130, RSKangXi=60.10, Def{wait for, await, expect, hope}
5FB0 CJK UNIFIED IDEOGRAPH-#5FB0, IRGKangXi=0370.190, RSKangXi=60.10
5FB1 CJK UNIFIED IDEOGRAPH-#5FB1, IRGKangXi=0370.240, RSKangXi=60.11
5FB2 CJK UNIFIED IDEOGRAPH-#5FB2, IRGKangXi=0370.250, RSKangXi=60.11
5FB3 CJK UNIFIED IDEOGRAPH-#5FB3, IRGKangXi=0370.401, RSKangXi=60.11, Def{virtue; ethics}
5FB4 CJK UNIFIED IDEOGRAPH-#5FB4, IRGKangXi=0370.401, RSKangXi=60.11, Def{summon}
5FB5 CJK UNIFIED IDEOGRAPH-#5FB5, IRGKangXi=0370.410, RSKangXi=60.12, Def{summon, recruit; musical note}
5FB6 CJK UNIFIED IDEOGRAPH-#5FB6, IRGKangXi=0371.070, RSKangXi=60.12
5FB7 CJK UNIFIED IDEOGRAPH-#5FB7, IRGKangXi=0371.080, RSKangXi=60.12, Def{ethics, morality, virtue}
5FB8 CJK UNIFIED IDEOGRAPH-#5FB8, IRGKangXi=0371.090, RSKangXi=60.12
5FB9 CJK UNIFIED IDEOGRAPH-#5FB9, IRGKangXi=0371.100, RSKangXi=60.12, Def{penetrate, pervade; penetrating}
5FBA CJK UNIFIED IDEOGRAPH-#5FBA, IRGKangXi=0371.191, RSKangXi=60.12
5FBB CJK UNIFIED IDEOGRAPH-#5FBB, IRGKangXi=0371.210, RSKangXi=60.13, Def{a wide room}
5FBC CJK UNIFIED IDEOGRAPH-#5FBC, IRGKangXi=0371.270, RSKangXi=60.13, Def{frontier, border; inspect, patrol}
5FBD CJK UNIFIED IDEOGRAPH-#5FBD, IRGKangXi=0372.040, RSKangXi=60.14, Def{a badge, insignia}
5FBE CJK UNIFIED IDEOGRAPH-#5FBE, IRGKangXi=0372.081, RSKangXi=60.14
5FBF CJK UNIFIED IDEOGRAPH-#5FBF, IRGKangXi=0372.130, RSKangXi=60.16
5FC0 CJK UNIFIED IDEOGRAPH-#5FC0, IRGKangXi=0372.200, RSKangXi=60.17, Def{to stroll; to ramble}
5FC1 CJK UNIFIED IDEOGRAPH-#5FC1, IRGKangXi=0372.201, RSKangXi=60.16
5FC2 CJK UNIFIED IDEOGRAPH-#5FC2, IRGKangXi=0372.210, RSKangXi=60.18
5FC3 CJK UNIFIED IDEOGRAPH-#5FC3, IRGKangXi=0375.010, RSKangXi=61.0, Def{heart; mind, intelligence; soul}
5FC4 CJK UNIFIED IDEOGRAPH-#5FC4, IRGKangXi=0375.011, RSKangXi=61.0, Def{heart; radical number 61}
5FC5 CJK UNIFIED IDEOGRAPH-#5FC5, IRGKangXi=0375.020, RSKangXi=61.1, Def{surely, most certainly; must}
5FC6 CJK UNIFIED IDEOGRAPH-#5FC6, IRGKangXi=0375.031, RSKangXi=61.1, Def{remember, reflect upon; memory}
5FC7 CJK UNIFIED IDEOGRAPH-#5FC7, IRGKangXi=0375.040, RSKangXi=61.2
5FC8 CJK UNIFIED IDEOGRAPH-#5FC8, IRGKangXi=0375.050, RSKangXi=61.2
5FC9 CJK UNIFIED IDEOGRAPH-#5FC9, IRGKangXi=0375.080, RSKangXi=61.2, Def{grieved; distressed in mind}
5FCA CJK UNIFIED IDEOGRAPH-#5FCA, IRGKangXi=0375.110, RSKangXi=61.2
5FCB CJK UNIFIED IDEOGRAPH-#5FCB, IRGKangXi=0375.120, RSKangXi=61.3, Def{to rely on; look up to}
5FCC CJK UNIFIED IDEOGRAPH-#5FCC, IRGKangXi=0376.010, RSKangXi=61.3, Def{jealous, envious; fear}
5FCD CJK UNIFIED IDEOGRAPH-#5FCD, IRGKangXi=0376.040, RSKangXi=61.3, Def{endure, bear, suffer; forbear}
5FCE CJK UNIFIED IDEOGRAPH-#5FCE, IRGKangXi=0376.060, RSKangXi=61.3
5FCF CJK UNIFIED IDEOGRAPH-#5FCF, IRGKangXi=0376.070, RSKangXi=61.3, Def{regret, repent; confess sins}
5FD0 CJK UNIFIED IDEOGRAPH-#5FD0, IRGKangXi=0376.080, RSKangXi=61.3, Def{timorous; nervous}
5FD1 CJK UNIFIED IDEOGRAPH-#5FD1, IRGKangXi=0376.090, RSKangXi=61.3, Def{fearful; nervous; timid}
5FD2 CJK UNIFIED IDEOGRAPH-#5FD2, IRGKangXi=0376.100, RSKangXi=61.3, Def{excessive; too; very-usually of objectionable things; to err; to mistake; changeable}
5FD3 CJK UNIFIED IDEOGRAPH-#5FD3, IRGKangXi=0376.110, RSKangXi=61.3, Def{concerned about}
5FD4 CJK UNIFIED IDEOGRAPH-#5FD4, IRGKangXi=0376.130, RSKangXi=61.3
5FD5 CJK UNIFIED IDEOGRAPH-#5FD5, IRGKangXi=0376.150, RSKangXi=61.3
5FD6 CJK UNIFIED IDEOGRAPH-#5FD6, IRGKangXi=0376.160, RSKangXi=61.3, Def{guess, suppose, conjecture}
5FD7 CJK UNIFIED IDEOGRAPH-#5FD7, IRGKangXi=0376.210, RSKangXi=61.3, Def{purpose, will, determination; annals}
5FD8 CJK UNIFIED IDEOGRAPH-#5FD8, IRGKangXi=0376.240, RSKangXi=61.3, Def{forget; neglect; miss, omit}
5FD9 CJK UNIFIED IDEOGRAPH-#5FD9, IRGKangXi=0377.010, RSKangXi=61.3, Def{busy, pressed for time; hustling}
5FDA CJK UNIFIED IDEOGRAPH-#5FDA, IRGKangXi=0377.050, RSKangXi=61.3
5FDB CJK UNIFIED IDEOGRAPH-#5FDB, IRGKangXi=0377.071, RSKangXi=61.3
5FDC CJK UNIFIED IDEOGRAPH-#5FDC, IRGKangXi=0377.071, RSKangXi=61.3, Def{should, ought to, must}
5FDD CJK UNIFIED IDEOGRAPH-#5FDD, IRGKangXi=0377.080, RSKangXi=61.4, Def{disgraced; ashamed; self-deprecating}
5FDE CJK UNIFIED IDEOGRAPH-#5FDE, IRGKangXi=0377.100, RSKangXi=61.4
5FDF CJK UNIFIED IDEOGRAPH-#5FDF, IRGKangXi=0377.110, RSKangXi=61.4, Def{(Cant.) impatient, restless}
5FE0 CJK UNIFIED IDEOGRAPH-#5FE0, IRGKangXi=0377.130, RSKangXi=61.4, Def{loyalty, devotion, fidelity}
5FE1 CJK UNIFIED IDEOGRAPH-#5FE1, IRGKangXi=0377.140, RSKangXi=61.4, Def{a sad, uneasy countenance}
5FE2 CJK UNIFIED IDEOGRAPH-#5FE2, IRGKangXi=0377.150, RSKangXi=61.4
5FE3 CJK UNIFIED IDEOGRAPH-#5FE3, IRGKangXi=0377.170, RSKangXi=61.4
5FE4 CJK UNIFIED IDEOGRAPH-#5FE4, IRGKangXi=0377.180, RSKangXi=61.4, Def{insubordinate, stubborn; wrong}
5FE5 CJK UNIFIED IDEOGRAPH-#5FE5, IRGKangXi=0377.200, RSKangXi=61.4
5FE6 CJK UNIFIED IDEOGRAPH-#5FE6, IRGKangXi=0377.210, RSKangXi=61.4
5FE7 CJK UNIFIED IDEOGRAPH-#5FE7, IRGKangXi=0377.220, RSKangXi=61.4, Def{sad, grieved; grief, melancholy}
5FE8 CJK UNIFIED IDEOGRAPH-#5FE8, IRGKangXi=0377.250, RSKangXi=61.4
5FE9 CJK UNIFIED IDEOGRAPH-#5FE9, IRGKangXi=0377.260, RSKangXi=61.4, Def{same as 怱 U+6031, hastily, in haste, hurriedly}
5FEA CJK UNIFIED IDEOGRAPH-#5FEA, IRGKangXi=0377.270, RSKangXi=61.4, Def{quiet, calm, tranquil, peaceful}
5FEB CJK UNIFIED IDEOGRAPH-#5FEB, IRGKangXi=0377.290, RSKangXi=61.4, Def{rapid, quick, speedy, fast; soon}
5FEC CJK UNIFIED IDEOGRAPH-#5FEC, IRGKangXi=0378.020, RSKangXi=61.4
5FED CJK UNIFIED IDEOGRAPH-#5FED, IRGKangXi=0378.030, RSKangXi=61.4, Def{delighted; pleased}
5FEE CJK UNIFIED IDEOGRAPH-#5FEE, IRGKangXi=0378.060, RSKangXi=61.4, Def{stubborn; perverse; aggressive}
5FEF CJK UNIFIED IDEOGRAPH-#5FEF, IRGKangXi=0378.080, RSKangXi=61.4
5FF0 CJK UNIFIED IDEOGRAPH-#5FF0, IRGKangXi=0378.120, RSKangXi=61.4, Def{suffer, become emaciated, haggard}
5FF1 CJK UNIFIED IDEOGRAPH-#5FF1, IRGKangXi=0378.130, RSKangXi=61.4, Def{truth, sincerity; sincere}
5FF2 CJK UNIFIED IDEOGRAPH-#5FF2, IRGKangXi=0378.150, RSKangXi=61.4, Def{extravagant}
5FF3 CJK UNIFIED IDEOGRAPH-#5FF3, IRGKangXi=0378.190, RSKangXi=61.4
5FF4 CJK UNIFIED IDEOGRAPH-#5FF4, IRGKangXi=0378.200, RSKangXi=61.4
5FF5 CJK UNIFIED IDEOGRAPH-#5FF5, IRGKangXi=0378.210, RSKangXi=61.4, Def{think of, recall, study}
5FF6 CJK UNIFIED IDEOGRAPH-#5FF6, IRGKangXi=0378.220, RSKangXi=61.4
5FF7 CJK UNIFIED IDEOGRAPH-#5FF7, IRGKangXi=0378.230, RSKangXi=61.4, Def{variant of 恟 U+605F, scared, nervous}
5FF8 CJK UNIFIED IDEOGRAPH-#5FF8, IRGKangXi=0378.270, RSKangXi=61.4, Def{blush, be bashful, be ashamed}
5FF9 CJK UNIFIED IDEOGRAPH-#5FF9, IRGKangXi=0378.290, RSKangXi=61.4
5FFA CJK UNIFIED IDEOGRAPH-#5FFA, IRGKangXi=0378.300, RSKangXi=61.4
5FFB CJK UNIFIED IDEOGRAPH-#5FFB, IRGKangXi=0378.310, RSKangXi=61.4, Def{delightful, joyful, pleasant}
5FFC CJK UNIFIED IDEOGRAPH-#5FFC, IRGKangXi=0378.320, RSKangXi=61.4, Def{ardent; generous, magnanimous}
5FFD CJK UNIFIED IDEOGRAPH-#5FFD, IRGKangXi=0378.340, RSKangXi=61.4, Def{suddenly, abruptly; neglect}
5FFE CJK UNIFIED IDEOGRAPH-#5FFE, IRGKangXi=0379.010, RSKangXi=61.4, Def{anger, wrath, hatred, enmity}
5FFF CJK UNIFIED IDEOGRAPH-#5FFF, IRGKangXi=0379.020, RSKangXi=61.4, Def{get angry; fury, exasperation}
6000 CJK UNIFIED IDEOGRAPH-#6000, IRGKangXi=0379.050, RSKangXi=61.4, Def{bosom, breast; carry in bosom}
6001 CJK UNIFIED IDEOGRAPH-#6001, IRGKangXi=0379.071, RSKangXi=61.4, Def{manner, bearing, attitude}
6002 CJK UNIFIED IDEOGRAPH-#6002, IRGKangXi=0379.071, RSKangXi=61.4, Def{instigate, arouse, incite}
6003 CJK UNIFIED IDEOGRAPH-#6003, IRGKangXi=0379.071, RSKangXi=61.5, Def{regretful, disappointed}
6004 CJK UNIFIED IDEOGRAPH-#6004, IRGKangXi=0379.071, RSKangXi=61.4, Def{annoyed}
6005 CJK UNIFIED IDEOGRAPH-#6005, IRGKangXi=0379.071, RSKangXi=61.4, Def{disappointed, dissatisfied}
6006 CJK UNIFIED IDEOGRAPH-#6006, IRGKangXi=0379.071, RSKangXi=61.4, Def{sad, broken-hearted, disconsolate}
6007 CJK UNIFIED IDEOGRAPH-#6007, IRGKangXi=0379.100, RSKangXi=61.5
6008 CJK UNIFIED IDEOGRAPH-#6008, IRGKangXi=0379.110, RSKangXi=61.5
6009 CJK UNIFIED IDEOGRAPH-#6009, IRGKangXi=0379.120, RSKangXi=61.5
600A CJK UNIFIED IDEOGRAPH-#600A, IRGKangXi=0379.130, RSKangXi=61.5
600B CJK UNIFIED IDEOGRAPH-#600B, IRGKangXi=0379.140, RSKangXi=61.5
600C CJK UNIFIED IDEOGRAPH-#600C, IRGKangXi=0379.150, RSKangXi=61.5, Def{bosom; to carry in the bosom; to cherish}
600D CJK UNIFIED IDEOGRAPH-#600D, IRGKangXi=0379.160, RSKangXi=61.5, Def{to be ashamed}
600E CJK UNIFIED IDEOGRAPH-#600E, IRGKangXi=0379.170, RSKangXi=61.5, Def{what? why? how?}
600F CJK UNIFIED IDEOGRAPH-#600F, IRGKangXi=0380.030, RSKangXi=61.5, Def{discontented, dispirited, sad}
6010 CJK UNIFIED IDEOGRAPH-#6010, IRGKangXi=0380.040, RSKangXi=61.5, Def{(Cant.) 怐豆 to stare}
6011 CJK UNIFIED IDEOGRAPH-#6011, IRGKangXi=0380.070, RSKangXi=61.5
6012 CJK UNIFIED IDEOGRAPH-#6012, IRGKangXi=0380.080, RSKangXi=61.5, Def{anger, rage, passion; angry}
6013 CJK UNIFIED IDEOGRAPH-#6013, IRGKangXi=0380.110, RSKangXi=61.5, Def{confusion; a braggart}
6014 CJK UNIFIED IDEOGRAPH-#6014, IRGKangXi=0380.140, RSKangXi=61.5, Def{a disease resembling neurosis}
6015 CJK UNIFIED IDEOGRAPH-#6015, IRGKangXi=0380.160, RSKangXi=61.5, Def{to fear, be afraid of; apprehensive}
6016 CJK UNIFIED IDEOGRAPH-#6016, IRGKangXi=0380.180, RSKangXi=61.5, Def{terror, fear; frighten; terrified}
6017 CJK UNIFIED IDEOGRAPH-#6017, IRGKangXi=0380.190, RSKangXi=61.5, Def{observant; peaceful; submissive}
6018 CJK UNIFIED IDEOGRAPH-#6018, IRGKangXi=0380.210, RSKangXi=61.5
6019 CJK UNIFIED IDEOGRAPH-#6019, IRGKangXi=0380.220, RSKangXi=61.5, Def{rely on, presume on; persist in}
601A CJK UNIFIED IDEOGRAPH-#601A, IRGKangXi=0380.250, RSKangXi=61.5, Def{dull, stupid, suspicious}
601B CJK UNIFIED IDEOGRAPH-#601B, IRGKangXi=0380.260, RSKangXi=61.5, Def{grieved, saddened; worried}
601C CJK UNIFIED IDEOGRAPH-#601C, IRGKangXi=0381.030, RSKangXi=61.5, Def{pity, sympathize}
601D CJK UNIFIED IDEOGRAPH-#601D, IRGKangXi=0381.040, RSKangXi=61.5, Def{think, consider, ponder; final particle}
601E CJK UNIFIED IDEOGRAPH-#601E, IRGKangXi=0381.090, RSKangXi=61.5, Def{to grieve; sorrowful}
601F CJK UNIFIED IDEOGRAPH-#601F, IRGKangXi=0381.140, RSKangXi=61.5
6020 CJK UNIFIED IDEOGRAPH-#6020, IRGKangXi=0381.150, RSKangXi=61.5, Def{idle, remiss, negligent; neglect}
6021 CJK UNIFIED IDEOGRAPH-#6021, IRGKangXi=0381.160, RSKangXi=61.5, Def{harmony; pleasure, joy; be glad}
6022 CJK UNIFIED IDEOGRAPH-#6022, IRGKangXi=0381.170, RSKangXi=61.5
6023 CJK UNIFIED IDEOGRAPH-#6023, IRGKangXi=0381.180, RSKangXi=61.5
6024 CJK UNIFIED IDEOGRAPH-#6024, IRGKangXi=0381.200, RSKangXi=61.5
6025 CJK UNIFIED IDEOGRAPH-#6025, IRGKangXi=0381.210, RSKangXi=61.5, Def{quick, quickly; urgent, pressing}
6026 CJK UNIFIED IDEOGRAPH-#6026, IRGKangXi=0381.220, RSKangXi=61.5, Def{eager, ardent, impulsive; anxious}
6027 CJK UNIFIED IDEOGRAPH-#6027, IRGKangXi=0381.240, RSKangXi=61.5, Def{nature, character, sex}
6028 CJK UNIFIED IDEOGRAPH-#6028, IRGKangXi=0382.010, RSKangXi=61.5, Def{hatred, enmity, resentment}
6029 CJK UNIFIED IDEOGRAPH-#6029, IRGKangXi=0382.080, RSKangXi=61.5, Def{shy, timid, bashful; look ashamed}
602A CJK UNIFIED IDEOGRAPH-#602A, IRGKangXi=0382.100, RSKangXi=61.5, Def{strange, unusual, peculiar}
602B CJK UNIFIED IDEOGRAPH-#602B, IRGKangXi=0382.130, RSKangXi=61.5, Def{sorry, anxious; depressed}
602C CJK UNIFIED IDEOGRAPH-#602C, IRGKangXi=0382.150, RSKangXi=61.5
602D CJK UNIFIED IDEOGRAPH-#602D, IRGKangXi=0382.160, RSKangXi=61.5, Def{rude}
602E CJK UNIFIED IDEOGRAPH-#602E, IRGKangXi=0382.170, RSKangXi=61.5
602F CJK UNIFIED IDEOGRAPH-#602F, IRGKangXi=0382.180, RSKangXi=61.5, Def{lacking in courage, afraid}
6030 CJK UNIFIED IDEOGRAPH-#6030, IRGKangXi=0382.190, RSKangXi=61.5
6031 CJK UNIFIED IDEOGRAPH-#6031, IRGKangXi=0382.210, RSKangXi=61.5, Def{hastily, in haste, hurriedly}
6032 CJK UNIFIED IDEOGRAPH-#6032, IRGKangXi=0382.220, RSKangXi=61.5, Def{be anxious, be grieved, be sad}
6033 CJK UNIFIED IDEOGRAPH-#6033, IRGKangXi=0382.230, RSKangXi=61.5, Def{wild, mad; flurried}
6034 CJK UNIFIED IDEOGRAPH-#6034, IRGKangXi=0382.240, RSKangXi=61.5
6035 CJK UNIFIED IDEOGRAPH-#6035, IRGKangXi=0382.250, RSKangXi=61.5, Def{fear, be afraid; shy, timid}
6036 CJK UNIFIED IDEOGRAPH-#6036, IRGKangXi=0383.010, RSKangXi=61.5, Def{(Cant.) to have no zeal at all}
6037 CJK UNIFIED IDEOGRAPH-#6037, IRGKangXi=0383.020, RSKangXi=61.5
6038 CJK UNIFIED IDEOGRAPH-#6038, IRGKangXi=0383.110, RSKangXi=61.5, Def{cns 2-2A40 is different}
6039 CJK UNIFIED IDEOGRAPH-#6039, IRGKangXi=0383.111, RSKangXi=61.5, Def{a polite version of he}
603A CJK UNIFIED IDEOGRAPH-#603A, IRGKangXi=0383.111, RSKangXi=61.5, Def{to endure}
603B CJK UNIFIED IDEOGRAPH-#603B, IRGKangXi=0383.111, RSKangXi=12.7, Def{collect; overall, altogether}
603C CJK UNIFIED IDEOGRAPH-#603C, IRGKangXi=0383.111, RSKangXi=61.5, Def{hate, abhor; hatred, resentment}
603D CJK UNIFIED IDEOGRAPH-#603D, IRGKangXi=0383.111, RSKangXi=61.5
603E CJK UNIFIED IDEOGRAPH-#603E, IRGKangXi=0383.111, RSKangXi=61.5, Def{mountain name}
603F CJK UNIFIED IDEOGRAPH-#603F, IRGKangXi=0383.111, RSKangXi=61.5, Def{enjoy, be glad, be pleased}
6040 CJK UNIFIED IDEOGRAPH-#6040, IRGKangXi=0383.120, RSKangXi=61.6
6041 CJK UNIFIED IDEOGRAPH-#6041, IRGKangXi=0383.160, RSKangXi=61.6, Def{that, like this, thus, so, such}
6042 CJK UNIFIED IDEOGRAPH-#6042, IRGKangXi=0383.180, RSKangXi=61.6, Def{careful, sincere, honest; trust}
6043 CJK UNIFIED IDEOGRAPH-#6043, IRGKangXi=0383.190, RSKangXi=61.6, Def{rely on, presume on, trust to}
6044 CJK UNIFIED IDEOGRAPH-#6044, IRGKangXi=0383.200, RSKangXi=61.6
6045 CJK UNIFIED IDEOGRAPH-#6045, IRGKangXi=0383.240, RSKangXi=61.6
6046 CJK UNIFIED IDEOGRAPH-#6046, IRGKangXi=0383.250, RSKangXi=61.6, Def{constant, regular, persistent}
6047 CJK UNIFIED IDEOGRAPH-#6047, IRGKangXi=0383.280, RSKangXi=61.6, Def{fear}
6048 CJK UNIFIED IDEOGRAPH-#6048, IRGKangXi=0383.290, RSKangXi=61.6
6049 CJK UNIFIED IDEOGRAPH-#6049, IRGKangXi=0383.310, RSKangXi=61.6, Def{meaning, purport, drift}
604A CJK UNIFIED IDEOGRAPH-#604A, IRGKangXi=0383.340, RSKangXi=61.6, Def{be united; cooperate}
604B CJK UNIFIED IDEOGRAPH-#604B, IRGKangXi=0383.360, RSKangXi=61.6, Def{love; long for, yearn for; love}
604C CJK UNIFIED IDEOGRAPH-#604C, IRGKangXi=0383.400, RSKangXi=61.6, Def{to worry; frivolous}
604D CJK UNIFIED IDEOGRAPH-#604D, IRGKangXi=0384.030, RSKangXi=61.6, Def{seemingly; absent-minded}
604E CJK UNIFIED IDEOGRAPH-#604E, IRGKangXi=0384.050, RSKangXi=61.6
604F CJK UNIFIED IDEOGRAPH-#604F, IRGKangXi=0384.060, RSKangXi=61.6
6050 CJK UNIFIED IDEOGRAPH-#6050, IRGKangXi=0384.080, RSKangXi=61.6, Def{fear; fearful, apprehensive}
6051 CJK UNIFIED IDEOGRAPH-#6051, IRGKangXi=0384.120, RSKangXi=61.6, Def{to change; to alter; to accommodate oneself to}
6052 CJK UNIFIED IDEOGRAPH-#6052, IRGKangXi=0384.130, RSKangXi=61.6, Def{constant, regular, persistent}
6053 CJK UNIFIED IDEOGRAPH-#6053, IRGKangXi=0384.140, RSKangXi=61.6, Def{vexed}
6054 CJK UNIFIED IDEOGRAPH-#6054, IRGKangXi=0384.150, RSKangXi=61.6, Def{cheerful; bright, sagacious}
6055 CJK UNIFIED IDEOGRAPH-#6055, IRGKangXi=0384.170, RSKangXi=61.6, Def{forgive, excuse, show mercy}
6056 CJK UNIFIED IDEOGRAPH-#6056, IRGKangXi=0384.200, RSKangXi=61.6
6057 CJK UNIFIED IDEOGRAPH-#6057, IRGKangXi=0384.210, RSKangXi=61.6
6058 CJK UNIFIED IDEOGRAPH-#6058, IRGKangXi=0384.220, RSKangXi=61.6
6059 CJK UNIFIED IDEOGRAPH-#6059, IRGKangXi=0384.230, RSKangXi=61.6, Def{illness, sickness; indisposition}
605A CJK UNIFIED IDEOGRAPH-#605A, IRGKangXi=0384.240, RSKangXi=61.6, Def{anger, rage}
605B CJK UNIFIED IDEOGRAPH-#605B, IRGKangXi=0384.260, RSKangXi=61.6, Def{disordered; indistinct doubtful; blurred}
605C CJK UNIFIED IDEOGRAPH-#605C, IRGKangXi=0384.270, RSKangXi=61.6
605D CJK UNIFIED IDEOGRAPH-#605D, IRGKangXi=0384.280, RSKangXi=61.6, Def{carefree; indifferent manner; without sorrow}
605E CJK UNIFIED IDEOGRAPH-#605E, IRGKangXi=0384.290, RSKangXi=61.6
605F CJK UNIFIED IDEOGRAPH-#605F, IRGKangXi=0384.300, RSKangXi=61.6, Def{scared, nervous}
6060 CJK UNIFIED IDEOGRAPH-#6060, IRGKangXi=0384.310, RSKangXi=61.6, Def{strange, unusual, peculiar}
6061 CJK UNIFIED IDEOGRAPH-#6061, IRGKangXi=0384.320, RSKangXi=61.6, Def{stingy, sparing of; close-fisted}
6062 CJK UNIFIED IDEOGRAPH-#6062, IRGKangXi=0384.330, RSKangXi=61.6, Def{restore; big, great, immense, vast}
6063 CJK UNIFIED IDEOGRAPH-#6063, IRGKangXi=0385.020, RSKangXi=61.6, Def{indulge oneself, unrestrained}
6064 CJK UNIFIED IDEOGRAPH-#6064, IRGKangXi=0385.040, RSKangXi=61.6, Def{show pity; relieve, help}
6065 CJK UNIFIED IDEOGRAPH-#6065, IRGKangXi=0385.060, RSKangXi=61.6, Def{shame, humiliation; ashamed}
6066 CJK UNIFIED IDEOGRAPH-#6066, IRGKangXi=0385.070, RSKangXi=61.6
6067 CJK UNIFIED IDEOGRAPH-#6067, IRGKangXi=0385.080, RSKangXi=61.6
6068 CJK UNIFIED IDEOGRAPH-#6068, IRGKangXi=0385.090, RSKangXi=61.6, Def{hatred, dislike; resent, hate}
6069 CJK UNIFIED IDEOGRAPH-#6069, IRGKangXi=0385.110, RSKangXi=61.6, Def{kindness, mercy, charity}
606A CJK UNIFIED IDEOGRAPH-#606A, IRGKangXi=0385.120, RSKangXi=61.6, Def{respectful, reverent}
606B CJK UNIFIED IDEOGRAPH-#606B, IRGKangXi=0385.130, RSKangXi=61.6, Def{in pain, sorrowful}
606C CJK UNIFIED IDEOGRAPH-#606C, IRGKangXi=0385.140, RSKangXi=61.6, Def{quiet, calm, tranquil, peaceful}
606D CJK UNIFIED IDEOGRAPH-#606D, IRGKangXi=0385.150, RSKangXi=61.6, Def{respectful, polite, reverent}
606E CJK UNIFIED IDEOGRAPH-#606E, IRGKangXi=0385.190, RSKangXi=61.6
606F CJK UNIFIED IDEOGRAPH-#606F, IRGKangXi=0385.200, RSKangXi=61.6, Def{rest, put stop to, end, cease}
6070 CJK UNIFIED IDEOGRAPH-#6070, IRGKangXi=0386.010, RSKangXi=61.6, Def{just, exactly, precisely; proper}
6071 CJK UNIFIED IDEOGRAPH-#6071, IRGKangXi=0386.030, RSKangXi=61.6
6072 CJK UNIFIED IDEOGRAPH-#6072, IRGKangXi=0386.150, RSKangXi=61.6
6073 CJK UNIFIED IDEOGRAPH-#6073, IRGKangXi=0386.161, RSKangXi=61.6, Def{sincere, earnest, cordial}
6074 CJK UNIFIED IDEOGRAPH-#6074, IRGKangXi=0386.161, RSKangXi=61.6
6075 CJK UNIFIED IDEOGRAPH-#6075, IRGKangXi=0386.161, RSKangXi=61.6, Def{favor, benefit, confer kindness}
6076 CJK UNIFIED IDEOGRAPH-#6076, IRGKangXi=0386.161, RSKangXi=61.6, Def{evil, wicked, bad, foul}
6077 CJK UNIFIED IDEOGRAPH-#6077, IRGKangXi=0386.161, RSKangXi=61.6
6078 CJK UNIFIED IDEOGRAPH-#6078, IRGKangXi=0386.161, RSKangXi=61.6, Def{sadness, grief; mourn; be moved}
6079 CJK UNIFIED IDEOGRAPH-#6079, IRGKangXi=0386.161, RSKangXi=61.6, Def{feeble, sickly; tranquil, calm}
607A CJK UNIFIED IDEOGRAPH-#607A, IRGKangXi=0386.161, RSKangXi=61.6, Def{enjoy, be contented, joyful}
607B CJK UNIFIED IDEOGRAPH-#607B, IRGKangXi=0386.161, RSKangXi=61.6, Def{feel anguish, feel compassion}
607C CJK UNIFIED IDEOGRAPH-#607C, IRGKangXi=0386.161, RSKangXi=61.6, Def{angered, filled with hate}
607D CJK UNIFIED IDEOGRAPH-#607D, IRGKangXi=0386.161, RSKangXi=61.6, Def{devise, plan, deliberate; consult}
607E CJK UNIFIED IDEOGRAPH-#607E, IRGKangXi=0386.170, RSKangXi=61.7
607F CJK UNIFIED IDEOGRAPH-#607F, IRGKangXi=0386.180, RSKangXi=61.7, Def{instigate, incite; to alarm}
6080 CJK UNIFIED IDEOGRAPH-#6080, IRGKangXi=0386.190, RSKangXi=61.7
6081 CJK UNIFIED IDEOGRAPH-#6081, IRGKangXi=0386.200, RSKangXi=61.7, Def{irritable, nervous, impatient}
6082 CJK UNIFIED IDEOGRAPH-#6082, IRGKangXi=0386.210, RSKangXi=61.7
6083 CJK UNIFIED IDEOGRAPH-#6083, IRGKangXi=0386.220, RSKangXi=61.7, Def{sincere, genuine, honest, loyal}
6084 CJK UNIFIED IDEOGRAPH-#6084, IRGKangXi=0386.240, RSKangXi=61.7, Def{silent, quiet, still; anxious}
6085 CJK UNIFIED IDEOGRAPH-#6085, IRGKangXi=0386.260, RSKangXi=61.7, Def{pleased}
6086 CJK UNIFIED IDEOGRAPH-#6086, IRGKangXi=0386.290, RSKangXi=61.7, Def{happy}
6087 CJK UNIFIED IDEOGRAPH-#6087, IRGKangXi=0386.300, RSKangXi=61.7
6088 CJK UNIFIED IDEOGRAPH-#6088, IRGKangXi=0386.310, RSKangXi=61.7, Def{to enjoin upon; urgent}
6089 CJK UNIFIED IDEOGRAPH-#6089, IRGKangXi=0386.320, RSKangXi=61.7, Def{know, learn about, comprehend}
608A CJK UNIFIED IDEOGRAPH-#608A, IRGKangXi=0386.380, RSKangXi=61.7, Def{wise. to know intuitively}
608B CJK UNIFIED IDEOGRAPH-#608B, IRGKangXi=0386.410, RSKangXi=61.7, Def{stingy, sparing of; closefisted}
608C CJK UNIFIED IDEOGRAPH-#608C, IRGKangXi=0386.430, RSKangXi=61.7, Def{brotherly, respectful}
608D CJK UNIFIED IDEOGRAPH-#608D, IRGKangXi=0387.010, RSKangXi=61.7, Def{courageous, brave; violent}
608E CJK UNIFIED IDEOGRAPH-#608E, IRGKangXi=0387.050, RSKangXi=61.7
608F CJK UNIFIED IDEOGRAPH-#608F, IRGKangXi=0387.080, RSKangXi=61.7
6090 CJK UNIFIED IDEOGRAPH-#6090, IRGKangXi=0387.090, RSKangXi=61.7, Def{respect, regard; to stand in awe of, to be alarmed}
6091 CJK UNIFIED IDEOGRAPH-#6091, IRGKangXi=0387.110, RSKangXi=61.7
6092 CJK UNIFIED IDEOGRAPH-#6092, IRGKangXi=0387.130, RSKangXi=61.7, Def{sorrowful, depressed, unhappy}
6093 CJK UNIFIED IDEOGRAPH-#6093, IRGKangXi=0387.160, RSKangXi=61.7
6094 CJK UNIFIED IDEOGRAPH-#6094, IRGKangXi=0387.170, RSKangXi=61.7, Def{repent, show remorse, regret}
6095 CJK UNIFIED IDEOGRAPH-#6095, IRGKangXi=0387.200, RSKangXi=61.7
6096 CJK UNIFIED IDEOGRAPH-#6096, IRGKangXi=0387.220, RSKangXi=61.7, Def{be contradictory to, go counter}
6097 CJK UNIFIED IDEOGRAPH-#6097, IRGKangXi=0387.230, RSKangXi=61.7
6098 CJK UNIFIED IDEOGRAPH-#6098, IRGKangXi=0387.250, RSKangXi=61.7
6099 CJK UNIFIED IDEOGRAPH-#6099, IRGKangXi=0387.290, RSKangXi=61.7
609A CJK UNIFIED IDEOGRAPH-#609A, IRGKangXi=0387.310, RSKangXi=61.7, Def{afraid, scared, frightened}
609B CJK UNIFIED IDEOGRAPH-#609B, IRGKangXi=0387.340, RSKangXi=61.7, Def{repent, reform}
609C CJK UNIFIED IDEOGRAPH-#609C, IRGKangXi=0387.350, RSKangXi=61.7, Def{obscure}
609D CJK UNIFIED IDEOGRAPH-#609D, IRGKangXi=0388.030, RSKangXi=61.7, Def{to laugh at to pity; afflicted, sad}
609E CJK UNIFIED IDEOGRAPH-#609E, IRGKangXi=0388.040, RSKangXi=61.7, Def{impede; neglect, delay}
609F CJK UNIFIED IDEOGRAPH-#609F, IRGKangXi=0388.050, RSKangXi=61.7, Def{to apprehend, realize, become aware}
60A0 CJK UNIFIED IDEOGRAPH-#60A0, IRGKangXi=0388.070, RSKangXi=61.7, Def{long, far, remote, distant; liesurely}
60A1 CJK UNIFIED IDEOGRAPH-#60A1, IRGKangXi=0388.140, RSKangXi=61.7
60A2 CJK UNIFIED IDEOGRAPH-#60A2, IRGKangXi=0388.150, RSKangXi=61.7
60A3 CJK UNIFIED IDEOGRAPH-#60A3, IRGKangXi=0388.160, RSKangXi=61.7, Def{suffer, worry about; suffering}
60A4 CJK UNIFIED IDEOGRAPH-#60A4, IRGKangXi=0388.210, RSKangXi=61.7, Def{agitated, restless, hurried}
60A5 CJK UNIFIED IDEOGRAPH-#60A5, IRGKangXi=0388.230, RSKangXi=61.7
60A6 CJK UNIFIED IDEOGRAPH-#60A6, IRGKangXi=0388.341, RSKangXi=61.7, Def{pleased, contented, gratified}
60A7 CJK UNIFIED IDEOGRAPH-#60A7, IRGKangXi=0388.341, RSKangXi=61.7, Def{smooth; active; clever, sharp}
60A8 CJK UNIFIED IDEOGRAPH-#60A8, IRGKangXi=0388.341, RSKangXi=61.7, Def{honorific for 'you'}
60A9 CJK UNIFIED IDEOGRAPH-#60A9, IRGKangXi=0388.341, RSKangXi=61.7, Def{angered, filled with hate}
60AA CJK UNIFIED IDEOGRAPH-#60AA, IRGKangXi=0388.341, RSKangXi=61.7, Def{evil, wicked, bad, foul}
60AB CJK UNIFIED IDEOGRAPH-#60AB, IRGKangXi=0388.341, RSKangXi=61.7, Def{sincerity, honesty; modest}
60AC CJK UNIFIED IDEOGRAPH-#60AC, IRGKangXi=0388.341, RSKangXi=61.7, Def{hang, suspend, hoist; be hung}
60AD CJK UNIFIED IDEOGRAPH-#60AD, IRGKangXi=0388.341, RSKangXi=61.7, Def{miserly, parsimonious, stingy}
60AE CJK UNIFIED IDEOGRAPH-#60AE, IRGKangXi=0388.341, RSKangXi=61.7, Def{impede; neglect, delay}
60AF CJK UNIFIED IDEOGRAPH-#60AF, IRGKangXi=0388.341, RSKangXi=61.7, Def{pity, sympathize with, grieve for}
60B0 CJK UNIFIED IDEOGRAPH-#60B0, IRGKangXi=0388.350, RSKangXi=61.8, Def{enjoy, amuse, please; joy}
60B1 CJK UNIFIED IDEOGRAPH-#60B1, IRGKangXi=0388.360, RSKangXi=61.8, Def{to be desirous of speaking}
60B2 CJK UNIFIED IDEOGRAPH-#60B2, IRGKangXi=0388.370, RSKangXi=61.8, Def{sorrow, grief; sorry, sad}
60B3 CJK UNIFIED IDEOGRAPH-#60B3, IRGKangXi=0388.410, RSKangXi=61.8, Def{ethics, morality, virtue}
60B4 CJK UNIFIED IDEOGRAPH-#60B4, IRGKangXi=0389.020, RSKangXi=61.8, Def{suffer, become emaciated, haggard}
60B5 CJK UNIFIED IDEOGRAPH-#60B5, IRGKangXi=0389.030, RSKangXi=61.8, Def{disappointed, dissatisfied}
60B6 CJK UNIFIED IDEOGRAPH-#60B6, IRGKangXi=1333.091, RSKangXi=61.8, Def{gloomy, depressed, melancholy}
60B7 CJK UNIFIED IDEOGRAPH-#60B7, IRGKangXi=0389.070, RSKangXi=61.8
60B8 CJK UNIFIED IDEOGRAPH-#60B8, IRGKangXi=0389.080, RSKangXi=61.8, Def{fearful, apprehensive, perturbed}
60B9 CJK UNIFIED IDEOGRAPH-#60B9, IRGKangXi=0389.090, RSKangXi=61.8
60BA CJK UNIFIED IDEOGRAPH-#60BA, IRGKangXi=0389.100, RSKangXi=61.8
60BB CJK UNIFIED IDEOGRAPH-#60BB, IRGKangXi=0389.120, RSKangXi=61.8, Def{anger, vexation; angry, indignant}
60BC CJK UNIFIED IDEOGRAPH-#60BC, IRGKangXi=0389.130, RSKangXi=61.8, Def{grieve, mourn, lament; grieved}
60BD CJK UNIFIED IDEOGRAPH-#60BD, IRGKangXi=0389.190, RSKangXi=61.8, Def{sorrowful, grieved, melancholy}
60BE CJK UNIFIED IDEOGRAPH-#60BE, IRGKangXi=0389.210, RSKangXi=61.8, Def{naive, guileless, simple-minded}
60BF CJK UNIFIED IDEOGRAPH-#60BF, IRGKangXi=0389.220, RSKangXi=61.8
60C0 CJK UNIFIED IDEOGRAPH-#60C0, IRGKangXi=0389.240, RSKangXi=61.8
60C1 CJK UNIFIED IDEOGRAPH-#60C1, IRGKangXi=0389.250, RSKangXi=61.8
60C2 CJK UNIFIED IDEOGRAPH-#60C2, IRGKangXi=0389.260, RSKangXi=61.8
60C3 CJK UNIFIED IDEOGRAPH-#60C3, IRGKangXi=0389.270, RSKangXi=61.8
60C4 CJK UNIFIED IDEOGRAPH-#60C4, IRGKangXi=0389.290, RSKangXi=61.8, Def{long for; hungry}
60C5 CJK UNIFIED IDEOGRAPH-#60C5, IRGKangXi=0389.310, RSKangXi=61.8, Def{feeling, sentiment, emotion}
60C6 CJK UNIFIED IDEOGRAPH-#60C6, IRGKangXi=0389.340, RSKangXi=61.8, Def{distressed, regretful, sad}
60C7 CJK UNIFIED IDEOGRAPH-#60C7, IRGKangXi=0390.010, RSKangXi=61.8, Def{be kind, cordial, sincere}
60C8 CJK UNIFIED IDEOGRAPH-#60C8, IRGKangXi=0390.040, RSKangXi=61.8
60C9 CJK UNIFIED IDEOGRAPH-#60C9, IRGKangXi=0390.060, RSKangXi=61.8
60CA CJK UNIFIED IDEOGRAPH-#60CA, IRGKangXi=0390.110, RSKangXi=61.8, Def{frighten, surprise, startle}
60CB CJK UNIFIED IDEOGRAPH-#60CB, IRGKangXi=0390.150, RSKangXi=61.8, Def{regret, be sorry; alarmed}
60CC CJK UNIFIED IDEOGRAPH-#60CC, IRGKangXi=0390.160, RSKangXi=61.8, Def{to bear a grudge against}
60CD CJK UNIFIED IDEOGRAPH-#60CD, IRGKangXi=0390.180, RSKangXi=61.8
60CE CJK UNIFIED IDEOGRAPH-#60CE, IRGKangXi=0390.200, RSKangXi=61.8, Def{injure, harm, murder}
60CF CJK UNIFIED IDEOGRAPH-#60CF, IRGKangXi=0390.300, RSKangXi=61.8, Def{avaricious; greedy cold}
60D0 CJK UNIFIED IDEOGRAPH-#60D0, IRGKangXi=0390.330, RSKangXi=61.8
60D1 CJK UNIFIED IDEOGRAPH-#60D1, IRGKangXi=0390.340, RSKangXi=61.8, Def{confuse, mislead, baffle; doubt}
60D2 CJK UNIFIED IDEOGRAPH-#60D2, IRGKangXi=0390.350, RSKangXi=61.8
60D3 CJK UNIFIED IDEOGRAPH-#60D3, IRGKangXi=0390.400, RSKangXi=61.8, Def{careful, sincere, candid}
60D4 CJK UNIFIED IDEOGRAPH-#60D4, IRGKangXi=0390.450, RSKangXi=61.8, Def{cheerful}
60D5 CJK UNIFIED IDEOGRAPH-#60D5, IRGKangXi=0390.480, RSKangXi=61.8, Def{be cautious, careful, alert}
60D6 CJK UNIFIED IDEOGRAPH-#60D6, IRGKangXi=0391.010, RSKangXi=61.8, Def{respect; fear}
60D7 CJK UNIFIED IDEOGRAPH-#60D7, IRGKangXi=0391.030, RSKangXi=61.8, Def{(Cant.) to think, consider}
60D8 CJK UNIFIED IDEOGRAPH-#60D8, IRGKangXi=0391.060, RSKangXi=61.8, Def{disconcerted, dejected, discouraged}
60D9 CJK UNIFIED IDEOGRAPH-#60D9, IRGKangXi=0391.070, RSKangXi=61.8, Def{sad, melancholy, grieving, mournful}
60DA CJK UNIFIED IDEOGRAPH-#60DA, IRGKangXi=0391.080, RSKangXi=61.8, Def{absent-minded, confused}
60DB CJK UNIFIED IDEOGRAPH-#60DB, IRGKangXi=0391.090, RSKangXi=61.8, Def{confused, stupid, dull, senile}
60DC CJK UNIFIED IDEOGRAPH-#60DC, IRGKangXi=0391.110, RSKangXi=61.8, Def{pity, regret, rue, begrudge}
60DD CJK UNIFIED IDEOGRAPH-#60DD, IRGKangXi=0391.120, RSKangXi=61.8, Def{alarmed, agitated}
60DE CJK UNIFIED IDEOGRAPH-#60DE, IRGKangXi=0391.150, RSKangXi=61.8
60DF CJK UNIFIED IDEOGRAPH-#60DF, IRGKangXi=0391.170, RSKangXi=61.8, Def{but, however, nevertheless; only}
60E0 CJK UNIFIED IDEOGRAPH-#60E0, IRGKangXi=0391.190, RSKangXi=61.8, Def{favor, benefit, confer kindness}
60E1 CJK UNIFIED IDEOGRAPH-#60E1, IRGKangXi=0391.250, RSKangXi=61.8, Def{evil, wicked, bad, foul}
60E2 CJK UNIFIED IDEOGRAPH-#60E2, IRGKangXi=0391.270, RSKangXi=61.8
60E3 CJK UNIFIED IDEOGRAPH-#60E3, IRGKangXi=0392.030, RSKangXi=61.8, Def{overall [questionable variant]}
60E4 CJK UNIFIED IDEOGRAPH-#60E4, IRGKangXi=0392.090, RSKangXi=61.8
60E5 CJK UNIFIED IDEOGRAPH-#60E5, IRGKangXi=0396.071, RSKangXi=61.8
60E6 CJK UNIFIED IDEOGRAPH-#60E6, IRGKangXi=0392.181, RSKangXi=61.8, Def{think of, remember, miss}
60E7 CJK UNIFIED IDEOGRAPH-#60E7, IRGKangXi=0392.181, RSKangXi=61.8, Def{fear, be afraid of, dread}
60E8 CJK UNIFIED IDEOGRAPH-#60E8, IRGKangXi=0392.181, RSKangXi=61.8, Def{sad, pitiful, wretched; cruel}
60E9 CJK UNIFIED IDEOGRAPH-#60E9, IRGKangXi=0392.181, RSKangXi=61.8, Def{punish, reprimand; warn}
60EA CJK UNIFIED IDEOGRAPH-#60EA, IRGKangXi=0392.181, RSKangXi=61.8, Def{ethics}
60EB CJK UNIFIED IDEOGRAPH-#60EB, IRGKangXi=0392.181, RSKangXi=34.9, Def{tired, weary, fatigued}
60EC CJK UNIFIED IDEOGRAPH-#60EC, IRGKangXi=0392.181, RSKangXi=61.8, Def{be satisfied, be comfortable}
60ED CJK UNIFIED IDEOGRAPH-#60ED, IRGKangXi=0392.181, RSKangXi=61.8, Def{ashamed, humiliated; shameful}
60EE CJK UNIFIED IDEOGRAPH-#60EE, IRGKangXi=0392.181, RSKangXi=61.8, Def{dread, shrink from, shirk, fear}
60EF CJK UNIFIED IDEOGRAPH-#60EF, IRGKangXi=0392.181, RSKangXi=61.8, Def{habit, custom; habitually, usual}
60F0 CJK UNIFIED IDEOGRAPH-#60F0, IRGKangXi=0392.210, RSKangXi=61.9, Def{indolent, careless, lazy, idle}
60F1 CJK UNIFIED IDEOGRAPH-#60F1, IRGKangXi=0392.240, RSKangXi=61.9, Def{angered, filled with hate}
60F2 CJK UNIFIED IDEOGRAPH-#60F2, IRGKangXi=0392.250, RSKangXi=61.9, Def{devise, plan, deliberate; consult}
60F3 CJK UNIFIED IDEOGRAPH-#60F3, IRGKangXi=0392.260, RSKangXi=61.9, Def{think, speculate, plan, consider}
60F4 CJK UNIFIED IDEOGRAPH-#60F4, IRGKangXi=0392.270, RSKangXi=61.9, Def{afraid, apprehensive, nervous}
60F5 CJK UNIFIED IDEOGRAPH-#60F5, IRGKangXi=0392.290, RSKangXi=61.9
60F6 CJK UNIFIED IDEOGRAPH-#60F6, IRGKangXi=0392.320, RSKangXi=61.9, Def{fearful, afraid, anxious, nervous}
60F7 CJK UNIFIED IDEOGRAPH-#60F7, IRGKangXi=0392.330, RSKangXi=61.9, Def{wriggle; stupid; silly; fat}
60F8 CJK UNIFIED IDEOGRAPH-#60F8, IRGKangXi=0392.340, RSKangXi=61.9, Def{troubled, worried, distressed}
60F9 CJK UNIFIED IDEOGRAPH-#60F9, IRGKangXi=0393.010, RSKangXi=61.9, Def{irritate, vex, offend, incite}
60FA CJK UNIFIED IDEOGRAPH-#60FA, IRGKangXi=0393.040, RSKangXi=61.9, Def{intelligent, clever, astute}
60FB CJK UNIFIED IDEOGRAPH-#60FB, IRGKangXi=0393.050, RSKangXi=61.9, Def{feel anguish, feel compassion}
60FC CJK UNIFIED IDEOGRAPH-#60FC, IRGKangXi=0393.080, RSKangXi=61.9, Def{narrow-minded}
60FD CJK UNIFIED IDEOGRAPH-#60FD, IRGKangXi=0393.110, RSKangXi=61.9, Def{confused}
60FE CJK UNIFIED IDEOGRAPH-#60FE, IRGKangXi=0393.150, RSKangXi=61.9
60FF CJK UNIFIED IDEOGRAPH-#60FF, IRGKangXi=0393.180, RSKangXi=61.9
6100 CJK UNIFIED IDEOGRAPH-#6100, IRGKangXi=0393.200, RSKangXi=61.9, Def{to change one's countenance, be anxious; to blush}
6101 CJK UNIFIED IDEOGRAPH-#6101, IRGKangXi=0393.210, RSKangXi=61.9, Def{anxiety; to worry about, be anxious}
6102 CJK UNIFIED IDEOGRAPH-#6102, IRGKangXi=0393.250, RSKangXi=61.9
6103 CJK UNIFIED IDEOGRAPH-#6103, IRGKangXi=0393.260, RSKangXi=61.9, Def{relax}
6104 CJK UNIFIED IDEOGRAPH-#6104, IRGKangXi=0393.270, RSKangXi=61.9
6105 CJK UNIFIED IDEOGRAPH-#6105, IRGKangXi=0393.330, RSKangXi=61.9
6106 CJK UNIFIED IDEOGRAPH-#6106, IRGKangXi=0393.350, RSKangXi=61.9, Def{a fault, mistake, error, transgression}
6107 CJK UNIFIED IDEOGRAPH-#6107, IRGKangXi=0394.010, RSKangXi=61.9
6108 CJK UNIFIED IDEOGRAPH-#6108, IRGKangXi=0394.030, RSKangXi=61.9, Def{more and more, even more}
6109 CJK UNIFIED IDEOGRAPH-#6109, IRGKangXi=0394.040, RSKangXi=61.9, Def{pleasant, delightful; please}
610A CJK UNIFIED IDEOGRAPH-#610A, IRGKangXi=0394.160, RSKangXi=61.9, Def{sincere, honest; depressed}
610B CJK UNIFIED IDEOGRAPH-#610B, IRGKangXi=0394.170, RSKangXi=61.9
610C CJK UNIFIED IDEOGRAPH-#610C, IRGKangXi=0394.180, RSKangXi=61.9
610D CJK UNIFIED IDEOGRAPH-#610D, IRGKangXi=0394.190, RSKangXi=61.9, Def{pity, sympathize with}
610E CJK UNIFIED IDEOGRAPH-#610E, IRGKangXi=0394.210, RSKangXi=61.9, Def{obstinate, stubborn, headstrong}
610F CJK UNIFIED IDEOGRAPH-#610F, IRGKangXi=0394.220, RSKangXi=61.9, Def{thought, idea, opinion; think}
6110 CJK UNIFIED IDEOGRAPH-#6110, IRGKangXi=0394.260, RSKangXi=61.9, Def{bashful; to consider}
6111 CJK UNIFIED IDEOGRAPH-#6111, IRGKangXi=0394.290, RSKangXi=61.9
6112 CJK UNIFIED IDEOGRAPH-#6112, IRGKangXi=0394.350, RSKangXi=61.9, Def{rest, stop}
6113 CJK UNIFIED IDEOGRAPH-#6113, IRGKangXi=0395.020, RSKangXi=61.9, Def{profligate}
6114 CJK UNIFIED IDEOGRAPH-#6114, IRGKangXi=0395.030, RSKangXi=61.9, Def{comfortable, contented, peaceful}
6115 CJK UNIFIED IDEOGRAPH-#6115, IRGKangXi=0395.050, RSKangXi=61.9, Def{startled, alarmed, astonished}
6116 CJK UNIFIED IDEOGRAPH-#6116, IRGKangXi=0395.060, RSKangXi=61.9, Def{to hesitate}
6117 CJK UNIFIED IDEOGRAPH-#6117, IRGKangXi=0395.080, RSKangXi=61.9
6118 CJK UNIFIED IDEOGRAPH-#6118, IRGKangXi=0395.090, RSKangXi=61.9
6119 CJK UNIFIED IDEOGRAPH-#6119, IRGKangXi=0395.100, RSKangXi=61.9
611A CJK UNIFIED IDEOGRAPH-#611A, IRGKangXi=0395.120, RSKangXi=61.9, Def{stupid, doltish, foolish}
611B CJK UNIFIED IDEOGRAPH-#611B, IRGKangXi=0395.130, RSKangXi=61.9, Def{love, be fond of, like}
611C CJK UNIFIED IDEOGRAPH-#611C, IRGKangXi=0395.180, RSKangXi=61.9, Def{be satisfied, be comfortable}
611D CJK UNIFIED IDEOGRAPH-#611D, IRGKangXi=0395.190, RSKangXi=61.9
611E CJK UNIFIED IDEOGRAPH-#611E, IRGKangXi=0395.200, RSKangXi=61.9, Def{timid, apprehensive}
611F CJK UNIFIED IDEOGRAPH-#611F, IRGKangXi=0395.210, RSKangXi=61.9, Def{feel, perceive, emotion}
6120 CJK UNIFIED IDEOGRAPH-#6120, IRGKangXi=0395.240, RSKangXi=61.9, Def{angry}
6121 CJK UNIFIED IDEOGRAPH-#6121, IRGKangXi=0395.260, RSKangXi=61.9, Def{absent-minded, confused}
6122 CJK UNIFIED IDEOGRAPH-#6122, IRGKangXi=0395.270, RSKangXi=61.9, Def{hesitant; modest}
6123 CJK UNIFIED IDEOGRAPH-#6123, IRGKangXi=0396.071, RSKangXi=61.9, Def{be in a daze}
6124 CJK UNIFIED IDEOGRAPH-#6124, IRGKangXi=0396.071, RSKangXi=61.9, Def{resent, hate; indignant}
6125 CJK UNIFIED IDEOGRAPH-#6125, IRGKangXi=0396.071, RSKangXi=61.9
6126 CJK UNIFIED IDEOGRAPH-#6126, IRGKangXi=0396.071, RSKangXi=61.9, Def{confused, troubled, muddle-headed}
6127 CJK UNIFIED IDEOGRAPH-#6127, IRGKangXi=0396.080, RSKangXi=61.10, Def{ashamed, conscience-stricken}
6128 CJK UNIFIED IDEOGRAPH-#6128, IRGKangXi=0396.090, RSKangXi=61.10, Def{sincerity, honesty; cautious}
6129 CJK UNIFIED IDEOGRAPH-#6129, IRGKangXi=0396.100, RSKangXi=61.10
612A CJK UNIFIED IDEOGRAPH-#612A, IRGKangXi=0396.110, RSKangXi=61.10, Def{to be grieved, sad}
612B CJK UNIFIED IDEOGRAPH-#612B, IRGKangXi=0396.120, RSKangXi=61.10, Def{guileless, sincere, honest}
612C CJK UNIFIED IDEOGRAPH-#612C, IRGKangXi=0396.140, RSKangXi=61.10, Def{accuse; sue; inform; narrate}
612D CJK UNIFIED IDEOGRAPH-#612D, IRGKangXi=0396.150, RSKangXi=61.10
612E CJK UNIFIED IDEOGRAPH-#612E, IRGKangXi=0396.160, RSKangXi=61.10, Def{distressed, agitated}
612F CJK UNIFIED IDEOGRAPH-#612F, IRGKangXi=0396.180, RSKangXi=61.10
6130 CJK UNIFIED IDEOGRAPH-#6130, IRGKangXi=0396.210, RSKangXi=61.10, Def{clearness of mind; doubtful; uncertain}
6131 CJK UNIFIED IDEOGRAPH-#6131, IRGKangXi=0396.230, RSKangXi=61.10
6132 CJK UNIFIED IDEOGRAPH-#6132, IRGKangXi=0396.270, RSKangXi=61.10
6133 CJK UNIFIED IDEOGRAPH-#6133, IRGKangXi=0396.280, RSKangXi=61.10
6134 CJK UNIFIED IDEOGRAPH-#6134, IRGKangXi=0396.320, RSKangXi=61.10, Def{sad, broken-hearted, disconsolate}
6135 CJK UNIFIED IDEOGRAPH-#6135, IRGKangXi=0396.340, RSKangXi=61.10
6136 CJK UNIFIED IDEOGRAPH-#6136, IRGKangXi=0396.360, RSKangXi=61.10
6137 CJK UNIFIED IDEOGRAPH-#6137, IRGKangXi=0396.380, RSKangXi=61.10, Def{enjoy, be contented, joyful}
6138 CJK UNIFIED IDEOGRAPH-#6138, IRGKangXi=0396.390, RSKangXi=61.10
6139 CJK UNIFIED IDEOGRAPH-#6139, IRGKangXi=0396.420, RSKangXi=61.19
613A CJK UNIFIED IDEOGRAPH-#613A, IRGKangXi=0396.440, RSKangXi=61.10
613B CJK UNIFIED IDEOGRAPH-#613B, IRGKangXi=0396.460, RSKangXi=61.10, Def{to yield, accord; humble, modest}
613C CJK UNIFIED IDEOGRAPH-#613C, IRGKangXi=0396.470, RSKangXi=61.10, Def{act with care, be cautious}
613D CJK UNIFIED IDEOGRAPH-#613D, IRGKangXi=0397.040, RSKangXi=61.10, Def{gamble, play games; wide, broad}
613E CJK UNIFIED IDEOGRAPH-#613E, IRGKangXi=0397.050, RSKangXi=61.10, Def{anger, wrath, hatred, enmity}
613F CJK UNIFIED IDEOGRAPH-#613F, IRGKangXi=0397.060, RSKangXi=61.10, Def{sincere, honest, virtuous}
6140 CJK UNIFIED IDEOGRAPH-#6140, IRGKangXi=0397.100, RSKangXi=61.10
6141 CJK UNIFIED IDEOGRAPH-#6141, IRGKangXi=0397.110, RSKangXi=61.10, Def{dishonor, disobey; insult}
6142 CJK UNIFIED IDEOGRAPH-#6142, IRGKangXi=0397.170, RSKangXi=61.10, Def{urge, incite, egg-on}
6143 CJK UNIFIED IDEOGRAPH-#6143, IRGKangXi=0397.190, RSKangXi=61.10
6144 CJK UNIFIED IDEOGRAPH-#6144, IRGKangXi=0397.200, RSKangXi=61.10, Def{shiver, shudder, tremble; tremble}
6145 CJK UNIFIED IDEOGRAPH-#6145, IRGKangXi=0397.210, RSKangXi=61.10, Def{agitated}
6146 CJK UNIFIED IDEOGRAPH-#6146, IRGKangXi=0397.220, RSKangXi=61.10, Def{excessive, dissolute; delighted}
6147 CJK UNIFIED IDEOGRAPH-#6147, IRGKangXi=0397.230, RSKangXi=61.10, Def{careful, anxious, attentive}
6148 CJK UNIFIED IDEOGRAPH-#6148, IRGKangXi=0397.250, RSKangXi=61.10, Def{kind, charitable, benevolent}
6149 CJK UNIFIED IDEOGRAPH-#6149, IRGKangXi=0397.260, RSKangXi=61.10, Def{to bring up; to raise}
614A CJK UNIFIED IDEOGRAPH-#614A, IRGKangXi=0398.020, RSKangXi=61.10, Def{to resent; contended; satisfied}
614B CJK UNIFIED IDEOGRAPH-#614B, IRGKangXi=0398.030, RSKangXi=61.10, Def{manner, bearing, attitude}
614C CJK UNIFIED IDEOGRAPH-#614C, IRGKangXi=0398.090, RSKangXi=61.10, Def{nervous, panicky, frantic}
614D CJK UNIFIED IDEOGRAPH-#614D, IRGKangXi=0398.110, RSKangXi=61.10, Def{angry, indignant, resentful}
614E CJK UNIFIED IDEOGRAPH-#614E, IRGKangXi=0398.261, RSKangXi=61.10, Def{act with care, be cautious}
614F CJK UNIFIED IDEOGRAPH-#614F, IRGKangXi=0398.261, RSKangXi=61.10
6150 CJK UNIFIED IDEOGRAPH-#6150, IRGKangXi=0398.261, RSKangXi=61.10
6151 CJK UNIFIED IDEOGRAPH-#6151, IRGKangXi=0398.261, RSKangXi=61.10, Def{afraid, scared, fearful}
6152 CJK UNIFIED IDEOGRAPH-#6152, IRGKangXi=0398.270, RSKangXi=61.11
6153 CJK UNIFIED IDEOGRAPH-#6153, IRGKangXi=0398.290, RSKangXi=61.11
6154 CJK UNIFIED IDEOGRAPH-#6154, IRGKangXi=0398.310, RSKangXi=61.11
6155 CJK UNIFIED IDEOGRAPH-#6155, IRGKangXi=0398.320, RSKangXi=61.11, Def{long for, desire; admire}
6156 CJK UNIFIED IDEOGRAPH-#6156, IRGKangXi=0398.350, RSKangXi=61.11
6157 CJK UNIFIED IDEOGRAPH-#6157, IRGKangXi=0398.370, RSKangXi=61.11
6158 CJK UNIFIED IDEOGRAPH-#6158, IRGKangXi=0398.380, RSKangXi=61.11, Def{sad, pitiful, wretched; cruel}
6159 CJK UNIFIED IDEOGRAPH-#6159, IRGKangXi=0398.390, RSKangXi=61.11, Def{ashamed, humiliated; shameful}
615A CJK UNIFIED IDEOGRAPH-#615A, IRGKangXi=0398.400, RSKangXi=61.11, Def{ashamed, humiliated; shameful}
615B CJK UNIFIED IDEOGRAPH-#615B, IRGKangXi=0399.010, RSKangXi=61.11
615C CJK UNIFIED IDEOGRAPH-#615C, IRGKangXi=0399.020, RSKangXi=61.11, Def{name of a monk in Tang dynasty}
615D CJK UNIFIED IDEOGRAPH-#615D, IRGKangXi=0399.030, RSKangXi=61.11, Def{do evil in secret; evil, vice}
615E CJK UNIFIED IDEOGRAPH-#615E, IRGKangXi=0399.040, RSKangXi=61.11, Def{terrified, alarmed}
615F CJK UNIFIED IDEOGRAPH-#615F, IRGKangXi=0399.060, RSKangXi=61.11, Def{sadness, grief; mourn; be moved}
6160 CJK UNIFIED IDEOGRAPH-#6160, IRGKangXi=0399.080, RSKangXi=61.11
6161 CJK UNIFIED IDEOGRAPH-#6161, IRGKangXi=0399.110, RSKangXi=61.11
6162 CJK UNIFIED IDEOGRAPH-#6162, IRGKangXi=0399.120, RSKangXi=61.11, Def{slow(ly), leisurely, sluggish}
6163 CJK UNIFIED IDEOGRAPH-#6163, IRGKangXi=0399.130, RSKangXi=61.11, Def{habit, custom; habitually, usually}
6164 CJK UNIFIED IDEOGRAPH-#6164, IRGKangXi=0399.140, RSKangXi=61.11, Def{sincerity, honesty; modest}
6165 CJK UNIFIED IDEOGRAPH-#6165, IRGKangXi=0399.160, RSKangXi=61.11, Def{sincere, earnest}
6166 CJK UNIFIED IDEOGRAPH-#6166, IRGKangXi=0399.170, RSKangXi=61.11
6167 CJK UNIFIED IDEOGRAPH-#6167, IRGKangXi=0399.180, RSKangXi=61.11, Def{bright, intelligent; intelligence}
6168 CJK UNIFIED IDEOGRAPH-#6168, IRGKangXi=0399.240, RSKangXi=61.9, Def{sigh, regret; generous}
6169 CJK UNIFIED IDEOGRAPH-#6169, IRGKangXi=0399.270, RSKangXi=61.11
616A CJK UNIFIED IDEOGRAPH-#616A, IRGKangXi=0399.280, RSKangXi=61.11, Def{annoyed}
616B CJK UNIFIED IDEOGRAPH-#616B, IRGKangXi=0399.290, RSKangXi=61.11, Def{to alarm; to instigate, arouse, incite}
616C CJK UNIFIED IDEOGRAPH-#616C, IRGKangXi=0399.310, RSKangXi=61.11, Def{brave; cautious; sad}
616D CJK UNIFIED IDEOGRAPH-#616D, IRGKangXi=0399.330, RSKangXi=61.11, Def{cautious; willing; but}
616E CJK UNIFIED IDEOGRAPH-#616E, IRGKangXi=0399.340, RSKangXi=61.11, Def{be concerned, worry about}
616F CJK UNIFIED IDEOGRAPH-#616F, IRGKangXi=0400.010, RSKangXi=61.11
6170 CJK UNIFIED IDEOGRAPH-#6170, IRGKangXi=0400.030, RSKangXi=61.11, Def{comfort, console, calm}
6171 CJK UNIFIED IDEOGRAPH-#6171, IRGKangXi=0400.050, RSKangXi=61.11, Def{sad}
6172 CJK UNIFIED IDEOGRAPH-#6172, IRGKangXi=0400.060, RSKangXi=61.11
6173 CJK UNIFIED IDEOGRAPH-#6173, IRGKangXi=0400.080, RSKangXi=61.11, Def{miserly, parsimonious, stingy}
6174 CJK UNIFIED IDEOGRAPH-#6174, IRGKangXi=0400.110, RSKangXi=61.11, Def{fear; terrified, fearful; fear}
6175 CJK UNIFIED IDEOGRAPH-#6175, IRGKangXi=0400.120, RSKangXi=61.11, Def{indolent, easy-going, lazy}
6176 CJK UNIFIED IDEOGRAPH-#6176, IRGKangXi=0400.130, RSKangXi=61.11, Def{congratulate, celebrate}
6177 CJK UNIFIED IDEOGRAPH-#6177, IRGKangXi=0400.160, RSKangXi=61.11, Def{ardent; generous, magnanimous}
6178 CJK UNIFIED IDEOGRAPH-#6178, IRGKangXi=0400.170, RSKangXi=61.11
6179 CJK UNIFIED IDEOGRAPH-#6179, IRGKangXi=0401.020, RSKangXi=61.11
617A CJK UNIFIED IDEOGRAPH-#617A, IRGKangXi=0401.070, RSKangXi=61.11
617B CJK UNIFIED IDEOGRAPH-#617B, IRGKangXi=0401.120, RSKangXi=61.11
617C CJK UNIFIED IDEOGRAPH-#617C, IRGKangXi=0401.130, RSKangXi=61.11, Def{sorrowful, mournful; sorrow}
617D CJK UNIFIED IDEOGRAPH-#617D, IRGKangXi=0401.140, RSKangXi=61.11, Def{sorrowful, mournful; sorrow}
617E CJK UNIFIED IDEOGRAPH-#617E, IRGKangXi=0401.180, RSKangXi=61.11, Def{lust, desire, passion; appetite}
617F CJK UNIFIED IDEOGRAPH-#617F, IRGKangXi=0401.190, RSKangXi=61.11
6180 CJK UNIFIED IDEOGRAPH-#6180, IRGKangXi=0401.220, RSKangXi=61.11, Def{to rely on}
6181 CJK UNIFIED IDEOGRAPH-#6181, IRGKangXi=0401.250, RSKangXi=61.11
6182 CJK UNIFIED IDEOGRAPH-#6182, IRGKangXi=0401.260, RSKangXi=61.11, Def{sad, grieved; grief, melancholy}
6183 CJK UNIFIED IDEOGRAPH-#6183, IRGKangXi=0401.300, RSKangXi=61.11, Def{foolish, stupid, dull, silly}
6184 CJK UNIFIED IDEOGRAPH-#6184, IRGKangXi=0401.320, RSKangXi=61.11
6185 CJK UNIFIED IDEOGRAPH-#6185, IRGKangXi=0401.360, RSKangXi=61.11
6186 CJK UNIFIED IDEOGRAPH-#6186, IRGKangXi=0401.370, RSKangXi=61.11
6187 CJK UNIFIED IDEOGRAPH-#6187, IRGKangXi=0401.391, RSKangXi=61.11, Def{rest, take rest}
6188 CJK UNIFIED IDEOGRAPH-#6188, IRGKangXi=0401.400, RSKangXi=61.11
6189 CJK UNIFIED IDEOGRAPH-#6189, IRGKangXi=0402.010, RSKangXi=61.12
618A CJK UNIFIED IDEOGRAPH-#618A, IRGKangXi=0402.020, RSKangXi=61.12, Def{tired, weary, fatigued}
618B CJK UNIFIED IDEOGRAPH-#618B, IRGKangXi=0402.030, RSKangXi=61.12, Def{to suppress inner feelings; hasty}
618C CJK UNIFIED IDEOGRAPH-#618C, IRGKangXi=0402.050, RSKangXi=61.12
618D CJK UNIFIED IDEOGRAPH-#618D, IRGKangXi=0402.070, RSKangXi=61.12, Def{be haughty, proud, arrogant}
618E CJK UNIFIED IDEOGRAPH-#618E, IRGKangXi=0402.080, RSKangXi=61.12, Def{hate, detest, abhor; hatred}
618F CJK UNIFIED IDEOGRAPH-#618F, IRGKangXi=0402.110
6190 CJK UNIFIED IDEOGRAPH-#6190, IRGKangXi=0402.120, RSKangXi=61.12, Def{pity, sympathize}
6191 CJK UNIFIED IDEOGRAPH-#6191, IRGKangXi=0402.160, RSKangXi=61.12, Def{lean on, depend on, rely on}
6192 CJK UNIFIED IDEOGRAPH-#6192, IRGKangXi=0402.170, RSKangXi=61.12, Def{confused, troubled, muddle-headed}
6193 CJK UNIFIED IDEOGRAPH-#6193, IRGKangXi=0402.180, RSKangXi=61.12
6194 CJK UNIFIED IDEOGRAPH-#6194, IRGKangXi=0402.190, RSKangXi=61.12, Def{be worn-out, emaciated, haggard}
6195 CJK UNIFIED IDEOGRAPH-#6195, IRGKangXi=0402.200, RSKangXi=61.12
6196 CJK UNIFIED IDEOGRAPH-#6196, IRGKangXi=0402.210, RSKangXi=61.12, Def{cautious; willing; but, moreover}
6197 CJK UNIFIED IDEOGRAPH-#6197, IRGKangXi=0402.220, RSKangXi=61.12
6198 CJK UNIFIED IDEOGRAPH-#6198, IRGKangXi=0402.240, RSKangXi=61.12, Def{like, love, enjoy; joyful thing}
6199 CJK UNIFIED IDEOGRAPH-#6199, IRGKangXi=0402.250, RSKangXi=61.12, Def{like, love, enjoy; joyful thing}
619A CJK UNIFIED IDEOGRAPH-#619A, IRGKangXi=0403.010, RSKangXi=61.12, Def{dread, shrink from, shirk, fear}
619B CJK UNIFIED IDEOGRAPH-#619B, IRGKangXi=0403.030, RSKangXi=61.12
619C CJK UNIFIED IDEOGRAPH-#619C, IRGKangXi=0403.040, RSKangXi=61.12
619D CJK UNIFIED IDEOGRAPH-#619D, IRGKangXi=0403.050, RSKangXi=61.12, Def{to dislike, to abhor, to hate}
619E CJK UNIFIED IDEOGRAPH-#619E, IRGKangXi=0403.070, RSKangXi=61.12
619F CJK UNIFIED IDEOGRAPH-#619F, IRGKangXi=0403.080, RSKangXi=61.12
61A0 CJK UNIFIED IDEOGRAPH-#61A0, IRGKangXi=0403.110, RSKangXi=61.12
61A1 CJK UNIFIED IDEOGRAPH-#61A1, IRGKangXi=0403.130, RSKangXi=61.12
61A2 CJK UNIFIED IDEOGRAPH-#61A2, IRGKangXi=0403.160, RSKangXi=61.12
61A3 CJK UNIFIED IDEOGRAPH-#61A3, IRGKangXi=0403.170, RSKangXi=61.12
61A4 CJK UNIFIED IDEOGRAPH-#61A4, IRGKangXi=0403.190, RSKangXi=61.12, Def{resent, hate; indignant}
61A5 CJK UNIFIED IDEOGRAPH-#61A5, IRGKangXi=0403.200, RSKangXi=61.12
61A6 CJK UNIFIED IDEOGRAPH-#61A6, IRGKangXi=0403.210, RSKangXi=61.12, Def{regret}
61A7 CJK UNIFIED IDEOGRAPH-#61A7, IRGKangXi=0403.220, RSKangXi=61.12, Def{irresolute, indecisive; yearn for}
61A8 CJK UNIFIED IDEOGRAPH-#61A8, IRGKangXi=0403.240, RSKangXi=61.12, Def{foolish, silly, coquettish}
61A9 CJK UNIFIED IDEOGRAPH-#61A9, IRGKangXi=0403.260, RSKangXi=61.12, Def{rest, take rest}
61AA CJK UNIFIED IDEOGRAPH-#61AA, IRGKangXi=0403.310, RSKangXi=61.12, Def{composed, contented}
61AB CJK UNIFIED IDEOGRAPH-#61AB, IRGKangXi=0403.320, RSKangXi=61.12, Def{pity, sympathize with, grieve for}
61AC CJK UNIFIED IDEOGRAPH-#61AC, IRGKangXi=0403.360, RSKangXi=61.12, Def{rouse, awaken; become conscious}
61AD CJK UNIFIED IDEOGRAPH-#61AD, IRGKangXi=0403.380, RSKangXi=61.12, Def{clear; intelligible; severe; cold}
61AE CJK UNIFIED IDEOGRAPH-#61AE, IRGKangXi=0404.010, RSKangXi=61.12, Def{regretful, disappointed}
61AF CJK UNIFIED IDEOGRAPH-#61AF, IRGKangXi=0404.020, RSKangXi=61.12, Def{sorrowful, sad; already, nevertheless}
61B0 CJK UNIFIED IDEOGRAPH-#61B0, IRGKangXi=0404.040, RSKangXi=61.12, Def{wily, time-serving; to feign, to act the hypocrite}
61B1 CJK UNIFIED IDEOGRAPH-#61B1, IRGKangXi=0404.060, RSKangXi=61.12
61B2 CJK UNIFIED IDEOGRAPH-#61B2, IRGKangXi=0404.110, RSKangXi=61.12, Def{constitution, statute, law}
61B3 CJK UNIFIED IDEOGRAPH-#61B3, IRGKangXi=0404.150, RSKangXi=61.12
61B4 CJK UNIFIED IDEOGRAPH-#61B4, IRGKangXi=0404.310, RSKangXi=61.13
61B5 CJK UNIFIED IDEOGRAPH-#61B5, IRGKangXi=0404.320, RSKangXi=61.13, Def{(Cant.) to rush}
61B6 CJK UNIFIED IDEOGRAPH-#61B6, IRGKangXi=0404.330, RSKangXi=61.13, Def{remember, reflect upon; memory}
61B7 CJK UNIFIED IDEOGRAPH-#61B7, IRGKangXi=0404.350, RSKangXi=61.13, Def{painful; suffering; privation}
61B8 CJK UNIFIED IDEOGRAPH-#61B8, IRGKangXi=0404.370, RSKangXi=61.13, Def{to flatter; crafty, having a specious tongue}
61B9 CJK UNIFIED IDEOGRAPH-#61B9, IRGKangXi=0404.420, RSKangXi=61.13
61BA CJK UNIFIED IDEOGRAPH-#61BA, IRGKangXi=0404.430, RSKangXi=61.13, Def{peace}
61BB CJK UNIFIED IDEOGRAPH-#61BB, IRGKangXi=0404.440, RSKangXi=61.14
61BC CJK UNIFIED IDEOGRAPH-#61BC, IRGKangXi=0404.460, RSKangXi=61.13
61BD CJK UNIFIED IDEOGRAPH-#61BD, IRGKangXi=0405.010, RSKangXi=61.13
61BE CJK UNIFIED IDEOGRAPH-#61BE, IRGKangXi=0405.040, RSKangXi=61.13, Def{to regret, remorse; dissatisfied}
61BF CJK UNIFIED IDEOGRAPH-#61BF, IRGKangXi=0405.080, RSKangXi=61.13
61C0 CJK UNIFIED IDEOGRAPH-#61C0, IRGKangXi=0405.090, RSKangXi=61.13
61C1 CJK UNIFIED IDEOGRAPH-#61C1, IRGKangXi=0405.110, RSKangXi=61.13, Def{anxious, distressed}
61C2 CJK UNIFIED IDEOGRAPH-#61C2, IRGKangXi=0405.120, RSKangXi=61.13, Def{understand, comprehend}
61C3 CJK UNIFIED IDEOGRAPH-#61C3, IRGKangXi=0405.130, RSKangXi=61.13, Def{courteous, cordial; zealous}
61C4 CJK UNIFIED IDEOGRAPH-#61C4, IRGKangXi=0405.140, RSKangXi=61.13, Def{grief}
61C5 CJK UNIFIED IDEOGRAPH-#61C5, IRGKangXi=0405.160, RSKangXi=61.13, Def{bashful; ashamed}
61C6 CJK UNIFIED IDEOGRAPH-#61C6, IRGKangXi=0405.170, RSKangXi=61.13, Def{anxious, apprehensive}
61C7 CJK UNIFIED IDEOGRAPH-#61C7, IRGKangXi=0405.180, RSKangXi=61.13, Def{sincere, earnest, cordial}
61C8 CJK UNIFIED IDEOGRAPH-#61C8, IRGKangXi=0405.190, RSKangXi=61.13, Def{idle, relaxed, remiss}
61C9 CJK UNIFIED IDEOGRAPH-#61C9, IRGKangXi=0405.210, RSKangXi=61.13, Def{should, ought to, must}
61CA CJK UNIFIED IDEOGRAPH-#61CA, IRGKangXi=0405.230, RSKangXi=61.13, Def{vexed, worried, nervous; regret}
61CB CJK UNIFIED IDEOGRAPH-#61CB, IRGKangXi=0405.240, RSKangXi=61.13, Def{splendid, grand, majestic}
61CC CJK UNIFIED IDEOGRAPH-#61CC, IRGKangXi=0406.010, RSKangXi=61.13, Def{enjoy, be glad, be pleased}
61CD CJK UNIFIED IDEOGRAPH-#61CD, IRGKangXi=0406.020, RSKangXi=61.13, Def{be afraid of, be awed by, be in awe}
61CE CJK UNIFIED IDEOGRAPH-#61CE, IRGKangXi=0406.040, RSKangXi=61.13
61CF CJK UNIFIED IDEOGRAPH-#61CF, IRGKangXi=0406.050, RSKangXi=61.13
61D0 CJK UNIFIED IDEOGRAPH-#61D0, IRGKangXi=0406.141, RSKangXi=61.13, Def{bosom, breast; carry in bosom}
61D1 CJK UNIFIED IDEOGRAPH-#61D1, IRGKangXi=0406.141, RSKangXi=61.13, Def{be sick at heart, sorrowful, sad}
61D2 CJK UNIFIED IDEOGRAPH-#61D2, IRGKangXi=0406.141, RSKangXi=61.13, Def{lazy, languid, listless}
61D3 CJK UNIFIED IDEOGRAPH-#61D3, IRGKangXi=0406.141
61D4 CJK UNIFIED IDEOGRAPH-#61D4, IRGKangXi=0406.141, RSKangXi=61.13, Def{be afraid of, to be in awe of}
61D5 CJK UNIFIED IDEOGRAPH-#61D5, IRGKangXi=0406.180, RSKangXi=61.14, Def{satiated; contented}
61D6 CJK UNIFIED IDEOGRAPH-#61D6, IRGKangXi=0406.190, RSKangXi=61.14
61D7 CJK UNIFIED IDEOGRAPH-#61D7, IRGKangXi=0406.230, RSKangXi=61.14
61D8 CJK UNIFIED IDEOGRAPH-#61D8, IRGKangXi=0406.240, RSKangXi=61.14
61D9 CJK UNIFIED IDEOGRAPH-#61D9, IRGKangXi=0406.270, RSKangXi=61.14
61DA CJK UNIFIED IDEOGRAPH-#61DA, IRGKangXi=0406.300, RSKangXi=61.14
61DB CJK UNIFIED IDEOGRAPH-#61DB, IRGKangXi=0406.320, RSKangXi=61.14, Def{alarmed, scared; stupid}
61DC CJK UNIFIED IDEOGRAPH-#61DC, IRGKangXi=0406.330, RSKangXi=61.14, Def{dull, stupid, doltish}
61DD CJK UNIFIED IDEOGRAPH-#61DD, IRGKangXi=0406.350, RSKangXi=61.14
61DE CJK UNIFIED IDEOGRAPH-#61DE, IRGKangXi=0406.360, RSKangXi=61.14, Def{variant of U+8499 蒙}
61DF CJK UNIFIED IDEOGRAPH-#61DF, IRGKangXi=0406.370, RSKangXi=61.14, Def{hate, abhor; hatred, resentment}
61E0 CJK UNIFIED IDEOGRAPH-#61E0, IRGKangXi=0406.380, RSKangXi=61.14, Def{angry}
61E1 CJK UNIFIED IDEOGRAPH-#61E1, IRGKangXi=0407.161, RSKangXi=61.14
61E2 CJK UNIFIED IDEOGRAPH-#61E2, IRGKangXi=0406.430, RSKangXi=61.14
61E3 CJK UNIFIED IDEOGRAPH-#61E3, IRGKangXi=0406.450, RSKangXi=61.14, Def{be sick at heart, sorrowful, sad}
61E4 CJK UNIFIED IDEOGRAPH-#61E4, IRGKangXi=0407.020, RSKangXi=61.14, Def{grieved, pained}
61E5 CJK UNIFIED IDEOGRAPH-#61E5, IRGKangXi=0407.040, RSKangXi=61.14, Def{angry, enraged, resentful; hate}
61E6 CJK UNIFIED IDEOGRAPH-#61E6, IRGKangXi=0407.060, RSKangXi=61.14, Def{weak, timid, cowardly}
61E7 CJK UNIFIED IDEOGRAPH-#61E7, IRGKangXi=0407.120, RSKangXi=61.14
61E8 CJK UNIFIED IDEOGRAPH-#61E8, IRGKangXi=0407.161, RSKangXi=61.14, Def{feeble, sickly; tranquil, calm}
61E9 CJK UNIFIED IDEOGRAPH-#61E9, IRGKangXi=0407.170, RSKangXi=61.15
61EA CJK UNIFIED IDEOGRAPH-#61EA, IRGKangXi=0407.180, RSKangXi=61.15
61EB CJK UNIFIED IDEOGRAPH-#61EB, IRGKangXi=0407.230, RSKangXi=61.15, Def{enraged; resentful.to hate. to desist}
61EC CJK UNIFIED IDEOGRAPH-#61EC, IRGKangXi=0407.270, RSKangXi=61.15
61ED CJK UNIFIED IDEOGRAPH-#61ED, IRGKangXi=0407.280, RSKangXi=61.15
61EE CJK UNIFIED IDEOGRAPH-#61EE, IRGKangXi=0407.320, RSKangXi=61.15, Def{calm, liesurely; procrastinating}
61EF CJK UNIFIED IDEOGRAPH-#61EF, IRGKangXi=0407.360, RSKangXi=61.15
61F0 CJK UNIFIED IDEOGRAPH-#61F0, IRGKangXi=0407.400, RSKangXi=61.15, Def{be glad, pleased, delighted}
61F1 CJK UNIFIED IDEOGRAPH-#61F1, IRGKangXi=0407.410, RSKangXi=61.15
61F2 CJK UNIFIED IDEOGRAPH-#61F2, IRGKangXi=0407.440, RSKangXi=61.15, Def{punish, reprimand; warn}
61F3 CJK UNIFIED IDEOGRAPH-#61F3, IRGKangXi=0407.551, RSKangXi=61.15
61F4 CJK UNIFIED IDEOGRAPH-#61F4, IRGKangXi=0407.551, RSKangXi=61.15, Def{regret, repent; confess sins}
61F5 CJK UNIFIED IDEOGRAPH-#61F5, IRGKangXi=0408.120, RSKangXi=61.16, Def{stupid, ignorant, dull}
61F6 CJK UNIFIED IDEOGRAPH-#61F6, IRGKangXi=0408.160, RSKangXi=61.16, Def{lazy, languid, listless}
61F7 CJK UNIFIED IDEOGRAPH-#61F7, IRGKangXi=0408.170, RSKangXi=61.16, Def{bosom, breast; carry in bosom}
61F8 CJK UNIFIED IDEOGRAPH-#61F8, IRGKangXi=0408.240, RSKangXi=61.16, Def{hang, suspend, hoist; be hung}
61F9 CJK UNIFIED IDEOGRAPH-#61F9, IRGKangXi=0408.320, RSKangXi=61.17
61FA CJK UNIFIED IDEOGRAPH-#61FA, IRGKangXi=0408.340, RSKangXi=61.17, Def{regret, repent; confess sins}
61FB CJK UNIFIED IDEOGRAPH-#61FB, IRGKangXi=0408.380, RSKangXi=61.17, Def{overbearing, crafty}
61FC CJK UNIFIED IDEOGRAPH-#61FC, IRGKangXi=0408.430, RSKangXi=61.18, Def{fear, be afraid of, dread}
61FD CJK UNIFIED IDEOGRAPH-#61FD, IRGKangXi=0409.010, RSKangXi=61.18, Def{happy, pleased, glad, joyous}
61FE CJK UNIFIED IDEOGRAPH-#61FE, IRGKangXi=0409.020, RSKangXi=61.18, Def{afraid, scared, fearful}
61FF CJK UNIFIED IDEOGRAPH-#61FF, IRGKangXi=0409.050, RSKangXi=61.18, Def{virtuous, admirable, esteemed}
6200 CJK UNIFIED IDEOGRAPH-#6200, IRGKangXi=0409.090, RSKangXi=61.19, Def{love; long for, yearn for; love}
6201 CJK UNIFIED IDEOGRAPH-#6201, IRGKangXi=0409.110, RSKangXi=61.19, Def{fear}
6202 CJK UNIFIED IDEOGRAPH-#6202, IRGKangXi=0409.140, RSKangXi=61.19
6203 CJK UNIFIED IDEOGRAPH-#6203, IRGKangXi=0409.200, RSKangXi=61.20
6204 CJK UNIFIED IDEOGRAPH-#6204, IRGKangXi=0409.210, RSKangXi=61.20, Def{to be in awe of; to fear}
6205 CJK UNIFIED IDEOGRAPH-#6205, IRGKangXi=0409.270, RSKangXi=61.21
6206 CJK UNIFIED IDEOGRAPH-#6206, IRGKangXi=0409.291, RSKangXi=61.21, Def{stupid, simple, simple-minded}
6207 CJK UNIFIED IDEOGRAPH-#6207, IRGKangXi=0409.310, RSKangXi=61.24, Def{stupid, simple, simple-minded}
6208 CJK UNIFIED IDEOGRAPH-#6208, IRGKangXi=0411.010, RSKangXi=62.0, Def{halberd, spear, lance; rad. 62}
6209 CJK UNIFIED IDEOGRAPH-#6209, IRGKangXi=0411.020, RSKangXi=62.1, Def{a battle-axe, a halberd}
620A CJK UNIFIED IDEOGRAPH-#620A, IRGKangXi=0411.030, RSKangXi=62.1, Def{5th heavenly stem}
620B CJK UNIFIED IDEOGRAPH-#620B, IRGKangXi=0411.031, RSKangXi=62.1, Def{small, narrow, tiny, little}
620C CJK UNIFIED IDEOGRAPH-#620C, IRGKangXi=0411.040, RSKangXi=62.2, Def{11th terrestrial branch}
620D CJK UNIFIED IDEOGRAPH-#620D, IRGKangXi=0411.060, RSKangXi=62.2, Def{defend borders, guard frontiers}
620E CJK UNIFIED IDEOGRAPH-#620E, IRGKangXi=0411.080, RSKangXi=62.2, Def{arms, armaments; military affair}
620F CJK UNIFIED IDEOGRAPH-#620F, IRGKangXi=0411.091, RSKangXi=62.2, Def{theatrical play, show}
6210 CJK UNIFIED IDEOGRAPH-#6210, IRGKangXi=0411.110, RSKangXi=62.3, Def{completed, finished, fixed}
6211 CJK UNIFIED IDEOGRAPH-#6211, IRGKangXi=0412.010, RSKangXi=62.3, Def{our, us, i, me, my, we}
6212 CJK UNIFIED IDEOGRAPH-#6212, IRGKangXi=0412.050, RSKangXi=62.3, Def{warn, caution, admonish}
6213 CJK UNIFIED IDEOGRAPH-#6213, IRGKangXi=0412.070, RSKangXi=62.3
6214 CJK UNIFIED IDEOGRAPH-#6214, IRGKangXi=0412.140, RSKangXi=62.4, Def{small, narrow, tiny, little}
6215 CJK UNIFIED IDEOGRAPH-#6215, IRGKangXi=0412.170, RSKangXi=62.4, Def{kill, slay; wound, injure, hurt}
6216 CJK UNIFIED IDEOGRAPH-#6216, IRGKangXi=0412.180, RSKangXi=62.4, Def{or, either, else; perhaps, maybe}
6217 CJK UNIFIED IDEOGRAPH-#6217, IRGKangXi=0412.221, RSKangXi=62.4, Def{support}
6218 CJK UNIFIED IDEOGRAPH-#6218, IRGKangXi=0412.291, RSKangXi=62.5, Def{war, fighting, battle}
6219 CJK UNIFIED IDEOGRAPH-#6219, IRGKangXi=0412.320, RSKangXi=62.6, Def{(Cant.) to trap; upright; a pile}
621A CJK UNIFIED IDEOGRAPH-#621A, IRGKangXi=0412.380, RSKangXi=62.7, Def{relative; be related to; sad}
621B CJK UNIFIED IDEOGRAPH-#621B, IRGKangXi=0413.040, RSKangXi=62.7, Def{lance; tap or strike lightly}
621C CJK UNIFIED IDEOGRAPH-#621C, IRGKangXi=0413.050, RSKangXi=62.7, Def{to scrape; advantageous}
621D CJK UNIFIED IDEOGRAPH-#621D, IRGKangXi=0413.061, RSKangXi=62.4, Def{pirate, thief}
621E CJK UNIFIED IDEOGRAPH-#621E, IRGKangXi=0413.080, RSKangXi=62.8, Def{lance; tap or strike lightly}
621F CJK UNIFIED IDEOGRAPH-#621F, IRGKangXi=0413.090, RSKangXi=62.8, Def{halberd with crescent blade}
6220 CJK UNIFIED IDEOGRAPH-#6220, IRGKangXi=0413.160, RSKangXi=62.9, Def{a sword; potter's clay; to gather}
6221 CJK UNIFIED IDEOGRAPH-#6221, IRGKangXi=0413.170, RSKangXi=62.9, Def{subjugate, subdue, quell; kill}
6222 CJK UNIFIED IDEOGRAPH-#6222, IRGKangXi=0413.180, RSKangXi=62.9, Def{to put away; to cease; store up}
6223 CJK UNIFIED IDEOGRAPH-#6223, IRGKangXi=0413.230, RSKangXi=62.9, Def{lance}
6224 CJK UNIFIED IDEOGRAPH-#6224, IRGKangXi=0413.241, RSKangXi=62.9, Def{to infringe a trade-mark to pledge an article}
6225 CJK UNIFIED IDEOGRAPH-#6225, IRGKangXi=0413.241, RSKangXi=62.9, Def{a small steelyard for weighing money, etc.}
6226 CJK UNIFIED IDEOGRAPH-#6226, IRGKangXi=0413.241, RSKangXi=62.8, Def{war, fighting, battle}
6227 CJK UNIFIED IDEOGRAPH-#6227, IRGKangXi=0413.250, RSKangXi=62.10, Def{support}
6228 CJK UNIFIED IDEOGRAPH-#6228, IRGKangXi=0413.290, RSKangXi=62.10
6229 CJK UNIFIED IDEOGRAPH-#6229, IRGKangXi=0413.300, RSKangXi=62.10, Def{exterminate, destroy; blessing}
622A CJK UNIFIED IDEOGRAPH-#622A, IRGKangXi=0413.320, RSKangXi=62.10, Def{cut off, stop, obstruct, intersect}
622B CJK UNIFIED IDEOGRAPH-#622B, IRGKangXi=0413.330, RSKangXi=62.10
622C CJK UNIFIED IDEOGRAPH-#622C, IRGKangXi=0413.371, RSKangXi=62.10, Def{exterminate, destroy; blessing}
622D CJK UNIFIED IDEOGRAPH-#622D, IRGKangXi=0413.410, RSKangXi=62.11, Def{spear}
622E CJK UNIFIED IDEOGRAPH-#622E, IRGKangXi=0414.040, RSKangXi=62.11, Def{kill, massacre; oppress}
622F CJK UNIFIED IDEOGRAPH-#622F, IRGKangXi=0414.091, RSKangXi=62.11, Def{theatrical play, show}
6230 CJK UNIFIED IDEOGRAPH-#6230, IRGKangXi=0414.110, RSKangXi=62.12, Def{war, fighting, battle}
6231 CJK UNIFIED IDEOGRAPH-#6231, IRGKangXi=0414.130, RSKangXi=62.11, Def{theatrical play}
6232 CJK UNIFIED IDEOGRAPH-#6232, IRGKangXi=0414.230, RSKangXi=62.13, Def{theatrical play, show}
6233 CJK UNIFIED IDEOGRAPH-#6233, IRGKangXi=0414.240, RSKangXi=62.14, Def{prick, stab; stamp, seal, chop}
6234 CJK UNIFIED IDEOGRAPH-#6234, IRGKangXi=0414.250, RSKangXi=62.14, Def{wear on top; support}
6235 CJK UNIFIED IDEOGRAPH-#6235, IRGKangXi=0414.310, RSKangXi=62.18, Def{a halberd}
6236 CJK UNIFIED IDEOGRAPH-#6236, IRGKangXi=0414.320, RSKangXi=63.0, Def{door; family, household}
6237 CJK UNIFIED IDEOGRAPH-#6237, IRGKangXi=0414.321, RSKangXi=63.0, Def{door; family}
6238 CJK UNIFIED IDEOGRAPH-#6238, IRGKangXi=0414.321, RSKangXi=63.0, Def{door; family}
6239 CJK UNIFIED IDEOGRAPH-#6239, IRGKangXi=0415.010, RSKangXi=63.1, Def{In difficulty, distressed}
623A CJK UNIFIED IDEOGRAPH-#623A, IRGKangXi=0415.030, RSKangXi=63.3, Def{stone boarder; steps}
623B CJK UNIFIED IDEOGRAPH-#623B, IRGKangXi=0415.070, RSKangXi=63.3, Def{perverse}
623C CJK UNIFIED IDEOGRAPH-#623C, IRGKangXi=0415.080, RSKangXi=63.3, Def{4th of Earth Branches; period from 5-7 a.m.}
623D CJK UNIFIED IDEOGRAPH-#623D, IRGKangXi=0415.100, RSKangXi=63.4, Def{to bale out water}
623E CJK UNIFIED IDEOGRAPH-#623E, IRGKangXi=0415.110, RSKangXi=63.4, Def{perverse, recalcitrant, rebellious}
623F CJK UNIFIED IDEOGRAPH-#623F, IRGKangXi=0415.150, RSKangXi=63.4, Def{house, building; room}
6240 CJK UNIFIED IDEOGRAPH-#6240, IRGKangXi=0415.160, RSKangXi=63.4, Def{place, location; numerary adjunct}
6241 CJK UNIFIED IDEOGRAPH-#6241, IRGKangXi=0415.220, RSKangXi=63.5, Def{flat; tablet, signboard}
6242 CJK UNIFIED IDEOGRAPH-#6242, IRGKangXi=0416.020, RSKangXi=63.5
6243 CJK UNIFIED IDEOGRAPH-#6243, IRGKangXi=0416.040, RSKangXi=63.5, Def{a door bar placed outside a door}
6244 CJK UNIFIED IDEOGRAPH-#6244, IRGKangXi=0416.080, RSKangXi=63.6, Def{large ring on a front door used as a knocker}
6245 CJK UNIFIED IDEOGRAPH-#6245, IRGKangXi=0416.120, RSKangXi=63.6, Def{gate bar, bolt}
6246 CJK UNIFIED IDEOGRAPH-#6246, IRGKangXi=0416.130, RSKangXi=63.6, Def{screen}
6247 CJK UNIFIED IDEOGRAPH-#6247, IRGKangXi=0416.140, RSKangXi=63.6, Def{fan; door panel}
6248 CJK UNIFIED IDEOGRAPH-#6248, IRGKangXi=0416.160, RSKangXi=63.7, Def{escort, retinue; insolent}
6249 CJK UNIFIED IDEOGRAPH-#6249, IRGKangXi=0416.190, RSKangXi=63.8, Def{door panel}
624A CJK UNIFIED IDEOGRAPH-#624A, IRGKangXi=0416.200, RSKangXi=63.8, Def{upright bar for fastening door}
624B CJK UNIFIED IDEOGRAPH-#624B, IRGKangXi=0416.280, RSKangXi=64.0, Def{hand}
624C CJK UNIFIED IDEOGRAPH-#624C, IRGKangXi=0416.291, RSKangXi=64.0, Def{hand; radical number 64}
624D CJK UNIFIED IDEOGRAPH-#624D, IRGKangXi=0416.300, RSKangXi=64.0, Def{talent, ability; just, only}
624E CJK UNIFIED IDEOGRAPH-#624E, IRGKangXi=0417.010, RSKangXi=64.1, Def{pull up; pierce; struggle free}
624F CJK UNIFIED IDEOGRAPH-#624F, IRGKangXi=0417.060, RSKangXi=64.3
6250 CJK UNIFIED IDEOGRAPH-#6250, IRGKangXi=0417.090, RSKangXi=64.2, Def{divine}
6251 CJK UNIFIED IDEOGRAPH-#6251, IRGKangXi=0417.100, RSKangXi=64.2, Def{pound, beat, strike; attack}
6252 CJK UNIFIED IDEOGRAPH-#6252, IRGKangXi=0417.110, RSKangXi=64.2, Def{scratch; dig up; crawl; crouch}
6253 CJK UNIFIED IDEOGRAPH-#6253, IRGKangXi=0417.120, RSKangXi=64.2, Def{strike, hit, beat; fight; attack}
6254 CJK UNIFIED IDEOGRAPH-#6254, IRGKangXi=0417.130, RSKangXi=64.2, Def{throw, hurl; throw away, cast}
6255 CJK UNIFIED IDEOGRAPH-#6255, IRGKangXi=0417.131, RSKangXi=64.2, Def{shake off, brush away; dust}
6256 CJK UNIFIED IDEOGRAPH-#6256, IRGKangXi=0417.131, RSKangXi=64.2
6257 CJK UNIFIED IDEOGRAPH-#6257, IRGKangXi=0417.170, RSKangXi=64.3
6258 CJK UNIFIED IDEOGRAPH-#6258, IRGKangXi=0417.180, RSKangXi=64.3, Def{to hold up with palm; to support, rely on}
6259 CJK UNIFIED IDEOGRAPH-#6259, IRGKangXi=0417.200, RSKangXi=64.3
625A CJK UNIFIED IDEOGRAPH-#625A, IRGKangXi=0417.220, RSKangXi=64.3
625B CJK UNIFIED IDEOGRAPH-#625B, IRGKangXi=0417.230, RSKangXi=64.3, Def{carry on shoulders; lift}
625C CJK UNIFIED IDEOGRAPH-#625C, IRGKangXi=0417.240, RSKangXi=64.3
625D CJK UNIFIED IDEOGRAPH-#625D, IRGKangXi=0418.010, RSKangXi=64.3
625E CJK UNIFIED IDEOGRAPH-#625E, IRGKangXi=0418.020, RSKangXi=64.3, Def{ward off, withstand, resist}
625F CJK UNIFIED IDEOGRAPH-#625F, IRGKangXi=0418.030, RSKangXi=64.4
6260 CJK UNIFIED IDEOGRAPH-#6260, IRGKangXi=0418.040, RSKangXi=64.3, Def{pick up with fork or pincers}
6261 CJK UNIFIED IDEOGRAPH-#6261, IRGKangXi=0418.050, RSKangXi=64.3, Def{drag along}
6262 CJK UNIFIED IDEOGRAPH-#6262, IRGKangXi=0418.060, RSKangXi=64.3, Def{caper}
6263 CJK UNIFIED IDEOGRAPH-#6263, IRGKangXi=0418.070, RSKangXi=64.3, Def{knock, strike, rap, tap; button}
6264 CJK UNIFIED IDEOGRAPH-#6264, IRGKangXi=0418.080, RSKangXi=64.3, Def{to thrust; to move}
6265 CJK UNIFIED IDEOGRAPH-#6265, IRGKangXi=0418.120, RSKangXi=64.3
6266 CJK UNIFIED IDEOGRAPH-#6266, IRGKangXi=0418.140, RSKangXi=64.3, Def{probe, poke, prick, pierce}
6267 CJK UNIFIED IDEOGRAPH-#6267, IRGKangXi=0418.141, RSKangXi=64.3, Def{hold in hand; keep; carry out}
6268 CJK UNIFIED IDEOGRAPH-#6268, IRGKangXi=0418.141, RSKangXi=64.3, Def{pick up with fork or pincers}
6269 CJK UNIFIED IDEOGRAPH-#6269, IRGKangXi=0418.141, RSKangXi=64.3, Def{expand, enlarge, stretch}
626A CJK UNIFIED IDEOGRAPH-#626A, IRGKangXi=0418.141, RSKangXi=64.3, Def{stoke, pat, feel by hand, grope}
626B CJK UNIFIED IDEOGRAPH-#626B, IRGKangXi=0418.141, RSKangXi=64.3, Def{sweep, clear away; exterminate}
626C CJK UNIFIED IDEOGRAPH-#626C, IRGKangXi=0418.141, RSKangXi=64.3, Def{scatter, spread; praise}
626D CJK UNIFIED IDEOGRAPH-#626D, IRGKangXi=0418.160, RSKangXi=64.4, Def{turn, twist, wrench; seize, grasp}
626E CJK UNIFIED IDEOGRAPH-#626E, IRGKangXi=0418.200, RSKangXi=64.4, Def{dress up; dress up as}
626F CJK UNIFIED IDEOGRAPH-#626F, IRGKangXi=0418.230, RSKangXi=64.4, Def{rip up, tear down; raise; haul}
6270 CJK UNIFIED IDEOGRAPH-#6270, IRGKangXi=0418.240, RSKangXi=64.4, Def{disturb, annoy, agitate}
6271 CJK UNIFIED IDEOGRAPH-#6271, IRGKangXi=0418.250, RSKangXi=64.4, Def{collect, draw in, gather; receive}
6272 CJK UNIFIED IDEOGRAPH-#6272, IRGKangXi=0419.010, RSKangXi=64.4, Def{(Cant.) to pull out}
6273 CJK UNIFIED IDEOGRAPH-#6273, IRGKangXi=0419.020, RSKangXi=64.4, Def{pull; drag; right itself}
6274 CJK UNIFIED IDEOGRAPH-#6274, IRGKangXi=0419.030, RSKangXi=64.4
6275 CJK UNIFIED IDEOGRAPH-#6275, IRGKangXi=0419.040, RSKangXi=64.4, Def{in, on, at, by, from; than; with reference to; compared with}
6276 CJK UNIFIED IDEOGRAPH-#6276, IRGKangXi=0419.050, RSKangXi=64.4, Def{support, help; protect; hold on}
6277 CJK UNIFIED IDEOGRAPH-#6277, IRGKangXi=0419.090, RSKangXi=64.4
6278 CJK UNIFIED IDEOGRAPH-#6278, IRGKangXi=0419.100, RSKangXi=64.5
6279 CJK UNIFIED IDEOGRAPH-#6279, IRGKangXi=0419.120, RSKangXi=64.4, Def{comment, criticize; wholesale}
627A CJK UNIFIED IDEOGRAPH-#627A, IRGKangXi=0419.130, RSKangXi=64.4, Def{to strike one's palm with one's fist}
627B CJK UNIFIED IDEOGRAPH-#627B, IRGKangXi=0419.140, RSKangXi=64.4, Def{to strike; to run against to throw, as a stone}
627C CJK UNIFIED IDEOGRAPH-#627C, IRGKangXi=0419.150, RSKangXi=64.4, Def{grasp, clutch; choke, strangle}
627D CJK UNIFIED IDEOGRAPH-#627D, IRGKangXi=0419.170, RSKangXi=64.4, Def{to move, to shake}
627E CJK UNIFIED IDEOGRAPH-#627E, IRGKangXi=0419.180, RSKangXi=64.4, Def{search, seek, look for; find}
627F CJK UNIFIED IDEOGRAPH-#627F, IRGKangXi=0419.190, RSKangXi=64.4, Def{inherit, receive; succeed}
6280 CJK UNIFIED IDEOGRAPH-#6280, IRGKangXi=0420.020, RSKangXi=64.4, Def{skill, ability, talent, ingenuity}
6281 CJK UNIFIED IDEOGRAPH-#6281, IRGKangXi=0420.050, RSKangXi=64.4
6282 CJK UNIFIED IDEOGRAPH-#6282, IRGKangXi=0420.060, RSKangXi=64.4
6283 CJK UNIFIED IDEOGRAPH-#6283, IRGKangXi=0420.070, RSKangXi=64.4, Def{to clap hands; to cheer}
6284 CJK UNIFIED IDEOGRAPH-#6284, IRGKangXi=0420.100, RSKangXi=64.4, Def{copy, confiscate, seize}
6285 CJK UNIFIED IDEOGRAPH-#6285, IRGKangXi=0420.120, RSKangXi=64.4, Def{to collect; to join together}
6286 CJK UNIFIED IDEOGRAPH-#6286, IRGKangXi=0420.150, RSKangXi=64.4, Def{wipe, rub off}
6287 CJK UNIFIED IDEOGRAPH-#6287, IRGKangXi=0420.160, RSKangXi=64.4
6288 CJK UNIFIED IDEOGRAPH-#6288, IRGKangXi=0420.180, RSKangXi=64.4, Def{to bend}
6289 CJK UNIFIED IDEOGRAPH-#6289, IRGKangXi=0420.200, RSKangXi=64.4, Def{choose, select; gouge, pluck out}
628A CJK UNIFIED IDEOGRAPH-#628A, IRGKangXi=0420.210, RSKangXi=64.4, Def{hold, take; guard; regard as}
628B CJK UNIFIED IDEOGRAPH-#628B, IRGKangXi=0421.010, RSKangXi=64.4
628C CJK UNIFIED IDEOGRAPH-#628C, IRGKangXi=0421.020, RSKangXi=64.4, Def{to bale out water, to dip}
628D CJK UNIFIED IDEOGRAPH-#628D, IRGKangXi=0421.040, RSKangXi=64.4, Def{to lift up; to rescue, save}
628E CJK UNIFIED IDEOGRAPH-#628E, IRGKangXi=0421.060, RSKangXi=64.4
628F CJK UNIFIED IDEOGRAPH-#628F, IRGKangXi=0421.070, RSKangXi=64.4
6290 CJK UNIFIED IDEOGRAPH-#6290, IRGKangXi=0421.080, RSKangXi=64.4
6291 CJK UNIFIED IDEOGRAPH-#6291, IRGKangXi=0421.090, RSKangXi=64.4, Def{press down, repress; curb, hinder}
6292 CJK UNIFIED IDEOGRAPH-#6292, IRGKangXi=0421.100, RSKangXi=64.4, Def{express; eliminate; relieve}
6293 CJK UNIFIED IDEOGRAPH-#6293, IRGKangXi=0421.110, RSKangXi=64.4, Def{scratch; clutch, seize, grab}
6294 CJK UNIFIED IDEOGRAPH-#6294, IRGKangXi=0421.120, RSKangXi=64.4, Def{take or hold up in both hands}
6295 CJK UNIFIED IDEOGRAPH-#6295, IRGKangXi=0421.130, RSKangXi=64.4, Def{throw, cast, fling, pitch; jump}
6296 CJK UNIFIED IDEOGRAPH-#6296, IRGKangXi=0422.010, RSKangXi=64.4, Def{tremble, shake, rouse; give shake}
6297 CJK UNIFIED IDEOGRAPH-#6297, IRGKangXi=0422.020, RSKangXi=64.4, Def{resist, oppose, defy, reject}
6298 CJK UNIFIED IDEOGRAPH-#6298, IRGKangXi=0422.040, RSKangXi=64.4, Def{break off, snap; bend}
6299 CJK UNIFIED IDEOGRAPH-#6299, IRGKangXi=0422.070, RSKangXi=64.4
629A CJK UNIFIED IDEOGRAPH-#629A, IRGKangXi=0422.120, RSKangXi=64.4, Def{pat, console, comfort; pacify}
629B CJK UNIFIED IDEOGRAPH-#629B, IRGKangXi=0422.121, RSKangXi=64.4, Def{throw (away)}
629C CJK UNIFIED IDEOGRAPH-#629C, IRGKangXi=0422.121, RSKangXi=64.4, Def{uproot, pull out}
629D CJK UNIFIED IDEOGRAPH-#629D, IRGKangXi=0422.121, RSKangXi=64.4
629E CJK UNIFIED IDEOGRAPH-#629E, IRGKangXi=0422.121, RSKangXi=64.4, Def{select, choose, pick out}
629F CJK UNIFIED IDEOGRAPH-#629F, IRGKangXi=0422.121, RSKangXi=64.4, Def{roll around with hand; model}
62A0 CJK UNIFIED IDEOGRAPH-#62A0, IRGKangXi=0422.121, RSKangXi=64.4, Def{raise, lift up; tight-fisted}
62A1 CJK UNIFIED IDEOGRAPH-#62A1, IRGKangXi=0422.121, RSKangXi=64.4, Def{swing, brandish, flourish}
62A2 CJK UNIFIED IDEOGRAPH-#62A2, IRGKangXi=0422.121, RSKangXi=64.4, Def{plunder, rob, take by force}
62A3 CJK UNIFIED IDEOGRAPH-#62A3, IRGKangXi=0422.121, RSKangXi=64.4
62A4 CJK UNIFIED IDEOGRAPH-#62A4, IRGKangXi=0422.121, RSKangXi=64.4, Def{protect, guard, defend, shelter}
62A5 CJK UNIFIED IDEOGRAPH-#62A5, IRGKangXi=0422.121, RSKangXi=64.4, Def{report, tell, announce}
62A6 CJK UNIFIED IDEOGRAPH-#62A6, IRGKangXi=0422.130, RSKangXi=64.5, Def{(Cant.) to beat}
62A7 CJK UNIFIED IDEOGRAPH-#62A7, IRGKangXi=0422.140, RSKangXi=64.5
62A8 CJK UNIFIED IDEOGRAPH-#62A8, IRGKangXi=0422.150, RSKangXi=64.5, Def{impeach, censure; attack}
62A9 CJK UNIFIED IDEOGRAPH-#62A9, IRGKangXi=0422.160, RSKangXi=64.5
62AA CJK UNIFIED IDEOGRAPH-#62AA, IRGKangXi=0422.190, RSKangXi=64.5, Def{to scatter, spread}
62AB CJK UNIFIED IDEOGRAPH-#62AB, IRGKangXi=0422.200, RSKangXi=64.5, Def{wear; split; crack}
62AC CJK UNIFIED IDEOGRAPH-#62AC, IRGKangXi=0423.010, RSKangXi=64.5, Def{lift, carry}
62AD CJK UNIFIED IDEOGRAPH-#62AD, IRGKangXi=0423.020, RSKangXi=64.5
62AE CJK UNIFIED IDEOGRAPH-#62AE, IRGKangXi=0423.040, RSKangXi=64.5, Def{to revolve, rotate}
62AF CJK UNIFIED IDEOGRAPH-#62AF, IRGKangXi=0423.050, RSKangXi=64.5, Def{(Cant.) to grasp, hold}
62B0 CJK UNIFIED IDEOGRAPH-#62B0, IRGKangXi=0423.060, RSKangXi=64.5
62B1 CJK UNIFIED IDEOGRAPH-#62B1, IRGKangXi=0423.080, RSKangXi=64.5, Def{embrace, hold in arms, enfold}
62B2 CJK UNIFIED IDEOGRAPH-#62B2, IRGKangXi=0423.090, RSKangXi=64.5
62B3 CJK UNIFIED IDEOGRAPH-#62B3, IRGKangXi=0423.100, RSKangXi=64.5, Def{(Cant.) to crush, mash, grind}
62B4 CJK UNIFIED IDEOGRAPH-#62B4, IRGKangXi=0423.110, RSKangXi=64.5
62B5 CJK UNIFIED IDEOGRAPH-#62B5, IRGKangXi=0423.120, RSKangXi=64.5, Def{resist, oppose; deny; off-set}
62B6 CJK UNIFIED IDEOGRAPH-#62B6, IRGKangXi=0423.140, RSKangXi=64.5, Def{beat}
62B7 CJK UNIFIED IDEOGRAPH-#62B7, IRGKangXi=0424.010, RSKangXi=64.5
62B8 CJK UNIFIED IDEOGRAPH-#62B8, IRGKangXi=0424.020, RSKangXi=64.5
62B9 CJK UNIFIED IDEOGRAPH-#62B9, IRGKangXi=0424.040, RSKangXi=64.5, Def{smear, apply, wipe off, erase}
62BA CJK UNIFIED IDEOGRAPH-#62BA, IRGKangXi=0424.050, RSKangXi=64.5
62BB CJK UNIFIED IDEOGRAPH-#62BB, IRGKangXi=0424.060, RSKangXi=64.5, Def{pull}
62BC CJK UNIFIED IDEOGRAPH-#62BC, IRGKangXi=0424.070, RSKangXi=64.5, Def{mortgage, pledge; deposit; to pawn; to arrest, detain, guard}
62BD CJK UNIFIED IDEOGRAPH-#62BD, IRGKangXi=0424.080, RSKangXi=64.5, Def{draw out, pull out; sprout}
62BE CJK UNIFIED IDEOGRAPH-#62BE, IRGKangXi=0424.090, RSKangXi=64.5
62BF CJK UNIFIED IDEOGRAPH-#62BF, IRGKangXi=0424.100, RSKangXi=64.5, Def{pucker up lips in smile; press}
62C0 CJK UNIFIED IDEOGRAPH-#62C0, IRGKangXi=0424.120, RSKangXi=64.5
62C1 CJK UNIFIED IDEOGRAPH-#62C1, IRGKangXi=0424.130, RSKangXi=64.5
62C2 CJK UNIFIED IDEOGRAPH-#62C2, IRGKangXi=0424.140, RSKangXi=64.5, Def{shake off, brush away; dust}
62C3 CJK UNIFIED IDEOGRAPH-#62C3, IRGKangXi=0424.160, RSKangXi=64.5, Def{grope, press, span}
62C4 CJK UNIFIED IDEOGRAPH-#62C4, IRGKangXi=0424.180, RSKangXi=64.5, Def{lean on; post; prod; ridicule}
62C5 CJK UNIFIED IDEOGRAPH-#62C5, IRGKangXi=0424.190, RSKangXi=64.5, Def{carry, bear, undertake}
62C6 CJK UNIFIED IDEOGRAPH-#62C6, IRGKangXi=0424.210, RSKangXi=64.5, Def{to break up, split apart, rip open; to destroy}
62C7 CJK UNIFIED IDEOGRAPH-#62C7, IRGKangXi=0424.220, RSKangXi=64.5, Def{thumb; big toe}
62C8 CJK UNIFIED IDEOGRAPH-#62C8, IRGKangXi=0424.230, RSKangXi=64.5, Def{pick up with fingers; draw lots}
62C9 CJK UNIFIED IDEOGRAPH-#62C9, IRGKangXi=0425.010, RSKangXi=64.5, Def{pull, drag; seize, hold; lengthen}
62CA CJK UNIFIED IDEOGRAPH-#62CA, IRGKangXi=0425.020, RSKangXi=64.5, Def{slap; pat; tap; handle of a vessel}
62CB CJK UNIFIED IDEOGRAPH-#62CB, IRGKangXi=0425.030, RSKangXi=64.5, Def{throw (away), abandon, reject}
62CC CJK UNIFIED IDEOGRAPH-#62CC, IRGKangXi=0425.050, RSKangXi=64.5, Def{mix}
62CD CJK UNIFIED IDEOGRAPH-#62CD, IRGKangXi=0425.070, RSKangXi=64.5, Def{clap, tap, beat; beat or rhythm}
62CE CJK UNIFIED IDEOGRAPH-#62CE, IRGKangXi=0425.080, RSKangXi=64.5, Def{to haul; to lift; to take}
62CF CJK UNIFIED IDEOGRAPH-#62CF, IRGKangXi=0425.090, RSKangXi=64.5, Def{take; bring; grasp, hold; arrest}
62D0 CJK UNIFIED IDEOGRAPH-#62D0, IRGKangXi=0425.100, RSKangXi=64.5, Def{kidnap, abduct; turn}
62D1 CJK UNIFIED IDEOGRAPH-#62D1, IRGKangXi=0425.110, RSKangXi=64.5, Def{to clamp, tie down or pin down}
62D2 CJK UNIFIED IDEOGRAPH-#62D2, IRGKangXi=0425.120, RSKangXi=64.5, Def{ward off with hand, defend}
62D3 CJK UNIFIED IDEOGRAPH-#62D3, IRGKangXi=0425.130, RSKangXi=64.5, Def{expand; open up; support or push}
62D4 CJK UNIFIED IDEOGRAPH-#62D4, IRGKangXi=0426.010, RSKangXi=64.5, Def{uproot, pull out}
62D5 CJK UNIFIED IDEOGRAPH-#62D5, IRGKangXi=0426.020, RSKangXi=64.5, Def{to drag after, to drag out, from which comes:to involve, to delay, to implicate}
62D6 CJK UNIFIED IDEOGRAPH-#62D6, IRGKangXi=0426.030, RSKangXi=64.5, Def{drag, tow, haul; delay, prolong}
62D7 CJK UNIFIED IDEOGRAPH-#62D7, IRGKangXi=0426.040, RSKangXi=64.5, Def{to pull, drag, break off, to pluck (a flower); bent, warped; perverse, obstinate}
62D8 CJK UNIFIED IDEOGRAPH-#62D8, IRGKangXi=0426.050, RSKangXi=64.5, Def{restrain, seize, detain}
62D9 CJK UNIFIED IDEOGRAPH-#62D9, IRGKangXi=0426.070, RSKangXi=64.5, Def{stupid, clumsy, crude; convention}
62DA CJK UNIFIED IDEOGRAPH-#62DA, IRGKangXi=0426.090, RSKangXi=64.5, Def{risk, disregard; go all out for}
62DB CJK UNIFIED IDEOGRAPH-#62DB, IRGKangXi=0427.010, RSKangXi=64.5, Def{beckon, summon; recruit, levy}
62DC CJK UNIFIED IDEOGRAPH-#62DC, IRGKangXi=0427.020, RSKangXi=64.5, Def{do obeisance, bow, kowtow}
62DD CJK UNIFIED IDEOGRAPH-#62DD, IRGKangXi=0427.161, RSKangXi=64.5, Def{do obeisance, bow, kowtow}
62DE CJK UNIFIED IDEOGRAPH-#62DE, IRGKangXi=0427.161, RSKangXi=64.5
62DF CJK UNIFIED IDEOGRAPH-#62DF, IRGKangXi=0427.161, RSKangXi=64.5, Def{draft; intend, plan, propose}
62E0 CJK UNIFIED IDEOGRAPH-#62E0, IRGKangXi=0427.161, RSKangXi=64.5, Def{to occupy, take possession of; a base, position}
62E1 CJK UNIFIED IDEOGRAPH-#62E1, IRGKangXi=0427.161, RSKangXi=64.5, Def{expand, enlarge, stretch}
62E2 CJK UNIFIED IDEOGRAPH-#62E2, IRGKangXi=0427.161, RSKangXi=64.5, Def{collect, bring together}
62E3 CJK UNIFIED IDEOGRAPH-#62E3, IRGKangXi=0427.161, RSKangXi=64.5, Def{choose; select; pick up; gather}
62E4 CJK UNIFIED IDEOGRAPH-#62E4, IRGKangXi=0427.161, RSKangXi=64.5
62E5 CJK UNIFIED IDEOGRAPH-#62E5, IRGKangXi=0427.161, RSKangXi=64.5, Def{embrace, hug, squeeze; crowd}
62E6 CJK UNIFIED IDEOGRAPH-#62E6, IRGKangXi=0427.161, RSKangXi=64.5, Def{obstruct, impede, bar, hinder}
62E7 CJK UNIFIED IDEOGRAPH-#62E7, IRGKangXi=0427.161, RSKangXi=64.5, Def{pinch; twist, wring; determined}
62E8 CJK UNIFIED IDEOGRAPH-#62E8, IRGKangXi=0427.161, RSKangXi=64.5, Def{move; dispel; distribute}
62E9 CJK UNIFIED IDEOGRAPH-#62E9, IRGKangXi=0427.161, RSKangXi=64.5, Def{select, choose, pick out}
62EA CJK UNIFIED IDEOGRAPH-#62EA, IRGKangXi=0427.170, RSKangXi=64.6
62EB CJK UNIFIED IDEOGRAPH-#62EB, IRGKangXi=0427.180, RSKangXi=64.6, Def{to pull; to drag; to stop; (Cant.) to turn fast}
62EC CJK UNIFIED IDEOGRAPH-#62EC, IRGKangXi=0427.190, RSKangXi=64.6, Def{include, embrace, enclose}
62ED CJK UNIFIED IDEOGRAPH-#62ED, IRGKangXi=0427.200, RSKangXi=64.6, Def{wipe away stains with cloth}
62EE CJK UNIFIED IDEOGRAPH-#62EE, IRGKangXi=0427.210, RSKangXi=64.6, Def{laboring hard, occupied; pursue}
62EF CJK UNIFIED IDEOGRAPH-#62EF, IRGKangXi=0427.220, RSKangXi=64.6, Def{help, save, aid; lift, raise}
62F0 CJK UNIFIED IDEOGRAPH-#62F0, IRGKangXi=0427.230, RSKangXi=64.6
62F1 CJK UNIFIED IDEOGRAPH-#62F1, IRGKangXi=0428.020, RSKangXi=64.6, Def{fold hands on breast; bow, salute}
62F2 CJK UNIFIED IDEOGRAPH-#62F2, IRGKangXi=0428.030, RSKangXi=64.6
62F3 CJK UNIFIED IDEOGRAPH-#62F3, IRGKangXi=0428.040, RSKangXi=64.6, Def{fist; various forms of boxing}
62F4 CJK UNIFIED IDEOGRAPH-#62F4, IRGKangXi=0428.100, RSKangXi=64.6, Def{bind with rope, fasten}
62F5 CJK UNIFIED IDEOGRAPH-#62F5, IRGKangXi=0428.110, RSKangXi=64.6, Def{to make, prepare, manufacture; workmanship; an arrangement}
62F6 CJK UNIFIED IDEOGRAPH-#62F6, IRGKangXi=0428.140, RSKangXi=64.6, Def{press, squeeze hard; force}
62F7 CJK UNIFIED IDEOGRAPH-#62F7, IRGKangXi=0428.160, RSKangXi=64.6, Def{torture and interrogate; hit}
62F8 CJK UNIFIED IDEOGRAPH-#62F8, IRGKangXi=0428.180, RSKangXi=64.6
62F9 CJK UNIFIED IDEOGRAPH-#62F9, IRGKangXi=0428.190, RSKangXi=64.6
62FA CJK UNIFIED IDEOGRAPH-#62FA, IRGKangXi=0428.200, RSKangXi=64.6
62FB CJK UNIFIED IDEOGRAPH-#62FB, IRGKangXi=0428.210, RSKangXi=64.6
62FC CJK UNIFIED IDEOGRAPH-#62FC, IRGKangXi=0428.220, RSKangXi=64.6, Def{join together, link, incorporate}
62FD CJK UNIFIED IDEOGRAPH-#62FD, IRGKangXi=0428.230, RSKangXi=64.6, Def{drag, tow; throw; twist}
62FE CJK UNIFIED IDEOGRAPH-#62FE, IRGKangXi=0428.240, RSKangXi=64.6, AccountingNumeric=10, Def{pick up, collect, tidy up; accounting form of the numeral ten}
62FF CJK UNIFIED IDEOGRAPH-#62FF, IRGKangXi=0429.010, RSKangXi=64.6, Def{take, hold, grasp; bring; with}
6300 CJK UNIFIED IDEOGRAPH-#6300, IRGKangXi=0429.040, RSKangXi=64.6
6301 CJK UNIFIED IDEOGRAPH-#6301, IRGKangXi=0429.050, RSKangXi=64.6, Def{sustain, support; hold, grasp}
6302 CJK UNIFIED IDEOGRAPH-#6302, IRGKangXi=0429.060, RSKangXi=64.6, Def{hang, suspend; suspense}
6303 CJK UNIFIED IDEOGRAPH-#6303, IRGKangXi=0429.110, RSKangXi=64.6, Def{(Cant.) to beat}
6304 CJK UNIFIED IDEOGRAPH-#6304, IRGKangXi=0429.150, RSKangXi=64.6
6305 CJK UNIFIED IDEOGRAPH-#6305, IRGKangXi=0429.160, RSKangXi=64.6
6306 CJK UNIFIED IDEOGRAPH-#6306, IRGKangXi=0429.170, RSKangXi=64.6
6307 CJK UNIFIED IDEOGRAPH-#6307, IRGKangXi=0429.200, RSKangXi=64.6, Def{finger, toe; point, indicate}
6308 CJK UNIFIED IDEOGRAPH-#6308, IRGKangXi=0429.220, RSKangXi=64.6, Def{assist, help, lead by hand}
6309 CJK UNIFIED IDEOGRAPH-#6309, IRGKangXi=0429.260, RSKangXi=64.6, Def{put hand on, press down with hand}
630A CJK UNIFIED IDEOGRAPH-#630A, IRGKangXi=0430.030, RSKangXi=64.6
630B CJK UNIFIED IDEOGRAPH-#630B, IRGKangXi=0430.070, RSKangXi=64.6
630C CJK UNIFIED IDEOGRAPH-#630C, IRGKangXi=0430.090, RSKangXi=64.6, Def{fight}
630D CJK UNIFIED IDEOGRAPH-#630D, IRGKangXi=0430.120, RSKangXi=64.6, Def{collate; (Cant.) to scratch}
630E CJK UNIFIED IDEOGRAPH-#630E, IRGKangXi=0430.130, RSKangXi=64.6, Def{carry}
630F CJK UNIFIED IDEOGRAPH-#630F, IRGKangXi=0430.140, RSKangXi=64.6, Def{(Cant.) to dredge or poke with a pole or stick}
6310 CJK UNIFIED IDEOGRAPH-#6310, IRGKangXi=0430.160, RSKangXi=64.6, Def{drag}
6311 CJK UNIFIED IDEOGRAPH-#6311, IRGKangXi=0430.170, RSKangXi=64.6, Def{a load carried on the shoulders; to carry}
6312 CJK UNIFIED IDEOGRAPH-#6312, IRGKangXi=0430.180, RSKangXi=64.6
6313 CJK UNIFIED IDEOGRAPH-#6313, IRGKangXi=0431.030, RSKangXi=64.6, Def{to open out; to expand}
6314 CJK UNIFIED IDEOGRAPH-#6314, IRGKangXi=0431.080, RSKangXi=64.6
6315 CJK UNIFIED IDEOGRAPH-#6315, IRGKangXi=0431.090, RSKangXi=64.6
6316 CJK UNIFIED IDEOGRAPH-#6316, IRGKangXi=0431.130, RSKangXi=64.6, Def{dig, dig out, gouge out, scoop}
6317 CJK UNIFIED IDEOGRAPH-#6317, IRGKangXi=0431.160, RSKangXi=64.6
6318 CJK UNIFIED IDEOGRAPH-#6318, IRGKangXi=0431.171, RSKangXi=64.6, Def{to pluck, pick, tear; (Cant.) rubbing action}
6319 CJK UNIFIED IDEOGRAPH-#6319, IRGKangXi=0431.171, RSKangXi=64.6, Def{raise, lift up; recommend}
631A CJK UNIFIED IDEOGRAPH-#631A, IRGKangXi=0431.171, RSKangXi=64.6, Def{sincere, warm, cordial; surname}
631B CJK UNIFIED IDEOGRAPH-#631B, IRGKangXi=0431.171, RSKangXi=64.6, Def{tangled; entwined; crooked}
631C CJK UNIFIED IDEOGRAPH-#631C, IRGKangXi=0431.171, RSKangXi=64.8, Def{take; hold; give forcefully}
631D CJK UNIFIED IDEOGRAPH-#631D, IRGKangXi=0434.241, RSKangXi=64.6, Def{to beat; to strike}
631E CJK UNIFIED IDEOGRAPH-#631E, IRGKangXi=0434.241, RSKangXi=64.6, Def{flog, whip; chastise}
631F CJK UNIFIED IDEOGRAPH-#631F, IRGKangXi=0431.171, RSKangXi=64.6, Def{clasp under arm; hold to bosom}
6320 CJK UNIFIED IDEOGRAPH-#6320, IRGKangXi=0431.171, RSKangXi=64.6, Def{scratch; disturb, bother; submit}
6321 CJK UNIFIED IDEOGRAPH-#6321, IRGKangXi=0431.171, RSKangXi=64.6, Def{obstruct, impede; stop; resist}
6322 CJK UNIFIED IDEOGRAPH-#6322, IRGKangXi=0431.171, RSKangXi=64.6, Def{correct}
6323 CJK UNIFIED IDEOGRAPH-#6323, IRGKangXi=0431.171, RSKangXi=64.6, Def{strive, endeavor, struggle}
6324 CJK UNIFIED IDEOGRAPH-#6324, IRGKangXi=0431.171, RSKangXi=64.6, Def{crowd, squeeze, push against}
6325 CJK UNIFIED IDEOGRAPH-#6325, IRGKangXi=0431.171, RSKangXi=64.6, Def{direct; wipe away; squander}
6326 CJK UNIFIED IDEOGRAPH-#6326, IRGKangXi=0431.171, RSKangXi=64.12, Def{pull out, pluck; take hold of}
6327 CJK UNIFIED IDEOGRAPH-#6327, IRGKangXi=0431.171, RSKangXi=64.6
6328 CJK UNIFIED IDEOGRAPH-#6328, IRGKangXi=0431.180, RSKangXi=64.7, Def{near, close by, next to, towards, against; to wait; to lean on}
6329 CJK UNIFIED IDEOGRAPH-#6329, IRGKangXi=0431.190, RSKangXi=64.7
632A CJK UNIFIED IDEOGRAPH-#632A, IRGKangXi=0431.200, RSKangXi=64.7, Def{move, shift on one side}
632B CJK UNIFIED IDEOGRAPH-#632B, IRGKangXi=0431.220, RSKangXi=64.7, Def{push down; chop down; grind}
632C CJK UNIFIED IDEOGRAPH-#632C, IRGKangXi=0431.240, RSKangXi=64.7
632D CJK UNIFIED IDEOGRAPH-#632D, IRGKangXi=0431.250, RSKangXi=64.7, Def{fish-bones, things that stick in the throat; unyielding, blunt of speech; (Cant.) to stir, mix, agitate; to wade}
632E CJK UNIFIED IDEOGRAPH-#632E, IRGKangXi=0431.260, RSKangXi=64.7
632F CJK UNIFIED IDEOGRAPH-#632F, IRGKangXi=0431.280, RSKangXi=64.7, Def{raise, excite, arouse action}
6330 CJK UNIFIED IDEOGRAPH-#6330, IRGKangXi=0431.290, RSKangXi=64.7
6331 CJK UNIFIED IDEOGRAPH-#6331, IRGKangXi=0431.300, RSKangXi=64.7, Def{to feel or fondle with the fingers}
6332 CJK UNIFIED IDEOGRAPH-#6332, IRGKangXi=0431.310, RSKangXi=64.7, Def{to feel or fondle with the fingers}
6333 CJK UNIFIED IDEOGRAPH-#6333, IRGKangXi=0431.330, RSKangXi=64.7
6334 CJK UNIFIED IDEOGRAPH-#6334, IRGKangXi=0431.340, RSKangXi=64.7
6335 CJK UNIFIED IDEOGRAPH-#6335, IRGKangXi=0431.360, RSKangXi=64.7, Def{to play with, handle things}
6336 CJK UNIFIED IDEOGRAPH-#6336, IRGKangXi=0431.370, RSKangXi=64.7, Def{hold in hands}
6337 CJK UNIFIED IDEOGRAPH-#6337, IRGKangXi=0431.380, RSKangXi=64.7, Def{to propel a boat; to beat}
6338 CJK UNIFIED IDEOGRAPH-#6338, IRGKangXi=0432.010, RSKangXi=64.7
6339 CJK UNIFIED IDEOGRAPH-#6339, IRGKangXi=0432.030, RSKangXi=64.7, Def{to bale out; to decant liquids}
633A CJK UNIFIED IDEOGRAPH-#633A, IRGKangXi=0432.040, RSKangXi=64.7, Def{to stand upright, straighten; rigid}
633B CJK UNIFIED IDEOGRAPH-#633B, IRGKangXi=0432.050, RSKangXi=64.7
633C CJK UNIFIED IDEOGRAPH-#633C, IRGKangXi=0432.070, RSKangXi=64.7, Def{rub, stroke with hands; crumple}
633D CJK UNIFIED IDEOGRAPH-#633D, IRGKangXi=0432.090, RSKangXi=64.7, Def{pull; pull back, draw back}
633E CJK UNIFIED IDEOGRAPH-#633E, IRGKangXi=0432.160, RSKangXi=64.7, Def{clasp under arm; hold to bosom}
633F CJK UNIFIED IDEOGRAPH-#633F, IRGKangXi=0432.170, RSKangXi=64.7, Def{insert, stick into; plant}
6340 CJK UNIFIED IDEOGRAPH-#6340, IRGKangXi=0432.180, RSKangXi=64.7
6341 CJK UNIFIED IDEOGRAPH-#6341, IRGKangXi=0432.210, RSKangXi=64.7
6342 CJK UNIFIED IDEOGRAPH-#6342, IRGKangXi=0432.220, RSKangXi=64.7, Def{resist}
6343 CJK UNIFIED IDEOGRAPH-#6343, IRGKangXi=0433.010, RSKangXi=64.7
6344 CJK UNIFIED IDEOGRAPH-#6344, IRGKangXi=0433.030, RSKangXi=64.7, Def{long and curved}
6345 CJK UNIFIED IDEOGRAPH-#6345, IRGKangXi=0433.060, RSKangXi=64.7, Def{jab}
6346 CJK UNIFIED IDEOGRAPH-#6346, IRGKangXi=0433.070, RSKangXi=64.7, Def{tie up; bind, truss up; bundle}
6347 CJK UNIFIED IDEOGRAPH-#6347, IRGKangXi=0433.100, RSKangXi=64.7
6348 CJK UNIFIED IDEOGRAPH-#6348, IRGKangXi=0433.110, RSKangXi=64.7
6349 CJK UNIFIED IDEOGRAPH-#6349, IRGKangXi=0433.120, RSKangXi=64.7, Def{grasp, clutch; catch, seize}
634A CJK UNIFIED IDEOGRAPH-#634A, IRGKangXi=0433.150, RSKangXi=64.7
634B CJK UNIFIED IDEOGRAPH-#634B, IRGKangXi=0433.170, RSKangXi=64.7, Def{to pluck; to gather in the fingers; to rub; to scrape off}
634C CJK UNIFIED IDEOGRAPH-#634C, IRGKangXi=0433.180, RSKangXi=64.7, AccountingNumeric=8, Def{break open, split open; an accounting version of the numeral eight}
634D CJK UNIFIED IDEOGRAPH-#634D, IRGKangXi=0433.200, RSKangXi=64.7, Def{ward off, guard against, defend}
634E CJK UNIFIED IDEOGRAPH-#634E, IRGKangXi=0433.250, RSKangXi=64.7, Def{to select; to take; to carry}
634F CJK UNIFIED IDEOGRAPH-#634F, IRGKangXi=0434.010, RSKangXi=64.7, Def{pick with fingers; knead; mold}
6350 CJK UNIFIED IDEOGRAPH-#6350, IRGKangXi=0434.020, RSKangXi=64.7, Def{contribute; give up, renounce}
6351 CJK UNIFIED IDEOGRAPH-#6351, IRGKangXi=0434.050, RSKangXi=64.7
6352 CJK UNIFIED IDEOGRAPH-#6352, IRGKangXi=0434.060, RSKangXi=64.7
6353 CJK UNIFIED IDEOGRAPH-#6353, IRGKangXi=0434.070, RSKangXi=64.7, Def{strive, endeavor}
6354 CJK UNIFIED IDEOGRAPH-#6354, IRGKangXi=0434.080, RSKangXi=64.7, Def{to gore, stab}
6355 CJK UNIFIED IDEOGRAPH-#6355, IRGKangXi=0434.090, RSKangXi=64.7, Def{arrest, catch, seize}
6356 CJK UNIFIED IDEOGRAPH-#6356, IRGKangXi=0434.100, RSKangXi=64.7
6357 CJK UNIFIED IDEOGRAPH-#6357, IRGKangXi=0434.120, RSKangXi=64.7, Def{make progress}
6358 CJK UNIFIED IDEOGRAPH-#6358, IRGKangXi=0434.130, RSKangXi=64.7, Def{push}
6359 CJK UNIFIED IDEOGRAPH-#6359, IRGKangXi=0434.180, RSKangXi=64.7
635A CJK UNIFIED IDEOGRAPH-#635A, IRGKangXi=0434.230, RSKangXi=64.7
635B CJK UNIFIED IDEOGRAPH-#635B, IRGKangXi=0434.241, RSKangXi=64.7
635C CJK UNIFIED IDEOGRAPH-#635C, IRGKangXi=0434.241, RSKangXi=64.7, Def{search, seek; investigate}
635D CJK UNIFIED IDEOGRAPH-#635D, IRGKangXi=0434.241, RSKangXi=64.7
635E CJK UNIFIED IDEOGRAPH-#635E, IRGKangXi=0434.241, RSKangXi=64.7, Def{scoop out of water; dredge, fish}
635F CJK UNIFIED IDEOGRAPH-#635F, IRGKangXi=0434.241, RSKangXi=64.7, Def{diminish; impair; injure}
6360 CJK UNIFIED IDEOGRAPH-#6360, IRGKangXi=0434.241, RSKangXi=64.6
6361 CJK UNIFIED IDEOGRAPH-#6361, IRGKangXi=0434.241, RSKangXi=64.7, Def{to pick up}
6362 CJK UNIFIED IDEOGRAPH-#6362, IRGKangXi=0434.241, RSKangXi=64.7, Def{change}
6363 CJK UNIFIED IDEOGRAPH-#6363, IRGKangXi=0434.241, RSKangXi=64.7, Def{hull; thresh; beat, attack}
6364 CJK UNIFIED IDEOGRAPH-#6364, IRGKangXi=0434.241, RSKangXi=64.7
6365 CJK UNIFIED IDEOGRAPH-#6365, IRGKangXi=0434.260, RSKangXi=64.8, Def{to bend the wrist}
6366 CJK UNIFIED IDEOGRAPH-#6366, IRGKangXi=0434.270, RSKangXi=64.8, Def{to seize; to clutch; to arrest; to capture; (Cant.) to climb}
6367 CJK UNIFIED IDEOGRAPH-#6367, IRGKangXi=0434.330, RSKangXi=64.8, Def{hold up in two hands}
6368 CJK UNIFIED IDEOGRAPH-#6368, IRGKangXi=0434.350, RSKangXi=64.8, Def{discard, give up willingly; give alms}
6369 CJK UNIFIED IDEOGRAPH-#6369, IRGKangXi=0434.360, RSKangXi=64.8, Def{twist with hands; snap, tear}
636A CJK UNIFIED IDEOGRAPH-#636A, IRGKangXi=0435.030, RSKangXi=64.8
636B CJK UNIFIED IDEOGRAPH-#636B, IRGKangXi=0435.050, RSKangXi=64.8, Def{stoke, pat, feel by hand, grope}
636C CJK UNIFIED IDEOGRAPH-#636C, IRGKangXi=0435.060, RSKangXi=64.8, Def{press down heavily with hands}
636D CJK UNIFIED IDEOGRAPH-#636D, IRGKangXi=0435.080, RSKangXi=64.8, Def{to open; to spread out}
636E CJK UNIFIED IDEOGRAPH-#636E, IRGKangXi=0435.120, RSKangXi=64.8, Def{to occupy, take possession of; a base, position}
636F CJK UNIFIED IDEOGRAPH-#636F, IRGKangXi=0435.130, RSKangXi=64.8
6370 CJK UNIFIED IDEOGRAPH-#6370, IRGKangXi=0435.140, RSKangXi=64.8
6371 CJK UNIFIED IDEOGRAPH-#6371, IRGKangXi=0435.150, RSKangXi=64.8, Def{put off, procrastinate; endure}
6372 CJK UNIFIED IDEOGRAPH-#6372, IRGKangXi=0435.160, RSKangXi=64.8, Def{curl, roll up; curly, rolled up}
6373 CJK UNIFIED IDEOGRAPH-#6373, IRGKangXi=0435.180, RSKangXi=64.8
6374 CJK UNIFIED IDEOGRAPH-#6374, IRGKangXi=0435.200, RSKangXi=64.8
6375 CJK UNIFIED IDEOGRAPH-#6375, IRGKangXi=0435.220, RSKangXi=64.8, Def{(Cant.) to hold between the fingers and thumb}
6376 CJK UNIFIED IDEOGRAPH-#6376, IRGKangXi=0435.230, RSKangXi=64.8, Def{strike with stick, lash, beat}
6377 CJK UNIFIED IDEOGRAPH-#6377, IRGKangXi=0435.240, RSKangXi=64.8, Def{win, victory, triumph}
6378 CJK UNIFIED IDEOGRAPH-#6378, IRGKangXi=0435.250, RSKangXi=64.8
6379 CJK UNIFIED IDEOGRAPH-#6379, IRGKangXi=0435.260, RSKangXi=64.8, Def{to fumble things over, mix up; (Cant.) to swing, fling; to flick off, throw off; to jerk}
637A CJK UNIFIED IDEOGRAPH-#637A, IRGKangXi=0435.290, RSKangXi=64.8, Def{to press down heavily with the fingers}
637B CJK UNIFIED IDEOGRAPH-#637B, IRGKangXi=0435.300, RSKangXi=64.8, Def{to twist or nip with the fingers}
637C CJK UNIFIED IDEOGRAPH-#637C, IRGKangXi=0435.310, RSKangXi=64.8, Def{to rub; to crumple}
637D CJK UNIFIED IDEOGRAPH-#637D, IRGKangXi=0436.020, RSKangXi=64.8, Def{clutch, grasp; pull up; contradict}
637E CJK UNIFIED IDEOGRAPH-#637E, IRGKangXi=0436.030, RSKangXi=64.8
637F CJK UNIFIED IDEOGRAPH-#637F, IRGKangXi=0436.040, RSKangXi=64.8, Def{perch; roost; stay}
6380 CJK UNIFIED IDEOGRAPH-#6380, IRGKangXi=0436.070, RSKangXi=64.8, Def{lift, raise; stir}
6381 CJK UNIFIED IDEOGRAPH-#6381, IRGKangXi=0436.100, RSKangXi=64.8
6382 CJK UNIFIED IDEOGRAPH-#6382, IRGKangXi=0436.120, RSKangXi=64.8, Def{heft, hold or weigh in palm}
6383 CJK UNIFIED IDEOGRAPH-#6383, IRGKangXi=0436.140, RSKangXi=64.8, Def{sweep, clear away; exterminate}
6384 CJK UNIFIED IDEOGRAPH-#6384, IRGKangXi=0436.150, RSKangXi=64.8, Def{swing, brandish, flourish}
6385 CJK UNIFIED IDEOGRAPH-#6385, IRGKangXi=0436.160, RSKangXi=64.8, Def{(Cant.) to lift up; to seize, grab}
6386 CJK UNIFIED IDEOGRAPH-#6386, IRGKangXi=0436.170, RSKangXi=64.8
6387 CJK UNIFIED IDEOGRAPH-#6387, IRGKangXi=0436.180, RSKangXi=64.8, Def{collect, gather up, pick up}
6388 CJK UNIFIED IDEOGRAPH-#6388, IRGKangXi=0436.190, RSKangXi=64.8, Def{give to, transmit; confer}
6389 CJK UNIFIED IDEOGRAPH-#6389, IRGKangXi=0436.200, RSKangXi=64.8, Def{turn, move; shake, wag; drop down}
638A CJK UNIFIED IDEOGRAPH-#638A, IRGKangXi=0437.010, RSKangXi=64.8, Def{to extract; injure}
638B CJK UNIFIED IDEOGRAPH-#638B, IRGKangXi=0437.030, RSKangXi=64.8
638C CJK UNIFIED IDEOGRAPH-#638C, IRGKangXi=0437.050, RSKangXi=64.8, Def{palm of hand, sole of foot, paw}
638D CJK UNIFIED IDEOGRAPH-#638D, IRGKangXi=0437.070, RSKangXi=64.8
638E CJK UNIFIED IDEOGRAPH-#638E, IRGKangXi=0437.080, RSKangXi=64.8, Def{drag aside, pull; drag one foot}
638F CJK UNIFIED IDEOGRAPH-#638F, IRGKangXi=0437.090, RSKangXi=64.8, Def{take out; pull out; clean out}
6390 CJK UNIFIED IDEOGRAPH-#6390, IRGKangXi=0437.110, RSKangXi=64.8, Def{hold; gather with hand; choke}
6391 CJK UNIFIED IDEOGRAPH-#6391, IRGKangXi=0437.120, RSKangXi=64.8
6392 CJK UNIFIED IDEOGRAPH-#6392, IRGKangXi=0437.130, RSKangXi=64.8, Def{row, rank, line}
6393 CJK UNIFIED IDEOGRAPH-#6393, IRGKangXi=0437.140, RSKangXi=64.8
6394 CJK UNIFIED IDEOGRAPH-#6394, IRGKangXi=0437.160, RSKangXi=64.8, Def{sturdy}
6395 CJK UNIFIED IDEOGRAPH-#6395, IRGKangXi=0437.170, RSKangXi=64.8
6396 CJK UNIFIED IDEOGRAPH-#6396, IRGKangXi=0437.190, RSKangXi=64.8, Def{support with the arms; stick in, tuck in; fold up}
6397 CJK UNIFIED IDEOGRAPH-#6397, IRGKangXi=0438.010, RSKangXi=64.8, Def{take; hold; give forcefully}
6398 CJK UNIFIED IDEOGRAPH-#6398, IRGKangXi=0438.020, RSKangXi=64.8, Def{dig, excavate; excavate cave}
6399 CJK UNIFIED IDEOGRAPH-#6399, IRGKangXi=0438.030, RSKangXi=64.8, Def{to strive, endeavor, struggle; to earn; to pierce; to wedge in}
639A CJK UNIFIED IDEOGRAPH-#639A, IRGKangXi=0438.040, RSKangXi=64.8
639B CJK UNIFIED IDEOGRAPH-#639B, IRGKangXi=0438.050, RSKangXi=64.8, Def{hang, suspend; suspense}
639C CJK UNIFIED IDEOGRAPH-#639C, IRGKangXi=0438.060, RSKangXi=64.8
639D CJK UNIFIED IDEOGRAPH-#639D, IRGKangXi=0438.070, RSKangXi=64.8
639E CJK UNIFIED IDEOGRAPH-#639E, IRGKangXi=0438.080, RSKangXi=64.8, Def{easy, smooth; quiet; suave}
639F CJK UNIFIED IDEOGRAPH-#639F, IRGKangXi=0438.100, RSKangXi=64.8, Def{law, commandments, regulations; (Cant.) to throw}
63A0 CJK UNIFIED IDEOGRAPH-#63A0, IRGKangXi=0438.110, RSKangXi=64.8, Def{rob, ransack, plunder; pass by}
63A1 CJK UNIFIED IDEOGRAPH-#63A1, IRGKangXi=0438.120, RSKangXi=64.8, Def{gather, collect; pick, select}
63A2 CJK UNIFIED IDEOGRAPH-#63A2, IRGKangXi=0438.140, RSKangXi=64.8, Def{find, locate; search, grope for}
63A3 CJK UNIFIED IDEOGRAPH-#63A3, IRGKangXi=0439.010, RSKangXi=64.8, Def{drag, pull; hinder by pulling back}
63A4 CJK UNIFIED IDEOGRAPH-#63A4, IRGKangXi=0439.030, RSKangXi=64.8, Def{quiver; (Cant.) to pull on something}
63A5 CJK UNIFIED IDEOGRAPH-#63A5, IRGKangXi=0439.040, RSKangXi=64.8, Def{receive; continue; catch; connect}
63A6 CJK UNIFIED IDEOGRAPH-#63A6, IRGKangXi=0439.050, RSKangXi=64.8, Def{to take up; to put by}
63A7 CJK UNIFIED IDEOGRAPH-#63A7, IRGKangXi=0439.070, RSKangXi=64.8, Def{accuse, charge; control}
63A8 CJK UNIFIED IDEOGRAPH-#63A8, IRGKangXi=0439.080, RSKangXi=64.8, Def{push, expel; push forward}
63A9 CJK UNIFIED IDEOGRAPH-#63A9, IRGKangXi=0439.090, RSKangXi=64.8, Def{to cover (with the hand); shut, conceal; ambush}
63AA CJK UNIFIED IDEOGRAPH-#63AA, IRGKangXi=0439.100, RSKangXi=64.8, Def{place; collect, arrange; employ}
63AB CJK UNIFIED IDEOGRAPH-#63AB, IRGKangXi=0439.110, RSKangXi=64.8, Def{be on night watch; grasp}
63AC CJK UNIFIED IDEOGRAPH-#63AC, IRGKangXi=0440.020, RSKangXi=64.8, Def{to grasp or hold with both hands}
63AD CJK UNIFIED IDEOGRAPH-#63AD, IRGKangXi=0440.181, RSKangXi=64.8, Def{to manipulate; a pricker for a lamp-wick}
63AE CJK UNIFIED IDEOGRAPH-#63AE, IRGKangXi=0440.181, RSKangXi=64.8, Def{to bear on the shoulders}
63AF CJK UNIFIED IDEOGRAPH-#63AF, IRGKangXi=0440.181, RSKangXi=64.8, Def{oppress, extort, take by force}
63B0 CJK UNIFIED IDEOGRAPH-#63B0, IRGKangXi=0440.181, RSKangXi=64.8, Def{(Cant.) to tear, to rip}
63B1 CJK UNIFIED IDEOGRAPH-#63B1, IRGKangXi=0440.181, RSKangXi=64.8, Def{pickpocket}
63B2 CJK UNIFIED IDEOGRAPH-#63B2, IRGKangXi=0440.181, RSKangXi=64.9, Def{to set (a table); to install, equip; to lay (a foundation)}
63B3 CJK UNIFIED IDEOGRAPH-#63B3, IRGKangXi=0440.181, RSKangXi=64.8, Def{capture, seize}
63B4 CJK UNIFIED IDEOGRAPH-#63B4, IRGKangXi=0440.181, RSKangXi=64.7, Def{box one's ears, slap}
63B5 CJK UNIFIED IDEOGRAPH-#63B5, IRGKangXi=0440.181, RSKangXi=64.8
63B6 CJK UNIFIED IDEOGRAPH-#63B6, IRGKangXi=0440.181, RSKangXi=64.8
63B7 CJK UNIFIED IDEOGRAPH-#63B7, IRGKangXi=0445.341, RSKangXi=64.8, Def{throw, hurl, cast, fling}
63B8 CJK UNIFIED IDEOGRAPH-#63B8, IRGKangXi=0440.181, RSKangXi=64.8, Def{to dust; a duster}
63B9 CJK UNIFIED IDEOGRAPH-#63B9, IRGKangXi=0440.181, RSKangXi=64.8, Def{(Cant.) to pluck, to pull}
63BA CJK UNIFIED IDEOGRAPH-#63BA, IRGKangXi=0440.181, RSKangXi=64.8, Def{mix, blend, adulterate}
63BB CJK UNIFIED IDEOGRAPH-#63BB, IRGKangXi=0440.181, RSKangXi=64.8, Def{scratch lightly}
63BC CJK UNIFIED IDEOGRAPH-#63BC, IRGKangXi=0440.181, RSKangXi=64.8, Def{throw ground; know, be familiar}
63BD CJK UNIFIED IDEOGRAPH-#63BD, IRGKangXi=0440.190, RSKangXi=64.8, Def{collide; meet unexpectedly}
63BE CJK UNIFIED IDEOGRAPH-#63BE, IRGKangXi=0440.200, RSKangXi=64.9, Def{a general designation of officials}
63BF CJK UNIFIED IDEOGRAPH-#63BF, IRGKangXi=0440.210, RSKangXi=64.9
63C0 CJK UNIFIED IDEOGRAPH-#63C0, IRGKangXi=0440.220, RSKangXi=64.9, Def{choose; select; pick up; gather}
63C1 CJK UNIFIED IDEOGRAPH-#63C1, IRGKangXi=0440.230, RSKangXi=64.9, Def{sound of setting up a koto}
63C2 CJK UNIFIED IDEOGRAPH-#63C2, IRGKangXi=0440.250, RSKangXi=64.9
63C3 CJK UNIFIED IDEOGRAPH-#63C3, IRGKangXi=0440.260, RSKangXi=64.9, Def{shear; (Cant.) to skin an animal}
63C4 CJK UNIFIED IDEOGRAPH-#63C4, IRGKangXi=0440.270, RSKangXi=64.9, Def{lift, raise; praise; hang; flap}
63C5 CJK UNIFIED IDEOGRAPH-#63C5, IRGKangXi=0441.020, RSKangXi=64.11, Def{grind, rub; study, research; (Cant.) to play a stringed instrument}
63C6 CJK UNIFIED IDEOGRAPH-#63C6, IRGKangXi=0441.040, RSKangXi=64.9, Def{prime minister; to guess, estimate}
63C7 CJK UNIFIED IDEOGRAPH-#63C7, IRGKangXi=0441.050, RSKangXi=64.9, Def{(Cant.) to measure a distance with the extended thumb and forefinger or middle finger}
63C8 CJK UNIFIED IDEOGRAPH-#63C8, IRGKangXi=0441.070, RSKangXi=64.9
63C9 CJK UNIFIED IDEOGRAPH-#63C9, IRGKangXi=0441.100, RSKangXi=64.9, Def{rub, massage; crush by hand}
63CA CJK UNIFIED IDEOGRAPH-#63CA, IRGKangXi=0441.120, RSKangXi=64.9
63CB CJK UNIFIED IDEOGRAPH-#63CB, IRGKangXi=0441.130, RSKangXi=64.9
63CC CJK UNIFIED IDEOGRAPH-#63CC, IRGKangXi=0441.140, RSKangXi=64.9, Def{to shake}
63CD CJK UNIFIED IDEOGRAPH-#63CD, IRGKangXi=0441.150, RSKangXi=64.9, Def{hit, beat; smash, break}
63CE CJK UNIFIED IDEOGRAPH-#63CE, IRGKangXi=0441.160, RSKangXi=64.9, Def{to pull up the sleeves and stretch out the arms; to strike with bare fists}
63CF CJK UNIFIED IDEOGRAPH-#63CF, IRGKangXi=0441.170, RSKangXi=64.9, Def{copy, trace, sketch; depict}
63D0 CJK UNIFIED IDEOGRAPH-#63D0, IRGKangXi=0441.220, RSKangXi=64.9, Def{hold in hand; lift in hand}
63D1 CJK UNIFIED IDEOGRAPH-#63D1, IRGKangXi=0441.230, RSKangXi=64.9, Def{to fabricate; to trump up}
63D2 CJK UNIFIED IDEOGRAPH-#63D2, IRGKangXi=0441.240, RSKangXi=64.9, Def{insert, stick into; plant}
63D3 CJK UNIFIED IDEOGRAPH-#63D3, IRGKangXi=0442.010, RSKangXi=64.9
63D4 CJK UNIFIED IDEOGRAPH-#63D4, IRGKangXi=0442.020, RSKangXi=64.9
63D5 CJK UNIFIED IDEOGRAPH-#63D5, IRGKangXi=0442.030, RSKangXi=64.9, Def{roll up the sleeves; fight bare-fisted; strike, stab}
63D6 CJK UNIFIED IDEOGRAPH-#63D6, IRGKangXi=0442.040, RSKangXi=64.9, Def{salute, bow; defer to, yield}
63D7 CJK UNIFIED IDEOGRAPH-#63D7, IRGKangXi=0442.050, RSKangXi=64.9, Def{strike, hit with hand; tap; (Cant.) to be frightened; to move to and fro}
63D8 CJK UNIFIED IDEOGRAPH-#63D8, IRGKangXi=0442.060, RSKangXi=64.9
63D9 CJK UNIFIED IDEOGRAPH-#63D9, IRGKangXi=0442.070, RSKangXi=64.9
63DA CJK UNIFIED IDEOGRAPH-#63DA, IRGKangXi=0442.080, RSKangXi=64.9, Def{scatter, spread; praise}
63DB CJK UNIFIED IDEOGRAPH-#63DB, IRGKangXi=0442.140, RSKangXi=64.9, Def{change, exchange; substitute}
63DC CJK UNIFIED IDEOGRAPH-#63DC, IRGKangXi=0442.150, RSKangXi=64.9, Def{cover up; take by force, shut}
63DD CJK UNIFIED IDEOGRAPH-#63DD, IRGKangXi=0443.010, RSKangXi=64.9, Def{to hold in the hand, to grasp; to wring}
63DE CJK UNIFIED IDEOGRAPH-#63DE, IRGKangXi=0443.020, RSKangXi=64.9, Def{to cover (with the hand)}
63DF CJK UNIFIED IDEOGRAPH-#63DF, IRGKangXi=0443.030, RSKangXi=64.9
63E0 CJK UNIFIED IDEOGRAPH-#63E0, IRGKangXi=0443.040, RSKangXi=64.9, Def{to pull up, to eradicate}
63E1 CJK UNIFIED IDEOGRAPH-#63E1, IRGKangXi=0443.070, RSKangXi=64.9, Def{grasp, hold fast, take by hand}
63E2 CJK UNIFIED IDEOGRAPH-#63E2, IRGKangXi=0443.090, RSKangXi=64.9, Def{to seize; (Cant.) to block, obstruct}
63E3 CJK UNIFIED IDEOGRAPH-#63E3, IRGKangXi=0443.130, RSKangXi=64.9, Def{put things under clothes}
63E4 CJK UNIFIED IDEOGRAPH-#63E4, IRGKangXi=0443.150, RSKangXi=64.9
63E5 CJK UNIFIED IDEOGRAPH-#63E5, IRGKangXi=0443.210, RSKangXi=64.9, Def{scratcher}
63E6 CJK UNIFIED IDEOGRAPH-#63E6, IRGKangXi=0443.220, RSKangXi=64.9, Def{to clutch; to grab at; to rub or scrape; to tear; (Cant.) to scratch; to feel around with the hand}
63E7 CJK UNIFIED IDEOGRAPH-#63E7, IRGKangXi=0443.230, RSKangXi=64.9
63E8 CJK UNIFIED IDEOGRAPH-#63E8, IRGKangXi=0443.240, RSKangXi=64.9
63E9 CJK UNIFIED IDEOGRAPH-#63E9, IRGKangXi=0443.250, RSKangXi=64.9, Def{rub and wipe, dust, clean}
63EA CJK UNIFIED IDEOGRAPH-#63EA, IRGKangXi=0444.010, RSKangXi=64.9, Def{grasp with hand, pinch}
63EB CJK UNIFIED IDEOGRAPH-#63EB, IRGKangXi=0444.020, RSKangXi=64.9, Def{grasp with hand, pinch}
63EC CJK UNIFIED IDEOGRAPH-#63EC, IRGKangXi=0444.040, RSKangXi=64.9, Def{(Cant.) lay up; sit}
63ED CJK UNIFIED IDEOGRAPH-#63ED, IRGKangXi=0444.050, RSKangXi=64.9, Def{raise, lift up; surname}
63EE CJK UNIFIED IDEOGRAPH-#63EE, IRGKangXi=0444.100, RSKangXi=64.9, Def{direct; wipe away; squander}
63EF CJK UNIFIED IDEOGRAPH-#63EF, IRGKangXi=0444.120, RSKangXi=64.9, Def{(Cant.) tight, distended}
63F0 CJK UNIFIED IDEOGRAPH-#63F0, IRGKangXi=0444.160, RSKangXi=64.9, Def{to push in or poke out; a punch; (Cant.) to collide}
63F1 CJK UNIFIED IDEOGRAPH-#63F1, IRGKangXi=0444.180, RSKangXi=64.9
63F2 CJK UNIFIED IDEOGRAPH-#63F2, IRGKangXi=0444.190, RSKangXi=64.9, Def{to sort out the stalks used in divination; to fold}
63F3 CJK UNIFIED IDEOGRAPH-#63F3, IRGKangXi=0444.200, RSKangXi=64.9
63F4 CJK UNIFIED IDEOGRAPH-#63F4, IRGKangXi=0445.020, RSKangXi=64.9, Def{aid, assist; lead; cite}
63F5 CJK UNIFIED IDEOGRAPH-#63F5, IRGKangXi=0445.040, RSKangXi=64.9, Def{carry}
63F6 CJK UNIFIED IDEOGRAPH-#63F6, IRGKangXi=0445.340, RSKangXi=64.9, Def{make fun of, ridicule}
63F7 CJK UNIFIED IDEOGRAPH-#63F7, IRGKangXi=0445.341, RSKangXi=64.9, Def{insert}
63F8 CJK UNIFIED IDEOGRAPH-#63F8, IRGKangXi=0445.341, RSKangXi=64.9, Def{handful; to grasp, seize, pick up with fingers; (Cant.) to take, carry}
63F9 CJK UNIFIED IDEOGRAPH-#63F9, IRGKangXi=0445.341, RSKangXi=64.9, Def{carry things on one's back}
63FA CJK UNIFIED IDEOGRAPH-#63FA, IRGKangXi=0445.341, RSKangXi=64.9, Def{wag, swing, wave; shake; scull}
63FB CJK UNIFIED IDEOGRAPH-#63FB, IRGKangXi=0445.341, RSKangXi=64.9
63FC CJK UNIFIED IDEOGRAPH-#63FC, IRGKangXi=0445.341, RSKangXi=64.9, Def{(Cant.) to delay, waste time; to throw down, beat; to hang down}
63FD CJK UNIFIED IDEOGRAPH-#63FD, IRGKangXi=0445.341, RSKangXi=64.9, Def{grasp, take hold of; monopolize}
63FE CJK UNIFIED IDEOGRAPH-#63FE, IRGKangXi=0445.341, RSKangXi=64.9, Def{wipe off; press down with knuckle}
63FF CJK UNIFIED IDEOGRAPH-#63FF, IRGKangXi=0445.341, RSKangXi=64.9, Def{press}
6400 CJK UNIFIED IDEOGRAPH-#6400, IRGKangXi=0445.341, RSKangXi=64.9, Def{give helping hand}
6401 CJK UNIFIED IDEOGRAPH-#6401, IRGKangXi=0445.341, RSKangXi=64.9, Def{place, put, lay down; delay}
6402 CJK UNIFIED IDEOGRAPH-#6402, IRGKangXi=0445.341, RSKangXi=64.9, Def{hug, embrace; drag, pull}
6403 CJK UNIFIED IDEOGRAPH-#6403, IRGKangXi=0445.341, RSKangXi=64.9, Def{all, general; to summarize; the chief; to manage}
6404 CJK UNIFIED IDEOGRAPH-#6404, IRGKangXi=0445.341, RSKangXi=64.9
6405 CJK UNIFIED IDEOGRAPH-#6405, IRGKangXi=0445.341, RSKangXi=64.9, Def{disturb, agitate, stir up}
6406 CJK UNIFIED IDEOGRAPH-#6406, IRGKangXi=0445.360, RSKangXi=64.10, Def{pull, drag; reach; implicate}
6407 CJK UNIFIED IDEOGRAPH-#6407, IRGKangXi=0445.370, RSKangXi=64.10, Def{to press down with the hand; to lead on; (Cant.) to cover, close up}
6408 CJK UNIFIED IDEOGRAPH-#6408, IRGKangXi=0445.380, RSKangXi=64.10
6409 CJK UNIFIED IDEOGRAPH-#6409, IRGKangXi=0445.400, RSKangXi=64.10, Def{knock; pick out; ridicule}
640A CJK UNIFIED IDEOGRAPH-#640A, IRGKangXi=0445.420, RSKangXi=64.10, Def{pluck}
640B CJK UNIFIED IDEOGRAPH-#640B, IRGKangXi=0446.040, RSKangXi=64.10, Def{to thump}
640C CJK UNIFIED IDEOGRAPH-#640C, IRGKangXi=0446.050, RSKangXi=64.10, Def{to wipe tears; to bind}
640D CJK UNIFIED IDEOGRAPH-#640D, IRGKangXi=0446.060, RSKangXi=64.10, Def{diminish; impair; injure}
640E CJK UNIFIED IDEOGRAPH-#640E, IRGKangXi=0446.120, RSKangXi=64.10, Def{to rub with the hand; to stroke}
640F CJK UNIFIED IDEOGRAPH-#640F, IRGKangXi=0446.140, RSKangXi=64.10, Def{seize; spring upon; strike}
6410 CJK UNIFIED IDEOGRAPH-#6410, IRGKangXi=0446.200, RSKangXi=64.10, Def{cramp, spasm, convulsion; twitch}
6411 CJK UNIFIED IDEOGRAPH-#6411, IRGKangXi=0446.210, RSKangXi=64.10
6412 CJK UNIFIED IDEOGRAPH-#6412, IRGKangXi=0446.220, RSKangXi=64.10, Def{pole; beat}
6413 CJK UNIFIED IDEOGRAPH-#6413, IRGKangXi=0446.240, RSKangXi=64.10, Def{to rub or roll between the hands}
6414 CJK UNIFIED IDEOGRAPH-#6414, IRGKangXi=0446.250, RSKangXi=64.10, Def{to scratch}
6415 CJK UNIFIED IDEOGRAPH-#6415, IRGKangXi=0446.260, RSKangXi=64.10, Def{to strike; to take in the hand}
6416 CJK UNIFIED IDEOGRAPH-#6416, IRGKangXi=0446.270, RSKangXi=64.10, Def{wag, swing, wave; shake; scull}
6417 CJK UNIFIED IDEOGRAPH-#6417, IRGKangXi=0447.010, RSKangXi=64.10, Def{hull; thresh; beat, attack}
6418 CJK UNIFIED IDEOGRAPH-#6418, IRGKangXi=0447.020, RSKangXi=64.10, Def{prop}
6419 CJK UNIFIED IDEOGRAPH-#6419, IRGKangXi=0447.030, RSKangXi=64.10, Def{to handle; to play with}
641A CJK UNIFIED IDEOGRAPH-#641A, IRGKangXi=0447.040, RSKangXi=64.10
641B CJK UNIFIED IDEOGRAPH-#641B, IRGKangXi=0447.050, RSKangXi=64.10
641C CJK UNIFIED IDEOGRAPH-#641C, IRGKangXi=0447.070, RSKangXi=64.9, Def{search, seek; investigate}
641D CJK UNIFIED IDEOGRAPH-#641D, IRGKangXi=0447.090, RSKangXi=64.10
641E CJK UNIFIED IDEOGRAPH-#641E, IRGKangXi=0447.100, RSKangXi=64.10, Def{to clear, clarify}
641F CJK UNIFIED IDEOGRAPH-#641F, IRGKangXi=0447.110, RSKangXi=64.10
6420 CJK UNIFIED IDEOGRAPH-#6420, IRGKangXi=0447.120, RSKangXi=64.10, Def{to daub; to thrust}
6421 CJK UNIFIED IDEOGRAPH-#6421, IRGKangXi=0447.140, RSKangXi=64.10, Def{to push over or push back}
6422 CJK UNIFIED IDEOGRAPH-#6422, IRGKangXi=0447.150, RSKangXi=64.10, Def{to stick into; to shake}
6423 CJK UNIFIED IDEOGRAPH-#6423, IRGKangXi=0447.160, RSKangXi=64.10, Def{(Cant.) to tear, peel, twist with the fingers}
6424 CJK UNIFIED IDEOGRAPH-#6424, IRGKangXi=0447.180, RSKangXi=64.10, Def{seize}
6425 CJK UNIFIED IDEOGRAPH-#6425, IRGKangXi=0447.190, RSKangXi=64.10, Def{beat, pound, strike, throw; shampoo}
6426 CJK UNIFIED IDEOGRAPH-#6426, IRGKangXi=0447.210, RSKangXi=64.10, Def{grasp, seize, take in hand}
6427 CJK UNIFIED IDEOGRAPH-#6427, IRGKangXi=0447.230, RSKangXi=64.10, Def{fan; strike on face; stir up}
6428 CJK UNIFIED IDEOGRAPH-#6428, IRGKangXi=0447.240, RSKangXi=64.10, Def{rub, make rubbings of inscription}
6429 CJK UNIFIED IDEOGRAPH-#6429, IRGKangXi=0447.250, RSKangXi=64.10
642A CJK UNIFIED IDEOGRAPH-#642A, IRGKangXi=0448.010, RSKangXi=64.10, Def{ward off, evade; parry; block}
642B CJK UNIFIED IDEOGRAPH-#642B, IRGKangXi=0448.020, RSKangXi=64.10
642C CJK UNIFIED IDEOGRAPH-#642C, IRGKangXi=0448.030, RSKangXi=64.10, Def{transfer, move, remove, shift}
642D CJK UNIFIED IDEOGRAPH-#642D, IRGKangXi=0448.040, RSKangXi=64.10, Def{join together, attach to; add to}
642E CJK UNIFIED IDEOGRAPH-#642E, IRGKangXi=0448.050, RSKangXi=64.10
642F CJK UNIFIED IDEOGRAPH-#642F, IRGKangXi=0448.060, RSKangXi=64.10, Def{take out, pull out}
6430 CJK UNIFIED IDEOGRAPH-#6430, IRGKangXi=0448.070, RSKangXi=64.10, Def{dig; turbid; exert; (Cant.) to shake}
6431 CJK UNIFIED IDEOGRAPH-#6431, IRGKangXi=0448.110, RSKangXi=64.12
6432 CJK UNIFIED IDEOGRAPH-#6432, IRGKangXi=0448.120, RSKangXi=64.10, Def{to seize, to grasp}
6433 CJK UNIFIED IDEOGRAPH-#6433, IRGKangXi=0448.130, RSKangXi=64.10
6434 CJK UNIFIED IDEOGRAPH-#6434, IRGKangXi=0448.150, RSKangXi=64.10, Def{extract; seize; pluck up}
6435 CJK UNIFIED IDEOGRAPH-#6435, IRGKangXi=0448.160, RSKangXi=64.10, Def{wipe off; press down with knuckle; to immerse; (Cant.) to search, look for}
6436 CJK UNIFIED IDEOGRAPH-#6436, IRGKangXi=0448.220, RSKangXi=64.10, Def{plunder, rob, take by force}
6437 CJK UNIFIED IDEOGRAPH-#6437, IRGKangXi=0448.230, RSKangXi=64.10, Def{to beat; to winnow}
6438 CJK UNIFIED IDEOGRAPH-#6438, IRGKangXi=0448.240
6439 CJK UNIFIED IDEOGRAPH-#6439, IRGKangXi=0448.250, RSKangXi=64.10
643A CJK UNIFIED IDEOGRAPH-#643A, IRGKangXi=0448.260, RSKangXi=64.10, Def{lead by hand, take with; carry}
643B CJK UNIFIED IDEOGRAPH-#643B, IRGKangXi=0448.310, RSKangXi=64.10
643C CJK UNIFIED IDEOGRAPH-#643C, IRGKangXi=0449.030, RSKangXi=64.10
643D CJK UNIFIED IDEOGRAPH-#643D, IRGKangXi=0449.081, RSKangXi=64.10, Def{smear; rub, wipe; anoint}
643E CJK UNIFIED IDEOGRAPH-#643E, IRGKangXi=0449.081, RSKangXi=64.10, Def{to crush with the hand, press, squeeze, extract}
643F CJK UNIFIED IDEOGRAPH-#643F, IRGKangXi=0449.081, RSKangXi=64.10
6440 CJK UNIFIED IDEOGRAPH-#6440, IRGKangXi=0449.081, RSKangXi=64.10, Def{to cover with the hand; to hide}
6441 CJK UNIFIED IDEOGRAPH-#6441, IRGKangXi=0449.081, RSKangXi=64.10, Def{to press with the hand}
6442 CJK UNIFIED IDEOGRAPH-#6442, IRGKangXi=0449.081, RSKangXi=64.10, Def{take in, absorb; act as deputy}
6443 CJK UNIFIED IDEOGRAPH-#6443, IRGKangXi=0449.081, RSKangXi=64.10
6444 CJK UNIFIED IDEOGRAPH-#6444, IRGKangXi=0449.081, RSKangXi=64.10, Def{take in, absorb; act as deputy}
6445 CJK UNIFIED IDEOGRAPH-#6445, IRGKangXi=0449.081, RSKangXi=64.10, Def{spread, disperse; vent, set forth}
6446 CJK UNIFIED IDEOGRAPH-#6446, IRGKangXi=0449.081, RSKangXi=64.10, Def{put, place; display; swing, sway}
6447 CJK UNIFIED IDEOGRAPH-#6447, IRGKangXi=0449.081, RSKangXi=64.10, Def{wag, swing, wave; shake; scull}
6448 CJK UNIFIED IDEOGRAPH-#6448, IRGKangXi=0449.081, RSKangXi=64.10, Def{exclude, expel, reject; usher}
6449 CJK UNIFIED IDEOGRAPH-#6449, IRGKangXi=0449.081
644A CJK UNIFIED IDEOGRAPH-#644A, IRGKangXi=0449.081, RSKangXi=64.10, Def{spread out, open; apportion}
644B CJK UNIFIED IDEOGRAPH-#644B, IRGKangXi=0449.090, RSKangXi=64.11
644C CJK UNIFIED IDEOGRAPH-#644C, IRGKangXi=0449.120, RSKangXi=64.11
644D CJK UNIFIED IDEOGRAPH-#644D, IRGKangXi=0449.130, RSKangXi=64.11
644E CJK UNIFIED IDEOGRAPH-#644E, IRGKangXi=0449.140, RSKangXi=64.11, Def{to strangle; to inquire into}
644F CJK UNIFIED IDEOGRAPH-#644F, IRGKangXi=0449.150, RSKangXi=64.11, Def{pound; strike against; ram; (Cant.) to hit with the elbow}
6450 CJK UNIFIED IDEOGRAPH-#6450, IRGKangXi=0449.160, RSKangXi=64.11, Def{to hit (a bell or drum)}
6451 CJK UNIFIED IDEOGRAPH-#6451, IRGKangXi=0449.220, RSKangXi=64.11, Def{box one's ears, slap}
6452 CJK UNIFIED IDEOGRAPH-#6452, IRGKangXi=0449.250, RSKangXi=64.11, Def{expel, cast off; arrange}
6453 CJK UNIFIED IDEOGRAPH-#6453, IRGKangXi=0449.260, RSKangXi=64.11
6454 CJK UNIFIED IDEOGRAPH-#6454, IRGKangXi=0449.270, RSKangXi=64.11, Def{fall ground, stumble, trip}
6455 CJK UNIFIED IDEOGRAPH-#6455, IRGKangXi=0449.280, RSKangXi=64.11, Def{(Cant.) to hit}
6456 CJK UNIFIED IDEOGRAPH-#6456, IRGKangXi=0449.290, RSKangXi=64.12
6457 CJK UNIFIED IDEOGRAPH-#6457, IRGKangXi=0449.300, RSKangXi=64.11
6458 CJK UNIFIED IDEOGRAPH-#6458, IRGKangXi=0449.320, RSKangXi=64.11, Def{pluck, pick; select; specify}
6459 CJK UNIFIED IDEOGRAPH-#6459, IRGKangXi=0449.340, RSKangXi=64.11, Def{to transport; to remove to take; (Cant.) to pinch; to tidy up}
645A CJK UNIFIED IDEOGRAPH-#645A, IRGKangXi=0449.360, RSKangXi=64.11, Def{(Cant.) to pull open (a drawer)}
645B CJK UNIFIED IDEOGRAPH-#645B, IRGKangXi=0450.010, RSKangXi=64.11, Def{to spread (name, news); to be known}
645C CJK UNIFIED IDEOGRAPH-#645C, IRGKangXi=0450.050, RSKangXi=64.11, Def{throw ground; know, be familiar}
645D CJK UNIFIED IDEOGRAPH-#645D, IRGKangXi=0450.070, RSKangXi=64.11
645E CJK UNIFIED IDEOGRAPH-#645E, IRGKangXi=0450.080, RSKangXi=64.11, Def{to pile up}
645F CJK UNIFIED IDEOGRAPH-#645F, IRGKangXi=0450.090, RSKangXi=64.11, Def{hug, embrace; drag, pull}
6460 CJK UNIFIED IDEOGRAPH-#6460, IRGKangXi=0450.100, RSKangXi=64.11, Def{general}
6461 CJK UNIFIED IDEOGRAPH-#6461, IRGKangXi=0450.110, RSKangXi=64.11, Def{to irrigate; to flood water flowing; to scour}
6462 CJK UNIFIED IDEOGRAPH-#6462, IRGKangXi=0450.140, RSKangXi=64.11
6463 CJK UNIFIED IDEOGRAPH-#6463, IRGKangXi=0450.150, RSKangXi=64.11, Def{a handful. to pick up with the fingers. to seize}
6464 CJK UNIFIED IDEOGRAPH-#6464, IRGKangXi=0450.170, RSKangXi=64.11
6465 CJK UNIFIED IDEOGRAPH-#6465, IRGKangXi=0450.210, RSKangXi=64.11
6466 CJK UNIFIED IDEOGRAPH-#6466, IRGKangXi=0450.220, RSKangXi=64.11, Def{wide}
6467 CJK UNIFIED IDEOGRAPH-#6467, IRGKangXi=0450.230, RSKangXi=64.11, Def{destroy, break, injure}
6468 CJK UNIFIED IDEOGRAPH-#6468, IRGKangXi=0450.240, RSKangXi=64.11
6469 CJK UNIFIED IDEOGRAPH-#6469, IRGKangXi=0450.280, RSKangXi=64.11, Def{rub, scour, grind; friction}
646A CJK UNIFIED IDEOGRAPH-#646A, IRGKangXi=0451.010, RSKangXi=64.11
646B CJK UNIFIED IDEOGRAPH-#646B, IRGKangXi=0451.080, RSKangXi=64.11
646C CJK UNIFIED IDEOGRAPH-#646C, IRGKangXi=0451.090, RSKangXi=64.11
646D CJK UNIFIED IDEOGRAPH-#646D, IRGKangXi=0451.100, RSKangXi=64.11, Def{pick up, gather}
646E CJK UNIFIED IDEOGRAPH-#646E, IRGKangXi=0451.120, RSKangXi=64.11, Def{to rattle; to shake. to smite}
646F CJK UNIFIED IDEOGRAPH-#646F, IRGKangXi=0451.180, RSKangXi=64.11, Def{sincere, warm, cordial; surname}
6470 CJK UNIFIED IDEOGRAPH-#6470, IRGKangXi=0451.190, RSKangXi=64.11, Def{to seize with the hand; to grasp; to advance; to break down}
6471 CJK UNIFIED IDEOGRAPH-#6471, IRGKangXi=0451.210, RSKangXi=64.11, Def{(Cant.) to climb, hold on to, cling to; to pull the trigger on a gun}
6472 CJK UNIFIED IDEOGRAPH-#6472, IRGKangXi=0451.230, RSKangXi=64.11, Def{raze}
6473 CJK UNIFIED IDEOGRAPH-#6473, IRGKangXi=0451.240, RSKangXi=64.11, Def{raise, lift up; tight-fisted}
6474 CJK UNIFIED IDEOGRAPH-#6474, IRGKangXi=0451.250, RSKangXi=64.11, Def{to stretch out, to unroll; comfortable, easy (used for U+8212 舒); 摴蒲 is the name of a traditional play}
6475 CJK UNIFIED IDEOGRAPH-#6475, IRGKangXi=0452.010, RSKangXi=64.11, Def{(Cant.) to pull, lift up}
6476 CJK UNIFIED IDEOGRAPH-#6476, IRGKangXi=0452.030, RSKangXi=64.11, Def{roll around with hand; model}
6477 CJK UNIFIED IDEOGRAPH-#6477, IRGKangXi=0452.040, RSKangXi=64.11, Def{(Cant.) to search for, look for; to beat up}
6478 CJK UNIFIED IDEOGRAPH-#6478, IRGKangXi=0452.050, RSKangXi=64.11, Def{gently touch with hand; caress}
6479 CJK UNIFIED IDEOGRAPH-#6479, IRGKangXi=0452.060, RSKangXi=64.11, Def{trace, copy, duplicate; pattern}
647A CJK UNIFIED IDEOGRAPH-#647A, IRGKangXi=0452.080, RSKangXi=64.11, Def{fold, bend; twisted, curved}
647B CJK UNIFIED IDEOGRAPH-#647B, IRGKangXi=0452.100, RSKangXi=64.11, Def{a delicate hand; mix, blend, adulterate}
647C CJK UNIFIED IDEOGRAPH-#647C, IRGKangXi=0452.110, RSKangXi=64.11, Def{(Cant.) to knock, hit}
647D CJK UNIFIED IDEOGRAPH-#647D, IRGKangXi=0452.120, RSKangXi=64.11, Def{throw out; push out; strike}
647E CJK UNIFIED IDEOGRAPH-#647E, IRGKangXi=0453.020, RSKangXi=64.11
647F CJK UNIFIED IDEOGRAPH-#647F, IRGKangXi=0453.060, RSKangXi=64.11
6480 CJK UNIFIED IDEOGRAPH-#6480, IRGKangXi=0453.120, RSKangXi=64.11
6481 CJK UNIFIED IDEOGRAPH-#6481, IRGKangXi=0453.191, RSKangXi=64.11
6482 CJK UNIFIED IDEOGRAPH-#6482, IRGKangXi=0453.191, RSKangXi=64.11, Def{put down, put aside; drop}
6483 CJK UNIFIED IDEOGRAPH-#6483, IRGKangXi=0453.191, RSKangXi=64.11, Def{strike, hit, beat; attack, fight}
6484 CJK UNIFIED IDEOGRAPH-#6484, IRGKangXi=0453.191, RSKangXi=64.11, Def{oppose, offend, run counter to}
6485 CJK UNIFIED IDEOGRAPH-#6485, IRGKangXi=0453.200, RSKangXi=64.12, Def{protrude; snap, break; dig}
6486 CJK UNIFIED IDEOGRAPH-#6486, IRGKangXi=0453.210, RSKangXi=64.12, Def{to skim off, cast away}
6487 CJK UNIFIED IDEOGRAPH-#6487, IRGKangXi=0453.220, RSKangXi=64.12, Def{discard, abandon, throw away}
6488 CJK UNIFIED IDEOGRAPH-#6488, IRGKangXi=0453.230, RSKangXi=64.12, Def{scoop out of water; dredge, fish}
6489 CJK UNIFIED IDEOGRAPH-#6489, IRGKangXi=0453.240, RSKangXi=64.12
648A CJK UNIFIED IDEOGRAPH-#648A, IRGKangXi=0453.260, RSKangXi=64.12, Def{fierce; wrathful}
648B CJK UNIFIED IDEOGRAPH-#648B, IRGKangXi=0453.270, RSKangXi=64.12, Def{to rub between the hands}
648C CJK UNIFIED IDEOGRAPH-#648C, IRGKangXi=0453.290, RSKangXi=64.12
648D CJK UNIFIED IDEOGRAPH-#648D, IRGKangXi=0453.310, RSKangXi=64.12, Def{to hold in the hand, to grasp; to wring; (Cant.) to pull out}
648E CJK UNIFIED IDEOGRAPH-#648E, IRGKangXi=0453.340, RSKangXi=64.12
648F CJK UNIFIED IDEOGRAPH-#648F, IRGKangXi=0454.010, RSKangXi=64.12, Def{pull out, pluck; take hold of}
6490 CJK UNIFIED IDEOGRAPH-#6490, IRGKangXi=0454.030, RSKangXi=64.12, Def{prop up, support; brace; to push off (with a pole)}
6491 CJK UNIFIED IDEOGRAPH-#6491, IRGKangXi=0454.040, RSKangXi=64.12, Def{prop up, support; brace}
6492 CJK UNIFIED IDEOGRAPH-#6492, IRGKangXi=0454.070, RSKangXi=64.12, Def{release, cast away, let go; disperse; relax}
6493 CJK UNIFIED IDEOGRAPH-#6493, IRGKangXi=0454.080, RSKangXi=64.12, Def{scratch; disturb, bother; submit}
6494 CJK UNIFIED IDEOGRAPH-#6494, IRGKangXi=0454.100, RSKangXi=64.12
6495 CJK UNIFIED IDEOGRAPH-#6495, IRGKangXi=0454.150, RSKangXi=64.12, Def{rip, tear; buy cloth}
6496 CJK UNIFIED IDEOGRAPH-#6496, IRGKangXi=0454.190, RSKangXi=64.12
6497 CJK UNIFIED IDEOGRAPH-#6497, IRGKangXi=0454.200, RSKangXi=64.12
6498 CJK UNIFIED IDEOGRAPH-#6498, IRGKangXi=0454.210, RSKangXi=64.12, Def{(Cant.) to strike, pound}
6499 CJK UNIFIED IDEOGRAPH-#6499, IRGKangXi=0454.220, RSKangXi=64.12, Def{economize; abide by, comply with}
649A CJK UNIFIED IDEOGRAPH-#649A, IRGKangXi=0454.230, RSKangXi=64.12, Def{twirl in fingers, tease, toy with}
649B CJK UNIFIED IDEOGRAPH-#649B, IRGKangXi=0454.240, RSKangXi=64.12
649C CJK UNIFIED IDEOGRAPH-#649C, IRGKangXi=0454.250, RSKangXi=64.12
649D CJK UNIFIED IDEOGRAPH-#649D, IRGKangXi=0454.260, RSKangXi=64.12, Def{wave, brandish; modest, humble}
649E CJK UNIFIED IDEOGRAPH-#649E, IRGKangXi=0455.010, RSKangXi=64.12, Def{knock against, bump into, collide}
649F CJK UNIFIED IDEOGRAPH-#649F, IRGKangXi=0455.030, RSKangXi=64.12, Def{correct; to bend or twist; to feign; to raise (the hand)}
64A0 CJK UNIFIED IDEOGRAPH-#64A0, IRGKangXi=0455.040, RSKangXi=64.12
64A1 CJK UNIFIED IDEOGRAPH-#64A1, IRGKangXi=0455.070, RSKangXi=64.12
64A2 CJK UNIFIED IDEOGRAPH-#64A2, IRGKangXi=0455.080, RSKangXi=64.12, Def{to dust; a duster}
64A3 CJK UNIFIED IDEOGRAPH-#64A3, IRGKangXi=0455.090, RSKangXi=64.12, Def{to dust; a duster}
64A4 CJK UNIFIED IDEOGRAPH-#64A4, IRGKangXi=0455.100, RSKangXi=64.12, Def{omit; remove; withdraw}
64A5 CJK UNIFIED IDEOGRAPH-#64A5, IRGKangXi=0455.110, RSKangXi=64.12, Def{move; dispel; distribute; plectrum, play stringed instrument}
64A6 CJK UNIFIED IDEOGRAPH-#64A6, IRGKangXi=0455.120, RSKangXi=64.12, Def{rip up, tear down; raise; haul}
64A7 CJK UNIFIED IDEOGRAPH-#64A7, IRGKangXi=0455.130, RSKangXi=64.12
64A8 CJK UNIFIED IDEOGRAPH-#64A8, IRGKangXi=0456.020, RSKangXi=64.12
64A9 CJK UNIFIED IDEOGRAPH-#64A9, IRGKangXi=0456.070, RSKangXi=64.12, Def{lift up, raise; leave, depart}
64AA CJK UNIFIED IDEOGRAPH-#64AA, IRGKangXi=0456.080, RSKangXi=64.12
64AB CJK UNIFIED IDEOGRAPH-#64AB, IRGKangXi=0456.090, RSKangXi=64.12, Def{pat, console, comfort; pacify}
64AC CJK UNIFIED IDEOGRAPH-#64AC, IRGKangXi=0456.140, RSKangXi=64.12, Def{lift, raise; pry open}
64AD CJK UNIFIED IDEOGRAPH-#64AD, IRGKangXi=0456.150, RSKangXi=64.12, Def{sow, spread; broadcast; cast away, reject}
64AE CJK UNIFIED IDEOGRAPH-#64AE, IRGKangXi=0456.180, RSKangXi=64.12, Def{little bit, small amount, pinch}
64AF CJK UNIFIED IDEOGRAPH-#64AF, IRGKangXi=0456.220, RSKangXi=64.12
64B0 CJK UNIFIED IDEOGRAPH-#64B0, IRGKangXi=0456.230, RSKangXi=64.12, Def{compose, write, compile}
64B1 CJK UNIFIED IDEOGRAPH-#64B1, IRGKangXi=0457.010, RSKangXi=64.12, Def{to shorten, to clip; to throw away}
64B2 CJK UNIFIED IDEOGRAPH-#64B2, IRGKangXi=0457.020, RSKangXi=64.12, Def{pound, beat, strike; attack}
64B3 CJK UNIFIED IDEOGRAPH-#64B3, IRGKangXi=0457.161, RSKangXi=64.12, Def{press; push}
64B4 CJK UNIFIED IDEOGRAPH-#64B4, IRGKangXi=0457.161, RSKangXi=64.12, Def{to jolt; to thump}
64B5 CJK UNIFIED IDEOGRAPH-#64B5, IRGKangXi=0457.161, RSKangXi=64.12, Def{drive away, expel, oust}
64B6 CJK UNIFIED IDEOGRAPH-#64B6, IRGKangXi=0457.161, RSKangXi=64.12
64B7 CJK UNIFIED IDEOGRAPH-#64B7, IRGKangXi=0457.161, RSKangXi=64.12, Def{pick up, gather up; hold in lap}
64B8 CJK UNIFIED IDEOGRAPH-#64B8, IRGKangXi=0457.161, RSKangXi=64.12
64B9 CJK UNIFIED IDEOGRAPH-#64B9, IRGKangXi=0457.161, RSKangXi=64.12, Def{disturb, agitate, stir up}
64BA CJK UNIFIED IDEOGRAPH-#64BA, IRGKangXi=0457.161, RSKangXi=64.12, Def{hurry; to throw; to urge}
64BB CJK UNIFIED IDEOGRAPH-#64BB, IRGKangXi=0457.170, RSKangXi=64.13, Def{flog, whip; chastise; (Cant.) classifier for places; a tart (from the English 'tart')}
64BC CJK UNIFIED IDEOGRAPH-#64BC, IRGKangXi=0457.200, RSKangXi=64.13, Def{move, shake; (Cant.) to fight}
64BD CJK UNIFIED IDEOGRAPH-#64BD, IRGKangXi=0457.210, RSKangXi=64.13
64BE CJK UNIFIED IDEOGRAPH-#64BE, IRGKangXi=0457.230, RSKangXi=64.13, Def{to beat; to strike}
64BF CJK UNIFIED IDEOGRAPH-#64BF, IRGKangXi=0457.240, RSKangXi=64.13, Def{to pick up}
64C0 CJK UNIFIED IDEOGRAPH-#64C0, IRGKangXi=0457.250, RSKangXi=64.13, Def{roll flat}
64C1 CJK UNIFIED IDEOGRAPH-#64C1, IRGKangXi=0457.260, RSKangXi=64.13, Def{embrace, hug, squeeze; crowd}
64C2 CJK UNIFIED IDEOGRAPH-#64C2, IRGKangXi=0457.270, RSKangXi=64.13, Def{rub, grind; grind with a mortar and pestle; triturate}
64C3 CJK UNIFIED IDEOGRAPH-#64C3, IRGKangXi=0457.300, RSKangXi=64.13, Def{to ward off; to stab, prick}
64C4 CJK UNIFIED IDEOGRAPH-#64C4, IRGKangXi=0457.310, RSKangXi=64.13, Def{capture, seize}
64C5 CJK UNIFIED IDEOGRAPH-#64C5, IRGKangXi=0457.340, RSKangXi=64.13, Def{monopolize; claim; arbitrarily; to dare}
64C6 CJK UNIFIED IDEOGRAPH-#64C6, IRGKangXi=0458.040, RSKangXi=64.12
64C7 CJK UNIFIED IDEOGRAPH-#64C7, IRGKangXi=0458.050, RSKangXi=64.13, Def{select, choose, pick out}
64C8 CJK UNIFIED IDEOGRAPH-#64C8, IRGKangXi=0458.060, RSKangXi=64.13
64C9 CJK UNIFIED IDEOGRAPH-#64C9, IRGKangXi=0458.080, RSKangXi=64.13, Def{to pierce; to break through}
64CA CJK UNIFIED IDEOGRAPH-#64CA, IRGKangXi=0458.090, RSKangXi=64.13, Def{strike, hit, beat; attack, fight}
64CB CJK UNIFIED IDEOGRAPH-#64CB, IRGKangXi=0458.110, RSKangXi=64.13, Def{obstruct, impede; stop; resist}
64CC CJK UNIFIED IDEOGRAPH-#64CC, IRGKangXi=0458.120, RSKangXi=64.13
64CD CJK UNIFIED IDEOGRAPH-#64CD, IRGKangXi=0458.150, RSKangXi=64.13, Def{conduct, run, control, manage}
64CE CJK UNIFIED IDEOGRAPH-#64CE, IRGKangXi=0458.170, RSKangXi=64.13, Def{lift up, hold up, support}
64CF CJK UNIFIED IDEOGRAPH-#64CF, IRGKangXi=0458.180, RSKangXi=64.13, Def{(Cant.) to guard against, take precautions}
64D0 CJK UNIFIED IDEOGRAPH-#64D0, IRGKangXi=0458.220, RSKangXi=64.13, Def{to put on}
64D1 CJK UNIFIED IDEOGRAPH-#64D1, IRGKangXi=0458.240, RSKangXi=64.13
64D2 CJK UNIFIED IDEOGRAPH-#64D2, IRGKangXi=0458.250, RSKangXi=64.13, Def{catch, capture, seize, arrest}
64D3 CJK UNIFIED IDEOGRAPH-#64D3, IRGKangXi=0458.320, RSKangXi=64.13, Def{to rub, to scratch}
64D4 CJK UNIFIED IDEOGRAPH-#64D4, IRGKangXi=0459.010, RSKangXi=64.13, Def{carry, bear, undertake}
64D5 CJK UNIFIED IDEOGRAPH-#64D5, IRGKangXi=0459.040, RSKangXi=64.13
64D6 CJK UNIFIED IDEOGRAPH-#64D6, IRGKangXi=0459.060, RSKangXi=64.13, Def{scrape}
64D7 CJK UNIFIED IDEOGRAPH-#64D7, IRGKangXi=0459.070, RSKangXi=64.13, Def{to beat the breast}
64D8 CJK UNIFIED IDEOGRAPH-#64D8, IRGKangXi=0459.080, RSKangXi=64.13, Def{thumb; break, tear open, rip}
64D9 CJK UNIFIED IDEOGRAPH-#64D9, IRGKangXi=0459.110, RSKangXi=64.13, Def{to reach}
64DA CJK UNIFIED IDEOGRAPH-#64DA, IRGKangXi=0459.120, RSKangXi=64.13, Def{to occupy, take possession of; a base}
64DB CJK UNIFIED IDEOGRAPH-#64DB, IRGKangXi=0459.160, RSKangXi=64.13
64DC CJK UNIFIED IDEOGRAPH-#64DC, IRGKangXi=0459.201, RSKangXi=64.13
64DD CJK UNIFIED IDEOGRAPH-#64DD, IRGKangXi=0459.201, RSKangXi=64.13, Def{(Cant.) to pull; to stretch; to pluck}
64DE CJK UNIFIED IDEOGRAPH-#64DE, IRGKangXi=0459.201, RSKangXi=64.13, Def{shake, tremble, quake; flutter}
64DF CJK UNIFIED IDEOGRAPH-#64DF, IRGKangXi=0459.220, RSKangXi=64.14
64E0 CJK UNIFIED IDEOGRAPH-#64E0, IRGKangXi=0459.230, RSKangXi=64.14, Def{crowd, squeeze, push against}
64E1 CJK UNIFIED IDEOGRAPH-#64E1, IRGKangXi=0459.260, RSKangXi=64.14, Def{carry, raise, lift}
64E2 CJK UNIFIED IDEOGRAPH-#64E2, IRGKangXi=0459.270, RSKangXi=64.14, Def{pull up, draw up; select}
64E3 CJK UNIFIED IDEOGRAPH-#64E3, IRGKangXi=0459.280, RSKangXi=64.14, Def{hull; thresh; beat, attack}
64E4 CJK UNIFIED IDEOGRAPH-#64E4, IRGKangXi=0460.040, RSKangXi=64.14, Def{to blow the nose with fingers}
64E5 CJK UNIFIED IDEOGRAPH-#64E5, IRGKangXi=0460.060, RSKangXi=64.15, Def{drive away, expel, oust}
64E6 CJK UNIFIED IDEOGRAPH-#64E6, IRGKangXi=0460.090, RSKangXi=64.14, Def{wipe, scrub, rub, scour; brush}
64E7 CJK UNIFIED IDEOGRAPH-#64E7, IRGKangXi=0460.100, RSKangXi=64.14, Def{raise, lift up; recommend}
64E8 CJK UNIFIED IDEOGRAPH-#64E8, IRGKangXi=0460.120, RSKangXi=64.14
64E9 CJK UNIFIED IDEOGRAPH-#64E9, IRGKangXi=0460.130, RSKangXi=64.14, Def{to stain, to dye}
64EA CJK UNIFIED IDEOGRAPH-#64EA, IRGKangXi=0460.140, RSKangXi=64.14, Def{to tuck in, to put the finger into, to put in, to stow away}
64EB CJK UNIFIED IDEOGRAPH-#64EB, IRGKangXi=0460.150, RSKangXi=64.14, Def{tuck; hold}
64EC CJK UNIFIED IDEOGRAPH-#64EC, IRGKangXi=0460.170, RSKangXi=64.14, Def{draft; intend, plan, propose}
64ED CJK UNIFIED IDEOGRAPH-#64ED, IRGKangXi=0460.230, RSKangXi=64.14, Def{trap catch animals, snare; seize}
64EE CJK UNIFIED IDEOGRAPH-#64EE, IRGKangXi=0460.260, RSKangXi=64.14
64EF CJK UNIFIED IDEOGRAPH-#64EF, IRGKangXi=0460.270, RSKangXi=64.14, Def{exclude, expel, reject; usher}
64F0 CJK UNIFIED IDEOGRAPH-#64F0, IRGKangXi=0460.300, RSKangXi=64.14, Def{pinch; twist, wring; determined}
64F1 CJK UNIFIED IDEOGRAPH-#64F1, IRGKangXi=0461.011, RSKangXi=64.14, Def{place, put, lay down; delay}
64F2 CJK UNIFIED IDEOGRAPH-#64F2, IRGKangXi=0461.020, RSKangXi=64.15, Def{throw (down), hurl, cast, fling}
64F3 CJK UNIFIED IDEOGRAPH-#64F3, IRGKangXi=0461.030, RSKangXi=64.15, Def{(Cant.) to squeeze out; tickle}
64F4 CJK UNIFIED IDEOGRAPH-#64F4, IRGKangXi=0461.040, RSKangXi=64.15, Def{expand, enlarge, stretch}
64F5 CJK UNIFIED IDEOGRAPH-#64F5, IRGKangXi=0461.060, RSKangXi=64.15, Def{to touch, feel with the hand}
64F6 CJK UNIFIED IDEOGRAPH-#64F6, IRGKangXi=0461.070, RSKangXi=64.15
64F7 CJK UNIFIED IDEOGRAPH-#64F7, IRGKangXi=0461.090, RSKangXi=64.15, Def{pick up, gather up; hold in lap}
64F8 CJK UNIFIED IDEOGRAPH-#64F8, IRGKangXi=0461.110, RSKangXi=64.15, Def{to hold, to grasp; to hold the hair; to pull at; (Cant.) to glance}
64F9 CJK UNIFIED IDEOGRAPH-#64F9, IRGKangXi=0461.160, RSKangXi=64.15
64FA CJK UNIFIED IDEOGRAPH-#64FA, IRGKangXi=0461.190, RSKangXi=64.15, Def{put, place; display; swing, sway}
64FB CJK UNIFIED IDEOGRAPH-#64FB, IRGKangXi=0461.200, RSKangXi=64.15, Def{shake, tremble, quake; flutter}
64FC CJK UNIFIED IDEOGRAPH-#64FC, IRGKangXi=0461.210, RSKangXi=64.15
64FD CJK UNIFIED IDEOGRAPH-#64FD, IRGKangXi=0461.270, RSKangXi=64.15, Def{tickle; ticklish, funny}
64FE CJK UNIFIED IDEOGRAPH-#64FE, IRGKangXi=0461.280, RSKangXi=64.15, Def{disturb, annoy, agitate}
64FF CJK UNIFIED IDEOGRAPH-#64FF, IRGKangXi=0461.300, RSKangXi=64.15, Def{to select, to pick out from, to discard}
6500 CJK UNIFIED IDEOGRAPH-#6500, IRGKangXi=0461.340, RSKangXi=64.15, Def{climb; pull; hang on to}
6501 CJK UNIFIED IDEOGRAPH-#6501, IRGKangXi=0461.350, RSKangXi=64.15
6502 CJK UNIFIED IDEOGRAPH-#6502, IRGKangXi=0461.360, RSKangXi=64.15, Def{to beat a drum}
6503 CJK UNIFIED IDEOGRAPH-#6503, IRGKangXi=0462.020, RSKangXi=64.15, Def{preceding}
6504 CJK UNIFIED IDEOGRAPH-#6504, IRGKangXi=0462.030, RSKangXi=64.15, Def{spread, disperse; vent, set forth}
6505 CJK UNIFIED IDEOGRAPH-#6505, IRGKangXi=0462.040, RSKangXi=64.15, Def{save, hoard}
6506 CJK UNIFIED IDEOGRAPH-#6506, IRGKangXi=0462.161, RSKangXi=64.15, Def{drive away, expel, oust}
6507 CJK UNIFIED IDEOGRAPH-#6507, IRGKangXi=0462.180, RSKangXi=64.16
6508 CJK UNIFIED IDEOGRAPH-#6508, IRGKangXi=0462.210, RSKangXi=64.16
6509 CJK UNIFIED IDEOGRAPH-#6509, IRGKangXi=0462.230, RSKangXi=64.16, Def{to beckon; to urge}
650A CJK UNIFIED IDEOGRAPH-#650A, IRGKangXi=0462.280, RSKangXi=64.16
650B CJK UNIFIED IDEOGRAPH-#650B, IRGKangXi=0462.320, RSKangXi=64.16, Def{to clutch; to grab at; to rub or scrape; to tear; (Cant.) to leave behind, omit}
650C CJK UNIFIED IDEOGRAPH-#650C, IRGKangXi=0462.330, RSKangXi=64.16
650D CJK UNIFIED IDEOGRAPH-#650D, IRGKangXi=0462.340, RSKangXi=64.16
650E CJK UNIFIED IDEOGRAPH-#650E, IRGKangXi=0462.360, RSKangXi=64.16
650F CJK UNIFIED IDEOGRAPH-#650F, IRGKangXi=0462.380, RSKangXi=64.16, Def{collect, bring together}
6510 CJK UNIFIED IDEOGRAPH-#6510, IRGKangXi=0462.390, RSKangXi=64.16
6511 CJK UNIFIED IDEOGRAPH-#6511, IRGKangXi=0463.211, RSKangXi=64.17
6512 CJK UNIFIED IDEOGRAPH-#6512, IRGKangXi=0462.461, RSKangXi=64.16, Def{save, hoard}
6513 CJK UNIFIED IDEOGRAPH-#6513, IRGKangXi=0462.470, RSKangXi=64.17
6514 CJK UNIFIED IDEOGRAPH-#6514, IRGKangXi=0462.480, RSKangXi=64.17, Def{obstruct, impede, bar, hinder}
6515 CJK UNIFIED IDEOGRAPH-#6515, IRGKangXi=0462.500, RSKangXi=64.17
6516 CJK UNIFIED IDEOGRAPH-#6516, IRGKangXi=0463.080, RSKangXi=64.17, Def{oppose, offend, run counter to}
6517 CJK UNIFIED IDEOGRAPH-#6517, IRGKangXi=0463.090, RSKangXi=64.17
6518 CJK UNIFIED IDEOGRAPH-#6518, IRGKangXi=0463.110, RSKangXi=64.17, Def{seize, take by force; repel}
6519 CJK UNIFIED IDEOGRAPH-#6519, IRGKangXi=0463.140, RSKangXi=64.17, Def{to give a helping hand; to support, hold up}
651A CJK UNIFIED IDEOGRAPH-#651A, IRGKangXi=0463.211, RSKangXi=64.17
651B CJK UNIFIED IDEOGRAPH-#651B, IRGKangXi=0463.270, RSKangXi=64.18, Def{hurry; to throw; to urge; (Cant.) to seduce}
651C CJK UNIFIED IDEOGRAPH-#651C, IRGKangXi=0463.310, RSKangXi=64.18, Def{lead by hand, take with; carry}
651D CJK UNIFIED IDEOGRAPH-#651D, IRGKangXi=0463.330, RSKangXi=64.18, Def{take in, absorb; act as deputy; administer, assist}
651E CJK UNIFIED IDEOGRAPH-#651E, IRGKangXi=0464.090, RSKangXi=64.19, Def{to split, to rend; to choose to rub, to wipe}
651F CJK UNIFIED IDEOGRAPH-#651F, IRGKangXi=0464.100, RSKangXi=64.19
6520 CJK UNIFIED IDEOGRAPH-#6520, IRGKangXi=0464.110, RSKangXi=64.19
6521 CJK UNIFIED IDEOGRAPH-#6521, IRGKangXi=0464.120, RSKangXi=64.19
6522 CJK UNIFIED IDEOGRAPH-#6522, IRGKangXi=0464.160, RSKangXi=64.19, Def{save, hoard}
6523 CJK UNIFIED IDEOGRAPH-#6523, IRGKangXi=0464.180, RSKangXi=64.19, Def{tangled; entwined; crooked}
6524 CJK UNIFIED IDEOGRAPH-#6524, IRGKangXi=0464.190, RSKangXi=64.19, Def{spread out, open; apportion}
6525 CJK UNIFIED IDEOGRAPH-#6525, IRGKangXi=0464.200, RSKangXi=64.20, Def{(coll.) hold; grip; grasp}
6526 CJK UNIFIED IDEOGRAPH-#6526, IRGKangXi=0464.220, RSKangXi=64.19
6527 CJK UNIFIED IDEOGRAPH-#6527, IRGKangXi=0464.251, RSKangXi=64.19
6528 CJK UNIFIED IDEOGRAPH-#6528, IRGKangXi=0464.260, RSKangXi=64.20
6529 CJK UNIFIED IDEOGRAPH-#6529, IRGKangXi=0464.270, RSKangXi=64.20, Def{obstruct, impede; stop; resist}
652A CJK UNIFIED IDEOGRAPH-#652A, IRGKangXi=0465.010, RSKangXi=64.20, Def{disturb, agitate, stir up}
652B CJK UNIFIED IDEOGRAPH-#652B, IRGKangXi=0465.030, RSKangXi=64.20, Def{snatch away, seize; catch with}
652C CJK UNIFIED IDEOGRAPH-#652C, IRGKangXi=0465.060, RSKangXi=64.21, Def{grasp, take hold of; monopolize}
652D CJK UNIFIED IDEOGRAPH-#652D, IRGKangXi=0465.120, RSKangXi=64.21
652E CJK UNIFIED IDEOGRAPH-#652E, IRGKangXi=0465.140, RSKangXi=64.22, Def{to fend off; to stab}
652F CJK UNIFIED IDEOGRAPH-#652F, IRGKangXi=0467.010, RSKangXi=65.0, Def{disperse, pay; support; branch}
6530 CJK UNIFIED IDEOGRAPH-#6530, IRGKangXi=0467.050, RSKangXi=19.4, Def{totally exhausted}
6531 CJK UNIFIED IDEOGRAPH-#6531, IRGKangXi=0467.090, RSKangXi=65.5
6532 CJK UNIFIED IDEOGRAPH-#6532, IRGKangXi=0467.210, RSKangXi=65.8, Def{up; uneven}
6533 CJK UNIFIED IDEOGRAPH-#6533, IRGKangXi=0467.250, RSKangXi=65.12
6534 CJK UNIFIED IDEOGRAPH-#6534, IRGKangXi=0468.040, RSKangXi=66.0, Def{rap, tap lightly; KangXi radical 66}
6535 CJK UNIFIED IDEOGRAPH-#6535, IRGKangXi=0468.050, RSKangXi=66.0, Def{rap, tap; radical number 66}
6536 CJK UNIFIED IDEOGRAPH-#6536, IRGKangXi=0468.060, RSKangXi=66.2, Def{gather together, collect; harvest}
6537 CJK UNIFIED IDEOGRAPH-#6537, IRGKangXi=0468.080, RSKangXi=66.2, Def{examine, test; investigate}
6538 CJK UNIFIED IDEOGRAPH-#6538, IRGKangXi=0468.100, RSKangXi=66.3, Def{distant, far; adverbial prefix}
6539 CJK UNIFIED IDEOGRAPH-#6539, IRGKangXi=0468.110, RSKangXi=66.3, Def{change, alter; improve, remodel}
653A CJK UNIFIED IDEOGRAPH-#653A, IRGKangXi=0468.120, RSKangXi=66.3
653B CJK UNIFIED IDEOGRAPH-#653B, IRGKangXi=0468.160, RSKangXi=66.3, Def{attack, assault; criticize}
653C CJK UNIFIED IDEOGRAPH-#653C, IRGKangXi=0468.180, RSKangXi=66.3
653D CJK UNIFIED IDEOGRAPH-#653D, IRGKangXi=0468.210, RSKangXi=66.4
653E CJK UNIFIED IDEOGRAPH-#653E, IRGKangXi=0469.030, RSKangXi=66.4, Def{put, release, free, liberate}
653F CJK UNIFIED IDEOGRAPH-#653F, IRGKangXi=0469.060, RSKangXi=66.4, Def{government, political affairs}
6540 CJK UNIFIED IDEOGRAPH-#6540, IRGKangXi=0469.180, RSKangXi=66.5
6541 CJK UNIFIED IDEOGRAPH-#6541, IRGKangXi=0469.190, RSKangXi=66.5, Def{to weigh in the hand, to estimate; to shake}
6542 CJK UNIFIED IDEOGRAPH-#6542, IRGKangXi=0469.200, RSKangXi=66.5, Def{deduct}
6543 CJK UNIFIED IDEOGRAPH-#6543, IRGKangXi=0469.230, RSKangXi=66.5, Def{strong; robust; vigorous}
6544 CJK UNIFIED IDEOGRAPH-#6544, IRGKangXi=0469.240, RSKangXi=66.5, Def{to put forth effort}
6545 CJK UNIFIED IDEOGRAPH-#6545, IRGKangXi=0469.250, RSKangXi=66.5, Def{ancient, old; reason, because}
6546 CJK UNIFIED IDEOGRAPH-#6546, IRGKangXi=0470.080, RSKangXi=66.6
6547 CJK UNIFIED IDEOGRAPH-#6547, IRGKangXi=0470.100, RSKangXi=66.6
6548 CJK UNIFIED IDEOGRAPH-#6548, IRGKangXi=0470.210, RSKangXi=66.6, Def{result, effect; effectiveness}
6549 CJK UNIFIED IDEOGRAPH-#6549, IRGKangXi=0470.260, RSKangXi=66.6, Def{pacify, soothe, stabilize}
654A CJK UNIFIED IDEOGRAPH-#654A, IRGKangXi=0470.270, RSKangXi=66.6
654B CJK UNIFIED IDEOGRAPH-#654B, IRGKangXi=0470.291, RSKangXi=66.6, Def{to strike}
654C CJK UNIFIED IDEOGRAPH-#654C, IRGKangXi=1007.050, RSKangXi=135.4, Def{enemy, foe, rival; resist}
654D CJK UNIFIED IDEOGRAPH-#654D, IRGKangXi=0470.320, RSKangXi=66.7, Def{express, state, relate, narrate}
654E CJK UNIFIED IDEOGRAPH-#654E, IRGKangXi=0470.380, RSKangXi=66.7, Def{teach}
654F CJK UNIFIED IDEOGRAPH-#654F, IRGKangXi=0471.040, RSKangXi=66.7, Def{fast, quick, clever, smart}
6550 CJK UNIFIED IDEOGRAPH-#6550, IRGKangXi=0471.060, RSKangXi=66.7
6551 CJK UNIFIED IDEOGRAPH-#6551, IRGKangXi=0471.090, RSKangXi=66.7, Def{save, rescue, relieve; help, aid}
6552 CJK UNIFIED IDEOGRAPH-#6552, IRGKangXi=0471.100, RSKangXi=66.7
6553 CJK UNIFIED IDEOGRAPH-#6553, IRGKangXi=0471.110, RSKangXi=66.7
6554 CJK UNIFIED IDEOGRAPH-#6554, IRGKangXi=0471.120, RSKangXi=66.7, Def{gavel}
6555 CJK UNIFIED IDEOGRAPH-#6555, IRGKangXi=0471.130, RSKangXi=66.7, Def{an imperial order or decree}
6556 CJK UNIFIED IDEOGRAPH-#6556, IRGKangXi=0471.140, RSKangXi=66.7, Def{ramble, play about; leisurely; surname}
6557 CJK UNIFIED IDEOGRAPH-#6557, IRGKangXi=0471.150, RSKangXi=66.7, Def{be defeated, decline, fail}
6558 CJK UNIFIED IDEOGRAPH-#6558, IRGKangXi=0472.051, RSKangXi=66.7, Def{express, state, relate, narrate}
6559 CJK UNIFIED IDEOGRAPH-#6559, IRGKangXi=0472.051, RSKangXi=66.7, Def{teach, class}
655A CJK UNIFIED IDEOGRAPH-#655A, IRGKangXi=0472.051, RSKangXi=66.7
655B CJK UNIFIED IDEOGRAPH-#655B, IRGKangXi=0472.051, RSKangXi=66.7, Def{draw back, fold back; collect}
655C CJK UNIFIED IDEOGRAPH-#655C, IRGKangXi=0472.100, RSKangXi=66.8, Def{fill up}
655D CJK UNIFIED IDEOGRAPH-#655D, IRGKangXi=0472.110, RSKangXi=66.8, Def{break, destroy; broken, tattered}
655E CJK UNIFIED IDEOGRAPH-#655E, IRGKangXi=0472.120, RSKangXi=66.8, Def{roomy, spacious, open, broad}
655F CJK UNIFIED IDEOGRAPH-#655F, IRGKangXi=0472.130, RSKangXi=66.8
6560 CJK UNIFIED IDEOGRAPH-#6560, IRGKangXi=0472.170, RSKangXi=66.8, Def{to weigh; cut; come without being invited}
6561 CJK UNIFIED IDEOGRAPH-#6561, IRGKangXi=0472.250, RSKangXi=66.8, Def{rebuke}
6562 CJK UNIFIED IDEOGRAPH-#6562, IRGKangXi=0472.260, RSKangXi=66.8, Def{to dare, venture; bold, brave}
6563 CJK UNIFIED IDEOGRAPH-#6563, IRGKangXi=0472.340, RSKangXi=66.8, Def{scatter, disperse, break up}
6564 CJK UNIFIED IDEOGRAPH-#6564, IRGKangXi=0473.020, RSKangXi=66.8
6565 CJK UNIFIED IDEOGRAPH-#6565, IRGKangXi=0473.050, RSKangXi=66.8
6566 CJK UNIFIED IDEOGRAPH-#6566, IRGKangXi=0473.080, RSKangXi=66.8, Def{esteem; honest, candid, sincere}
6567 CJK UNIFIED IDEOGRAPH-#6567, IRGKangXi=0473.150, RSKangXi=66.8, Def{to pick up thing with chopsticks or pincers.}
6568 CJK UNIFIED IDEOGRAPH-#6568, IRGKangXi=0473.171, RSKangXi=66.8
6569 CJK UNIFIED IDEOGRAPH-#6569, IRGKangXi=0473.171, RSKangXi=66.16
656A CJK UNIFIED IDEOGRAPH-#656A, IRGKangXi=0473.171, RSKangXi=66.8, Def{to weigh; cut; come without being invited}
656B CJK UNIFIED IDEOGRAPH-#656B, IRGKangXi=0473.180, RSKangXi=66.9, Def{ancient musical instrument}
656C CJK UNIFIED IDEOGRAPH-#656C, IRGKangXi=0473.350, RSKangXi=66.9, Def{respect, honor; respectfully}
656D CJK UNIFIED IDEOGRAPH-#656D, IRGKangXi=0474.020, RSKangXi=66.8, Def{scatter, spread; praise; raise}
656E CJK UNIFIED IDEOGRAPH-#656E, IRGKangXi=0474.040, RSKangXi=66.9
656F CJK UNIFIED IDEOGRAPH-#656F, IRGKangXi=0474.131, RSKangXi=66.9, Def{to defy, dare; strong; to suffocate}
6570 CJK UNIFIED IDEOGRAPH-#6570, IRGKangXi=0474.131, RSKangXi=66.9, Def{number; several, count; fate}
6571 CJK UNIFIED IDEOGRAPH-#6571, IRGKangXi=0474.250, RSKangXi=66.10
6572 CJK UNIFIED IDEOGRAPH-#6572, IRGKangXi=0474.310, RSKangXi=66.10, Def{strike, beat, pound, hammer; rap}
6573 CJK UNIFIED IDEOGRAPH-#6573, IRGKangXi=0474.401, RSKangXi=66.10, Def{to govern forcefully}
6574 CJK UNIFIED IDEOGRAPH-#6574, IRGKangXi=0475.321, RSKangXi=66.11, Def{orderly, neat, tidy; whole}
6575 CJK UNIFIED IDEOGRAPH-#6575, IRGKangXi=0474.480, RSKangXi=66.11, Def{enemy, foe, rival; resist}
6576 CJK UNIFIED IDEOGRAPH-#6576, IRGKangXi=0474.510, RSKangXi=66.11
6577 CJK UNIFIED IDEOGRAPH-#6577, IRGKangXi=0474.530, RSKangXi=66.11, Def{spread, diffuse; apply, paint}
6578 CJK UNIFIED IDEOGRAPH-#6578, IRGKangXi=0475.040, RSKangXi=66.11, Def{number; several; count; fate}
6579 CJK UNIFIED IDEOGRAPH-#6579, IRGKangXi=0475.050, RSKangXi=66.11, Def{to sew; keep tidy and repaired}
657A CJK UNIFIED IDEOGRAPH-#657A, IRGKangXi=0475.060, RSKangXi=66.11, Def{expel, drive away; beat, assault}
657B CJK UNIFIED IDEOGRAPH-#657B, IRGKangXi=0475.101, RSKangXi=66.11, Def{long, faraway; pre-eminent}
657C CJK UNIFIED IDEOGRAPH-#657C, IRGKangXi=0475.120, RSKangXi=66.12
657D CJK UNIFIED IDEOGRAPH-#657D, IRGKangXi=0475.180, RSKangXi=66.12, Def{bind}
657E CJK UNIFIED IDEOGRAPH-#657E, IRGKangXi=0475.321, RSKangXi=66.12, Def{to rule}
657F CJK UNIFIED IDEOGRAPH-#657F, IRGKangXi=0475.321, RSKangXi=66.12, Def{bind}
6580 CJK UNIFIED IDEOGRAPH-#6580, IRGKangXi=0475.390, RSKangXi=66.13
6581 CJK UNIFIED IDEOGRAPH-#6581, IRGKangXi=0476.010, RSKangXi=66.13, Def{dislike; be weary of; explain}
6582 CJK UNIFIED IDEOGRAPH-#6582, IRGKangXi=0476.020, RSKangXi=66.13, Def{draw back, fold back; collect}
6583 CJK UNIFIED IDEOGRAPH-#6583, IRGKangXi=0476.090, RSKangXi=66.14, Def{kill; die violent death}
6584 CJK UNIFIED IDEOGRAPH-#6584, IRGKangXi=0476.180, RSKangXi=66.15
6585 CJK UNIFIED IDEOGRAPH-#6585, IRGKangXi=0476.230, RSKangXi=66.16, Def{teach, instruct; be aroused; awake; intelligent}
6586 CJK UNIFIED IDEOGRAPH-#6586, IRGKangXi=0476.271, RSKangXi=66.16, Def{teach, instruct; be aroused; awake; intelligent}
6587 CJK UNIFIED IDEOGRAPH-#6587, IRGKangXi=0477.010, RSKangXi=67.0, Def{literature, culture, writing}
6588 CJK UNIFIED IDEOGRAPH-#6588, IRGKangXi=0477.011, RSKangXi=67.3, Def{learning, knowledge; school}
6589 CJK UNIFIED IDEOGRAPH-#6589, IRGKangXi=0477.011, RSKangXi=210.0, Def{even, uniform, of equal length}
658A CJK UNIFIED IDEOGRAPH-#658A, IRGKangXi=0477.040, RSKangXi=67.6
658B CJK UNIFIED IDEOGRAPH-#658B, IRGKangXi=0477.050, RSKangXi=67.6, Def{vegetarian diet; study}
658C CJK UNIFIED IDEOGRAPH-#658C, IRGKangXi=0477.070, RSKangXi=67.7, Def{refined, having both appearance}
658D CJK UNIFIED IDEOGRAPH-#658D, IRGKangXi=0477.091, RSKangXi=67.7, Def{to perceive, feel}
658E CJK UNIFIED IDEOGRAPH-#658E, IRGKangXi=0477.091, RSKangXi=67.7, Def{vegetarian diet; study}
658F CJK UNIFIED IDEOGRAPH-#658F, IRGKangXi=0477.091, RSKangXi=67.7
6590 CJK UNIFIED IDEOGRAPH-#6590, IRGKangXi=0477.100, RSKangXi=67.8, Def{graceful, elegant, beautiful}
6591 CJK UNIFIED IDEOGRAPH-#6591, IRGKangXi=0477.110, RSKangXi=67.8, Def{mottled, striped, freckle}
6592 CJK UNIFIED IDEOGRAPH-#6592, IRGKangXi=0477.120, RSKangXi=67.9, Def{variegated; striped; marbled}
6593 CJK UNIFIED IDEOGRAPH-#6593, IRGKangXi=0477.201, RSKangXi=67.12, Def{multicolored}
6594 CJK UNIFIED IDEOGRAPH-#6594, IRGKangXi=0477.210, RSKangXi=67.15
6595 CJK UNIFIED IDEOGRAPH-#6595, IRGKangXi=0477.220, RSKangXi=67.17, Def{multicolored}
6596 CJK UNIFIED IDEOGRAPH-#6596, IRGKangXi=0477.230, RSKangXi=67.19
6597 CJK UNIFIED IDEOGRAPH-#6597, IRGKangXi=0477.240, RSKangXi=68.0, Def{Chinese peck; liquid measure}
6598 CJK UNIFIED IDEOGRAPH-#6598, IRGKangXi=0478.020, RSKangXi=68.3
6599 CJK UNIFIED IDEOGRAPH-#6599, IRGKangXi=0478.090, RSKangXi=68.6, Def{consider, conjecture; materials, ingredients}
659A CJK UNIFIED IDEOGRAPH-#659A, IRGKangXi=0478.100, Def{a small cup of stone with ears, used in ancient times for libations}
659B CJK UNIFIED IDEOGRAPH-#659B, IRGKangXi=0478.140, RSKangXi=68.7, Def{dry measure equal to some five or ten dou (U+6597 舒)}
659C CJK UNIFIED IDEOGRAPH-#659C, IRGKangXi=0478.150, RSKangXi=68.7, Def{slanting, sloping, inclined}
659D CJK UNIFIED IDEOGRAPH-#659D, IRGKangXi=0478.160, RSKangXi=68.8, Def{small jade wine cup}
659E CJK UNIFIED IDEOGRAPH-#659E, IRGKangXi=0478.180, RSKangXi=68.9, Def{a stack of grain; a measure of 16 dou3}
659F CJK UNIFIED IDEOGRAPH-#659F, IRGKangXi=0478.190, RSKangXi=68.9, Def{to pour wine or tea into a cup; to gauge}
65A0 CJK UNIFIED IDEOGRAPH-#65A0, IRGKangXi=0478.220, RSKangXi=68.10, Def{measure}
65A1 CJK UNIFIED IDEOGRAPH-#65A1, IRGKangXi=0478.230, RSKangXi=68.10, Def{revolve, rotate, turn}
65A2 CJK UNIFIED IDEOGRAPH-#65A2, IRGKangXi=0478.280, RSKangXi=68.12
65A3 CJK UNIFIED IDEOGRAPH-#65A3, IRGKangXi=0478.290, RSKangXi=68.13
65A4 CJK UNIFIED IDEOGRAPH-#65A4, IRGKangXi=0479.040, RSKangXi=69.0, Def{a catty (approximately 500 g); an axe; keen, shrewd; KangXi radical number 69}
65A5 CJK UNIFIED IDEOGRAPH-#65A5, IRGKangXi=0479.050, RSKangXi=69.1, Def{to scold, upbraid, accuse, reproach}
65A6 CJK UNIFIED IDEOGRAPH-#65A6, IRGKangXi=0479.070, RSKangXi=69.4
65A7 CJK UNIFIED IDEOGRAPH-#65A7, IRGKangXi=0479.080, RSKangXi=69.4, Def{axe, hatchet; chop, hew}
65A8 CJK UNIFIED IDEOGRAPH-#65A8, IRGKangXi=0479.090, RSKangXi=69.4, Def{axe}
65A9 CJK UNIFIED IDEOGRAPH-#65A9, IRGKangXi=0479.111, RSKangXi=159.4, Def{cut, chop, sever; behead}
65AA CJK UNIFIED IDEOGRAPH-#65AA, IRGKangXi=0479.140, RSKangXi=69.5
65AB CJK UNIFIED IDEOGRAPH-#65AB, IRGKangXi=0479.150, RSKangXi=69.5, Def{cut, chop, lop off}
65AC CJK UNIFIED IDEOGRAPH-#65AC, IRGKangXi=0479.180, RSKangXi=69.7, Def{cut, chop, sever; behead}
65AD CJK UNIFIED IDEOGRAPH-#65AD, IRGKangXi=0479.200, RSKangXi=69.7, Def{sever, cut off; interrupt}
65AE CJK UNIFIED IDEOGRAPH-#65AE, IRGKangXi=0480.020, RSKangXi=69.8, Def{cut off}
65AF CJK UNIFIED IDEOGRAPH-#65AF, IRGKangXi=0480.040, RSKangXi=69.8, Def{this, thus, such; to lop off; emphatic particle}
65B0 CJK UNIFIED IDEOGRAPH-#65B0, IRGKangXi=0480.100, RSKangXi=69.9, Def{new, recent, fresh, modern}
65B1 CJK UNIFIED IDEOGRAPH-#65B1, IRGKangXi=0480.120, RSKangXi=69.9
65B2 CJK UNIFIED IDEOGRAPH-#65B2, IRGKangXi=0480.180, RSKangXi=69.10, Def{cut, chop, hack}
65B3 CJK UNIFIED IDEOGRAPH-#65B3, IRGKangXi=0480.231, RSKangXi=69.11
65B4 CJK UNIFIED IDEOGRAPH-#65B4, IRGKangXi=0480.250, RSKangXi=69.12, Def{the sound of water flowing among rocks}
65B5 CJK UNIFIED IDEOGRAPH-#65B5, IRGKangXi=0480.310, RSKangXi=69.13, Def{to cut to pieces; to hack; to chop or hew; to carve for ornaments}
65B6 CJK UNIFIED IDEOGRAPH-#65B6, IRGKangXi=0480.320, RSKangXi=69.13
65B7 CJK UNIFIED IDEOGRAPH-#65B7, IRGKangXi=0480.350, RSKangXi=69.14, Def{sever, cut off; interrupt}
65B8 CJK UNIFIED IDEOGRAPH-#65B8, IRGKangXi=0481.020, RSKangXi=69.21, Def{cut}
65B9 CJK UNIFIED IDEOGRAPH-#65B9, IRGKangXi=0481.030, RSKangXi=70.0, Def{a square, rectangle; a region; local}
65BA CJK UNIFIED IDEOGRAPH-#65BA, IRGKangXi=0481.080, RSKangXi=70.4
65BB CJK UNIFIED IDEOGRAPH-#65BB, IRGKangXi=0481.090, RSKangXi=70.4
65BC CJK UNIFIED IDEOGRAPH-#65BC, IRGKangXi=0481.110, RSKangXi=70.4, Def{in, at, on; interjection alas!}
65BD CJK UNIFIED IDEOGRAPH-#65BD, IRGKangXi=0482.010, RSKangXi=70.5, Def{grant, bestow; give; act; name}
65BE CJK UNIFIED IDEOGRAPH-#65BE, IRGKangXi=0482.050, RSKangXi=70.5, Def{a pennon; a streamer}
65BF CJK UNIFIED IDEOGRAPH-#65BF, IRGKangXi=0482.070, RSKangXi=70.5, Def{to swim; to move or rove freely}
65C0 CJK UNIFIED IDEOGRAPH-#65C0, IRGKangXi=0482.101, RSKangXi=70.5, Def{place name}
65C1 CJK UNIFIED IDEOGRAPH-#65C1, IRGKangXi=0482.110, RSKangXi=70.6, Def{side; by side, close by, near}
65C2 CJK UNIFIED IDEOGRAPH-#65C2, IRGKangXi=0482.150, RSKangXi=70.6, Def{flag}
65C3 CJK UNIFIED IDEOGRAPH-#65C3, IRGKangXi=0482.170, RSKangXi=70.6, Def{silk banner with bent pole}
65C4 CJK UNIFIED IDEOGRAPH-#65C4, IRGKangXi=0482.180, RSKangXi=70.6, Def{a kind of ancient flag; old}
65C5 CJK UNIFIED IDEOGRAPH-#65C5, IRGKangXi=0483.020, RSKangXi=70.6, Def{trip, journey; travel; traveler}
65C6 CJK UNIFIED IDEOGRAPH-#65C6, IRGKangXi=0483.080, RSKangXi=70.6, Def{flag ornament; flags, banners}
65C7 CJK UNIFIED IDEOGRAPH-#65C7, IRGKangXi=0483.110, RSKangXi=70.7
65C8 CJK UNIFIED IDEOGRAPH-#65C8, IRGKangXi=0483.120, RSKangXi=70.7, Def{fringes of pearls on crowns; a pennant}
65C9 CJK UNIFIED IDEOGRAPH-#65C9, IRGKangXi=0483.150, RSKangXi=70.7, Def{to state to, to announce}
65CA CJK UNIFIED IDEOGRAPH-#65CA, IRGKangXi=0483.160, RSKangXi=70.6
65CB CJK UNIFIED IDEOGRAPH-#65CB, IRGKangXi=0483.170, RSKangXi=70.7, Def{revolve, move in orbit; return}
65CC CJK UNIFIED IDEOGRAPH-#65CC, IRGKangXi=0483.190, RSKangXi=70.7, Def{banner or flag adorned with feathers; to signal}
65CD CJK UNIFIED IDEOGRAPH-#65CD, IRGKangXi=0484.010, RSKangXi=70.7
65CE CJK UNIFIED IDEOGRAPH-#65CE, IRGKangXi=0484.020, RSKangXi=70.7, Def{fluttering of flag; romantic}
65CF CJK UNIFIED IDEOGRAPH-#65CF, IRGKangXi=0484.030, RSKangXi=70.7, Def{a family clan, ethnic group, tribe}
65D0 CJK UNIFIED IDEOGRAPH-#65D0, IRGKangXi=0484.120, RSKangXi=70.8, Def{an embroidered pennant}
65D1 CJK UNIFIED IDEOGRAPH-#65D1, IRGKangXi=0484.151, RSKangXi=70.8
65D2 CJK UNIFIED IDEOGRAPH-#65D2, IRGKangXi=0484.180, RSKangXi=70.9, Def{fringes of pearls on crowns}
65D3 CJK UNIFIED IDEOGRAPH-#65D3, IRGKangXi=0484.200, RSKangXi=70.9, Def{serrated edges on a Chinese flag}
65D4 CJK UNIFIED IDEOGRAPH-#65D4, IRGKangXi=0484.210, RSKangXi=70.9
65D5 CJK UNIFIED IDEOGRAPH-#65D5, IRGKangXi=0484.221, RSKangXi=70.9, Def{place name}
65D6 CJK UNIFIED IDEOGRAPH-#65D6, IRGKangXi=0484.260, RSKangXi=70.10, Def{romantic; tender; charming}
65D7 CJK UNIFIED IDEOGRAPH-#65D7, IRGKangXi=0484.280, RSKangXi=70.10, Def{banner, flag, streamer}
65D8 CJK UNIFIED IDEOGRAPH-#65D8, IRGKangXi=0485.040, RSKangXi=70.12, Def{a pennon; a flag. to fasten}
65D9 CJK UNIFIED IDEOGRAPH-#65D9, IRGKangXi=0485.051, RSKangXi=70.12, Def{a pennant, a banner}
65DA CJK UNIFIED IDEOGRAPH-#65DA, IRGKangXi=0485.070, RSKangXi=70.13
65DB CJK UNIFIED IDEOGRAPH-#65DB, IRGKangXi=0485.090, RSKangXi=70.14, Def{a pennant, a banner}
65DC CJK UNIFIED IDEOGRAPH-#65DC, IRGKangXi=0485.140, RSKangXi=70.15, Def{flag}
65DD CJK UNIFIED IDEOGRAPH-#65DD, IRGKangXi=0485.150, RSKangXi=70.15, Def{banner, flag, streamer; insignia}
65DE CJK UNIFIED IDEOGRAPH-#65DE, IRGKangXi=0485.160, RSKangXi=70.15
65DF CJK UNIFIED IDEOGRAPH-#65DF, IRGKangXi=0485.170, RSKangXi=70.16, Def{an military flag or standard}
65E0 CJK UNIFIED IDEOGRAPH-#65E0, IRGKangXi=0485.230, RSKangXi=71.0, Def{negative, no, not; KangXi radical 71}
65E1 CJK UNIFIED IDEOGRAPH-#65E1, IRGKangXi=0485.250, RSKangXi=71.1, Def{choke on something eaten}
65E2 CJK UNIFIED IDEOGRAPH-#65E2, IRGKangXi=0485.310, RSKangXi=71.5, Def{already; de facto; since; then}
65E3 CJK UNIFIED IDEOGRAPH-#65E3, IRGKangXi=0485.300, RSKangXi=71.7, Def{already; de facto; since; then}
65E4 CJK UNIFIED IDEOGRAPH-#65E4, IRGKangXi=0485.350, RSKangXi=71.9
65E5 CJK UNIFIED IDEOGRAPH-#65E5, IRGKangXi=0489.010, RSKangXi=72.0, Def{sun; day; daytime}
65E6 CJK UNIFIED IDEOGRAPH-#65E6, IRGKangXi=0489.030, RSKangXi=72.1, Def{dawn; morning; day}
65E7 CJK UNIFIED IDEOGRAPH-#65E7, IRGKangXi=0489.051, RSKangXi=72.1, Def{old, ancient; former, past}
65E8 CJK UNIFIED IDEOGRAPH-#65E8, IRGKangXi=0489.060, RSKangXi=72.2, Def{purpose, aim; excellent}
65E9 CJK UNIFIED IDEOGRAPH-#65E9, IRGKangXi=0489.120, RSKangXi=72.2, Def{early; soon; morning}
65EA CJK UNIFIED IDEOGRAPH-#65EA, IRGKangXi=0489.130, RSKangXi=72.2, Def{united in; agreement; mutual aid}
65EB CJK UNIFIED IDEOGRAPH-#65EB, IRGKangXi=0489.150, RSKangXi=72.2
65EC CJK UNIFIED IDEOGRAPH-#65EC, IRGKangXi=0489.160, RSKangXi=72.2, Def{ten-day period; period of time}
65ED CJK UNIFIED IDEOGRAPH-#65ED, IRGKangXi=0489.190, RSKangXi=72.2, Def{rising sun; brilliance; radiant}
65EE CJK UNIFIED IDEOGRAPH-#65EE, IRGKangXi=0490.010, RSKangXi=72.2, Def{nook, corner}
65EF CJK UNIFIED IDEOGRAPH-#65EF, IRGKangXi=0490.041, RSKangXi=72.2, Def{nook, corner}
65F0 CJK UNIFIED IDEOGRAPH-#65F0, IRGKangXi=0490.050, RSKangXi=72.3, Def{sunset, dusk; evening}
65F1 CJK UNIFIED IDEOGRAPH-#65F1, IRGKangXi=0490.060, RSKangXi=72.3, Def{drought; dry; dry land}
65F2 CJK UNIFIED IDEOGRAPH-#65F2, IRGKangXi=0490.070, RSKangXi=72.3
65F3 CJK UNIFIED IDEOGRAPH-#65F3, IRGKangXi=0490.130, RSKangXi=72.3
65F4 CJK UNIFIED IDEOGRAPH-#65F4, IRGKangXi=0490.140, RSKangXi=72.3, Def{dawn}
65F5 CJK UNIFIED IDEOGRAPH-#65F5, IRGKangXi=0490.150, RSKangXi=72.3
65F6 CJK UNIFIED IDEOGRAPH-#65F6, IRGKangXi=0490.221, RSKangXi=72.3, Def{time, season; era, age, period}
65F7 CJK UNIFIED IDEOGRAPH-#65F7, IRGKangXi=0490.221, RSKangXi=72.3, Def{extensive, wide, broad; empty}
65F8 CJK UNIFIED IDEOGRAPH-#65F8, IRGKangXi=0490.221, RSKangXi=72.3, Def{rising sun; sunshine}
65F9 CJK UNIFIED IDEOGRAPH-#65F9, IRGKangXi=0490.230, RSKangXi=72.4, Def{time, season; era, age, period}
65FA CJK UNIFIED IDEOGRAPH-#65FA, IRGKangXi=0490.240, RSKangXi=72.4, Def{prosper; prosperous; increase}
65FB CJK UNIFIED IDEOGRAPH-#65FB, IRGKangXi=0490.250, RSKangXi=72.4, Def{heaven}
65FC CJK UNIFIED IDEOGRAPH-#65FC, IRGKangXi=0490.260, RSKangXi=72.4, Def{gentle and affable}
65FD CJK UNIFIED IDEOGRAPH-#65FD, IRGKangXi=0490.270, RSKangXi=72.4, Def{morning sun, sunrise}
65FE CJK UNIFIED IDEOGRAPH-#65FE, IRGKangXi=0490.280, RSKangXi=72.4
65FF CJK UNIFIED IDEOGRAPH-#65FF, IRGKangXi=0490.300, RSKangXi=72.4
6600 CJK UNIFIED IDEOGRAPH-#6600, IRGKangXi=0490.310, RSKangXi=72.4, Def{sun light; used in personal names}
6601 CJK UNIFIED IDEOGRAPH-#6601, IRGKangXi=0490.320, RSKangXi=72.4
6602 CJK UNIFIED IDEOGRAPH-#6602, IRGKangXi=0490.330, RSKangXi=72.4, Def{rise, raise; proud, bold; upright}
6603 CJK UNIFIED IDEOGRAPH-#6603, IRGKangXi=0490.350, RSKangXi=72.4, Def{afternoon; the sun in the afternoon sky; to decline}
6604 CJK UNIFIED IDEOGRAPH-#6604, IRGKangXi=0490.360, RSKangXi=72.4, Def{big}
6605 CJK UNIFIED IDEOGRAPH-#6605, IRGKangXi=0490.370, RSKangXi=72.4
6606 CJK UNIFIED IDEOGRAPH-#6606, IRGKangXi=0490.390, RSKangXi=72.4, Def{elder brother; descendants}
6607 CJK UNIFIED IDEOGRAPH-#6607, IRGKangXi=0491.020, RSKangXi=72.4, Def{rise, ascent; peaceful; peace}
6608 CJK UNIFIED IDEOGRAPH-#6608, IRGKangXi=0491.030, RSKangXi=72.4
6609 CJK UNIFIED IDEOGRAPH-#6609, IRGKangXi=0491.040, RSKangXi=72.4, Def{bright dawn, daybreak; appear}
660A CJK UNIFIED IDEOGRAPH-#660A, IRGKangXi=0491.070, RSKangXi=72.4, Def{summer time; sky; heaven}
660B CJK UNIFIED IDEOGRAPH-#660B, IRGKangXi=0491.080, RSKangXi=72.4
660C CJK UNIFIED IDEOGRAPH-#660C, IRGKangXi=0491.100, RSKangXi=72.4, Def{light of sun; good, proper}
660D CJK UNIFIED IDEOGRAPH-#660D, IRGKangXi=0491.110, RSKangXi=72.4
660E CJK UNIFIED IDEOGRAPH-#660E, IRGKangXi=0491.120, RSKangXi=72.4, Def{bright, light, brilliant; clear}
660F CJK UNIFIED IDEOGRAPH-#660F, IRGKangXi=0491.140, RSKangXi=72.4, Def{dusk, nightfall, twilight, dark}
6610 CJK UNIFIED IDEOGRAPH-#6610, IRGKangXi=0491.180, RSKangXi=72.4
6611 CJK UNIFIED IDEOGRAPH-#6611, IRGKangXi=0491.210, RSKangXi=72.4, Def{bright}
6612 CJK UNIFIED IDEOGRAPH-#6612, IRGKangXi=0492.010, RSKangXi=72.4
6613 CJK UNIFIED IDEOGRAPH-#6613, IRGKangXi=0492.030, RSKangXi=72.4, Def{change; easy}
6614 CJK UNIFIED IDEOGRAPH-#6614, IRGKangXi=0492.050, RSKangXi=72.4, Def{formerly; ancient; in beginning}
6615 CJK UNIFIED IDEOGRAPH-#6615, IRGKangXi=0492.060, RSKangXi=72.4, Def{dawn; early morning; day}
6616 CJK UNIFIED IDEOGRAPH-#6616, IRGKangXi=0492.080, RSKangXi=72.4
6617 CJK UNIFIED IDEOGRAPH-#6617, IRGKangXi=0492.121, RSKangXi=72.4
6618 CJK UNIFIED IDEOGRAPH-#6618, IRGKangXi=0492.121, RSKangXi=72.4
6619 CJK UNIFIED IDEOGRAPH-#6619, IRGKangXi=0492.121, RSKangXi=72.4, Def{become cloudy, overcast}
661A CJK UNIFIED IDEOGRAPH-#661A, IRGKangXi=0492.130, RSKangXi=72.5
661B CJK UNIFIED IDEOGRAPH-#661B, IRGKangXi=0492.160, RSKangXi=72.5
661C CJK UNIFIED IDEOGRAPH-#661C, IRGKangXi=0492.170, RSKangXi=72.5, Def{to open out, to expand; bright, glorious}
661D CJK UNIFIED IDEOGRAPH-#661D, IRGKangXi=0492.190, RSKangXi=72.5, Def{a dual pronoun, I, you and me, we two}
661E CJK UNIFIED IDEOGRAPH-#661E, IRGKangXi=0492.200, RSKangXi=72.5, Def{bright, luminous; glorious}
661F CJK UNIFIED IDEOGRAPH-#661F, IRGKangXi=0492.210, RSKangXi=72.5, Def{a star, planet; any point of light}
6620 CJK UNIFIED IDEOGRAPH-#6620, IRGKangXi=0493.010, RSKangXi=72.5, Def{project; reflect light}
6621 CJK UNIFIED IDEOGRAPH-#6621, IRGKangXi=0493.020, RSKangXi=72.5, Def{long day; extended; relaxed}
6622 CJK UNIFIED IDEOGRAPH-#6622, IRGKangXi=0493.030, RSKangXi=72.5
6623 CJK UNIFIED IDEOGRAPH-#6623, IRGKangXi=0493.040, RSKangXi=72.5
6624 CJK UNIFIED IDEOGRAPH-#6624, IRGKangXi=0493.050, RSKangXi=72.5, Def{sunshine}
6625 CJK UNIFIED IDEOGRAPH-#6625, IRGKangXi=0493.060, RSKangXi=72.5, Def{spring; wanton}
6626 CJK UNIFIED IDEOGRAPH-#6626, IRGKangXi=0493.110, RSKangXi=72.5
6627 CJK UNIFIED IDEOGRAPH-#6627, IRGKangXi=0493.120, RSKangXi=72.5, Def{obscure, dark; darken}
6628 CJK UNIFIED IDEOGRAPH-#6628, IRGKangXi=0493.140, RSKangXi=72.5, Def{yesterday; in former times, past}
6629 CJK UNIFIED IDEOGRAPH-#6629, IRGKangXi=0493.150, RSKangXi=72.5
662A CJK UNIFIED IDEOGRAPH-#662A, IRGKangXi=0493.160, RSKangXi=72.5, Def{delighted; pleased}
662B CJK UNIFIED IDEOGRAPH-#662B, IRGKangXi=0493.190, RSKangXi=72.5, Def{warm}
662C CJK UNIFIED IDEOGRAPH-#662C, IRGKangXi=0493.200, RSKangXi=72.5, Def{dusk, dark confused; stupid}
662D CJK UNIFIED IDEOGRAPH-#662D, IRGKangXi=0493.220, RSKangXi=72.5, Def{bright, luminous; illustrious}
662E CJK UNIFIED IDEOGRAPH-#662E, IRGKangXi=0493.230, RSKangXi=72.5
662F CJK UNIFIED IDEOGRAPH-#662F, IRGKangXi=0493.260, RSKangXi=72.5, Def{indeed, yes, right; to be; demonstrative pronoun, this, that}
6630 CJK UNIFIED IDEOGRAPH-#6630, IRGKangXi=0494.010, RSKangXi=72.5, Def{variant of 'to be'; summer; name}
6631 CJK UNIFIED IDEOGRAPH-#6631, IRGKangXi=0494.030, RSKangXi=72.5, Def{bright light, sunlight; dazzling}
6632 CJK UNIFIED IDEOGRAPH-#6632, IRGKangXi=0494.040, RSKangXi=72.5
6633 CJK UNIFIED IDEOGRAPH-#6633, IRGKangXi=0494.050, RSKangXi=72.5, Def{the declining sun in the west}
6634 CJK UNIFIED IDEOGRAPH-#6634, IRGKangXi=0494.060, RSKangXi=72.5, Def{one of the 28 constellations}
6635 CJK UNIFIED IDEOGRAPH-#6635, IRGKangXi=0494.070, RSKangXi=72.5, Def{intimate, close; approach}
6636 CJK UNIFIED IDEOGRAPH-#6636, IRGKangXi=0494.080, RSKangXi=72.5, Def{a long day. bright. extended. clear}
6637 CJK UNIFIED IDEOGRAPH-#6637, IRGKangXi=0494.090, RSKangXi=72.5, Def{to feed a prisoner}
6638 CJK UNIFIED IDEOGRAPH-#6638, IRGKangXi=0494.140, RSKangXi=72.5
6639 CJK UNIFIED IDEOGRAPH-#6639, IRGKangXi=0494.170, RSKangXi=72.5
663A CJK UNIFIED IDEOGRAPH-#663A, IRGKangXi=0494.180, RSKangXi=72.5, Def{bright, glorious; brilliant}
663B CJK UNIFIED IDEOGRAPH-#663B, IRGKangXi=0494.181, RSKangXi=72.5, Def{rise}
663C CJK UNIFIED IDEOGRAPH-#663C, IRGKangXi=0494.181, RSKangXi=44.6, Def{daytime, daylight}
663D CJK UNIFIED IDEOGRAPH-#663D, IRGKangXi=0494.181, RSKangXi=72.16, Def{vague, dim; twilight}
663E CJK UNIFIED IDEOGRAPH-#663E, IRGKangXi=0494.181, RSKangXi=72.5, Def{manifest, display; evident, clear}
663F CJK UNIFIED IDEOGRAPH-#663F, IRGKangXi=0494.181, RSKangXi=72.5, Def{extensive, wide, broad; empty}
6640 CJK UNIFIED IDEOGRAPH-#6640, IRGKangXi=0494.200, RSKangXi=72.6
6641 CJK UNIFIED IDEOGRAPH-#6641, IRGKangXi=0494.210, RSKangXi=72.6, Def{morning, dawn; surname}
6642 CJK UNIFIED IDEOGRAPH-#6642, IRGKangXi=0494.220, RSKangXi=72.6, Def{time, season; era, age, period}
6643 CJK UNIFIED IDEOGRAPH-#6643, IRGKangXi=0494.240, RSKangXi=72.6, Def{bright, dazzling; to sway, shake}
6644 CJK UNIFIED IDEOGRAPH-#6644, IRGKangXi=0494.250, RSKangXi=72.6, Def{bright, dazzling; to sway, shake}
6645 CJK UNIFIED IDEOGRAPH-#6645, IRGKangXi=0494.260, RSKangXi=72.6, Def{light of the sun; to dry in the sun}
6646 CJK UNIFIED IDEOGRAPH-#6646, IRGKangXi=0494.270, RSKangXi=72.6
6647 CJK UNIFIED IDEOGRAPH-#6647, IRGKangXi=0494.290, RSKangXi=72.6
6648 CJK UNIFIED IDEOGRAPH-#6648, IRGKangXi=0494.300, RSKangXi=72.6
6649 CJK UNIFIED IDEOGRAPH-#6649, IRGKangXi=0494.310, RSKangXi=72.6, Def{advance, increase; promote}
664A CJK UNIFIED IDEOGRAPH-#664A, IRGKangXi=0495.010, RSKangXi=72.6
664B CJK UNIFIED IDEOGRAPH-#664B, IRGKangXi=0495.020, RSKangXi=72.6, Def{advance, increase; promote}
664C CJK UNIFIED IDEOGRAPH-#664C, IRGKangXi=0495.050, RSKangXi=72.6, Def{noon, midday; moment; unit land measurement equal to seven mou (U+755D 畝), or the area that can be sown in one day}
664D CJK UNIFIED IDEOGRAPH-#664D, IRGKangXi=0495.090, RSKangXi=72.6
664E CJK UNIFIED IDEOGRAPH-#664E, IRGKangXi=0495.140, RSKangXi=72.6
664F CJK UNIFIED IDEOGRAPH-#664F, IRGKangXi=0495.150, RSKangXi=72.6, Def{peaceful, quiet; clear; late in the day}
6650 CJK UNIFIED IDEOGRAPH-#6650, IRGKangXi=0495.160, RSKangXi=72.6
6651 CJK UNIFIED IDEOGRAPH-#6651, IRGKangXi=0495.210, RSKangXi=72.6
6652 CJK UNIFIED IDEOGRAPH-#6652, IRGKangXi=0495.241, RSKangXi=72.6, Def{dry in sun, expose to sun}
6653 CJK UNIFIED IDEOGRAPH-#6653, IRGKangXi=0495.241, RSKangXi=72.6, Def{dawn, daybreak; clear, explicit}
6654 CJK UNIFIED IDEOGRAPH-#6654, IRGKangXi=0495.241, RSKangXi=72.6, Def{bright; radiant; thriving}
6655 CJK UNIFIED IDEOGRAPH-#6655, IRGKangXi=0495.241, RSKangXi=72.6, Def{halo in sky; fog; dizzy, faint}
6656 CJK UNIFIED IDEOGRAPH-#6656, IRGKangXi=0495.241, RSKangXi=72.6, Def{sunshine; light, bright, radiant}
6657 CJK UNIFIED IDEOGRAPH-#6657, IRGKangXi=0495.270, RSKangXi=72.7, Def{pre-dawn}
6658 CJK UNIFIED IDEOGRAPH-#6658, IRGKangXi=0495.280, RSKangXi=72.7
6659 CJK UNIFIED IDEOGRAPH-#6659, IRGKangXi=0495.330, RSKangXi=72.7, Def{early; bright; respect}
665A CJK UNIFIED IDEOGRAPH-#665A, IRGKangXi=0495.340, RSKangXi=72.7, Def{night, evening; late}
665B CJK UNIFIED IDEOGRAPH-#665B, IRGKangXi=0495.370, RSKangXi=72.7, Def{sunlight}
665C CJK UNIFIED IDEOGRAPH-#665C, IRGKangXi=0495.390, RSKangXi=72.7, Def{insect}
665D CJK UNIFIED IDEOGRAPH-#665D, IRGKangXi=0495.430, RSKangXi=72.7, Def{daytime, daylight}
665E CJK UNIFIED IDEOGRAPH-#665E, IRGKangXi=0495.440, RSKangXi=72.7, Def{dry, expose sun; dawn}
665F CJK UNIFIED IDEOGRAPH-#665F, IRGKangXi=0495.450, RSKangXi=72.7, Def{clear, bright; splendor, brightness}
6660 CJK UNIFIED IDEOGRAPH-#6660, IRGKangXi=0496.010, RSKangXi=72.7
6661 CJK UNIFIED IDEOGRAPH-#6661, IRGKangXi=0496.020, RSKangXi=72.7, Def{late afternoon}
6662 CJK UNIFIED IDEOGRAPH-#6662, IRGKangXi=0496.030, RSKangXi=72.7, Def{light of stars; shine}
6663 CJK UNIFIED IDEOGRAPH-#6663, IRGKangXi=0496.040, RSKangXi=72.7
6664 CJK UNIFIED IDEOGRAPH-#6664, IRGKangXi=0496.060, RSKangXi=72.7, Def{have interview with; meet}
6665 CJK UNIFIED IDEOGRAPH-#6665, IRGKangXi=0496.080, RSKangXi=72.7, Def{Anhui province}
6666 CJK UNIFIED IDEOGRAPH-#6666, IRGKangXi=0496.100, RSKangXi=72.7, Def{dark, unclear, obscure; night}
6667 CJK UNIFIED IDEOGRAPH-#6667, IRGKangXi=0496.110, RSKangXi=72.7, Def{daybreak; bright and brilliant}
6668 CJK UNIFIED IDEOGRAPH-#6668, IRGKangXi=0496.120, RSKangXi=72.7, Def{early morning, daybreak}
6669 CJK UNIFIED IDEOGRAPH-#6669, IRGKangXi=0497.311, RSKangXi=72.7, Def{night}
666A CJK UNIFIED IDEOGRAPH-#666A, IRGKangXi=0496.220, RSKangXi=72.8
666B CJK UNIFIED IDEOGRAPH-#666B, IRGKangXi=0496.230, RSKangXi=72.8, Def{bright}
666C CJK UNIFIED IDEOGRAPH-#666C, IRGKangXi=0496.240, RSKangXi=72.8, Def{first birthday of a child}
666D CJK UNIFIED IDEOGRAPH-#666D, IRGKangXi=0496.280, RSKangXi=72.8
666E CJK UNIFIED IDEOGRAPH-#666E, IRGKangXi=0496.290, RSKangXi=72.8, Def{universal, general, widespread}
666F CJK UNIFIED IDEOGRAPH-#666F, IRGKangXi=0496.300, RSKangXi=72.8, Def{scenery, view; conditions}
6670 CJK UNIFIED IDEOGRAPH-#6670, IRGKangXi=0496.330, RSKangXi=72.8, Def{clear, evident; clearly}
6671 CJK UNIFIED IDEOGRAPH-#6671, IRGKangXi=0496.340, RSKangXi=72.8
6672 CJK UNIFIED IDEOGRAPH-#6672, IRGKangXi=0496.360, RSKangXi=72.8
6673 CJK UNIFIED IDEOGRAPH-#6673, IRGKangXi=0496.370, RSKangXi=72.8, Def{fair; white; clear; discriminate}
6674 CJK UNIFIED IDEOGRAPH-#6674, IRGKangXi=0496.390, RSKangXi=72.8, Def{clear weather, fine weather}
6675 CJK UNIFIED IDEOGRAPH-#6675, IRGKangXi=0497.030, RSKangXi=72.8
6676 CJK UNIFIED IDEOGRAPH-#6676, IRGKangXi=0497.060, RSKangXi=72.8, Def{crystal; clear, bright; radiant}
6677 CJK UNIFIED IDEOGRAPH-#6677, IRGKangXi=0497.100, RSKangXi=72.8, Def{shadows of sun; time; sundial}
6678 CJK UNIFIED IDEOGRAPH-#6678, IRGKangXi=0497.120, RSKangXi=72.8, Def{appearance of the sun}
6679 CJK UNIFIED IDEOGRAPH-#6679, IRGKangXi=0497.140, RSKangXi=72.8, Def{the sun going behind and out from behind clouds}
667A CJK UNIFIED IDEOGRAPH-#667A, IRGKangXi=0497.150, RSKangXi=72.8, Def{wisdom, knowledge, intelligence}
667B CJK UNIFIED IDEOGRAPH-#667B, IRGKangXi=0497.190, RSKangXi=72.8
667C CJK UNIFIED IDEOGRAPH-#667C, IRGKangXi=0497.230, RSKangXi=72.8, Def{sunset}
667D CJK UNIFIED IDEOGRAPH-#667D, IRGKangXi=0497.250, RSKangXi=72.8
667E CJK UNIFIED IDEOGRAPH-#667E, IRGKangXi=0497.270, RSKangXi=72.8, Def{air-dry; sun-dry}
667F CJK UNIFIED IDEOGRAPH-#667F, IRGKangXi=0497.311, RSKangXi=72.8
6680 CJK UNIFIED IDEOGRAPH-#6680, IRGKangXi=0497.311, RSKangXi=72.8
6681 CJK UNIFIED IDEOGRAPH-#6681, IRGKangXi=0497.311, RSKangXi=72.8, Def{dawn, daybreak; clear, explicit}
6682 CJK UNIFIED IDEOGRAPH-#6682, IRGKangXi=0497.311, RSKangXi=72.8, Def{temporary}
6683 CJK UNIFIED IDEOGRAPH-#6683, IRGKangXi=0497.311, RSKangXi=72.8
6684 CJK UNIFIED IDEOGRAPH-#6684, IRGKangXi=0497.330, RSKangXi=72.9, Def{warm, comfortable; warm, genial}
6685 CJK UNIFIED IDEOGRAPH-#6685, IRGKangXi=0497.340, RSKangXi=72.9
6686 CJK UNIFIED IDEOGRAPH-#6686, IRGKangXi=0497.350, RSKangXi=72.9
6687 CJK UNIFIED IDEOGRAPH-#6687, IRGKangXi=0497.360, RSKangXi=72.9, Def{leisure, relaxation, spare time}
6688 CJK UNIFIED IDEOGRAPH-#6688, IRGKangXi=0497.370, RSKangXi=72.9, Def{halo in sky; fog; dizzy, faint}
6689 CJK UNIFIED IDEOGRAPH-#6689, IRGKangXi=0497.380, RSKangXi=72.9, Def{sunshine; light, bright, radiant}
668A CJK UNIFIED IDEOGRAPH-#668A, IRGKangXi=0498.020, RSKangXi=72.9
668B CJK UNIFIED IDEOGRAPH-#668B, IRGKangXi=0498.030, RSKangXi=72.9, Def{strong, robust, tough}
668C CJK UNIFIED IDEOGRAPH-#668C, IRGKangXi=0498.070, RSKangXi=72.9, Def{in opposition; distant from; separated}
668D CJK UNIFIED IDEOGRAPH-#668D, IRGKangXi=0498.090, RSKangXi=72.9, Def{sunstroke}
668E CJK UNIFIED IDEOGRAPH-#668E, IRGKangXi=0498.100, RSKangXi=72.9, Def{sun beginning decline; reflect}
668F CJK UNIFIED IDEOGRAPH-#668F, IRGKangXi=0498.110, RSKangXi=72.9, Def{variant of 暑 U+6691, summer heat; hot}
6690 CJK UNIFIED IDEOGRAPH-#6690, IRGKangXi=0498.120, RSKangXi=72.9, Def{the bright shining of the sun}
6691 CJK UNIFIED IDEOGRAPH-#6691, IRGKangXi=0498.130, RSKangXi=72.8, Def{hot}
6692 CJK UNIFIED IDEOGRAPH-#6692, IRGKangXi=0498.140, RSKangXi=72.9
6693 CJK UNIFIED IDEOGRAPH-#6693, IRGKangXi=0498.160, RSKangXi=72.9
6694 CJK UNIFIED IDEOGRAPH-#6694, IRGKangXi=0498.170, RSKangXi=72.9
6695 CJK UNIFIED IDEOGRAPH-#6695, IRGKangXi=0498.190, RSKangXi=72.9
6696 CJK UNIFIED IDEOGRAPH-#6696, IRGKangXi=0498.260, RSKangXi=72.9, Def{warm, genial}
6697 CJK UNIFIED IDEOGRAPH-#6697, IRGKangXi=0498.270, RSKangXi=72.9, Def{dark; obscure; in secret, covert}
6698 CJK UNIFIED IDEOGRAPH-#6698, IRGKangXi=0498.280, RSKangXi=72.9, Def{rising sun; sunshine}
6699 CJK UNIFIED IDEOGRAPH-#6699, IRGKangXi=0498.311, RSKangXi=72.9
669A CJK UNIFIED IDEOGRAPH-#669A, IRGKangXi=0498.320, RSKangXi=72.10
669B CJK UNIFIED IDEOGRAPH-#669B, IRGKangXi=0498.340, RSKangXi=72.10
669C CJK UNIFIED IDEOGRAPH-#669C, IRGKangXi=0498.360, RSKangXi=72.10
669D CJK UNIFIED IDEOGRAPH-#669D, IRGKangXi=0498.370, RSKangXi=72.10, Def{dark, obscure}
669E CJK UNIFIED IDEOGRAPH-#669E, IRGKangXi=0498.400, RSKangXi=72.10
669F CJK UNIFIED IDEOGRAPH-#669F, IRGKangXi=0498.420, RSKangXi=72.10
66A0 CJK UNIFIED IDEOGRAPH-#66A0, IRGKangXi=0498.430, RSKangXi=72.10, Def{daybreak; bright and brilliant}
66A1 CJK UNIFIED IDEOGRAPH-#66A1, IRGKangXi=0498.480, RSKangXi=72.10
66A2 CJK UNIFIED IDEOGRAPH-#66A2, IRGKangXi=0498.490, RSKangXi=72.10, Def{smoothly, freely, unrestrained}
66A3 CJK UNIFIED IDEOGRAPH-#66A3, IRGKangXi=0498.500, RSKangXi=72.10
66A4 CJK UNIFIED IDEOGRAPH-#66A4, IRGKangXi=0499.020, RSKangXi=72.10
66A5 CJK UNIFIED IDEOGRAPH-#66A5, IRGKangXi=0499.030, RSKangXi=72.10
66A6 CJK UNIFIED IDEOGRAPH-#66A6, IRGKangXi=0499.061, RSKangXi=72.10, Def{calendar, era}
66A7 CJK UNIFIED IDEOGRAPH-#66A7, IRGKangXi=0499.061, RSKangXi=72.10, Def{obscure, dim, ambiguous, vague}
66A8 CJK UNIFIED IDEOGRAPH-#66A8, IRGKangXi=0499.061, RSKangXi=72.10, Def{and; attain, reach; confines}
66A9 CJK UNIFIED IDEOGRAPH-#66A9, IRGKangXi=0499.070, RSKangXi=72.11
66AA CJK UNIFIED IDEOGRAPH-#66AA, IRGKangXi=0499.140, RSKangXi=72.11
66AB CJK UNIFIED IDEOGRAPH-#66AB, IRGKangXi=0499.150, RSKangXi=72.11, Def{temporary}
66AC CJK UNIFIED IDEOGRAPH-#66AC, IRGKangXi=0499.160, RSKangXi=72.11
66AD CJK UNIFIED IDEOGRAPH-#66AD, IRGKangXi=0499.170, RSKangXi=72.11
66AE CJK UNIFIED IDEOGRAPH-#66AE, IRGKangXi=0499.210, RSKangXi=72.11, Def{evening, dusk, sunset; ending}
66AF CJK UNIFIED IDEOGRAPH-#66AF, IRGKangXi=0499.220, RSKangXi=72.11
66B0 CJK UNIFIED IDEOGRAPH-#66B0, IRGKangXi=0499.230, RSKangXi=72.11
66B1 CJK UNIFIED IDEOGRAPH-#66B1, IRGKangXi=0499.250, RSKangXi=72.11, Def{intimate, close; approach}
66B2 CJK UNIFIED IDEOGRAPH-#66B2, IRGKangXi=0499.260, RSKangXi=72.11, Def{bright; to rise (of sun)}
66B3 CJK UNIFIED IDEOGRAPH-#66B3, IRGKangXi=0499.280, RSKangXi=72.11
66B4 CJK UNIFIED IDEOGRAPH-#66B4, IRGKangXi=0499.290, RSKangXi=72.11, Def{violent, brutal, tyrannical}
66B5 CJK UNIFIED IDEOGRAPH-#66B5, IRGKangXi=0499.310, RSKangXi=72.11, Def{dry by exposing sun}
66B6 CJK UNIFIED IDEOGRAPH-#66B6, IRGKangXi=0499.320, RSKangXi=72.11
66B7 CJK UNIFIED IDEOGRAPH-#66B7, IRGKangXi=0499.361, RSKangXi=72.11
66B8 CJK UNIFIED IDEOGRAPH-#66B8, IRGKangXi=0499.370, RSKangXi=72.12, Def{bright, clear}
66B9 CJK UNIFIED IDEOGRAPH-#66B9, IRGKangXi=0499.390, RSKangXi=72.12, Def{rise; advance, go forward}
66BA CJK UNIFIED IDEOGRAPH-#66BA, IRGKangXi=0499.400, RSKangXi=72.12
66BB CJK UNIFIED IDEOGRAPH-#66BB, IRGKangXi=0499.420, RSKangXi=72.12, Def{bright}
66BC CJK UNIFIED IDEOGRAPH-#66BC, IRGKangXi=0499.440, RSKangXi=72.12, Def{take fleeting glance at}
66BD CJK UNIFIED IDEOGRAPH-#66BD, IRGKangXi=0499.450, RSKangXi=72.12
66BE CJK UNIFIED IDEOGRAPH-#66BE, IRGKangXi=0499.490, RSKangXi=72.12, Def{morning sun, sunrise}
66BF CJK UNIFIED IDEOGRAPH-#66BF, IRGKangXi=0499.510, RSKangXi=72.12
66C0 CJK UNIFIED IDEOGRAPH-#66C0, IRGKangXi=0499.520, RSKangXi=72.12, Def{stormy; cloudy, misty; dim; (Cant.) sultry}
66C1 CJK UNIFIED IDEOGRAPH-#66C1, IRGKangXi=0500.020, RSKangXi=72.12, Def{and; attain}
66C2 CJK UNIFIED IDEOGRAPH-#66C2, IRGKangXi=0500.060, RSKangXi=72.12
66C3 CJK UNIFIED IDEOGRAPH-#66C3, IRGKangXi=0500.070, RSKangXi=72.12
66C4 CJK UNIFIED IDEOGRAPH-#66C4, IRGKangXi=0500.080, RSKangXi=72.12, Def{bright; radiant; thriving}
66C5 CJK UNIFIED IDEOGRAPH-#66C5, IRGKangXi=0500.090, RSKangXi=72.12, Def{bright; flourishing}
66C6 CJK UNIFIED IDEOGRAPH-#66C6, IRGKangXi=0500.100, RSKangXi=72.12, Def{calendar, era}
66C7 CJK UNIFIED IDEOGRAPH-#66C7, IRGKangXi=0500.130, RSKangXi=72.12, Def{become cloudy, overcast}
66C8 CJK UNIFIED IDEOGRAPH-#66C8, IRGKangXi=0500.160, RSKangXi=72.12, Def{twilight just before sunrise}
66C9 CJK UNIFIED IDEOGRAPH-#66C9, IRGKangXi=0500.170, RSKangXi=72.12, Def{dawn, daybreak; clear, explicit}
66CA CJK UNIFIED IDEOGRAPH-#66CA, IRGKangXi=0500.180, RSKangXi=72.12
66CB CJK UNIFIED IDEOGRAPH-#66CB, IRGKangXi=0500.251, RSKangXi=72.12
66CC CJK UNIFIED IDEOGRAPH-#66CC, IRGKangXi=0500.251, RSKangXi=72.12
66CD CJK UNIFIED IDEOGRAPH-#66CD, IRGKangXi=0500.251, RSKangXi=72.12, Def{bright, brilliant}
66CE CJK UNIFIED IDEOGRAPH-#66CE, IRGKangXi=0500.260, RSKangXi=72.13
66CF CJK UNIFIED IDEOGRAPH-#66CF, IRGKangXi=0500.270, RSKangXi=72.13, Def{once upon time; period of time}
66D0 CJK UNIFIED IDEOGRAPH-#66D0, IRGKangXi=0500.280, RSKangXi=72.13
66D1 CJK UNIFIED IDEOGRAPH-#66D1, IRGKangXi=0500.290, RSKangXi=72.13
66D2 CJK UNIFIED IDEOGRAPH-#66D2, IRGKangXi=0500.320, RSKangXi=72.13
66D3 CJK UNIFIED IDEOGRAPH-#66D3, IRGKangXi=0500.330, RSKangXi=72.13
66D4 CJK UNIFIED IDEOGRAPH-#66D4, IRGKangXi=0500.340, RSKangXi=72.13
66D5 CJK UNIFIED IDEOGRAPH-#66D5, IRGKangXi=0500.360, RSKangXi=72.13, Def{to dry or cook in the sun}
66D6 CJK UNIFIED IDEOGRAPH-#66D6, IRGKangXi=0500.380, RSKangXi=72.13, Def{obscure, dim, ambiguous, vague}
66D7 CJK UNIFIED IDEOGRAPH-#66D7, IRGKangXi=0500.410, RSKangXi=72.13
66D8 CJK UNIFIED IDEOGRAPH-#66D8, IRGKangXi=0501.020, RSKangXi=72.14
66D9 CJK UNIFIED IDEOGRAPH-#66D9, IRGKangXi=0501.040, RSKangXi=72.14, Def{bright, light of rising sun}
66DA CJK UNIFIED IDEOGRAPH-#66DA, IRGKangXi=0501.070, RSKangXi=72.13, Def{twilight just before sun rises}
66DB CJK UNIFIED IDEOGRAPH-#66DB, IRGKangXi=0501.080, RSKangXi=72.14, Def{twilight; sunset}
66DC CJK UNIFIED IDEOGRAPH-#66DC, IRGKangXi=0501.110, RSKangXi=72.14, Def{glorious, as sun; daylight, sunlight; one of the seven planets of pre-modern astronomy (the sun, the moon, Mercury, Venus, Mars, Jupiter, and Saturn)}
66DD CJK UNIFIED IDEOGRAPH-#66DD, IRGKangXi=0501.180, RSKangXi=72.15, Def{sun, air in sun, expose or dry in the sun}
66DE CJK UNIFIED IDEOGRAPH-#66DE, IRGKangXi=0501.200, RSKangXi=72.15
66DF CJK UNIFIED IDEOGRAPH-#66DF, IRGKangXi=0501.230, RSKangXi=72.15
66E0 CJK UNIFIED IDEOGRAPH-#66E0, IRGKangXi=0501.240, RSKangXi=72.15, Def{extensive, wide, broad; empty}
66E1 CJK UNIFIED IDEOGRAPH-#66E1, IRGKangXi=0501.281, RSKangXi=72.15, Def{repeat, duplicate; repeitious}
66E2 CJK UNIFIED IDEOGRAPH-#66E2, IRGKangXi=0501.281, RSKangXi=72.15
66E3 CJK UNIFIED IDEOGRAPH-#66E3, IRGKangXi=0501.300, RSKangXi=72.16, Def{fair weather; warm}
66E4 CJK UNIFIED IDEOGRAPH-#66E4, IRGKangXi=0501.310, RSKangXi=72.16
66E5 CJK UNIFIED IDEOGRAPH-#66E5, IRGKangXi=0501.320, RSKangXi=72.16
66E6 CJK UNIFIED IDEOGRAPH-#66E6, IRGKangXi=0501.330, RSKangXi=72.16, Def{sunlight, sunshine, early dawn}
66E7 CJK UNIFIED IDEOGRAPH-#66E7, IRGKangXi=0501.340, RSKangXi=72.16
66E8 CJK UNIFIED IDEOGRAPH-#66E8, IRGKangXi=0501.350, RSKangXi=72.16, Def{vague, dim; twilight}
66E9 CJK UNIFIED IDEOGRAPH-#66E9, IRGKangXi=0501.370, RSKangXi=72.17, Def{in ancient times, of old, former}
66EA CJK UNIFIED IDEOGRAPH-#66EA, IRGKangXi=0501.420, RSKangXi=72.19
66EB CJK UNIFIED IDEOGRAPH-#66EB, IRGKangXi=0501.430, RSKangXi=72.19
66EC CJK UNIFIED IDEOGRAPH-#66EC, IRGKangXi=0501.440, RSKangXi=72.19, Def{dry in sun, expose to sun}
66ED CJK UNIFIED IDEOGRAPH-#66ED, IRGKangXi=0501.480, RSKangXi=72.20
66EE CJK UNIFIED IDEOGRAPH-#66EE, IRGKangXi=0501.490, RSKangXi=72.20
66EF CJK UNIFIED IDEOGRAPH-#66EF, IRGKangXi=0501.510, RSKangXi=72.21
66F0 CJK UNIFIED IDEOGRAPH-#66F0, IRGKangXi=0502.010, RSKangXi=73.0, Def{say; KangXi radical 73}
66F1 CJK UNIFIED IDEOGRAPH-#66F1, IRGKangXi=0502.011, RSKangXi=102.0, Def{(Cant.) cockroach}
66F2 CJK UNIFIED IDEOGRAPH-#66F2, IRGKangXi=0502.020, RSKangXi=73.2, Def{crooked, bent; wrong, false}
66F3 CJK UNIFIED IDEOGRAPH-#66F3, IRGKangXi=0502.040, RSKangXi=73.2, Def{trail, tow, drag, pull}
66F4 CJK UNIFIED IDEOGRAPH-#66F4, IRGKangXi=0502.060, RSKangXi=73.3, Def{more, still further, much more}
66F5 CJK UNIFIED IDEOGRAPH-#66F5, IRGKangXi=0502.061, RSKangXi=73.3, Def{trail, tow, drag, pull}
66F6 CJK UNIFIED IDEOGRAPH-#66F6, IRGKangXi=0492.020, RSKangXi=73.4
66F7 CJK UNIFIED IDEOGRAPH-#66F7, IRGKangXi=0502.100, RSKangXi=73.5, Def{why? what? where?}
66F8 CJK UNIFIED IDEOGRAPH-#66F8, IRGKangXi=0502.120, RSKangXi=73.6, Def{book, letter, document; writings}
66F9 CJK UNIFIED IDEOGRAPH-#66F9, IRGKangXi=0502.130, RSKangXi=73.7, Def{ministry officials; surname}
66FA CJK UNIFIED IDEOGRAPH-#66FA, IRGKangXi=0503.011, RSKangXi=73.6
66FB CJK UNIFIED IDEOGRAPH-#66FB, IRGKangXi=0503.011, RSKangXi=72.7
66FC CJK UNIFIED IDEOGRAPH-#66FC, IRGKangXi=0503.020, RSKangXi=72.7, Def{long, extended, vast; beautiful}
66FD CJK UNIFIED IDEOGRAPH-#66FD, IRGKangXi=0503.021, RSKangXi=72.7, Def{already; sign of past}
66FE CJK UNIFIED IDEOGRAPH-#66FE, IRGKangXi=0503.030, RSKangXi=73.8, Def{already; sign of past}
66FF CJK UNIFIED IDEOGRAPH-#66FF, IRGKangXi=0503.040, RSKangXi=73.8, Def{change, replace, substitute for}
6700 CJK UNIFIED IDEOGRAPH-#6700, IRGKangXi=0503.050, RSKangXi=73.8, Def{most, extremely, exceedingly}
6701 CJK UNIFIED IDEOGRAPH-#6701, IRGKangXi=0503.070, RSKangXi=73.8, Def{if, supposing, nevertheless}
6702 CJK UNIFIED IDEOGRAPH-#6702, IRGKangXi=0503.071, RSKangXi=73.8
6703 CJK UNIFIED IDEOGRAPH-#6703, IRGKangXi=0503.080, RSKangXi=73.9, Def{to assemble, meet together; a meeting; an organization}
6704 CJK UNIFIED IDEOGRAPH-#6704, IRGKangXi=0504.020, RSKangXi=73.10
6705 CJK UNIFIED IDEOGRAPH-#6705, IRGKangXi=0504.030, RSKangXi=73.10, Def{brave}
6706 CJK UNIFIED IDEOGRAPH-#6706, IRGKangXi=0504.091, RSKangXi=73.12
6707 CJK UNIFIED IDEOGRAPH-#6707, IRGKangXi=0504.160, RSKangXi=73.17
6708 CJK UNIFIED IDEOGRAPH-#6708, IRGKangXi=0504.190, RSKangXi=74.0, Def{moon; month; KangXi radical 74}
6709 CJK UNIFIED IDEOGRAPH-#6709, IRGKangXi=0504.200, RSKangXi=74.2, Def{have, own, possess; exist}
670A CJK UNIFIED IDEOGRAPH-#670A, IRGKangXi=0504.280, RSKangXi=130.4
670B CJK UNIFIED IDEOGRAPH-#670B, IRGKangXi=0504.290, RSKangXi=74.4, Def{friend, pal, acquaintance}
670C CJK UNIFIED IDEOGRAPH-#670C, IRGKangXi=0504.320, RSKangXi=74.4, Def{distribute, large head}
670D CJK UNIFIED IDEOGRAPH-#670D, IRGKangXi=0505.020, RSKangXi=74.4, Def{clothes; wear, dress}
670E CJK UNIFIED IDEOGRAPH-#670E, IRGKangXi=0505.050, RSKangXi=74.5
670F CJK UNIFIED IDEOGRAPH-#670F, IRGKangXi=0505.080, RSKangXi=74.5, Def{light of crescent moon}
6710 CJK UNIFIED IDEOGRAPH-#6710, IRGKangXi=0505.100, RSKangXi=74.5, Def{warm}
6711 CJK UNIFIED IDEOGRAPH-#6711, IRGKangXi=0505.111, RSKangXi=130.5
6712 CJK UNIFIED IDEOGRAPH-#6712, IRGKangXi=0505.130, RSKangXi=74.6
6713 CJK UNIFIED IDEOGRAPH-#6713, IRGKangXi=0505.150, RSKangXi=74.6, Def{sacrifice}
6714 CJK UNIFIED IDEOGRAPH-#6714, IRGKangXi=0505.160, RSKangXi=74.6, Def{first day of lunar month; the north}
6715 CJK UNIFIED IDEOGRAPH-#6715, IRGKangXi=0505.190, RSKangXi=74.6, Def{pronoun 'I'}
6716 CJK UNIFIED IDEOGRAPH-#6716, IRGKangXi=0505.220, RSKangXi=74.7, Def{clear, bright; distinct}
6717 CJK UNIFIED IDEOGRAPH-#6717, IRGKangXi=0505.230, RSKangXi=74.7, Def{clear, bright; distinct}
6718 CJK UNIFIED IDEOGRAPH-#6718, IRGKangXi=0505.260, RSKangXi=74.7, Def{wane, reduce, contract; exploit}
6719 CJK UNIFIED IDEOGRAPH-#6719, IRGKangXi=0505.270, RSKangXi=74.7, Def{bright, clear, intelligent; light, brilliant; to understand; to illustrate}
671A CJK UNIFIED IDEOGRAPH-#671A, IRGKangXi=0505.280, RSKangXi=74.7
671B CJK UNIFIED IDEOGRAPH-#671B, IRGKangXi=0505.290, RSKangXi=74.7, Def{to look at, look forward; to hope, expect}
671C CJK UNIFIED IDEOGRAPH-#671C, IRGKangXi=0506.020, RSKangXi=74.8
671D CJK UNIFIED IDEOGRAPH-#671D, IRGKangXi=0506.030, RSKangXi=74.8, Def{dynasty; morning}
671E CJK UNIFIED IDEOGRAPH-#671E, IRGKangXi=0506.070, RSKangXi=74.8, Def{full year, anniversary}
671F CJK UNIFIED IDEOGRAPH-#671F, IRGKangXi=0506.110, RSKangXi=74.8, Def{period of time; date; time limit}
6720 CJK UNIFIED IDEOGRAPH-#6720, IRGKangXi=0506.190, RSKangXi=74.9, Def{color of the moon}
6721 CJK UNIFIED IDEOGRAPH-#6721, IRGKangXi=0506.210, RSKangXi=74.9
6722 CJK UNIFIED IDEOGRAPH-#6722, IRGKangXi=0506.240, RSKangXi=74.10, Def{look at, gaze at; hope, expect}
6723 CJK UNIFIED IDEOGRAPH-#6723, IRGKangXi=0506.310, RSKangXi=74.12, Def{the rising moon}
6724 CJK UNIFIED IDEOGRAPH-#6724, IRGKangXi=0506.330, RSKangXi=74.12
6725 CJK UNIFIED IDEOGRAPH-#6725, IRGKangXi=0506.341, RSKangXi=130.12
6726 CJK UNIFIED IDEOGRAPH-#6726, IRGKangXi=0507.030, RSKangXi=74.14, Def{condition or appearance of moon}
6727 CJK UNIFIED IDEOGRAPH-#6727, IRGKangXi=0507.040, RSKangXi=74.16, Def{condition or appearance of moon}
6728 CJK UNIFIED IDEOGRAPH-#6728, IRGKangXi=0509.010, RSKangXi=75.0, Def{tree; wood, lumber; wooden}
6729 CJK UNIFIED IDEOGRAPH-#6729, IRGKangXi=0509.011, Def{kwukyel: rank, grade; wait; equal; 'etc.'}
672A CJK UNIFIED IDEOGRAPH-#672A, IRGKangXi=0509.050, RSKangXi=75.1, Def{not yet; 8th terrestrial branch}
672B CJK UNIFIED IDEOGRAPH-#672B, IRGKangXi=0509.060, RSKangXi=75.1, Def{final, last, end; insignificant}
672C CJK UNIFIED IDEOGRAPH-#672C, IRGKangXi=0509.070, RSKangXi=75.1, Def{root, origin, source; basis}
672D CJK UNIFIED IDEOGRAPH-#672D, IRGKangXi=0509.110, RSKangXi=75.1, Def{letter, note; correspondence}
672E CJK UNIFIED IDEOGRAPH-#672E, IRGKangXi=0509.120, RSKangXi=75.1, Def{skill, art; method; trick, device}
672F CJK UNIFIED IDEOGRAPH-#672F, IRGKangXi=0509.121, RSKangXi=75.1, Def{art, skill, special feat; method, technique}
6730 CJK UNIFIED IDEOGRAPH-#6730, IRGKangXi=0509.121, RSKangXi=5.4, Def{kwukyel}
6731 CJK UNIFIED IDEOGRAPH-#6731, IRGKangXi=0509.130, RSKangXi=75.2, Def{cinnabar, vermilion; surname}
6732 CJK UNIFIED IDEOGRAPH-#6732, IRGKangXi=0510.010, RSKangXi=75.2
6733 CJK UNIFIED IDEOGRAPH-#6733, IRGKangXi=0510.030, RSKangXi=75.2, Def{tree}
6734 CJK UNIFIED IDEOGRAPH-#6734, IRGKangXi=0510.040, RSKangXi=75.2, Def{simple, unadorned; sincere; surname; a tree}
6735 CJK UNIFIED IDEOGRAPH-#6735, IRGKangXi=0510.050, RSKangXi=75.2, Def{cluster of flowers; earlobe}
6736 CJK UNIFIED IDEOGRAPH-#6736, IRGKangXi=0510.070, RSKangXi=75.2, Def{cluster of flowers; earlobe}
6737 CJK UNIFIED IDEOGRAPH-#6737, IRGKangXi=0510.090, RSKangXi=75.2
6738 CJK UNIFIED IDEOGRAPH-#6738, IRGKangXi=0510.100, RSKangXi=75.2
6739 CJK UNIFIED IDEOGRAPH-#6739, IRGKangXi=0510.110, RSKangXi=75.2
673A CJK UNIFIED IDEOGRAPH-#673A, IRGKangXi=0510.120, RSKangXi=75.2, Def{desk; machine; moment}
673B CJK UNIFIED IDEOGRAPH-#673B, IRGKangXi=0510.130, RSKangXi=75.2
673C CJK UNIFIED IDEOGRAPH-#673C, IRGKangXi=0510.150, RSKangXi=75.2
673D CJK UNIFIED IDEOGRAPH-#673D, IRGKangXi=0510.160, RSKangXi=75.2, Def{decayed, rotten; rot, decay}
673E CJK UNIFIED IDEOGRAPH-#673E, IRGKangXi=0510.170, RSKangXi=75.2, Def{to bump}
673F CJK UNIFIED IDEOGRAPH-#673F, IRGKangXi=0510.180, RSKangXi=75.2, Def{stab}
6740 CJK UNIFIED IDEOGRAPH-#6740, IRGKangXi=0510.181, RSKangXi=75.2, Def{kill, slaughter, murder; hurt}
6741 CJK UNIFIED IDEOGRAPH-#6741, IRGKangXi=0510.181, RSKangXi=75.2
6742 CJK UNIFIED IDEOGRAPH-#6742, IRGKangXi=0510.181, RSKangXi=75.2, Def{mixed, blended; mix, mingle}
6743 CJK UNIFIED IDEOGRAPH-#6743, IRGKangXi=0510.181, RSKangXi=75.2, Def{power, right, authority}
6744 CJK UNIFIED IDEOGRAPH-#6744, IRGKangXi=0510.190, RSKangXi=75.3
6745 CJK UNIFIED IDEOGRAPH-#6745, IRGKangXi=0510.200, RSKangXi=75.3, Def{tub}
6746 CJK UNIFIED IDEOGRAPH-#6746, IRGKangXi=0511.010, RSKangXi=75.3, Def{pole; shaft of spear}
6747 CJK UNIFIED IDEOGRAPH-#6747, IRGKangXi=0511.020, RSKangXi=75.3, Def{loquat}
6748 CJK UNIFIED IDEOGRAPH-#6748, IRGKangXi=0511.030, RSKangXi=75.3, Def{fork of a tree; a pitchfork}
6749 CJK UNIFIED IDEOGRAPH-#6749, IRGKangXi=0511.040, RSKangXi=75.3, Def{various species of pine and fir}
674A CJK UNIFIED IDEOGRAPH-#674A, IRGKangXi=0511.070, RSKangXi=75.3
674B CJK UNIFIED IDEOGRAPH-#674B, IRGKangXi=0511.080, RSKangXi=75.3
674C CJK UNIFIED IDEOGRAPH-#674C, IRGKangXi=0511.090, RSKangXi=75.3, Def{the stump f a tree, hence, sterility; a square stool}
674D CJK UNIFIED IDEOGRAPH-#674D, IRGKangXi=0511.100, RSKangXi=75.3
674E CJK UNIFIED IDEOGRAPH-#674E, IRGKangXi=0511.110, RSKangXi=75.3, Def{plum; judge; surname}
674F CJK UNIFIED IDEOGRAPH-#674F, IRGKangXi=0511.140, RSKangXi=75.3, Def{apricot; almond}
6750 CJK UNIFIED IDEOGRAPH-#6750, IRGKangXi=0511.160, RSKangXi=75.3, Def{material, stuff; timber; talent}
6751 CJK UNIFIED IDEOGRAPH-#6751, IRGKangXi=0511.170, RSKangXi=75.3, Def{village, hamlet; uncouth, vulgar}
6752 CJK UNIFIED IDEOGRAPH-#6752, IRGKangXi=0511.180, RSKangXi=75.3
6753 CJK UNIFIED IDEOGRAPH-#6753, IRGKangXi=0511.190, RSKangXi=75.3, Def{handle of cup, ladle, spoon; name of a constellation}
6754 CJK UNIFIED IDEOGRAPH-#6754, IRGKangXi=0511.200, RSKangXi=75.3
6755 CJK UNIFIED IDEOGRAPH-#6755, IRGKangXi=0511.210, RSKangXi=75.3, Def{alone}
6756 CJK UNIFIED IDEOGRAPH-#6756, IRGKangXi=0512.010, RSKangXi=75.3, Def{cane, walking stick}
6757 CJK UNIFIED IDEOGRAPH-#6757, IRGKangXi=0512.020, RSKangXi=75.3, Def{beam}
6758 CJK UNIFIED IDEOGRAPH-#6758, IRGKangXi=0512.040, RSKangXi=75.3
6759 CJK UNIFIED IDEOGRAPH-#6759, IRGKangXi=0512.050, RSKangXi=75.3, Def{a tiny wooden post; peg}
675A CJK UNIFIED IDEOGRAPH-#675A, IRGKangXi=0512.060, RSKangXi=75.3
675B CJK UNIFIED IDEOGRAPH-#675B, IRGKangXi=0512.070, RSKangXi=75.3
675C CJK UNIFIED IDEOGRAPH-#675C, IRGKangXi=0512.090, RSKangXi=75.3, Def{stop, prevent; restrict; surname}
675D CJK UNIFIED IDEOGRAPH-#675D, IRGKangXi=0512.100, RSKangXi=75.3, Def{tree}
675E CJK UNIFIED IDEOGRAPH-#675E, IRGKangXi=0512.110, RSKangXi=75.3, Def{willow; medlar tree; a small feudal state (Qi)}
675F CJK UNIFIED IDEOGRAPH-#675F, IRGKangXi=0512.120, RSKangXi=75.3, Def{bind, control, restrain; bale}
6760 CJK UNIFIED IDEOGRAPH-#6760, IRGKangXi=0512.130, RSKangXi=75.3, Def{lever, pole, crowbar; sharpen}
6761 CJK UNIFIED IDEOGRAPH-#6761, IRGKangXi=0513.011, RSKangXi=75.3, Def{clause, condition; string, stripe}
6762 CJK UNIFIED IDEOGRAPH-#6762, IRGKangXi=0513.011, RSKangXi=75.3, Def{woodworker}
6763 CJK UNIFIED IDEOGRAPH-#6763, IRGKangXi=0513.011, RSKangXi=75.3, Def{timber forest; timber, lumber; woodcutter}
6764 CJK UNIFIED IDEOGRAPH-#6764, IRGKangXi=0513.011, RSKangXi=75.3, Def{type of oak; stable}
6765 CJK UNIFIED IDEOGRAPH-#6765, IRGKangXi=0513.011, RSKangXi=75.3, Def{come, coming; return, returning}
6766 CJK UNIFIED IDEOGRAPH-#6766, IRGKangXi=0513.011, RSKangXi=75.3
6767 CJK UNIFIED IDEOGRAPH-#6767, IRGKangXi=0513.011, RSKangXi=75.3, Def{mango (Mangifera indica)}
6768 CJK UNIFIED IDEOGRAPH-#6768, IRGKangXi=0513.011, RSKangXi=75.3, Def{willow, poplar, aspen; surname}
6769 CJK UNIFIED IDEOGRAPH-#6769, IRGKangXi=0513.011, RSKangXi=75.3, Def{headboard}
676A CJK UNIFIED IDEOGRAPH-#676A, IRGKangXi=0513.020, RSKangXi=75.4, Def{tip of twig, top of tree; twig}
676B CJK UNIFIED IDEOGRAPH-#676B, IRGKangXi=0513.030, RSKangXi=75.4
676C CJK UNIFIED IDEOGRAPH-#676C, IRGKangXi=0513.050, RSKangXi=75.4
676D CJK UNIFIED IDEOGRAPH-#676D, IRGKangXi=0513.060, RSKangXi=75.4, Def{cross stream; navigate}
676E CJK UNIFIED IDEOGRAPH-#676E, IRGKangXi=0513.080, RSKangXi=75.4, Def{wood shavings}
676F CJK UNIFIED IDEOGRAPH-#676F, IRGKangXi=0513.090, RSKangXi=75.4, Def{cup, glass}
6770 CJK UNIFIED IDEOGRAPH-#6770, IRGKangXi=0513.110, RSKangXi=75.4, Def{hero; heroic, outstanding}
6771 CJK UNIFIED IDEOGRAPH-#6771, IRGKangXi=0513.120, RSKangXi=75.4, Def{east, eastern, eastward}
6772 CJK UNIFIED IDEOGRAPH-#6772, IRGKangXi=0513.130, RSKangXi=75.4, Def{bright sun; brilliant; high}
6773 CJK UNIFIED IDEOGRAPH-#6773, IRGKangXi=0513.140, RSKangXi=75.4, Def{obscure, dark, mysterious, deep}
6774 CJK UNIFIED IDEOGRAPH-#6774, IRGKangXi=0513.150, RSKangXi=75.4, Def{shovel; trough used to carry water}
6775 CJK UNIFIED IDEOGRAPH-#6775, IRGKangXi=0513.170, RSKangXi=75.4, Def{pestle; baton used beat clothes}
6776 CJK UNIFIED IDEOGRAPH-#6776, IRGKangXi=0513.180, RSKangXi=75.4, Def{varnish}
6777 CJK UNIFIED IDEOGRAPH-#6777, IRGKangXi=0513.190, RSKangXi=75.4, Def{loquat}
6778 CJK UNIFIED IDEOGRAPH-#6778, IRGKangXi=0514.020, RSKangXi=75.4, Def{to kill; a spear}
6779 CJK UNIFIED IDEOGRAPH-#6779, IRGKangXi=0514.050, RSKangXi=75.4
677A CJK UNIFIED IDEOGRAPH-#677A, IRGKangXi=0514.060, RSKangXi=75.4
677B CJK UNIFIED IDEOGRAPH-#677B, IRGKangXi=0514.070, RSKangXi=75.4, Def{ligustrum sinenese, tree}
677C CJK UNIFIED IDEOGRAPH-#677C, IRGKangXi=0514.080, RSKangXi=75.4, Def{shuttle of loom; narrow; long-headed; a scrub oak; thin}
677D CJK UNIFIED IDEOGRAPH-#677D, IRGKangXi=0514.100, RSKangXi=75.4
677E CJK UNIFIED IDEOGRAPH-#677E, IRGKangXi=0514.110, RSKangXi=75.4, Def{pine tree; fir tree}
677F CJK UNIFIED IDEOGRAPH-#677F, IRGKangXi=0514.150, RSKangXi=75.4, Def{plank, board; iron or tin plate}
6780 CJK UNIFIED IDEOGRAPH-#6780, IRGKangXi=0514.160, RSKangXi=75.4
6781 CJK UNIFIED IDEOGRAPH-#6781, IRGKangXi=0514.170, RSKangXi=75.3, Def{extreme, utmost, furthest, final}
6782 CJK UNIFIED IDEOGRAPH-#6782, IRGKangXi=0514.190, RSKangXi=75.4
6783 CJK UNIFIED IDEOGRAPH-#6783, IRGKangXi=0514.200, RSKangXi=75.4
6784 CJK UNIFIED IDEOGRAPH-#6784, IRGKangXi=0514.210, RSKangXi=75.4, Def{frame, building, structure}
6785 CJK UNIFIED IDEOGRAPH-#6785, IRGKangXi=0514.230, RSKangXi=75.4
6786 CJK UNIFIED IDEOGRAPH-#6786, IRGKangXi=0514.240, RSKangXi=75.4
6787 CJK UNIFIED IDEOGRAPH-#6787, IRGKangXi=0514.260, RSKangXi=75.4, Def{loquat}
6788 CJK UNIFIED IDEOGRAPH-#6788, IRGKangXi=0514.270, RSKangXi=75.4
6789 CJK UNIFIED IDEOGRAPH-#6789, IRGKangXi=0514.280, RSKangXi=75.4, Def{useless, in vain; bent, crooked}
678A CJK UNIFIED IDEOGRAPH-#678A, IRGKangXi=0515.010, RSKangXi=75.4
678B CJK UNIFIED IDEOGRAPH-#678B, IRGKangXi=0515.020, RSKangXi=75.4, Def{sandalwood; tree used as timber}
678C CJK UNIFIED IDEOGRAPH-#678C, IRGKangXi=0515.040, RSKangXi=75.4, Def{variety of elm with small seeds}
678D CJK UNIFIED IDEOGRAPH-#678D, IRGKangXi=0515.050, RSKangXi=75.4
678E CJK UNIFIED IDEOGRAPH-#678E, IRGKangXi=0515.060, RSKangXi=75.4
678F CJK UNIFIED IDEOGRAPH-#678F, IRGKangXi=0515.070, RSKangXi=75.4, Def{a variety of evergreen tree}
6790 CJK UNIFIED IDEOGRAPH-#6790, IRGKangXi=0515.080, RSKangXi=75.4, Def{split wood; break apart; divide}
6791 CJK UNIFIED IDEOGRAPH-#6791, IRGKangXi=0515.100, RSKangXi=75.4
6792 CJK UNIFIED IDEOGRAPH-#6792, IRGKangXi=0515.120, RSKangXi=75.4, Def{the coconut tree; rim}
6793 CJK UNIFIED IDEOGRAPH-#6793, IRGKangXi=0515.130, RSKangXi=75.4, Def{capital}
6794 CJK UNIFIED IDEOGRAPH-#6794, IRGKangXi=0515.150, RSKangXi=75.4
6795 CJK UNIFIED IDEOGRAPH-#6795, IRGKangXi=0515.160, RSKangXi=75.4, Def{pillow}
6796 CJK UNIFIED IDEOGRAPH-#6796, IRGKangXi=0516.030, RSKangXi=75.4
6797 CJK UNIFIED IDEOGRAPH-#6797, IRGKangXi=0516.050, RSKangXi=75.4, Def{forest, grove; surname}
6798 CJK UNIFIED IDEOGRAPH-#6798, IRGKangXi=0516.060, RSKangXi=75.4, Def{the handle of tools}
6799 CJK UNIFIED IDEOGRAPH-#6799, IRGKangXi=0516.070, RSKangXi=75.4
679A CJK UNIFIED IDEOGRAPH-#679A, IRGKangXi=0516.080, RSKangXi=75.4, Def{stalk of shrub, trunk of tree}
679B CJK UNIFIED IDEOGRAPH-#679B, IRGKangXi=0516.090, RSKangXi=75.4
679C CJK UNIFIED IDEOGRAPH-#679C, IRGKangXi=0516.110, RSKangXi=75.4, Def{fruit; result}
679D CJK UNIFIED IDEOGRAPH-#679D, IRGKangXi=0516.120, RSKangXi=75.4, Def{branches, limbs; branch off}
679E CJK UNIFIED IDEOGRAPH-#679E, IRGKangXi=0516.130, RSKangXi=75.4, Def{fir tree}
679F CJK UNIFIED IDEOGRAPH-#679F, IRGKangXi=0517.011, RSKangXi=75.4, Def{wood streaks}
67A0 CJK UNIFIED IDEOGRAPH-#67A0, IRGKangXi=0517.011, RSKangXi=75.4, Def{a frame; a reel, spindle, spool}
67A1 CJK UNIFIED IDEOGRAPH-#67A1, IRGKangXi=0517.011, RSKangXi=75.4, Def{measuring box}
67A2 CJK UNIFIED IDEOGRAPH-#67A2, IRGKangXi=0517.011, RSKangXi=75.4, Def{door hinge; pivot; center of power}
67A3 CJK UNIFIED IDEOGRAPH-#67A3, IRGKangXi=0517.011, RSKangXi=75.4, Def{date tree; dates, jujubes; surname}
67A4 CJK UNIFIED IDEOGRAPH-#67A4, IRGKangXi=0517.011, RSKangXi=75.4
67A5 CJK UNIFIED IDEOGRAPH-#67A5, IRGKangXi=0517.011, RSKangXi=75.4, Def{type of oak; stable}
67A6 CJK UNIFIED IDEOGRAPH-#67A6, IRGKangXi=0517.011, RSKangXi=75.4
67A7 CJK UNIFIED IDEOGRAPH-#67A7, IRGKangXi=0517.011, RSKangXi=75.4, Def{bamboo tube, wooden peg; spout}
67A8 CJK UNIFIED IDEOGRAPH-#67A8, IRGKangXi=0517.011, RSKangXi=75.4, Def{door stop, door jam; touch; (Cant.) to use the body to move someone}
67A9 CJK UNIFIED IDEOGRAPH-#67A9, IRGKangXi=0517.011, RSKangXi=75.4, Def{pine tree; fir tree}
67AA CJK UNIFIED IDEOGRAPH-#67AA, IRGKangXi=0517.011, RSKangXi=75.4, Def{spear, lance; gun, rifle}
67AB CJK UNIFIED IDEOGRAPH-#67AB, IRGKangXi=0517.011, RSKangXi=75.4, Def{maple tree}
67AC CJK UNIFIED IDEOGRAPH-#67AC, IRGKangXi=0517.011, RSKangXi=75.4, Def{an even-grained, yellowish, fine wood used for furniture; cedar}
67AD CJK UNIFIED IDEOGRAPH-#67AD, IRGKangXi=0517.011, RSKangXi=75.4, Def{owl thus, something evil}
67AE CJK UNIFIED IDEOGRAPH-#67AE, IRGKangXi=0517.020, RSKangXi=75.5
67AF CJK UNIFIED IDEOGRAPH-#67AF, IRGKangXi=0517.030, RSKangXi=75.5, Def{dried out, withered, decayed}
67B0 CJK UNIFIED IDEOGRAPH-#67B0, IRGKangXi=0517.040, RSKangXi=75.5, Def{smooth board; chessboard; chess}
67B1 CJK UNIFIED IDEOGRAPH-#67B1, IRGKangXi=0517.050, RSKangXi=75.5, Def{a table, desk}
67B2 CJK UNIFIED IDEOGRAPH-#67B2, IRGKangXi=0517.060, RSKangXi=75.5, Def{male nettle-hemp}
67B3 CJK UNIFIED IDEOGRAPH-#67B3, IRGKangXi=0517.070, RSKangXi=75.5, Def{trifoliate orange; hedge thorn; (Cant.) a plug}
67B4 CJK UNIFIED IDEOGRAPH-#67B4, IRGKangXi=0521.121, RSKangXi=75.5, Def{cane}
67B5 CJK UNIFIED IDEOGRAPH-#67B5, IRGKangXi=0517.090, RSKangXi=75.5, Def{hollo stump of a tree; empty, thin}
67B6 CJK UNIFIED IDEOGRAPH-#67B6, IRGKangXi=0517.100, RSKangXi=75.5, Def{rack, stand, prop; prop up}
67B7 CJK UNIFIED IDEOGRAPH-#67B7, IRGKangXi=0517.110, RSKangXi=75.5, Def{cangue scaffold}
67B8 CJK UNIFIED IDEOGRAPH-#67B8, IRGKangXi=0517.120, RSKangXi=75.5, Def{kind of aspen found in Sichuan}
67B9 CJK UNIFIED IDEOGRAPH-#67B9, IRGKangXi=0517.130, RSKangXi=75.5, Def{drumstick}
67BA CJK UNIFIED IDEOGRAPH-#67BA, IRGKangXi=0517.140, RSKangXi=75.5
67BB CJK UNIFIED IDEOGRAPH-#67BB, IRGKangXi=0517.160, RSKangXi=75.5, Def{long oar, sweep}
67BC CJK UNIFIED IDEOGRAPH-#67BC, IRGKangXi=0517.170, RSKangXi=75.5, Def{a table, flat pieces of wood, a slip, a leaf}
67BD CJK UNIFIED IDEOGRAPH-#67BD, IRGKangXi=0517.180, RSKangXi=75.5
67BE CJK UNIFIED IDEOGRAPH-#67BE, IRGKangXi=0517.190, RSKangXi=75.5, Def{persimmon}
67BF CJK UNIFIED IDEOGRAPH-#67BF, IRGKangXi=0518.020, RSKangXi=75.5
67C0 CJK UNIFIED IDEOGRAPH-#67C0, IRGKangXi=0518.030, RSKangXi=75.5
67C1 CJK UNIFIED IDEOGRAPH-#67C1, IRGKangXi=0518.040, RSKangXi=75.5, Def{large tie-beams}
67C2 CJK UNIFIED IDEOGRAPH-#67C2, IRGKangXi=0518.050, RSKangXi=75.5, Def{helm}
67C3 CJK UNIFIED IDEOGRAPH-#67C3, IRGKangXi=0518.060, RSKangXi=75.5
67C4 CJK UNIFIED IDEOGRAPH-#67C4, IRGKangXi=0518.080, RSKangXi=75.5, Def{handle, lever, knob; authority}
67C5 CJK UNIFIED IDEOGRAPH-#67C5, IRGKangXi=0518.100, RSKangXi=75.5, Def{flourish}
67C6 CJK UNIFIED IDEOGRAPH-#67C6, IRGKangXi=0518.110, RSKangXi=75.5
67C7 CJK UNIFIED IDEOGRAPH-#67C7, IRGKangXi=0518.120, RSKangXi=75.5
67C8 CJK UNIFIED IDEOGRAPH-#67C8, IRGKangXi=0518.130, RSKangXi=75.5, Def{container}
67C9 CJK UNIFIED IDEOGRAPH-#67C9, IRGKangXi=0518.140, RSKangXi=75.5
67CA CJK UNIFIED IDEOGRAPH-#67CA, IRGKangXi=0518.150, RSKangXi=75.5, Def{holly}
67CB CJK UNIFIED IDEOGRAPH-#67CB, IRGKangXi=0518.170, RSKangXi=75.5
67CC CJK UNIFIED IDEOGRAPH-#67CC, IRGKangXi=0518.180, RSKangXi=75.5
67CD CJK UNIFIED IDEOGRAPH-#67CD, IRGKangXi=0518.200, RSKangXi=75.5
67CE CJK UNIFIED IDEOGRAPH-#67CE, IRGKangXi=0518.210, RSKangXi=75.5, Def{calyx of flower; railing raft}
67CF CJK UNIFIED IDEOGRAPH-#67CF, IRGKangXi=0518.220, RSKangXi=75.5, Def{cypress, cedar}
67D0 CJK UNIFIED IDEOGRAPH-#67D0, IRGKangXi=0519.010, RSKangXi=75.5, Def{certain thing or person}
67D1 CJK UNIFIED IDEOGRAPH-#67D1, IRGKangXi=0519.020, RSKangXi=75.5, Def{tangerine, loose-skinned orange}
67D2 CJK UNIFIED IDEOGRAPH-#67D2, IRGKangXi=0519.030, RSKangXi=75.5, AccountingNumeric=7, Def{number seven}
67D3 CJK UNIFIED IDEOGRAPH-#67D3, IRGKangXi=0519.040, RSKangXi=75.5, Def{dye; be contagious; infect}
67D4 CJK UNIFIED IDEOGRAPH-#67D4, IRGKangXi=0519.050, RSKangXi=75.5, Def{soft; gentle, pliant}
67D5 CJK UNIFIED IDEOGRAPH-#67D5, IRGKangXi=0519.060, RSKangXi=75.5
67D6 CJK UNIFIED IDEOGRAPH-#67D6, IRGKangXi=0519.070, RSKangXi=75.5
67D7 CJK UNIFIED IDEOGRAPH-#67D7, IRGKangXi=0519.080, RSKangXi=75.5
67D8 CJK UNIFIED IDEOGRAPH-#67D8, IRGKangXi=0519.090, RSKangXi=75.5, Def{a thorny tree; sugarcane}
67D9 CJK UNIFIED IDEOGRAPH-#67D9, IRGKangXi=0519.100, RSKangXi=75.5, Def{cage, pen for wild animals}
67DA CJK UNIFIED IDEOGRAPH-#67DA, IRGKangXi=0519.120, RSKangXi=75.5, Def{pomelo, grapefruit}
67DB CJK UNIFIED IDEOGRAPH-#67DB, IRGKangXi=0519.130, RSKangXi=75.5
67DC CJK UNIFIED IDEOGRAPH-#67DC, IRGKangXi=0519.140, RSKangXi=75.5, Def{cabinet, cupboard; shop counter}
67DD CJK UNIFIED IDEOGRAPH-#67DD, IRGKangXi=0519.160, RSKangXi=75.5, Def{watchman's rattle}
67DE CJK UNIFIED IDEOGRAPH-#67DE, IRGKangXi=0519.190, RSKangXi=75.5, Def{oak; spinous evergreen tree; to clear away trees}
67DF CJK UNIFIED IDEOGRAPH-#67DF, IRGKangXi=0520.010, RSKangXi=75.5, Def{Machilus nanmu, variety of evergreen}
67E0 CJK UNIFIED IDEOGRAPH-#67E0, IRGKangXi=0520.020, RSKangXi=75.5, Def{lemon}
67E1 CJK UNIFIED IDEOGRAPH-#67E1, IRGKangXi=0520.030, RSKangXi=75.5
67E2 CJK UNIFIED IDEOGRAPH-#67E2, IRGKangXi=0520.040, RSKangXi=75.5, Def{root, base; bottom of object}
67E3 CJK UNIFIED IDEOGRAPH-#67E3, IRGKangXi=0520.050, RSKangXi=75.5, Def{sill}
67E4 CJK UNIFIED IDEOGRAPH-#67E4, IRGKangXi=0520.060, RSKangXi=75.5, Def{hawthorn}
67E5 CJK UNIFIED IDEOGRAPH-#67E5, IRGKangXi=0520.070, RSKangXi=75.5, Def{investigate, examine, seek into}
67E6 CJK UNIFIED IDEOGRAPH-#67E6, IRGKangXi=0520.080, RSKangXi=75.5
67E7 CJK UNIFIED IDEOGRAPH-#67E7, IRGKangXi=0520.090, RSKangXi=75.5
67E8 CJK UNIFIED IDEOGRAPH-#67E8, IRGKangXi=0520.120, RSKangXi=75.5
67E9 CJK UNIFIED IDEOGRAPH-#67E9, IRGKangXi=0520.140, RSKangXi=75.5, Def{coffin which contains corpse}
67EA CJK UNIFIED IDEOGRAPH-#67EA, IRGKangXi=0520.150, RSKangXi=75.5
67EB CJK UNIFIED IDEOGRAPH-#67EB, IRGKangXi=0520.180, RSKangXi=75.5
67EC CJK UNIFIED IDEOGRAPH-#67EC, IRGKangXi=0520.190, RSKangXi=75.5, Def{letter, invitation; choose}
67ED CJK UNIFIED IDEOGRAPH-#67ED, IRGKangXi=0520.200, RSKangXi=75.5
67EE CJK UNIFIED IDEOGRAPH-#67EE, IRGKangXi=0520.210, RSKangXi=75.5, Def{flat pieces of wood, scraps of wood}
67EF CJK UNIFIED IDEOGRAPH-#67EF, IRGKangXi=0520.220, RSKangXi=75.5, Def{axe-handle; stalk, bough; surname}
67F0 CJK UNIFIED IDEOGRAPH-#67F0, IRGKangXi=0520.230, RSKangXi=75.5, Def{crab-apple tree; endure, bear}
67F1 CJK UNIFIED IDEOGRAPH-#67F1, IRGKangXi=0520.240, RSKangXi=75.5, Def{pillar, post; support; lean on}
67F2 CJK UNIFIED IDEOGRAPH-#67F2, IRGKangXi=0521.010, RSKangXi=75.5, Def{handle}
67F3 CJK UNIFIED IDEOGRAPH-#67F3, IRGKangXi=0521.020, RSKangXi=75.5, Def{willow tree; pleasure}
67F4 CJK UNIFIED IDEOGRAPH-#67F4, IRGKangXi=0521.060, RSKangXi=75.5, Def{firewood, faggots, fuel}
67F5 CJK UNIFIED IDEOGRAPH-#67F5, IRGKangXi=0521.121, RSKangXi=75.5, Def{fence; palisade; grid}
67F6 CJK UNIFIED IDEOGRAPH-#67F6, IRGKangXi=0521.080, RSKangXi=75.5, Def{ladle}
67F7 CJK UNIFIED IDEOGRAPH-#67F7, IRGKangXi=0521.090, RSKangXi=75.5, Def{instrument}
67F8 CJK UNIFIED IDEOGRAPH-#67F8, IRGKangXi=0521.110, RSKangXi=75.5, Def{cup (same as 杯 [U+676F] and 桮 [U+686E]); unhappy, displeased, anxious, unsettled}
67F9 CJK UNIFIED IDEOGRAPH-#67F9, IRGKangXi=0521.121, RSKangXi=75.5, Def{persimmon}
67FA CJK UNIFIED IDEOGRAPH-#67FA, IRGKangXi=0517.080, RSKangXi=75.5, Def{an old man's staff}
67FB CJK UNIFIED IDEOGRAPH-#67FB, IRGKangXi=0521.121, RSKangXi=75.5, Def{investigate, examine, seek into}
67FC CJK UNIFIED IDEOGRAPH-#67FC, IRGKangXi=0521.121, RSKangXi=75.5
67FD CJK UNIFIED IDEOGRAPH-#67FD, IRGKangXi=0521.121, RSKangXi=75.5, Def{type of willow; tamarisk}
67FE CJK UNIFIED IDEOGRAPH-#67FE, IRGKangXi=0521.121, RSKangXi=75.5, Def{straight grain}
67FF CJK UNIFIED IDEOGRAPH-#67FF, IRGKangXi=0521.121, RSKangXi=75.5, Def{persimmon}
6800 CJK UNIFIED IDEOGRAPH-#6800, IRGKangXi=0521.121, RSKangXi=75.5, Def{gardenia}
6801 CJK UNIFIED IDEOGRAPH-#6801, IRGKangXi=0521.121, RSKangXi=75.5
6802 CJK UNIFIED IDEOGRAPH-#6802, IRGKangXi=0521.121, RSKangXi=75.5, Def{a kind of evergreen tree}
6803 CJK UNIFIED IDEOGRAPH-#6803, IRGKangXi=0521.121, RSKangXi=75.5, Def{type of oak; stable}
6804 CJK UNIFIED IDEOGRAPH-#6804, IRGKangXi=0521.121, RSKangXi=75.5, Def{glory, honor; flourish, prosper}
6805 CJK UNIFIED IDEOGRAPH-#6805, IRGKangXi=0521.121, RSKangXi=75.5, Def{fence; palisade; grid}
6806 CJK UNIFIED IDEOGRAPH-#6806, IRGKangXi=0521.121, RSKangXi=75.5
6807 CJK UNIFIED IDEOGRAPH-#6807, IRGKangXi=0521.121, RSKangXi=75.5, Def{mark, symbol, label, sign; stand the bole of a tree}
6808 CJK UNIFIED IDEOGRAPH-#6808, IRGKangXi=0521.121, RSKangXi=75.5, Def{warehouse; tavern, inn}
6809 CJK UNIFIED IDEOGRAPH-#6809, IRGKangXi=0521.121, RSKangXi=75.5, Def{comb; comb out; weed out, elimininate}
680A CJK UNIFIED IDEOGRAPH-#680A, IRGKangXi=0521.121, RSKangXi=75.5, Def{cage, pen; set of bars}
680B CJK UNIFIED IDEOGRAPH-#680B, IRGKangXi=0521.121, RSKangXi=75.5, Def{main beams supporting house}
680C CJK UNIFIED IDEOGRAPH-#680C, IRGKangXi=0521.121, RSKangXi=75.5, Def{supporting block; sumac, loquat}
680D CJK UNIFIED IDEOGRAPH-#680D, IRGKangXi=0521.121, RSKangXi=75.5, Def{a lot; a label; a slip of bamboo engraved with signs}
680E CJK UNIFIED IDEOGRAPH-#680E, IRGKangXi=0521.121, RSKangXi=75.5, Def{chestnut-leaved oak; oak}
680F CJK UNIFIED IDEOGRAPH-#680F, IRGKangXi=0521.121, RSKangXi=75.5, Def{railing, balustrade; animal pan}
6810 CJK UNIFIED IDEOGRAPH-#6810, IRGKangXi=0521.121, RSKangXi=75.5
6811 CJK UNIFIED IDEOGRAPH-#6811, IRGKangXi=0521.121, RSKangXi=75.5, Def{tree; plant; set up, establish}
6812 CJK UNIFIED IDEOGRAPH-#6812, IRGKangXi=0521.130, RSKangXi=75.6, Def{cross bar}
6813 CJK UNIFIED IDEOGRAPH-#6813, IRGKangXi=0521.140, RSKangXi=75.6, Def{wooden peg, post or stick}
6814 CJK UNIFIED IDEOGRAPH-#6814, IRGKangXi=0522.010, RSKangXi=75.6, Def{carve, engrave}
6815 CJK UNIFIED IDEOGRAPH-#6815, IRGKangXi=0522.020, RSKangXi=75.6
6816 CJK UNIFIED IDEOGRAPH-#6816, IRGKangXi=0522.030, RSKangXi=75.6, Def{perch; roost; stay}
6817 CJK UNIFIED IDEOGRAPH-#6817, IRGKangXi=0522.050, RSKangXi=75.6, Def{chestnut tree, chestnuts; surname}
6818 CJK UNIFIED IDEOGRAPH-#6818, IRGKangXi=0522.090, RSKangXi=75.6, Def{fruit tree}
6819 CJK UNIFIED IDEOGRAPH-#6819, IRGKangXi=0522.100, RSKangXi=75.6
681A CJK UNIFIED IDEOGRAPH-#681A, IRGKangXi=0522.110, RSKangXi=75.6
681B CJK UNIFIED IDEOGRAPH-#681B, IRGKangXi=0522.150, RSKangXi=75.6, Def{the lichee, a fruit which grows in South China}
681C CJK UNIFIED IDEOGRAPH-#681C, IRGKangXi=0522.180, RSKangXi=75.6
681D CJK UNIFIED IDEOGRAPH-#681D, IRGKangXi=0522.190, RSKangXi=75.6, Def{a builder's frame for measuring}
681E CJK UNIFIED IDEOGRAPH-#681E, IRGKangXi=0522.210, RSKangXi=75.6, Def{publication, periodical; publish}
681F CJK UNIFIED IDEOGRAPH-#681F, IRGKangXi=0522.230, RSKangXi=75.6, Def{hemp palm}
6820 CJK UNIFIED IDEOGRAPH-#6820, IRGKangXi=0522.240, RSKangXi=75.6
6821 CJK UNIFIED IDEOGRAPH-#6821, IRGKangXi=0522.250, RSKangXi=75.6, Def{school; military field officer}
6822 CJK UNIFIED IDEOGRAPH-#6822, IRGKangXi=0523.010, RSKangXi=75.6, Def{cypress, cedar}
6823 CJK UNIFIED IDEOGRAPH-#6823, IRGKangXi=0523.020, RSKangXi=75.6
6824 CJK UNIFIED IDEOGRAPH-#6824, IRGKangXi=0523.030, RSKangXi=75.6
6825 CJK UNIFIED IDEOGRAPH-#6825, IRGKangXi=0523.040, RSKangXi=75.6
6826 CJK UNIFIED IDEOGRAPH-#6826, IRGKangXi=0523.050, RSKangXi=75.6
6827 CJK UNIFIED IDEOGRAPH-#6827, IRGKangXi=0523.060, RSKangXi=75.6
6828 CJK UNIFIED IDEOGRAPH-#6828, IRGKangXi=0523.080, RSKangXi=75.6
6829 CJK UNIFIED IDEOGRAPH-#6829, IRGKangXi=0523.090, RSKangXi=75.6, Def{species of oak; be glad, be pleased}
682A CJK UNIFIED IDEOGRAPH-#682A, IRGKangXi=0523.110, RSKangXi=75.6, Def{numerary adjunct for trees; root}
682B CJK UNIFIED IDEOGRAPH-#682B, IRGKangXi=0523.120, RSKangXi=75.6, Def{fence}
682C CJK UNIFIED IDEOGRAPH-#682C, IRGKangXi=0523.140, RSKangXi=75.6
682D CJK UNIFIED IDEOGRAPH-#682D, IRGKangXi=0523.150, RSKangXi=75.6, Def{king-post}
682E CJK UNIFIED IDEOGRAPH-#682E, IRGKangXi=0523.160, RSKangXi=75.6
682F CJK UNIFIED IDEOGRAPH-#682F, IRGKangXi=0523.170, RSKangXi=75.6
6830 CJK UNIFIED IDEOGRAPH-#6830, IRGKangXi=0523.190, RSKangXi=75.6, Def{a bamboo raft}
6831 CJK UNIFIED IDEOGRAPH-#6831, IRGKangXi=0523.200, RSKangXi=75.6, Def{large peg, stake; post, pillar}
6832 CJK UNIFIED IDEOGRAPH-#6832, IRGKangXi=0523.220, RSKangXi=75.6, Def{mangrove}
6833 CJK UNIFIED IDEOGRAPH-#6833, IRGKangXi=0523.230, RSKangXi=75.6, Def{a basket}
6834 CJK UNIFIED IDEOGRAPH-#6834, IRGKangXi=0523.240, RSKangXi=75.6, Def{sandalwood}
6835 CJK UNIFIED IDEOGRAPH-#6835, IRGKangXi=0523.260, RSKangXi=75.6, Def{hedge}
6836 CJK UNIFIED IDEOGRAPH-#6836, IRGKangXi=0524.020, RSKangXi=75.6
6837 CJK UNIFIED IDEOGRAPH-#6837, IRGKangXi=0524.030, RSKangXi=75.6, Def{shape, form, pattern, style}
6838 CJK UNIFIED IDEOGRAPH-#6838, IRGKangXi=0524.040, RSKangXi=75.6, Def{seed, kernel, core, nut; atom}
6839 CJK UNIFIED IDEOGRAPH-#6839, IRGKangXi=0524.070, RSKangXi=75.6, Def{root, base(d on); foundation}
683A CJK UNIFIED IDEOGRAPH-#683A, IRGKangXi=0524.090, RSKangXi=75.6
683B CJK UNIFIED IDEOGRAPH-#683B, IRGKangXi=0524.100, RSKangXi=75.6, Def{tree}
683C CJK UNIFIED IDEOGRAPH-#683C, IRGKangXi=0524.110, RSKangXi=75.6, Def{pattern, standard, form; style}
683D CJK UNIFIED IDEOGRAPH-#683D, IRGKangXi=0524.120, RSKangXi=75.6, Def{to cultivate, plant; to care for plants}
683E CJK UNIFIED IDEOGRAPH-#683E, IRGKangXi=0524.130, RSKangXi=75.6, Def{name of tree; a part of cornice}
683F CJK UNIFIED IDEOGRAPH-#683F, IRGKangXi=0524.140, RSKangXi=75.6
6840 CJK UNIFIED IDEOGRAPH-#6840, IRGKangXi=0524.150, RSKangXi=75.6, Def{chicken roost; ancient emperor}
6841 CJK UNIFIED IDEOGRAPH-#6841, IRGKangXi=0525.010, RSKangXi=75.6, Def{cross-beams of roof}
6842 CJK UNIFIED IDEOGRAPH-#6842, IRGKangXi=0525.020, RSKangXi=75.6, Def{cassia or cinnamon}
6843 CJK UNIFIED IDEOGRAPH-#6843, IRGKangXi=0525.040, RSKangXi=75.6, Def{peach; marriage; surname}
6844 CJK UNIFIED IDEOGRAPH-#6844, IRGKangXi=0525.050, RSKangXi=75.6, Def{a coir-palm}
6845 CJK UNIFIED IDEOGRAPH-#6845, IRGKangXi=0525.060, RSKangXi=75.6, Def{mast of ship}
6846 CJK UNIFIED IDEOGRAPH-#6846, IRGKangXi=0525.070, RSKangXi=75.6, Def{frame; framework; door frame}
6847 CJK UNIFIED IDEOGRAPH-#6847, IRGKangXi=0525.080, RSKangXi=75.6
6848 CJK UNIFIED IDEOGRAPH-#6848, IRGKangXi=0525.090, RSKangXi=75.6, Def{table, bench; legal case}
6849 CJK UNIFIED IDEOGRAPH-#6849, IRGKangXi=0525.100, RSKangXi=75.6, Def{eucalyptus}
684A CJK UNIFIED IDEOGRAPH-#684A, IRGKangXi=0525.110, RSKangXi=75.6
684B CJK UNIFIED IDEOGRAPH-#684B, IRGKangXi=0525.120, RSKangXi=75.6, Def{tree}
684C CJK UNIFIED IDEOGRAPH-#684C, IRGKangXi=0525.130, RSKangXi=75.6, Def{table, desk, stand}
684D CJK UNIFIED IDEOGRAPH-#684D, IRGKangXi=0525.140, RSKangXi=75.6
684E CJK UNIFIED IDEOGRAPH-#684E, IRGKangXi=0525.150, RSKangXi=75.6, Def{fetters, shackles, handcuffs}
684F CJK UNIFIED IDEOGRAPH-#684F, IRGKangXi=0525.160, RSKangXi=75.6
6850 CJK UNIFIED IDEOGRAPH-#6850, IRGKangXi=0525.170, RSKangXi=75.6, Def{name applied various trees}
6851 CJK UNIFIED IDEOGRAPH-#6851, IRGKangXi=0526.010, RSKangXi=75.6, Def{mulberry tree; surname}
6852 CJK UNIFIED IDEOGRAPH-#6852, IRGKangXi=0526.040, RSKangXi=75.6
6853 CJK UNIFIED IDEOGRAPH-#6853, IRGKangXi=0526.050, RSKangXi=75.6, Def{variety of tree; surname}
6854 CJK UNIFIED IDEOGRAPH-#6854, IRGKangXi=0526.080, RSKangXi=75.6, Def{Chinese bellflower; well-swept; the inner fibers of corn-stalks}
6855 CJK UNIFIED IDEOGRAPH-#6855, IRGKangXi=0526.090, RSKangXi=75.6, Def{tallow tree}
6856 CJK UNIFIED IDEOGRAPH-#6856, IRGKangXi=0526.100, RSKangXi=75.6
6857 CJK UNIFIED IDEOGRAPH-#6857, IRGKangXi=0526.110, RSKangXi=75.6
6858 CJK UNIFIED IDEOGRAPH-#6858, IRGKangXi=0526.120, RSKangXi=75.6
6859 CJK UNIFIED IDEOGRAPH-#6859, IRGKangXi=0526.150, RSKangXi=75.6
685A CJK UNIFIED IDEOGRAPH-#685A, IRGKangXi=0526.211, RSKangXi=75.6, Def{press, squeeze hard; force}
685B CJK UNIFIED IDEOGRAPH-#685B, IRGKangXi=0526.211, RSKangXi=75.6, Def{a real, hank, skein}
685C CJK UNIFIED IDEOGRAPH-#685C, IRGKangXi=0526.211, RSKangXi=75.6, Def{cherry, cherry blossom}
685D CJK UNIFIED IDEOGRAPH-#685D, IRGKangXi=0526.211, RSKangXi=75.6, Def{variant of 枡 U+67A1, a measuring box}
685E CJK UNIFIED IDEOGRAPH-#685E, IRGKangXi=0526.211, RSKangXi=75.6
685F CJK UNIFIED IDEOGRAPH-#685F, IRGKangXi=0526.211, RSKangXi=75.6, Def{a crosspiece, cleat, frame, door bolt; shelf}
6860 CJK UNIFIED IDEOGRAPH-#6860, IRGKangXi=0526.211, RSKangXi=75.6, Def{the forking branch of a tree}
6861 CJK UNIFIED IDEOGRAPH-#6861, IRGKangXi=0526.211, RSKangXi=75.6, Def{bent or twisted piece of wood}
6862 CJK UNIFIED IDEOGRAPH-#6862, IRGKangXi=0526.211, RSKangXi=75.6, Def{hardwood; supports, posts}
6863 CJK UNIFIED IDEOGRAPH-#6863, IRGKangXi=0526.211, RSKangXi=75.6, Def{shelf; frame, crosspiece}
6864 CJK UNIFIED IDEOGRAPH-#6864, IRGKangXi=0526.211, RSKangXi=75.6, Def{alder}
6865 CJK UNIFIED IDEOGRAPH-#6865, IRGKangXi=0526.211, RSKangXi=75.6, Def{bridge; beam, crosspiece}
6866 CJK UNIFIED IDEOGRAPH-#6866, IRGKangXi=0526.211, RSKangXi=75.6, Def{type of birch}
6867 CJK UNIFIED IDEOGRAPH-#6867, IRGKangXi=0526.211, RSKangXi=75.6, Def{Chinese cypress, Chinese juniper}
6868 CJK UNIFIED IDEOGRAPH-#6868, IRGKangXi=0526.211, RSKangXi=75.6, Def{oar, paddle}
6869 CJK UNIFIED IDEOGRAPH-#6869, IRGKangXi=0526.211, RSKangXi=75.6, Def{stake, post; affair, matter}
686A CJK UNIFIED IDEOGRAPH-#686A, IRGKangXi=0526.211, RSKangXi=75.6, Def{mythical giant tree}
686B CJK UNIFIED IDEOGRAPH-#686B, IRGKangXi=0526.220, RSKangXi=75.7, Def{horse chestnut}
686C CJK UNIFIED IDEOGRAPH-#686C, IRGKangXi=0526.230, RSKangXi=75.7, Def{pear and other trees}
686D CJK UNIFIED IDEOGRAPH-#686D, IRGKangXi=0526.240, RSKangXi=75.7, Def{eaves; space between two pillars}
686E CJK UNIFIED IDEOGRAPH-#686E, IRGKangXi=0526.250, RSKangXi=75.7, Def{cup, glass, tumbler}
686F CJK UNIFIED IDEOGRAPH-#686F, IRGKangXi=0526.260, RSKangXi=75.7, Def{table}
6870 CJK UNIFIED IDEOGRAPH-#6870, IRGKangXi=0527.020, RSKangXi=75.7
6871 CJK UNIFIED IDEOGRAPH-#6871, IRGKangXi=0527.030, RSKangXi=75.7
6872 CJK UNIFIED IDEOGRAPH-#6872, IRGKangXi=0527.040, RSKangXi=75.7
6873 CJK UNIFIED IDEOGRAPH-#6873, IRGKangXi=0527.050, RSKangXi=75.7
6874 CJK UNIFIED IDEOGRAPH-#6874, IRGKangXi=0527.060, RSKangXi=75.7, Def{raft; drum stick; ridge pole}
6875 CJK UNIFIED IDEOGRAPH-#6875, IRGKangXi=0527.090, RSKangXi=75.7
6876 CJK UNIFIED IDEOGRAPH-#6876, IRGKangXi=0527.100, RSKangXi=75.7, Def{pail, bucket, tub; cask, keg}
6877 CJK UNIFIED IDEOGRAPH-#6877, IRGKangXi=0527.120, RSKangXi=75.7, Def{rafter; malus toringo}
6878 CJK UNIFIED IDEOGRAPH-#6878, IRGKangXi=0527.130, RSKangXi=75.7
6879 CJK UNIFIED IDEOGRAPH-#6879, IRGKangXi=0527.140, RSKangXi=75.7, Def{palm}
687A CJK UNIFIED IDEOGRAPH-#687A, IRGKangXi=0527.150, RSKangXi=75.7
687B CJK UNIFIED IDEOGRAPH-#687B, IRGKangXi=0527.160, RSKangXi=75.7
687C CJK UNIFIED IDEOGRAPH-#687C, IRGKangXi=0527.170, RSKangXi=75.7, Def{the varnish tree; lacquer, varnish, paint}
687D CJK UNIFIED IDEOGRAPH-#687D, IRGKangXi=0527.200, RSKangXi=75.7
687E CJK UNIFIED IDEOGRAPH-#687E, IRGKangXi=0527.210, RSKangXi=75.7
687F CJK UNIFIED IDEOGRAPH-#687F, IRGKangXi=0527.230, RSKangXi=75.7, Def{pole; stick; club; pole as unit}
6880 CJK UNIFIED IDEOGRAPH-#6880, IRGKangXi=0527.240, RSKangXi=75.7
6881 CJK UNIFIED IDEOGRAPH-#6881, IRGKangXi=0528.010, RSKangXi=75.7, Def{bridge; beam; rafters; surname}
6882 CJK UNIFIED IDEOGRAPH-#6882, IRGKangXi=0528.040, RSKangXi=75.7, Def{acorn cup}
6883 CJK UNIFIED IDEOGRAPH-#6883, IRGKangXi=0528.050, RSKangXi=75.7, Def{a club; a stalk; straight}
6884 CJK UNIFIED IDEOGRAPH-#6884, IRGKangXi=0528.070, RSKangXi=75.7, Def{a soft wood; to lay in stores of firewood}
6885 CJK UNIFIED IDEOGRAPH-#6885, IRGKangXi=0528.080, RSKangXi=75.7, Def{plums; prunes; surname}
6886 CJK UNIFIED IDEOGRAPH-#6886, IRGKangXi=0528.110, RSKangXi=75.7, Def{watchman's rattle}
6887 CJK UNIFIED IDEOGRAPH-#6887, IRGKangXi=0528.120, RSKangXi=75.7
6888 CJK UNIFIED IDEOGRAPH-#6888, IRGKangXi=0528.130, RSKangXi=75.7
6889 CJK UNIFIED IDEOGRAPH-#6889, IRGKangXi=0528.140, RSKangXi=75.7
688A CJK UNIFIED IDEOGRAPH-#688A, IRGKangXi=0528.150, RSKangXi=75.7, Def{squeeze out of; extract}
688B CJK UNIFIED IDEOGRAPH-#688B, IRGKangXi=0528.170, RSKangXi=75.7
688C CJK UNIFIED IDEOGRAPH-#688C, IRGKangXi=0528.180, RSKangXi=75.7
688D CJK UNIFIED IDEOGRAPH-#688D, IRGKangXi=0528.190, RSKangXi=75.7, Def{tree name}
688E CJK UNIFIED IDEOGRAPH-#688E, IRGKangXi=0528.200, RSKangXi=75.7, Def{sickle handle, branch}
688F CJK UNIFIED IDEOGRAPH-#688F, IRGKangXi=0528.210, RSKangXi=75.7, Def{handcuffs, manacles, fetters}
6890 CJK UNIFIED IDEOGRAPH-#6890, IRGKangXi=0528.220, RSKangXi=75.7, Def{fence}
6891 CJK UNIFIED IDEOGRAPH-#6891, IRGKangXi=0528.230, RSKangXi=75.7
6892 CJK UNIFIED IDEOGRAPH-#6892, IRGKangXi=0528.240, RSKangXi=75.7
6893 CJK UNIFIED IDEOGRAPH-#6893, IRGKangXi=0528.250, RSKangXi=75.7, Def{catalpa ovata}
6894 CJK UNIFIED IDEOGRAPH-#6894, IRGKangXi=0529.010, RSKangXi=75.7, Def{gardenia}
6895 CJK UNIFIED IDEOGRAPH-#6895, IRGKangXi=0529.020, RSKangXi=75.7
6896 CJK UNIFIED IDEOGRAPH-#6896, IRGKangXi=0529.030, RSKangXi=75.7, Def{a palm-tree}
6897 CJK UNIFIED IDEOGRAPH-#6897, IRGKangXi=0529.040, RSKangXi=75.7, Def{stem of flower, branch of plant}
6898 CJK UNIFIED IDEOGRAPH-#6898, IRGKangXi=0529.080, RSKangXi=75.7, Def{bamboo tube, wooden peg; spout}
6899 CJK UNIFIED IDEOGRAPH-#6899, IRGKangXi=0529.090, RSKangXi=75.7
689A CJK UNIFIED IDEOGRAPH-#689A, IRGKangXi=0529.100, RSKangXi=75.7
689B CJK UNIFIED IDEOGRAPH-#689B, IRGKangXi=0529.110, RSKangXi=75.7
689C CJK UNIFIED IDEOGRAPH-#689C, IRGKangXi=0529.120, RSKangXi=75.7, Def{chopstick}
689D CJK UNIFIED IDEOGRAPH-#689D, IRGKangXi=0529.140, RSKangXi=75.7, Def{clause, condition; string, stripe}
689E CJK UNIFIED IDEOGRAPH-#689E, IRGKangXi=0529.150, RSKangXi=75.7
689F CJK UNIFIED IDEOGRAPH-#689F, IRGKangXi=0529.160, RSKangXi=75.7, Def{an owl; thus, something evil}
68A0 CJK UNIFIED IDEOGRAPH-#68A0, IRGKangXi=0530.010, RSKangXi=75.7, Def{a small beam supporting the rafters at the eaves}
68A1 CJK UNIFIED IDEOGRAPH-#68A1, IRGKangXi=0530.040, RSKangXi=75.7, Def{tray for carrying sacrificial meat}
68A2 CJK UNIFIED IDEOGRAPH-#68A2, IRGKangXi=0530.050, RSKangXi=75.7, Def{pointed tip of something long like a branch; rudder}
68A3 CJK UNIFIED IDEOGRAPH-#68A3, IRGKangXi=0530.060, RSKangXi=75.7
68A4 CJK UNIFIED IDEOGRAPH-#68A4, IRGKangXi=0530.070, RSKangXi=75.7
68A5 CJK UNIFIED IDEOGRAPH-#68A5, IRGKangXi=0530.080, RSKangXi=75.7
68A6 CJK UNIFIED IDEOGRAPH-#68A6, IRGKangXi=0530.100, RSKangXi=75.7, Def{dream; visionary; wishful}
68A7 CJK UNIFIED IDEOGRAPH-#68A7, IRGKangXi=0530.110, RSKangXi=75.7, Def{Chinese parasoltree, Sterculia platanifolia}
68A8 CJK UNIFIED IDEOGRAPH-#68A8, IRGKangXi=0530.120, RSKangXi=75.7, Def{pear; opera; cut, slash}
68A9 CJK UNIFIED IDEOGRAPH-#68A9, IRGKangXi=0530.130, RSKangXi=75.7, Def{a hod, a basket in which to carry earth}
68AA CJK UNIFIED IDEOGRAPH-#68AA, IRGKangXi=0530.140, RSKangXi=75.7
68AB CJK UNIFIED IDEOGRAPH-#68AB, IRGKangXi=0530.150, RSKangXi=75.7
68AC CJK UNIFIED IDEOGRAPH-#68AC, IRGKangXi=0530.160, RSKangXi=75.7
68AD CJK UNIFIED IDEOGRAPH-#68AD, IRGKangXi=0530.170, RSKangXi=75.7, Def{weaver's shuttle; go to and fro}
68AE CJK UNIFIED IDEOGRAPH-#68AE, IRGKangXi=0530.180, RSKangXi=75.7, Def{snowshoes}
68AF CJK UNIFIED IDEOGRAPH-#68AF, IRGKangXi=0531.020, RSKangXi=75.7, Def{ladder, steps, stairs; lean}
68B0 CJK UNIFIED IDEOGRAPH-#68B0, IRGKangXi=0531.030, RSKangXi=75.7, Def{weapons; implements, instruments}
68B1 CJK UNIFIED IDEOGRAPH-#68B1, IRGKangXi=0531.040, RSKangXi=75.7, Def{doorsill; doorjamb}
68B2 CJK UNIFIED IDEOGRAPH-#68B2, IRGKangXi=0531.060, RSKangXi=75.7, Def{joist; cane, club; king-post}
68B3 CJK UNIFIED IDEOGRAPH-#68B3, IRGKangXi=0531.070, RSKangXi=75.7, Def{comb; brush}
68B4 CJK UNIFIED IDEOGRAPH-#68B4, IRGKangXi=0531.080, RSKangXi=75.7, Def{long}
68B5 CJK UNIFIED IDEOGRAPH-#68B5, IRGKangXi=0531.090, RSKangXi=75.7, Def{Buddhist, Sanskrit}
68B6 CJK UNIFIED IDEOGRAPH-#68B6, IRGKangXi=0531.100, RSKangXi=75.7, Def{oar, shaft}
68B7 CJK UNIFIED IDEOGRAPH-#68B7, IRGKangXi=0531.131, RSKangXi=75.7
68B8 CJK UNIFIED IDEOGRAPH-#68B8, IRGKangXi=0531.131, RSKangXi=75.7
68B9 CJK UNIFIED IDEOGRAPH-#68B9, IRGKangXi=0531.131, RSKangXi=75.7, Def{the areca-nut; the betel-nut}
68BA CJK UNIFIED IDEOGRAPH-#68BA, IRGKangXi=0531.131, RSKangXi=75.7
68BB CJK UNIFIED IDEOGRAPH-#68BB, IRGKangXi=0531.131, RSKangXi=75.7, Def{a tree whose branches are placed on Buddhist graves}
68BC CJK UNIFIED IDEOGRAPH-#68BC, IRGKangXi=0531.131, RSKangXi=75.7, Def{block of wood; blockhead; stupid}
68BD CJK UNIFIED IDEOGRAPH-#68BD, IRGKangXi=0531.131, RSKangXi=75.7
68BE CJK UNIFIED IDEOGRAPH-#68BE, IRGKangXi=0531.131, RSKangXi=75.7
68BF CJK UNIFIED IDEOGRAPH-#68BF, IRGKangXi=0537.131, RSKangXi=75.7
68C0 CJK UNIFIED IDEOGRAPH-#68C0, IRGKangXi=0531.131, RSKangXi=75.7, Def{check; examine}
68C1 CJK UNIFIED IDEOGRAPH-#68C1, IRGKangXi=0531.131, RSKangXi=75.7, Def{joist; cane}
68C2 CJK UNIFIED IDEOGRAPH-#68C2, IRGKangXi=0531.131, RSKangXi=75.7, Def{carved or patterned window sills}
68C3 CJK UNIFIED IDEOGRAPH-#68C3, IRGKangXi=0531.140, RSKangXi=75.8, Def{a pear}
68C4 CJK UNIFIED IDEOGRAPH-#68C4, IRGKangXi=0531.150, RSKangXi=75.8, Def{reject, abandon, discard}
68C5 CJK UNIFIED IDEOGRAPH-#68C5, IRGKangXi=0531.200, RSKangXi=75.8, Def{handle, lever, knob; authority}
68C6 CJK UNIFIED IDEOGRAPH-#68C6, IRGKangXi=0531.210, RSKangXi=75.8, Def{camphor tree}
68C7 CJK UNIFIED IDEOGRAPH-#68C7, IRGKangXi=0531.220, RSKangXi=75.8
68C8 CJK UNIFIED IDEOGRAPH-#68C8, IRGKangXi=0531.230, RSKangXi=75.8
68C9 CJK UNIFIED IDEOGRAPH-#68C9, IRGKangXi=0531.240, RSKangXi=75.8, Def{cotton; cotton padded}
68CA CJK UNIFIED IDEOGRAPH-#68CA, IRGKangXi=0532.020, RSKangXi=75.8, Def{chess; any game similar to chess}
68CB CJK UNIFIED IDEOGRAPH-#68CB, IRGKangXi=0532.030, RSKangXi=75.8, Def{chess; any game similar to chess}
68CC CJK UNIFIED IDEOGRAPH-#68CC, IRGKangXi=0532.040, RSKangXi=75.8
68CD CJK UNIFIED IDEOGRAPH-#68CD, IRGKangXi=0532.050, RSKangXi=75.8, Def{stick, cudgel; scoundrel}
68CE CJK UNIFIED IDEOGRAPH-#68CE, IRGKangXi=0532.060, RSKangXi=75.8
68CF CJK UNIFIED IDEOGRAPH-#68CF, IRGKangXi=0532.070, RSKangXi=75.8
68D0 CJK UNIFIED IDEOGRAPH-#68D0, IRGKangXi=0532.080, RSKangXi=75.8, Def{species of yew}
68D1 CJK UNIFIED IDEOGRAPH-#68D1, IRGKangXi=0532.090, RSKangXi=75.8, Def{raft}
68D2 CJK UNIFIED IDEOGRAPH-#68D2, IRGKangXi=0532.100, RSKangXi=75.8, Def{stick, club, truncheon; hit}
68D3 CJK UNIFIED IDEOGRAPH-#68D3, IRGKangXi=0532.110, RSKangXi=75.8, Def{hit, strike}
68D4 CJK UNIFIED IDEOGRAPH-#68D4, IRGKangXi=0532.120, RSKangXi=75.8
68D5 CJK UNIFIED IDEOGRAPH-#68D5, IRGKangXi=0532.140, RSKangXi=75.8, Def{hemp palm; palm tree}
68D6 CJK UNIFIED IDEOGRAPH-#68D6, IRGKangXi=0532.170, RSKangXi=75.8, Def{door stop, door jam; touch; a prop, post}
68D7 CJK UNIFIED IDEOGRAPH-#68D7, IRGKangXi=0532.180, RSKangXi=75.8, Def{date tree; dates, jujubes; surname}
68D8 CJK UNIFIED IDEOGRAPH-#68D8, IRGKangXi=0532.200, RSKangXi=75.8, Def{jujube tree; thorns, brambles}
68D9 CJK UNIFIED IDEOGRAPH-#68D9, IRGKangXi=0532.210, RSKangXi=75.8, Def{obstinate; to draw the fingers across; to steer}
68DA CJK UNIFIED IDEOGRAPH-#68DA, IRGKangXi=0533.020, RSKangXi=75.8, Def{tent, awning; booth; shed}
68DB CJK UNIFIED IDEOGRAPH-#68DB, IRGKangXi=0533.050, RSKangXi=75.8
68DC CJK UNIFIED IDEOGRAPH-#68DC, IRGKangXi=0533.060, RSKangXi=75.8, Def{branch, fork; tray}
68DD CJK UNIFIED IDEOGRAPH-#68DD, IRGKangXi=0533.070, RSKangXi=75.8
68DE CJK UNIFIED IDEOGRAPH-#68DE, IRGKangXi=0533.080, RSKangXi=75.8
68DF CJK UNIFIED IDEOGRAPH-#68DF, IRGKangXi=0533.100, RSKangXi=75.8, Def{the main beams supporting a house}
68E0 CJK UNIFIED IDEOGRAPH-#68E0, IRGKangXi=0533.140, RSKangXi=75.8, Def{crab apple tree; wild plums}
68E1 CJK UNIFIED IDEOGRAPH-#68E1, IRGKangXi=0533.160, RSKangXi=75.8
68E2 CJK UNIFIED IDEOGRAPH-#68E2, IRGKangXi=0533.170, RSKangXi=75.8, Def{the felloe or rim of a wheel}
68E3 CJK UNIFIED IDEOGRAPH-#68E3, IRGKangXi=0533.180, RSKangXi=75.8, Def{kerria japonica plant, cherry}
68E4 CJK UNIFIED IDEOGRAPH-#68E4, IRGKangXi=0533.190, RSKangXi=75.8
68E5 CJK UNIFIED IDEOGRAPH-#68E5, IRGKangXi=0533.200, RSKangXi=75.8, Def{a railing; a fence an enclosed place}
68E6 CJK UNIFIED IDEOGRAPH-#68E6, IRGKangXi=0533.210, RSKangXi=75.8
68E7 CJK UNIFIED IDEOGRAPH-#68E7, IRGKangXi=0533.240, RSKangXi=75.8, Def{warehouse; tavern, inn}
68E8 CJK UNIFIED IDEOGRAPH-#68E8, IRGKangXi=0534.020, RSKangXi=75.8, Def{tally or wooden pass}
68E9 CJK UNIFIED IDEOGRAPH-#68E9, IRGKangXi=0534.030, RSKangXi=75.8
68EA CJK UNIFIED IDEOGRAPH-#68EA, IRGKangXi=0534.040, RSKangXi=75.8, Def{tree}
68EB CJK UNIFIED IDEOGRAPH-#68EB, IRGKangXi=0534.050, RSKangXi=75.8, Def{thorny shrub with yellow flowers; a kind of oak}
68EC CJK UNIFIED IDEOGRAPH-#68EC, IRGKangXi=0534.060, RSKangXi=75.8, Def{bowl}
68ED CJK UNIFIED IDEOGRAPH-#68ED, IRGKangXi=0534.070, RSKangXi=75.8
68EE CJK UNIFIED IDEOGRAPH-#68EE, IRGKangXi=0534.110, RSKangXi=75.8, Def{forest; luxuriant vegetation}
68EF CJK UNIFIED IDEOGRAPH-#68EF, IRGKangXi=0534.140, RSKangXi=75.8, Def{jujube tree}
68F0 CJK UNIFIED IDEOGRAPH-#68F0, IRGKangXi=0534.150, RSKangXi=75.8
68F1 CJK UNIFIED IDEOGRAPH-#68F1, IRGKangXi=0534.160, RSKangXi=75.8, Def{squared timber; angle, edge}
68F2 CJK UNIFIED IDEOGRAPH-#68F2, IRGKangXi=0534.170, RSKangXi=75.8, Def{perch; roost; stay}
68F3 CJK UNIFIED IDEOGRAPH-#68F3, IRGKangXi=0534.180, RSKangXi=75.8, Def{small pillars that support the roof, those which rest on the main bean}
68F4 CJK UNIFIED IDEOGRAPH-#68F4, IRGKangXi=0534.190, RSKangXi=75.8
68F5 CJK UNIFIED IDEOGRAPH-#68F5, IRGKangXi=0534.200, RSKangXi=75.8, Def{numerary adjunct for trees}
68F6 CJK UNIFIED IDEOGRAPH-#68F6, IRGKangXi=0534.240, RSKangXi=75.8
68F7 CJK UNIFIED IDEOGRAPH-#68F7, IRGKangXi=0535.010, RSKangXi=75.8
68F8 CJK UNIFIED IDEOGRAPH-#68F8, IRGKangXi=0535.020, RSKangXi=75.8, Def{surname}
68F9 CJK UNIFIED IDEOGRAPH-#68F9, IRGKangXi=0535.030, RSKangXi=75.8, Def{oar; boat}
68FA CJK UNIFIED IDEOGRAPH-#68FA, IRGKangXi=0535.040, RSKangXi=75.8, Def{coffin}
68FB CJK UNIFIED IDEOGRAPH-#68FB, IRGKangXi=0535.060, RSKangXi=75.8, Def{kind of wood from which perfume}
68FC CJK UNIFIED IDEOGRAPH-#68FC, IRGKangXi=0535.070, RSKangXi=75.8, Def{beams in the roof of a house confused, disordered}
68FD CJK UNIFIED IDEOGRAPH-#68FD, IRGKangXi=0535.080, RSKangXi=75.8
68FE CJK UNIFIED IDEOGRAPH-#68FE, IRGKangXi=0535.100, RSKangXi=75.8
68FF CJK UNIFIED IDEOGRAPH-#68FF, IRGKangXi=0535.110, RSKangXi=75.8
6900 CJK UNIFIED IDEOGRAPH-#6900, IRGKangXi=0535.130, RSKangXi=75.8, Def{bowl; cup; dish}
6901 CJK UNIFIED IDEOGRAPH-#6901, IRGKangXi=0535.150, RSKangXi=75.8, Def{outer-coffin; vault}
6902 CJK UNIFIED IDEOGRAPH-#6902, IRGKangXi=0535.160, RSKangXi=75.8
6903 CJK UNIFIED IDEOGRAPH-#6903, IRGKangXi=0535.170, RSKangXi=75.8
6904 CJK UNIFIED IDEOGRAPH-#6904, IRGKangXi=0535.200, RSKangXi=75.8, Def{to graft}
6905 CJK UNIFIED IDEOGRAPH-#6905, IRGKangXi=0535.210, RSKangXi=75.8, Def{chair, seat}
6906 CJK UNIFIED IDEOGRAPH-#6906, IRGKangXi=0535.230, RSKangXi=75.8
6907 CJK UNIFIED IDEOGRAPH-#6907, IRGKangXi=0535.250, RSKangXi=75.8
6908 CJK UNIFIED IDEOGRAPH-#6908, IRGKangXi=0536.010, RSKangXi=75.8, Def{cedar}
6909 CJK UNIFIED IDEOGRAPH-#6909, IRGKangXi=0536.030, RSKangXi=75.8
690A CJK UNIFIED IDEOGRAPH-#690A, IRGKangXi=0536.060, RSKangXi=75.8, Def{to fit a handle into a socket; a plug or cork}
690B CJK UNIFIED IDEOGRAPH-#690B, IRGKangXi=0536.070, RSKangXi=75.8, Def{fruit}
690C CJK UNIFIED IDEOGRAPH-#690C, IRGKangXi=0536.080, RSKangXi=75.8, Def{instrument}
690D CJK UNIFIED IDEOGRAPH-#690D, IRGKangXi=0536.100, RSKangXi=75.8, Def{plant, trees, plants; grow}
690E CJK UNIFIED IDEOGRAPH-#690E, IRGKangXi=0536.110, RSKangXi=75.8, Def{hammer, mallet; vertebra}
690F CJK UNIFIED IDEOGRAPH-#690F, IRGKangXi=0536.120, RSKangXi=75.8, Def{the forking branch of a tree}
6910 CJK UNIFIED IDEOGRAPH-#6910, IRGKangXi=0536.130, RSKangXi=75.8
6911 CJK UNIFIED IDEOGRAPH-#6911, IRGKangXi=0536.140, RSKangXi=75.8, Def{oval}
6912 CJK UNIFIED IDEOGRAPH-#6912, IRGKangXi=0536.160, RSKangXi=75.8, Def{pepper, spices}
6913 CJK UNIFIED IDEOGRAPH-#6913, IRGKangXi=0537.020, RSKangXi=75.8, Def{strike, hit, beat, hammer}
6914 CJK UNIFIED IDEOGRAPH-#6914, IRGKangXi=0537.040, RSKangXi=75.8
6915 CJK UNIFIED IDEOGRAPH-#6915, IRGKangXi=0537.090, RSKangXi=75.8
6916 CJK UNIFIED IDEOGRAPH-#6916, IRGKangXi=0537.131, RSKangXi=75.8
6917 CJK UNIFIED IDEOGRAPH-#6917, IRGKangXi=0537.131, RSKangXi=75.8
6918 CJK UNIFIED IDEOGRAPH-#6918, IRGKangXi=0537.131, RSKangXi=75.8
6919 CJK UNIFIED IDEOGRAPH-#6919, IRGKangXi=0537.131, RSKangXi=75.8
691A CJK UNIFIED IDEOGRAPH-#691A, IRGKangXi=0537.131, RSKangXi=75.8, Def{a kind of oak used for charcoal}
691B CJK UNIFIED IDEOGRAPH-#691B, IRGKangXi=0537.131, RSKangXi=75.8, Def{type of birch}
691C CJK UNIFIED IDEOGRAPH-#691C, IRGKangXi=0537.131, RSKangXi=75.8, Def{check; examine}
691D CJK UNIFIED IDEOGRAPH-#691D, IRGKangXi=0537.131, RSKangXi=75.11
691E CJK UNIFIED IDEOGRAPH-#691E, IRGKangXi=0537.131, RSKangXi=75.8
691F CJK UNIFIED IDEOGRAPH-#691F, IRGKangXi=0537.131, RSKangXi=75.8, Def{cabinet, wardrobe; closet}
6920 CJK UNIFIED IDEOGRAPH-#6920, IRGKangXi=0537.131, RSKangXi=75.8, Def{wooden tablet; edition}
6921 CJK UNIFIED IDEOGRAPH-#6921, IRGKangXi=0537.131, RSKangXi=75.8
6922 CJK UNIFIED IDEOGRAPH-#6922, IRGKangXi=0537.131, RSKangXi=75.8
6923 CJK UNIFIED IDEOGRAPH-#6923, IRGKangXi=0537.131, RSKangXi=75.8
6924 CJK UNIFIED IDEOGRAPH-#6924, IRGKangXi=0537.131, RSKangXi=75.8, Def{tree}
6925 CJK UNIFIED IDEOGRAPH-#6925, IRGKangXi=0537.131, RSKangXi=75.8
6926 CJK UNIFIED IDEOGRAPH-#6926, IRGKangXi=0537.131, RSKangXi=75.8
6927 CJK UNIFIED IDEOGRAPH-#6927, IRGKangXi=0537.131, RSKangXi=75.8, Def{gutter}
6928 CJK UNIFIED IDEOGRAPH-#6928, IRGKangXi=0537.131, RSKangXi=75.8
6929 CJK UNIFIED IDEOGRAPH-#6929, IRGKangXi=0537.131, RSKangXi=75.8
692A CJK UNIFIED IDEOGRAPH-#692A, IRGKangXi=0537.131, RSKangXi=75.8, Def{Machilus nanmu, variety of evergreen}
692B CJK UNIFIED IDEOGRAPH-#692B, IRGKangXi=0537.131, RSKangXi=75.12
692C CJK UNIFIED IDEOGRAPH-#692C, IRGKangXi=0537.131, RSKangXi=75.8
692D CJK UNIFIED IDEOGRAPH-#692D, IRGKangXi=0542.191, RSKangXi=75.8, Def{oval-shaped, elliptical, tubular}
692E CJK UNIFIED IDEOGRAPH-#692E, IRGKangXi=0537.131, RSKangXi=75.8
692F CJK UNIFIED IDEOGRAPH-#692F, IRGKangXi=0537.160, RSKangXi=75.9
6930 CJK UNIFIED IDEOGRAPH-#6930, IRGKangXi=0537.170, RSKangXi=75.9, Def{palm tree, coconut palm}
6931 CJK UNIFIED IDEOGRAPH-#6931, IRGKangXi=0537.180, RSKangXi=75.9
6932 CJK UNIFIED IDEOGRAPH-#6932, IRGKangXi=0537.190, RSKangXi=75.9
6933 CJK UNIFIED IDEOGRAPH-#6933, IRGKangXi=0537.210, RSKangXi=75.9, Def{the pivots, at the top and bottom of a Chinese door, on which the door turns}
6934 CJK UNIFIED IDEOGRAPH-#6934, IRGKangXi=0537.230, RSKangXi=75.9, Def{poplar, aspen}
6935 CJK UNIFIED IDEOGRAPH-#6935, IRGKangXi=0537.240, RSKangXi=75.9, Def{pompelmous; canque (breech, rump, buttock)}
6936 CJK UNIFIED IDEOGRAPH-#6936, IRGKangXi=0537.260, RSKangXi=75.9, Def{palm tree}
6937 CJK UNIFIED IDEOGRAPH-#6937, IRGKangXi=0537.270, RSKangXi=75.9, Def{box; casket; letter; envelope}
6938 CJK UNIFIED IDEOGRAPH-#6938, IRGKangXi=0537.290, RSKangXi=75.9, Def{rack}
6939 CJK UNIFIED IDEOGRAPH-#6939, IRGKangXi=0537.300, RSKangXi=75.9, Def{a chopping board}
693A CJK UNIFIED IDEOGRAPH-#693A, IRGKangXi=0538.010, RSKangXi=75.9, Def{beam of a house}
693B CJK UNIFIED IDEOGRAPH-#693B, IRGKangXi=0538.020, RSKangXi=75.9
693C CJK UNIFIED IDEOGRAPH-#693C, IRGKangXi=0538.040, RSKangXi=75.9
693D CJK UNIFIED IDEOGRAPH-#693D, IRGKangXi=0538.050, RSKangXi=75.9, Def{beams, rafters, supports}
693E CJK UNIFIED IDEOGRAPH-#693E, IRGKangXi=0538.060, RSKangXi=75.9
693F CJK UNIFIED IDEOGRAPH-#693F, IRGKangXi=0538.080, RSKangXi=75.9, Def{father; a plant with white flowers}
6940 CJK UNIFIED IDEOGRAPH-#6940, IRGKangXi=0538.090, RSKangXi=75.9, Def{name of tree; surname}
6941 CJK UNIFIED IDEOGRAPH-#6941, IRGKangXi=0538.100, RSKangXi=75.9
6942 CJK UNIFIED IDEOGRAPH-#6942, IRGKangXi=0538.120, RSKangXi=75.9, Def{a raft, to hew, to fell trees}
6943 CJK UNIFIED IDEOGRAPH-#6943, IRGKangXi=0538.140, RSKangXi=75.9
6944 CJK UNIFIED IDEOGRAPH-#6944, IRGKangXi=0538.150, RSKangXi=75.9, Def{block}
6945 CJK UNIFIED IDEOGRAPH-#6945, IRGKangXi=0538.230, RSKangXi=75.9, Def{wooden board}
6946 CJK UNIFIED IDEOGRAPH-#6946, IRGKangXi=0538.250, RSKangXi=75.9
6947 CJK UNIFIED IDEOGRAPH-#6947, IRGKangXi=0538.260, RSKangXi=75.9
6948 CJK UNIFIED IDEOGRAPH-#6948, IRGKangXi=0538.270, RSKangXi=75.9
6949 CJK UNIFIED IDEOGRAPH-#6949, IRGKangXi=0538.290, RSKangXi=75.9
694A CJK UNIFIED IDEOGRAPH-#694A, IRGKangXi=0538.300, RSKangXi=75.9, Def{willow, poplar, aspen; surname}
694B CJK UNIFIED IDEOGRAPH-#694B, IRGKangXi=0538.310, RSKangXi=75.9
694C CJK UNIFIED IDEOGRAPH-#694C, IRGKangXi=0538.350, RSKangXi=75.9
694D CJK UNIFIED IDEOGRAPH-#694D, IRGKangXi=0538.360, RSKangXi=75.9
694E CJK UNIFIED IDEOGRAPH-#694E, IRGKangXi=0538.380, RSKangXi=75.9, Def{peg}
694F CJK UNIFIED IDEOGRAPH-#694F, IRGKangXi=0539.010, RSKangXi=75.9
6950 CJK UNIFIED IDEOGRAPH-#6950, IRGKangXi=0539.020, RSKangXi=75.9
6951 CJK UNIFIED IDEOGRAPH-#6951, IRGKangXi=0539.040, RSKangXi=75.9
6952 CJK UNIFIED IDEOGRAPH-#6952, IRGKangXi=0539.070, RSKangXi=75.9
6953 CJK UNIFIED IDEOGRAPH-#6953, IRGKangXi=0539.080, RSKangXi=75.9, Def{maple tree}
6954 CJK UNIFIED IDEOGRAPH-#6954, IRGKangXi=0539.130, RSKangXi=75.9, Def{wedge; gatepost; foreword}
6955 CJK UNIFIED IDEOGRAPH-#6955, IRGKangXi=0539.150, RSKangXi=75.9, Def{oval-shaped, elliptical, tubular}
6956 CJK UNIFIED IDEOGRAPH-#6956, IRGKangXi=0539.160, RSKangXi=75.9
6957 CJK UNIFIED IDEOGRAPH-#6957, IRGKangXi=0539.180, RSKangXi=75.9, Def{bar of door, bolt of lock}
6958 CJK UNIFIED IDEOGRAPH-#6958, IRGKangXi=0539.200, RSKangXi=75.9, Def{band}
6959 CJK UNIFIED IDEOGRAPH-#6959, IRGKangXi=0539.220, RSKangXi=75.9, Def{name of plant; lush}
695A CJK UNIFIED IDEOGRAPH-#695A, IRGKangXi=0539.230, RSKangXi=75.9, Def{name of feudal state; clear}
695B CJK UNIFIED IDEOGRAPH-#695B, IRGKangXi=0540.030, RSKangXi=75.9, Def{coarse, crude; plant}
695C CJK UNIFIED IDEOGRAPH-#695C, IRGKangXi=0540.060, RSKangXi=75.9
695D CJK UNIFIED IDEOGRAPH-#695D, IRGKangXi=0540.070, RSKangXi=75.9, Def{Melia japonica}
695E CJK UNIFIED IDEOGRAPH-#695E, IRGKangXi=0540.080, RSKangXi=75.9, Def{used for Ceylon in Buddhist texts}
695F CJK UNIFIED IDEOGRAPH-#695F, IRGKangXi=0540.100, RSKangXi=75.9, Def{tree}
6960 CJK UNIFIED IDEOGRAPH-#6960, IRGKangXi=0540.110, RSKangXi=75.9, Def{name of tree, machilus nanmu}
6961 CJK UNIFIED IDEOGRAPH-#6961, IRGKangXi=0540.120, RSKangXi=75.9, Def{elm tree}
6962 CJK UNIFIED IDEOGRAPH-#6962, IRGKangXi=0540.130, RSKangXi=75.9, Def{tinder}
6963 CJK UNIFIED IDEOGRAPH-#6963, IRGKangXi=0540.140, RSKangXi=75.9, Def{crossbeam above or under gate}
6964 CJK UNIFIED IDEOGRAPH-#6964, IRGKangXi=0540.160, RSKangXi=75.9
6965 CJK UNIFIED IDEOGRAPH-#6965, IRGKangXi=0540.170, RSKangXi=75.9, Def{a last for making shoes; to turn on a lathe}
6966 CJK UNIFIED IDEOGRAPH-#6966, IRGKangXi=0540.180, RSKangXi=75.9, Def{a last for making shoes; to turn on a lathe}
6967 CJK UNIFIED IDEOGRAPH-#6967, IRGKangXi=0540.210, RSKangXi=75.9
6968 CJK UNIFIED IDEOGRAPH-#6968, IRGKangXi=0540.220, RSKangXi=75.9, Def{hardwood; supports, posts}
6969 CJK UNIFIED IDEOGRAPH-#6969, IRGKangXi=0540.240, RSKangXi=75.9, Def{tree}
696A CJK UNIFIED IDEOGRAPH-#696A, IRGKangXi=0541.020, RSKangXi=75.9, Def{small dish; window}
696B CJK UNIFIED IDEOGRAPH-#696B, IRGKangXi=0541.030, RSKangXi=75.9, Def{oar, paddle}
696C CJK UNIFIED IDEOGRAPH-#696C, IRGKangXi=0541.040, RSKangXi=75.9, Def{tablet; a signpost}
696D CJK UNIFIED IDEOGRAPH-#696D, IRGKangXi=0541.050, RSKangXi=75.9, Def{profession, business, trade}
696E CJK UNIFIED IDEOGRAPH-#696E, IRGKangXi=0541.090, RSKangXi=75.9, Def{mulberry; paper}
696F CJK UNIFIED IDEOGRAPH-#696F, IRGKangXi=0541.100, RSKangXi=75.9, Def{shield; horizontal bar}
6970 CJK UNIFIED IDEOGRAPH-#6970, IRGKangXi=0541.110, RSKangXi=75.9, Def{tree}
6971 CJK UNIFIED IDEOGRAPH-#6971, IRGKangXi=0541.120, RSKangXi=75.9
6972 CJK UNIFIED IDEOGRAPH-#6972, IRGKangXi=0541.140, RSKangXi=75.9
6973 CJK UNIFIED IDEOGRAPH-#6973, IRGKangXi=0541.150, RSKangXi=75.9, Def{plums; prunes; surname}
6974 CJK UNIFIED IDEOGRAPH-#6974, IRGKangXi=0541.160, RSKangXi=75.9
6975 CJK UNIFIED IDEOGRAPH-#6975, IRGKangXi=0542.020, RSKangXi=75.9, Def{extreme, utmost, furthest, final}
6976 CJK UNIFIED IDEOGRAPH-#6976, IRGKangXi=0542.030, RSKangXi=75.9
6977 CJK UNIFIED IDEOGRAPH-#6977, IRGKangXi=0542.050, RSKangXi=75.9, Def{model style of Chinese writing}
6978 CJK UNIFIED IDEOGRAPH-#6978, IRGKangXi=0542.070, RSKangXi=75.9, Def{mallotus japonicus, deciduous tre}
6979 CJK UNIFIED IDEOGRAPH-#6979, IRGKangXi=0542.090, RSKangXi=75.9, Def{column, pillar; numerary adjunct}
697A CJK UNIFIED IDEOGRAPH-#697A, IRGKangXi=0542.110, RSKangXi=75.9
697B CJK UNIFIED IDEOGRAPH-#697B, IRGKangXi=0542.150, RSKangXi=75.9
697C CJK UNIFIED IDEOGRAPH-#697C, IRGKangXi=0542.191, RSKangXi=75.9, Def{building of two or more stories}
697D CJK UNIFIED IDEOGRAPH-#697D, IRGKangXi=0542.191, RSKangXi=75.9, Def{happy, glad; enjoyable; music}
697E CJK UNIFIED IDEOGRAPH-#697E, IRGKangXi=0542.191, RSKangXi=75.9
697F CJK UNIFIED IDEOGRAPH-#697F, IRGKangXi=0542.191, RSKangXi=75.9
6980 CJK UNIFIED IDEOGRAPH-#6980, IRGKangXi=0542.191, RSKangXi=75.9
6981 CJK UNIFIED IDEOGRAPH-#6981, IRGKangXi=0542.191, RSKangXi=75.9
6982 CJK UNIFIED IDEOGRAPH-#6982, IRGKangXi=0542.191, RSKangXi=75.9, Def{generally, approximately}
6983 CJK UNIFIED IDEOGRAPH-#6983, IRGKangXi=0542.191, RSKangXi=75.9, Def{raised path between fields}
6984 CJK UNIFIED IDEOGRAPH-#6984, IRGKangXi=0542.191, RSKangXi=75.9, Def{olive}
6985 CJK UNIFIED IDEOGRAPH-#6985, IRGKangXi=0542.191, RSKangXi=75.9, Def{pillar, cryptomeria}
6986 CJK UNIFIED IDEOGRAPH-#6986, IRGKangXi=0542.191, RSKangXi=75.9, Def{elm tree}
6987 CJK UNIFIED IDEOGRAPH-#6987, IRGKangXi=0542.191, RSKangXi=75.9, Def{coffin; tung tree}
6988 CJK UNIFIED IDEOGRAPH-#6988, IRGKangXi=0542.191, RSKangXi=75.9, Def{palm}
6989 CJK UNIFIED IDEOGRAPH-#6989, IRGKangXi=0542.191, RSKangXi=75.9, Def{type of elm}
698A CJK UNIFIED IDEOGRAPH-#698A, IRGKangXi=0546.251, RSKangXi=75.10, Def{a sacred Shinto tree}
698B CJK UNIFIED IDEOGRAPH-#698B, IRGKangXi=0542.191, RSKangXi=75.9
698C CJK UNIFIED IDEOGRAPH-#698C, IRGKangXi=0542.191, RSKangXi=75.9, Def{wooden ladder}
698D CJK UNIFIED IDEOGRAPH-#698D, IRGKangXi=0542.200, RSKangXi=75.10
698E CJK UNIFIED IDEOGRAPH-#698E, IRGKangXi=0542.210, RSKangXi=75.10, Def{small evergreen shrub}
698F CJK UNIFIED IDEOGRAPH-#698F, IRGKangXi=0542.220, RSKangXi=75.10
6990 CJK UNIFIED IDEOGRAPH-#6990, IRGKangXi=0542.230, RSKangXi=75.10
6991 CJK UNIFIED IDEOGRAPH-#6991, IRGKangXi=0542.240, RSKangXi=75.10
6992 CJK UNIFIED IDEOGRAPH-#6992, IRGKangXi=0543.020, RSKangXi=75.10
6993 CJK UNIFIED IDEOGRAPH-#6993, IRGKangXi=0543.030, RSKangXi=75.10
6994 CJK UNIFIED IDEOGRAPH-#6994, IRGKangXi=0543.040, RSKangXi=75.9, Def{betel-nut tree}
6995 CJK UNIFIED IDEOGRAPH-#6995, IRGKangXi=0543.060, RSKangXi=75.10, Def{banyan tree}
6996 CJK UNIFIED IDEOGRAPH-#6996, IRGKangXi=0543.070, RSKangXi=75.10, Def{paper mulberry}
6997 CJK UNIFIED IDEOGRAPH-#6997, IRGKangXi=0543.090, RSKangXi=75.10
6998 CJK UNIFIED IDEOGRAPH-#6998, IRGKangXi=0543.110, RSKangXi=75.9, Def{carpenter's square, ruler, rule}
6999 CJK UNIFIED IDEOGRAPH-#6999, IRGKangXi=0543.130, RSKangXi=75.10
699A CJK UNIFIED IDEOGRAPH-#699A, IRGKangXi=0543.150, RSKangXi=75.10
699B CJK UNIFIED IDEOGRAPH-#699B, IRGKangXi=0543.180, RSKangXi=75.10, Def{hazelnut; thicket, underbrush}
699C CJK UNIFIED IDEOGRAPH-#699C, IRGKangXi=0543.190, RSKangXi=75.10, Def{placard; list of successful exam candidates}
699D CJK UNIFIED IDEOGRAPH-#699D, IRGKangXi=0543.200, RSKangXi=75.10
699E CJK UNIFIED IDEOGRAPH-#699E, IRGKangXi=0543.210, RSKangXi=75.10
699F CJK UNIFIED IDEOGRAPH-#699F, IRGKangXi=0543.220, RSKangXi=75.10
69A0 CJK UNIFIED IDEOGRAPH-#69A0, IRGKangXi=0543.230, RSKangXi=75.10
69A1 CJK UNIFIED IDEOGRAPH-#69A1, IRGKangXi=0543.270, RSKangXi=75.10
69A2 CJK UNIFIED IDEOGRAPH-#69A2, IRGKangXi=0543.280, RSKangXi=75.10, Def{a frame, a stand, a rack. framework or scaffold.to lay on a frame; to put up}
69A3 CJK UNIFIED IDEOGRAPH-#69A3, IRGKangXi=0543.300, RSKangXi=75.10
69A4 CJK UNIFIED IDEOGRAPH-#69A4, IRGKangXi=0543.330, RSKangXi=75.10, Def{perch for fowls roost on}
69A5 CJK UNIFIED IDEOGRAPH-#69A5, IRGKangXi=0543.350, RSKangXi=75.10, Def{screen}
69A6 CJK UNIFIED IDEOGRAPH-#69A6, IRGKangXi=0544.010, RSKangXi=75.10, Def{tree trunk; support, prop}
69A7 CJK UNIFIED IDEOGRAPH-#69A7, IRGKangXi=0544.020, RSKangXi=75.10, Def{type of yew}
69A8 CJK UNIFIED IDEOGRAPH-#69A8, IRGKangXi=0544.030, RSKangXi=75.10, Def{to press or extract juices; a press to extract juices; a vegetable}
69A9 CJK UNIFIED IDEOGRAPH-#69A9, IRGKangXi=0546.251, RSKangXi=75.10
69AA CJK UNIFIED IDEOGRAPH-#69AA, IRGKangXi=0544.050, RSKangXi=75.10, Def{headboard}
69AB CJK UNIFIED IDEOGRAPH-#69AB, IRGKangXi=0544.080, RSKangXi=75.10, Def{mortise and tenon; fit into}
69AC CJK UNIFIED IDEOGRAPH-#69AC, IRGKangXi=0544.090, RSKangXi=75.10
69AD CJK UNIFIED IDEOGRAPH-#69AD, IRGKangXi=0544.160, RSKangXi=75.10, Def{kiosk, pavilion}
69AE CJK UNIFIED IDEOGRAPH-#69AE, IRGKangXi=0544.170, RSKangXi=75.10, Def{glory, honor; flourish, prosper}
69AF CJK UNIFIED IDEOGRAPH-#69AF, IRGKangXi=0544.180, RSKangXi=75.10
69B0 CJK UNIFIED IDEOGRAPH-#69B0, IRGKangXi=0544.190, RSKangXi=75.10
69B1 CJK UNIFIED IDEOGRAPH-#69B1, IRGKangXi=0544.200, RSKangXi=75.10, Def{rafter}
69B2 CJK UNIFIED IDEOGRAPH-#69B2, IRGKangXi=0544.210, RSKangXi=75.10, Def{pillar, cryptomeria}
69B3 CJK UNIFIED IDEOGRAPH-#69B3, IRGKangXi=0544.230, RSKangXi=75.10
69B4 CJK UNIFIED IDEOGRAPH-#69B4, IRGKangXi=0544.240, RSKangXi=75.10, Def{pomegranate}
69B5 CJK UNIFIED IDEOGRAPH-#69B5, IRGKangXi=0544.250, RSKangXi=75.10
69B6 CJK UNIFIED IDEOGRAPH-#69B6, IRGKangXi=0544.260, RSKangXi=75.10
69B7 CJK UNIFIED IDEOGRAPH-#69B7, IRGKangXi=0544.270, RSKangXi=75.10, Def{footbridge; toll, levy; monopoly}
69B8 CJK UNIFIED IDEOGRAPH-#69B8, IRGKangXi=0545.040, RSKangXi=75.10
69B9 CJK UNIFIED IDEOGRAPH-#69B9, IRGKangXi=0545.050, RSKangXi=75.10
69BA CJK UNIFIED IDEOGRAPH-#69BA, IRGKangXi=0545.070, RSKangXi=75.10
69BB CJK UNIFIED IDEOGRAPH-#69BB, IRGKangXi=0545.090, RSKangXi=75.10, Def{cot, couch, bed}
69BC CJK UNIFIED IDEOGRAPH-#69BC, IRGKangXi=0545.120, RSKangXi=75.10, Def{wine glass}
69BD CJK UNIFIED IDEOGRAPH-#69BD, IRGKangXi=0545.130, RSKangXi=75.10
69BE CJK UNIFIED IDEOGRAPH-#69BE, IRGKangXi=0545.140, RSKangXi=75.10, Def{pieces of wood}
69BF CJK UNIFIED IDEOGRAPH-#69BF, IRGKangXi=0545.150, RSKangXi=75.10, Def{alder}
69C0 CJK UNIFIED IDEOGRAPH-#69C0, IRGKangXi=0545.160, RSKangXi=75.10, Def{draft, manuscript}
69C1 CJK UNIFIED IDEOGRAPH-#69C1, IRGKangXi=0545.170, RSKangXi=75.10, Def{wither; withered, rotten, dead}
69C2 CJK UNIFIED IDEOGRAPH-#69C2, IRGKangXi=0545.190, RSKangXi=75.10
69C3 CJK UNIFIED IDEOGRAPH-#69C3, IRGKangXi=0545.200, RSKangXi=75.10, Def{tray; turn, rotate; search}
69C4 CJK UNIFIED IDEOGRAPH-#69C4, IRGKangXi=0545.220, RSKangXi=75.10
69C5 CJK UNIFIED IDEOGRAPH-#69C5, IRGKangXi=0545.230, RSKangXi=75.10
69C6 CJK UNIFIED IDEOGRAPH-#69C6, IRGKangXi=0545.260, RSKangXi=75.10
69C7 CJK UNIFIED IDEOGRAPH-#69C7, IRGKangXi=0545.270, RSKangXi=75.10, Def{tip of a tree; fallen tree}
69C8 CJK UNIFIED IDEOGRAPH-#69C8, IRGKangXi=0546.020, RSKangXi=75.10
69C9 CJK UNIFIED IDEOGRAPH-#69C9, IRGKangXi=0546.040, RSKangXi=75.10
69CA CJK UNIFIED IDEOGRAPH-#69CA, IRGKangXi=0546.060, RSKangXi=75.10, Def{spear, lance}
69CB CJK UNIFIED IDEOGRAPH-#69CB, IRGKangXi=0546.070, RSKangXi=75.10, Def{frame, building, structure}
69CC CJK UNIFIED IDEOGRAPH-#69CC, IRGKangXi=0546.080, RSKangXi=75.10, Def{hammer, mallet; strike, beat}
69CD CJK UNIFIED IDEOGRAPH-#69CD, IRGKangXi=0546.090, RSKangXi=75.10, Def{spear, lance; gun, rifle}
69CE CJK UNIFIED IDEOGRAPH-#69CE, IRGKangXi=0546.100, RSKangXi=75.10, Def{raft; time, occasion; to hew}
69CF CJK UNIFIED IDEOGRAPH-#69CF, IRGKangXi=0546.110, RSKangXi=75.10
69D0 CJK UNIFIED IDEOGRAPH-#69D0, IRGKangXi=0546.130, RSKangXi=75.10, Def{locust tree}
69D1 CJK UNIFIED IDEOGRAPH-#69D1, IRGKangXi=0546.140, RSKangXi=75.10
69D2 CJK UNIFIED IDEOGRAPH-#69D2, IRGKangXi=0546.230, RSKangXi=75.10
69D3 CJK UNIFIED IDEOGRAPH-#69D3, IRGKangXi=0546.251, RSKangXi=75.10, Def{lever, pole, crowbar; sharpen; (Cant.) a wardrobe, trunk}
69D4 CJK UNIFIED IDEOGRAPH-#69D4, IRGKangXi=0546.251, RSKangXi=75.10
69D5 CJK UNIFIED IDEOGRAPH-#69D5, IRGKangXi=0546.251, RSKangXi=75.10
69D6 CJK UNIFIED IDEOGRAPH-#69D6, IRGKangXi=0546.251, RSKangXi=75.10, Def{a sack; a stamping sound}
69D7 CJK UNIFIED IDEOGRAPH-#69D7, IRGKangXi=0546.251, RSKangXi=75.10
69D8 CJK UNIFIED IDEOGRAPH-#69D8, IRGKangXi=0546.251, RSKangXi=75.10, Def{shape, form, pattern, style}
69D9 CJK UNIFIED IDEOGRAPH-#69D9, IRGKangXi=0546.251, RSKangXi=75.10, Def{a twig; an ornamental evergreen}
69DA CJK UNIFIED IDEOGRAPH-#69DA, IRGKangXi=0546.251, RSKangXi=75.13, Def{small evergreen shrub}
69DB CJK UNIFIED IDEOGRAPH-#69DB, IRGKangXi=0546.251, RSKangXi=75.10, Def{threshold, door-sill}
69DC CJK UNIFIED IDEOGRAPH-#69DC, IRGKangXi=0546.251, RSKangXi=75.10
69DD CJK UNIFIED IDEOGRAPH-#69DD, IRGKangXi=0546.251, RSKangXi=75.10
69DE CJK UNIFIED IDEOGRAPH-#69DE, IRGKangXi=0546.251, RSKangXi=75.10
69DF CJK UNIFIED IDEOGRAPH-#69DF, IRGKangXi=0546.251, RSKangXi=75.10, Def{betel-nut, areca nut}
69E0 CJK UNIFIED IDEOGRAPH-#69E0, IRGKangXi=0551.181, RSKangXi=75.10, Def{Oak}
69E1 CJK UNIFIED IDEOGRAPH-#69E1, IRGKangXi=0546.251, RSKangXi=75.10
69E2 CJK UNIFIED IDEOGRAPH-#69E2, IRGKangXi=0546.260, RSKangXi=75.11, Def{a hard wood}
69E3 CJK UNIFIED IDEOGRAPH-#69E3, IRGKangXi=0546.270, RSKangXi=75.11
69E4 CJK UNIFIED IDEOGRAPH-#69E4, IRGKangXi=0546.280, RSKangXi=75.11, Def{a flail}
69E5 CJK UNIFIED IDEOGRAPH-#69E5, IRGKangXi=0546.290, RSKangXi=75.11, Def{coffin}
69E6 CJK UNIFIED IDEOGRAPH-#69E6, IRGKangXi=0547.010, RSKangXi=75.11
69E7 CJK UNIFIED IDEOGRAPH-#69E7, IRGKangXi=0547.020, RSKangXi=75.11, Def{wooden tablet; edition}
69E8 CJK UNIFIED IDEOGRAPH-#69E8, IRGKangXi=0547.050, RSKangXi=75.11, Def{outer-coffin}
69E9 CJK UNIFIED IDEOGRAPH-#69E9, IRGKangXi=0547.060, RSKangXi=75.10, Def{generally, approximately}
69EA CJK UNIFIED IDEOGRAPH-#69EA, IRGKangXi=0547.070, RSKangXi=75.11, Def{generally}
69EB CJK UNIFIED IDEOGRAPH-#69EB, IRGKangXi=0547.090, RSKangXi=75.11
69EC CJK UNIFIED IDEOGRAPH-#69EC, IRGKangXi=0547.110, RSKangXi=75.11
69ED CJK UNIFIED IDEOGRAPH-#69ED, IRGKangXi=0547.120, RSKangXi=75.11, Def{maple}
69EE CJK UNIFIED IDEOGRAPH-#69EE, IRGKangXi=0547.130, RSKangXi=75.11
69EF CJK UNIFIED IDEOGRAPH-#69EF, IRGKangXi=0547.140, RSKangXi=75.11
69F0 CJK UNIFIED IDEOGRAPH-#69F0, IRGKangXi=0547.160, RSKangXi=75.11
69F1 CJK UNIFIED IDEOGRAPH-#69F1, IRGKangXi=0547.170, RSKangXi=75.11, Def{firewood for sacrifice}
69F2 CJK UNIFIED IDEOGRAPH-#69F2, IRGKangXi=0547.180, RSKangXi=75.11, Def{type of oak}
69F3 CJK UNIFIED IDEOGRAPH-#69F3, IRGKangXi=0547.210, RSKangXi=75.11, Def{oar, paddle}
69F4 CJK UNIFIED IDEOGRAPH-#69F4, IRGKangXi=0548.010, RSKangXi=75.11
69F5 CJK UNIFIED IDEOGRAPH-#69F5, IRGKangXi=0548.020, RSKangXi=75.11
69F6 CJK UNIFIED IDEOGRAPH-#69F6, IRGKangXi=0548.030, RSKangXi=75.11
69F7 CJK UNIFIED IDEOGRAPH-#69F7, IRGKangXi=0548.040, RSKangXi=75.11
69F8 CJK UNIFIED IDEOGRAPH-#69F8, IRGKangXi=0548.050, RSKangXi=75.11
69F9 CJK UNIFIED IDEOGRAPH-#69F9, IRGKangXi=0548.060, RSKangXi=75.11, Def{spar; well-sweep}
69FA CJK UNIFIED IDEOGRAPH-#69FA, IRGKangXi=0548.090, RSKangXi=75.11
69FB CJK UNIFIED IDEOGRAPH-#69FB, IRGKangXi=0548.110, RSKangXi=75.11, Def{zelkova tree}
69FC CJK UNIFIED IDEOGRAPH-#69FC, IRGKangXi=0548.120, RSKangXi=75.11, Def{rules, regulations, customs, law}
69FD CJK UNIFIED IDEOGRAPH-#69FD, IRGKangXi=0548.140, RSKangXi=75.11, Def{trough; manger; vat, tank; groove; a distillery}
69FE CJK UNIFIED IDEOGRAPH-#69FE, IRGKangXi=0548.150, RSKangXi=75.11, Def{paste wall with dirt}
69FF CJK UNIFIED IDEOGRAPH-#69FF, IRGKangXi=0548.160, RSKangXi=75.11, Def{hibiscus}
6A00 CJK UNIFIED IDEOGRAPH-#6A00, IRGKangXi=0548.170, RSKangXi=75.11
6A01 CJK UNIFIED IDEOGRAPH-#6A01, IRGKangXi=0548.190, RSKangXi=75.11, Def{stake, post; affair, matter}
6A02 CJK UNIFIED IDEOGRAPH-#6A02, IRGKangXi=0548.200, RSKangXi=75.11, Def{happy, glad; enjoyable; music}
6A03 CJK UNIFIED IDEOGRAPH-#6A03, IRGKangXi=0549.010, RSKangXi=75.11
6A04 CJK UNIFIED IDEOGRAPH-#6A04, IRGKangXi=0549.040, RSKangXi=75.11
6A05 CJK UNIFIED IDEOGRAPH-#6A05, IRGKangXi=0549.050, RSKangXi=75.11, Def{fir tree}
6A06 CJK UNIFIED IDEOGRAPH-#6A06, IRGKangXi=0549.060, RSKangXi=75.11
6A07 CJK UNIFIED IDEOGRAPH-#6A07, IRGKangXi=0549.080, RSKangXi=75.11
6A08 CJK UNIFIED IDEOGRAPH-#6A08, IRGKangXi=0549.100, RSKangXi=75.11
6A09 CJK UNIFIED IDEOGRAPH-#6A09, IRGKangXi=0549.130, RSKangXi=75.11
6A0A CJK UNIFIED IDEOGRAPH-#6A0A, IRGKangXi=0549.150, RSKangXi=75.11, Def{a railing; a fence an enclosed place}
6A0B CJK UNIFIED IDEOGRAPH-#6A0B, IRGKangXi=0549.160, RSKangXi=75.11, Def{tree name}
6A0C CJK UNIFIED IDEOGRAPH-#6A0C, IRGKangXi=0549.170, RSKangXi=75.11
6A0D CJK UNIFIED IDEOGRAPH-#6A0D, IRGKangXi=0549.210, RSKangXi=75.11
6A0E CJK UNIFIED IDEOGRAPH-#6A0E, IRGKangXi=0549.220, RSKangXi=75.11
6A0F CJK UNIFIED IDEOGRAPH-#6A0F, IRGKangXi=0549.260, RSKangXi=75.11, Def{sedan}
6A10 CJK UNIFIED IDEOGRAPH-#6A10, IRGKangXi=0549.270, RSKangXi=75.11, Def{a lookout turret on a city wall, movable wooden tower for archers; a scull a sweep, an oar}
6A11 CJK UNIFIED IDEOGRAPH-#6A11, IRGKangXi=0549.280, RSKangXi=75.11, Def{bridge; beam}
6A12 CJK UNIFIED IDEOGRAPH-#6A12, IRGKangXi=0549.290, RSKangXi=75.11, Def{a tree whose branches are placed on Buddhist graves}
6A13 CJK UNIFIED IDEOGRAPH-#6A13, IRGKangXi=0549.310, RSKangXi=75.11, Def{building of two or more stories}
6A14 CJK UNIFIED IDEOGRAPH-#6A14, IRGKangXi=0550.030, RSKangXi=75.11
6A15 CJK UNIFIED IDEOGRAPH-#6A15, IRGKangXi=0550.050, RSKangXi=75.11, Def{shrub}
6A16 CJK UNIFIED IDEOGRAPH-#6A16, IRGKangXi=0550.070, RSKangXi=75.11, Def{(Cant.) classifier for plants or trees; a tree-trunk}
6A17 CJK UNIFIED IDEOGRAPH-#6A17, IRGKangXi=0550.080, RSKangXi=75.11, Def{Ailanthus glandulosa or A. altissima, a kind of tree useless as timber}
6A18 CJK UNIFIED IDEOGRAPH-#6A18, IRGKangXi=0550.100, RSKangXi=75.11
6A19 CJK UNIFIED IDEOGRAPH-#6A19, IRGKangXi=0550.120, RSKangXi=75.11, Def{a mark, symbol, label, sign; standard}
6A1A CJK UNIFIED IDEOGRAPH-#6A1A, IRGKangXi=0550.130, RSKangXi=75.11, Def{a pulley, a windlass, a wheel, a block}
6A1B CJK UNIFIED IDEOGRAPH-#6A1B, IRGKangXi=0550.150, RSKangXi=75.11, Def{bending branches, bent limbs}
6A1C CJK UNIFIED IDEOGRAPH-#6A1C, IRGKangXi=0550.170, RSKangXi=75.11
6A1D CJK UNIFIED IDEOGRAPH-#6A1D, IRGKangXi=0550.190, RSKangXi=75.11, Def{a kind of hawthorne}
6A1E CJK UNIFIED IDEOGRAPH-#6A1E, IRGKangXi=0550.200, RSKangXi=75.11, Def{door hinge; pivot; center of power}
6A1F CJK UNIFIED IDEOGRAPH-#6A1F, IRGKangXi=0550.210, RSKangXi=75.11, Def{camphor tree}
6A20 CJK UNIFIED IDEOGRAPH-#6A20, IRGKangXi=0551.010, RSKangXi=75.11, Def{elm; gum}
6A21 CJK UNIFIED IDEOGRAPH-#6A21, IRGKangXi=0551.020, RSKangXi=75.11, Def{model, standard, pattern; copy}
6A22 CJK UNIFIED IDEOGRAPH-#6A22, IRGKangXi=0551.040, RSKangXi=75.11
6A23 CJK UNIFIED IDEOGRAPH-#6A23, IRGKangXi=0551.050, RSKangXi=75.11, Def{shape, form, pattern, style}
6A24 CJK UNIFIED IDEOGRAPH-#6A24, IRGKangXi=0551.080, RSKangXi=75.11
6A25 CJK UNIFIED IDEOGRAPH-#6A25, IRGKangXi=0551.100, RSKangXi=75.11
6A26 CJK UNIFIED IDEOGRAPH-#6A26, IRGKangXi=0551.110, RSKangXi=75.11
6A27 CJK UNIFIED IDEOGRAPH-#6A27, IRGKangXi=0551.181, RSKangXi=75.11
6A28 CJK UNIFIED IDEOGRAPH-#6A28, IRGKangXi=0555.311, RSKangXi=75.11, Def{scrambled eggs}
6A29 CJK UNIFIED IDEOGRAPH-#6A29, IRGKangXi=0551.181, RSKangXi=75.11, Def{power, right, authority}
6A2A CJK UNIFIED IDEOGRAPH-#6A2A, IRGKangXi=0551.181, RSKangXi=75.11, Def{across}
6A2B CJK UNIFIED IDEOGRAPH-#6A2B, IRGKangXi=0551.181, RSKangXi=75.11, Def{evergreen oak}
6A2C CJK UNIFIED IDEOGRAPH-#6A2C, IRGKangXi=0551.181, RSKangXi=75.11
6A2D CJK UNIFIED IDEOGRAPH-#6A2D, IRGKangXi=0551.181, RSKangXi=75.11
6A2E CJK UNIFIED IDEOGRAPH-#6A2E, IRGKangXi=0551.181, RSKangXi=75.10
6A2F CJK UNIFIED IDEOGRAPH-#6A2F, IRGKangXi=0551.181, RSKangXi=75.11, Def{mast, yard-arm, boom}
6A30 CJK UNIFIED IDEOGRAPH-#6A30, IRGKangXi=0551.181, RSKangXi=75.11
6A31 CJK UNIFIED IDEOGRAPH-#6A31, IRGKangXi=0551.181, RSKangXi=75.11, Def{cherry, cherry blossom}
6A32 CJK UNIFIED IDEOGRAPH-#6A32, IRGKangXi=0551.190, RSKangXi=75.12, Def{jujube}
6A33 CJK UNIFIED IDEOGRAPH-#6A33, IRGKangXi=0551.200, RSKangXi=75.12, Def{tall tree}
6A34 CJK UNIFIED IDEOGRAPH-#6A34, IRGKangXi=0551.210, RSKangXi=75.12
6A35 CJK UNIFIED IDEOGRAPH-#6A35, IRGKangXi=0551.220, RSKangXi=75.12, Def{woodcutter; firewood; gather wood}
6A36 CJK UNIFIED IDEOGRAPH-#6A36, IRGKangXi=0551.240, RSKangXi=75.12, Def{a wooden joint}
6A37 CJK UNIFIED IDEOGRAPH-#6A37, IRGKangXi=0551.250, RSKangXi=75.12, Def{bushy; a grove; crowded}
6A38 CJK UNIFIED IDEOGRAPH-#6A38, IRGKangXi=0551.280, RSKangXi=75.12, Def{simple, honest; plain; rough}
6A39 CJK UNIFIED IDEOGRAPH-#6A39, IRGKangXi=0551.290, RSKangXi=75.12, Def{tree; plant; set up, establish}
6A3A CJK UNIFIED IDEOGRAPH-#6A3A, IRGKangXi=0552.010, RSKangXi=75.12, Def{type of birch}
6A3B CJK UNIFIED IDEOGRAPH-#6A3B, IRGKangXi=0552.020, RSKangXi=75.12, Def{cupboard, wardrobe, counter}
6A3C CJK UNIFIED IDEOGRAPH-#6A3C, IRGKangXi=0552.030, RSKangXi=75.12
6A3D CJK UNIFIED IDEOGRAPH-#6A3D, IRGKangXi=0552.040, RSKangXi=75.12, Def{goblet; jar, jug; lush}
6A3E CJK UNIFIED IDEOGRAPH-#6A3E, IRGKangXi=0552.060, RSKangXi=75.12, Def{the shade of trees}
6A3F CJK UNIFIED IDEOGRAPH-#6A3F, IRGKangXi=0552.080, RSKangXi=75.12, Def{coffin}
6A40 CJK UNIFIED IDEOGRAPH-#6A40, IRGKangXi=0552.090, RSKangXi=75.12
6A41 CJK UNIFIED IDEOGRAPH-#6A41, IRGKangXi=0552.100, RSKangXi=75.12, Def{tree}
6A42 CJK UNIFIED IDEOGRAPH-#6A42, IRGKangXi=0552.110, RSKangXi=75.12
6A43 CJK UNIFIED IDEOGRAPH-#6A43, IRGKangXi=0552.120, RSKangXi=75.12
6A44 CJK UNIFIED IDEOGRAPH-#6A44, IRGKangXi=0552.160, RSKangXi=75.12, Def{olive}
6A45 CJK UNIFIED IDEOGRAPH-#6A45, IRGKangXi=0552.170, RSKangXi=75.12, Def{a beech tree}
6A46 CJK UNIFIED IDEOGRAPH-#6A46, IRGKangXi=0552.180, RSKangXi=75.12, Def{without, apart from, none; a negative}
6A47 CJK UNIFIED IDEOGRAPH-#6A47, IRGKangXi=0552.210, RSKangXi=75.12, Def{a sledge for transportation}
6A48 CJK UNIFIED IDEOGRAPH-#6A48, IRGKangXi=0552.250, RSKangXi=75.12, Def{bent or twisted piece of wood; a paddle}
6A49 CJK UNIFIED IDEOGRAPH-#6A49, IRGKangXi=0552.280, RSKangXi=75.12
6A4A CJK UNIFIED IDEOGRAPH-#6A4A, IRGKangXi=0552.290, RSKangXi=75.12, Def{variant of 榴 U+69B4, pomegranate}
6A4B CJK UNIFIED IDEOGRAPH-#6A4B, IRGKangXi=0553.010, RSKangXi=75.12, Def{bridge; beam, crosspiece}
6A4C CJK UNIFIED IDEOGRAPH-#6A4C, IRGKangXi=0553.020, RSKangXi=75.12
6A4D CJK UNIFIED IDEOGRAPH-#6A4D, IRGKangXi=0553.040, RSKangXi=75.12
6A4E CJK UNIFIED IDEOGRAPH-#6A4E, IRGKangXi=0553.060, RSKangXi=75.12
6A4F CJK UNIFIED IDEOGRAPH-#6A4F, IRGKangXi=0553.070, RSKangXi=75.12
6A50 CJK UNIFIED IDEOGRAPH-#6A50, IRGKangXi=0553.080, RSKangXi=75.12, Def{a sack, a bag opening at both ends}
6A51 CJK UNIFIED IDEOGRAPH-#6A51, IRGKangXi=0553.100, RSKangXi=75.12
6A52 CJK UNIFIED IDEOGRAPH-#6A52, IRGKangXi=0553.130, RSKangXi=75.12, Def{wood streaks}
6A53 CJK UNIFIED IDEOGRAPH-#6A53, IRGKangXi=0553.160, RSKangXi=75.12, Def{hibiscus; transient}
6A54 CJK UNIFIED IDEOGRAPH-#6A54, IRGKangXi=0553.170, RSKangXi=75.12, Def{withered, dried-up; cloth coffin-lid cover}
6A55 CJK UNIFIED IDEOGRAPH-#6A55, IRGKangXi=0553.190, RSKangXi=75.12, Def{a prop; a shore}
6A56 CJK UNIFIED IDEOGRAPH-#6A56, IRGKangXi=0553.200, RSKangXi=75.12
6A57 CJK UNIFIED IDEOGRAPH-#6A57, IRGKangXi=0553.250, RSKangXi=75.12
6A58 CJK UNIFIED IDEOGRAPH-#6A58, IRGKangXi=0553.270, RSKangXi=75.12, Def{orange, tangerine}
6A59 CJK UNIFIED IDEOGRAPH-#6A59, IRGKangXi=0553.280, RSKangXi=75.12, Def{orange}
6A5A CJK UNIFIED IDEOGRAPH-#6A5A, IRGKangXi=0554.020, RSKangXi=75.12, Def{tall tree}
6A5B CJK UNIFIED IDEOGRAPH-#6A5B, IRGKangXi=0554.030, RSKangXi=75.12, Def{a post, a stake; an axle}
6A5C CJK UNIFIED IDEOGRAPH-#6A5C, IRGKangXi=0554.040, RSKangXi=75.12, Def{a post, a stake; an axle}
6A5D CJK UNIFIED IDEOGRAPH-#6A5D, IRGKangXi=0554.050, RSKangXi=75.12
6A5E CJK UNIFIED IDEOGRAPH-#6A5E, IRGKangXi=0554.070, RSKangXi=75.12
6A5F CJK UNIFIED IDEOGRAPH-#6A5F, IRGKangXi=0554.080, RSKangXi=75.12, Def{machine; moment, chance}
6A60 CJK UNIFIED IDEOGRAPH-#6A60, IRGKangXi=0554.090, RSKangXi=75.12
6A61 CJK UNIFIED IDEOGRAPH-#6A61, IRGKangXi=0554.110, RSKangXi=75.12, Def{chestnut oak; rubber tree; rubber}
6A62 CJK UNIFIED IDEOGRAPH-#6A62, IRGKangXi=0554.120, RSKangXi=75.12, Def{oval-shaped, elliptical, tubular}
6A63 CJK UNIFIED IDEOGRAPH-#6A63, IRGKangXi=0554.130, RSKangXi=75.12
6A64 CJK UNIFIED IDEOGRAPH-#6A64, IRGKangXi=0554.150, RSKangXi=75.12, Def{stamen}
6A65 CJK UNIFIED IDEOGRAPH-#6A65, IRGKangXi=0554.210, RSKangXi=75.11, Def{wooden peg, post or stick}
6A66 CJK UNIFIED IDEOGRAPH-#6A66, IRGKangXi=0554.230, RSKangXi=75.12, Def{tree}
6A67 CJK UNIFIED IDEOGRAPH-#6A67, IRGKangXi=0555.020, RSKangXi=75.12, Def{hut}
6A68 CJK UNIFIED IDEOGRAPH-#6A68, IRGKangXi=0555.030, RSKangXi=75.12
6A69 CJK UNIFIED IDEOGRAPH-#6A69, IRGKangXi=0555.040, RSKangXi=75.12
6A6A CJK UNIFIED IDEOGRAPH-#6A6A, IRGKangXi=0555.050, RSKangXi=75.12
6A6B CJK UNIFIED IDEOGRAPH-#6A6B, IRGKangXi=0555.100, RSKangXi=75.12, Def{across, horizontal, lateral}
6A6C CJK UNIFIED IDEOGRAPH-#6A6C, IRGKangXi=0555.110, RSKangXi=75.12
6A6D CJK UNIFIED IDEOGRAPH-#6A6D, IRGKangXi=0555.140, RSKangXi=75.12
6A6E CJK UNIFIED IDEOGRAPH-#6A6E, IRGKangXi=0555.160, RSKangXi=75.12
6A6F CJK UNIFIED IDEOGRAPH-#6A6F, IRGKangXi=0555.190, RSKangXi=75.12
6A70 CJK UNIFIED IDEOGRAPH-#6A70, IRGKangXi=0555.311, RSKangXi=75.12, Def{a spar}
6A71 CJK UNIFIED IDEOGRAPH-#6A71, IRGKangXi=0555.311, RSKangXi=75.12, Def{cabinet, wardrobe, cupboard}
6A72 CJK UNIFIED IDEOGRAPH-#6A72, IRGKangXi=0555.311, RSKangXi=75.12
6A73 CJK UNIFIED IDEOGRAPH-#6A73, IRGKangXi=0555.311, RSKangXi=75.12
6A74 CJK UNIFIED IDEOGRAPH-#6A74, IRGKangXi=0551.181, RSKangXi=75.11, Def{place name}
6A75 CJK UNIFIED IDEOGRAPH-#6A75, IRGKangXi=0555.311, RSKangXi=75.12, Def{wood placed under roof tiles}
6A76 CJK UNIFIED IDEOGRAPH-#6A76, IRGKangXi=0555.311, RSKangXi=75.12
6A77 CJK UNIFIED IDEOGRAPH-#6A77, IRGKangXi=0555.311, RSKangXi=75.12
6A78 CJK UNIFIED IDEOGRAPH-#6A78, IRGKangXi=0555.311, RSKangXi=75.12
6A79 CJK UNIFIED IDEOGRAPH-#6A79, IRGKangXi=0555.311, RSKangXi=75.12, Def{oar, scull; row, scull}
6A7A CJK UNIFIED IDEOGRAPH-#6A7A, IRGKangXi=0555.311, RSKangXi=75.12, Def{(Cant.) a partition; to separate}
6A7B CJK UNIFIED IDEOGRAPH-#6A7B, IRGKangXi=0555.311, RSKangXi=75.12
6A7C CJK UNIFIED IDEOGRAPH-#6A7C, IRGKangXi=0555.311, RSKangXi=75.12, Def{citrus}
6A7D CJK UNIFIED IDEOGRAPH-#6A7D, IRGKangXi=0555.320, RSKangXi=75.13
6A7E CJK UNIFIED IDEOGRAPH-#6A7E, IRGKangXi=0555.350, RSKangXi=75.13, Def{the hole in the center of a wheel accommodating the axle (archaic)}
6A7F CJK UNIFIED IDEOGRAPH-#6A7F, IRGKangXi=0555.360, RSKangXi=75.13, Def{a kind of oak}
6A80 CJK UNIFIED IDEOGRAPH-#6A80, IRGKangXi=0555.390, RSKangXi=75.13, Def{sandalwood, hardwood; surname}
6A81 CJK UNIFIED IDEOGRAPH-#6A81, IRGKangXi=0556.010, RSKangXi=75.13, Def{the bole of a tree; a cross beam; the combing round the hatches of a ship}
6A82 CJK UNIFIED IDEOGRAPH-#6A82, IRGKangXi=0556.020, RSKangXi=75.13
6A83 CJK UNIFIED IDEOGRAPH-#6A83, IRGKangXi=0556.040, RSKangXi=75.13
6A84 CJK UNIFIED IDEOGRAPH-#6A84, IRGKangXi=0556.070, RSKangXi=75.13, Def{call arms; urgency}
6A85 CJK UNIFIED IDEOGRAPH-#6A85, IRGKangXi=0556.100, RSKangXi=75.13
6A86 CJK UNIFIED IDEOGRAPH-#6A86, IRGKangXi=0556.110, RSKangXi=75.13
6A87 CJK UNIFIED IDEOGRAPH-#6A87, IRGKangXi=0556.120, RSKangXi=75.13, Def{wooden rammer or pestle; place}
6A88 CJK UNIFIED IDEOGRAPH-#6A88, IRGKangXi=0556.150, RSKangXi=75.13
6A89 CJK UNIFIED IDEOGRAPH-#6A89, IRGKangXi=0556.180, RSKangXi=75.13, Def{type of willow; tamarisk}
6A8A CJK UNIFIED IDEOGRAPH-#6A8A, IRGKangXi=0556.200, RSKangXi=75.13
6A8B CJK UNIFIED IDEOGRAPH-#6A8B, IRGKangXi=0556.210, RSKangXi=75.13
6A8C CJK UNIFIED IDEOGRAPH-#6A8C, IRGKangXi=0556.230, RSKangXi=75.13
6A8D CJK UNIFIED IDEOGRAPH-#6A8D, IRGKangXi=0556.240, RSKangXi=75.13, Def{ilex}
6A8E CJK UNIFIED IDEOGRAPH-#6A8E, IRGKangXi=0556.250, RSKangXi=75.13, Def{small red apple}
6A8F CJK UNIFIED IDEOGRAPH-#6A8F, IRGKangXi=0556.260, RSKangXi=75.13
6A90 CJK UNIFIED IDEOGRAPH-#6A90, IRGKangXi=0556.270, RSKangXi=75.13, Def{eaves of house; brim, rim}
6A91 CJK UNIFIED IDEOGRAPH-#6A91, IRGKangXi=0556.280, RSKangXi=75.13
6A92 CJK UNIFIED IDEOGRAPH-#6A92, IRGKangXi=0556.300, RSKangXi=75.13
6A93 CJK UNIFIED IDEOGRAPH-#6A93, IRGKangXi=0556.310, RSKangXi=75.13
6A94 CJK UNIFIED IDEOGRAPH-#6A94, IRGKangXi=0556.330, RSKangXi=75.13, Def{shelf; frame, crosspiece}
6A95 CJK UNIFIED IDEOGRAPH-#6A95, IRGKangXi=0557.010, RSKangXi=75.13
6A96 CJK UNIFIED IDEOGRAPH-#6A96, IRGKangXi=0557.020, RSKangXi=75.13, Def{wild pear tree}
6A97 CJK UNIFIED IDEOGRAPH-#6A97, IRGKangXi=0557.040, RSKangXi=75.13, Def{tree}
6A98 CJK UNIFIED IDEOGRAPH-#6A98, IRGKangXi=0557.050, RSKangXi=75.13
6A99 CJK UNIFIED IDEOGRAPH-#6A99, IRGKangXi=0557.060, RSKangXi=75.13
6A9A CJK UNIFIED IDEOGRAPH-#6A9A, IRGKangXi=0557.090, RSKangXi=75.13
6A9B CJK UNIFIED IDEOGRAPH-#6A9B, IRGKangXi=0557.100, RSKangXi=75.13, Def{a switch, whip}
6A9C CJK UNIFIED IDEOGRAPH-#6A9C, IRGKangXi=0557.110, RSKangXi=75.13, Def{Chinese cypress, Chinese juniper}
6A9D CJK UNIFIED IDEOGRAPH-#6A9D, IRGKangXi=0557.120, RSKangXi=75.13, Def{oar}
6A9E CJK UNIFIED IDEOGRAPH-#6A9E, IRGKangXi=0557.140, RSKangXi=75.13, Def{a kind of oak}
6A9F CJK UNIFIED IDEOGRAPH-#6A9F, IRGKangXi=0557.150, RSKangXi=75.13, Def{small evergreen shrub}
6AA0 CJK UNIFIED IDEOGRAPH-#6AA0, IRGKangXi=0557.160, RSKangXi=75.13, Def{stand for lamp; frame for bow}
6AA1 CJK UNIFIED IDEOGRAPH-#6AA1, IRGKangXi=0557.180, RSKangXi=75.13
6AA2 CJK UNIFIED IDEOGRAPH-#6AA2, IRGKangXi=0557.190, RSKangXi=75.13, Def{check; examine}
6AA3 CJK UNIFIED IDEOGRAPH-#6AA3, IRGKangXi=0557.220, RSKangXi=75.13, Def{mast, yard-arm, boom}
6AA4 CJK UNIFIED IDEOGRAPH-#6AA4, IRGKangXi=0557.230, RSKangXi=75.13
6AA5 CJK UNIFIED IDEOGRAPH-#6AA5, IRGKangXi=0557.250, RSKangXi=75.13, Def{variant of 艤 U+8264, to moor a boat to the bank}
6AA6 CJK UNIFIED IDEOGRAPH-#6AA6, IRGKangXi=0557.270, RSKangXi=75.13
6AA7 CJK UNIFIED IDEOGRAPH-#6AA7, IRGKangXi=0558.020, RSKangXi=75.13
6AA8 CJK UNIFIED IDEOGRAPH-#6AA8, IRGKangXi=0558.091, RSKangXi=75.13, Def{mango}
6AA9 CJK UNIFIED IDEOGRAPH-#6AA9, IRGKangXi=0558.091, RSKangXi=75.13, Def{the bole of a tree; a cross beam; the combing round the hatches of a ship}
6AAA CJK UNIFIED IDEOGRAPH-#6AAA, IRGKangXi=0558.091, RSKangXi=75.13, Def{chestnut-leaved oak; oak}
6AAB CJK UNIFIED IDEOGRAPH-#6AAB, IRGKangXi=0558.110, RSKangXi=75.14, Def{sassafras tzumu}
6AAC CJK UNIFIED IDEOGRAPH-#6AAC, IRGKangXi=0558.120, RSKangXi=75.14, Def{type of locust oracacia}
6AAD CJK UNIFIED IDEOGRAPH-#6AAD, IRGKangXi=0558.130, RSKangXi=75.14
6AAE CJK UNIFIED IDEOGRAPH-#6AAE, IRGKangXi=0558.150, RSKangXi=75.14, Def{block of wood; blockhead; stupid}
6AAF CJK UNIFIED IDEOGRAPH-#6AAF, IRGKangXi=0558.200, RSKangXi=75.14, Def{table}
6AB0 CJK UNIFIED IDEOGRAPH-#6AB0, IRGKangXi=0558.250, RSKangXi=75.14
6AB1 CJK UNIFIED IDEOGRAPH-#6AB1, IRGKangXi=0558.280, RSKangXi=75.14
6AB2 CJK UNIFIED IDEOGRAPH-#6AB2, IRGKangXi=0558.330, RSKangXi=75.14
6AB3 CJK UNIFIED IDEOGRAPH-#6AB3, IRGKangXi=0558.360, RSKangXi=75.14, Def{betel-nut, areca nut}
6AB4 CJK UNIFIED IDEOGRAPH-#6AB4, IRGKangXi=0558.370, RSKangXi=75.14, Def{tree}
6AB5 CJK UNIFIED IDEOGRAPH-#6AB5, IRGKangXi=0558.390, RSKangXi=75.14
6AB6 CJK UNIFIED IDEOGRAPH-#6AB6, IRGKangXi=0558.400, RSKangXi=75.14
6AB7 CJK UNIFIED IDEOGRAPH-#6AB7, IRGKangXi=0558.430, RSKangXi=75.14
6AB8 CJK UNIFIED IDEOGRAPH-#6AB8, IRGKangXi=0558.440, RSKangXi=75.14, Def{lemon}
6AB9 CJK UNIFIED IDEOGRAPH-#6AB9, IRGKangXi=0558.450, RSKangXi=75.14
6ABA CJK UNIFIED IDEOGRAPH-#6ABA, IRGKangXi=0558.460, RSKangXi=75.14
6ABB CJK UNIFIED IDEOGRAPH-#6ABB, IRGKangXi=0558.470, RSKangXi=75.14, Def{threshold, door-sill}
6ABC CJK UNIFIED IDEOGRAPH-#6ABC, IRGKangXi=0559.020, RSKangXi=75.14, Def{ridge pole; shape wood by use of heat; tool for shaping bent wood}
6ABD CJK UNIFIED IDEOGRAPH-#6ABD, IRGKangXi=0559.030, RSKangXi=75.14
6ABE CJK UNIFIED IDEOGRAPH-#6ABE, IRGKangXi=0559.040, RSKangXi=75.14, Def{grassy plant with fibres from which cloth is made}
6ABF CJK UNIFIED IDEOGRAPH-#6ABF, IRGKangXi=0559.050, RSKangXi=75.14, Def{mulberry}
6AC0 CJK UNIFIED IDEOGRAPH-#6AC0, IRGKangXi=0559.080, RSKangXi=75.14
6AC1 CJK UNIFIED IDEOGRAPH-#6AC1, IRGKangXi=0559.090, RSKangXi=75.14
6AC2 CJK UNIFIED IDEOGRAPH-#6AC2, IRGKangXi=0559.110, RSKangXi=75.14, Def{oar, scull, paddle; row}
6AC3 CJK UNIFIED IDEOGRAPH-#6AC3, IRGKangXi=0559.120, RSKangXi=75.14, Def{cupboard, wardrobe, counter}
6AC4 CJK UNIFIED IDEOGRAPH-#6AC4, IRGKangXi=0559.130, RSKangXi=75.14
6AC5 CJK UNIFIED IDEOGRAPH-#6AC5, IRGKangXi=0559.140, RSKangXi=75.14, Def{a kind of tree suitable for use to make axles for large carts}
6AC6 CJK UNIFIED IDEOGRAPH-#6AC6, IRGKangXi=0559.200, RSKangXi=75.14, Def{Polaris, the north star}
6AC7 CJK UNIFIED IDEOGRAPH-#6AC7, IRGKangXi=0559.250, RSKangXi=75.14
6AC8 CJK UNIFIED IDEOGRAPH-#6AC8, IRGKangXi=0559.261, RSKangXi=75.14, Def{bench; stool}
6AC9 CJK UNIFIED IDEOGRAPH-#6AC9, IRGKangXi=0559.261, RSKangXi=75.14
6ACA CJK UNIFIED IDEOGRAPH-#6ACA, IRGKangXi=0559.261, RSKangXi=75.14
6ACB CJK UNIFIED IDEOGRAPH-#6ACB, IRGKangXi=0559.280, RSKangXi=75.15
6ACC CJK UNIFIED IDEOGRAPH-#6ACC, IRGKangXi=0559.290, RSKangXi=75.15, Def{a kind of hoe}
6ACD CJK UNIFIED IDEOGRAPH-#6ACD, IRGKangXi=0559.300, RSKangXi=75.15
6ACE CJK UNIFIED IDEOGRAPH-#6ACE, IRGKangXi=0559.310, RSKangXi=75.15
6ACF CJK UNIFIED IDEOGRAPH-#6ACF, IRGKangXi=0559.330, RSKangXi=75.15
6AD0 CJK UNIFIED IDEOGRAPH-#6AD0, IRGKangXi=0560.020, RSKangXi=75.15
6AD1 CJK UNIFIED IDEOGRAPH-#6AD1, IRGKangXi=0560.030, RSKangXi=75.15
6AD2 CJK UNIFIED IDEOGRAPH-#6AD2, IRGKangXi=0560.040, RSKangXi=75.15
6AD3 CJK UNIFIED IDEOGRAPH-#6AD3, IRGKangXi=0560.050, RSKangXi=75.15, Def{oar, scull; row}
6AD4 CJK UNIFIED IDEOGRAPH-#6AD4, IRGKangXi=0560.070, RSKangXi=75.15
6AD5 CJK UNIFIED IDEOGRAPH-#6AD5, IRGKangXi=0560.080, RSKangXi=75.15
6AD6 CJK UNIFIED IDEOGRAPH-#6AD6, IRGKangXi=0560.120, RSKangXi=75.15
6AD7 CJK UNIFIED IDEOGRAPH-#6AD7, IRGKangXi=0560.130, RSKangXi=75.15
6AD8 CJK UNIFIED IDEOGRAPH-#6AD8, IRGKangXi=0560.140, RSKangXi=75.15
6AD9 CJK UNIFIED IDEOGRAPH-#6AD9, IRGKangXi=0560.180, RSKangXi=75.15
6ADA CJK UNIFIED IDEOGRAPH-#6ADA, IRGKangXi=0560.220, RSKangXi=75.15, Def{palm}
6ADB CJK UNIFIED IDEOGRAPH-#6ADB, IRGKangXi=0560.240, RSKangXi=75.15, Def{comb out; weed out, eliminate}
6ADC CJK UNIFIED IDEOGRAPH-#6ADC, IRGKangXi=0560.250, RSKangXi=75.15, Def{quiver (case for arrows)}
6ADD CJK UNIFIED IDEOGRAPH-#6ADD, IRGKangXi=0560.280, RSKangXi=75.15, Def{cabinet, wardrobe; closet}
6ADE CJK UNIFIED IDEOGRAPH-#6ADE, IRGKangXi=0560.290, RSKangXi=75.15, Def{citrus}
6ADF CJK UNIFIED IDEOGRAPH-#6ADF, IRGKangXi=0560.300, RSKangXi=75.15, Def{chestnut-leaved oak; oak}
6AE0 CJK UNIFIED IDEOGRAPH-#6AE0, IRGKangXi=0561.010, RSKangXi=75.15
6AE1 CJK UNIFIED IDEOGRAPH-#6AE1, IRGKangXi=0561.030, RSKangXi=75.15
6AE2 CJK UNIFIED IDEOGRAPH-#6AE2, IRGKangXi=0561.090, RSKangXi=75.15
6AE3 CJK UNIFIED IDEOGRAPH-#6AE3, IRGKangXi=0561.111, RSKangXi=75.15
6AE4 CJK UNIFIED IDEOGRAPH-#6AE4, IRGKangXi=0561.111, RSKangXi=75.15
6AE5 CJK UNIFIED IDEOGRAPH-#6AE5, IRGKangXi=0561.111, RSKangXi=75.15, Def{cabinet, wardrobe, cupboard}
6AE6 CJK UNIFIED IDEOGRAPH-#6AE6, IRGKangXi=0561.111, RSKangXi=75.15
6AE7 CJK UNIFIED IDEOGRAPH-#6AE7, IRGKangXi=0561.130, RSKangXi=75.16, Def{Oak}
6AE8 CJK UNIFIED IDEOGRAPH-#6AE8, IRGKangXi=0561.140, RSKangXi=75.16, Def{supporting block; sumac, loquat}
6AE9 CJK UNIFIED IDEOGRAPH-#6AE9, IRGKangXi=0561.150, RSKangXi=75.16
6AEA CJK UNIFIED IDEOGRAPH-#6AEA, IRGKangXi=0561.160, RSKangXi=75.16, Def{type of oak; stable}
6AEB CJK UNIFIED IDEOGRAPH-#6AEB, IRGKangXi=0561.180, RSKangXi=75.15, Def{wooden peg, post or stick}
6AEC CJK UNIFIED IDEOGRAPH-#6AEC, IRGKangXi=0561.210, RSKangXi=75.16, Def{coffin; tung tree}
6AED CJK UNIFIED IDEOGRAPH-#6AED, IRGKangXi=0561.230, RSKangXi=75.15
6AEE CJK UNIFIED IDEOGRAPH-#6AEE, IRGKangXi=0561.240, RSKangXi=75.16
6AEF CJK UNIFIED IDEOGRAPH-#6AEF, IRGKangXi=0561.290, RSKangXi=75.16
6AF0 CJK UNIFIED IDEOGRAPH-#6AF0, IRGKangXi=0561.320, RSKangXi=75.16
6AF1 CJK UNIFIED IDEOGRAPH-#6AF1, IRGKangXi=0561.330, RSKangXi=75.16, Def{yeast; leaven for making liquors}
6AF2 CJK UNIFIED IDEOGRAPH-#6AF2, IRGKangXi=0561.350, RSKangXi=75.16
6AF3 CJK UNIFIED IDEOGRAPH-#6AF3, IRGKangXi=0561.390, RSKangXi=75.16, Def{cage, pen; set of bars}
6AF4 CJK UNIFIED IDEOGRAPH-#6AF4, IRGKangXi=0562.040, RSKangXi=75.16
6AF5 CJK UNIFIED IDEOGRAPH-#6AF5, IRGKangXi=0562.101, RSKangXi=75.16
6AF6 CJK UNIFIED IDEOGRAPH-#6AF6, IRGKangXi=0562.101, RSKangXi=75.16
6AF7 CJK UNIFIED IDEOGRAPH-#6AF7, IRGKangXi=0562.101, RSKangXi=75.18
6AF8 CJK UNIFIED IDEOGRAPH-#6AF8, IRGKangXi=0562.101, RSKangXi=75.17, Def{type of elm}
6AF9 CJK UNIFIED IDEOGRAPH-#6AF9, IRGKangXi=0562.150, RSKangXi=75.17
6AFA CJK UNIFIED IDEOGRAPH-#6AFA, IRGKangXi=0562.170, RSKangXi=75.17, Def{carved or patterned window sills}
6AFB CJK UNIFIED IDEOGRAPH-#6AFB, IRGKangXi=0562.180, RSKangXi=75.17, Def{cherry, cherry blossom}
6AFC CJK UNIFIED IDEOGRAPH-#6AFC, IRGKangXi=0562.190, RSKangXi=75.17
6AFD CJK UNIFIED IDEOGRAPH-#6AFD, IRGKangXi=0562.220, RSKangXi=75.17, Def{shape wood by use of heat; tool for shaping bent wood}
6AFE CJK UNIFIED IDEOGRAPH-#6AFE, IRGKangXi=0562.230, RSKangXi=75.17, Def{the pomelo}
6AFF CJK UNIFIED IDEOGRAPH-#6AFF, IRGKangXi=0562.260, RSKangXi=75.17
6B00 CJK UNIFIED IDEOGRAPH-#6B00, IRGKangXi=0562.280, RSKangXi=75.17
6B01 CJK UNIFIED IDEOGRAPH-#6B01, IRGKangXi=0562.320, RSKangXi=75.17
6B02 CJK UNIFIED IDEOGRAPH-#6B02, IRGKangXi=0562.330, RSKangXi=75.17
6B03 CJK UNIFIED IDEOGRAPH-#6B03, IRGKangXi=0562.340, RSKangXi=75.17, Def{sandalwood; comet}
6B04 CJK UNIFIED IDEOGRAPH-#6B04, IRGKangXi=0562.350, RSKangXi=75.17, Def{railing, balustrade; animal pan}
6B05 CJK UNIFIED IDEOGRAPH-#6B05, IRGKangXi=0563.061, RSKangXi=75.17, Def{zelkova}
6B06 CJK UNIFIED IDEOGRAPH-#6B06, IRGKangXi=0563.120, RSKangXi=75.18
6B07 CJK UNIFIED IDEOGRAPH-#6B07, IRGKangXi=0563.140, RSKangXi=75.18
6B08 CJK UNIFIED IDEOGRAPH-#6B08, IRGKangXi=0563.170, RSKangXi=75.18
6B09 CJK UNIFIED IDEOGRAPH-#6B09, IRGKangXi=0563.180, RSKangXi=75.18
6B0A CJK UNIFIED IDEOGRAPH-#6B0A, IRGKangXi=0563.190, RSKangXi=75.18, Def{power, right, authority}
6B0B CJK UNIFIED IDEOGRAPH-#6B0B, IRGKangXi=0563.220, RSKangXi=75.18
6B0C CJK UNIFIED IDEOGRAPH-#6B0C, IRGKangXi=0563.231, RSKangXi=75.17
6B0D CJK UNIFIED IDEOGRAPH-#6B0D, IRGKangXi=0563.231, RSKangXi=75.18
6B0E CJK UNIFIED IDEOGRAPH-#6B0E, IRGKangXi=0563.231, RSKangXi=75.18
6B0F CJK UNIFIED IDEOGRAPH-#6B0F, IRGKangXi=0563.240, RSKangXi=75.19, Def{the horse-chestnut}
6B10 CJK UNIFIED IDEOGRAPH-#6B10, IRGKangXi=0563.330, RSKangXi=75.19, Def{beam}
6B11 CJK UNIFIED IDEOGRAPH-#6B11, IRGKangXi=0563.340, RSKangXi=75.19, Def{gather}
6B12 CJK UNIFIED IDEOGRAPH-#6B12, IRGKangXi=0564.010, RSKangXi=75.19, Def{name of tree; a part of cornice}
6B13 CJK UNIFIED IDEOGRAPH-#6B13, IRGKangXi=0564.040, RSKangXi=75.20, Def{a cross-piece, as the round of a ladder, the rail of a chair; shelves; pigeonholes}
6B14 CJK UNIFIED IDEOGRAPH-#6B14, IRGKangXi=0564.060, RSKangXi=75.20
6B15 CJK UNIFIED IDEOGRAPH-#6B15, IRGKangXi=0564.091, RSKangXi=75.20, Def{tree name}
6B16 CJK UNIFIED IDEOGRAPH-#6B16, IRGKangXi=0564.100, RSKangXi=75.21, Def{olive}
6B17 CJK UNIFIED IDEOGRAPH-#6B17, IRGKangXi=0564.130, RSKangXi=75.21
6B18 CJK UNIFIED IDEOGRAPH-#6B18, IRGKangXi=0564.140, RSKangXi=75.21
6B19 CJK UNIFIED IDEOGRAPH-#6B19, IRGKangXi=0564.150, RSKangXi=75.21, Def{sedan}
6B1A CJK UNIFIED IDEOGRAPH-#6B1A, IRGKangXi=0564.160, RSKangXi=75.21
6B1B CJK UNIFIED IDEOGRAPH-#6B1B, IRGKangXi=0564.170, RSKangXi=75.21, Def{a handle}
6B1C CJK UNIFIED IDEOGRAPH-#6B1C, IRGKangXi=0564.200, RSKangXi=75.22
6B1D CJK UNIFIED IDEOGRAPH-#6B1D, IRGKangXi=0564.210, RSKangXi=75.22, Def{luxuriant; dense, thick; moody}
6B1E CJK UNIFIED IDEOGRAPH-#6B1E, IRGKangXi=0564.260, RSKangXi=75.24, Def{the lattice of a window a sill, a lintel}
6B1F CJK UNIFIED IDEOGRAPH-#6B1F, IRGKangXi=0564.261, RSKangXi=75.24
6B20 CJK UNIFIED IDEOGRAPH-#6B20, IRGKangXi=0565.010, RSKangXi=76.0, Def{owe, lack, be deficient; KangXi radical number 76}
6B21 CJK UNIFIED IDEOGRAPH-#6B21, IRGKangXi=0565.030, RSKangXi=76.2, Def{order, sequence; next}
6B22 CJK UNIFIED IDEOGRAPH-#6B22, IRGKangXi=0565.061, RSKangXi=76.2, Def{happy, pleased, glad; joy; enjoy}
6B23 CJK UNIFIED IDEOGRAPH-#6B23, IRGKangXi=0566.040, RSKangXi=76.4, Def{happy, joyous, delighted}
6B24 CJK UNIFIED IDEOGRAPH-#6B24, IRGKangXi=0566.080, RSKangXi=76.3, Def{a final particle used to express admiration, doubt, surprise, or to mark a question}
6B25 CJK UNIFIED IDEOGRAPH-#6B25, IRGKangXi=0566.130, RSKangXi=76.4
6B26 CJK UNIFIED IDEOGRAPH-#6B26, IRGKangXi=0566.150, RSKangXi=76.4
6B27 CJK UNIFIED IDEOGRAPH-#6B27, IRGKangXi=0566.181, RSKangXi=76.4, Def{translit.: Europe; ohm; surname}
6B28 CJK UNIFIED IDEOGRAPH-#6B28, IRGKangXi=0566.220, RSKangXi=76.5, Def{to blow or breathe upon; to smile}
6B29 CJK UNIFIED IDEOGRAPH-#6B29, IRGKangXi=0566.310, RSKangXi=76.5
6B2A CJK UNIFIED IDEOGRAPH-#6B2A, IRGKangXi=0566.330, RSKangXi=76.5
6B2B CJK UNIFIED IDEOGRAPH-#6B2B, IRGKangXi=0567.110, RSKangXi=76.6
6B2C CJK UNIFIED IDEOGRAPH-#6B2C, IRGKangXi=0567.190, RSKangXi=76.6, Def{cough; sound of laughter}
6B2D CJK UNIFIED IDEOGRAPH-#6B2D, IRGKangXi=0567.200, RSKangXi=76.6
6B2E CJK UNIFIED IDEOGRAPH-#6B2E, IRGKangXi=0567.220, RSKangXi=76.6, Def{to hiccough; to dig out to expand}
6B2F CJK UNIFIED IDEOGRAPH-#6B2F, IRGKangXi=0567.250, RSKangXi=76.6
6B30 CJK UNIFIED IDEOGRAPH-#6B30, IRGKangXi=0567.270, RSKangXi=76.6
6B31 CJK UNIFIED IDEOGRAPH-#6B31, IRGKangXi=0567.290, RSKangXi=76.6
6B32 CJK UNIFIED IDEOGRAPH-#6B32, IRGKangXi=0567.360, RSKangXi=76.7, Def{desire, want, long for; intend}
6B33 CJK UNIFIED IDEOGRAPH-#6B33, IRGKangXi=0567.380, RSKangXi=76.7
6B34 CJK UNIFIED IDEOGRAPH-#6B34, IRGKangXi=0568.010, RSKangXi=76.7
6B35 CJK UNIFIED IDEOGRAPH-#6B35, IRGKangXi=0568.020, RSKangXi=76.7, Def{to treat well; to detain}
6B36 CJK UNIFIED IDEOGRAPH-#6B36, IRGKangXi=0568.030, RSKangXi=76.7, Def{to suck in}
6B37 CJK UNIFIED IDEOGRAPH-#6B37, IRGKangXi=0568.040, RSKangXi=76.7, Def{sob; sigh}
6B38 CJK UNIFIED IDEOGRAPH-#6B38, IRGKangXi=0568.070, RSKangXi=76.7, Def{sigh; an exclamatory sound}
6B39 CJK UNIFIED IDEOGRAPH-#6B39, IRGKangXi=0568.100, RSKangXi=76.8, Def{fierce dog; interjection of pleas; (Cant.) strange}
6B3A CJK UNIFIED IDEOGRAPH-#6B3A, IRGKangXi=0568.140, RSKangXi=76.8, Def{cheat, double-cross, deceive}
6B3B CJK UNIFIED IDEOGRAPH-#6B3B, IRGKangXi=0568.160, RSKangXi=76.8, Def{sudden, abrupt, quick}
6B3C CJK UNIFIED IDEOGRAPH-#6B3C, IRGKangXi=0568.200, RSKangXi=76.8, Def{drink; (Cant.) to use one's teeth and hands to break something such as a string}
6B3D CJK UNIFIED IDEOGRAPH-#6B3D, IRGKangXi=0568.210, RSKangXi=76.8, Def{respect, admire; respectful}
6B3E CJK UNIFIED IDEOGRAPH-#6B3E, IRGKangXi=0569.030, RSKangXi=76.8, Def{item, article; clause; fund}
6B3F CJK UNIFIED IDEOGRAPH-#6B3F, IRGKangXi=0569.070, RSKangXi=76.8, Def{discontented; sad; gloomy}
6B40 CJK UNIFIED IDEOGRAPH-#6B40, IRGKangXi=0569.170, RSKangXi=76.9, Def{same as 款 U+6B3E, an item, article; clause, fund}
6B41 CJK UNIFIED IDEOGRAPH-#6B41, IRGKangXi=0569.180, RSKangXi=76.9
6B42 CJK UNIFIED IDEOGRAPH-#6B42, IRGKangXi=0570.010, RSKangXi=76.9
6B43 CJK UNIFIED IDEOGRAPH-#6B43, IRGKangXi=0570.050, RSKangXi=76.9, Def{smear one's mouth with blood of a victim when taking an oath}
6B44 CJK UNIFIED IDEOGRAPH-#6B44, IRGKangXi=0570.080, RSKangXi=76.9
6B45 CJK UNIFIED IDEOGRAPH-#6B45, IRGKangXi=0570.120, RSKangXi=76.9
6B46 CJK UNIFIED IDEOGRAPH-#6B46, IRGKangXi=0570.130, RSKangXi=76.9, Def{like, admire; willingly, gladly; to quicken}
6B47 CJK UNIFIED IDEOGRAPH-#6B47, IRGKangXi=0570.150, RSKangXi=76.9, Def{rest, stop, lodge}
6B48 CJK UNIFIED IDEOGRAPH-#6B48, IRGKangXi=0570.170, RSKangXi=76.9, Def{songs}
6B49 CJK UNIFIED IDEOGRAPH-#6B49, IRGKangXi=0570.300, RSKangXi=76.10, Def{deficient, lacking, insufficient}
6B4A CJK UNIFIED IDEOGRAPH-#6B4A, IRGKangXi=0571.010, RSKangXi=76.10, Def{sigh}
6B4B CJK UNIFIED IDEOGRAPH-#6B4B, IRGKangXi=0571.060, RSKangXi=76.10
6B4C CJK UNIFIED IDEOGRAPH-#6B4C, IRGKangXi=0571.070, RSKangXi=76.10, Def{song, lyrics; sing, chant; praise}
6B4D CJK UNIFIED IDEOGRAPH-#6B4D, IRGKangXi=0571.100, RSKangXi=76.10
6B4E CJK UNIFIED IDEOGRAPH-#6B4E, IRGKangXi=0571.240, RSKangXi=76.11, Def{sigh, admire}
6B4F CJK UNIFIED IDEOGRAPH-#6B4F, IRGKangXi=0571.250, RSKangXi=76.11
6B50 CJK UNIFIED IDEOGRAPH-#6B50, IRGKangXi=0571.270, RSKangXi=76.11, Def{used in transliterating non-Chinese words such as Europe, ohm; surname}
6B51 CJK UNIFIED IDEOGRAPH-#6B51, IRGKangXi=0572.010, RSKangXi=76.11
6B52 CJK UNIFIED IDEOGRAPH-#6B52, IRGKangXi=0572.050, RSKangXi=76.11
6B53 CJK UNIFIED IDEOGRAPH-#6B53, IRGKangXi=0572.101, RSKangXi=76.11, Def{happy, pleased, glad; joy; enjoy}
6B54 CJK UNIFIED IDEOGRAPH-#6B54, IRGKangXi=0572.110, RSKangXi=76.12, Def{blow through nose, snort}
6B55 CJK UNIFIED IDEOGRAPH-#6B55, IRGKangXi=0572.130, RSKangXi=76.12, Def{spurt, blow out, puff out}
6B56 CJK UNIFIED IDEOGRAPH-#6B56, IRGKangXi=0572.140, RSKangXi=76.12
6B57 CJK UNIFIED IDEOGRAPH-#6B57, IRGKangXi=0572.150, RSKangXi=76.12, Def{roar, howl, scream; whistle}
6B58 CJK UNIFIED IDEOGRAPH-#6B58, IRGKangXi=0572.160, RSKangXi=76.12, Def{sudden}
6B59 CJK UNIFIED IDEOGRAPH-#6B59, IRGKangXi=0572.180, RSKangXi=76.12, Def{to suck; a county's name in anhui}
6B5A CJK UNIFIED IDEOGRAPH-#6B5A, IRGKangXi=0572.221, RSKangXi=76.12, Def{used in name of famous Korean painter Ceng Sen}
6B5B CJK UNIFIED IDEOGRAPH-#6B5B, IRGKangXi=0572.230, RSKangXi=76.13, Def{draw back, fold back; collect}
6B5C CJK UNIFIED IDEOGRAPH-#6B5C, IRGKangXi=0572.300, RSKangXi=76.13, Def{furious; wrathful}
6B5D CJK UNIFIED IDEOGRAPH-#6B5D, IRGKangXi=0572.320, RSKangXi=76.13
6B5E CJK UNIFIED IDEOGRAPH-#6B5E, IRGKangXi=0572.340, RSKangXi=76.14
6B5F CJK UNIFIED IDEOGRAPH-#6B5F, IRGKangXi=0573.010, RSKangXi=76.14, Def{a final particle used to express admiration, doubt, surprise, or to mark a question}
6B60 CJK UNIFIED IDEOGRAPH-#6B60, IRGKangXi=0573.020, RSKangXi=76.15, Def{sip, drink, suck}
6B61 CJK UNIFIED IDEOGRAPH-#6B61, IRGKangXi=0573.120, RSKangXi=76.18, Def{happy, pleased, glad; joy; to enjoy}
6B62 CJK UNIFIED IDEOGRAPH-#6B62, IRGKangXi=0573.240, RSKangXi=77.0, Def{stop, halt, desist; detain}
6B63 CJK UNIFIED IDEOGRAPH-#6B63, IRGKangXi=0574.020, RSKangXi=77.1, Def{right, proper, correct}
6B64 CJK UNIFIED IDEOGRAPH-#6B64, IRGKangXi=0574.100, RSKangXi=77.2, Def{this, these; in this case, then}
6B65 CJK UNIFIED IDEOGRAPH-#6B65, IRGKangXi=0574.150, RSKangXi=77.3, Def{step, pace; walk, stroll}
6B66 CJK UNIFIED IDEOGRAPH-#6B66, IRGKangXi=0575.090, RSKangXi=77.4, Def{military; martial, warlike}
6B67 CJK UNIFIED IDEOGRAPH-#6B67, IRGKangXi=0576.020, RSKangXi=77.4, Def{fork of road; branching off}
6B68 CJK UNIFIED IDEOGRAPH-#6B68, IRGKangXi=0576.040, RSKangXi=77.4
6B69 CJK UNIFIED IDEOGRAPH-#6B69, IRGKangXi=0576.101, RSKangXi=77.4, Def{step}
6B6A CJK UNIFIED IDEOGRAPH-#6B6A, IRGKangXi=0576.120, RSKangXi=77.5, Def{slant; inclined; askewd, awry}
6B6B CJK UNIFIED IDEOGRAPH-#6B6B, IRGKangXi=0576.130, RSKangXi=77.5
6B6C CJK UNIFIED IDEOGRAPH-#6B6C, IRGKangXi=0576.160, RSKangXi=77.6
6B6D CJK UNIFIED IDEOGRAPH-#6B6D, IRGKangXi=0576.180, RSKangXi=77.6
6B6E CJK UNIFIED IDEOGRAPH-#6B6E, IRGKangXi=0576.380, RSKangXi=77.8
6B6F CJK UNIFIED IDEOGRAPH-#6B6F, IRGKangXi=0576.421, RSKangXi=211.0, Def{teeth; gears, cogs; age; a form of KangXi radical 211}
6B70 CJK UNIFIED IDEOGRAPH-#6B70, IRGKangXi=0576.430, RSKangXi=77.9, Def{(Cant.) 歰氣 to argue, wrangle, disagree}
6B71 CJK UNIFIED IDEOGRAPH-#6B71, IRGKangXi=0577.010, RSKangXi=77.9, Def{to visit; to imitate}
6B72 CJK UNIFIED IDEOGRAPH-#6B72, IRGKangXi=0577.020, RSKangXi=77.9, Def{year; age; harvest}
6B73 CJK UNIFIED IDEOGRAPH-#6B73, IRGKangXi=0577.071, RSKangXi=77.9, Def{year; age; harvest}
6B74 CJK UNIFIED IDEOGRAPH-#6B74, IRGKangXi=0577.081, RSKangXi=77.10, Def{take place, past, history}
6B75 CJK UNIFIED IDEOGRAPH-#6B75, IRGKangXi=0577.090, RSKangXi=77.11
6B76 CJK UNIFIED IDEOGRAPH-#6B76, IRGKangXi=0848.151, RSKangXi=114.9
6B77 CJK UNIFIED IDEOGRAPH-#6B77, IRGKangXi=0577.140, RSKangXi=77.12, Def{take place, past, history}
6B78 CJK UNIFIED IDEOGRAPH-#6B78, IRGKangXi=0578.070, RSKangXi=77.14, Def{return; return to, revert to}
6B79 CJK UNIFIED IDEOGRAPH-#6B79, IRGKangXi=0578.150, RSKangXi=78.0, Def{bad, vicious, depraved, wicked}
6B7A CJK UNIFIED IDEOGRAPH-#6B7A, IRGKangXi=0578.180, RSKangXi=78.1, Def{vicious, depraved, bad}
6B7B CJK UNIFIED IDEOGRAPH-#6B7B, IRGKangXi=0578.220, RSKangXi=78.2, Def{die; dead; death}
6B7C CJK UNIFIED IDEOGRAPH-#6B7C, IRGKangXi=0579.121, RSKangXi=78.3, Def{annihilate, wipe out, kill off}
6B7D CJK UNIFIED IDEOGRAPH-#6B7D, IRGKangXi=0579.130, RSKangXi=78.4
6B7E CJK UNIFIED IDEOGRAPH-#6B7E, IRGKangXi=0579.150, RSKangXi=78.4, Def{drown}
6B7F CJK UNIFIED IDEOGRAPH-#6B7F, IRGKangXi=0579.160, RSKangXi=78.4, Def{die; death; dead}
6B80 CJK UNIFIED IDEOGRAPH-#6B80, IRGKangXi=0579.200, RSKangXi=78.4, Def{die young, die prematurely}
6B81 CJK UNIFIED IDEOGRAPH-#6B81, IRGKangXi=0579.331, RSKangXi=78.4, Def{die; death; dead}
6B82 CJK UNIFIED IDEOGRAPH-#6B82, IRGKangXi=0579.340, RSKangXi=78.5, Def{to die}
6B83 CJK UNIFIED IDEOGRAPH-#6B83, IRGKangXi=0579.410, RSKangXi=78.5, Def{misfortune, disaster, calamity}
6B84 CJK UNIFIED IDEOGRAPH-#6B84, IRGKangXi=0579.450, RSKangXi=78.5, Def{to end; to exterminate}
6B85 CJK UNIFIED IDEOGRAPH-#6B85, IRGKangXi=0579.540, RSKangXi=78.5
6B86 CJK UNIFIED IDEOGRAPH-#6B86, IRGKangXi=0580.040, RSKangXi=78.5, Def{dangerous, perilous; endanger}
6B87 CJK UNIFIED IDEOGRAPH-#6B87, IRGKangXi=0580.081, RSKangXi=78.5, Def{die young; national mourning}
6B88 CJK UNIFIED IDEOGRAPH-#6B88, IRGKangXi=0580.120, RSKangXi=78.6, Def{infertile}
6B89 CJK UNIFIED IDEOGRAPH-#6B89, IRGKangXi=0580.220, RSKangXi=78.6, Def{die for cause, be martyr for}
6B8A CJK UNIFIED IDEOGRAPH-#6B8A, IRGKangXi=0580.250, RSKangXi=78.6, Def{different, special, unusual}
6B8B CJK UNIFIED IDEOGRAPH-#6B8B, IRGKangXi=0580.291, RSKangXi=78.5, Def{injure, spoil; oppress; broken}
6B8C CJK UNIFIED IDEOGRAPH-#6B8C, IRGKangXi=0580.320, RSKangXi=78.7
6B8D CJK UNIFIED IDEOGRAPH-#6B8D, IRGKangXi=0580.340, RSKangXi=78.7, Def{to starve to death}
6B8E CJK UNIFIED IDEOGRAPH-#6B8E, IRGKangXi=0581.040, RSKangXi=78.7
6B8F CJK UNIFIED IDEOGRAPH-#6B8F, IRGKangXi=0581.050, RSKangXi=78.7
6B90 CJK UNIFIED IDEOGRAPH-#6B90, IRGKangXi=0581.080, RSKangXi=78.7
6B91 CJK UNIFIED IDEOGRAPH-#6B91, IRGKangXi=0581.090, RSKangXi=78.7, Def{swoon}
6B92 CJK UNIFIED IDEOGRAPH-#6B92, IRGKangXi=0581.131, RSKangXi=78.7, Def{die, perish; vanish; fall}
6B93 CJK UNIFIED IDEOGRAPH-#6B93, IRGKangXi=0581.131, RSKangXi=78.7, Def{dress corpse for burial}
6B94 CJK UNIFIED IDEOGRAPH-#6B94, IRGKangXi=0581.200, RSKangXi=78.8
6B95 CJK UNIFIED IDEOGRAPH-#6B95, IRGKangXi=0581.290, RSKangXi=78.8
6B96 CJK UNIFIED IDEOGRAPH-#6B96, IRGKangXi=0581.330, RSKangXi=78.8, Def{breed, spawn; increase; prosper}
6B97 CJK UNIFIED IDEOGRAPH-#6B97, IRGKangXi=0581.360, RSKangXi=78.8, Def{sickness; repeated}
6B98 CJK UNIFIED IDEOGRAPH-#6B98, IRGKangXi=0581.370, RSKangXi=78.8, Def{injure, spoil; oppress; broken}
6B99 CJK UNIFIED IDEOGRAPH-#6B99, IRGKangXi=0582.010, RSKangXi=78.8, Def{to die by taking poison}
6B9A CJK UNIFIED IDEOGRAPH-#6B9A, IRGKangXi=0582.041, RSKangXi=78.8, Def{utmost, entirely, quite; use up}
6B9B CJK UNIFIED IDEOGRAPH-#6B9B, IRGKangXi=0582.080, RSKangXi=78.9, Def{to put to death to imprison for life}
6B9C CJK UNIFIED IDEOGRAPH-#6B9C, IRGKangXi=0582.140, RSKangXi=78.9, Def{half-sitting, half-reclining}
6B9D CJK UNIFIED IDEOGRAPH-#6B9D, IRGKangXi=0582.230, RSKangXi=78.10
6B9E CJK UNIFIED IDEOGRAPH-#6B9E, IRGKangXi=0582.240, RSKangXi=78.10, Def{die, perish; vanish; fall}
6B9F CJK UNIFIED IDEOGRAPH-#6B9F, IRGKangXi=0582.250, RSKangXi=78.10
6BA0 CJK UNIFIED IDEOGRAPH-#6BA0, IRGKangXi=0582.300, RSKangXi=78.10
6BA1 CJK UNIFIED IDEOGRAPH-#6BA1, IRGKangXi=0582.351, RSKangXi=78.10, Def{encoffin; embalm; funeral}
6BA2 CJK UNIFIED IDEOGRAPH-#6BA2, IRGKangXi=0582.370, RSKangXi=78.11, Def{be in great difficulty, greatly}
6BA3 CJK UNIFIED IDEOGRAPH-#6BA3, IRGKangXi=0582.380, RSKangXi=78.11, Def{die; death; to starve to death}
6BA4 CJK UNIFIED IDEOGRAPH-#6BA4, IRGKangXi=0583.060, RSKangXi=78.11, Def{die young; national mourning}
6BA5 CJK UNIFIED IDEOGRAPH-#6BA5, IRGKangXi=0583.140, RSKangXi=78.11
6BA6 CJK UNIFIED IDEOGRAPH-#6BA6, IRGKangXi=0583.141, RSKangXi=78.11
6BA7 CJK UNIFIED IDEOGRAPH-#6BA7, IRGKangXi=0583.150, RSKangXi=78.12
6BA8 CJK UNIFIED IDEOGRAPH-#6BA8, IRGKangXi=0583.180, RSKangXi=78.12, Def{to open as an ulcer or sore}
6BA9 CJK UNIFIED IDEOGRAPH-#6BA9, IRGKangXi=0583.240, RSKangXi=78.12
6BAA CJK UNIFIED IDEOGRAPH-#6BAA, IRGKangXi=0583.250, RSKangXi=78.12, Def{die; kill, exterminate}
6BAB CJK UNIFIED IDEOGRAPH-#6BAB, IRGKangXi=0583.300, RSKangXi=78.12, Def{utmost, entirely, quite; use up}
6BAC CJK UNIFIED IDEOGRAPH-#6BAC, IRGKangXi=0583.320, RSKangXi=78.13
6BAD CJK UNIFIED IDEOGRAPH-#6BAD, IRGKangXi=0583.360, RSKangXi=78.13, Def{a stiff corpse}
6BAE CJK UNIFIED IDEOGRAPH-#6BAE, IRGKangXi=0583.380, RSKangXi=78.13, Def{dress corpse for burial}
6BAF CJK UNIFIED IDEOGRAPH-#6BAF, IRGKangXi=0583.440, RSKangXi=78.14, Def{encoffin; embalm; funeral}
6BB0 CJK UNIFIED IDEOGRAPH-#6BB0, IRGKangXi=0584.020, RSKangXi=78.15, Def{an abortion; stillborn}
6BB1 CJK UNIFIED IDEOGRAPH-#6BB1, IRGKangXi=0584.041, RSKangXi=78.15, Def{annihilate, wipe out, kill off}
6BB2 CJK UNIFIED IDEOGRAPH-#6BB2, IRGKangXi=0584.110, RSKangXi=78.17, Def{annihilate, wipe out, kill off}
6BB3 CJK UNIFIED IDEOGRAPH-#6BB3, IRGKangXi=0584.170, RSKangXi=79.0, Def{name of old weapon; kill; rad. 79}
6BB4 CJK UNIFIED IDEOGRAPH-#6BB4, IRGKangXi=0584.211, RSKangXi=79.4, Def{beat, fight with fists, hit}
6BB5 CJK UNIFIED IDEOGRAPH-#6BB5, IRGKangXi=0584.220, RSKangXi=79.5, Def{section, piece, division}
6BB6 CJK UNIFIED IDEOGRAPH-#6BB6, IRGKangXi=0584.260, RSKangXi=79.5
6BB7 CJK UNIFIED IDEOGRAPH-#6BB7, IRGKangXi=0585.020, RSKangXi=79.6, Def{many, great; abundant, flourishing}
6BB8 CJK UNIFIED IDEOGRAPH-#6BB8, IRGKangXi=0585.060, RSKangXi=79.7, Def{stone chimes}
6BB9 CJK UNIFIED IDEOGRAPH-#6BB9, IRGKangXi=0585.070, RSKangXi=79.7, Def{an echo}
6BBA CJK UNIFIED IDEOGRAPH-#6BBA, IRGKangXi=0585.110, RSKangXi=79.7, Def{kill, slaughter, murder; hurt; to pare off, reduce, clip}
6BBB CJK UNIFIED IDEOGRAPH-#6BBB, IRGKangXi=0586.011, RSKangXi=79.7, Def{casing, shell, husk, hull, skin}
6BBC CJK UNIFIED IDEOGRAPH-#6BBC, IRGKangXi=0586.050, RSKangXi=79.8, Def{casing, shell, husk, hull, skin}
6BBD CJK UNIFIED IDEOGRAPH-#6BBD, IRGKangXi=0586.060, RSKangXi=79.8, Def{mixed up, confused; cooked}
6BBE CJK UNIFIED IDEOGRAPH-#6BBE, IRGKangXi=0586.080, RSKangXi=79.9
6BBF CJK UNIFIED IDEOGRAPH-#6BBF, IRGKangXi=0586.090, RSKangXi=79.9, Def{hall; palace; temple}
6BC0 CJK UNIFIED IDEOGRAPH-#6BC0, IRGKangXi=0586.120, RSKangXi=79.9, Def{destroy, ruin, injure; slander}
6BC1 CJK UNIFIED IDEOGRAPH-#6BC1, IRGKangXi=0587.031, RSKangXi=79.9, Def{destroy}
6BC2 CJK UNIFIED IDEOGRAPH-#6BC2, IRGKangXi=0587.031, RSKangXi=79.9, Def{hub of wheel}
6BC3 CJK UNIFIED IDEOGRAPH-#6BC3, IRGKangXi=0587.070, RSKangXi=79.10
6BC4 CJK UNIFIED IDEOGRAPH-#6BC4, IRGKangXi=0587.100, RSKangXi=79.10
6BC5 CJK UNIFIED IDEOGRAPH-#6BC5, IRGKangXi=0587.140, RSKangXi=79.11, Def{resolute, decisive, firm, persist}
6BC6 CJK UNIFIED IDEOGRAPH-#6BC6, IRGKangXi=0587.150, RSKangXi=79.11, Def{beat, fight with fists, hit; to strike, brawl}
6BC7 CJK UNIFIED IDEOGRAPH-#6BC7, IRGKangXi=0587.200, RSKangXi=79.12
6BC8 CJK UNIFIED IDEOGRAPH-#6BC8, IRGKangXi=0587.220, RSKangXi=79.12, Def{infertile eggs; (Cant.) rotten, muddled}
6BC9 CJK UNIFIED IDEOGRAPH-#6BC9, IRGKangXi=0588.090, RSKangXi=79.15
6BCA CJK UNIFIED IDEOGRAPH-#6BCA, IRGKangXi=0588.170, RSKangXi=79.19
6BCB CJK UNIFIED IDEOGRAPH-#6BCB, IRGKangXi=0588.230, RSKangXi=80.0, Def{do not; not; surname; rad. 80}
6BCC CJK UNIFIED IDEOGRAPH-#6BCC, IRGKangXi=0588.240, RSKangXi=80.0, Def{old form of 貫; component in 贯,貫,實, etc.; not to be confused with 毋}
6BCD CJK UNIFIED IDEOGRAPH-#6BCD, IRGKangXi=0588.250, RSKangXi=80.1, Def{mother; female elders; female}
6BCE CJK UNIFIED IDEOGRAPH-#6BCE, IRGKangXi=0589.011, RSKangXi=80.2, Def{every}
6BCF CJK UNIFIED IDEOGRAPH-#6BCF, IRGKangXi=0589.020, RSKangXi=80.3, Def{every, each}
6BD0 CJK UNIFIED IDEOGRAPH-#6BD0, IRGKangXi=0589.040, RSKangXi=80.3, Def{person of reprehensible morals; immoral; adulterer}
6BD1 CJK UNIFIED IDEOGRAPH-#6BD1, IRGKangXi=0589.050, RSKangXi=80.4
6BD2 CJK UNIFIED IDEOGRAPH-#6BD2, IRGKangXi=0589.060, RSKangXi=80.4, Def{poison, venom; poisonous}
6BD3 CJK UNIFIED IDEOGRAPH-#6BD3, IRGKangXi=0590.060, RSKangXi=80.9, Def{give birth to; bring up, educate}
6BD4 CJK UNIFIED IDEOGRAPH-#6BD4, IRGKangXi=0590.090, RSKangXi=81.0, Def{to compare, liken; comparison; than}
6BD5 CJK UNIFIED IDEOGRAPH-#6BD5, IRGKangXi=0590.091, RSKangXi=81.2, Def{end, finish, conclude; completed}
6BD6 CJK UNIFIED IDEOGRAPH-#6BD6, IRGKangXi=0591.040, RSKangXi=81.5, Def{guard against, take care; caution}
6BD7 CJK UNIFIED IDEOGRAPH-#6BD7, IRGKangXi=0591.060, RSKangXi=102.4, Def{help, assist; connect, adjoin}
6BD8 CJK UNIFIED IDEOGRAPH-#6BD8, IRGKangXi=0591.070, RSKangXi=81.5, Def{help, assist; connect, adjoin}
6BD9 CJK UNIFIED IDEOGRAPH-#6BD9, IRGKangXi=0591.101, RSKangXi=81.6, Def{kill; die violent death}
6BDA CJK UNIFIED IDEOGRAPH-#6BDA, IRGKangXi=0591.180, RSKangXi=81.13, Def{cunning; greedy; crafty}
6BDB CJK UNIFIED IDEOGRAPH-#6BDB, IRGKangXi=0591.220, RSKangXi=82.0, Def{hair, fur, feathers; coarse}
6BDC CJK UNIFIED IDEOGRAPH-#6BDC, IRGKangXi=0592.061, RSKangXi=82.3
6BDD CJK UNIFIED IDEOGRAPH-#6BDD, IRGKangXi=0592.061, RSKangXi=82.3
6BDE CJK UNIFIED IDEOGRAPH-#6BDE, IRGKangXi=0592.090, RSKangXi=82.4
6BDF CJK UNIFIED IDEOGRAPH-#6BDF, IRGKangXi=0592.161, RSKangXi=82.4, Def{to pluck, pick, tear}
6BE0 CJK UNIFIED IDEOGRAPH-#6BE0, IRGKangXi=0592.210, RSKangXi=82.5
6BE1 CJK UNIFIED IDEOGRAPH-#6BE1, IRGKangXi=0592.270, RSKangXi=82.5, Def{felt; rug, carpet}
6BE2 CJK UNIFIED IDEOGRAPH-#6BE2, IRGKangXi=0592.350, RSKangXi=82.6
6BE3 CJK UNIFIED IDEOGRAPH-#6BE3, IRGKangXi=0592.360, RSKangXi=82.6
6BE4 CJK UNIFIED IDEOGRAPH-#6BE4, IRGKangXi=0592.390, RSKangXi=82.6
6BE5 CJK UNIFIED IDEOGRAPH-#6BE5, IRGKangXi=0592.400, RSKangXi=82.6
6BE6 CJK UNIFIED IDEOGRAPH-#6BE6, IRGKangXi=0592.410, RSKangXi=82.6
6BE7 CJK UNIFIED IDEOGRAPH-#6BE7, IRGKangXi=0593.010, RSKangXi=82.6, Def{fur, hair, down; camel hair}
6BE8 CJK UNIFIED IDEOGRAPH-#6BE8, IRGKangXi=0593.030, RSKangXi=82.6
6BE9 CJK UNIFIED IDEOGRAPH-#6BE9, IRGKangXi=0593.091, RSKangXi=82.6, Def{a leather ball for kicking}
6BEA CJK UNIFIED IDEOGRAPH-#6BEA, IRGKangXi=0593.091, RSKangXi=82.6, Def{serge from Tibet}
6BEB CJK UNIFIED IDEOGRAPH-#6BEB, IRGKangXi=0593.100, RSKangXi=82.7, Def{fine hair; measure of length}
6BEC CJK UNIFIED IDEOGRAPH-#6BEC, IRGKangXi=0593.170, RSKangXi=82.7, Def{ball, anything round, sphere}
6BED CJK UNIFIED IDEOGRAPH-#6BED, IRGKangXi=0593.250, RSKangXi=82.7
6BEE CJK UNIFIED IDEOGRAPH-#6BEE, IRGKangXi=0594.031, RSKangXi=82.7, Def{[kokuji] to pull out hair, etc.}
6BEF CJK UNIFIED IDEOGRAPH-#6BEF, IRGKangXi=0594.050, RSKangXi=82.8, Def{rug, carpet, blanket}
6BF0 CJK UNIFIED IDEOGRAPH-#6BF0, IRGKangXi=0594.110, RSKangXi=82.8
6BF1 CJK UNIFIED IDEOGRAPH-#6BF1, IRGKangXi=0594.120, RSKangXi=82.8
6BF2 CJK UNIFIED IDEOGRAPH-#6BF2, IRGKangXi=0594.170, RSKangXi=82.8
6BF3 CJK UNIFIED IDEOGRAPH-#6BF3, IRGKangXi=0594.190, RSKangXi=82.8, Def{fine hair or fur on animals}
6BF4 CJK UNIFIED IDEOGRAPH-#6BF4, IRGKangXi=0594.261, RSKangXi=82.8
6BF5 CJK UNIFIED IDEOGRAPH-#6BF5, IRGKangXi=0594.261, RSKangXi=82.8, Def{long feathers; scraggy}
6BF6 CJK UNIFIED IDEOGRAPH-#6BF6, IRGKangXi=0594.261, RSKangXi=82.8
6BF7 CJK UNIFIED IDEOGRAPH-#6BF7, IRGKangXi=0594.320, RSKangXi=82.9, Def{restless}
6BF8 CJK UNIFIED IDEOGRAPH-#6BF8, IRGKangXi=0594.370, RSKangXi=82.9
6BF9 CJK UNIFIED IDEOGRAPH-#6BF9, IRGKangXi=0594.380, RSKangXi=82.9
6BFA CJK UNIFIED IDEOGRAPH-#6BFA, IRGKangXi=0595.010, RSKangXi=82.9
6BFB CJK UNIFIED IDEOGRAPH-#6BFB, IRGKangXi=0595.030, RSKangXi=82.9, Def{to molt; to change the coat of animals; (Cant.) muddled, confused}
6BFC CJK UNIFIED IDEOGRAPH-#6BFC, IRGKangXi=0595.040, RSKangXi=82.9
6BFD CJK UNIFIED IDEOGRAPH-#6BFD, IRGKangXi=0595.130, RSKangXi=82.9, Def{a shuttlecock}
6BFE CJK UNIFIED IDEOGRAPH-#6BFE, IRGKangXi=0595.190, RSKangXi=82.10, Def{a coarse, woollen serge}
6BFF CJK UNIFIED IDEOGRAPH-#6BFF, IRGKangXi=0595.370, RSKangXi=82.11, Def{long feathers; scraggy}
6C00 CJK UNIFIED IDEOGRAPH-#6C00, IRGKangXi=0595.440, RSKangXi=82.11
6C01 CJK UNIFIED IDEOGRAPH-#6C01, IRGKangXi=0595.450, RSKangXi=82.11
6C02 CJK UNIFIED IDEOGRAPH-#6C02, IRGKangXi=0595.460, RSKangXi=82.11, Def{tail; hair; yak}
6C03 CJK UNIFIED IDEOGRAPH-#6C03, IRGKangXi=0596.110, RSKangXi=82.12
6C04 CJK UNIFIED IDEOGRAPH-#6C04, IRGKangXi=0596.160, RSKangXi=82.12, Def{down}
6C05 CJK UNIFIED IDEOGRAPH-#6C05, IRGKangXi=0596.190, RSKangXi=82.12, Def{overcoat; down feathers}
6C06 CJK UNIFIED IDEOGRAPH-#6C06, IRGKangXi=0596.200, RSKangXi=82.12, Def{thick, rough serge from Tibet}
6C07 CJK UNIFIED IDEOGRAPH-#6C07, IRGKangXi=0596.231, RSKangXi=82.12, Def{thick rough serge from Tibet}
6C08 CJK UNIFIED IDEOGRAPH-#6C08, IRGKangXi=0596.270, RSKangXi=82.13, Def{felt; rug, carpet}
6C09 CJK UNIFIED IDEOGRAPH-#6C09, IRGKangXi=0596.280, RSKangXi=82.13, Def{restless, melancholy}
6C0A CJK UNIFIED IDEOGRAPH-#6C0A, IRGKangXi=0596.311, RSKangXi=82.13, Def{felt; coarse fabrics use for rugs, carpets, wrappers etc.}
6C0B CJK UNIFIED IDEOGRAPH-#6C0B, IRGKangXi=0596.330, RSKangXi=82.14
6C0C CJK UNIFIED IDEOGRAPH-#6C0C, IRGKangXi=0597.040, RSKangXi=82.15, Def{thick rough serge from Tibet}
6C0D CJK UNIFIED IDEOGRAPH-#6C0D, IRGKangXi=0597.130, RSKangXi=82.18, Def{fine woollen cloth; a mat used by the emperor in worshipping god}
6C0E CJK UNIFIED IDEOGRAPH-#6C0E, IRGKangXi=0597.160, RSKangXi=82.22
6C0F CJK UNIFIED IDEOGRAPH-#6C0F, IRGKangXi=0597.180, RSKangXi=83.0, Def{clan, family; mister}
6C10 CJK UNIFIED IDEOGRAPH-#6C10, IRGKangXi=0597.190, RSKangXi=83.1, Def{name of an ancient tribe}
6C11 CJK UNIFIED IDEOGRAPH-#6C11, IRGKangXi=0598.010, RSKangXi=83.1, Def{people, subjects, citizens}
6C12 CJK UNIFIED IDEOGRAPH-#6C12, IRGKangXi=0598.030, RSKangXi=83.2
6C13 CJK UNIFIED IDEOGRAPH-#6C13, IRGKangXi=0598.040, RSKangXi=83.4, Def{people; subjects; vassals}
6C14 CJK UNIFIED IDEOGRAPH-#6C14, IRGKangXi=0599.030, RSKangXi=84.0, Def{steam, vapor; KangXi radical 84}
6C15 CJK UNIFIED IDEOGRAPH-#6C15, IRGKangXi=0599.031, RSKangXi=84.1, Def{hydrogen-1, protium}
6C16 CJK UNIFIED IDEOGRAPH-#6C16, IRGKangXi=0599.041, RSKangXi=84.2, Def{neon}
6C17 CJK UNIFIED IDEOGRAPH-#6C17, IRGKangXi=0599.041, RSKangXi=84.2, Def{air, gas, steam, vapor; spirit}
6C18 CJK UNIFIED IDEOGRAPH-#6C18, IRGKangXi=0599.041, RSKangXi=84.2, Def{deuterium}
6C19 CJK UNIFIED IDEOGRAPH-#6C19, IRGKangXi=0599.041, RSKangXi=84.3, Def{xenon}
6C1A CJK UNIFIED IDEOGRAPH-#6C1A, IRGKangXi=0599.041, RSKangXi=84.3, Def{tritium}
6C1B CJK UNIFIED IDEOGRAPH-#6C1B, IRGKangXi=0599.050, RSKangXi=84.4, Def{gas, vapor, air}
6C1C CJK UNIFIED IDEOGRAPH-#6C1C, IRGKangXi=0599.060, RSKangXi=84.4, Def{clear, bright; the sun; heat pertaining to this world; superior; upper; front}
6C1D CJK UNIFIED IDEOGRAPH-#6C1D, IRGKangXi=0599.101, RSKangXi=84.4, Def{neon}
6C1E CJK UNIFIED IDEOGRAPH-#6C1E, IRGKangXi=0599.111
6C1F CJK UNIFIED IDEOGRAPH-#6C1F, IRGKangXi=0599.111, RSKangXi=84.5, Def{fluorine}
6C20 CJK UNIFIED IDEOGRAPH-#6C20, IRGKangXi=0599.111, RSKangXi=84.5
6C21 CJK UNIFIED IDEOGRAPH-#6C21, IRGKangXi=0599.111, RSKangXi=84.5, Def{radon}
6C22 CJK UNIFIED IDEOGRAPH-#6C22, IRGKangXi=0599.111, RSKangXi=84.5, Def{ammonia; hydrogen nitride}
6C23 CJK UNIFIED IDEOGRAPH-#6C23, IRGKangXi=0599.120, RSKangXi=84.6, Def{air, gas, steam, vapor; spirit}
6C24 CJK UNIFIED IDEOGRAPH-#6C24, IRGKangXi=0599.140, RSKangXi=84.6, Def{hanging fog, misty}
6C25 CJK UNIFIED IDEOGRAPH-#6C25, IRGKangXi=0599.151, RSKangXi=84.6, Def{xenon}
6C26 CJK UNIFIED IDEOGRAPH-#6C26, IRGKangXi=0599.151, RSKangXi=84.6, Def{helium}
6C27 CJK UNIFIED IDEOGRAPH-#6C27, IRGKangXi=0599.151, RSKangXi=84.6, Def{oxygen}
6C28 CJK UNIFIED IDEOGRAPH-#6C28, IRGKangXi=0599.151, RSKangXi=84.6, Def{ammonia; hydrogen nitride}
6C29 CJK UNIFIED IDEOGRAPH-#6C29, IRGKangXi=0599.151, RSKangXi=84.6, Def{argonium}
6C2A CJK UNIFIED IDEOGRAPH-#6C2A, IRGKangXi=0600.011, RSKangXi=84.7, Def{krypton}
6C2B CJK UNIFIED IDEOGRAPH-#6C2B, IRGKangXi=0600.011, RSKangXi=84.7, Def{hydrogen}
6C2C CJK UNIFIED IDEOGRAPH-#6C2C, IRGKangXi=0600.011, RSKangXi=84.8, Def{argonium}
6C2D CJK UNIFIED IDEOGRAPH-#6C2D, IRGKangXi=0600.011, RSKangXi=84.8
6C2E CJK UNIFIED IDEOGRAPH-#6C2E, IRGKangXi=0600.011, RSKangXi=84.8, Def{nitrogen}
6C2F CJK UNIFIED IDEOGRAPH-#6C2F, IRGKangXi=0600.011, RSKangXi=84.8, Def{chlorine}
6C30 CJK UNIFIED IDEOGRAPH-#6C30, IRGKangXi=0600.011, RSKangXi=84.8, Def{cyanogen; ethane dinitrile}
6C31 CJK UNIFIED IDEOGRAPH-#6C31, IRGKangXi=0600.021, RSKangXi=84.9
6C32 CJK UNIFIED IDEOGRAPH-#6C32, IRGKangXi=0600.021, RSKangXi=84.10, Def{life giving influences of nature; spirit of harmony; prosperity}
6C33 CJK UNIFIED IDEOGRAPH-#6C33, IRGKangXi=0600.030, RSKangXi=84.10, Def{life giving influences of nature; spirit of harmony; prosperity}
6C34 CJK UNIFIED IDEOGRAPH-#6C34, IRGKangXi=0603.010, RSKangXi=85.0, Def{water, liquid, lotion, juice}
6C35 CJK UNIFIED IDEOGRAPH-#6C35, IRGKangXi=0603.011, RSKangXi=85.0, Def{water; radical number 85}
6C36 CJK UNIFIED IDEOGRAPH-#6C36, IRGKangXi=0603.020, RSKangXi=85.1, Def{name of a river in Shandong}
6C37 CJK UNIFIED IDEOGRAPH-#6C37, IRGKangXi=0603.030, RSKangXi=85.1, Def{ice, frost, icicles; cold}
6C38 CJK UNIFIED IDEOGRAPH-#6C38, IRGKangXi=0603.040, RSKangXi=85.1, Def{long, perpetual, eternal, forever}
6C39 CJK UNIFIED IDEOGRAPH-#6C39, IRGKangXi=0603.051, RSKangXi=5.5, Def{ditch; pool}
6C3A CJK UNIFIED IDEOGRAPH-#6C3A, IRGKangXi=0603.011, RSKangXi=85.1
6C3B CJK UNIFIED IDEOGRAPH-#6C3B, IRGKangXi=0603.070, RSKangXi=85.2
6C3C CJK UNIFIED IDEOGRAPH-#6C3C, IRGKangXi=0603.120, RSKangXi=85.2, Def{to sink; to drown to be given over to}
6C3D CJK UNIFIED IDEOGRAPH-#6C3D, IRGKangXi=0603.130, RSKangXi=9.4, Def{to float; to deep fry; (Cant.) to turn inside-out}
6C3E CJK UNIFIED IDEOGRAPH-#6C3E, IRGKangXi=0603.140, RSKangXi=85.2, Def{overflow, flood, inundate}
6C3F CJK UNIFIED IDEOGRAPH-#6C3F, IRGKangXi=0604.010, RSKangXi=85.2, Def{spring}
6C40 CJK UNIFIED IDEOGRAPH-#6C40, IRGKangXi=0604.020, RSKangXi=85.2, Def{sandbar, beach, bank, shore}
6C41 CJK UNIFIED IDEOGRAPH-#6C41, IRGKangXi=0604.030, RSKangXi=85.2, Def{juice, liquor, fluid, sap, gravy, sauce}
6C42 CJK UNIFIED IDEOGRAPH-#6C42, IRGKangXi=0604.040, RSKangXi=85.2, Def{seek; demand, request; beseech}
6C43 CJK UNIFIED IDEOGRAPH-#6C43, IRGKangXi=0604.050, RSKangXi=85.2
6C44 CJK UNIFIED IDEOGRAPH-#6C44, IRGKangXi=0604.070, RSKangXi=85.2
6C45 CJK UNIFIED IDEOGRAPH-#6C45, IRGKangXi=0604.080, RSKangXi=85.2
6C46 CJK UNIFIED IDEOGRAPH-#6C46, IRGKangXi=0604.091, RSKangXi=85.2, Def{to parboil; hot water kettle; to boil}
6C47 CJK UNIFIED IDEOGRAPH-#6C47, IRGKangXi=0604.091, RSKangXi=85.2, Def{concourse; flow together, gather}
6C48 CJK UNIFIED IDEOGRAPH-#6C48, IRGKangXi=0604.091, RSKangXi=85.2
6C49 CJK UNIFIED IDEOGRAPH-#6C49, IRGKangXi=0604.091, RSKangXi=85.2, Def{Chinese people; Chinese language}
6C4A CJK UNIFIED IDEOGRAPH-#6C4A, IRGKangXi=0604.100, RSKangXi=85.3, Def{a branching stream}
6C4B CJK UNIFIED IDEOGRAPH-#6C4B, IRGKangXi=0604.110, RSKangXi=85.3, Def{to pour}
6C4C CJK UNIFIED IDEOGRAPH-#6C4C, IRGKangXi=0604.120, RSKangXi=85.3
6C4D CJK UNIFIED IDEOGRAPH-#6C4D, IRGKangXi=0604.140, RSKangXi=85.3, Def{weep}
6C4E CJK UNIFIED IDEOGRAPH-#6C4E, IRGKangXi=0604.150, RSKangXi=85.3, Def{float, drift; afloat; careless}
6C4F CJK UNIFIED IDEOGRAPH-#6C4F, IRGKangXi=0605.010, RSKangXi=85.3
6C50 CJK UNIFIED IDEOGRAPH-#6C50, IRGKangXi=0605.030, RSKangXi=85.3, Def{night tides, evening ebb tide}
6C51 CJK UNIFIED IDEOGRAPH-#6C51, IRGKangXi=0605.040, RSKangXi=85.3
6C52 CJK UNIFIED IDEOGRAPH-#6C52, IRGKangXi=0605.060, RSKangXi=85.3
6C53 CJK UNIFIED IDEOGRAPH-#6C53, IRGKangXi=0605.070, RSKangXi=85.3
6C54 CJK UNIFIED IDEOGRAPH-#6C54, IRGKangXi=0605.080, RSKangXi=85.3
6C55 CJK UNIFIED IDEOGRAPH-#6C55, IRGKangXi=0605.090, RSKangXi=85.3, Def{basket for catching fish; bamboo; Swatow (Shantou)}
6C56 CJK UNIFIED IDEOGRAPH-#6C56, IRGKangXi=0605.100, RSKangXi=85.3
6C57 CJK UNIFIED IDEOGRAPH-#6C57, IRGKangXi=0605.110, RSKangXi=85.3, Def{perspiration, sweat}
6C58 CJK UNIFIED IDEOGRAPH-#6C58, IRGKangXi=0605.120, RSKangXi=85.3
6C59 CJK UNIFIED IDEOGRAPH-#6C59, IRGKangXi=0605.130, RSKangXi=85.3, Def{filthy, dirty, impure, polluted}
6C5A CJK UNIFIED IDEOGRAPH-#6C5A, IRGKangXi=0605.150, RSKangXi=85.3, Def{filthy, dirty, impure, polluted}
6C5B CJK UNIFIED IDEOGRAPH-#6C5B, IRGKangXi=0605.160, RSKangXi=85.3, Def{high water, flood tides}
6C5C CJK UNIFIED IDEOGRAPH-#6C5C, IRGKangXi=0605.170, RSKangXi=85.3, Def{a stream which leaves the main branch then later returns}
6C5D CJK UNIFIED IDEOGRAPH-#6C5D, IRGKangXi=0606.020, RSKangXi=85.3, Def{you}
6C5E CJK UNIFIED IDEOGRAPH-#6C5E, IRGKangXi=0606.030, RSKangXi=85.3, Def{element mercury}
6C5F CJK UNIFIED IDEOGRAPH-#6C5F, IRGKangXi=0606.040, RSKangXi=85.3, Def{large river; yangzi; surname}
6C60 CJK UNIFIED IDEOGRAPH-#6C60, IRGKangXi=0606.050, RSKangXi=85.3, Def{pool, pond; moat; cistern}
6C61 CJK UNIFIED IDEOGRAPH-#6C61, IRGKangXi=0607.051, RSKangXi=85.3, Def{filthy, dirty, impure, polluted}
6C62 CJK UNIFIED IDEOGRAPH-#6C62, IRGKangXi=0607.051, RSKangXi=85.3
6C63 CJK UNIFIED IDEOGRAPH-#6C63, IRGKangXi=0607.051, RSKangXi=85.3
6C64 CJK UNIFIED IDEOGRAPH-#6C64, IRGKangXi=0607.051, RSKangXi=85.3, Def{hot water; soup, gravy, broth}
6C65 CJK UNIFIED IDEOGRAPH-#6C65, IRGKangXi=0607.060, RSKangXi=85.4
6C66 CJK UNIFIED IDEOGRAPH-#6C66, IRGKangXi=0607.070, RSKangXi=85.4
6C67 CJK UNIFIED IDEOGRAPH-#6C67, IRGKangXi=0607.080, RSKangXi=85.4, Def{name of a river in Shangdong; marsh; float}
6C68 CJK UNIFIED IDEOGRAPH-#6C68, IRGKangXi=0607.090, RSKangXi=85.4, Def{Mi(luo) river in Hunan province where Qu Yuan drowned himself; to sink; used (erroneously) for U+6C69 汩}
6C69 CJK UNIFIED IDEOGRAPH-#6C69, IRGKangXi=0607.110, RSKangXi=85.4, Def{run swiftly}
6C6A CJK UNIFIED IDEOGRAPH-#6C6A, IRGKangXi=0607.120, RSKangXi=85.4, Def{vast, extensive, deep; surname}
6C6B CJK UNIFIED IDEOGRAPH-#6C6B, IRGKangXi=0607.130, RSKangXi=85.4, Def{a pit, trap; the appearance of a small, meandering stream}
6C6C CJK UNIFIED IDEOGRAPH-#6C6C, IRGKangXi=0607.140, RSKangXi=85.4
6C6D CJK UNIFIED IDEOGRAPH-#6C6D, IRGKangXi=0607.150, RSKangXi=85.4, Def{confluence of two streams; bend}
6C6E CJK UNIFIED IDEOGRAPH-#6C6E, IRGKangXi=0607.160, RSKangXi=85.4
6C6F CJK UNIFIED IDEOGRAPH-#6C6F, IRGKangXi=0607.170, RSKangXi=85.4
6C70 CJK UNIFIED IDEOGRAPH-#6C70, IRGKangXi=0607.180, RSKangXi=85.4, Def{excessive; scour, wash out}
6C71 CJK UNIFIED IDEOGRAPH-#6C71, IRGKangXi=0608.010, RSKangXi=85.4
6C72 CJK UNIFIED IDEOGRAPH-#6C72, IRGKangXi=0608.030, RSKangXi=85.4, Def{draw water from well; imbibe}
6C73 CJK UNIFIED IDEOGRAPH-#6C73, IRGKangXi=0608.040, RSKangXi=85.4
6C74 CJK UNIFIED IDEOGRAPH-#6C74, IRGKangXi=0608.050, RSKangXi=85.4, Def{name of a river in Henan; Henan}
6C75 CJK UNIFIED IDEOGRAPH-#6C75, IRGKangXi=0608.060, RSKangXi=85.4
6C76 CJK UNIFIED IDEOGRAPH-#6C76, IRGKangXi=0608.080, RSKangXi=85.4, Def{a river in Shandong province}
6C77 CJK UNIFIED IDEOGRAPH-#6C77, IRGKangXi=0605.050, RSKangXi=85.4
6C78 CJK UNIFIED IDEOGRAPH-#6C78, IRGKangXi=0608.110, RSKangXi=85.4
6C79 CJK UNIFIED IDEOGRAPH-#6C79, IRGKangXi=0609.010, RSKangXi=85.4, Def{turbulent; noisy, restless}
6C7A CJK UNIFIED IDEOGRAPH-#6C7A, IRGKangXi=0609.030, RSKangXi=85.4, Def{decide, determine, judge}
6C7B CJK UNIFIED IDEOGRAPH-#6C7B, IRGKangXi=0609.040, RSKangXi=85.4
6C7C CJK UNIFIED IDEOGRAPH-#6C7C, IRGKangXi=0609.050, RSKangXi=85.4
6C7D CJK UNIFIED IDEOGRAPH-#6C7D, IRGKangXi=0609.060, RSKangXi=85.4, Def{steam, vapor, gas}
6C7E CJK UNIFIED IDEOGRAPH-#6C7E, IRGKangXi=0609.070, RSKangXi=85.4, Def{river in Shanxi province}
6C7F CJK UNIFIED IDEOGRAPH-#6C7F, IRGKangXi=0609.090, RSKangXi=85.4
6C80 CJK UNIFIED IDEOGRAPH-#6C80, IRGKangXi=0609.100, RSKangXi=85.4
6C81 CJK UNIFIED IDEOGRAPH-#6C81, IRGKangXi=0609.110, RSKangXi=85.4, Def{soak into, seep in, percolate}
6C82 CJK UNIFIED IDEOGRAPH-#6C82, IRGKangXi=0609.120, RSKangXi=85.4, Def{river in southeast Shandong}
6C83 CJK UNIFIED IDEOGRAPH-#6C83, IRGKangXi=0609.130, RSKangXi=85.4, Def{water, irrigate; fertile, rich}
6C84 CJK UNIFIED IDEOGRAPH-#6C84, IRGKangXi=0610.010, RSKangXi=85.4, Def{billows}
6C85 CJK UNIFIED IDEOGRAPH-#6C85, IRGKangXi=0610.020, RSKangXi=85.4, Def{name of a river in western Hunan that flows into Dongting lake}
6C86 CJK UNIFIED IDEOGRAPH-#6C86, IRGKangXi=0610.030, RSKangXi=85.4, Def{a ferry; fog; flowing}
6C87 CJK UNIFIED IDEOGRAPH-#6C87, IRGKangXi=0610.040, RSKangXi=85.4, Def{flowing and engulfing; brimming}
6C88 CJK UNIFIED IDEOGRAPH-#6C88, IRGKangXi=0610.060, RSKangXi=85.4, Def{sink, submerge; addicted to; surname}
6C89 CJK UNIFIED IDEOGRAPH-#6C89, IRGKangXi=0610.070, RSKangXi=85.4, Def{sink, submerge; addicted to}
6C8A CJK UNIFIED IDEOGRAPH-#6C8A, IRGKangXi=0610.080, RSKangXi=85.4, Def{(Cant.) onomatopoetic}
6C8B CJK UNIFIED IDEOGRAPH-#6C8B, IRGKangXi=0610.090, RSKangXi=85.4
6C8C CJK UNIFIED IDEOGRAPH-#6C8C, IRGKangXi=0610.100, RSKangXi=85.4, Def{chaotic, confused; turbid, murky}
6C8D CJK UNIFIED IDEOGRAPH-#6C8D, IRGKangXi=0610.110, RSKangXi=85.4, Def{freezing; stopped up, closed off}
6C8E CJK UNIFIED IDEOGRAPH-#6C8E, IRGKangXi=0611.030, RSKangXi=85.4
6C8F CJK UNIFIED IDEOGRAPH-#6C8F, IRGKangXi=0611.050, RSKangXi=85.4, Def{infuse}
6C90 CJK UNIFIED IDEOGRAPH-#6C90, IRGKangXi=0611.070, RSKangXi=85.4, Def{bathe, cleanse, wash, shampoo}
6C91 CJK UNIFIED IDEOGRAPH-#6C91, IRGKangXi=0611.080, RSKangXi=85.4
6C92 CJK UNIFIED IDEOGRAPH-#6C92, IRGKangXi=0611.100, RSKangXi=85.4, Def{not, have not, none; to drown, sink}
6C93 CJK UNIFIED IDEOGRAPH-#6C93, IRGKangXi=0611.150, RSKangXi=85.4, Def{connected, joined; repeated}
6C94 CJK UNIFIED IDEOGRAPH-#6C94, IRGKangXi=0611.160, RSKangXi=85.4, Def{flood; overflowing}
6C95 CJK UNIFIED IDEOGRAPH-#6C95, IRGKangXi=0611.170, RSKangXi=85.4, Def{deep; (Cant.) to dive}
6C96 CJK UNIFIED IDEOGRAPH-#6C96, IRGKangXi=0611.180, RSKangXi=85.4, Def{pour, infuse, steep; wash away}
6C97 CJK UNIFIED IDEOGRAPH-#6C97, IRGKangXi=0611.190, RSKangXi=85.4
6C98 CJK UNIFIED IDEOGRAPH-#6C98, IRGKangXi=0611.200, RSKangXi=85.4, Def{name of a river}
6C99 CJK UNIFIED IDEOGRAPH-#6C99, IRGKangXi=0611.210, RSKangXi=85.4, Def{sand, gravel, pebbles; granulated}
6C9A CJK UNIFIED IDEOGRAPH-#6C9A, IRGKangXi=0612.010, RSKangXi=85.4, Def{islet in stream; small sandbar}
6C9B CJK UNIFIED IDEOGRAPH-#6C9B, IRGKangXi=0612.030, RSKangXi=85.4, Def{abundant, full, copious; sudden}
6C9C CJK UNIFIED IDEOGRAPH-#6C9C, IRGKangXi=0612.040, RSKangXi=85.4
6C9D CJK UNIFIED IDEOGRAPH-#6C9D, IRGKangXi=0612.050, RSKangXi=85.4
6C9E CJK UNIFIED IDEOGRAPH-#6C9E, IRGKangXi=0612.070, RSKangXi=85.4
6C9F CJK UNIFIED IDEOGRAPH-#6C9F, IRGKangXi=0612.080, RSKangXi=85.4, Def{ditch, drain, narrow waterway}
6CA0 CJK UNIFIED IDEOGRAPH-#6CA0, IRGKangXi=0612.121, RSKangXi=85.4
6CA1 CJK UNIFIED IDEOGRAPH-#6CA1, IRGKangXi=0612.121, RSKangXi=85.4, Def{not, have not, none; drown, sink}
6CA2 CJK UNIFIED IDEOGRAPH-#6CA2, IRGKangXi=0612.121, RSKangXi=85.4, Def{marsh, swamp; grace, brilliance}
6CA3 CJK UNIFIED IDEOGRAPH-#6CA3, IRGKangXi=0612.121, RSKangXi=85.4, Def{river in Shanxi province}
6CA4 CJK UNIFIED IDEOGRAPH-#6CA4, IRGKangXi=0612.121, RSKangXi=85.4, Def{soak, steep; sodden or soaked}
6CA5 CJK UNIFIED IDEOGRAPH-#6CA5, IRGKangXi=0612.121, RSKangXi=85.4, Def{trickle, drip; strain; dregs}
6CA6 CJK UNIFIED IDEOGRAPH-#6CA6, IRGKangXi=0612.121, RSKangXi=85.4, Def{be lost; sink, be submerged}
6CA7 CJK UNIFIED IDEOGRAPH-#6CA7, IRGKangXi=0612.121, RSKangXi=85.4, Def{blue, dark green; cold}
6CA8 CJK UNIFIED IDEOGRAPH-#6CA8, IRGKangXi=0612.121, RSKangXi=85.4
6CA9 CJK UNIFIED IDEOGRAPH-#6CA9, IRGKangXi=0612.121, RSKangXi=85.4, Def{name of a river in Shanxi}
6CAA CJK UNIFIED IDEOGRAPH-#6CAA, IRGKangXi=0612.121, RSKangXi=85.4, Def{Shanghai; river near Shanghai}
6CAB CJK UNIFIED IDEOGRAPH-#6CAB, IRGKangXi=0612.130, RSKangXi=85.5, Def{froth, foam, bubbles, suds}
6CAC CJK UNIFIED IDEOGRAPH-#6CAC, IRGKangXi=0612.140, RSKangXi=85.5, Def{dusk; Mei river; Zhou dynasty place-name; (Cant.) to go underwater, to dive}
6CAD CJK UNIFIED IDEOGRAPH-#6CAD, IRGKangXi=0613.010, RSKangXi=85.5, Def{river in Shantung}
6CAE CJK UNIFIED IDEOGRAPH-#6CAE, IRGKangXi=0613.020, RSKangXi=85.5, Def{stop, prevent; defeated, dejected}
6CAF CJK UNIFIED IDEOGRAPH-#6CAF, IRGKangXi=0613.040, RSKangXi=85.5
6CB0 CJK UNIFIED IDEOGRAPH-#6CB0, IRGKangXi=0613.060, RSKangXi=85.5, Def{to let drop}
6CB1 CJK UNIFIED IDEOGRAPH-#6CB1, IRGKangXi=0613.070, RSKangXi=85.5, Def{rivers, streams, waterways; flow}
6CB2 CJK UNIFIED IDEOGRAPH-#6CB2, IRGKangXi=0613.080, RSKangXi=85.5, Def{float}
6CB3 CJK UNIFIED IDEOGRAPH-#6CB3, IRGKangXi=0613.090, RSKangXi=85.5, Def{river; stream; yellow river}
6CB4 CJK UNIFIED IDEOGRAPH-#6CB4, IRGKangXi=0613.100, RSKangXi=85.5, Def{foul and poisonous in confusion; out of harmony}
6CB5 CJK UNIFIED IDEOGRAPH-#6CB5, IRGKangXi=0613.110, RSKangXi=85.5
6CB6 CJK UNIFIED IDEOGRAPH-#6CB6, IRGKangXi=0613.120, RSKangXi=85.5
6CB7 CJK UNIFIED IDEOGRAPH-#6CB7, IRGKangXi=0614.010, RSKangXi=85.5, Def{to remove evil; to cleanse; to wash away}
6CB8 CJK UNIFIED IDEOGRAPH-#6CB8, IRGKangXi=0614.020, RSKangXi=85.5, Def{boil, bubble up, gush}
6CB9 CJK UNIFIED IDEOGRAPH-#6CB9, IRGKangXi=0614.040, RSKangXi=85.5, Def{oil, fat, grease, lard; paints}
6CBA CJK UNIFIED IDEOGRAPH-#6CBA, IRGKangXi=0614.050, RSKangXi=85.5, Def{turbulent}
6CBB CJK UNIFIED IDEOGRAPH-#6CBB, IRGKangXi=0614.070, RSKangXi=85.5, Def{govern, regulate, administer}
6CBC CJK UNIFIED IDEOGRAPH-#6CBC, IRGKangXi=0614.090, RSKangXi=85.5, Def{lake, fishpond, swamps}
6CBD CJK UNIFIED IDEOGRAPH-#6CBD, IRGKangXi=0614.100, RSKangXi=85.5, Def{buy and sell; inferior in quality}
6CBE CJK UNIFIED IDEOGRAPH-#6CBE, IRGKangXi=0614.120, RSKangXi=85.5, Def{moisten, wet, soak; touch}
6CBF CJK UNIFIED IDEOGRAPH-#6CBF, IRGKangXi=0614.130, RSKangXi=85.5, Def{follow a course, go along}
6CC0 CJK UNIFIED IDEOGRAPH-#6CC0, IRGKangXi=0614.140, RSKangXi=85.5
6CC1 CJK UNIFIED IDEOGRAPH-#6CC1, IRGKangXi=0615.010, RSKangXi=85.5, Def{condition, situation; furthermore}
6CC2 CJK UNIFIED IDEOGRAPH-#6CC2, IRGKangXi=0615.030, RSKangXi=85.5, Def{clear and deep (of water); wide}
6CC3 CJK UNIFIED IDEOGRAPH-#6CC3, IRGKangXi=0615.040, RSKangXi=85.5, Def{river in Henan}
6CC4 CJK UNIFIED IDEOGRAPH-#6CC4, IRGKangXi=0615.050, RSKangXi=85.5, Def{leak; vent; flow; reveal}
6CC5 CJK UNIFIED IDEOGRAPH-#6CC5, IRGKangXi=0615.080, RSKangXi=85.5, Def{swim, float, wade}
6CC6 CJK UNIFIED IDEOGRAPH-#6CC6, IRGKangXi=0615.090, RSKangXi=85.5, Def{licentious, libertine, dissipated}
6CC7 CJK UNIFIED IDEOGRAPH-#6CC7, IRGKangXi=0615.100, RSKangXi=85.5
6CC8 CJK UNIFIED IDEOGRAPH-#6CC8, IRGKangXi=0615.110, RSKangXi=85.5
6CC9 CJK UNIFIED IDEOGRAPH-#6CC9, IRGKangXi=0615.120, RSKangXi=85.5, Def{spring, fountain; wealth, money}
6CCA CJK UNIFIED IDEOGRAPH-#6CCA, IRGKangXi=0615.140, RSKangXi=85.5, Def{anchor vessel; lie at anchor}
6CCB CJK UNIFIED IDEOGRAPH-#6CCB, IRGKangXi=0615.170, RSKangXi=85.5
6CCC CJK UNIFIED IDEOGRAPH-#6CCC, IRGKangXi=0615.180, RSKangXi=85.5, Def{to seep out, excrete}
6CCD CJK UNIFIED IDEOGRAPH-#6CCD, IRGKangXi=0616.010, RSKangXi=85.5
6CCE CJK UNIFIED IDEOGRAPH-#6CCE, IRGKangXi=0616.020, RSKangXi=85.5
6CCF CJK UNIFIED IDEOGRAPH-#6CCF, IRGKangXi=0616.030, RSKangXi=85.5
6CD0 CJK UNIFIED IDEOGRAPH-#6CD0, IRGKangXi=0616.040, RSKangXi=85.5, Def{to write; to indite; veins in minerals}
6CD1 CJK UNIFIED IDEOGRAPH-#6CD1, IRGKangXi=0616.050, RSKangXi=85.5, Def{the vitreous glaze on china, porcelain, etc.}
6CD2 CJK UNIFIED IDEOGRAPH-#6CD2, IRGKangXi=0616.080, RSKangXi=85.5, Def{a river in Hubei province}
6CD3 CJK UNIFIED IDEOGRAPH-#6CD3, IRGKangXi=0616.090, RSKangXi=85.5, Def{clear, deep pool of water}
6CD4 CJK UNIFIED IDEOGRAPH-#6CD4, IRGKangXi=0616.100, RSKangXi=85.5, Def{water from washing rice to boil thick, as gruel}
6CD5 CJK UNIFIED IDEOGRAPH-#6CD5, IRGKangXi=0616.110, RSKangXi=85.5, Def{law, rule, regulation, statute; France, French}
6CD6 CJK UNIFIED IDEOGRAPH-#6CD6, IRGKangXi=0616.160, RSKangXi=85.5, Def{still waters; river in Jiangsu}
6CD7 CJK UNIFIED IDEOGRAPH-#6CD7, IRGKangXi=0616.170, RSKangXi=85.5, Def{mucous; nasal flow; sniffle; river in Shandong}
6CD8 CJK UNIFIED IDEOGRAPH-#6CD8, IRGKangXi=0616.180, RSKangXi=85.5
6CD9 CJK UNIFIED IDEOGRAPH-#6CD9, IRGKangXi=0616.190, RSKangXi=85.5, Def{roar}
6CDA CJK UNIFIED IDEOGRAPH-#6CDA, IRGKangXi=0616.200, RSKangXi=85.6, Def{clear; bright and brilliant; sweat}
6CDB CJK UNIFIED IDEOGRAPH-#6CDB, IRGKangXi=0616.210, RSKangXi=85.5, Def{to drift, float; careless, reckless}
6CDC CJK UNIFIED IDEOGRAPH-#6CDC, IRGKangXi=0616.220, RSKangXi=85.5, Def{a river in Hebei province}
6CDD CJK UNIFIED IDEOGRAPH-#6CDD, IRGKangXi=0617.010, RSKangXi=85.5, Def{go upstream; trace source; formerly}
6CDE CJK UNIFIED IDEOGRAPH-#6CDE, IRGKangXi=0617.030, RSKangXi=85.5, Def{mud; miry, muddy, stagnant}
6CDF CJK UNIFIED IDEOGRAPH-#6CDF, IRGKangXi=0617.050, RSKangXi=85.5
6CE0 CJK UNIFIED IDEOGRAPH-#6CE0, IRGKangXi=0617.060, RSKangXi=85.5, Def{nice and cool, mild and comfortable}
6CE1 CJK UNIFIED IDEOGRAPH-#6CE1, IRGKangXi=0617.070, RSKangXi=85.5, Def{bubbles, suds; blister; soak}
6CE2 CJK UNIFIED IDEOGRAPH-#6CE2, IRGKangXi=0617.080, RSKangXi=85.5, Def{waves, breakers; undulations}
6CE3 CJK UNIFIED IDEOGRAPH-#6CE3, IRGKangXi=0617.090, RSKangXi=85.5, Def{cry, sob, weep}
6CE4 CJK UNIFIED IDEOGRAPH-#6CE4, IRGKangXi=0617.100, RSKangXi=85.5
6CE5 CJK UNIFIED IDEOGRAPH-#6CE5, IRGKangXi=0617.110, RSKangXi=85.5, Def{mud, mire; earth, clay; plaster}
6CE6 CJK UNIFIED IDEOGRAPH-#6CE6, IRGKangXi=0618.020, RSKangXi=85.5
6CE7 CJK UNIFIED IDEOGRAPH-#6CE7, IRGKangXi=0618.040, RSKangXi=85.5
6CE8 CJK UNIFIED IDEOGRAPH-#6CE8, IRGKangXi=0618.050, RSKangXi=85.5, Def{concentrate, focus, direct}
6CE9 CJK UNIFIED IDEOGRAPH-#6CE9, IRGKangXi=0618.060, RSKangXi=85.5
6CEA CJK UNIFIED IDEOGRAPH-#6CEA, IRGKangXi=0618.070, RSKangXi=85.5, Def{tears; weep, cry}
6CEB CJK UNIFIED IDEOGRAPH-#6CEB, IRGKangXi=0618.080, RSKangXi=85.5, Def{weep; cry; shine, glisten}
6CEC CJK UNIFIED IDEOGRAPH-#6CEC, IRGKangXi=0618.090, RSKangXi=85.5
6CED CJK UNIFIED IDEOGRAPH-#6CED, IRGKangXi=0618.100, RSKangXi=85.5, Def{a raft}
6CEE CJK UNIFIED IDEOGRAPH-#6CEE, IRGKangXi=0618.120, RSKangXi=85.5, Def{Zhou dynasty school; disperse; fall apart}
6CEF CJK UNIFIED IDEOGRAPH-#6CEF, IRGKangXi=0618.140, RSKangXi=85.5, Def{destroy, eliminate; perish}
6CF0 CJK UNIFIED IDEOGRAPH-#6CF0, IRGKangXi=0618.150, RSKangXi=85.5, Def{great, exalted, superior; big}
6CF1 CJK UNIFIED IDEOGRAPH-#6CF1, IRGKangXi=0618.170, RSKangXi=85.5, Def{great, expansive; agitated}
6CF2 CJK UNIFIED IDEOGRAPH-#6CF2, IRGKangXi=0619.010, RSKangXi=85.5, Def{kind of white wine; rivers in Hebei and Shandong}
6CF3 CJK UNIFIED IDEOGRAPH-#6CF3, IRGKangXi=0619.020, RSKangXi=85.5, Def{dive; swim}
6CF4 CJK UNIFIED IDEOGRAPH-#6CF4, IRGKangXi=0619.090, RSKangXi=85.5
6CF5 CJK UNIFIED IDEOGRAPH-#6CF5, IRGKangXi=0619.121, RSKangXi=85.5, Def{pump}
6CF6 CJK UNIFIED IDEOGRAPH-#6CF6, IRGKangXi=0619.121, RSKangXi=85.5
6CF7 CJK UNIFIED IDEOGRAPH-#6CF7, IRGKangXi=0619.121, RSKangXi=85.5, Def{raining; wet; soaked; a river in Guangdong}
6CF8 CJK UNIFIED IDEOGRAPH-#6CF8, IRGKangXi=0619.121, RSKangXi=85.5, Def{river in Jiangxi province}
6CF9 CJK UNIFIED IDEOGRAPH-#6CF9, IRGKangXi=0619.121, RSKangXi=85.5
6CFA CJK UNIFIED IDEOGRAPH-#6CFA, IRGKangXi=0619.121, RSKangXi=85.5, Def{river in Shandong province}
6CFB CJK UNIFIED IDEOGRAPH-#6CFB, IRGKangXi=0619.121, RSKangXi=85.5, Def{drain off, leak; flow, pour down}
6CFC CJK UNIFIED IDEOGRAPH-#6CFC, IRGKangXi=0619.121, RSKangXi=85.5, Def{pour, splash, water, sprinkle}
6CFD CJK UNIFIED IDEOGRAPH-#6CFD, IRGKangXi=0619.121, RSKangXi=85.5, Def{marsh, swamp; grace, brilliance}
6CFE CJK UNIFIED IDEOGRAPH-#6CFE, IRGKangXi=0619.121, RSKangXi=85.5, Def{name of a river}
6CFF CJK UNIFIED IDEOGRAPH-#6CFF, IRGKangXi=0619.130, RSKangXi=85.6
6D00 CJK UNIFIED IDEOGRAPH-#6D00, IRGKangXi=0619.140, RSKangXi=85.6
6D01 CJK UNIFIED IDEOGRAPH-#6D01, IRGKangXi=0619.150, RSKangXi=85.6, Def{clean, purify, pure}
6D02 CJK UNIFIED IDEOGRAPH-#6D02, IRGKangXi=0619.160, RSKangXi=85.6
6D03 CJK UNIFIED IDEOGRAPH-#6D03, IRGKangXi=0619.170, RSKangXi=85.6
6D04 CJK UNIFIED IDEOGRAPH-#6D04, IRGKangXi=0619.180, RSKangXi=85.6, Def{a back-water; an eddy a whirlpool}
6D05 CJK UNIFIED IDEOGRAPH-#6D05, IRGKangXi=0619.200, RSKangXi=85.6
6D06 CJK UNIFIED IDEOGRAPH-#6D06, IRGKangXi=0619.220, RSKangXi=85.6
6D07 CJK UNIFIED IDEOGRAPH-#6D07, IRGKangXi=0619.230, RSKangXi=85.6
6D08 CJK UNIFIED IDEOGRAPH-#6D08, IRGKangXi=0619.250, RSKangXi=85.6
6D09 CJK UNIFIED IDEOGRAPH-#6D09, IRGKangXi=0619.260, RSKangXi=85.6
6D0A CJK UNIFIED IDEOGRAPH-#6D0A, IRGKangXi=0619.270, RSKangXi=85.6, Def{flowing water}
6D0B CJK UNIFIED IDEOGRAPH-#6D0B, IRGKangXi=0619.280, RSKangXi=85.6, Def{ocean, sea; foreign; western}
6D0C CJK UNIFIED IDEOGRAPH-#6D0C, IRGKangXi=0619.290, RSKangXi=85.6, Def{clear}
6D0D CJK UNIFIED IDEOGRAPH-#6D0D, IRGKangXi=0619.310, RSKangXi=85.7
6D0E CJK UNIFIED IDEOGRAPH-#6D0E, IRGKangXi=0619.340, RSKangXi=85.6, Def{until; till; soup; to soak}
6D0F CJK UNIFIED IDEOGRAPH-#6D0F, IRGKangXi=0620.010, RSKangXi=85.6, Def{tears; tearful}
6D10 CJK UNIFIED IDEOGRAPH-#6D10, IRGKangXi=0620.020, RSKangXi=85.6
6D11 CJK UNIFIED IDEOGRAPH-#6D11, IRGKangXi=0620.040, RSKangXi=85.6, Def{whirlpool, undercurrent}
6D12 CJK UNIFIED IDEOGRAPH-#6D12, IRGKangXi=0620.050, RSKangXi=85.6, Def{sprinkle; scatter; pour; to wipe away; to shiver}
6D13 CJK UNIFIED IDEOGRAPH-#6D13, IRGKangXi=0620.060, RSKangXi=85.6
6D14 CJK UNIFIED IDEOGRAPH-#6D14, IRGKangXi=0620.070, RSKangXi=85.6
6D15 CJK UNIFIED IDEOGRAPH-#6D15, IRGKangXi=0620.090, RSKangXi=85.6
6D16 CJK UNIFIED IDEOGRAPH-#6D16, IRGKangXi=0620.100, RSKangXi=85.7
6D17 CJK UNIFIED IDEOGRAPH-#6D17, IRGKangXi=0620.110, RSKangXi=85.6, Def{wash, rinse; clean, purify}
6D18 CJK UNIFIED IDEOGRAPH-#6D18, IRGKangXi=0620.120, RSKangXi=85.6
6D19 CJK UNIFIED IDEOGRAPH-#6D19, IRGKangXi=0620.130, RSKangXi=85.6, Def{name of a river in Shandong}
6D1A CJK UNIFIED IDEOGRAPH-#6D1A, IRGKangXi=0620.140, RSKangXi=85.6, Def{a flood}
6D1B CJK UNIFIED IDEOGRAPH-#6D1B, IRGKangXi=0620.150, RSKangXi=85.6, Def{river in Shanxi province; city}
6D1C CJK UNIFIED IDEOGRAPH-#6D1C, IRGKangXi=0620.160, RSKangXi=85.6
6D1D CJK UNIFIED IDEOGRAPH-#6D1D, IRGKangXi=0620.170, RSKangXi=85.6
6D1E CJK UNIFIED IDEOGRAPH-#6D1E, IRGKangXi=0620.180, RSKangXi=85.6, Def{cave, grotto; ravine; hole}
6D1F CJK UNIFIED IDEOGRAPH-#6D1F, IRGKangXi=0620.190, RSKangXi=85.6, Def{snivel, mucus from nose}
6D20 CJK UNIFIED IDEOGRAPH-#6D20, IRGKangXi=0621.020, RSKangXi=85.6
6D21 CJK UNIFIED IDEOGRAPH-#6D21, IRGKangXi=0621.040, RSKangXi=85.6
6D22 CJK UNIFIED IDEOGRAPH-#6D22, IRGKangXi=0621.050, RSKangXi=85.6
6D23 CJK UNIFIED IDEOGRAPH-#6D23, IRGKangXi=0621.060, RSKangXi=85.6, Def{Mi river in Hunan, tributary of Xiangjiang}
6D24 CJK UNIFIED IDEOGRAPH-#6D24, IRGKangXi=0621.080, RSKangXi=85.6, Def{a fountain or spring}
6D25 CJK UNIFIED IDEOGRAPH-#6D25, IRGKangXi=0621.090, RSKangXi=85.6, Def{ferry; saliva; ford}
6D26 CJK UNIFIED IDEOGRAPH-#6D26, IRGKangXi=0621.160, RSKangXi=85.6
6D27 CJK UNIFIED IDEOGRAPH-#6D27, IRGKangXi=0621.170, RSKangXi=85.6, Def{name of a river in honan}
6D28 CJK UNIFIED IDEOGRAPH-#6D28, IRGKangXi=0621.180, RSKangXi=85.6, Def{river in Hebei province}
6D29 CJK UNIFIED IDEOGRAPH-#6D29, IRGKangXi=0621.200, RSKangXi=85.6, Def{leak, drip; vent or release}
6D2A CJK UNIFIED IDEOGRAPH-#6D2A, IRGKangXi=0621.210, RSKangXi=85.6, Def{vast, immense; flood, deluge}
6D2B CJK UNIFIED IDEOGRAPH-#6D2B, IRGKangXi=0621.220, RSKangXi=85.6, Def{to ditch; a moat}
6D2C CJK UNIFIED IDEOGRAPH-#6D2C, IRGKangXi=0621.230, RSKangXi=85.6
6D2D CJK UNIFIED IDEOGRAPH-#6D2D, IRGKangXi=0621.250, RSKangXi=85.6
6D2E CJK UNIFIED IDEOGRAPH-#6D2E, IRGKangXi=0622.030, RSKangXi=85.6, Def{cleanse; river in Gansu province}
6D2F CJK UNIFIED IDEOGRAPH-#6D2F, IRGKangXi=0622.040, RSKangXi=85.6
6D30 CJK UNIFIED IDEOGRAPH-#6D30, IRGKangXi=0622.070, RSKangXi=85.6
6D31 CJK UNIFIED IDEOGRAPH-#6D31, IRGKangXi=0622.080, RSKangXi=85.6, Def{a lake in Yunnan}
6D32 CJK UNIFIED IDEOGRAPH-#6D32, IRGKangXi=0622.090, RSKangXi=85.6, Def{continent; island; islet}
6D33 CJK UNIFIED IDEOGRAPH-#6D33, IRGKangXi=0622.100, RSKangXi=85.6, Def{damp, boggy, marshy}
6D34 CJK UNIFIED IDEOGRAPH-#6D34, IRGKangXi=0622.110, RSKangXi=85.6, Def{sound}
6D35 CJK UNIFIED IDEOGRAPH-#6D35, IRGKangXi=0622.120, RSKangXi=85.6, Def{true, real, truly, really}
6D36 CJK UNIFIED IDEOGRAPH-#6D36, IRGKangXi=0622.130, RSKangXi=85.6, Def{the rush of water; turbulent; noisy, restless}
6D37 CJK UNIFIED IDEOGRAPH-#6D37, IRGKangXi=0622.140, RSKangXi=85.6
6D38 CJK UNIFIED IDEOGRAPH-#6D38, IRGKangXi=0622.150, RSKangXi=85.6, Def{sparkle, glitter}
6D39 CJK UNIFIED IDEOGRAPH-#6D39, IRGKangXi=0622.160, RSKangXi=85.6, Def{river in Henan province}
6D3A CJK UNIFIED IDEOGRAPH-#6D3A, IRGKangXi=0622.170, RSKangXi=85.6, Def{river in Hebei province}
6D3B CJK UNIFIED IDEOGRAPH-#6D3B, IRGKangXi=0622.180, RSKangXi=85.6, Def{live, exist, survive; lively}
6D3C CJK UNIFIED IDEOGRAPH-#6D3C, IRGKangXi=0622.200, RSKangXi=85.6, Def{hollow; pit; depression; swamp}
6D3D CJK UNIFIED IDEOGRAPH-#6D3D, IRGKangXi=0622.210, RSKangXi=85.6, Def{to blend with, be in harmony; to penetrate; to cover; a river in Shenxi}
6D3E CJK UNIFIED IDEOGRAPH-#6D3E, IRGKangXi=0623.010, RSKangXi=85.6, Def{school of thought, sect, branch}
6D3F CJK UNIFIED IDEOGRAPH-#6D3F, IRGKangXi=0623.020, RSKangXi=85.6, Def{stagnant water; impure, filthy}
6D40 CJK UNIFIED IDEOGRAPH-#6D40, IRGKangXi=0623.030, RSKangXi=85.6
6D41 CJK UNIFIED IDEOGRAPH-#6D41, IRGKangXi=0623.040, RSKangXi=85.6, Def{flow, circulate, drift; class}
6D42 CJK UNIFIED IDEOGRAPH-#6D42, IRGKangXi=0623.150, RSKangXi=85.6
6D43 CJK UNIFIED IDEOGRAPH-#6D43, IRGKangXi=0623.171, RSKangXi=85.6, Def{saturate, drench; damp, wet}
6D44 CJK UNIFIED IDEOGRAPH-#6D44, IRGKangXi=0623.171, RSKangXi=85.6, Def{pure, clean, unspoiled}
6D45 CJK UNIFIED IDEOGRAPH-#6D45, IRGKangXi=0619.121, RSKangXi=85.5, Def{shallow, not deep; superficial}
6D46 CJK UNIFIED IDEOGRAPH-#6D46, IRGKangXi=0623.171, RSKangXi=85.6, Def{any thick fluid; starch; broth}
6D47 CJK UNIFIED IDEOGRAPH-#6D47, IRGKangXi=0623.171, RSKangXi=85.6, Def{spray, water, sprinkle}
6D48 CJK UNIFIED IDEOGRAPH-#6D48, IRGKangXi=0623.171, RSKangXi=85.6, Def{river in Guangdong province}
6D49 CJK UNIFIED IDEOGRAPH-#6D49, IRGKangXi=0623.171, RSKangXi=85.10
6D4A CJK UNIFIED IDEOGRAPH-#6D4A, IRGKangXi=0623.171, RSKangXi=85.6, Def{muddy, turbid, dirty, filthy}
6D4B CJK UNIFIED IDEOGRAPH-#6D4B, IRGKangXi=0623.171, RSKangXi=85.6, Def{measure, estimate, conjecture}
6D4C CJK UNIFIED IDEOGRAPH-#6D4C, IRGKangXi=0623.171, RSKangXi=85.6
6D4D CJK UNIFIED IDEOGRAPH-#6D4D, IRGKangXi=0623.171, RSKangXi=85.6, Def{irrigation ditch, trench; river}
6D4E CJK UNIFIED IDEOGRAPH-#6D4E, IRGKangXi=0623.171, RSKangXi=85.6, Def{help, aid, relieve; ferry, cross}
6D4F CJK UNIFIED IDEOGRAPH-#6D4F, IRGKangXi=0623.171, RSKangXi=85.6, Def{clear; bright; whistling}
6D50 CJK UNIFIED IDEOGRAPH-#6D50, IRGKangXi=0623.171, RSKangXi=85.11
6D51 CJK UNIFIED IDEOGRAPH-#6D51, IRGKangXi=0623.171, RSKangXi=85.6, Def{muddy, turbid; blend, merge, mix}
6D52 CJK UNIFIED IDEOGRAPH-#6D52, IRGKangXi=0623.171, RSKangXi=85.6, Def{riverbank, shore}
6D53 CJK UNIFIED IDEOGRAPH-#6D53, IRGKangXi=0623.171, RSKangXi=85.6, Def{thick, strong, concentrated}
6D54 CJK UNIFIED IDEOGRAPH-#6D54, IRGKangXi=0623.171, RSKangXi=85.6, Def{steep bank by stream; jiujiang}
6D55 CJK UNIFIED IDEOGRAPH-#6D55, IRGKangXi=0623.171, RSKangXi=85.14
6D56 CJK UNIFIED IDEOGRAPH-#6D56, IRGKangXi=0623.180, RSKangXi=85.7, Def{(Cant.) intensifier}
6D57 CJK UNIFIED IDEOGRAPH-#6D57, IRGKangXi=0623.190, RSKangXi=85.7
6D58 CJK UNIFIED IDEOGRAPH-#6D58, IRGKangXi=0623.200, RSKangXi=85.7
6D59 CJK UNIFIED IDEOGRAPH-#6D59, IRGKangXi=0623.210, RSKangXi=85.7, Def{Zhejiang province; river}
6D5A CJK UNIFIED IDEOGRAPH-#6D5A, IRGKangXi=0623.230, RSKangXi=85.7, Def{dredge}
6D5B CJK UNIFIED IDEOGRAPH-#6D5B, IRGKangXi=0623.240
6D5C CJK UNIFIED IDEOGRAPH-#6D5C, IRGKangXi=0623.250, RSKangXi=85.7, Def{creek, stream; beach, sea coast}
6D5D CJK UNIFIED IDEOGRAPH-#6D5D, IRGKangXi=0623.260, RSKangXi=85.7
6D5E CJK UNIFIED IDEOGRAPH-#6D5E, IRGKangXi=0623.270, RSKangXi=85.7, Def{to soak, to steep in water}
6D5F CJK UNIFIED IDEOGRAPH-#6D5F, IRGKangXi=0624.010, RSKangXi=85.7
6D60 CJK UNIFIED IDEOGRAPH-#6D60, IRGKangXi=0624.020, RSKangXi=85.7
6D61 CJK UNIFIED IDEOGRAPH-#6D61, IRGKangXi=0624.030, RSKangXi=85.7, Def{burst forth; rise; vigorous}
6D62 CJK UNIFIED IDEOGRAPH-#6D62, IRGKangXi=0624.040, RSKangXi=85.7
6D63 CJK UNIFIED IDEOGRAPH-#6D63, IRGKangXi=0624.060, RSKangXi=85.7, Def{to wash, to rinse}
6D64 CJK UNIFIED IDEOGRAPH-#6D64, IRGKangXi=0624.070, RSKangXi=85.7, Def{beating of ocean; surging of water}
6D65 CJK UNIFIED IDEOGRAPH-#6D65, IRGKangXi=0624.100, RSKangXi=85.7, Def{moist, wet, dampen}
6D66 CJK UNIFIED IDEOGRAPH-#6D66, IRGKangXi=0624.110, RSKangXi=85.7, Def{bank of river, shore; surname}
6D67 CJK UNIFIED IDEOGRAPH-#6D67, IRGKangXi=0624.120, RSKangXi=85.7
6D68 CJK UNIFIED IDEOGRAPH-#6D68, IRGKangXi=0624.130, RSKangXi=85.7
6D69 CJK UNIFIED IDEOGRAPH-#6D69, IRGKangXi=0624.150, RSKangXi=85.7, Def{great, numerous, vast, abundant}
6D6A CJK UNIFIED IDEOGRAPH-#6D6A, IRGKangXi=0624.180, RSKangXi=85.7, Def{wave; wasteful, reckless}
6D6B CJK UNIFIED IDEOGRAPH-#6D6B, IRGKangXi=0624.190, RSKangXi=85.7
6D6C CJK UNIFIED IDEOGRAPH-#6D6C, IRGKangXi=0624.210, RSKangXi=85.7, Def{nautical mile}
6D6D CJK UNIFIED IDEOGRAPH-#6D6D, IRGKangXi=0624.220, RSKangXi=85.7, Def{river in Hebei province; (Cant.) a ford; to wade}
6D6E CJK UNIFIED IDEOGRAPH-#6D6E, IRGKangXi=0624.230, RSKangXi=85.7, Def{to float, drift, waft; to exceed; superfluous}
6D6F CJK UNIFIED IDEOGRAPH-#6D6F, IRGKangXi=0625.010, RSKangXi=85.7, Def{name of a river in Shandong}
6D70 CJK UNIFIED IDEOGRAPH-#6D70, IRGKangXi=0625.020, RSKangXi=85.7
6D71 CJK UNIFIED IDEOGRAPH-#6D71, IRGKangXi=0625.040, RSKangXi=85.7
6D72 CJK UNIFIED IDEOGRAPH-#6D72, IRGKangXi=0625.050, RSKangXi=85.7
6D73 CJK UNIFIED IDEOGRAPH-#6D73, IRGKangXi=0625.060, RSKangXi=85.7
6D74 CJK UNIFIED IDEOGRAPH-#6D74, IRGKangXi=0625.090, RSKangXi=85.7, Def{bathe, wash; bath}
6D75 CJK UNIFIED IDEOGRAPH-#6D75, IRGKangXi=0625.120, RSKangXi=85.7
6D76 CJK UNIFIED IDEOGRAPH-#6D76, IRGKangXi=0625.130, RSKangXi=85.7
6D77 CJK UNIFIED IDEOGRAPH-#6D77, IRGKangXi=0625.140, RSKangXi=85.7, Def{sea, ocean; maritime}
6D78 CJK UNIFIED IDEOGRAPH-#6D78, IRGKangXi=0625.150, RSKangXi=85.7, Def{soak, immerse, dip, percolate}
6D79 CJK UNIFIED IDEOGRAPH-#6D79, IRGKangXi=0625.170, RSKangXi=85.7, Def{saturate, drench; damp, wet}
6D7A CJK UNIFIED IDEOGRAPH-#6D7A, IRGKangXi=0625.180, RSKangXi=85.7
6D7B CJK UNIFIED IDEOGRAPH-#6D7B, IRGKangXi=0625.200, RSKangXi=85.7
6D7C CJK UNIFIED IDEOGRAPH-#6D7C, IRGKangXi=0625.210, RSKangXi=85.7, Def{to request; to ask a favour of; to pollute, contaminate}
6D7D CJK UNIFIED IDEOGRAPH-#6D7D, IRGKangXi=0625.220, RSKangXi=85.7
6D7E CJK UNIFIED IDEOGRAPH-#6D7E, IRGKangXi=0625.230, RSKangXi=85.7
6D7F CJK UNIFIED IDEOGRAPH-#6D7F, IRGKangXi=0625.240, RSKangXi=85.7
6D80 CJK UNIFIED IDEOGRAPH-#6D80, IRGKangXi=0625.250, RSKangXi=85.7
6D81 CJK UNIFIED IDEOGRAPH-#6D81, IRGKangXi=0625.260, RSKangXi=85.7
6D82 CJK UNIFIED IDEOGRAPH-#6D82, IRGKangXi=0625.290, RSKangXi=85.7, Def{surname; name of certain rivers}
6D83 CJK UNIFIED IDEOGRAPH-#6D83, IRGKangXi=0626.010, RSKangXi=85.7
6D84 CJK UNIFIED IDEOGRAPH-#6D84, IRGKangXi=0626.020, RSKangXi=85.7
6D85 CJK UNIFIED IDEOGRAPH-#6D85, IRGKangXi=0626.030, RSKangXi=85.7, Def{blacken; black mud, slime}
6D86 CJK UNIFIED IDEOGRAPH-#6D86, IRGKangXi=0626.040, RSKangXi=85.7
6D87 CJK UNIFIED IDEOGRAPH-#6D87, IRGKangXi=0626.080, RSKangXi=85.7, Def{name of a river}
6D88 CJK UNIFIED IDEOGRAPH-#6D88, IRGKangXi=0626.110, RSKangXi=85.7, Def{vanish, die out; melt away}
6D89 CJK UNIFIED IDEOGRAPH-#6D89, IRGKangXi=0626.130, RSKangXi=85.7, Def{ford stream, wade across}
6D8A CJK UNIFIED IDEOGRAPH-#6D8A, IRGKangXi=0626.170, RSKangXi=85.7, Def{dirt}
6D8B CJK UNIFIED IDEOGRAPH-#6D8B, IRGKangXi=0626.180, RSKangXi=85.7
6D8C CJK UNIFIED IDEOGRAPH-#6D8C, IRGKangXi=0626.190, RSKangXi=85.7, Def{surge up, bubble up, gush forth}
6D8D CJK UNIFIED IDEOGRAPH-#6D8D, IRGKangXi=0626.200, RSKangXi=85.7
6D8E CJK UNIFIED IDEOGRAPH-#6D8E, IRGKangXi=0626.210, RSKangXi=85.7, Def{saliva}
6D8F CJK UNIFIED IDEOGRAPH-#6D8F, IRGKangXi=0626.220, RSKangXi=85.7
6D90 CJK UNIFIED IDEOGRAPH-#6D90, IRGKangXi=0626.230, RSKangXi=85.7
6D91 CJK UNIFIED IDEOGRAPH-#6D91, IRGKangXi=0626.240, RSKangXi=85.7, Def{river in Shansi province}
6D92 CJK UNIFIED IDEOGRAPH-#6D92, IRGKangXi=0627.010, RSKangXi=85.7, Def{meander}
6D93 CJK UNIFIED IDEOGRAPH-#6D93, IRGKangXi=0627.020, RSKangXi=85.7, Def{brook, stream; select; pure}
6D94 CJK UNIFIED IDEOGRAPH-#6D94, IRGKangXi=0627.030, RSKangXi=85.7, Def{river in Shaanxi; murky torrent}
6D95 CJK UNIFIED IDEOGRAPH-#6D95, IRGKangXi=0627.040, RSKangXi=85.7, Def{tear; snivel, nasal mucus}
6D96 CJK UNIFIED IDEOGRAPH-#6D96, IRGKangXi=0627.050, RSKangXi=85.7, Def{river in Hebei province; creek}
6D97 CJK UNIFIED IDEOGRAPH-#6D97, IRGKangXi=0627.060, RSKangXi=85.7
6D98 CJK UNIFIED IDEOGRAPH-#6D98, IRGKangXi=0627.070, RSKangXi=85.7, Def{river bank; water's edge}
6D99 CJK UNIFIED IDEOGRAPH-#6D99, IRGKangXi=0627.311, RSKangXi=85.8, Def{tears; weep}
6D9A CJK UNIFIED IDEOGRAPH-#6D9A, IRGKangXi=0627.311, RSKangXi=85.7
6D9B CJK UNIFIED IDEOGRAPH-#6D9B, IRGKangXi=0627.311, RSKangXi=85.7, Def{large waves}
6D9C CJK UNIFIED IDEOGRAPH-#6D9C, IRGKangXi=0627.311, RSKangXi=85.7, Def{ditch, sluice, gutter, drain}
6D9D CJK UNIFIED IDEOGRAPH-#6D9D, IRGKangXi=0627.311, RSKangXi=85.7, Def{inundate, flood; torrent}
6D9E CJK UNIFIED IDEOGRAPH-#6D9E, IRGKangXi=0627.311, RSKangXi=85.7, Def{river in Hebei province; creek}
6D9F CJK UNIFIED IDEOGRAPH-#6D9F, IRGKangXi=0633.371, RSKangXi=85.7, Def{flowing water; ripples; weeping}
6DA0 CJK UNIFIED IDEOGRAPH-#6DA0, IRGKangXi=0627.311, RSKangXi=85.7, Def{still water}
6DA1 CJK UNIFIED IDEOGRAPH-#6DA1, IRGKangXi=0627.311, RSKangXi=85.7, Def{swirl, whirlpool, eddy}
6DA2 CJK UNIFIED IDEOGRAPH-#6DA2, IRGKangXi=0627.311, RSKangXi=85.10
6DA3 CJK UNIFIED IDEOGRAPH-#6DA3, IRGKangXi=0627.311, RSKangXi=85.7, Def{scatter; scattered}
6DA4 CJK UNIFIED IDEOGRAPH-#6DA4, IRGKangXi=0627.311, RSKangXi=85.7, Def{wash, cleanse, purify; sweep}
6DA5 CJK UNIFIED IDEOGRAPH-#6DA5, IRGKangXi=0627.311, RSKangXi=85.7
6DA6 CJK UNIFIED IDEOGRAPH-#6DA6, IRGKangXi=0627.311, RSKangXi=85.7, Def{soft, moist; sleek; freshen}
6DA7 CJK UNIFIED IDEOGRAPH-#6DA7, IRGKangXi=0627.311, RSKangXi=85.7, Def{brook, mountain stream}
6DA8 CJK UNIFIED IDEOGRAPH-#6DA8, IRGKangXi=0627.311, RSKangXi=85.7, Def{rise in price}
6DA9 CJK UNIFIED IDEOGRAPH-#6DA9, IRGKangXi=0627.311, RSKangXi=85.7, Def{astringent; harsh; uneven, rough}
6DAA CJK UNIFIED IDEOGRAPH-#6DAA, IRGKangXi=0627.320, RSKangXi=85.8, Def{river in Sichuan province}
6DAB CJK UNIFIED IDEOGRAPH-#6DAB, IRGKangXi=0627.330, RSKangXi=85.8
6DAC CJK UNIFIED IDEOGRAPH-#6DAC, IRGKangXi=0627.340, RSKangXi=85.8, Def{watery expanse}
6DAD CJK UNIFIED IDEOGRAPH-#6DAD, IRGKangXi=0627.350
6DAE CJK UNIFIED IDEOGRAPH-#6DAE, IRGKangXi=0627.360, RSKangXi=85.8, Def{rinse; cook or boil in juice}
6DAF CJK UNIFIED IDEOGRAPH-#6DAF, IRGKangXi=0627.380, RSKangXi=85.8, Def{shore, bank, water's edge}
6DB0 CJK UNIFIED IDEOGRAPH-#6DB0, IRGKangXi=0628.020, RSKangXi=85.8
6DB1 CJK UNIFIED IDEOGRAPH-#6DB1, IRGKangXi=0628.030, RSKangXi=85.8
6DB2 CJK UNIFIED IDEOGRAPH-#6DB2, IRGKangXi=0628.040, RSKangXi=85.8, Def{sap, juice, liquid, fluid}
6DB3 CJK UNIFIED IDEOGRAPH-#6DB3, IRGKangXi=0628.070, RSKangXi=85.8
6DB4 CJK UNIFIED IDEOGRAPH-#6DB4, IRGKangXi=0628.110, RSKangXi=85.8, Def{daub}
6DB5 CJK UNIFIED IDEOGRAPH-#6DB5, IRGKangXi=0628.130, RSKangXi=85.8, Def{soak, wet; tolerate, be lenient}
6DB6 CJK UNIFIED IDEOGRAPH-#6DB6, IRGKangXi=0628.140, RSKangXi=85.8, Def{to spit; saliva}
6DB7 CJK UNIFIED IDEOGRAPH-#6DB7, IRGKangXi=0628.180, RSKangXi=85.8, Def{rainstorm}
6DB8 CJK UNIFIED IDEOGRAPH-#6DB8, IRGKangXi=0628.190, RSKangXi=85.8, Def{dried up; exhausted, tired; dry}
6DB9 CJK UNIFIED IDEOGRAPH-#6DB9, IRGKangXi=0628.200, RSKangXi=85.8
6DBA CJK UNIFIED IDEOGRAPH-#6DBA, IRGKangXi=0628.210, RSKangXi=85.8
6DBB CJK UNIFIED IDEOGRAPH-#6DBB, IRGKangXi=0628.230, RSKangXi=85.8
6DBC CJK UNIFIED IDEOGRAPH-#6DBC, IRGKangXi=0628.240, RSKangXi=85.8, Def{cool, cold; disheartened}
6DBD CJK UNIFIED IDEOGRAPH-#6DBD, IRGKangXi=0628.250, RSKangXi=85.8
6DBE CJK UNIFIED IDEOGRAPH-#6DBE, IRGKangXi=0628.260, RSKangXi=85.8
6DBF CJK UNIFIED IDEOGRAPH-#6DBF, IRGKangXi=0628.270, RSKangXi=85.8, Def{drip, dribble, trickle}
6DC0 CJK UNIFIED IDEOGRAPH-#6DC0, IRGKangXi=0628.280, RSKangXi=85.8, Def{shallow water, swamp; swampy}
6DC1 CJK UNIFIED IDEOGRAPH-#6DC1, IRGKangXi=0628.300, RSKangXi=85.8
6DC2 CJK UNIFIED IDEOGRAPH-#6DC2, IRGKangXi=0629.010, RSKangXi=85.8
6DC3 CJK UNIFIED IDEOGRAPH-#6DC3, IRGKangXi=0629.020, RSKangXi=85.8
6DC4 CJK UNIFIED IDEOGRAPH-#6DC4, IRGKangXi=0629.040, RSKangXi=85.8, Def{river in Shandong province}
6DC5 CJK UNIFIED IDEOGRAPH-#6DC5, IRGKangXi=0629.050, RSKangXi=85.8, Def{water used wash rice; to wash ric}
6DC6 CJK UNIFIED IDEOGRAPH-#6DC6, IRGKangXi=0629.070, RSKangXi=85.8, Def{confused, in disarray, mixed up}
6DC7 CJK UNIFIED IDEOGRAPH-#6DC7, IRGKangXi=0629.080, RSKangXi=85.8, Def{river in Henan province}
6DC8 CJK UNIFIED IDEOGRAPH-#6DC8, IRGKangXi=0629.100, RSKangXi=85.8
6DC9 CJK UNIFIED IDEOGRAPH-#6DC9, IRGKangXi=0629.110, RSKangXi=85.8
6DCA CJK UNIFIED IDEOGRAPH-#6DCA, IRGKangXi=0629.120, RSKangXi=85.8
6DCB CJK UNIFIED IDEOGRAPH-#6DCB, IRGKangXi=0629.140, RSKangXi=85.8, Def{drip, soak, drench; perfectly}
6DCC CJK UNIFIED IDEOGRAPH-#6DCC, IRGKangXi=0629.170, RSKangXi=85.8, Def{trickle; flow down; drip}
6DCD CJK UNIFIED IDEOGRAPH-#6DCD, IRGKangXi=0629.180, RSKangXi=85.8
6DCE CJK UNIFIED IDEOGRAPH-#6DCE, IRGKangXi=0629.190, RSKangXi=85.8
6DCF CJK UNIFIED IDEOGRAPH-#6DCF, IRGKangXi=0629.200, RSKangXi=85.8
6DD0 CJK UNIFIED IDEOGRAPH-#6DD0, IRGKangXi=0629.210, RSKangXi=85.8
6DD1 CJK UNIFIED IDEOGRAPH-#6DD1, IRGKangXi=0629.220, RSKangXi=85.8, Def{good, pure, virtuous, charming}
6DD2 CJK UNIFIED IDEOGRAPH-#6DD2, IRGKangXi=0629.230, RSKangXi=85.8, Def{bitter cold, miserable, dreary}
6DD3 CJK UNIFIED IDEOGRAPH-#6DD3, IRGKangXi=0629.240, RSKangXi=85.8
6DD4 CJK UNIFIED IDEOGRAPH-#6DD4, IRGKangXi=0629.250, RSKangXi=85.8
6DD5 CJK UNIFIED IDEOGRAPH-#6DD5, IRGKangXi=0629.260, RSKangXi=85.8
6DD6 CJK UNIFIED IDEOGRAPH-#6DD6, IRGKangXi=0629.270, RSKangXi=85.8, Def{slush; mud}
6DD7 CJK UNIFIED IDEOGRAPH-#6DD7, IRGKangXi=0629.290, RSKangXi=85.8
6DD8 CJK UNIFIED IDEOGRAPH-#6DD8, IRGKangXi=0629.300, RSKangXi=85.8, Def{wash in sieve; weed out}
6DD9 CJK UNIFIED IDEOGRAPH-#6DD9, IRGKangXi=0630.010, RSKangXi=85.8, Def{gurgling sound of water}
6DDA CJK UNIFIED IDEOGRAPH-#6DDA, IRGKangXi=0630.020, RSKangXi=85.8, Def{tears; weep, cry}
6DDB CJK UNIFIED IDEOGRAPH-#6DDB, IRGKangXi=0630.040, RSKangXi=85.8
6DDC CJK UNIFIED IDEOGRAPH-#6DDC, IRGKangXi=0630.050, RSKangXi=85.8, Def{roar of dashing waves}
6DDD CJK UNIFIED IDEOGRAPH-#6DDD, IRGKangXi=0630.070, RSKangXi=85.8, Def{name of an affluent of the Poyang Lake}
6DDE CJK UNIFIED IDEOGRAPH-#6DDE, IRGKangXi=0630.090, RSKangXi=85.8, Def{name of a river in Jiangsu}
6DDF CJK UNIFIED IDEOGRAPH-#6DDF, IRGKangXi=0630.120, RSKangXi=85.8, Def{turbid; muddy}
6DE0 CJK UNIFIED IDEOGRAPH-#6DE0, IRGKangXi=0630.130, RSKangXi=85.8
6DE1 CJK UNIFIED IDEOGRAPH-#6DE1, IRGKangXi=0630.180, RSKangXi=85.8, Def{weak, watery; insipid, tasteless}
6DE2 CJK UNIFIED IDEOGRAPH-#6DE2, IRGKangXi=0630.200, RSKangXi=85.8, Def{ditch}
6DE3 CJK UNIFIED IDEOGRAPH-#6DE3, IRGKangXi=0630.220, RSKangXi=85.8
6DE4 CJK UNIFIED IDEOGRAPH-#6DE4, IRGKangXi=0630.230, RSKangXi=85.8, Def{mud, sediment; clog up, silt up}
6DE5 CJK UNIFIED IDEOGRAPH-#6DE5, IRGKangXi=0630.240, RSKangXi=85.8, Def{strain; (Cant.) to scald}
6DE6 CJK UNIFIED IDEOGRAPH-#6DE6, IRGKangXi=0630.250, RSKangXi=85.8, Def{river in Jiangxi province; water leaking into a boat}
6DE7 CJK UNIFIED IDEOGRAPH-#6DE7, IRGKangXi=0630.260, RSKangXi=85.8
6DE8 CJK UNIFIED IDEOGRAPH-#6DE8, IRGKangXi=0630.270, RSKangXi=85.8, Def{pure, clean, unspoiled}
6DE9 CJK UNIFIED IDEOGRAPH-#6DE9, IRGKangXi=0631.010, RSKangXi=85.8, Def{pass over, cross, traverse}
6DEA CJK UNIFIED IDEOGRAPH-#6DEA, IRGKangXi=0631.060, RSKangXi=85.8, Def{be lost; sink, be submerged}
6DEB CJK UNIFIED IDEOGRAPH-#6DEB, IRGKangXi=0631.090, RSKangXi=85.8, Def{obscene, licentious, lewd}
6DEC CJK UNIFIED IDEOGRAPH-#6DEC, IRGKangXi=0631.110, RSKangXi=85.8, Def{temper; dye; soak; change, alter}
6DED CJK UNIFIED IDEOGRAPH-#6DED, IRGKangXi=0631.120, RSKangXi=85.8
6DEE CJK UNIFIED IDEOGRAPH-#6DEE, IRGKangXi=0631.140, RSKangXi=85.8, Def{river in Anhui province}
6DEF CJK UNIFIED IDEOGRAPH-#6DEF, IRGKangXi=0631.150, RSKangXi=85.8, Def{name of river; old name of Baihe in Henan}
6DF0 CJK UNIFIED IDEOGRAPH-#6DF0, IRGKangXi=0631.170, RSKangXi=85.8, Def{fish; still; (Cant.) thoroughly soaked; a deep sleep}
6DF1 CJK UNIFIED IDEOGRAPH-#6DF1, IRGKangXi=0632.010, RSKangXi=85.8, Def{deep; depth; far; very, extreme}
6DF2 CJK UNIFIED IDEOGRAPH-#6DF2, IRGKangXi=0632.040, RSKangXi=85.8
6DF3 CJK UNIFIED IDEOGRAPH-#6DF3, IRGKangXi=0632.050, RSKangXi=85.8, Def{honest, simple, unsophisticated; cyanogen; ethane dinitrile}
6DF4 CJK UNIFIED IDEOGRAPH-#6DF4, IRGKangXi=0632.070, RSKangXi=85.8
6DF5 CJK UNIFIED IDEOGRAPH-#6DF5, IRGKangXi=0632.080, RSKangXi=85.8, Def{gulf, abyss, deep}
6DF6 CJK UNIFIED IDEOGRAPH-#6DF6, IRGKangXi=0632.130, RSKangXi=85.8, Def{river in Hebei province; creek}
6DF7 CJK UNIFIED IDEOGRAPH-#6DF7, IRGKangXi=0632.140, RSKangXi=85.8, Def{to mix, blend, mingle; to bumble along}
6DF8 CJK UNIFIED IDEOGRAPH-#6DF8, IRGKangXi=0632.150, RSKangXi=85.8, Def{clear}
6DF9 CJK UNIFIED IDEOGRAPH-#6DF9, IRGKangXi=0632.170, RSKangXi=85.8, Def{drown; cover with liquid, steep}
6DFA CJK UNIFIED IDEOGRAPH-#6DFA, IRGKangXi=0632.180, RSKangXi=85.8, Def{shallow, not deep; superficial}
6DFB CJK UNIFIED IDEOGRAPH-#6DFB, IRGKangXi=0632.190, RSKangXi=85.8, Def{append, add to; increase}
6DFC CJK UNIFIED IDEOGRAPH-#6DFC, IRGKangXi=0632.200, RSKangXi=85.8, Def{a wide expanse of water}
6DFD CJK UNIFIED IDEOGRAPH-#6DFD, IRGKangXi=0633.020, RSKangXi=85.8
6DFE CJK UNIFIED IDEOGRAPH-#6DFE, IRGKangXi=0633.080, RSKangXi=85.8
6DFF CJK UNIFIED IDEOGRAPH-#6DFF, IRGKangXi=0633.100, RSKangXi=85.8
6E00 CJK UNIFIED IDEOGRAPH-#6E00, IRGKangXi=0633.160, RSKangXi=85.8
6E01 CJK UNIFIED IDEOGRAPH-#6E01, IRGKangXi=0633.210, RSKangXi=85.8
6E02 CJK UNIFIED IDEOGRAPH-#6E02, IRGKangXi=0633.240, RSKangXi=85.8
6E03 CJK UNIFIED IDEOGRAPH-#6E03, IRGKangXi=0633.270, RSKangXi=85.9
6E04 CJK UNIFIED IDEOGRAPH-#6E04, IRGKangXi=0633.360, RSKangXi=85.8
6E05 CJK UNIFIED IDEOGRAPH-#6E05, IRGKangXi=0633.371, RSKangXi=85.8, Def{clear, pure, clean; peaceful}
6E06 CJK UNIFIED IDEOGRAPH-#6E06, IRGKangXi=0633.371, RSKangXi=85.8
6E07 CJK UNIFIED IDEOGRAPH-#6E07, IRGKangXi=0633.371, RSKangXi=85.8, Def{thirsty}
6E08 CJK UNIFIED IDEOGRAPH-#6E08, IRGKangXi=0633.371, RSKangXi=85.8, Def{help, aid, relieve; ferry, cross}
6E09 CJK UNIFIED IDEOGRAPH-#6E09, IRGKangXi=0633.371, RSKangXi=85.8, Def{ford stream}
6E0A CJK UNIFIED IDEOGRAPH-#6E0A, IRGKangXi=0633.371, RSKangXi=85.8, Def{surge up, bubble up, gush forth}
6E0B CJK UNIFIED IDEOGRAPH-#6E0B, IRGKangXi=0633.371, RSKangXi=85.8, Def{astringent; harsh; uneven, rough}
6E0C CJK UNIFIED IDEOGRAPH-#6E0C, IRGKangXi=0633.371, RSKangXi=85.8, Def{strain}
6E0D CJK UNIFIED IDEOGRAPH-#6E0D, IRGKangXi=0633.371, RSKangXi=85.8, Def{soak, steep; dye; stains; sodden}
6E0E CJK UNIFIED IDEOGRAPH-#6E0E, IRGKangXi=0633.371, RSKangXi=85.8, Def{ditch, sluice, gutter, drain}
6E0F CJK UNIFIED IDEOGRAPH-#6E0F, IRGKangXi=0633.371, RSKangXi=85.8
6E10 CJK UNIFIED IDEOGRAPH-#6E10, IRGKangXi=0633.371, RSKangXi=85.8, Def{gradually}
6E11 CJK UNIFIED IDEOGRAPH-#6E11, IRGKangXi=0633.371, RSKangXi=85.8, Def{name of a river in Shandong}
6E12 CJK UNIFIED IDEOGRAPH-#6E12, IRGKangXi=0633.371, RSKangXi=85.8
6E13 CJK UNIFIED IDEOGRAPH-#6E13, IRGKangXi=0633.371, RSKangXi=85.8, Def{mountain stream, creek}
6E14 CJK UNIFIED IDEOGRAPH-#6E14, IRGKangXi=0633.371, RSKangXi=85.8, Def{to fish; seize; pursue; surname}
6E15 CJK UNIFIED IDEOGRAPH-#6E15, IRGKangXi=0633.371, RSKangXi=85.8, Def{surge up, bubble up, gush forth}
6E16 CJK UNIFIED IDEOGRAPH-#6E16, IRGKangXi=0633.371, RSKangXi=85.8, Def{juice; liquid; water; to leak, pour}
6E17 CJK UNIFIED IDEOGRAPH-#6E17, IRGKangXi=0633.371, RSKangXi=85.8, Def{soak through, infiltrate}
6E18 CJK UNIFIED IDEOGRAPH-#6E18, IRGKangXi=0633.380, RSKangXi=85.9
6E19 CJK UNIFIED IDEOGRAPH-#6E19, IRGKangXi=0633.400, RSKangXi=85.9, Def{scatter; scattered, dispersed}
6E1A CJK UNIFIED IDEOGRAPH-#6E1A, IRGKangXi=0633.410, RSKangXi=85.8, Def{small sand bank, islet}
6E1B CJK UNIFIED IDEOGRAPH-#6E1B, IRGKangXi=0633.420, RSKangXi=85.9, Def{decrease, subtract, diminish}
6E1C CJK UNIFIED IDEOGRAPH-#6E1C, IRGKangXi=0633.430, RSKangXi=85.9
6E1D CJK UNIFIED IDEOGRAPH-#6E1D, IRGKangXi=0633.450, RSKangXi=85.9, Def{change; chongqing}
6E1E CJK UNIFIED IDEOGRAPH-#6E1E, IRGKangXi=0633.460, RSKangXi=85.9
6E1F CJK UNIFIED IDEOGRAPH-#6E1F, IRGKangXi=0633.470, RSKangXi=85.9, Def{(of water) not flowing; clear}
6E20 CJK UNIFIED IDEOGRAPH-#6E20, IRGKangXi=0633.480, RSKangXi=85.9, Def{ditch, canal, channel, gutter}
6E21 CJK UNIFIED IDEOGRAPH-#6E21, IRGKangXi=0634.010, RSKangXi=85.9, Def{cross, ferry over; ferry}
6E22 CJK UNIFIED IDEOGRAPH-#6E22, IRGKangXi=0634.020, RSKangXi=85.9, Def{pleasant sound}
6E23 CJK UNIFIED IDEOGRAPH-#6E23, IRGKangXi=0634.030, RSKangXi=85.9, Def{refuse, dregs, lees, sediment}
6E24 CJK UNIFIED IDEOGRAPH-#6E24, IRGKangXi=0634.050, RSKangXi=85.9, Def{swelling; the Gulf of Hopei (Hebei)}
6E25 CJK UNIFIED IDEOGRAPH-#6E25, IRGKangXi=0634.060, RSKangXi=85.9, Def{moisten, soak; great, deep; dye; to enrich}
6E26 CJK UNIFIED IDEOGRAPH-#6E26, IRGKangXi=0634.070, RSKangXi=85.9, Def{swirl, whirlpool, eddy}
6E27 CJK UNIFIED IDEOGRAPH-#6E27, IRGKangXi=0634.080, RSKangXi=85.9, Def{to drop, as liquids; a drop}
6E28 CJK UNIFIED IDEOGRAPH-#6E28, IRGKangXi=0634.090, RSKangXi=85.9, Def{a cove, a bay; a bend or nook in the hills; the curve of a bow}
6E29 CJK UNIFIED IDEOGRAPH-#6E29, IRGKangXi=0634.100, RSKangXi=85.9, Def{lukewarm}
6E2A CJK UNIFIED IDEOGRAPH-#6E2A, IRGKangXi=0634.120, RSKangXi=85.9
6E2B CJK UNIFIED IDEOGRAPH-#6E2B, IRGKangXi=0634.140, RSKangXi=85.9, Def{beating of ocean; surging of water}
6E2C CJK UNIFIED IDEOGRAPH-#6E2C, IRGKangXi=0635.010, RSKangXi=85.9, Def{measure, estimate, conjecture}
6E2D CJK UNIFIED IDEOGRAPH-#6E2D, IRGKangXi=0635.020, RSKangXi=85.9, Def{name of a river in Shanxi}
6E2E CJK UNIFIED IDEOGRAPH-#6E2E, IRGKangXi=0635.030, RSKangXi=85.9, Def{river in Shandong province}
6E2F CJK UNIFIED IDEOGRAPH-#6E2F, IRGKangXi=0635.040, RSKangXi=85.9, Def{port, harbor; small stream; bay}
6E30 CJK UNIFIED IDEOGRAPH-#6E30, IRGKangXi=0635.050, RSKangXi=85.9, Def{(of cloud) forming or rising}
6E31 CJK UNIFIED IDEOGRAPH-#6E31, IRGKangXi=0635.060, RSKangXi=85.9
6E32 CJK UNIFIED IDEOGRAPH-#6E32, IRGKangXi=0635.070, RSKangXi=85.9, Def{add repeated washes of color}
6E33 CJK UNIFIED IDEOGRAPH-#6E33, IRGKangXi=0635.080, RSKangXi=85.9
6E34 CJK UNIFIED IDEOGRAPH-#6E34, IRGKangXi=0635.090, RSKangXi=85.9, Def{thirsty, parched; yearn, pine}
6E35 CJK UNIFIED IDEOGRAPH-#6E35, IRGKangXi=0635.110, RSKangXi=85.9
6E36 CJK UNIFIED IDEOGRAPH-#6E36, IRGKangXi=0635.120, RSKangXi=85.9
6E37 CJK UNIFIED IDEOGRAPH-#6E37, IRGKangXi=0635.130, RSKangXi=85.9
6E38 CJK UNIFIED IDEOGRAPH-#6E38, IRGKangXi=0635.140, RSKangXi=85.9, Def{to swim; float, drift; wander, roam}
6E39 CJK UNIFIED IDEOGRAPH-#6E39, IRGKangXi=0635.160, RSKangXi=85.9, Def{roar, crash}
6E3A CJK UNIFIED IDEOGRAPH-#6E3A, IRGKangXi=0635.170, RSKangXi=85.9, Def{endlessly long, boundless, vast}
6E3B CJK UNIFIED IDEOGRAPH-#6E3B, IRGKangXi=0635.180, RSKangXi=85.9
6E3C CJK UNIFIED IDEOGRAPH-#6E3C, IRGKangXi=0635.190, RSKangXi=85.9, Def{ripples}
6E3D CJK UNIFIED IDEOGRAPH-#6E3D, IRGKangXi=0635.200, RSKangXi=85.9
6E3E CJK UNIFIED IDEOGRAPH-#6E3E, IRGKangXi=0635.230, RSKangXi=85.9, Def{muddy, turbid; blend, merge, mix}
6E3F CJK UNIFIED IDEOGRAPH-#6E3F, IRGKangXi=0636.020, RSKangXi=85.9
6E40 CJK UNIFIED IDEOGRAPH-#6E40, IRGKangXi=0636.030, RSKangXi=85.9
6E41 CJK UNIFIED IDEOGRAPH-#6E41, IRGKangXi=0636.040, RSKangXi=85.9
6E42 CJK UNIFIED IDEOGRAPH-#6E42, IRGKangXi=0636.070, RSKangXi=85.9
6E43 CJK UNIFIED IDEOGRAPH-#6E43, IRGKangXi=0636.080, RSKangXi=85.9, Def{sound of waves; turbulent}
6E44 CJK UNIFIED IDEOGRAPH-#6E44, IRGKangXi=0636.090, RSKangXi=85.9, Def{water's edge, shore, bank}
6E45 CJK UNIFIED IDEOGRAPH-#6E45, IRGKangXi=0636.100, RSKangXi=85.9, Def{boil silk}
6E46 CJK UNIFIED IDEOGRAPH-#6E46, IRGKangXi=0636.110, RSKangXi=85.9, Def{(Cant.) sticky, not smooth, slow}
6E47 CJK UNIFIED IDEOGRAPH-#6E47, IRGKangXi=0636.120, RSKangXi=85.9
6E48 CJK UNIFIED IDEOGRAPH-#6E48, IRGKangXi=0636.150, RSKangXi=85.9
6E49 CJK UNIFIED IDEOGRAPH-#6E49, IRGKangXi=0636.210, RSKangXi=85.9
6E4A CJK UNIFIED IDEOGRAPH-#6E4A, IRGKangXi=0636.220, RSKangXi=85.9, Def{piece together, assemble}
6E4B CJK UNIFIED IDEOGRAPH-#6E4B, IRGKangXi=0636.230, RSKangXi=85.9, Def{river in Shanxi province}
6E4C CJK UNIFIED IDEOGRAPH-#6E4C, IRGKangXi=0636.240, RSKangXi=85.9
6E4D CJK UNIFIED IDEOGRAPH-#6E4D, IRGKangXi=0636.250, RSKangXi=85.9, Def{rapid water current, rapids}
6E4E CJK UNIFIED IDEOGRAPH-#6E4E, IRGKangXi=0636.260, RSKangXi=85.9, Def{flushed with drink, drunk}
6E4F CJK UNIFIED IDEOGRAPH-#6E4F, IRGKangXi=0636.270, RSKangXi=85.9, Def{wash face; erroneously borrowed for DKW 43352 'necessary, must'}
6E50 CJK UNIFIED IDEOGRAPH-#6E50, IRGKangXi=0636.280, RSKangXi=85.9
6E51 CJK UNIFIED IDEOGRAPH-#6E51, IRGKangXi=0636.290, RSKangXi=85.9, Def{to strain spirits; river in Guangxi; abundant; bright}
6E52 CJK UNIFIED IDEOGRAPH-#6E52, IRGKangXi=0636.310, RSKangXi=85.9
6E53 CJK UNIFIED IDEOGRAPH-#6E53, IRGKangXi=0636.320, RSKangXi=85.9, Def{an affluent of the River Yangtze near Kiukiang}
6E54 CJK UNIFIED IDEOGRAPH-#6E54, IRGKangXi=0637.010, RSKangXi=85.9, Def{wash, cleanse; purge}
6E55 CJK UNIFIED IDEOGRAPH-#6E55, IRGKangXi=0637.030, RSKangXi=85.9
6E56 CJK UNIFIED IDEOGRAPH-#6E56, IRGKangXi=0637.040, RSKangXi=85.9, Def{a lake; Hubei, Hunan; bluish-green}
6E57 CJK UNIFIED IDEOGRAPH-#6E57, IRGKangXi=0637.050, RSKangXi=85.9
6E58 CJK UNIFIED IDEOGRAPH-#6E58, IRGKangXi=0637.110, RSKangXi=85.9, Def{Hunan province}
6E59 CJK UNIFIED IDEOGRAPH-#6E59, IRGKangXi=0637.120, RSKangXi=85.9
6E5A CJK UNIFIED IDEOGRAPH-#6E5A, IRGKangXi=0637.150, RSKangXi=85.9
6E5B CJK UNIFIED IDEOGRAPH-#6E5B, IRGKangXi=0637.160, RSKangXi=85.9, Def{deep; profound; clear; tranquil, placid}
6E5C CJK UNIFIED IDEOGRAPH-#6E5C, IRGKangXi=0637.180, RSKangXi=85.9, Def{transparent, clear}
6E5D CJK UNIFIED IDEOGRAPH-#6E5D, IRGKangXi=0637.190, RSKangXi=85.9, Def{flow}
6E5E CJK UNIFIED IDEOGRAPH-#6E5E, IRGKangXi=0637.200, RSKangXi=85.9, Def{river in Guangdong province}
6E5F CJK UNIFIED IDEOGRAPH-#6E5F, IRGKangXi=0637.210, RSKangXi=85.9, Def{river in qinghai province}
6E60 CJK UNIFIED IDEOGRAPH-#6E60, IRGKangXi=0637.220, RSKangXi=85.9
6E61 CJK UNIFIED IDEOGRAPH-#6E61, IRGKangXi=0637.230, RSKangXi=85.9
6E62 CJK UNIFIED IDEOGRAPH-#6E62, IRGKangXi=0637.240, RSKangXi=85.9, Def{bathroom; neat; orderly}
6E63 CJK UNIFIED IDEOGRAPH-#6E63, IRGKangXi=0637.250, RSKangXi=85.9, Def{mixed, confused; pity}
6E64 CJK UNIFIED IDEOGRAPH-#6E64, IRGKangXi=0637.260, RSKangXi=85.9
6E65 CJK UNIFIED IDEOGRAPH-#6E65, IRGKangXi=0637.270, RSKangXi=85.9
6E66 CJK UNIFIED IDEOGRAPH-#6E66, IRGKangXi=0638.030, RSKangXi=85.9
6E67 CJK UNIFIED IDEOGRAPH-#6E67, IRGKangXi=0638.050, RSKangXi=85.9, Def{well up; gush forth; rise}
6E68 CJK UNIFIED IDEOGRAPH-#6E68, IRGKangXi=0638.060, RSKangXi=85.9
6E69 CJK UNIFIED IDEOGRAPH-#6E69, IRGKangXi=0638.070, RSKangXi=85.9, Def{muddy, turbid; milk}
6E6A CJK UNIFIED IDEOGRAPH-#6E6A, IRGKangXi=0638.090, RSKangXi=85.9
6E6B CJK UNIFIED IDEOGRAPH-#6E6B, IRGKangXi=0638.100, RSKangXi=85.9, Def{a small pond; a damp and narrow place}
6E6C CJK UNIFIED IDEOGRAPH-#6E6C, IRGKangXi=0638.110, RSKangXi=85.9
6E6D CJK UNIFIED IDEOGRAPH-#6E6D, IRGKangXi=0638.120, RSKangXi=85.9
6E6E CJK UNIFIED IDEOGRAPH-#6E6E, IRGKangXi=0638.150, RSKangXi=85.9, Def{bury, sink, block up; stain}
6E6F CJK UNIFIED IDEOGRAPH-#6E6F, IRGKangXi=0638.160, RSKangXi=85.9, Def{hot water; soup, gravy, broth}
6E70 CJK UNIFIED IDEOGRAPH-#6E70, IRGKangXi=0638.170, RSKangXi=85.9
6E71 CJK UNIFIED IDEOGRAPH-#6E71, IRGKangXi=0638.180, RSKangXi=85.9, Def{sound of water}
6E72 CJK UNIFIED IDEOGRAPH-#6E72, IRGKangXi=0638.190, RSKangXi=85.9, Def{flow}
6E73 CJK UNIFIED IDEOGRAPH-#6E73, IRGKangXi=0638.200, RSKangXi=85.9
6E74 CJK UNIFIED IDEOGRAPH-#6E74, IRGKangXi=0638.210, RSKangXi=85.8, Def{(Cant.) mud, mire}
6E75 CJK UNIFIED IDEOGRAPH-#6E75, IRGKangXi=0638.260, RSKangXi=85.9
6E76 CJK UNIFIED IDEOGRAPH-#6E76, IRGKangXi=0638.340, RSKangXi=85.9
6E77 CJK UNIFIED IDEOGRAPH-#6E77, IRGKangXi=0639.050, RSKangXi=85.9
6E78 CJK UNIFIED IDEOGRAPH-#6E78, IRGKangXi=0639.111, RSKangXi=85.9
6E79 CJK UNIFIED IDEOGRAPH-#6E79, IRGKangXi=0639.111, RSKangXi=85.9
6E7A CJK UNIFIED IDEOGRAPH-#6E7A, IRGKangXi=0639.111, RSKangXi=85.9
6E7B CJK UNIFIED IDEOGRAPH-#6E7B, IRGKangXi=0639.111, RSKangXi=85.9, Def{pure, unmixed, genuine; honest}
6E7C CJK UNIFIED IDEOGRAPH-#6E7C, IRGKangXi=0639.111, RSKangXi=85.9, Def{black mud; slime}
6E7D CJK UNIFIED IDEOGRAPH-#6E7D, IRGKangXi=0639.111, RSKangXi=85.9
6E7E CJK UNIFIED IDEOGRAPH-#6E7E, IRGKangXi=0639.111, RSKangXi=85.9, Def{bay, cove, inlet, bend of stream}
6E7F CJK UNIFIED IDEOGRAPH-#6E7F, IRGKangXi=0639.111, RSKangXi=85.9, Def{wet, moist, humid, damp; illness}
6E80 CJK UNIFIED IDEOGRAPH-#6E80, IRGKangXi=0639.111, RSKangXi=85.9, Def{fullness, enough; pride}
6E81 CJK UNIFIED IDEOGRAPH-#6E81, IRGKangXi=0639.111, RSKangXi=85.14
6E82 CJK UNIFIED IDEOGRAPH-#6E82, IRGKangXi=0639.111, RSKangXi=85.9
6E83 CJK UNIFIED IDEOGRAPH-#6E83, IRGKangXi=0639.111, RSKangXi=85.9, Def{flooding river; militarily defeat}
6E84 CJK UNIFIED IDEOGRAPH-#6E84, IRGKangXi=0639.111, RSKangXi=85.9
6E85 CJK UNIFIED IDEOGRAPH-#6E85, IRGKangXi=0639.111, RSKangXi=85.9, Def{sprinkle, spray; spill, splash}
6E86 CJK UNIFIED IDEOGRAPH-#6E86, IRGKangXi=0639.111, RSKangXi=85.9, Def{river in Hunan}
6E87 CJK UNIFIED IDEOGRAPH-#6E87, IRGKangXi=0639.111, RSKangXi=85.11
6E88 CJK UNIFIED IDEOGRAPH-#6E88, IRGKangXi=0639.111, RSKangXi=85.9, Def{name of a river in Shanxi}
6E89 CJK UNIFIED IDEOGRAPH-#6E89, IRGKangXi=0639.111, RSKangXi=85.9, Def{water, irrigate, flood; wash}
6E8A CJK UNIFIED IDEOGRAPH-#6E8A, IRGKangXi=0639.111, RSKangXi=85.9
6E8B CJK UNIFIED IDEOGRAPH-#6E8B, IRGKangXi=0639.111, RSKangXi=85.9
6E8C CJK UNIFIED IDEOGRAPH-#6E8C, IRGKangXi=0639.111, RSKangXi=85.9, Def{pour, splash, water, sprinkle}
6E8D CJK UNIFIED IDEOGRAPH-#6E8D, IRGKangXi=0639.120, RSKangXi=85.10, Def{water}
6E8E CJK UNIFIED IDEOGRAPH-#6E8E, IRGKangXi=0639.130, RSKangXi=85.10, Def{river in Guangxi province}
6E8F CJK UNIFIED IDEOGRAPH-#6E8F, IRGKangXi=0639.150, RSKangXi=85.10, Def{pool; not hardened, semi-soft}
6E90 CJK UNIFIED IDEOGRAPH-#6E90, IRGKangXi=0639.160, RSKangXi=85.10, Def{spring; source, head; surname}
6E91 CJK UNIFIED IDEOGRAPH-#6E91, IRGKangXi=0639.170, RSKangXi=85.10
6E92 CJK UNIFIED IDEOGRAPH-#6E92, IRGKangXi=0639.180, RSKangXi=85.10
6E93 CJK UNIFIED IDEOGRAPH-#6E93, IRGKangXi=0639.190, RSKangXi=85.10
6E94 CJK UNIFIED IDEOGRAPH-#6E94, IRGKangXi=0639.200, RSKangXi=85.10
6E95 CJK UNIFIED IDEOGRAPH-#6E95, IRGKangXi=0639.220, RSKangXi=85.10
6E96 CJK UNIFIED IDEOGRAPH-#6E96, IRGKangXi=0639.240, RSKangXi=85.10, Def{rule, guideline, standard}
6E97 CJK UNIFIED IDEOGRAPH-#6E97, IRGKangXi=0639.250, RSKangXi=85.10
6E98 CJK UNIFIED IDEOGRAPH-#6E98, IRGKangXi=0639.260, RSKangXi=85.10, Def{abruptly, suddenly, unexpectedly}
6E99 CJK UNIFIED IDEOGRAPH-#6E99, IRGKangXi=0639.270, RSKangXi=85.10
6E9A CJK UNIFIED IDEOGRAPH-#6E9A, IRGKangXi=0639.310, Def{(Cant.) to get wet by rain; to drip}
6E9B CJK UNIFIED IDEOGRAPH-#6E9B, IRGKangXi=0639.320, RSKangXi=85.10
6E9C CJK UNIFIED IDEOGRAPH-#6E9C, IRGKangXi=0639.330, RSKangXi=85.10, Def{slide, glide, slip; slippery}
6E9D CJK UNIFIED IDEOGRAPH-#6E9D, IRGKangXi=0639.340, RSKangXi=85.10, Def{ditch, drain, narrow waterway}
6E9E CJK UNIFIED IDEOGRAPH-#6E9E, IRGKangXi=0639.350, RSKangXi=85.10
6E9F CJK UNIFIED IDEOGRAPH-#6E9F, IRGKangXi=0640.020, RSKangXi=85.10, Def{drizzling rain; dark, obscure}
6EA0 CJK UNIFIED IDEOGRAPH-#6EA0, IRGKangXi=0640.030, RSKangXi=85.10, Def{river in Hubei province}
6EA1 CJK UNIFIED IDEOGRAPH-#6EA1, IRGKangXi=0640.040, RSKangXi=85.10
6EA2 CJK UNIFIED IDEOGRAPH-#6EA2, IRGKangXi=0640.060, RSKangXi=85.10, Def{overflow, brim over; full}
6EA3 CJK UNIFIED IDEOGRAPH-#6EA3, IRGKangXi=0640.100, RSKangXi=85.10
6EA4 CJK UNIFIED IDEOGRAPH-#6EA4, IRGKangXi=0640.110, RSKangXi=85.10
6EA5 CJK UNIFIED IDEOGRAPH-#6EA5, IRGKangXi=0640.120, RSKangXi=85.10, Def{big, great, vast, wide; widespread}
6EA6 CJK UNIFIED IDEOGRAPH-#6EA6, IRGKangXi=0640.140, RSKangXi=85.10, Def{drizzle; (variant) valley; (variant) mold}
6EA7 CJK UNIFIED IDEOGRAPH-#6EA7, IRGKangXi=0640.150, RSKangXi=85.10, Def{river in Anhui and Jiangsu provinces}
6EA8 CJK UNIFIED IDEOGRAPH-#6EA8, IRGKangXi=0640.170, RSKangXi=85.10
6EA9 CJK UNIFIED IDEOGRAPH-#6EA9, IRGKangXi=0640.190, RSKangXi=85.10
6EAA CJK UNIFIED IDEOGRAPH-#6EAA, IRGKangXi=0640.220, RSKangXi=85.10, Def{mountain stream, creek}
6EAB CJK UNIFIED IDEOGRAPH-#6EAB, IRGKangXi=0640.230, RSKangXi=85.10, Def{lukewarm, warm; tepid, mild}
6EAC CJK UNIFIED IDEOGRAPH-#6EAC, IRGKangXi=0640.250, RSKangXi=85.10
6EAD CJK UNIFIED IDEOGRAPH-#6EAD, IRGKangXi=0640.260, RSKangXi=85.10
6EAE CJK UNIFIED IDEOGRAPH-#6EAE, IRGKangXi=0640.270, RSKangXi=85.10, Def{river in Henan province}
6EAF CJK UNIFIED IDEOGRAPH-#6EAF, IRGKangXi=0640.300, RSKangXi=85.10, Def{go upstream, go against current; formerly}
6EB0 CJK UNIFIED IDEOGRAPH-#6EB0, IRGKangXi=0640.310, RSKangXi=85.10
6EB1 CJK UNIFIED IDEOGRAPH-#6EB1, IRGKangXi=0640.330, RSKangXi=85.10, Def{river in Henan}
6EB2 CJK UNIFIED IDEOGRAPH-#6EB2, IRGKangXi=0640.340, RSKangXi=85.10, Def{urinate; soak, drench}
6EB3 CJK UNIFIED IDEOGRAPH-#6EB3, IRGKangXi=0641.010, RSKangXi=85.10
6EB4 CJK UNIFIED IDEOGRAPH-#6EB4, IRGKangXi=0641.020, RSKangXi=85.10, Def{bromine}
6EB5 CJK UNIFIED IDEOGRAPH-#6EB5, IRGKangXi=0641.030, RSKangXi=85.10
6EB6 CJK UNIFIED IDEOGRAPH-#6EB6, IRGKangXi=0641.040, RSKangXi=85.10, Def{to melt, dissolve; overflowing with}
6EB7 CJK UNIFIED IDEOGRAPH-#6EB7, IRGKangXi=0641.070, RSKangXi=85.10, Def{privy, latrine; turbid, dirty}
6EB8 CJK UNIFIED IDEOGRAPH-#6EB8, IRGKangXi=0641.080, RSKangXi=85.10
6EB9 CJK UNIFIED IDEOGRAPH-#6EB9, IRGKangXi=0641.100, RSKangXi=85.10
6EBA CJK UNIFIED IDEOGRAPH-#6EBA, IRGKangXi=0641.110, RSKangXi=85.10, Def{drown; submerge in water; indulge}
6EBB CJK UNIFIED IDEOGRAPH-#6EBB, IRGKangXi=0641.130, RSKangXi=85.10, Def{wet}
6EBC CJK UNIFIED IDEOGRAPH-#6EBC, IRGKangXi=0641.140, RSKangXi=85.10, Def{damp, moist; dampness, moisture}
6EBD CJK UNIFIED IDEOGRAPH-#6EBD, IRGKangXi=0641.180, RSKangXi=85.10, Def{moist, humid, muggy}
6EBE CJK UNIFIED IDEOGRAPH-#6EBE, IRGKangXi=0641.190, RSKangXi=85.10
6EBF CJK UNIFIED IDEOGRAPH-#6EBF, IRGKangXi=0641.200, RSKangXi=85.10
6EC0 CJK UNIFIED IDEOGRAPH-#6EC0, IRGKangXi=0641.210, RSKangXi=85.10
6EC1 CJK UNIFIED IDEOGRAPH-#6EC1, IRGKangXi=0641.240, RSKangXi=85.10, Def{district in Anhui province}
6EC2 CJK UNIFIED IDEOGRAPH-#6EC2, IRGKangXi=0641.250, RSKangXi=85.10, Def{torrential; voluminous}
6EC3 CJK UNIFIED IDEOGRAPH-#6EC3, IRGKangXi=0641.260, RSKangXi=85.10, Def{swelling, rising, dispersing}
6EC4 CJK UNIFIED IDEOGRAPH-#6EC4, IRGKangXi=0641.290, RSKangXi=85.10, Def{blue, dark green; cold}
6EC5 CJK UNIFIED IDEOGRAPH-#6EC5, IRGKangXi=0642.010, RSKangXi=85.10, Def{extinguish; wipe out, exterminate}
6EC6 CJK UNIFIED IDEOGRAPH-#6EC6, IRGKangXi=0642.040, RSKangXi=85.10
6EC7 CJK UNIFIED IDEOGRAPH-#6EC7, IRGKangXi=0642.050, RSKangXi=85.10, Def{Yunnan province}
6EC8 CJK UNIFIED IDEOGRAPH-#6EC8, IRGKangXi=0642.090, RSKangXi=85.10
6EC9 CJK UNIFIED IDEOGRAPH-#6EC9, IRGKangXi=0642.110, RSKangXi=85.10, Def{deep}
6ECA CJK UNIFIED IDEOGRAPH-#6ECA, IRGKangXi=0642.130, RSKangXi=85.10, Def{a river name; a long rain}
6ECB CJK UNIFIED IDEOGRAPH-#6ECB, IRGKangXi=0642.150, RSKangXi=85.10, Def{grow, multiply, increase; thrive}
6ECC CJK UNIFIED IDEOGRAPH-#6ECC, IRGKangXi=0642.200, RSKangXi=85.11, Def{wash, cleanse, purify; sweep}
6ECD CJK UNIFIED IDEOGRAPH-#6ECD, IRGKangXi=0642.220, RSKangXi=85.10
6ECE CJK UNIFIED IDEOGRAPH-#6ECE, IRGKangXi=0642.230, RSKangXi=85.10, Def{county in Henan; rising and dashing of waves}
6ECF CJK UNIFIED IDEOGRAPH-#6ECF, IRGKangXi=0642.240, RSKangXi=85.10
6ED0 CJK UNIFIED IDEOGRAPH-#6ED0, IRGKangXi=0642.260, RSKangXi=85.10, Def{(Cant.) dense, thick, viscous}
6ED1 CJK UNIFIED IDEOGRAPH-#6ED1, IRGKangXi=0643.030, RSKangXi=85.10, Def{slip, slide; slippery, polished}
6ED2 CJK UNIFIED IDEOGRAPH-#6ED2, IRGKangXi=0643.040, RSKangXi=85.10
6ED3 CJK UNIFIED IDEOGRAPH-#6ED3, IRGKangXi=0643.050, RSKangXi=85.10, Def{sediment, lees, dregs}
6ED4 CJK UNIFIED IDEOGRAPH-#6ED4, IRGKangXi=0643.060, RSKangXi=85.10, Def{overflow; rushing water, a torrent}
6ED5 CJK UNIFIED IDEOGRAPH-#6ED5, IRGKangXi=0643.070, RSKangXi=85.10, Def{an ancient state in Shandong province; water bursting forth}
6ED6 CJK UNIFIED IDEOGRAPH-#6ED6, IRGKangXi=0643.160, RSKangXi=85.10
6ED7 CJK UNIFIED IDEOGRAPH-#6ED7, IRGKangXi=0643.190, RSKangXi=85.10, Def{drain}
6ED8 CJK UNIFIED IDEOGRAPH-#6ED8, IRGKangXi=0643.241, RSKangXi=85.10, Def{a branching river (used in place names)}
6ED9 CJK UNIFIED IDEOGRAPH-#6ED9, IRGKangXi=0643.241, RSKangXi=85.10, Def{waters converging to one spot; whirling waters; to remit money}
6EDA CJK UNIFIED IDEOGRAPH-#6EDA, IRGKangXi=0643.241, RSKangXi=85.11, Def{turn}
6EDB CJK UNIFIED IDEOGRAPH-#6EDB, IRGKangXi=0643.241, RSKangXi=85.10
6EDC CJK UNIFIED IDEOGRAPH-#6EDC, IRGKangXi=0643.241, RSKangXi=85.10
6EDD CJK UNIFIED IDEOGRAPH-#6EDD, IRGKangXi=0643.241, RSKangXi=85.10, Def{onomatopoeic for the sound of falling rain; an ancient name for Wu Shui; a place in Guangdong}
6EDE CJK UNIFIED IDEOGRAPH-#6EDE, IRGKangXi=0639.111, RSKangXi=85.9, Def{block up, obstruct; stagnant}
6EDF CJK UNIFIED IDEOGRAPH-#6EDF, IRGKangXi=0643.241, RSKangXi=85.10, Def{overflowing, billowing; wavy}
6EE0 CJK UNIFIED IDEOGRAPH-#6EE0, IRGKangXi=0643.241, RSKangXi=85.10, Def{river in Hubei province}
6EE1 CJK UNIFIED IDEOGRAPH-#6EE1, IRGKangXi=0643.241, RSKangXi=85.10, Def{fill; full, satisfied}
6EE2 CJK UNIFIED IDEOGRAPH-#6EE2, IRGKangXi=0643.241, RSKangXi=85.10, Def{clear, pure water; lucid; glossy}
6EE3 CJK UNIFIED IDEOGRAPH-#6EE3, IRGKangXi=0643.241, RSKangXi=85.10
6EE4 CJK UNIFIED IDEOGRAPH-#6EE4, IRGKangXi=0643.241, RSKangXi=85.10, Def{strain out, filter}
6EE5 CJK UNIFIED IDEOGRAPH-#6EE5, IRGKangXi=0643.241, RSKangXi=85.10, Def{flood, overflow; excessive}
6EE6 CJK UNIFIED IDEOGRAPH-#6EE6, IRGKangXi=0643.241, RSKangXi=85.10, Def{river and county in Hebei province}
6EE7 CJK UNIFIED IDEOGRAPH-#6EE7, IRGKangXi=0643.241, RSKangXi=85.10
6EE8 CJK UNIFIED IDEOGRAPH-#6EE8, IRGKangXi=0643.241, RSKangXi=85.10, Def{beach, sea coast; river bank}
6EE9 CJK UNIFIED IDEOGRAPH-#6EE9, IRGKangXi=0643.241, RSKangXi=85.10, Def{bank, a sandbar, shoal; rapids}
6EEA CJK UNIFIED IDEOGRAPH-#6EEA, IRGKangXi=0643.241, RSKangXi=85.13, Def{place in Sichuan}
6EEB CJK UNIFIED IDEOGRAPH-#6EEB, IRGKangXi=0643.250, RSKangXi=85.11, Def{water in which rice has been boiled}
6EEC CJK UNIFIED IDEOGRAPH-#6EEC, IRGKangXi=0643.260, RSKangXi=85.11, Def{Shanghai; river near Shanghai}
6EED CJK UNIFIED IDEOGRAPH-#6EED, IRGKangXi=0643.270, RSKangXi=85.11
6EEE CJK UNIFIED IDEOGRAPH-#6EEE, IRGKangXi=0643.280, RSKangXi=85.11, Def{flow; (Cant.) to ooze; to spurt}
6EEF CJK UNIFIED IDEOGRAPH-#6EEF, IRGKangXi=0643.290, RSKangXi=85.11, Def{block up, obstruct; stagnant}
6EF0 CJK UNIFIED IDEOGRAPH-#6EF0, IRGKangXi=0643.310, RSKangXi=85.11
6EF1 CJK UNIFIED IDEOGRAPH-#6EF1, IRGKangXi=0648.281, RSKangXi=85.11
6EF2 CJK UNIFIED IDEOGRAPH-#6EF2, IRGKangXi=0643.350, RSKangXi=85.11, Def{soak through, infiltrate}
6EF3 CJK UNIFIED IDEOGRAPH-#6EF3, IRGKangXi=0644.020, RSKangXi=85.11
6EF4 CJK UNIFIED IDEOGRAPH-#6EF4, IRGKangXi=0644.030, RSKangXi=85.11, Def{drip; drop of water}
6EF5 CJK UNIFIED IDEOGRAPH-#6EF5, IRGKangXi=0644.040, RSKangXi=85.11
6EF6 CJK UNIFIED IDEOGRAPH-#6EF6, IRGKangXi=0644.060, RSKangXi=85.11
6EF7 CJK UNIFIED IDEOGRAPH-#6EF7, IRGKangXi=0644.070, RSKangXi=85.11, Def{thick gravy, sauce, broth; brine}
6EF8 CJK UNIFIED IDEOGRAPH-#6EF8, IRGKangXi=0644.080, RSKangXi=85.11, Def{riverbank, shore}
6EF9 CJK UNIFIED IDEOGRAPH-#6EF9, IRGKangXi=0644.110, RSKangXi=85.11, Def{the bank of a steam}
6EFA CJK UNIFIED IDEOGRAPH-#6EFA, IRGKangXi=0644.120, RSKangXi=85.11, Def{flow}
6EFB CJK UNIFIED IDEOGRAPH-#6EFB, IRGKangXi=0644.140, RSKangXi=85.11
6EFC CJK UNIFIED IDEOGRAPH-#6EFC, IRGKangXi=0644.150, RSKangXi=85.11
6EFD CJK UNIFIED IDEOGRAPH-#6EFD, IRGKangXi=0644.160, RSKangXi=85.11
6EFE CJK UNIFIED IDEOGRAPH-#6EFE, IRGKangXi=0644.170, RSKangXi=85.11, Def{turn, roll, rotate; boil}
6EFF CJK UNIFIED IDEOGRAPH-#6EFF, IRGKangXi=0644.180, RSKangXi=85.11, Def{fill; full, satisfied}
6F00 CJK UNIFIED IDEOGRAPH-#6F00, IRGKangXi=0644.200, RSKangXi=85.11
6F01 CJK UNIFIED IDEOGRAPH-#6F01, IRGKangXi=0644.210, RSKangXi=85.11, Def{to fish; seize; pursue; surname}
6F02 CJK UNIFIED IDEOGRAPH-#6F02, IRGKangXi=0644.220, RSKangXi=85.11, Def{float, drift; tossed about}
6F03 CJK UNIFIED IDEOGRAPH-#6F03, IRGKangXi=0644.240, RSKangXi=85.11
6F04 CJK UNIFIED IDEOGRAPH-#6F04, IRGKangXi=0644.250, RSKangXi=85.11
6F05 CJK UNIFIED IDEOGRAPH-#6F05, IRGKangXi=0644.270, RSKangXi=85.11
6F06 CJK UNIFIED IDEOGRAPH-#6F06, IRGKangXi=0644.280, RSKangXi=85.11, AccountingNumeric=7, Def{varnish, lacquer, paint}
6F07 CJK UNIFIED IDEOGRAPH-#6F07, IRGKangXi=0645.020, RSKangXi=85.11, Def{(Cant.) waste}
6F08 CJK UNIFIED IDEOGRAPH-#6F08, IRGKangXi=0645.030, RSKangXi=85.11, Def{shore; waterside}
6F09 CJK UNIFIED IDEOGRAPH-#6F09, IRGKangXi=0645.040, RSKangXi=85.11, Def{filter, strain; wet, dripping}
6F0A CJK UNIFIED IDEOGRAPH-#6F0A, IRGKangXi=0645.050, RSKangXi=85.11, Def{river in Hubei province}
6F0B CJK UNIFIED IDEOGRAPH-#6F0B, IRGKangXi=0645.070, RSKangXi=85.12
6F0C CJK UNIFIED IDEOGRAPH-#6F0C, IRGKangXi=0645.080, RSKangXi=85.11
6F0D CJK UNIFIED IDEOGRAPH-#6F0D, IRGKangXi=0645.090, RSKangXi=85.11
6F0E CJK UNIFIED IDEOGRAPH-#6F0E, IRGKangXi=0645.120, RSKangXi=85.11, Def{a place where small streams flow into a large one}
6F0F CJK UNIFIED IDEOGRAPH-#6F0F, IRGKangXi=0645.130, RSKangXi=85.11, Def{leak, drip; funnel; hour glass}
6F10 CJK UNIFIED IDEOGRAPH-#6F10, IRGKangXi=0645.150, RSKangXi=85.11
6F11 CJK UNIFIED IDEOGRAPH-#6F11, IRGKangXi=0645.160, RSKangXi=85.11, Def{water}
6F12 CJK UNIFIED IDEOGRAPH-#6F12, IRGKangXi=0645.170, RSKangXi=85.11
6F13 CJK UNIFIED IDEOGRAPH-#6F13, IRGKangXi=0645.200, RSKangXi=85.10, Def{river in Guangxi province; water dripping}
6F14 CJK UNIFIED IDEOGRAPH-#6F14, IRGKangXi=0645.230, RSKangXi=85.11, Def{perform, put on; exercise}
6F15 CJK UNIFIED IDEOGRAPH-#6F15, IRGKangXi=0645.240, RSKangXi=85.11, Def{transport by water; canal transportation}
6F16 CJK UNIFIED IDEOGRAPH-#6F16, IRGKangXi=0645.250, RSKangXi=85.11, Def{(Cant.) a branching river (used in toponyms)}
6F17 CJK UNIFIED IDEOGRAPH-#6F17, IRGKangXi=0645.270, RSKangXi=85.11
6F18 CJK UNIFIED IDEOGRAPH-#6F18, IRGKangXi=0645.280, RSKangXi=85.11, Def{bank}
6F19 CJK UNIFIED IDEOGRAPH-#6F19, IRGKangXi=0645.290, RSKangXi=85.11, Def{dewy}
6F1A CJK UNIFIED IDEOGRAPH-#6F1A, IRGKangXi=0646.030, RSKangXi=85.11, Def{soak, steep; sodden, soaked; rotten; foam, froth}
6F1B CJK UNIFIED IDEOGRAPH-#6F1B, IRGKangXi=0646.040, RSKangXi=85.11
6F1C CJK UNIFIED IDEOGRAPH-#6F1C, IRGKangXi=0646.080, RSKangXi=85.11
6F1D CJK UNIFIED IDEOGRAPH-#6F1D, IRGKangXi=0646.100, RSKangXi=85.11
6F1E CJK UNIFIED IDEOGRAPH-#6F1E, IRGKangXi=0646.110, RSKangXi=85.11
6F1F CJK UNIFIED IDEOGRAPH-#6F1F, IRGKangXi=0646.120, RSKangXi=85.11
6F20 CJK UNIFIED IDEOGRAPH-#6F20, IRGKangXi=0646.130, RSKangXi=85.11, Def{desert; aloof, indifferent, cool}
6F21 CJK UNIFIED IDEOGRAPH-#6F21, IRGKangXi=0646.150, RSKangXi=85.11
6F22 CJK UNIFIED IDEOGRAPH-#6F22, IRGKangXi=0646.170, RSKangXi=85.11, Def{the Chinese people, Chinese language}
6F23 CJK UNIFIED IDEOGRAPH-#6F23, IRGKangXi=0646.210, RSKangXi=85.11, Def{flowing water; ripples; weeping}
6F24 CJK UNIFIED IDEOGRAPH-#6F24, IRGKangXi=0646.220, RSKangXi=85.11, Def{marinate in salt}
6F25 CJK UNIFIED IDEOGRAPH-#6F25, IRGKangXi=0646.240, RSKangXi=85.11, Def{puddle, hollow, swamp}
6F26 CJK UNIFIED IDEOGRAPH-#6F26, IRGKangXi=0646.260, RSKangXi=85.11, Def{saliva; spittle; flowing downstream}
6F27 CJK UNIFIED IDEOGRAPH-#6F27, IRGKangXi=0646.270, RSKangXi=85.11
6F28 CJK UNIFIED IDEOGRAPH-#6F28, IRGKangXi=0646.280, RSKangXi=85.11
6F29 CJK UNIFIED IDEOGRAPH-#6F29, IRGKangXi=0646.290, RSKangXi=85.11, Def{eddy, whirlpool}
6F2A CJK UNIFIED IDEOGRAPH-#6F2A, IRGKangXi=0646.300, RSKangXi=85.11, Def{ripples on water; swirling}
6F2B CJK UNIFIED IDEOGRAPH-#6F2B, IRGKangXi=0646.320, RSKangXi=85.11, Def{overflow of water; spreading}
6F2C CJK UNIFIED IDEOGRAPH-#6F2C, IRGKangXi=0647.010, RSKangXi=85.11, Def{soak, steep; dye; stains; sodden}
6F2D CJK UNIFIED IDEOGRAPH-#6F2D, IRGKangXi=0647.030, RSKangXi=85.11, Def{vast; expansive}
6F2E CJK UNIFIED IDEOGRAPH-#6F2E, IRGKangXi=0647.040, RSKangXi=85.11
6F2F CJK UNIFIED IDEOGRAPH-#6F2F, IRGKangXi=0647.050, RSKangXi=85.11, Def{river in northern Shandong}
6F30 CJK UNIFIED IDEOGRAPH-#6F30, IRGKangXi=0647.060, RSKangXi=85.11, Def{roar}
6F31 CJK UNIFIED IDEOGRAPH-#6F31, IRGKangXi=0647.070, RSKangXi=85.11, Def{gargle, rinse; wash, scour}
6F32 CJK UNIFIED IDEOGRAPH-#6F32, IRGKangXi=0647.080, RSKangXi=85.11, Def{rise in price}
6F33 CJK UNIFIED IDEOGRAPH-#6F33, IRGKangXi=0647.090, RSKangXi=85.11, Def{name of a river in Henan}
6F34 CJK UNIFIED IDEOGRAPH-#6F34, IRGKangXi=0647.100, RSKangXi=85.11
6F35 CJK UNIFIED IDEOGRAPH-#6F35, IRGKangXi=0647.110, RSKangXi=85.11, Def{river in Hunan}
6F36 CJK UNIFIED IDEOGRAPH-#6F36, IRGKangXi=0647.120, RSKangXi=85.11, Def{indecipherable}
6F37 CJK UNIFIED IDEOGRAPH-#6F37, IRGKangXi=0647.130, RSKangXi=85.11, Def{river in Hebei province}
6F38 CJK UNIFIED IDEOGRAPH-#6F38, IRGKangXi=0647.140, RSKangXi=85.11, Def{gradually}
6F39 CJK UNIFIED IDEOGRAPH-#6F39, IRGKangXi=0647.150, RSKangXi=85.11
6F3A CJK UNIFIED IDEOGRAPH-#6F3A, IRGKangXi=0648.010, RSKangXi=85.11
6F3B CJK UNIFIED IDEOGRAPH-#6F3B, IRGKangXi=0648.020, RSKangXi=85.11
6F3C CJK UNIFIED IDEOGRAPH-#6F3C, IRGKangXi=0648.030, RSKangXi=85.11, Def{having the appearance of depth}
6F3D CJK UNIFIED IDEOGRAPH-#6F3D, IRGKangXi=0648.040, RSKangXi=85.12
6F3E CJK UNIFIED IDEOGRAPH-#6F3E, IRGKangXi=0648.050, RSKangXi=85.11, Def{overflow; swirl, ripple; to be tosssed by waves}
6F3F CJK UNIFIED IDEOGRAPH-#6F3F, IRGKangXi=0648.070, RSKangXi=85.11, Def{any thick fluid; starch; broth}
6F40 CJK UNIFIED IDEOGRAPH-#6F40, IRGKangXi=0648.100, RSKangXi=85.11, Def{gather; flow into (water); sound of waters flowing together}
6F41 CJK UNIFIED IDEOGRAPH-#6F41, IRGKangXi=0648.110, RSKangXi=85.11, Def{river in Anhui}
6F42 CJK UNIFIED IDEOGRAPH-#6F42, IRGKangXi=0648.200, RSKangXi=85.11
6F43 CJK UNIFIED IDEOGRAPH-#6F43, IRGKangXi=0648.240, RSKangXi=85.11
6F44 CJK UNIFIED IDEOGRAPH-#6F44, IRGKangXi=0648.281, RSKangXi=85.11
6F45 CJK UNIFIED IDEOGRAPH-#6F45, IRGKangXi=0648.281, RSKangXi=85.11, Def{pour; water; irrigate, flood}
6F46 CJK UNIFIED IDEOGRAPH-#6F46, IRGKangXi=0648.281, RSKangXi=85.11, Def{tiny stream; swirl around}
6F47 CJK UNIFIED IDEOGRAPH-#6F47, IRGKangXi=0652.321, RSKangXi=85.11, Def{sound of beating wind and rain}
6F48 CJK UNIFIED IDEOGRAPH-#6F48, IRGKangXi=0648.281
6F49 CJK UNIFIED IDEOGRAPH-#6F49, IRGKangXi=0648.281, RSKangXi=85.11
6F4A CJK UNIFIED IDEOGRAPH-#6F4A, IRGKangXi=0648.281, RSKangXi=85.11
6F4B CJK UNIFIED IDEOGRAPH-#6F4B, IRGKangXi=0648.281, RSKangXi=85.11, Def{waves, ripples; overflow}
6F4C CJK UNIFIED IDEOGRAPH-#6F4C, IRGKangXi=0648.281
6F4D CJK UNIFIED IDEOGRAPH-#6F4D, IRGKangXi=0648.281, RSKangXi=85.11, Def{county in Shandong province}
6F4E CJK UNIFIED IDEOGRAPH-#6F4E, IRGKangXi=0648.290, RSKangXi=85.12, Def{rippling; pour}
6F4F CJK UNIFIED IDEOGRAPH-#6F4F, IRGKangXi=0648.300, RSKangXi=85.12, Def{land reclaimed from a wetlands/river, dike/embankment/man-made island}
6F50 CJK UNIFIED IDEOGRAPH-#6F50, IRGKangXi=0648.320, RSKangXi=85.12
6F51 CJK UNIFIED IDEOGRAPH-#6F51, IRGKangXi=0648.340, RSKangXi=85.12, Def{pour, splash, water, sprinkle; violent, malignant}
6F52 CJK UNIFIED IDEOGRAPH-#6F52, IRGKangXi=0648.350, RSKangXi=85.12
6F53 CJK UNIFIED IDEOGRAPH-#6F53, IRGKangXi=0648.370, RSKangXi=85.12
6F54 CJK UNIFIED IDEOGRAPH-#6F54, IRGKangXi=0648.400, RSKangXi=85.12, Def{clean, purify, pure}
6F55 CJK UNIFIED IDEOGRAPH-#6F55, IRGKangXi=0649.010, RSKangXi=85.12, Def{river in Henan}
6F56 CJK UNIFIED IDEOGRAPH-#6F56, IRGKangXi=0649.030, Def{name of a certain river}
6F57 CJK UNIFIED IDEOGRAPH-#6F57, IRGKangXi=0649.040, RSKangXi=85.12, Def{friendly; harmonious}
6F58 CJK UNIFIED IDEOGRAPH-#6F58, IRGKangXi=0649.050, RSKangXi=85.12, Def{surname; water in which rice has been rinsed; a river that flows into the Han}
6F59 CJK UNIFIED IDEOGRAPH-#6F59, IRGKangXi=0649.070, RSKangXi=85.12, Def{river in Shanxi}
6F5A CJK UNIFIED IDEOGRAPH-#6F5A, IRGKangXi=0649.080, RSKangXi=85.12, Def{gay; deep}
6F5B CJK UNIFIED IDEOGRAPH-#6F5B, IRGKangXi=0652.321, RSKangXi=85.12, Def{hide; hidden, secret, latent}
6F5C CJK UNIFIED IDEOGRAPH-#6F5C, IRGKangXi=0649.100, RSKangXi=85.12, Def{hide; hidden, secret, latent}
6F5D CJK UNIFIED IDEOGRAPH-#6F5D, IRGKangXi=0649.110, RSKangXi=85.12, Def{agree}
6F5E CJK UNIFIED IDEOGRAPH-#6F5E, IRGKangXi=0649.120, RSKangXi=85.12, Def{river in northern china}
6F5F CJK UNIFIED IDEOGRAPH-#6F5F, IRGKangXi=0649.160, RSKangXi=85.12, Def{land impregnated with salt from the tide}
6F60 CJK UNIFIED IDEOGRAPH-#6F60, IRGKangXi=0649.170, RSKangXi=85.12, Def{to blow out; to puff out}
6F61 CJK UNIFIED IDEOGRAPH-#6F61, IRGKangXi=0649.180, RSKangXi=85.12
6F62 CJK UNIFIED IDEOGRAPH-#6F62, IRGKangXi=0649.200, RSKangXi=85.12, Def{expanse of water, lake, pond}
6F63 CJK UNIFIED IDEOGRAPH-#6F63, IRGKangXi=0649.230, RSKangXi=85.12, Def{to pollute, contaminate}
6F64 CJK UNIFIED IDEOGRAPH-#6F64, IRGKangXi=0649.240, RSKangXi=85.12, Def{soft, moist; sleek; freshen}
6F65 CJK UNIFIED IDEOGRAPH-#6F65, IRGKangXi=0649.250, RSKangXi=85.12
6F66 CJK UNIFIED IDEOGRAPH-#6F66, IRGKangXi=0650.010, RSKangXi=85.12, Def{to flood; a puddle; without care}
6F67 CJK UNIFIED IDEOGRAPH-#6F67, IRGKangXi=0650.020, RSKangXi=85.12
6F68 CJK UNIFIED IDEOGRAPH-#6F68, IRGKangXi=0650.040, RSKangXi=85.12, Def{gather; flow into (water); sound of waters flowing together}
6F69 CJK UNIFIED IDEOGRAPH-#6F69, IRGKangXi=0650.070, RSKangXi=85.12
6F6A CJK UNIFIED IDEOGRAPH-#6F6A, IRGKangXi=0650.090, RSKangXi=85.12
6F6B CJK UNIFIED IDEOGRAPH-#6F6B, IRGKangXi=0650.100, RSKangXi=85.12
6F6C CJK UNIFIED IDEOGRAPH-#6F6C, IRGKangXi=0650.120, RSKangXi=85.12, Def{a rapid; a sand-bank; a foreshore}
6F6D CJK UNIFIED IDEOGRAPH-#6F6D, IRGKangXi=0650.130, RSKangXi=85.12, Def{deep pool, lake; deep, profound}
6F6E CJK UNIFIED IDEOGRAPH-#6F6E, IRGKangXi=0650.190, RSKangXi=85.12, Def{tide; moist, wet, damp; flow}
6F6F CJK UNIFIED IDEOGRAPH-#6F6F, IRGKangXi=0650.220, RSKangXi=85.12, Def{steep bank by stream; jiujiang}
6F70 CJK UNIFIED IDEOGRAPH-#6F70, IRGKangXi=0650.230, RSKangXi=85.12, Def{flooding river; militarily defeat}
6F71 CJK UNIFIED IDEOGRAPH-#6F71, IRGKangXi=0650.240, RSKangXi=85.12
6F72 CJK UNIFIED IDEOGRAPH-#6F72, IRGKangXi=0650.270, RSKangXi=85.12, Def{driving rain; to sprinkle}
6F73 CJK UNIFIED IDEOGRAPH-#6F73, IRGKangXi=0650.280, RSKangXi=85.12
6F74 CJK UNIFIED IDEOGRAPH-#6F74, IRGKangXi=0650.290, RSKangXi=85.12, Def{pond; a pool}
6F75 CJK UNIFIED IDEOGRAPH-#6F75, IRGKangXi=0650.300
6F76 CJK UNIFIED IDEOGRAPH-#6F76, IRGKangXi=0651.010, RSKangXi=85.12
6F77 CJK UNIFIED IDEOGRAPH-#6F77, IRGKangXi=0651.020, RSKangXi=85.12, Def{drain}
6F78 CJK UNIFIED IDEOGRAPH-#6F78, IRGKangXi=0651.040, RSKangXi=85.12, Def{weep; tears flowing}
6F79 CJK UNIFIED IDEOGRAPH-#6F79, IRGKangXi=0651.060, RSKangXi=85.12
6F7A CJK UNIFIED IDEOGRAPH-#6F7A, IRGKangXi=0651.070, RSKangXi=85.12, Def{sound of flowing water}
6F7B CJK UNIFIED IDEOGRAPH-#6F7B, IRGKangXi=0651.090, RSKangXi=85.12
6F7C CJK UNIFIED IDEOGRAPH-#6F7C, IRGKangXi=0651.110, RSKangXi=85.12, Def{high, lofty; damp}
6F7D CJK UNIFIED IDEOGRAPH-#6F7D, IRGKangXi=0651.130, RSKangXi=85.12
6F7E CJK UNIFIED IDEOGRAPH-#6F7E, IRGKangXi=0651.170, RSKangXi=85.12, Def{clear water}
6F7F CJK UNIFIED IDEOGRAPH-#6F7F, IRGKangXi=0651.190, RSKangXi=85.12, Def{still water}
6F80 CJK UNIFIED IDEOGRAPH-#6F80, IRGKangXi=0651.200, RSKangXi=85.12, Def{astringent; harsh; uneven, rough}
6F81 CJK UNIFIED IDEOGRAPH-#6F81, IRGKangXi=0651.210, RSKangXi=85.12, Def{astringent; harsh; uneven, rough}
6F82 CJK UNIFIED IDEOGRAPH-#6F82, IRGKangXi=0651.220, RSKangXi=85.12, Def{clear and still water}
6F83 CJK UNIFIED IDEOGRAPH-#6F83, IRGKangXi=0651.230, RSKangXi=85.12
6F84 CJK UNIFIED IDEOGRAPH-#6F84, IRGKangXi=0651.240, RSKangXi=85.12, Def{purify water by allowing sediment to settle; clear, pure}
6F85 CJK UNIFIED IDEOGRAPH-#6F85, IRGKangXi=0651.260, RSKangXi=85.12
6F86 CJK UNIFIED IDEOGRAPH-#6F86, IRGKangXi=0651.270, RSKangXi=85.12, Def{spray, water, sprinkle}
6F87 CJK UNIFIED IDEOGRAPH-#6F87, IRGKangXi=0651.280, RSKangXi=85.12, Def{inundate, flood; torrent}
6F88 CJK UNIFIED IDEOGRAPH-#6F88, IRGKangXi=0651.290, RSKangXi=85.12, Def{thoroughly, completely}
6F89 CJK UNIFIED IDEOGRAPH-#6F89, IRGKangXi=0651.300, RSKangXi=85.12, Def{to wash name of a place}
6F8A CJK UNIFIED IDEOGRAPH-#6F8A, IRGKangXi=0651.320, RSKangXi=85.12
6F8B CJK UNIFIED IDEOGRAPH-#6F8B, IRGKangXi=0651.360, RSKangXi=85.12
6F8C CJK UNIFIED IDEOGRAPH-#6F8C, IRGKangXi=0651.380, RSKangXi=85.12, Def{to exhaust; to drain dry}
6F8D CJK UNIFIED IDEOGRAPH-#6F8D, IRGKangXi=0652.010, RSKangXi=85.12, Def{timely rain, life-giving rain}
6F8E CJK UNIFIED IDEOGRAPH-#6F8E, IRGKangXi=0652.040, RSKangXi=85.12, Def{splatter}
6F8F CJK UNIFIED IDEOGRAPH-#6F8F, IRGKangXi=0652.050, RSKangXi=85.12
6F90 CJK UNIFIED IDEOGRAPH-#6F90, IRGKangXi=0652.060, RSKangXi=85.12, Def{billows}
6F91 CJK UNIFIED IDEOGRAPH-#6F91, IRGKangXi=0652.070, RSKangXi=85.12, Def{slide, glide, slip; slippery}
6F92 CJK UNIFIED IDEOGRAPH-#6F92, IRGKangXi=0652.080, RSKangXi=85.12, Def{vast}
6F93 CJK UNIFIED IDEOGRAPH-#6F93, IRGKangXi=0652.090, RSKangXi=85.12
6F94 CJK UNIFIED IDEOGRAPH-#6F94, IRGKangXi=0652.100, RSKangXi=85.12, Def{radiance of gems}
6F95 CJK UNIFIED IDEOGRAPH-#6F95, IRGKangXi=0652.190, RSKangXi=85.12
6F96 CJK UNIFIED IDEOGRAPH-#6F96, IRGKangXi=0652.210, RSKangXi=85.12
6F97 CJK UNIFIED IDEOGRAPH-#6F97, IRGKangXi=0652.321, RSKangXi=85.12, Def{brook, mountain stream}
6F98 CJK UNIFIED IDEOGRAPH-#6F98, IRGKangXi=0652.321, RSKangXi=85.12
6F99 CJK UNIFIED IDEOGRAPH-#6F99, IRGKangXi=0652.321, RSKangXi=85.13
6F9A CJK UNIFIED IDEOGRAPH-#6F9A, IRGKangXi=0652.321, RSKangXi=85.12
6F9B CJK UNIFIED IDEOGRAPH-#6F9B, IRGKangXi=0652.321, RSKangXi=85.15
6F9C CJK UNIFIED IDEOGRAPH-#6F9C, IRGKangXi=0652.321, RSKangXi=85.12, Def{overflowing; waves, ripples}
6F9D CJK UNIFIED IDEOGRAPH-#6F9D, IRGKangXi=0652.321, RSKangXi=85.12, Def{mud; miry, muddy, stagnant}
6F9E CJK UNIFIED IDEOGRAPH-#6F9E, IRGKangXi=0652.360, RSKangXi=85.13
6F9F CJK UNIFIED IDEOGRAPH-#6F9F, IRGKangXi=0652.380, RSKangXi=85.13
6FA0 CJK UNIFIED IDEOGRAPH-#6FA0, IRGKangXi=0652.390, RSKangXi=85.13, Def{name of a river in Shandong}
6FA1 CJK UNIFIED IDEOGRAPH-#6FA1, IRGKangXi=0652.400, RSKangXi=85.13, Def{wash, bathe}
6FA2 CJK UNIFIED IDEOGRAPH-#6FA2, IRGKangXi=0652.420, RSKangXi=85.13
6FA3 CJK UNIFIED IDEOGRAPH-#6FA3, IRGKangXi=0652.430, RSKangXi=85.13, Def{cleanse, wash}
6FA4 CJK UNIFIED IDEOGRAPH-#6FA4, IRGKangXi=0652.440, RSKangXi=85.13, Def{marsh, swamp; grace, brilliance; damp, moist; fertile}
6FA5 CJK UNIFIED IDEOGRAPH-#6FA5, IRGKangXi=0652.470, RSKangXi=85.13, Def{a blocked stream; gulf}
6FA6 CJK UNIFIED IDEOGRAPH-#6FA6, IRGKangXi=0653.010, RSKangXi=85.13, Def{place in Sichuan}
6FA7 CJK UNIFIED IDEOGRAPH-#6FA7, IRGKangXi=0653.030, RSKangXi=85.13, Def{river in northern Hunan province}
6FA8 CJK UNIFIED IDEOGRAPH-#6FA8, IRGKangXi=0653.050, RSKangXi=85.13, Def{shore; river in Hubei}
6FA9 CJK UNIFIED IDEOGRAPH-#6FA9, IRGKangXi=0653.080, RSKangXi=85.13
6FAA CJK UNIFIED IDEOGRAPH-#6FAA, IRGKangXi=0653.110, RSKangXi=85.13
6FAB CJK UNIFIED IDEOGRAPH-#6FAB, IRGKangXi=0653.140, RSKangXi=85.13
6FAC CJK UNIFIED IDEOGRAPH-#6FAC, IRGKangXi=0653.150, RSKangXi=85.13
6FAD CJK UNIFIED IDEOGRAPH-#6FAD, IRGKangXi=0653.160, RSKangXi=85.13
6FAE CJK UNIFIED IDEOGRAPH-#6FAE, IRGKangXi=0653.180, RSKangXi=85.13, Def{irrigation ditch, trench; river}
6FAF CJK UNIFIED IDEOGRAPH-#6FAF, IRGKangXi=0653.220, RSKangXi=85.13
6FB0 CJK UNIFIED IDEOGRAPH-#6FB0, IRGKangXi=0653.250, RSKangXi=85.13, Def{overflowing}
6FB1 CJK UNIFIED IDEOGRAPH-#6FB1, IRGKangXi=0653.260, RSKangXi=85.13, Def{sediment, dregs, precipitate}
6FB2 CJK UNIFIED IDEOGRAPH-#6FB2, IRGKangXi=0653.270, RSKangXi=85.13
6FB3 CJK UNIFIED IDEOGRAPH-#6FB3, IRGKangXi=0653.280, RSKangXi=85.13, Def{inlet, bay; dock, bank}
6FB4 CJK UNIFIED IDEOGRAPH-#6FB4, IRGKangXi=0653.290, RSKangXi=85.13, Def{river in Hubei province}
6FB5 CJK UNIFIED IDEOGRAPH-#6FB5, IRGKangXi=0653.300, RSKangXi=85.13
6FB6 CJK UNIFIED IDEOGRAPH-#6FB6, IRGKangXi=0653.310, RSKangXi=85.13, Def{still water, placid, tranquil}
6FB7 CJK UNIFIED IDEOGRAPH-#6FB7, IRGKangXi=0653.320, RSKangXi=85.13, Def{water overflowing diffused; spreading}
6FB8 CJK UNIFIED IDEOGRAPH-#6FB8, IRGKangXi=0653.340, RSKangXi=85.13
6FB9 CJK UNIFIED IDEOGRAPH-#6FB9, IRGKangXi=0653.360, RSKangXi=85.13, Def{calm, quiet, tranquil}
6FBA CJK UNIFIED IDEOGRAPH-#6FBA, IRGKangXi=0654.010, RSKangXi=85.13
6FBB CJK UNIFIED IDEOGRAPH-#6FBB, IRGKangXi=0654.050, RSKangXi=85.13
6FBC CJK UNIFIED IDEOGRAPH-#6FBC, IRGKangXi=0654.070, RSKangXi=85.13, Def{bleach; wash, clean}
6FBD CJK UNIFIED IDEOGRAPH-#6FBD, IRGKangXi=0654.120, RSKangXi=85.13
6FBE CJK UNIFIED IDEOGRAPH-#6FBE, IRGKangXi=0654.130, RSKangXi=85.13, Def{slippery, smooth}
6FBF CJK UNIFIED IDEOGRAPH-#6FBF, IRGKangXi=0654.150, RSKangXi=85.13
6FC0 CJK UNIFIED IDEOGRAPH-#6FC0, IRGKangXi=0654.170, RSKangXi=85.13, Def{arouse, excite, incite; quickly}
6FC1 CJK UNIFIED IDEOGRAPH-#6FC1, IRGKangXi=0654.190, RSKangXi=85.13, Def{muddy, turbid, dirty, filthy}
6FC2 CJK UNIFIED IDEOGRAPH-#6FC2, IRGKangXi=0654.200, RSKangXi=85.13, Def{a waterfall; a river in Hunan}
6FC3 CJK UNIFIED IDEOGRAPH-#6FC3, IRGKangXi=0654.210, RSKangXi=85.13, Def{thick, strong, concentrated}
6FC4 CJK UNIFIED IDEOGRAPH-#6FC4, IRGKangXi=0654.220, RSKangXi=85.13
6FC5 CJK UNIFIED IDEOGRAPH-#6FC5, IRGKangXi=0654.240, RSKangXi=85.13
6FC6 CJK UNIFIED IDEOGRAPH-#6FC6, IRGKangXi=0654.250, RSKangXi=85.13, Def{river bank; river in Henan province; gush}
6FC7 CJK UNIFIED IDEOGRAPH-#6FC7, IRGKangXi=0654.270, RSKangXi=85.13, Def{astringent; harsh, rough; uneven}
6FC8 CJK UNIFIED IDEOGRAPH-#6FC8, IRGKangXi=0654.290, RSKangXi=85.13, Def{many}
6FC9 CJK UNIFIED IDEOGRAPH-#6FC9, IRGKangXi=0654.300, RSKangXi=85.13
6FCA CJK UNIFIED IDEOGRAPH-#6FCA, IRGKangXi=0654.330, RSKangXi=85.13, Def{vast, expansive, deep; dirty}
6FCB CJK UNIFIED IDEOGRAPH-#6FCB, IRGKangXi=0655.010, RSKangXi=85.13
6FCC CJK UNIFIED IDEOGRAPH-#6FCC, IRGKangXi=0655.020, RSKangXi=85.13
6FCD CJK UNIFIED IDEOGRAPH-#6FCD, IRGKangXi=0655.030, RSKangXi=85.13
6FCE CJK UNIFIED IDEOGRAPH-#6FCE, IRGKangXi=0655.040, RSKangXi=85.13
6FCF CJK UNIFIED IDEOGRAPH-#6FCF, IRGKangXi=0655.200, RSKangXi=85.13
6FD0 CJK UNIFIED IDEOGRAPH-#6FD0, IRGKangXi=0655.201, RSKangXi=85.12
6FD1 CJK UNIFIED IDEOGRAPH-#6FD1, IRGKangXi=0655.201, RSKangXi=85.13, Def{swift current; rapids}
6FD2 CJK UNIFIED IDEOGRAPH-#6FD2, IRGKangXi=0655.201, RSKangXi=85.13, Def{approach, be on verge of; near}
6FD3 CJK UNIFIED IDEOGRAPH-#6FD3, IRGKangXi=0655.201, RSKangXi=85.13
6FD4 CJK UNIFIED IDEOGRAPH-#6FD4, IRGKangXi=0655.210, RSKangXi=85.14, Def{many}
6FD5 CJK UNIFIED IDEOGRAPH-#6FD5, IRGKangXi=0655.220, RSKangXi=85.14, Def{wet, moist, humid, damp; an illness}
6FD6 CJK UNIFIED IDEOGRAPH-#6FD6, IRGKangXi=0655.240, RSKangXi=85.13
6FD7 CJK UNIFIED IDEOGRAPH-#6FD7, IRGKangXi=0655.250, RSKangXi=85.14
6FD8 CJK UNIFIED IDEOGRAPH-#6FD8, IRGKangXi=0655.270, RSKangXi=85.14, Def{mud; miry, muddy, stagnant}
6FD9 CJK UNIFIED IDEOGRAPH-#6FD9, IRGKangXi=0655.280, RSKangXi=85.14, Def{to revolve; to curl in eddies, as rushing water}
6FDA CJK UNIFIED IDEOGRAPH-#6FDA, IRGKangXi=0655.290, RSKangXi=85.14, Def{a stream, eddy; to eddy}
6FDB CJK UNIFIED IDEOGRAPH-#6FDB, IRGKangXi=0655.300, RSKangXi=85.14, Def{drizzling, misty, raining}
6FDC CJK UNIFIED IDEOGRAPH-#6FDC, IRGKangXi=0655.310, RSKangXi=85.14, Def{river in Hubei province}
6FDD CJK UNIFIED IDEOGRAPH-#6FDD, IRGKangXi=0655.330, RSKangXi=85.14
6FDE CJK UNIFIED IDEOGRAPH-#6FDE, IRGKangXi=0655.350, RSKangXi=85.14
6FDF CJK UNIFIED IDEOGRAPH-#6FDF, IRGKangXi=0656.010, RSKangXi=85.14, Def{to help, aid, relieve; to ferry, cross}
6FE0 CJK UNIFIED IDEOGRAPH-#6FE0, IRGKangXi=0656.060, RSKangXi=85.14, Def{moat, trench, ditch}
6FE1 CJK UNIFIED IDEOGRAPH-#6FE1, IRGKangXi=0656.080, RSKangXi=85.14, Def{immerse, moisten; wet, damp}
6FE2 CJK UNIFIED IDEOGRAPH-#6FE2, IRGKangXi=0656.090, RSKangXi=85.14
6FE3 CJK UNIFIED IDEOGRAPH-#6FE3, IRGKangXi=0656.100, RSKangXi=85.14
6FE4 CJK UNIFIED IDEOGRAPH-#6FE4, IRGKangXi=0656.120, RSKangXi=85.14, Def{large waves}
6FE5 CJK UNIFIED IDEOGRAPH-#6FE5, IRGKangXi=0656.130, RSKangXi=85.14
6FE6 CJK UNIFIED IDEOGRAPH-#6FE6, IRGKangXi=0656.140, RSKangXi=85.14
6FE7 CJK UNIFIED IDEOGRAPH-#6FE7, IRGKangXi=0656.150, RSKangXi=85.14
6FE8 CJK UNIFIED IDEOGRAPH-#6FE8, IRGKangXi=0656.190, RSKangXi=85.14
6FE9 CJK UNIFIED IDEOGRAPH-#6FE9, IRGKangXi=0656.210, RSKangXi=85.14, Def{pour down, cascade down; look}
6FEA CJK UNIFIED IDEOGRAPH-#6FEA, IRGKangXi=0656.220, RSKangXi=85.14
6FEB CJK UNIFIED IDEOGRAPH-#6FEB, IRGKangXi=0657.030, RSKangXi=85.14, Def{flood, overflow; excessive}
6FEC CJK UNIFIED IDEOGRAPH-#6FEC, IRGKangXi=0657.060, RSKangXi=85.14, Def{dredge, dig; profound, deep}
6FED CJK UNIFIED IDEOGRAPH-#6FED, IRGKangXi=0657.090, RSKangXi=85.14
6FEE CJK UNIFIED IDEOGRAPH-#6FEE, IRGKangXi=0657.100, RSKangXi=85.14, Def{county in Henan province}
6FEF CJK UNIFIED IDEOGRAPH-#6FEF, IRGKangXi=0657.150, RSKangXi=85.14, Def{wash out, rinse; cleanse}
6FF0 CJK UNIFIED IDEOGRAPH-#6FF0, IRGKangXi=0657.160, RSKangXi=85.14, Def{county in Shandong province}
6FF1 CJK UNIFIED IDEOGRAPH-#6FF1, IRGKangXi=0657.200, RSKangXi=85.14, Def{beach, sea coast; river bank}
6FF2 CJK UNIFIED IDEOGRAPH-#6FF2, IRGKangXi=0657.260, RSKangXi=85.14
6FF3 CJK UNIFIED IDEOGRAPH-#6FF3, IRGKangXi=0657.280, RSKangXi=85.16, Def{hide, conceal, secrete; hidden}
6FF4 CJK UNIFIED IDEOGRAPH-#6FF4, IRGKangXi=0657.290, RSKangXi=85.14
6FF5 CJK UNIFIED IDEOGRAPH-#6FF5, IRGKangXi=0657.361, RSKangXi=85.14, Def{a bank, a brink. a shore, a beach}
6FF6 CJK UNIFIED IDEOGRAPH-#6FF6, IRGKangXi=0657.361, RSKangXi=85.14, Def{broad, ample, wide; be apart}
6FF7 CJK UNIFIED IDEOGRAPH-#6FF7, IRGKangXi=0657.361, RSKangXi=85.14
6FF8 CJK UNIFIED IDEOGRAPH-#6FF8, IRGKangXi=0657.361, RSKangXi=85.14
6FF9 CJK UNIFIED IDEOGRAPH-#6FF9, IRGKangXi=0657.361, RSKangXi=85.15
6FFA CJK UNIFIED IDEOGRAPH-#6FFA, IRGKangXi=0657.380, RSKangXi=85.15, Def{sprinkle, spray; spill, splash}
6FFB CJK UNIFIED IDEOGRAPH-#6FFB, IRGKangXi=0658.040, RSKangXi=85.15
6FFC CJK UNIFIED IDEOGRAPH-#6FFC, IRGKangXi=0658.060, RSKangXi=85.15, Def{river in Shandong province}
6FFD CJK UNIFIED IDEOGRAPH-#6FFD, IRGKangXi=0658.070, RSKangXi=85.15
6FFE CJK UNIFIED IDEOGRAPH-#6FFE, IRGKangXi=0658.080, RSKangXi=85.15, Def{strain out, filter}
6FFF CJK UNIFIED IDEOGRAPH-#6FFF, IRGKangXi=0658.120, RSKangXi=85.15, Def{cross on stepping-stones}
7000 CJK UNIFIED IDEOGRAPH-#7000, IRGKangXi=0658.140, RSKangXi=85.15
7001 CJK UNIFIED IDEOGRAPH-#7001, IRGKangXi=0658.160, RSKangXi=85.15, Def{waves, ripples, rapids; overflow}
7002 CJK UNIFIED IDEOGRAPH-#7002, IRGKangXi=0658.170, RSKangXi=85.15
7003 CJK UNIFIED IDEOGRAPH-#7003, IRGKangXi=0658.190, RSKangXi=85.15
7004 CJK UNIFIED IDEOGRAPH-#7004, IRGKangXi=0658.260, RSKangXi=85.15, Def{(Cant.) to squeeze; to eject; to spray}
7005 CJK UNIFIED IDEOGRAPH-#7005, IRGKangXi=0658.300, RSKangXi=85.15, Def{clear, pure water; lucid; glossy}
7006 CJK UNIFIED IDEOGRAPH-#7006, IRGKangXi=0658.340, RSKangXi=85.15, Def{ditch, sluice, gutter, drain}
7007 CJK UNIFIED IDEOGRAPH-#7007, IRGKangXi=0658.370, RSKangXi=85.15, Def{extensive body of water; broad and deep of water; momentum of moving water deep and wide}
7008 CJK UNIFIED IDEOGRAPH-#7008, IRGKangXi=0658.380, RSKangXi=85.15
7009 CJK UNIFIED IDEOGRAPH-#7009, IRGKangXi=0658.390, RSKangXi=85.15, Def{drain off, leak; flow, pour down}
700A CJK UNIFIED IDEOGRAPH-#700A, IRGKangXi=0659.010, RSKangXi=85.15
700B CJK UNIFIED IDEOGRAPH-#700B, IRGKangXi=0659.040, RSKangXi=85.15, Def{juice; liquid; water; leak, pour}
700C CJK UNIFIED IDEOGRAPH-#700C, IRGKangXi=0659.050, RSKangXi=85.15, Def{plenty}
700D CJK UNIFIED IDEOGRAPH-#700D, IRGKangXi=0659.060, RSKangXi=85.15, Def{river in Henan province}
700E CJK UNIFIED IDEOGRAPH-#700E, IRGKangXi=0659.100, RSKangXi=85.15
700F CJK UNIFIED IDEOGRAPH-#700F, IRGKangXi=0659.110, RSKangXi=85.15, Def{clear; bright; whistling}
7010 CJK UNIFIED IDEOGRAPH-#7010, IRGKangXi=0659.120, RSKangXi=85.15
7011 CJK UNIFIED IDEOGRAPH-#7011, IRGKangXi=0659.130, RSKangXi=85.15, Def{waterfall, cascade; heavy rain}
7012 CJK UNIFIED IDEOGRAPH-#7012, IRGKangXi=0659.140, RSKangXi=85.15, Def{coarse, rough; astringent}
7013 CJK UNIFIED IDEOGRAPH-#7013, IRGKangXi=0659.200, RSKangXi=85.15
7014 CJK UNIFIED IDEOGRAPH-#7014, IRGKangXi=0659.291, RSKangXi=85.15, Def{river name in Henan province}
7015 CJK UNIFIED IDEOGRAPH-#7015, IRGKangXi=0659.320, RSKangXi=85.16, Def{approach, be on verge of; near}
7016 CJK UNIFIED IDEOGRAPH-#7016, IRGKangXi=0659.340, RSKangXi=85.16
7017 CJK UNIFIED IDEOGRAPH-#7017, IRGKangXi=0659.400, RSKangXi=85.16
7018 CJK UNIFIED IDEOGRAPH-#7018, IRGKangXi=0659.420, RSKangXi=85.16, Def{river in Jiangxi province}
7019 CJK UNIFIED IDEOGRAPH-#7019, IRGKangXi=0659.450, RSKangXi=85.16
701A CJK UNIFIED IDEOGRAPH-#701A, IRGKangXi=0659.480, RSKangXi=85.16, Def{vast, wide, extensive}
701B CJK UNIFIED IDEOGRAPH-#701B, IRGKangXi=0660.040, RSKangXi=85.16, Def{sea, ocean}
701C CJK UNIFIED IDEOGRAPH-#701C, IRGKangXi=0660.050, RSKangXi=85.16
701D CJK UNIFIED IDEOGRAPH-#701D, IRGKangXi=0660.060, RSKangXi=85.16, Def{trickle, drip; strain; dregs}
701E CJK UNIFIED IDEOGRAPH-#701E, IRGKangXi=0657.020, RSKangXi=85.16, Def{pool in a river}
701F CJK UNIFIED IDEOGRAPH-#701F, IRGKangXi=0660.080, RSKangXi=85.16, Def{sound of beating wind and rain; light, ethereal}
7020 CJK UNIFIED IDEOGRAPH-#7020, IRGKangXi=0660.090, RSKangXi=85.16, Def{tiny stream; swirl around; eddy}
7021 CJK UNIFIED IDEOGRAPH-#7021, IRGKangXi=0660.130, RSKangXi=85.16, Def{slippery, smooth}
7022 CJK UNIFIED IDEOGRAPH-#7022, IRGKangXi=0660.140, RSKangXi=85.16
7023 CJK UNIFIED IDEOGRAPH-#7023, IRGKangXi=0660.150, RSKangXi=85.16, Def{sea mist; vapor}
7024 CJK UNIFIED IDEOGRAPH-#7024, IRGKangXi=0660.160, RSKangXi=85.16
7025 CJK UNIFIED IDEOGRAPH-#7025, IRGKangXi=0660.170, RSKangXi=85.16
7026 CJK UNIFIED IDEOGRAPH-#7026, IRGKangXi=0660.180, RSKangXi=85.16, Def{pond; a pool}
7027 CJK UNIFIED IDEOGRAPH-#7027, IRGKangXi=0660.190, RSKangXi=85.16, Def{raining; wet; soaked; a river in Guangdong}
7028 CJK UNIFIED IDEOGRAPH-#7028, IRGKangXi=0660.200, RSKangXi=85.16, Def{swift current; rapids}
7029 CJK UNIFIED IDEOGRAPH-#7029, IRGKangXi=0660.210, RSKangXi=85.16
702A CJK UNIFIED IDEOGRAPH-#702A, IRGKangXi=0660.230, RSKangXi=85.16
702B CJK UNIFIED IDEOGRAPH-#702B, IRGKangXi=0660.240, RSKangXi=85.16
702C CJK UNIFIED IDEOGRAPH-#702C, IRGKangXi=0660.271, RSKangXi=85.16, Def{swift current; rapids}
702D CJK UNIFIED IDEOGRAPH-#702D, IRGKangXi=0660.271, RSKangXi=85.16
702E CJK UNIFIED IDEOGRAPH-#702E, IRGKangXi=0660.271, RSKangXi=85.16
702F CJK UNIFIED IDEOGRAPH-#702F, IRGKangXi=0660.280, RSKangXi=85.17
7030 CJK UNIFIED IDEOGRAPH-#7030, IRGKangXi=0660.310, RSKangXi=85.17, Def{overflow}
7031 CJK UNIFIED IDEOGRAPH-#7031, IRGKangXi=0660.320, RSKangXi=85.17
7032 CJK UNIFIED IDEOGRAPH-#7032, IRGKangXi=0660.340, RSKangXi=85.17, Def{waves, ripples; overflow}
7033 CJK UNIFIED IDEOGRAPH-#7033, IRGKangXi=0661.010, RSKangXi=85.17
7034 CJK UNIFIED IDEOGRAPH-#7034, IRGKangXi=0661.020, RSKangXi=85.17
7035 CJK UNIFIED IDEOGRAPH-#7035, IRGKangXi=0661.030, RSKangXi=85.17
7036 CJK UNIFIED IDEOGRAPH-#7036, IRGKangXi=0661.070, RSKangXi=85.17
7037 CJK UNIFIED IDEOGRAPH-#7037, IRGKangXi=0661.110, RSKangXi=85.17
7038 CJK UNIFIED IDEOGRAPH-#7038, IRGKangXi=0661.130, RSKangXi=85.17
7039 CJK UNIFIED IDEOGRAPH-#7039, IRGKangXi=0661.160, RSKangXi=85.17, Def{to boil; to wash, to cleanse, to soak}
703A CJK UNIFIED IDEOGRAPH-#703A, IRGKangXi=0661.210, RSKangXi=85.17, Def{sound}
703B CJK UNIFIED IDEOGRAPH-#703B, IRGKangXi=0661.220, RSKangXi=85.17
703C CJK UNIFIED IDEOGRAPH-#703C, IRGKangXi=0661.230, RSKangXi=85.17, Def{river in Henan province; flowing}
703D CJK UNIFIED IDEOGRAPH-#703D, IRGKangXi=0661.250, RSKangXi=85.17
703E CJK UNIFIED IDEOGRAPH-#703E, IRGKangXi=0661.290, RSKangXi=85.17, Def{overflowing; waves, ripples}
703F CJK UNIFIED IDEOGRAPH-#703F, IRGKangXi=0662.010, RSKangXi=85.17
7040 CJK UNIFIED IDEOGRAPH-#7040, IRGKangXi=0662.020, RSKangXi=85.17
7041 CJK UNIFIED IDEOGRAPH-#7041, IRGKangXi=0662.070, RSKangXi=85.17
7042 CJK UNIFIED IDEOGRAPH-#7042, IRGKangXi=0662.110, RSKangXi=85.18
7043 CJK UNIFIED IDEOGRAPH-#7043, IRGKangXi=0662.150, RSKangXi=85.18, Def{river in Shanxi province}
7044 CJK UNIFIED IDEOGRAPH-#7044, IRGKangXi=0662.170, RSKangXi=85.18, Def{river in Hubei province}
7045 CJK UNIFIED IDEOGRAPH-#7045, IRGKangXi=0662.180, RSKangXi=85.18
7046 CJK UNIFIED IDEOGRAPH-#7046, IRGKangXi=0662.200, RSKangXi=85.18
7047 CJK UNIFIED IDEOGRAPH-#7047, IRGKangXi=0662.210, RSKangXi=85.18
7048 CJK UNIFIED IDEOGRAPH-#7048, IRGKangXi=0662.220, RSKangXi=85.18
7049 CJK UNIFIED IDEOGRAPH-#7049, IRGKangXi=0662.250, RSKangXi=85.18, Def{a river in Shandong province; a sluice}
704A CJK UNIFIED IDEOGRAPH-#704A, IRGKangXi=0662.260, RSKangXi=85.18
704B CJK UNIFIED IDEOGRAPH-#704B, IRGKangXi=0662.340, RSKangXi=85.18, Def{law}
704C CJK UNIFIED IDEOGRAPH-#704C, IRGKangXi=0662.350, RSKangXi=85.18, Def{pour; water; irrigate, flood}
704D CJK UNIFIED IDEOGRAPH-#704D, IRGKangXi=0663.010, RSKangXi=85.18
704E CJK UNIFIED IDEOGRAPH-#704E, IRGKangXi=0664.170, RSKangXi=85.23, Def{movement of water; overflowing, billowing; wavy}
704F CJK UNIFIED IDEOGRAPH-#704F, IRGKangXi=0663.091, RSKangXi=85.18, Def{vast, large, grand, expansive}
7050 CJK UNIFIED IDEOGRAPH-#7050, IRGKangXi=0663.091, RSKangXi=85.18
7051 CJK UNIFIED IDEOGRAPH-#7051, IRGKangXi=0663.110, RSKangXi=85.19, Def{sprinkle, splash; scatter, throw}
7052 CJK UNIFIED IDEOGRAPH-#7052, IRGKangXi=0663.130, RSKangXi=85.19, Def{to spatter, to splash, to scatter}
7053 CJK UNIFIED IDEOGRAPH-#7053, IRGKangXi=0663.140, RSKangXi=85.19
7054 CJK UNIFIED IDEOGRAPH-#7054, IRGKangXi=0663.150, RSKangXi=85.19, Def{waves, billows}
7055 CJK UNIFIED IDEOGRAPH-#7055, IRGKangXi=0663.170, RSKangXi=85.19, Def{short name for Guangxi province}
7056 CJK UNIFIED IDEOGRAPH-#7056, IRGKangXi=0663.190, RSKangXi=85.19
7057 CJK UNIFIED IDEOGRAPH-#7057, IRGKangXi=0663.210, RSKangXi=85.19
7058 CJK UNIFIED IDEOGRAPH-#7058, IRGKangXi=0663.220, RSKangXi=85.19, Def{bank, a sandbar, shoal; rapids}
7059 CJK UNIFIED IDEOGRAPH-#7059, IRGKangXi=0663.280, RSKangXi=85.20
705A CJK UNIFIED IDEOGRAPH-#705A, IRGKangXi=0663.300, RSKangXi=85.20
705B CJK UNIFIED IDEOGRAPH-#705B, IRGKangXi=0663.310, RSKangXi=85.20
705C CJK UNIFIED IDEOGRAPH-#705C, IRGKangXi=0663.421, RSKangXi=85.20
705D CJK UNIFIED IDEOGRAPH-#705D, IRGKangXi=0663.460, RSKangXi=85.21, Def{vast, large, grand, expansive}
705E CJK UNIFIED IDEOGRAPH-#705E, IRGKangXi=0664.030, RSKangXi=85.21, Def{river in Shanxi province}
705F CJK UNIFIED IDEOGRAPH-#705F, IRGKangXi=0664.040, RSKangXi=85.21
7060 CJK UNIFIED IDEOGRAPH-#7060, IRGKangXi=0664.050, RSKangXi=85.21, Def{marinate in salt}
7061 CJK UNIFIED IDEOGRAPH-#7061, IRGKangXi=0664.080, RSKangXi=85.21
7062 CJK UNIFIED IDEOGRAPH-#7062, IRGKangXi=0664.090, RSKangXi=85.22, Def{muddy; thick, muddy water}
7063 CJK UNIFIED IDEOGRAPH-#7063, IRGKangXi=0664.100, RSKangXi=85.22, Def{a bay, cove, inlet, bend of stream}
7064 CJK UNIFIED IDEOGRAPH-#7064, IRGKangXi=0664.190, RSKangXi=85.23, Def{river and county in Hebei province}
7065 CJK UNIFIED IDEOGRAPH-#7065, IRGKangXi=0664.200, RSKangXi=85.23, Def{a group of springs}
7066 CJK UNIFIED IDEOGRAPH-#7066, IRGKangXi=0664.210, RSKangXi=85.23
7067 CJK UNIFIED IDEOGRAPH-#7067, IRGKangXi=0664.250, RSKangXi=85.24, Def{overflowing, billowing; wavy}
7068 CJK UNIFIED IDEOGRAPH-#7068, IRGKangXi=0664.280, RSKangXi=85.24, Def{the River Gan in Jiangxi}
7069 CJK UNIFIED IDEOGRAPH-#7069, IRGKangXi=0664.300, RSKangXi=85.28, Def{overflowing, billowing; wavy}
706A CJK UNIFIED IDEOGRAPH-#706A, IRGKangXi=0664.310, RSKangXi=85.29
706B CJK UNIFIED IDEOGRAPH-#706B, IRGKangXi=0665.010, RSKangXi=86.0, Def{fire, flame; burn; anger, rage}
706C CJK UNIFIED IDEOGRAPH-#706C, IRGKangXi=0665.030, RSKangXi=86.0, Def{fire; radical number 86}
706D CJK UNIFIED IDEOGRAPH-#706D, IRGKangXi=0665.031, RSKangXi=86.1, Def{extinguish; wipe out, exterminate}
706E CJK UNIFIED IDEOGRAPH-#706E, IRGKangXi=0665.050, RSKangXi=86.2
706F CJK UNIFIED IDEOGRAPH-#706F, IRGKangXi=0665.060, RSKangXi=86.2, Def{lantern, lamp}
7070 CJK UNIFIED IDEOGRAPH-#7070, IRGKangXi=0665.090, RSKangXi=86.2, Def{ashes; dust; lime, mortar}
7071 CJK UNIFIED IDEOGRAPH-#7071, IRGKangXi=0666.010, RSKangXi=86.2
7072 CJK UNIFIED IDEOGRAPH-#7072, IRGKangXi=0666.020, RSKangXi=86.2
7073 CJK UNIFIED IDEOGRAPH-#7073, IRGKangXi=0666.060, RSKangXi=86.2
7074 CJK UNIFIED IDEOGRAPH-#7074, IRGKangXi=0666.070, RSKangXi=86.3, Def{to bake, to roast; to dry at a fire}
7075 CJK UNIFIED IDEOGRAPH-#7075, IRGKangXi=0666.080, RSKangXi=58.4, Def{spirit, soul; spiritual world}
7076 CJK UNIFIED IDEOGRAPH-#7076, IRGKangXi=0666.090, RSKangXi=86.3, Def{kitchen stove, cooking stove}
7077 CJK UNIFIED IDEOGRAPH-#7077, IRGKangXi=0666.110, RSKangXi=86.3
7078 CJK UNIFIED IDEOGRAPH-#7078, IRGKangXi=0666.120, RSKangXi=86.3, Def{cauterize with moxa; moxibustion}
7079 CJK UNIFIED IDEOGRAPH-#7079, IRGKangXi=0666.130, RSKangXi=86.3
707A CJK UNIFIED IDEOGRAPH-#707A, IRGKangXi=0666.140, RSKangXi=86.3, Def{candle-end}
707B CJK UNIFIED IDEOGRAPH-#707B, IRGKangXi=0666.160, RSKangXi=86.3
707C CJK UNIFIED IDEOGRAPH-#707C, IRGKangXi=0666.170, RSKangXi=86.3, Def{burn; broil; cauterize; bright}
707D CJK UNIFIED IDEOGRAPH-#707D, IRGKangXi=0666.180, RSKangXi=86.3, Def{calamity, disaster, catastrophe}
707E CJK UNIFIED IDEOGRAPH-#707E, IRGKangXi=0666.220, RSKangXi=86.3, Def{calamity, disaster, catastrophe}
707F CJK UNIFIED IDEOGRAPH-#707F, IRGKangXi=0666.261, RSKangXi=86.3, Def{vivid, illuminating; bright}
7080 CJK UNIFIED IDEOGRAPH-#7080, IRGKangXi=0666.261, RSKangXi=86.3, Def{roast; scorch; melt; flame}
7081 CJK UNIFIED IDEOGRAPH-#7081, IRGKangXi=0666.270, RSKangXi=86.4, Def{breath, air, steam, gas. weather. used in Taoist charms}
7082 CJK UNIFIED IDEOGRAPH-#7082, IRGKangXi=0666.280, RSKangXi=86.4
7083 CJK UNIFIED IDEOGRAPH-#7083, IRGKangXi=0666.290, RSKangXi=86.4
7084 CJK UNIFIED IDEOGRAPH-#7084, IRGKangXi=0666.310, RSKangXi=86.4
7085 CJK UNIFIED IDEOGRAPH-#7085, IRGKangXi=0666.320, RSKangXi=86.4, Def{brilliance}
7086 CJK UNIFIED IDEOGRAPH-#7086, IRGKangXi=0667.010, RSKangXi=86.4, Def{(Cant.) to simmer, cook over a slow fire}
7087 CJK UNIFIED IDEOGRAPH-#7087, IRGKangXi=0667.020, RSKangXi=86.2
7088 CJK UNIFIED IDEOGRAPH-#7088, IRGKangXi=0667.040, RSKangXi=86.4
7089 CJK UNIFIED IDEOGRAPH-#7089, IRGKangXi=0667.050, RSKangXi=86.4, Def{fireplace, stove, oven, furnace}
708A CJK UNIFIED IDEOGRAPH-#708A, IRGKangXi=0667.070, RSKangXi=86.4, Def{cook; meal}
708B CJK UNIFIED IDEOGRAPH-#708B, IRGKangXi=0667.090, RSKangXi=86.4
708C CJK UNIFIED IDEOGRAPH-#708C, IRGKangXi=0667.110, RSKangXi=86.4
708D CJK UNIFIED IDEOGRAPH-#708D, IRGKangXi=0667.120, RSKangXi=86.4
708E CJK UNIFIED IDEOGRAPH-#708E, IRGKangXi=0667.130, RSKangXi=86.4, Def{flame, blaze; hot}
708F CJK UNIFIED IDEOGRAPH-#708F, IRGKangXi=0667.140, RSKangXi=86.4
7090 CJK UNIFIED IDEOGRAPH-#7090, IRGKangXi=0667.150, RSKangXi=86.4
7091 CJK UNIFIED IDEOGRAPH-#7091, IRGKangXi=0667.160, RSKangXi=86.4
7092 CJK UNIFIED IDEOGRAPH-#7092, IRGKangXi=0667.170, RSKangXi=86.4, Def{fry, saute, roast, boil, cook}
7093 CJK UNIFIED IDEOGRAPH-#7093, IRGKangXi=0667.180, RSKangXi=86.4
7094 CJK UNIFIED IDEOGRAPH-#7094, IRGKangXi=0667.190, RSKangXi=86.4, Def{acetylene}
7095 CJK UNIFIED IDEOGRAPH-#7095, IRGKangXi=0667.200, RSKangXi=86.4, Def{the brick-bed in northern China}
7096 CJK UNIFIED IDEOGRAPH-#7096, IRGKangXi=0667.210, RSKangXi=86.4, Def{heat with fire; stew}
7097 CJK UNIFIED IDEOGRAPH-#7097, IRGKangXi=0667.220, RSKangXi=86.4
7098 CJK UNIFIED IDEOGRAPH-#7098, IRGKangXi=0667.230, RSKangXi=86.4, Def{brilliant, shining, bright}
7099 CJK UNIFIED IDEOGRAPH-#7099, IRGKangXi=0667.240, RSKangXi=86.4, Def{roast, broil; toast; cauterize}
709A CJK UNIFIED IDEOGRAPH-#709A, IRGKangXi=0668.010, RSKangXi=86.4
709B CJK UNIFIED IDEOGRAPH-#709B, IRGKangXi=0668.031, RSKangXi=86.4
709C CJK UNIFIED IDEOGRAPH-#709C, IRGKangXi=0668.031, RSKangXi=86.4, Def{brilliant red; glowing}
709D CJK UNIFIED IDEOGRAPH-#709D, IRGKangXi=0668.031, RSKangXi=86.4, Def{stir-fry or boil in water or oil then cook with a sauce}
709E CJK UNIFIED IDEOGRAPH-#709E, IRGKangXi=0668.031, RSKangXi=86.4
709F CJK UNIFIED IDEOGRAPH-#709F, IRGKangXi=0668.040, RSKangXi=86.5
70A0 CJK UNIFIED IDEOGRAPH-#70A0, IRGKangXi=0668.050, RSKangXi=86.5, Def{(Cant.) to cook in boiling water}
70A1 CJK UNIFIED IDEOGRAPH-#70A1, IRGKangXi=0668.060, RSKangXi=86.5
70A2 CJK UNIFIED IDEOGRAPH-#70A2, IRGKangXi=0668.080, RSKangXi=86.5
70A3 CJK UNIFIED IDEOGRAPH-#70A3, IRGKangXi=0668.100, RSKangXi=86.5
70A4 CJK UNIFIED IDEOGRAPH-#70A4, IRGKangXi=0668.110, RSKangXi=86.5, Def{illumine, light up; reflect}
70A5 CJK UNIFIED IDEOGRAPH-#70A5, IRGKangXi=0668.120, RSKangXi=86.5
70A6 CJK UNIFIED IDEOGRAPH-#70A6, IRGKangXi=0668.130, RSKangXi=86.5
70A7 CJK UNIFIED IDEOGRAPH-#70A7, IRGKangXi=0668.150, RSKangXi=86.5, Def{ashes}
70A8 CJK UNIFIED IDEOGRAPH-#70A8, IRGKangXi=0668.160, RSKangXi=86.5
70A9 CJK UNIFIED IDEOGRAPH-#70A9, IRGKangXi=0668.170, RSKangXi=86.5
70AA CJK UNIFIED IDEOGRAPH-#70AA, IRGKangXi=0668.180, RSKangXi=86.5
70AB CJK UNIFIED IDEOGRAPH-#70AB, IRGKangXi=0668.190, RSKangXi=86.5, Def{shine, glitter; show off, flaunt}
70AC CJK UNIFIED IDEOGRAPH-#70AC, IRGKangXi=0668.200, RSKangXi=86.5, Def{torch}
70AD CJK UNIFIED IDEOGRAPH-#70AD, IRGKangXi=0668.240, RSKangXi=86.5, Def{charcoal; coal; carbon}
70AE CJK UNIFIED IDEOGRAPH-#70AE, IRGKangXi=0668.250, RSKangXi=86.5, Def{large gun, cannon; artillery}
70AF CJK UNIFIED IDEOGRAPH-#70AF, IRGKangXi=0668.260, RSKangXi=86.5, Def{bright, brilliant, clear; hot}
70B0 CJK UNIFIED IDEOGRAPH-#70B0, IRGKangXi=0668.270, RSKangXi=86.5, Def{roast, broil; bake}
70B1 CJK UNIFIED IDEOGRAPH-#70B1, IRGKangXi=0668.280, RSKangXi=86.5, Def{soot}
70B2 CJK UNIFIED IDEOGRAPH-#70B2, IRGKangXi=0668.290, RSKangXi=86.5
70B3 CJK UNIFIED IDEOGRAPH-#70B3, IRGKangXi=0669.010, RSKangXi=86.5, Def{bright, luminous; glorious}
70B4 CJK UNIFIED IDEOGRAPH-#70B4, IRGKangXi=0669.020, RSKangXi=86.5
70B5 CJK UNIFIED IDEOGRAPH-#70B5, IRGKangXi=0669.030, RSKangXi=86.5
70B6 CJK UNIFIED IDEOGRAPH-#70B6, IRGKangXi=0669.040, RSKangXi=86.5
70B7 CJK UNIFIED IDEOGRAPH-#70B7, IRGKangXi=0669.060, RSKangXi=86.5, Def{candle wick, lamp wick; stick of incense}
70B8 CJK UNIFIED IDEOGRAPH-#70B8, IRGKangXi=0669.101, RSKangXi=86.5, Def{to fry in oil; to scald; to explode}
70B9 CJK UNIFIED IDEOGRAPH-#70B9, IRGKangXi=0669.101, RSKangXi=86.5, Def{dot, speck, spot; point, degree}
70BA CJK UNIFIED IDEOGRAPH-#70BA, IRGKangXi=0669.101, RSKangXi=86.5, Def{do, handle, govern, act; be}
70BB CJK UNIFIED IDEOGRAPH-#70BB, IRGKangXi=0669.101, RSKangXi=86.5, Def{a kind of china}
70BC CJK UNIFIED IDEOGRAPH-#70BC, IRGKangXi=0669.101, RSKangXi=86.5, Def{smelt, refine; distill, condense}
70BD CJK UNIFIED IDEOGRAPH-#70BD, IRGKangXi=0669.101, RSKangXi=86.5, Def{burning-hot, intense; to burn, blaze; splendid, illustrious}
70BE CJK UNIFIED IDEOGRAPH-#70BE, IRGKangXi=0669.101, RSKangXi=86.5
70BF CJK UNIFIED IDEOGRAPH-#70BF, IRGKangXi=0669.101, RSKangXi=86.5
70C0 CJK UNIFIED IDEOGRAPH-#70C0, IRGKangXi=0669.101, RSKangXi=86.5, Def{simmer}
70C1 CJK UNIFIED IDEOGRAPH-#70C1, IRGKangXi=0669.101, RSKangXi=86.5, Def{shine, glitter, sparkle}
70C2 CJK UNIFIED IDEOGRAPH-#70C2, IRGKangXi=0669.101, RSKangXi=86.5, Def{rotten, spoiled, decayed}
70C3 CJK UNIFIED IDEOGRAPH-#70C3, IRGKangXi=0669.101, RSKangXi=86.5, Def{hydrocarbon}
70C4 CJK UNIFIED IDEOGRAPH-#70C4, IRGKangXi=0669.110, RSKangXi=86.6
70C5 CJK UNIFIED IDEOGRAPH-#70C5, IRGKangXi=0669.120, RSKangXi=86.6
70C6 CJK UNIFIED IDEOGRAPH-#70C6, IRGKangXi=0669.130, RSKangXi=86.6
70C7 CJK UNIFIED IDEOGRAPH-#70C7, IRGKangXi=0669.150, RSKangXi=86.6
70C8 CJK UNIFIED IDEOGRAPH-#70C8, IRGKangXi=0669.160, RSKangXi=86.6, Def{fiery, violent, vehement, ardent}
70C9 CJK UNIFIED IDEOGRAPH-#70C9, IRGKangXi=0669.190, Def{shining, brilliant, lustrous}
70CA CJK UNIFIED IDEOGRAPH-#70CA, IRGKangXi=0669.200, RSKangXi=86.6, Def{to smelt; to melt}
70CB CJK UNIFIED IDEOGRAPH-#70CB, IRGKangXi=0669.210, RSKangXi=86.6, Def{boast}
70CC CJK UNIFIED IDEOGRAPH-#70CC, IRGKangXi=0669.220, RSKangXi=86.6
70CD CJK UNIFIED IDEOGRAPH-#70CD, IRGKangXi=0669.240, RSKangXi=86.6
70CE CJK UNIFIED IDEOGRAPH-#70CE, IRGKangXi=0669.250, RSKangXi=86.6
70CF CJK UNIFIED IDEOGRAPH-#70CF, IRGKangXi=0670.010, RSKangXi=86.6, Def{crow, rook, raven; black, dark}
70D0 CJK UNIFIED IDEOGRAPH-#70D0, IRGKangXi=0670.050, RSKangXi=86.6
70D1 CJK UNIFIED IDEOGRAPH-#70D1, IRGKangXi=0670.060, RSKangXi=86.6
70D2 CJK UNIFIED IDEOGRAPH-#70D2, IRGKangXi=0670.070, RSKangXi=86.6
70D3 CJK UNIFIED IDEOGRAPH-#70D3, IRGKangXi=0670.090, RSKangXi=86.6, Def{stove}
70D4 CJK UNIFIED IDEOGRAPH-#70D4, IRGKangXi=0670.100, RSKangXi=86.6, Def{heat}
70D5 CJK UNIFIED IDEOGRAPH-#70D5, IRGKangXi=0670.120, RSKangXi=86.6, Def{to destroy; to exterminate to extinguish}
70D6 CJK UNIFIED IDEOGRAPH-#70D6, IRGKangXi=0670.130, RSKangXi=86.6, Def{calamities from Heaven, as floods, famines, pestilence, etc.; misery}
70D7 CJK UNIFIED IDEOGRAPH-#70D7, IRGKangXi=0670.150, RSKangXi=86.6
70D8 CJK UNIFIED IDEOGRAPH-#70D8, IRGKangXi=0670.170, RSKangXi=86.6, Def{bake, roast; dry by fire}
70D9 CJK UNIFIED IDEOGRAPH-#70D9, IRGKangXi=0670.180, RSKangXi=86.6, Def{brand, burn; branding iron}
70DA CJK UNIFIED IDEOGRAPH-#70DA, IRGKangXi=0670.190, RSKangXi=86.6, Def{(Cant.) hot; to argue, wrangle, rail at (i.e., to flame)}
70DB CJK UNIFIED IDEOGRAPH-#70DB, IRGKangXi=0670.210, RSKangXi=86.6, Def{candle, taper; shine, illuminate}
70DC CJK UNIFIED IDEOGRAPH-#70DC, IRGKangXi=0670.220, RSKangXi=86.6, Def{light of the sun; to dry in the sun}
70DD CJK UNIFIED IDEOGRAPH-#70DD, IRGKangXi=0671.010, RSKangXi=86.6, Def{rise, steam; many, numerous}
70DE CJK UNIFIED IDEOGRAPH-#70DE, IRGKangXi=0671.030, RSKangXi=86.6
70DF CJK UNIFIED IDEOGRAPH-#70DF, IRGKangXi=0671.040, RSKangXi=86.6, Def{smoke, soot; opium; tobacco, cigarettes}
70E0 CJK UNIFIED IDEOGRAPH-#70E0, IRGKangXi=0671.050, RSKangXi=86.6
70E1 CJK UNIFIED IDEOGRAPH-#70E1, IRGKangXi=0671.060, RSKangXi=86.6
70E2 CJK UNIFIED IDEOGRAPH-#70E2, IRGKangXi=0671.070, RSKangXi=86.6
70E3 CJK UNIFIED IDEOGRAPH-#70E3, IRGKangXi=0671.081, RSKangXi=86.6
70E4 CJK UNIFIED IDEOGRAPH-#70E4, IRGKangXi=0671.081, RSKangXi=86.6, Def{bake, roast, toast, cook}
70E5 CJK UNIFIED IDEOGRAPH-#70E5, IRGKangXi=0671.081, RSKangXi=86.6
70E6 CJK UNIFIED IDEOGRAPH-#70E6, IRGKangXi=0671.081, RSKangXi=86.6, Def{bother, vex, trouble; troublesome}
70E7 CJK UNIFIED IDEOGRAPH-#70E7, IRGKangXi=0671.081, RSKangXi=86.6, Def{burn; bake; heat; roast}
70E8 CJK UNIFIED IDEOGRAPH-#70E8, IRGKangXi=0671.081, RSKangXi=86.6, Def{bright, glorious, splendid, flame}
70E9 CJK UNIFIED IDEOGRAPH-#70E9, IRGKangXi=0671.081, RSKangXi=86.6, Def{ragout, cook, braise}
70EA CJK UNIFIED IDEOGRAPH-#70EA, IRGKangXi=0671.081, RSKangXi=86.6
70EB CJK UNIFIED IDEOGRAPH-#70EB, IRGKangXi=0671.081, RSKangXi=86.6, Def{scald, heat; wash; iron clothes}
70EC CJK UNIFIED IDEOGRAPH-#70EC, IRGKangXi=0671.081, RSKangXi=86.6, Def{cinders, ashes, embers; remnants}
70ED CJK UNIFIED IDEOGRAPH-#70ED, IRGKangXi=0671.081, RSKangXi=86.6, Def{hot; heat; fever; restless; zeal}
70EE CJK UNIFIED IDEOGRAPH-#70EE, IRGKangXi=0671.081, RSKangXi=86.6
70EF CJK UNIFIED IDEOGRAPH-#70EF, IRGKangXi=0671.100, RSKangXi=86.7, Def{alkene}
70F0 CJK UNIFIED IDEOGRAPH-#70F0, IRGKangXi=0671.120, RSKangXi=86.7
70F1 CJK UNIFIED IDEOGRAPH-#70F1, IRGKangXi=0671.130, RSKangXi=86.7, Def{bright, brilliant, clear; hot}
70F2 CJK UNIFIED IDEOGRAPH-#70F2, IRGKangXi=0671.140, RSKangXi=86.7
70F3 CJK UNIFIED IDEOGRAPH-#70F3, IRGKangXi=0671.150, RSKangXi=86.7
70F4 CJK UNIFIED IDEOGRAPH-#70F4, IRGKangXi=0671.160, RSKangXi=86.7, Def{hydrocarbon}
70F5 CJK UNIFIED IDEOGRAPH-#70F5, IRGKangXi=0671.170, RSKangXi=86.7
70F6 CJK UNIFIED IDEOGRAPH-#70F6, IRGKangXi=0671.180, RSKangXi=86.7
70F7 CJK UNIFIED IDEOGRAPH-#70F7, IRGKangXi=0671.190, RSKangXi=86.7, Def{alkane}
70F8 CJK UNIFIED IDEOGRAPH-#70F8, IRGKangXi=0671.200, RSKangXi=86.7
70F9 CJK UNIFIED IDEOGRAPH-#70F9, IRGKangXi=0671.210, RSKangXi=86.7, Def{boil, cook; quick fry, stir fry}
70FA CJK UNIFIED IDEOGRAPH-#70FA, IRGKangXi=0671.280, RSKangXi=86.7, Def{(said of fire) bright}
70FB CJK UNIFIED IDEOGRAPH-#70FB, IRGKangXi=0671.300, RSKangXi=86.7
70FC CJK UNIFIED IDEOGRAPH-#70FC, IRGKangXi=0672.010, RSKangXi=86.7
70FD CJK UNIFIED IDEOGRAPH-#70FD, IRGKangXi=0672.040, RSKangXi=86.7, Def{signal fire; tower where signal}
70FE CJK UNIFIED IDEOGRAPH-#70FE, IRGKangXi=0672.060, RSKangXi=32.8
70FF CJK UNIFIED IDEOGRAPH-#70FF, IRGKangXi=0672.070, RSKangXi=86.7
7100 CJK UNIFIED IDEOGRAPH-#7100, IRGKangXi=0672.090, RSKangXi=86.7
7101 CJK UNIFIED IDEOGRAPH-#7101, IRGKangXi=0672.110, RSKangXi=86.7
7102 CJK UNIFIED IDEOGRAPH-#7102, IRGKangXi=0672.120, RSKangXi=86.7
7103 CJK UNIFIED IDEOGRAPH-#7103, IRGKangXi=0672.130, RSKangXi=86.7
7104 CJK UNIFIED IDEOGRAPH-#7104, IRGKangXi=0672.140, RSKangXi=86.7, Def{rising flames or fumes; aroma}
7105 CJK UNIFIED IDEOGRAPH-#7105, IRGKangXi=0672.160, RSKangXi=86.7, Def{(Cant.) to roast, suffocate}
7106 CJK UNIFIED IDEOGRAPH-#7106, IRGKangXi=0672.180, RSKangXi=86.7
7107 CJK UNIFIED IDEOGRAPH-#7107, IRGKangXi=0672.190, RSKangXi=86.7
7108 CJK UNIFIED IDEOGRAPH-#7108, IRGKangXi=0672.200, RSKangXi=86.7
7109 CJK UNIFIED IDEOGRAPH-#7109, IRGKangXi=0672.210, RSKangXi=86.7, Def{thereupon, then; how? why? where?}
710A CJK UNIFIED IDEOGRAPH-#710A, IRGKangXi=0673.010, RSKangXi=86.7, Def{weld, solder}
710B CJK UNIFIED IDEOGRAPH-#710B, IRGKangXi=0673.020, RSKangXi=86.7
710C CJK UNIFIED IDEOGRAPH-#710C, IRGKangXi=0673.030, RSKangXi=86.7, Def{to light}
710D CJK UNIFIED IDEOGRAPH-#710D, IRGKangXi=0673.050, RSKangXi=86.7
710E CJK UNIFIED IDEOGRAPH-#710E, IRGKangXi=0673.111, RSKangXi=86.7
710F CJK UNIFIED IDEOGRAPH-#710F, IRGKangXi=0673.111, RSKangXi=86.7
7110 CJK UNIFIED IDEOGRAPH-#7110, IRGKangXi=0673.111, RSKangXi=86.7
7111 CJK UNIFIED IDEOGRAPH-#7111, IRGKangXi=0673.111, RSKangXi=86.7
7112 CJK UNIFIED IDEOGRAPH-#7112, IRGKangXi=0673.111, RSKangXi=86.7
7113 CJK UNIFIED IDEOGRAPH-#7113, IRGKangXi=0673.111, RSKangXi=86.7, Def{(Cant.) onomatopoetic, the sound of a fiercely-burning fire}
7114 CJK UNIFIED IDEOGRAPH-#7114, IRGKangXi=0673.111, RSKangXi=86.8, Def{flame, blaze; glowing, blazing}
7115 CJK UNIFIED IDEOGRAPH-#7115, IRGKangXi=0673.111, RSKangXi=86.7, Def{shining}
7116 CJK UNIFIED IDEOGRAPH-#7116, IRGKangXi=0673.111, RSKangXi=86.7, Def{simmer, cook over slow fire}
7117 CJK UNIFIED IDEOGRAPH-#7117, IRGKangXi=0673.111, RSKangXi=86.7, Def{(Cant.) to roast, bake; to suffocate, stuffy}
7118 CJK UNIFIED IDEOGRAPH-#7118, IRGKangXi=0673.111, RSKangXi=86.7, Def{shine, illuminate; cover, envelope}
7119 CJK UNIFIED IDEOGRAPH-#7119, IRGKangXi=0673.120, RSKangXi=86.8, Def{dry over slow fire; bake; roast}
711A CJK UNIFIED IDEOGRAPH-#711A, IRGKangXi=0673.130, RSKangXi=86.8, Def{burn}
711B CJK UNIFIED IDEOGRAPH-#711B, IRGKangXi=0673.150, RSKangXi=86.8
711C CJK UNIFIED IDEOGRAPH-#711C, IRGKangXi=0673.160, RSKangXi=86.8, Def{fire, flames; bright, shining}
711D CJK UNIFIED IDEOGRAPH-#711D, IRGKangXi=0673.180, RSKangXi=86.8
711E CJK UNIFIED IDEOGRAPH-#711E, IRGKangXi=0673.200, RSKangXi=86.8, Def{dim}
711F CJK UNIFIED IDEOGRAPH-#711F, IRGKangXi=0673.210, RSKangXi=86.8
7120 CJK UNIFIED IDEOGRAPH-#7120, IRGKangXi=0673.240, RSKangXi=86.8, Def{temper; burn}
7121 CJK UNIFIED IDEOGRAPH-#7121, IRGKangXi=0673.260, RSKangXi=86.8, Def{negative, no, not; lack, have no}
7122 CJK UNIFIED IDEOGRAPH-#7122, IRGKangXi=0674.010, RSKangXi=86.8
7123 CJK UNIFIED IDEOGRAPH-#7123, IRGKangXi=0674.030, RSKangXi=86.8
7124 CJK UNIFIED IDEOGRAPH-#7124, IRGKangXi=0674.040, RSKangXi=86.8
7125 CJK UNIFIED IDEOGRAPH-#7125, IRGKangXi=0674.050, RSKangXi=86.8
7126 CJK UNIFIED IDEOGRAPH-#7126, IRGKangXi=0674.060, RSKangXi=86.8, Def{burned, scorched; anxious, vexed}
7127 CJK UNIFIED IDEOGRAPH-#7127, IRGKangXi=0674.090, RSKangXi=86.8
7128 CJK UNIFIED IDEOGRAPH-#7128, IRGKangXi=0674.100, RSKangXi=86.8
7129 CJK UNIFIED IDEOGRAPH-#7129, IRGKangXi=0674.120, RSKangXi=86.8
712A CJK UNIFIED IDEOGRAPH-#712A, IRGKangXi=0674.150, RSKangXi=86.8
712B CJK UNIFIED IDEOGRAPH-#712B, IRGKangXi=0674.170, RSKangXi=86.8, Def{(Cant.) hot; to scald, burn}
712C CJK UNIFIED IDEOGRAPH-#712C, IRGKangXi=0674.180, RSKangXi=86.8
712D CJK UNIFIED IDEOGRAPH-#712D, IRGKangXi=0674.200, RSKangXi=86.8, Def{orphan; alone, desolate}
712E CJK UNIFIED IDEOGRAPH-#712E, IRGKangXi=0674.230, RSKangXi=86.8, Def{heat, radiate heat; broil; cauterize}
712F CJK UNIFIED IDEOGRAPH-#712F, IRGKangXi=0675.020, RSKangXi=86.8, Def{boil vegetables for a very short time; scald}
7130 CJK UNIFIED IDEOGRAPH-#7130, IRGKangXi=0675.040, RSKangXi=86.8, Def{flame, blaze; glowing, blazing}
7131 CJK UNIFIED IDEOGRAPH-#7131, IRGKangXi=0675.050, RSKangXi=86.8, Def{flames}
7132 CJK UNIFIED IDEOGRAPH-#7132, IRGKangXi=0675.060, RSKangXi=86.8
7133 CJK UNIFIED IDEOGRAPH-#7133, IRGKangXi=0675.080, RSKangXi=86.8
7134 CJK UNIFIED IDEOGRAPH-#7134, IRGKangXi=0675.090, RSKangXi=86.8, Def{bright; flame}
7135 CJK UNIFIED IDEOGRAPH-#7135, IRGKangXi=0675.110, RSKangXi=86.8, Def{to temper steel}
7136 CJK UNIFIED IDEOGRAPH-#7136, IRGKangXi=0675.120, RSKangXi=86.8, Def{yes, certainly; pledge, promise}
7137 CJK UNIFIED IDEOGRAPH-#7137, IRGKangXi=0675.150, RSKangXi=86.8
7138 CJK UNIFIED IDEOGRAPH-#7138, IRGKangXi=0675.160, RSKangXi=86.8
7139 CJK UNIFIED IDEOGRAPH-#7139, IRGKangXi=0675.191, RSKangXi=86.8
713A CJK UNIFIED IDEOGRAPH-#713A, IRGKangXi=0675.191, RSKangXi=86.8
713B CJK UNIFIED IDEOGRAPH-#713B, IRGKangXi=0675.191, RSKangXi=86.8, Def{breath}
713C CJK UNIFIED IDEOGRAPH-#713C, IRGKangXi=0675.191, RSKangXi=86.8, Def{burn; bake; heat; roast}
713D CJK UNIFIED IDEOGRAPH-#713D, IRGKangXi=0675.191, RSKangXi=86.8
713E CJK UNIFIED IDEOGRAPH-#713E, IRGKangXi=0675.191, RSKangXi=86.8, Def{(Cant.) soft}
713F CJK UNIFIED IDEOGRAPH-#713F, IRGKangXi=0675.191, RSKangXi=86.8, Def{name of a place in northeastern Taiwan; a kind of thick soup}
7140 CJK UNIFIED IDEOGRAPH-#7140, IRGKangXi=0675.191, RSKangXi=86.8, Def{(Cant.) to smoke; to fumigate}
7141 CJK UNIFIED IDEOGRAPH-#7141, IRGKangXi=0675.210, RSKangXi=86.9, Def{hearth; (Cant.) soft, tender}
7142 CJK UNIFIED IDEOGRAPH-#7142, IRGKangXi=0675.220, RSKangXi=86.9
7143 CJK UNIFIED IDEOGRAPH-#7143, IRGKangXi=0675.230, RSKangXi=86.9, Def{remove, get rid of; scatter}
7144 CJK UNIFIED IDEOGRAPH-#7144, IRGKangXi=0675.240, RSKangXi=86.9
7145 CJK UNIFIED IDEOGRAPH-#7145, IRGKangXi=0678.161, RSKangXi=86.9, Def{forge metal; perfect one's skill}
7146 CJK UNIFIED IDEOGRAPH-#7146, IRGKangXi=0675.260, RSKangXi=86.9, Def{raging fire; to forge, work}
7147 CJK UNIFIED IDEOGRAPH-#7147, IRGKangXi=0675.270, RSKangXi=86.9, Def{weld, solder}
7148 CJK UNIFIED IDEOGRAPH-#7148, IRGKangXi=0676.010, RSKangXi=86.9
7149 CJK UNIFIED IDEOGRAPH-#7149, IRGKangXi=0676.040, RSKangXi=86.9, Def{smelt, refine; distill, condense}
714A CJK UNIFIED IDEOGRAPH-#714A, IRGKangXi=0676.050, RSKangXi=86.9, Def{warm}
714B CJK UNIFIED IDEOGRAPH-#714B, IRGKangXi=0676.060, RSKangXi=86.9
714C CJK UNIFIED IDEOGRAPH-#714C, IRGKangXi=0676.070, RSKangXi=86.9, Def{bright, shining, luminous}
714D CJK UNIFIED IDEOGRAPH-#714D, IRGKangXi=0676.080, RSKangXi=86.9, Def{to color by smoke}
714E CJK UNIFIED IDEOGRAPH-#714E, IRGKangXi=0676.100, RSKangXi=86.9, Def{fry in fat or oil; boil in water}
714F CJK UNIFIED IDEOGRAPH-#714F, IRGKangXi=0676.110, RSKangXi=86.9, Def{dry by fire; iron}
7150 CJK UNIFIED IDEOGRAPH-#7150, IRGKangXi=0676.120, RSKangXi=86.9
7151 CJK UNIFIED IDEOGRAPH-#7151, IRGKangXi=0676.130, Def{cook}
7152 CJK UNIFIED IDEOGRAPH-#7152, IRGKangXi=0676.140, RSKangXi=86.9, Def{brilliant red; glowing}
7153 CJK UNIFIED IDEOGRAPH-#7153, IRGKangXi=0676.150, RSKangXi=86.9
7154 CJK UNIFIED IDEOGRAPH-#7154, IRGKangXi=0676.160, RSKangXi=86.9
7155 CJK UNIFIED IDEOGRAPH-#7155, IRGKangXi=0676.170, RSKangXi=86.9, Def{bright, splendid, glorious}
7156 CJK UNIFIED IDEOGRAPH-#7156, IRGKangXi=0676.220, RSKangXi=86.9, Def{warm, genial}
7157 CJK UNIFIED IDEOGRAPH-#7157, IRGKangXi=0677.010, RSKangXi=86.9
7158 CJK UNIFIED IDEOGRAPH-#7158, IRGKangXi=0677.020, RSKangXi=86.9
7159 CJK UNIFIED IDEOGRAPH-#7159, IRGKangXi=0677.070, RSKangXi=86.9, Def{smoke, soot; opium; tobacco, cigarettes}
715A CJK UNIFIED IDEOGRAPH-#715A, IRGKangXi=0677.120, RSKangXi=86.9, Def{fire}
715B CJK UNIFIED IDEOGRAPH-#715B, IRGKangXi=0812.190, RSKangXi=109.9
715C CJK UNIFIED IDEOGRAPH-#715C, IRGKangXi=0677.150, RSKangXi=86.9, Def{bright, shining, brilliant}
715D CJK UNIFIED IDEOGRAPH-#715D, IRGKangXi=0677.170, RSKangXi=86.9, Def{twisted paper for lighting cigarettes}
715E CJK UNIFIED IDEOGRAPH-#715E, IRGKangXi=0677.180, RSKangXi=86.9, Def{malignant deity; baleful, noxious; strike dead}
715F CJK UNIFIED IDEOGRAPH-#715F, IRGKangXi=0677.200, RSKangXi=86.9, Def{bright room}
7160 CJK UNIFIED IDEOGRAPH-#7160, IRGKangXi=0677.210, RSKangXi=86.9, Def{to fry in fat or oil. to scald}
7161 CJK UNIFIED IDEOGRAPH-#7161, IRGKangXi=0677.240, RSKangXi=86.9
7162 CJK UNIFIED IDEOGRAPH-#7162, IRGKangXi=0677.250, RSKangXi=86.9, Def{alone; no friends or relatives}
7163 CJK UNIFIED IDEOGRAPH-#7163, IRGKangXi=0677.280, RSKangXi=86.9
7164 CJK UNIFIED IDEOGRAPH-#7164, IRGKangXi=0677.290, RSKangXi=86.9, Def{coal, coke, charcoal, carbon}
7165 CJK UNIFIED IDEOGRAPH-#7165, IRGKangXi=0677.330, RSKangXi=86.9, Def{shining, brilliant, lustrous}
7166 CJK UNIFIED IDEOGRAPH-#7166, IRGKangXi=0677.350, RSKangXi=86.9, Def{kind, gentle, gracious, genial}
7167 CJK UNIFIED IDEOGRAPH-#7167, IRGKangXi=0677.360, RSKangXi=86.9, Def{shine, illumine, reflect}
7168 CJK UNIFIED IDEOGRAPH-#7168, IRGKangXi=0678.010, RSKangXi=86.9, Def{to stew, simmer}
7169 CJK UNIFIED IDEOGRAPH-#7169, IRGKangXi=0678.030, RSKangXi=86.9, Def{bother, vex, trouble; troublesome}
716A CJK UNIFIED IDEOGRAPH-#716A, IRGKangXi=0678.040, RSKangXi=86.9
716B CJK UNIFIED IDEOGRAPH-#716B, IRGKangXi=0678.060, RSKangXi=86.9
716C CJK UNIFIED IDEOGRAPH-#716C, IRGKangXi=0678.070, RSKangXi=86.9, Def{roast; scorch; melt; flame}
716D CJK UNIFIED IDEOGRAPH-#716D, IRGKangXi=0678.140, RSKangXi=86.9
716E CJK UNIFIED IDEOGRAPH-#716E, IRGKangXi=0678.161, RSKangXi=86.8, Def{cook}
716F CJK UNIFIED IDEOGRAPH-#716F, IRGKangXi=0678.161, RSKangXi=86.9
7170 CJK UNIFIED IDEOGRAPH-#7170, IRGKangXi=0678.161, RSKangXi=86.9
7171 CJK UNIFIED IDEOGRAPH-#7171, IRGKangXi=0678.161, RSKangXi=86.9, Def{(Cant.) 火煱, to instant-boil thin slices of meat and vegetables in a chafing dish at the dining table}
7172 CJK UNIFIED IDEOGRAPH-#7172, IRGKangXi=0678.161, RSKangXi=86.9, Def{to heat; to boil a saucepan}
7173 CJK UNIFIED IDEOGRAPH-#7173, IRGKangXi=0678.161, RSKangXi=86.9, Def{be burned, to char (in cooking)}
7174 CJK UNIFIED IDEOGRAPH-#7174, IRGKangXi=0678.161, RSKangXi=86.9, Def{sultriness, stuffiness}
7175 CJK UNIFIED IDEOGRAPH-#7175, IRGKangXi=0678.161, RSKangXi=86.9
7176 CJK UNIFIED IDEOGRAPH-#7176, IRGKangXi=0678.161, RSKangXi=86.9
7177 CJK UNIFIED IDEOGRAPH-#7177, IRGKangXi=0678.161, RSKangXi=86.9
7178 CJK UNIFIED IDEOGRAPH-#7178, IRGKangXi=0678.161, RSKangXi=86.9, Def{to stir-fry before broiling or stewing}
7179 CJK UNIFIED IDEOGRAPH-#7179, IRGKangXi=0678.170, RSKangXi=86.10
717A CJK UNIFIED IDEOGRAPH-#717A, IRGKangXi=0678.190, RSKangXi=86.9
717B CJK UNIFIED IDEOGRAPH-#717B, IRGKangXi=0678.220, RSKangXi=86.10, Def{to warm; to toast}
717C CJK UNIFIED IDEOGRAPH-#717C, IRGKangXi=0678.230, RSKangXi=86.10
717D CJK UNIFIED IDEOGRAPH-#717D, IRGKangXi=0678.250, RSKangXi=86.10, Def{stir up, incite, agitate, provoke}
717E CJK UNIFIED IDEOGRAPH-#717E, IRGKangXi=0678.270, RSKangXi=86.10
717F CJK UNIFIED IDEOGRAPH-#717F, IRGKangXi=0678.300, RSKangXi=86.10
7180 CJK UNIFIED IDEOGRAPH-#7180, IRGKangXi=0678.330, RSKangXi=86.10, Def{the blaze of fire; dazzling}
7181 CJK UNIFIED IDEOGRAPH-#7181, IRGKangXi=0678.340, RSKangXi=86.10
7182 CJK UNIFIED IDEOGRAPH-#7182, IRGKangXi=0678.360, RSKangXi=86.10
7183 CJK UNIFIED IDEOGRAPH-#7183, IRGKangXi=0679.010, RSKangXi=86.10
7184 CJK UNIFIED IDEOGRAPH-#7184, IRGKangXi=0679.030, RSKangXi=86.10, Def{put out, extinguish, quash}
7185 CJK UNIFIED IDEOGRAPH-#7185, IRGKangXi=0679.040, RSKangXi=86.10, Def{smooth out, iron out}
7186 CJK UNIFIED IDEOGRAPH-#7186, IRGKangXi=0679.060, RSKangXi=86.10
7187 CJK UNIFIED IDEOGRAPH-#7187, IRGKangXi=0679.070, RSKangXi=86.10, Def{bake}
7188 CJK UNIFIED IDEOGRAPH-#7188, IRGKangXi=0679.080, RSKangXi=86.10, Def{bright, splendid, glorious}
7189 CJK UNIFIED IDEOGRAPH-#7189, IRGKangXi=0679.090, RSKangXi=86.10, Def{yellow color}
718A CJK UNIFIED IDEOGRAPH-#718A, IRGKangXi=0679.100, RSKangXi=86.10, Def{a bear; brilliant; bright; surname}
718B CJK UNIFIED IDEOGRAPH-#718B, IRGKangXi=0679.120, RSKangXi=86.10
718C CJK UNIFIED IDEOGRAPH-#718C, IRGKangXi=0679.140, RSKangXi=86.10
718D CJK UNIFIED IDEOGRAPH-#718D, IRGKangXi=0679.150, RSKangXi=86.10
718E CJK UNIFIED IDEOGRAPH-#718E, IRGKangXi=0679.160, RSKangXi=86.10
718F CJK UNIFIED IDEOGRAPH-#718F, IRGKangXi=0679.170, RSKangXi=86.10, Def{smoke, fog, vapor; smoke, cure}
7190 CJK UNIFIED IDEOGRAPH-#7190, IRGKangXi=0679.190, RSKangXi=86.10
7191 CJK UNIFIED IDEOGRAPH-#7191, IRGKangXi=0679.200, RSKangXi=86.10
7192 CJK UNIFIED IDEOGRAPH-#7192, IRGKangXi=0679.210, RSKangXi=86.10, Def{shine, shimmer; shining, dazzling}
7193 CJK UNIFIED IDEOGRAPH-#7193, IRGKangXi=0680.040, Def{to bank a fire; to smother, put out}
7194 CJK UNIFIED IDEOGRAPH-#7194, IRGKangXi=0680.101, RSKangXi=86.10, Def{melt, smelt, fuse; mold}
7195 CJK UNIFIED IDEOGRAPH-#7195, IRGKangXi=0680.101, RSKangXi=86.10
7196 CJK UNIFIED IDEOGRAPH-#7196, IRGKangXi=0680.101, RSKangXi=86.10, Def{same as 燄 U+71C4, flame; blazing, brilliant}
7197 CJK UNIFIED IDEOGRAPH-#7197, IRGKangXi=0680.101, RSKangXi=86.10, Def{stir-fry or boil in water or oil then cook with a sauce}
7198 CJK UNIFIED IDEOGRAPH-#7198, IRGKangXi=0680.101, RSKangXi=86.10, Def{to steam}
7199 CJK UNIFIED IDEOGRAPH-#7199, IRGKangXi=0678.161, RSKangXi=86.10, Def{bright, splendid, glorious}
719A CJK UNIFIED IDEOGRAPH-#719A, IRGKangXi=0680.120, RSKangXi=86.11
719B CJK UNIFIED IDEOGRAPH-#719B, IRGKangXi=0680.130, RSKangXi=86.11, Def{blaze}
719C CJK UNIFIED IDEOGRAPH-#719C, IRGKangXi=0680.140, RSKangXi=86.11
719D CJK UNIFIED IDEOGRAPH-#719D, IRGKangXi=0680.150, RSKangXi=86.11, Def{(Cant.) to scald with steam}
719E CJK UNIFIED IDEOGRAPH-#719E, IRGKangXi=0680.160, RSKangXi=86.11
719F CJK UNIFIED IDEOGRAPH-#719F, IRGKangXi=0680.200, RSKangXi=86.11, Def{well-cooked; ripe; familiar with}
71A0 CJK UNIFIED IDEOGRAPH-#71A0, IRGKangXi=0680.220, RSKangXi=86.11, Def{bright and sparkling}
71A1 CJK UNIFIED IDEOGRAPH-#71A1, IRGKangXi=0680.240, RSKangXi=86.11
71A2 CJK UNIFIED IDEOGRAPH-#71A2, IRGKangXi=0680.260, RSKangXi=86.11
71A3 CJK UNIFIED IDEOGRAPH-#71A3, IRGKangXi=0680.300, RSKangXi=86.11
71A4 CJK UNIFIED IDEOGRAPH-#71A4, IRGKangXi=0680.310, RSKangXi=86.11
71A5 CJK UNIFIED IDEOGRAPH-#71A5, IRGKangXi=0680.320, RSKangXi=86.11, Def{heat up by steaming}
71A6 CJK UNIFIED IDEOGRAPH-#71A6, IRGKangXi=0680.330, RSKangXi=86.10
71A7 CJK UNIFIED IDEOGRAPH-#71A7, IRGKangXi=0680.340, RSKangXi=86.11
71A8 CJK UNIFIED IDEOGRAPH-#71A8, IRGKangXi=0680.350, RSKangXi=86.11, Def{iron, press}
71A9 CJK UNIFIED IDEOGRAPH-#71A9, IRGKangXi=0680.360, RSKangXi=86.11
71AA CJK UNIFIED IDEOGRAPH-#71AA, IRGKangXi=0680.380, RSKangXi=86.11
71AB CJK UNIFIED IDEOGRAPH-#71AB, IRGKangXi=0680.390, RSKangXi=86.11
71AC CJK UNIFIED IDEOGRAPH-#71AC, IRGKangXi=0680.410, RSKangXi=86.11, Def{cook down, to boil; endure}
71AD CJK UNIFIED IDEOGRAPH-#71AD, IRGKangXi=0681.010, RSKangXi=86.11
71AE CJK UNIFIED IDEOGRAPH-#71AE, IRGKangXi=0681.020, RSKangXi=86.11
71AF CJK UNIFIED IDEOGRAPH-#71AF, IRGKangXi=0681.030, RSKangXi=86.11, Def{by fire}
71B0 CJK UNIFIED IDEOGRAPH-#71B0, IRGKangXi=0681.040, RSKangXi=86.11, Def{great drought; heat}
71B1 CJK UNIFIED IDEOGRAPH-#71B1, IRGKangXi=0681.080, RSKangXi=86.11, Def{hot; heat; fever; restless; zeal}
71B2 CJK UNIFIED IDEOGRAPH-#71B2, IRGKangXi=0681.090, RSKangXi=86.11, Def{bright}
71B3 CJK UNIFIED IDEOGRAPH-#71B3, IRGKangXi=0681.141, RSKangXi=86.11
71B4 CJK UNIFIED IDEOGRAPH-#71B4, IRGKangXi=0681.141, RSKangXi=86.11
71B5 CJK UNIFIED IDEOGRAPH-#71B5, IRGKangXi=0681.141, RSKangXi=86.11, Def{entropy}
71B6 CJK UNIFIED IDEOGRAPH-#71B6, IRGKangXi=0681.170, RSKangXi=86.12
71B7 CJK UNIFIED IDEOGRAPH-#71B7, IRGKangXi=0681.180, RSKangXi=86.12
71B8 CJK UNIFIED IDEOGRAPH-#71B8, IRGKangXi=0681.200, RSKangXi=86.12, Def{put out}
71B9 CJK UNIFIED IDEOGRAPH-#71B9, IRGKangXi=0681.210, RSKangXi=86.12, Def{dim light, glimmer; warm, bright}
71BA CJK UNIFIED IDEOGRAPH-#71BA, IRGKangXi=0681.220, RSKangXi=86.12, Def{dim light, glimmer; warm}
71BB CJK UNIFIED IDEOGRAPH-#71BB, IRGKangXi=0681.230, RSKangXi=86.12, Def{to heat; to roast; to burn}
71BC CJK UNIFIED IDEOGRAPH-#71BC, IRGKangXi=0681.240, RSKangXi=86.12
71BD CJK UNIFIED IDEOGRAPH-#71BD, IRGKangXi=0681.250, RSKangXi=86.12
71BE CJK UNIFIED IDEOGRAPH-#71BE, IRGKangXi=0681.260, RSKangXi=86.12, Def{burning-hot, intense; to burn, blaze; splendid, illustrious}
71BF CJK UNIFIED IDEOGRAPH-#71BF, IRGKangXi=0681.290, RSKangXi=86.12
71C0 CJK UNIFIED IDEOGRAPH-#71C0, IRGKangXi=0682.010, RSKangXi=86.12, Def{to make a fire; blaze}
71C1 CJK UNIFIED IDEOGRAPH-#71C1, IRGKangXi=0682.030, RSKangXi=86.12, Def{bright, glorious, splendid, flame}
71C2 CJK UNIFIED IDEOGRAPH-#71C2, IRGKangXi=0682.040, RSKangXi=86.12, Def{smoke, fumes; tobacco, opium; (Cant.) to singe}
71C3 CJK UNIFIED IDEOGRAPH-#71C3, IRGKangXi=0682.070, RSKangXi=86.12, Def{burn; light fire, ignite}
71C4 CJK UNIFIED IDEOGRAPH-#71C4, IRGKangXi=0682.080, RSKangXi=86.12, Def{flame; blazing, brilliant}
71C5 CJK UNIFIED IDEOGRAPH-#71C5, IRGKangXi=0682.100, RSKangXi=86.12
71C6 CJK UNIFIED IDEOGRAPH-#71C6, IRGKangXi=0682.120, RSKangXi=86.12
71C7 CJK UNIFIED IDEOGRAPH-#71C7, IRGKangXi=0682.130, RSKangXi=86.12
71C8 CJK UNIFIED IDEOGRAPH-#71C8, IRGKangXi=0682.140, RSKangXi=86.12, Def{lantern, lamp}
71C9 CJK UNIFIED IDEOGRAPH-#71C9, IRGKangXi=0682.150, RSKangXi=86.12, Def{heat with fire; stew}
71CA CJK UNIFIED IDEOGRAPH-#71CA, IRGKangXi=0682.190, RSKangXi=86.12, Def{luxuriant}
71CB CJK UNIFIED IDEOGRAPH-#71CB, IRGKangXi=0682.210, RSKangXi=86.12, Def{scorch, burn, scald; torch}
71CC CJK UNIFIED IDEOGRAPH-#71CC, IRGKangXi=0682.220, RSKangXi=86.12
71CD CJK UNIFIED IDEOGRAPH-#71CD, IRGKangXi=0683.010, RSKangXi=86.12
71CE CJK UNIFIED IDEOGRAPH-#71CE, IRGKangXi=0683.020, RSKangXi=86.12, Def{to burn, set afire; to illuminate; a signal lamp}
71CF CJK UNIFIED IDEOGRAPH-#71CF, IRGKangXi=0683.030, RSKangXi=86.12, Def{blaze}
71D0 CJK UNIFIED IDEOGRAPH-#71D0, IRGKangXi=0683.050, RSKangXi=86.12, Def{phosphorus}
71D1 CJK UNIFIED IDEOGRAPH-#71D1, IRGKangXi=0683.060, RSKangXi=86.12
71D2 CJK UNIFIED IDEOGRAPH-#71D2, IRGKangXi=0683.080, RSKangXi=86.12, Def{burn; bake; heat; roast}
71D3 CJK UNIFIED IDEOGRAPH-#71D3, IRGKangXi=0683.090, RSKangXi=86.12
71D4 CJK UNIFIED IDEOGRAPH-#71D4, IRGKangXi=0683.130, RSKangXi=86.12, Def{to roast; to burn}
71D5 CJK UNIFIED IDEOGRAPH-#71D5, IRGKangXi=0683.160, RSKangXi=86.12, Def{swallow (bird); comfort, enjoy}
71D6 CJK UNIFIED IDEOGRAPH-#71D6, IRGKangXi=0683.170, RSKangXi=86.12, Def{reheat food}
71D7 CJK UNIFIED IDEOGRAPH-#71D7, IRGKangXi=0683.180, RSKangXi=86.12, Def{warming sake, to heat sake}
71D8 CJK UNIFIED IDEOGRAPH-#71D8, IRGKangXi=0683.190, RSKangXi=86.12, Def{(Cant.) to suck or chew without using the teeth}
71D9 CJK UNIFIED IDEOGRAPH-#71D9, IRGKangXi=0684.010, RSKangXi=86.12, Def{scald, heat; wash; iron clothes}
71DA CJK UNIFIED IDEOGRAPH-#71DA, IRGKangXi=0684.060, RSKangXi=86.12
71DB CJK UNIFIED IDEOGRAPH-#71DB, IRGKangXi=0684.090, RSKangXi=86.12
71DC CJK UNIFIED IDEOGRAPH-#71DC, IRGKangXi=0684.161, RSKangXi=86.12, Def{simmer, cook over slow fire}
71DD CJK UNIFIED IDEOGRAPH-#71DD, IRGKangXi=0684.161, RSKangXi=86.12
71DE CJK UNIFIED IDEOGRAPH-#71DE, IRGKangXi=0684.161, RSKangXi=86.12
71DF CJK UNIFIED IDEOGRAPH-#71DF, IRGKangXi=0684.170, RSKangXi=86.13, Def{encampment, barracks; manage}
71E0 CJK UNIFIED IDEOGRAPH-#71E0, IRGKangXi=0684.180, RSKangXi=86.13, Def{warm; warmth}
71E1 CJK UNIFIED IDEOGRAPH-#71E1, IRGKangXi=0684.210, RSKangXi=86.13, Def{bright}
71E2 CJK UNIFIED IDEOGRAPH-#71E2, IRGKangXi=0684.240, RSKangXi=86.13
71E3 CJK UNIFIED IDEOGRAPH-#71E3, IRGKangXi=0684.250, RSKangXi=86.13, Def{disappointed}
71E4 CJK UNIFIED IDEOGRAPH-#71E4, IRGKangXi=0684.280, RSKangXi=86.13
71E5 CJK UNIFIED IDEOGRAPH-#71E5, IRGKangXi=0684.290, RSKangXi=86.13, Def{dry, parched, arid; quick-tempered}
71E6 CJK UNIFIED IDEOGRAPH-#71E6, IRGKangXi=0684.300, RSKangXi=86.13, Def{vivid, illuminating; bright}
71E7 CJK UNIFIED IDEOGRAPH-#71E7, IRGKangXi=0684.310, RSKangXi=86.13, Def{flintstone; beacon, signal fire; torch}
71E8 CJK UNIFIED IDEOGRAPH-#71E8, IRGKangXi=0685.030, RSKangXi=86.13
71E9 CJK UNIFIED IDEOGRAPH-#71E9, IRGKangXi=0685.050, RSKangXi=86.13
71EA CJK UNIFIED IDEOGRAPH-#71EA, IRGKangXi=0685.070, RSKangXi=86.13
71EB CJK UNIFIED IDEOGRAPH-#71EB, IRGKangXi=0685.080, RSKangXi=86.13
71EC CJK UNIFIED IDEOGRAPH-#71EC, IRGKangXi=0685.090, RSKangXi=86.13, Def{burn down; blaze, fire}
71ED CJK UNIFIED IDEOGRAPH-#71ED, IRGKangXi=0685.110, RSKangXi=86.13, Def{candle, taper; to shine, illuminate}
71EE CJK UNIFIED IDEOGRAPH-#71EE, IRGKangXi=0685.120, RSKangXi=86.13, Def{harmonize, blend; adjust}
71EF CJK UNIFIED IDEOGRAPH-#71EF, IRGKangXi=0685.140, RSKangXi=86.13
71F0 CJK UNIFIED IDEOGRAPH-#71F0, IRGKangXi=0685.190, RSKangXi=86.13
71F1 CJK UNIFIED IDEOGRAPH-#71F1, IRGKangXi=0685.201, RSKangXi=86.13
71F2 CJK UNIFIED IDEOGRAPH-#71F2, IRGKangXi=0685.201, RSKangXi=86.13
71F3 CJK UNIFIED IDEOGRAPH-#71F3, IRGKangXi=0685.201, RSKangXi=86.13
71F4 CJK UNIFIED IDEOGRAPH-#71F4, IRGKangXi=0685.201, RSKangXi=86.13, Def{ragout, cook, braise}
71F5 CJK UNIFIED IDEOGRAPH-#71F5, IRGKangXi=0685.201, RSKangXi=86.13, Def{a foot-warmer}
71F6 CJK UNIFIED IDEOGRAPH-#71F6, IRGKangXi=0685.201, RSKangXi=86.13, Def{(Cant.) to scorch, burn}
71F7 CJK UNIFIED IDEOGRAPH-#71F7, IRGKangXi=0685.201, RSKangXi=86.13, Def{disappointed}
71F8 CJK UNIFIED IDEOGRAPH-#71F8, IRGKangXi=0685.230, RSKangXi=86.14
71F9 CJK UNIFIED IDEOGRAPH-#71F9, IRGKangXi=0685.240, RSKangXi=86.14, Def{fire; wild fires}
71FA CJK UNIFIED IDEOGRAPH-#71FA, IRGKangXi=0685.270, RSKangXi=86.14, Def{the dry at the fire to roast}
71FB CJK UNIFIED IDEOGRAPH-#71FB, IRGKangXi=0685.290, RSKangXi=86.14, Def{smoke, fog, vapor; smoke, cure}
71FC CJK UNIFIED IDEOGRAPH-#71FC, IRGKangXi=0685.310, RSKangXi=86.14, Def{cinders, ashes, embers; remnants}
71FD CJK UNIFIED IDEOGRAPH-#71FD, IRGKangXi=0685.330, RSKangXi=86.14
71FE CJK UNIFIED IDEOGRAPH-#71FE, IRGKangXi=0685.350, RSKangXi=86.14, Def{shine, illuminate; cover, envelope}
71FF CJK UNIFIED IDEOGRAPH-#71FF, IRGKangXi=0686.010, RSKangXi=86.14, Def{shine, dazzle; brilliant, radiant}
7200 CJK UNIFIED IDEOGRAPH-#7200, IRGKangXi=0686.020, RSKangXi=86.14
7201 CJK UNIFIED IDEOGRAPH-#7201, IRGKangXi=0686.040, RSKangXi=86.14
7202 CJK UNIFIED IDEOGRAPH-#7202, IRGKangXi=0686.110, RSKangXi=86.14
7203 CJK UNIFIED IDEOGRAPH-#7203, IRGKangXi=0686.111, RSKangXi=86.14
7204 CJK UNIFIED IDEOGRAPH-#7204, IRGKangXi=0686.120, RSKangXi=86.15
7205 CJK UNIFIED IDEOGRAPH-#7205, IRGKangXi=0686.150, RSKangXi=86.15
7206 CJK UNIFIED IDEOGRAPH-#7206, IRGKangXi=0686.160, RSKangXi=86.15, Def{crackle, pop, burst, explode}
7207 CJK UNIFIED IDEOGRAPH-#7207, IRGKangXi=0686.170, RSKangXi=86.15, Def{burn}
7208 CJK UNIFIED IDEOGRAPH-#7208, IRGKangXi=0686.190, RSKangXi=86.15
7209 CJK UNIFIED IDEOGRAPH-#7209, IRGKangXi=0686.200, RSKangXi=86.15
720A CJK UNIFIED IDEOGRAPH-#720A, IRGKangXi=0686.220, RSKangXi=86.15
720B CJK UNIFIED IDEOGRAPH-#720B, IRGKangXi=0687.171, RSKangXi=86.16
720C CJK UNIFIED IDEOGRAPH-#720C, IRGKangXi=0686.240, RSKangXi=86.15
720D CJK UNIFIED IDEOGRAPH-#720D, IRGKangXi=0686.250, RSKangXi=86.15, Def{shine, glitter, sparkle}
720E CJK UNIFIED IDEOGRAPH-#720E, IRGKangXi=0686.271, RSKangXi=86.15
720F CJK UNIFIED IDEOGRAPH-#720F, IRGKangXi=0686.300, RSKangXi=86.16
7210 CJK UNIFIED IDEOGRAPH-#7210, IRGKangXi=0686.310, RSKangXi=86.16, Def{fireplace, stove, oven, furnace}
7211 CJK UNIFIED IDEOGRAPH-#7211, IRGKangXi=0686.340, RSKangXi=86.16
7212 CJK UNIFIED IDEOGRAPH-#7212, IRGKangXi=0686.380, RSKangXi=86.16
7213 CJK UNIFIED IDEOGRAPH-#7213, IRGKangXi=0687.010, RSKangXi=86.16, Def{flame; brilliant, blazing}
7214 CJK UNIFIED IDEOGRAPH-#7214, IRGKangXi=0687.030, RSKangXi=86.16
7215 CJK UNIFIED IDEOGRAPH-#7215, IRGKangXi=0687.040, RSKangXi=86.15
7216 CJK UNIFIED IDEOGRAPH-#7216, IRGKangXi=0687.100, RSKangXi=86.16, Def{fire}
7217 CJK UNIFIED IDEOGRAPH-#7217, IRGKangXi=0687.171, RSKangXi=86.16
7218 CJK UNIFIED IDEOGRAPH-#7218, IRGKangXi=0687.171, RSKangXi=86.16
7219 CJK UNIFIED IDEOGRAPH-#7219, IRGKangXi=0687.220, RSKangXi=86.17
721A CJK UNIFIED IDEOGRAPH-#721A, IRGKangXi=0687.240, RSKangXi=86.17, Def{bright; fiery}
721B CJK UNIFIED IDEOGRAPH-#721B, IRGKangXi=0687.250, RSKangXi=86.17, Def{rotten, spoiled, decayed}
721C CJK UNIFIED IDEOGRAPH-#721C, IRGKangXi=0687.290, RSKangXi=86.18
721D CJK UNIFIED IDEOGRAPH-#721D, IRGKangXi=0687.330, RSKangXi=86.18
721E CJK UNIFIED IDEOGRAPH-#721E, IRGKangXi=0687.340, RSKangXi=86.18
721F CJK UNIFIED IDEOGRAPH-#721F, IRGKangXi=0687.360, RSKangXi=86.18, Def{fire}
7220 CJK UNIFIED IDEOGRAPH-#7220, IRGKangXi=0688.021, RSKangXi=86.18
7221 CJK UNIFIED IDEOGRAPH-#7221, IRGKangXi=0688.030, RSKangXi=86.19
7222 CJK UNIFIED IDEOGRAPH-#7222, IRGKangXi=0688.080, RSKangXi=86.19
7223 CJK UNIFIED IDEOGRAPH-#7223, IRGKangXi=0688.100, RSKangXi=86.20
7224 CJK UNIFIED IDEOGRAPH-#7224, IRGKangXi=0688.120, RSKangXi=86.21
7225 CJK UNIFIED IDEOGRAPH-#7225, IRGKangXi=0688.140, RSKangXi=86.21, Def{simmer, cook over slow fire}
7226 CJK UNIFIED IDEOGRAPH-#7226, IRGKangXi=0688.151, RSKangXi=86.21
7227 CJK UNIFIED IDEOGRAPH-#7227, IRGKangXi=0688.180, RSKangXi=86.24
7228 CJK UNIFIED IDEOGRAPH-#7228, IRGKangXi=0688.210, RSKangXi=86.25, Def{oven, cooking stove; cook}
7229 CJK UNIFIED IDEOGRAPH-#7229, IRGKangXi=0688.240, RSKangXi=86.29, Def{(Cant.) to smoke, fumigate; to bleach with burning sulfur}
722A CJK UNIFIED IDEOGRAPH-#722A, IRGKangXi=0688.260, RSKangXi=87.0, Def{claw, nail, talon; animal feet}
722B CJK UNIFIED IDEOGRAPH-#722B, IRGKangXi=0688.281, RSKangXi=87.0, Def{radical 87}
722C CJK UNIFIED IDEOGRAPH-#722C, IRGKangXi=0688.320, RSKangXi=87.4, Def{crawl, creep; climb; scramble}
722D CJK UNIFIED IDEOGRAPH-#722D, IRGKangXi=0688.330, RSKangXi=87.4, Def{to dispute, fight, contend, strive}
722E CJK UNIFIED IDEOGRAPH-#722E, IRGKangXi=0689.020
722F CJK UNIFIED IDEOGRAPH-#722F, IRGKangXi=0689.030, RSKangXi=87.5
7230 CJK UNIFIED IDEOGRAPH-#7230, IRGKangXi=0689.050, RSKangXi=87.5, Def{lead on to; therefore, then}
7231 CJK UNIFIED IDEOGRAPH-#7231, IRGKangXi=0689.091, RSKangXi=87.6, Def{love, be fond of, like}
7232 CJK UNIFIED IDEOGRAPH-#7232, IRGKangXi=0689.130, RSKangXi=87.8, Def{do, handle, govern, act; be}
7233 CJK UNIFIED IDEOGRAPH-#7233, IRGKangXi=0689.221, RSKangXi=6.13
7234 CJK UNIFIED IDEOGRAPH-#7234, IRGKangXi=0689.261, RSKangXi=87.11
7235 CJK UNIFIED IDEOGRAPH-#7235, IRGKangXi=0689.290, RSKangXi=87.14, Def{feudal title or rank}
7236 CJK UNIFIED IDEOGRAPH-#7236, IRGKangXi=0690.010, RSKangXi=88.0, Def{father; KangXi radical 88}
7237 CJK UNIFIED IDEOGRAPH-#7237, IRGKangXi=0690.011, RSKangXi=88.2, Def{father, grandfather}
7238 CJK UNIFIED IDEOGRAPH-#7238, IRGKangXi=0690.030, RSKangXi=88.4, Def{father, papa}
7239 CJK UNIFIED IDEOGRAPH-#7239, IRGKangXi=0690.040, RSKangXi=88.6, Def{father, daddy}
723A CJK UNIFIED IDEOGRAPH-#723A, IRGKangXi=0690.110, RSKangXi=88.9, Def{father, grandfather}
723B CJK UNIFIED IDEOGRAPH-#723B, IRGKangXi=0690.130, RSKangXi=89.0, Def{diagrams for divination}
723C CJK UNIFIED IDEOGRAPH-#723C, IRGKangXi=0690.190, RSKangXi=89.5, Def{a small table or tiered stand filled with meat offerings}
723D CJK UNIFIED IDEOGRAPH-#723D, IRGKangXi=0690.220, RSKangXi=89.7, Def{happy, cheerful; refreshing}
723E CJK UNIFIED IDEOGRAPH-#723E, IRGKangXi=0691.040, RSKangXi=89.10, Def{you; that, those; final particle}
723F CJK UNIFIED IDEOGRAPH-#723F, IRGKangXi=0691.090, RSKangXi=90.0, Def{half of tree trunk; KangXi radical 90}
7240 CJK UNIFIED IDEOGRAPH-#7240, IRGKangXi=0691.150, RSKangXi=90.4, Def{bed, couch; bench; chassis}
7241 CJK UNIFIED IDEOGRAPH-#7241, IRGKangXi=0691.190, RSKangXi=90.5, Def{mooring stake; painter, mooring}
7242 CJK UNIFIED IDEOGRAPH-#7242, IRGKangXi=0692.020, RSKangXi=90.6, Def{female sheep, ewe}
7243 CJK UNIFIED IDEOGRAPH-#7243, IRGKangXi=0692.160, RSKangXi=90.9
7244 CJK UNIFIED IDEOGRAPH-#7244, IRGKangXi=0692.180, RSKangXi=90.10, Def{to walk rapidly}
7245 CJK UNIFIED IDEOGRAPH-#7245, IRGKangXi=0692.220, RSKangXi=90.11
7246 CJK UNIFIED IDEOGRAPH-#7246, IRGKangXi=0692.290, RSKangXi=90.13, Def{wall}
7247 CJK UNIFIED IDEOGRAPH-#7247, IRGKangXi=0692.360, RSKangXi=91.0, Def{slice, splinter, strip; rad. 91}
7248 CJK UNIFIED IDEOGRAPH-#7248, IRGKangXi=0693.030, RSKangXi=91.4, Def{printing blocks; edition}
7249 CJK UNIFIED IDEOGRAPH-#7249, IRGKangXi=0693.150, RSKangXi=91.5
724A CJK UNIFIED IDEOGRAPH-#724A, IRGKangXi=0693.160, RSKangXi=91.5
724B CJK UNIFIED IDEOGRAPH-#724B, IRGKangXi=0693.280, RSKangXi=91.8, Def{memorandum, official note}
724C CJK UNIFIED IDEOGRAPH-#724C, IRGKangXi=0693.340, RSKangXi=91.8, Def{signboard, placard}
724D CJK UNIFIED IDEOGRAPH-#724D, IRGKangXi=0693.391, RSKangXi=91.8, Def{writing tablet; documents, books}
724E CJK UNIFIED IDEOGRAPH-#724E, IRGKangXi=0693.420, RSKangXi=91.9
724F CJK UNIFIED IDEOGRAPH-#724F, IRGKangXi=0693.450, RSKangXi=91.9, Def{privy hole}
7250 CJK UNIFIED IDEOGRAPH-#7250, IRGKangXi=0694.010, RSKangXi=91.9, Def{sluice; flood gate, canal lock}
7251 CJK UNIFIED IDEOGRAPH-#7251, IRGKangXi=0694.020, RSKangXi=91.9
7252 CJK UNIFIED IDEOGRAPH-#7252, IRGKangXi=0694.030, RSKangXi=91.9, Def{documents, records; dispatch}
7253 CJK UNIFIED IDEOGRAPH-#7253, IRGKangXi=0694.060, RSKangXi=91.10, Def{tablet; public notice; register}
7254 CJK UNIFIED IDEOGRAPH-#7254, IRGKangXi=0694.070, RSKangXi=91.10, Def{gable}
7255 CJK UNIFIED IDEOGRAPH-#7255, IRGKangXi=0694.110, RSKangXi=91.11, Def{window}
7256 CJK UNIFIED IDEOGRAPH-#7256, IRGKangXi=0694.180, RSKangXi=91.11, Def{window; lead enlightenment}
7257 CJK UNIFIED IDEOGRAPH-#7257, IRGKangXi=0694.191, RSKangXi=91.11
7258 CJK UNIFIED IDEOGRAPH-#7258, IRGKangXi=0694.320, RSKangXi=91.15, Def{writing tablet; documents, books}
7259 CJK UNIFIED IDEOGRAPH-#7259, IRGKangXi=0695.030, RSKangXi=92.0, Def{tooth, molars, teeth; serrated}
725A CJK UNIFIED IDEOGRAPH-#725A, IRGKangXi=0695.100, RSKangXi=92.8
725B CJK UNIFIED IDEOGRAPH-#725B, IRGKangXi=0697.010, RSKangXi=93.0, Def{cow, ox, bull; KangXi radical93}
725C CJK UNIFIED IDEOGRAPH-#725C, IRGKangXi=0697.011, RSKangXi=93.0, Def{an ox, a cow Radical 93}
725D CJK UNIFIED IDEOGRAPH-#725D, IRGKangXi=0697.020, RSKangXi=93.2, Def{female of species; deep gorge}
725E CJK UNIFIED IDEOGRAPH-#725E, IRGKangXi=0697.040, RSKangXi=93.2
725F CJK UNIFIED IDEOGRAPH-#725F, IRGKangXi=0697.060, RSKangXi=93.2, Def{make; seek, get; barley; low}
7260 CJK UNIFIED IDEOGRAPH-#7260, IRGKangXi=0697.090, RSKangXi=93.3, Def{it; polled cattle}
7261 CJK UNIFIED IDEOGRAPH-#7261, IRGKangXi=0697.110, RSKangXi=93.3, Def{male of animals; bolt of door}
7262 CJK UNIFIED IDEOGRAPH-#7262, IRGKangXi=0698.010, RSKangXi=93.3, Def{prison; stable, pen; secure}
7263 CJK UNIFIED IDEOGRAPH-#7263, IRGKangXi=0698.030, RSKangXi=93.3, Def{fill, stuff; full}
7264 CJK UNIFIED IDEOGRAPH-#7264, IRGKangXi=0698.041, RSKangXi=93.3, Def{a bull}
7265 CJK UNIFIED IDEOGRAPH-#7265, IRGKangXi=0698.050, RSKangXi=93.4
7266 CJK UNIFIED IDEOGRAPH-#7266, IRGKangXi=0698.080, RSKangXi=93.4, Def{tail; hair; yak}
7267 CJK UNIFIED IDEOGRAPH-#7267, IRGKangXi=0698.160, RSKangXi=93.4, Def{tend cattle, shepherd}
7268 CJK UNIFIED IDEOGRAPH-#7268, IRGKangXi=0699.030, RSKangXi=93.4
7269 CJK UNIFIED IDEOGRAPH-#7269, IRGKangXi=0699.090, RSKangXi=93.4, Def{thing, substance, creature}
726A CJK UNIFIED IDEOGRAPH-#726A, IRGKangXi=0699.100, RSKangXi=93.4
726B CJK UNIFIED IDEOGRAPH-#726B, IRGKangXi=0699.111, RSKangXi=93.4
726C CJK UNIFIED IDEOGRAPH-#726C, IRGKangXi=0700.061, RSKangXi=93.4
726D CJK UNIFIED IDEOGRAPH-#726D, IRGKangXi=0699.150, RSKangXi=93.5
726E CJK UNIFIED IDEOGRAPH-#726E, IRGKangXi=0699.220, RSKangXi=93.5
726F CJK UNIFIED IDEOGRAPH-#726F, IRGKangXi=0699.240, RSKangXi=93.5, Def{cow; bull; ox}
7270 CJK UNIFIED IDEOGRAPH-#7270, IRGKangXi=0699.270, RSKangXi=93.5
7271 CJK UNIFIED IDEOGRAPH-#7271, IRGKangXi=0700.010, RSKangXi=93.5
7272 CJK UNIFIED IDEOGRAPH-#7272, IRGKangXi=0700.030, RSKangXi=93.5, Def{sacrificial animal; animal}
7273 CJK UNIFIED IDEOGRAPH-#7273, IRGKangXi=0700.040, RSKangXi=93.5
7274 CJK UNIFIED IDEOGRAPH-#7274, IRGKangXi=0700.050, RSKangXi=93.5, Def{gore, butt; resist}
7275 CJK UNIFIED IDEOGRAPH-#7275, IRGKangXi=0700.061, RSKangXi=37.6, Def{drag, pull, lead by hand}
7276 CJK UNIFIED IDEOGRAPH-#7276, IRGKangXi=0700.080, RSKangXi=93.6, Def{a nose-ring for an animal}
7277 CJK UNIFIED IDEOGRAPH-#7277, IRGKangXi=0700.090, RSKangXi=93.6, Def{cow or ox of one color, perfect}
7278 CJK UNIFIED IDEOGRAPH-#7278, IRGKangXi=0700.190, RSKangXi=93.6, Def{the female of certain animals; to bring forth young of animals}
7279 CJK UNIFIED IDEOGRAPH-#7279, IRGKangXi=0700.200, RSKangXi=93.6, Def{special, unique, distinguished}
727A CJK UNIFIED IDEOGRAPH-#727A, IRGKangXi=0700.221, RSKangXi=93.6, Def{sacrifice, give up; sacrificial}
727B CJK UNIFIED IDEOGRAPH-#727B, IRGKangXi=0700.270, RSKangXi=93.7
727C CJK UNIFIED IDEOGRAPH-#727C, IRGKangXi=0700.300, RSKangXi=93.7, Def{ox shank, person's name}
727D CJK UNIFIED IDEOGRAPH-#727D, IRGKangXi=0701.020, RSKangXi=93.7, Def{drag, pull, lead by hand}
727E CJK UNIFIED IDEOGRAPH-#727E, IRGKangXi=0701.070, RSKangXi=93.7, Def{to oppose; to gore}
727F CJK UNIFIED IDEOGRAPH-#727F, IRGKangXi=0701.110, RSKangXi=93.7
7280 CJK UNIFIED IDEOGRAPH-#7280, IRGKangXi=0701.140, RSKangXi=93.8, Def{rhinoceros; sharp, well-tempered}
7281 CJK UNIFIED IDEOGRAPH-#7281, IRGKangXi=0701.170, RSKangXi=93.7, Def{plow}
7282 CJK UNIFIED IDEOGRAPH-#7282, IRGKangXi=0701.200, RSKangXi=93.8, Def{plow}
7283 CJK UNIFIED IDEOGRAPH-#7283, IRGKangXi=0702.040, RSKangXi=93.8
7284 CJK UNIFIED IDEOGRAPH-#7284, IRGKangXi=0702.060, RSKangXi=93.8, Def{animal horns}
7285 CJK UNIFIED IDEOGRAPH-#7285, IRGKangXi=0702.080, RSKangXi=93.8
7286 CJK UNIFIED IDEOGRAPH-#7286, IRGKangXi=0702.090, RSKangXi=93.8, Def{special}
7287 CJK UNIFIED IDEOGRAPH-#7287, IRGKangXi=0702.100, RSKangXi=93.8, Def{run fast, flee; rush about; run}
7288 CJK UNIFIED IDEOGRAPH-#7288, IRGKangXi=0702.110, RSKangXi=93.8
7289 CJK UNIFIED IDEOGRAPH-#7289, IRGKangXi=0702.140, RSKangXi=93.8, Def{an ox with yellow hair and black lips}
728A CJK UNIFIED IDEOGRAPH-#728A, IRGKangXi=0702.141, RSKangXi=93.8, Def{calf; victim of sacrifice}
728B CJK UNIFIED IDEOGRAPH-#728B, IRGKangXi=0702.141, RSKangXi=93.8
728C CJK UNIFIED IDEOGRAPH-#728C, IRGKangXi=0702.180, RSKangXi=93.9
728D CJK UNIFIED IDEOGRAPH-#728D, IRGKangXi=0702.190, RSKangXi=93.9, Def{a bullock; a fabulous monster}
728E CJK UNIFIED IDEOGRAPH-#728E, IRGKangXi=0702.270, RSKangXi=93.9, Def{the zebu, or humped-ox}
728F CJK UNIFIED IDEOGRAPH-#728F, IRGKangXi=0703.020, RSKangXi=93.9, Def{yak-ox}
7290 CJK UNIFIED IDEOGRAPH-#7290, IRGKangXi=0703.030, RSKangXi=93.9
7291 CJK UNIFIED IDEOGRAPH-#7291, IRGKangXi=0703.040, RSKangXi=93.9
7292 CJK UNIFIED IDEOGRAPH-#7292, IRGKangXi=0703.110, RSKangXi=93.10, Def{entertain victorious soldiers}
7293 CJK UNIFIED IDEOGRAPH-#7293, IRGKangXi=0703.130, RSKangXi=93.10
7294 CJK UNIFIED IDEOGRAPH-#7294, IRGKangXi=0703.140
7295 CJK UNIFIED IDEOGRAPH-#7295, IRGKangXi=0703.190, RSKangXi=93.10
7296 CJK UNIFIED IDEOGRAPH-#7296, IRGKangXi=0703.220, RSKangXi=93.10, Def{brindled ox; brindled in color}
7297 CJK UNIFIED IDEOGRAPH-#7297, IRGKangXi=0703.240, RSKangXi=93.10
7298 CJK UNIFIED IDEOGRAPH-#7298, IRGKangXi=0703.310, RSKangXi=93.11
7299 CJK UNIFIED IDEOGRAPH-#7299, IRGKangXi=0703.330, RSKangXi=93.11
729A CJK UNIFIED IDEOGRAPH-#729A, IRGKangXi=0703.340, RSKangXi=93.11
729B CJK UNIFIED IDEOGRAPH-#729B, IRGKangXi=0704.070, RSKangXi=93.11, Def{a black ox, a yak}
729C CJK UNIFIED IDEOGRAPH-#729C, IRGKangXi=0704.140, RSKangXi=93.12
729D CJK UNIFIED IDEOGRAPH-#729D, IRGKangXi=0704.170, RSKangXi=93.12
729E CJK UNIFIED IDEOGRAPH-#729E, IRGKangXi=0704.210, RSKangXi=93.12
729F CJK UNIFIED IDEOGRAPH-#729F, IRGKangXi=0704.081, RSKangXi=93.12, Def{stubborn}
72A0 CJK UNIFIED IDEOGRAPH-#72A0, IRGKangXi=0704.321, RSKangXi=93.13, Def{sacrifice, give up; sacrificial}
72A1 CJK UNIFIED IDEOGRAPH-#72A1, IRGKangXi=0704.370, RSKangXi=93.15
72A2 CJK UNIFIED IDEOGRAPH-#72A2, IRGKangXi=0704.380, RSKangXi=93.15, Def{calf; victim of sacrifice}
72A3 CJK UNIFIED IDEOGRAPH-#72A3, IRGKangXi=0704.390, RSKangXi=93.15
72A4 CJK UNIFIED IDEOGRAPH-#72A4, IRGKangXi=0704.410, RSKangXi=93.15
72A5 CJK UNIFIED IDEOGRAPH-#72A5, IRGKangXi=0705.020, RSKangXi=93.15
72A6 CJK UNIFIED IDEOGRAPH-#72A6, IRGKangXi=0705.040, RSKangXi=93.15
72A7 CJK UNIFIED IDEOGRAPH-#72A7, IRGKangXi=0705.090, RSKangXi=93.16, Def{sacrifice, give up; sacrificial}
72A8 CJK UNIFIED IDEOGRAPH-#72A8, IRGKangXi=0705.100, RSKangXi=93.16, Def{panting of cow; grunting of ox}
72A9 CJK UNIFIED IDEOGRAPH-#72A9, IRGKangXi=0705.160, RSKangXi=93.18
72AA CJK UNIFIED IDEOGRAPH-#72AA, IRGKangXi=0705.220, RSKangXi=93.20
72AB CJK UNIFIED IDEOGRAPH-#72AB, IRGKangXi=0705.250, RSKangXi=93.23, Def{protrude}
72AC CJK UNIFIED IDEOGRAPH-#72AC, IRGKangXi=0705.270, RSKangXi=94.0, Def{dog; radical number 94}
72AD CJK UNIFIED IDEOGRAPH-#72AD, IRGKangXi=0705.271, RSKangXi=94.0, Def{dog; radical number 94}
72AE CJK UNIFIED IDEOGRAPH-#72AE, IRGKangXi=0706.010, RSKangXi=94.1, Def{to pull up}
72AF CJK UNIFIED IDEOGRAPH-#72AF, IRGKangXi=0706.020, RSKangXi=94.2, Def{commit crime, violate; criminal}
72B0 CJK UNIFIED IDEOGRAPH-#72B0, IRGKangXi=0706.080, RSKangXi=94.2, Def{armadillo}
72B1 CJK UNIFIED IDEOGRAPH-#72B1, IRGKangXi=0706.120, RSKangXi=94.3
72B2 CJK UNIFIED IDEOGRAPH-#72B2, IRGKangXi=0706.140, RSKangXi=94.3, Def{wolf; cruel, wicked, mean}
72B3 CJK UNIFIED IDEOGRAPH-#72B3, IRGKangXi=0706.150, RSKangXi=94.3
72B4 CJK UNIFIED IDEOGRAPH-#72B4, IRGKangXi=0706.160, RSKangXi=94.3, Def{a wild dog, a not very large lock-up}
72B5 CJK UNIFIED IDEOGRAPH-#72B5, IRGKangXi=0706.170, RSKangXi=94.3, Def{resolute; a non-Han ethnic group in Guangxi, Hunan, and Guizhou}
72B6 CJK UNIFIED IDEOGRAPH-#72B6, IRGKangXi=0706.171, RSKangXi=94.3, Def{form; appearance; shape; official}
72B7 CJK UNIFIED IDEOGRAPH-#72B7, IRGKangXi=0706.171, RSKangXi=94.3, Def{fierce, rude, uncivilized}
72B8 CJK UNIFIED IDEOGRAPH-#72B8, IRGKangXi=0706.171, RSKangXi=94.3, Def{mammoth}
72B9 CJK UNIFIED IDEOGRAPH-#72B9, IRGKangXi=0706.190, RSKangXi=94.4, Def{like, similar to, just like, as}
72BA CJK UNIFIED IDEOGRAPH-#72BA, IRGKangXi=0706.210, RSKangXi=94.4, Def{animal}
72BB CJK UNIFIED IDEOGRAPH-#72BB, IRGKangXi=0706.240, RSKangXi=94.4
72BC CJK UNIFIED IDEOGRAPH-#72BC, IRGKangXi=0707.050, RSKangXi=94.4, Def{a fierce Mongolian wolf dragon's head on roofs}
72BD CJK UNIFIED IDEOGRAPH-#72BD, IRGKangXi=0707.070, RSKangXi=94.4
72BE CJK UNIFIED IDEOGRAPH-#72BE, IRGKangXi=0707.090, RSKangXi=94.4
72BF CJK UNIFIED IDEOGRAPH-#72BF, IRGKangXi=0707.120, RSKangXi=94.4
72C0 CJK UNIFIED IDEOGRAPH-#72C0, IRGKangXi=0707.130, RSKangXi=94.4, Def{form; appearance; shape; official}
72C1 CJK UNIFIED IDEOGRAPH-#72C1, IRGKangXi=0707.190, RSKangXi=94.4, Def{a tribe of Scythian nomads}
72C2 CJK UNIFIED IDEOGRAPH-#72C2, IRGKangXi=0707.200, RSKangXi=94.4, Def{insane, mad; violent; wild}
72C3 CJK UNIFIED IDEOGRAPH-#72C3, IRGKangXi=0707.230, RSKangXi=94.4, Def{to covet; to be accustomed}
72C4 CJK UNIFIED IDEOGRAPH-#72C4, IRGKangXi=0707.240, RSKangXi=94.4, Def{tribe from northern china; surnam}
72C5 CJK UNIFIED IDEOGRAPH-#72C5, IRGKangXi=0708.020, RSKangXi=94.4
72C6 CJK UNIFIED IDEOGRAPH-#72C6, IRGKangXi=0708.021, RSKangXi=94.4, Def{pekinese dog, lap dog, pug; pup}
72C7 CJK UNIFIED IDEOGRAPH-#72C7, IRGKangXi=0708.021, RSKangXi=94.4
72C8 CJK UNIFIED IDEOGRAPH-#72C8, IRGKangXi=0708.021, RSKangXi=94.4, Def{a legendary animal with short forelegs which rode a wolf}
72C9 CJK UNIFIED IDEOGRAPH-#72C9, IRGKangXi=0708.120, RSKangXi=94.5, Def{fox-cub}
72CA CJK UNIFIED IDEOGRAPH-#72CA, IRGKangXi=0708.160, RSKangXi=94.5
72CB CJK UNIFIED IDEOGRAPH-#72CB, IRGKangXi=0708.170, RSKangXi=94.5
72CC CJK UNIFIED IDEOGRAPH-#72CC, IRGKangXi=0708.200, RSKangXi=94.5
72CD CJK UNIFIED IDEOGRAPH-#72CD, IRGKangXi=0708.240, RSKangXi=94.5, Def{species of deer found in north China}
72CE CJK UNIFIED IDEOGRAPH-#72CE, IRGKangXi=0708.250, RSKangXi=94.5, Def{be familiar with; disrespect}
72CF CJK UNIFIED IDEOGRAPH-#72CF, IRGKangXi=0708.280, RSKangXi=94.5
72D0 CJK UNIFIED IDEOGRAPH-#72D0, IRGKangXi=0708.290, RSKangXi=94.5, Def{species of fox}
72D1 CJK UNIFIED IDEOGRAPH-#72D1, IRGKangXi=0709.020, RSKangXi=94.5
72D2 CJK UNIFIED IDEOGRAPH-#72D2, IRGKangXi=0709.050, RSKangXi=94.5, Def{baboon}
72D3 CJK UNIFIED IDEOGRAPH-#72D3, IRGKangXi=0709.080, RSKangXi=94.5
72D4 CJK UNIFIED IDEOGRAPH-#72D4, IRGKangXi=0709.090, RSKangXi=94.5
72D5 CJK UNIFIED IDEOGRAPH-#72D5, IRGKangXi=0709.100, RSKangXi=94.5
72D6 CJK UNIFIED IDEOGRAPH-#72D6, IRGKangXi=0709.110, RSKangXi=94.5, Def{a gibbon with a long tail and prominent nose}
72D7 CJK UNIFIED IDEOGRAPH-#72D7, IRGKangXi=0709.120, RSKangXi=94.5, Def{dog, canis familiaris}
72D8 CJK UNIFIED IDEOGRAPH-#72D8, IRGKangXi=0709.130, RSKangXi=94.5, Def{jump}
72D9 CJK UNIFIED IDEOGRAPH-#72D9, IRGKangXi=0709.140, RSKangXi=94.5, Def{an ape, monkey; to spy, watch for; to lie}
72DA CJK UNIFIED IDEOGRAPH-#72DA, IRGKangXi=0709.150, RSKangXi=94.5
72DB CJK UNIFIED IDEOGRAPH-#72DB, IRGKangXi=0709.160, RSKangXi=94.5, Def{lion-dog shrine guardians}
72DC CJK UNIFIED IDEOGRAPH-#72DC, IRGKangXi=0709.181, RSKangXi=94.5
72DD CJK UNIFIED IDEOGRAPH-#72DD, IRGKangXi=0709.181, RSKangXi=94.5, Def{hunt; autumn hunting; to capture with a fine net}
72DE CJK UNIFIED IDEOGRAPH-#72DE, IRGKangXi=0709.181, RSKangXi=94.5, Def{ferocious appearance; hideous}
72DF CJK UNIFIED IDEOGRAPH-#72DF, IRGKangXi=0710.010, RSKangXi=94.6
72E0 CJK UNIFIED IDEOGRAPH-#72E0, IRGKangXi=0710.020, RSKangXi=94.6, Def{vicious, cruel; severely, extreme}
72E1 CJK UNIFIED IDEOGRAPH-#72E1, IRGKangXi=0710.050, RSKangXi=94.6, Def{cunning, deceitful, treacherous}
72E2 CJK UNIFIED IDEOGRAPH-#72E2, IRGKangXi=0710.060, RSKangXi=94.6, Def{animal name}
72E3 CJK UNIFIED IDEOGRAPH-#72E3, IRGKangXi=0710.080, RSKangXi=94.6
72E4 CJK UNIFIED IDEOGRAPH-#72E4, IRGKangXi=0710.170, RSKangXi=94.6
72E5 CJK UNIFIED IDEOGRAPH-#72E5, IRGKangXi=0710.200, RSKangXi=94.6, Def{follow}
72E6 CJK UNIFIED IDEOGRAPH-#72E6, IRGKangXi=0710.230, RSKangXi=94.6
72E7 CJK UNIFIED IDEOGRAPH-#72E7, IRGKangXi=0710.240, RSKangXi=94.6
72E8 CJK UNIFIED IDEOGRAPH-#72E8, IRGKangXi=0710.270, RSKangXi=94.6
72E9 CJK UNIFIED IDEOGRAPH-#72E9, IRGKangXi=0711.040, RSKangXi=94.6, Def{winter hunting; imperial tour}
72EA CJK UNIFIED IDEOGRAPH-#72EA, IRGKangXi=0711.050, RSKangXi=94.6
72EB CJK UNIFIED IDEOGRAPH-#72EB, IRGKangXi=0711.080, RSKangXi=94.6
72EC CJK UNIFIED IDEOGRAPH-#72EC, IRGKangXi=0711.101, RSKangXi=94.6, Def{alone, single, solitary, only}
72ED CJK UNIFIED IDEOGRAPH-#72ED, IRGKangXi=0711.101, RSKangXi=94.6, Def{narrow, limited; narrow-minded}
72EE CJK UNIFIED IDEOGRAPH-#72EE, IRGKangXi=0711.101, RSKangXi=94.6, Def{lion}
72EF CJK UNIFIED IDEOGRAPH-#72EF, IRGKangXi=0711.101, RSKangXi=94.6, Def{sly, cunning, crafty}
72F0 CJK UNIFIED IDEOGRAPH-#72F0, IRGKangXi=0711.101, RSKangXi=94.6, Def{fierce-looking, ferocious}
72F1 CJK UNIFIED IDEOGRAPH-#72F1, IRGKangXi=0711.101, RSKangXi=94.6, Def{prison, jail; case; lawsuit}
72F2 CJK UNIFIED IDEOGRAPH-#72F2, IRGKangXi=0711.101, RSKangXi=94.6, Def{monkey}
72F3 CJK UNIFIED IDEOGRAPH-#72F3, IRGKangXi=0711.120, RSKangXi=94.7
72F4 CJK UNIFIED IDEOGRAPH-#72F4, IRGKangXi=0711.130, RSKangXi=94.7, Def{a kind of tapir; a fierce beast depicted on the door of prisons}
72F5 CJK UNIFIED IDEOGRAPH-#72F5, IRGKangXi=0711.160, RSKangXi=94.7, Def{blend; variegated; striped}
72F6 CJK UNIFIED IDEOGRAPH-#72F6, IRGKangXi=0711.190, RSKangXi=94.7
72F7 CJK UNIFIED IDEOGRAPH-#72F7, IRGKangXi=0711.280, RSKangXi=94.7, Def{rash, impetuous, impulsive}
72F8 CJK UNIFIED IDEOGRAPH-#72F8, IRGKangXi=0711.290, RSKangXi=94.7, Def{fox}
72F9 CJK UNIFIED IDEOGRAPH-#72F9, IRGKangXi=0711.300, RSKangXi=94.7, Def{narrow, limited; narrow-minded; to pinch}
72FA CJK UNIFIED IDEOGRAPH-#72FA, IRGKangXi=0711.320, RSKangXi=94.7, Def{the snarling of dogs}
72FB CJK UNIFIED IDEOGRAPH-#72FB, IRGKangXi=0712.010, RSKangXi=94.7, Def{a fabulous beast}
72FC CJK UNIFIED IDEOGRAPH-#72FC, IRGKangXi=0712.020, RSKangXi=94.7, Def{wolf}
72FD CJK UNIFIED IDEOGRAPH-#72FD, IRGKangXi=0712.030, RSKangXi=94.7, Def{a legendary animal with short forelegs which rode a wolf}
72FE CJK UNIFIED IDEOGRAPH-#72FE, IRGKangXi=0712.040, RSKangXi=94.7
72FF CJK UNIFIED IDEOGRAPH-#72FF, IRGKangXi=0712.050, RSKangXi=94.7
7300 CJK UNIFIED IDEOGRAPH-#7300, IRGKangXi=0712.071, RSKangXi=94.7
7301 CJK UNIFIED IDEOGRAPH-#7301, IRGKangXi=0712.071, RSKangXi=94.7, Def{a kind of monkey}
7302 CJK UNIFIED IDEOGRAPH-#7302, IRGKangXi=0712.071, RSKangXi=94.7
7303 CJK UNIFIED IDEOGRAPH-#7303, IRGKangXi=0712.071, RSKangXi=94.7, Def{dog}
7304 CJK UNIFIED IDEOGRAPH-#7304, IRGKangXi=0712.080, RSKangXi=94.8
7305 CJK UNIFIED IDEOGRAPH-#7305, IRGKangXi=0712.090, RSKangXi=94.8
7306 CJK UNIFIED IDEOGRAPH-#7306, IRGKangXi=0712.100, RSKangXi=94.8
7307 CJK UNIFIED IDEOGRAPH-#7307, IRGKangXi=0712.140, RSKangXi=94.8, Def{the scream or roar of a tiger; to intimidate; to scare}
7308 CJK UNIFIED IDEOGRAPH-#7308, IRGKangXi=0712.160, RSKangXi=94.8
7309 CJK UNIFIED IDEOGRAPH-#7309, IRGKangXi=0712.170, RSKangXi=94.8
730A CJK UNIFIED IDEOGRAPH-#730A, IRGKangXi=0712.210, RSKangXi=94.8, Def{lion; wild beast; wild horse}
730B CJK UNIFIED IDEOGRAPH-#730B, IRGKangXi=0712.220, RSKangXi=94.8, Def{wind; storm; gale; dog moving; (Cant.) running quickly}
730C CJK UNIFIED IDEOGRAPH-#730C, IRGKangXi=0712.230, RSKangXi=94.8
730D CJK UNIFIED IDEOGRAPH-#730D, IRGKangXi=0712.240, RSKangXi=94.8
730E CJK UNIFIED IDEOGRAPH-#730E, IRGKangXi=0712.250, RSKangXi=94.8, Def{hunt; field sports}
730F CJK UNIFIED IDEOGRAPH-#730F, IRGKangXi=0713.030, RSKangXi=94.8
7310 CJK UNIFIED IDEOGRAPH-#7310, IRGKangXi=0713.050, RSKangXi=94.8
7311 CJK UNIFIED IDEOGRAPH-#7311, IRGKangXi=0713.070, RSKangXi=94.8
7312 CJK UNIFIED IDEOGRAPH-#7312, IRGKangXi=0713.100, RSKangXi=94.8
7313 CJK UNIFIED IDEOGRAPH-#7313, IRGKangXi=0713.110, RSKangXi=94.8, Def{monkey}
7314 CJK UNIFIED IDEOGRAPH-#7314, IRGKangXi=0713.140, RSKangXi=94.8, Def{name of an ancient tribe}
7315 CJK UNIFIED IDEOGRAPH-#7315, IRGKangXi=0713.150, RSKangXi=94.8, Def{macacus monkey}
7316 CJK UNIFIED IDEOGRAPH-#7316, IRGKangXi=0713.170, RSKangXi=94.8, Def{mad, wild, reckless, unruly}
7317 CJK UNIFIED IDEOGRAPH-#7317, IRGKangXi=0713.200, RSKangXi=94.8, Def{exclamation of admiration}
7318 CJK UNIFIED IDEOGRAPH-#7318, IRGKangXi=0713.210, RSKangXi=94.8, Def{fierce dog; furious, frenzied}
7319 CJK UNIFIED IDEOGRAPH-#7319, IRGKangXi=0713.230, RSKangXi=94.8, Def{fierce-looking, ferocious}
731A CJK UNIFIED IDEOGRAPH-#731A, IRGKangXi=0713.250, RSKangXi=94.8
731B CJK UNIFIED IDEOGRAPH-#731B, IRGKangXi=0713.260, RSKangXi=94.8, Def{violent, savage, cruel; bold}
731C CJK UNIFIED IDEOGRAPH-#731C, IRGKangXi=0714.010, RSKangXi=94.8, Def{guess, conjecture, suppose; feel}
731D CJK UNIFIED IDEOGRAPH-#731D, IRGKangXi=0714.020, RSKangXi=94.8, Def{abruptly, suddenly; abrupt}
731E CJK UNIFIED IDEOGRAPH-#731E, IRGKangXi=0714.051, RSKangXi=94.8, Def{a wild cat; 猞猁, a lynx}
731F CJK UNIFIED IDEOGRAPH-#731F, IRGKangXi=0714.051, RSKangXi=94.8, Def{hunt; field sports}
7320 CJK UNIFIED IDEOGRAPH-#7320, IRGKangXi=0714.051, RSKangXi=94.8
7321 CJK UNIFIED IDEOGRAPH-#7321, IRGKangXi=0714.051, RSKangXi=94.8, Def{pig; Lolo aboringinal tribe}
7322 CJK UNIFIED IDEOGRAPH-#7322, IRGKangXi=0714.060, RSKangXi=94.9, Def{a kind of monkey found in W.China}
7323 CJK UNIFIED IDEOGRAPH-#7323, IRGKangXi=0714.070, RSKangXi=94.9
7324 CJK UNIFIED IDEOGRAPH-#7324, IRGKangXi=0714.100, RSKangXi=94.9
7325 CJK UNIFIED IDEOGRAPH-#7325, IRGKangXi=0714.120, RSKangXi=94.9, Def{vulgar, low, cheap; wanton; obscene}
7326 CJK UNIFIED IDEOGRAPH-#7326, IRGKangXi=0714.150, RSKangXi=94.9
7327 CJK UNIFIED IDEOGRAPH-#7327, IRGKangXi=0714.170, RSKangXi=94.9
7328 CJK UNIFIED IDEOGRAPH-#7328, IRGKangXi=0714.180, RSKangXi=94.9, Def{ape}
7329 CJK UNIFIED IDEOGRAPH-#7329, IRGKangXi=0714.210, RSKangXi=94.9, Def{species of orangutan}
732A CJK UNIFIED IDEOGRAPH-#732A, IRGKangXi=0714.260, RSKangXi=94.9, Def{pig, hog, wild boar}
732B CJK UNIFIED IDEOGRAPH-#732B, IRGKangXi=0714.270, RSKangXi=94.9, Def{cat}
732C CJK UNIFIED IDEOGRAPH-#732C, IRGKangXi=0715.010, RSKangXi=94.9, Def{vulgar; wanton; low; many; varied; a hedgehog, porcupine}
732D CJK UNIFIED IDEOGRAPH-#732D, IRGKangXi=0715.030, RSKangXi=94.9
732E CJK UNIFIED IDEOGRAPH-#732E, IRGKangXi=0715.040, RSKangXi=94.9, Def{offer, present; show, display}
732F CJK UNIFIED IDEOGRAPH-#732F, IRGKangXi=0715.050, RSKangXi=94.9
7330 CJK UNIFIED IDEOGRAPH-#7330, IRGKangXi=0715.070, RSKangXi=94.9
7331 CJK UNIFIED IDEOGRAPH-#7331, IRGKangXi=0715.080, RSKangXi=94.9, Def{a monkey with yellow hair}
7332 CJK UNIFIED IDEOGRAPH-#7332, IRGKangXi=0715.140, RSKangXi=94.9, Def{smoke or flames from fire; roast}
7333 CJK UNIFIED IDEOGRAPH-#7333, IRGKangXi=0715.150, RSKangXi=94.9
7334 CJK UNIFIED IDEOGRAPH-#7334, IRGKangXi=0715.170, RSKangXi=94.9, Def{monkey, ape; monkey-like}
7335 CJK UNIFIED IDEOGRAPH-#7335, IRGKangXi=0715.190, RSKangXi=94.9
7336 CJK UNIFIED IDEOGRAPH-#7336, IRGKangXi=0715.200, RSKangXi=94.9, Def{like, similar to, just like, as}
7337 CJK UNIFIED IDEOGRAPH-#7337, IRGKangXi=0716.010, RSKangXi=94.9, Def{plan, scheme; plan, plot; way}
7338 CJK UNIFIED IDEOGRAPH-#7338, IRGKangXi=0716.040, RSKangXi=94.9, Def{a kind of animal}
7339 CJK UNIFIED IDEOGRAPH-#7339, IRGKangXi=0716.051, RSKangXi=94.9, Def{wild animal mentioned in short story by Lu Xun}
733A CJK UNIFIED IDEOGRAPH-#733A, IRGKangXi=0716.060, RSKangXi=94.10, Def{jackal; name of a tribe}
733B CJK UNIFIED IDEOGRAPH-#733B, IRGKangXi=0716.080, RSKangXi=94.10, Def{monkey}
733C CJK UNIFIED IDEOGRAPH-#733C, IRGKangXi=0716.130, RSKangXi=94.10
733D CJK UNIFIED IDEOGRAPH-#733D, IRGKangXi=0716.140, RSKangXi=94.10
733E CJK UNIFIED IDEOGRAPH-#733E, IRGKangXi=0716.180, RSKangXi=94.10, Def{crafty, cunning, shrewd; deceitful}
733F CJK UNIFIED IDEOGRAPH-#733F, IRGKangXi=0716.190, RSKangXi=94.10, Def{ape}
7340 CJK UNIFIED IDEOGRAPH-#7340, IRGKangXi=0716.230, RSKangXi=94.10, Def{to gather; to hunt or search for}
7341 CJK UNIFIED IDEOGRAPH-#7341, IRGKangXi=0716.300, RSKangXi=94.9, Def{mammoth}
7342 CJK UNIFIED IDEOGRAPH-#7342, IRGKangXi=0716.310, RSKangXi=94.10
7343 CJK UNIFIED IDEOGRAPH-#7343, IRGKangXi=0716.340, RSKangXi=94.10, Def{dull; dull-minded, simple, stupid}
7344 CJK UNIFIED IDEOGRAPH-#7344, IRGKangXi=0717.030, RSKangXi=94.10, Def{prison, jail; case; lawsuit}
7345 CJK UNIFIED IDEOGRAPH-#7345, IRGKangXi=0717.100, RSKangXi=94.10, Def{lion}
7346 CJK UNIFIED IDEOGRAPH-#7346, IRGKangXi=0717.110, RSKangXi=94.10
7347 CJK UNIFIED IDEOGRAPH-#7347, IRGKangXi=0717.111, RSKangXi=94.10
7348 CJK UNIFIED IDEOGRAPH-#7348, IRGKangXi=0717.111, RSKangXi=94.10
7349 CJK UNIFIED IDEOGRAPH-#7349, IRGKangXi=0717.111, RSKangXi=94.10, Def{jungle}
734A CJK UNIFIED IDEOGRAPH-#734A, IRGKangXi=0717.111, RSKangXi=94.10
734B CJK UNIFIED IDEOGRAPH-#734B, IRGKangXi=0717.150, RSKangXi=94.12, Def{roar; cry}
734C CJK UNIFIED IDEOGRAPH-#734C, IRGKangXi=0717.180, RSKangXi=94.11
734D CJK UNIFIED IDEOGRAPH-#734D, IRGKangXi=0717.190, RSKangXi=94.11, Def{a mythical animal that eats its mother when it is born; Manchurian tiger}
734E CJK UNIFIED IDEOGRAPH-#734E, IRGKangXi=0717.290, RSKangXi=94.11, Def{prize, reward; give award to}
734F CJK UNIFIED IDEOGRAPH-#734F, IRGKangXi=0717.300, RSKangXi=94.11, Def{the panther; the tapir}
7350 CJK UNIFIED IDEOGRAPH-#7350, IRGKangXi=0717.350, RSKangXi=94.11, Def{roebuck, hornless river deer}
7351 CJK UNIFIED IDEOGRAPH-#7351, IRGKangXi=0718.010, RSKangXi=94.11
7352 CJK UNIFIED IDEOGRAPH-#7352, IRGKangXi=0718.020, RSKangXi=94.11, Def{mastiff, large fierce dog}
7353 CJK UNIFIED IDEOGRAPH-#7353, IRGKangXi=0718.030, RSKangXi=94.11
7354 CJK UNIFIED IDEOGRAPH-#7354, IRGKangXi=0718.041, RSKangXi=94.11
7355 CJK UNIFIED IDEOGRAPH-#7355, IRGKangXi=0718.041, RSKangXi=94.11
7356 CJK UNIFIED IDEOGRAPH-#7356, IRGKangXi=0718.060, RSKangXi=94.12
7357 CJK UNIFIED IDEOGRAPH-#7357, IRGKangXi=0718.080, RSKangXi=94.12, Def{unruly, wild, violent, lawless}
7358 CJK UNIFIED IDEOGRAPH-#7358, IRGKangXi=0718.090, RSKangXi=94.12, Def{collapse}
7359 CJK UNIFIED IDEOGRAPH-#7359, IRGKangXi=0718.100, RSKangXi=94.12
735A CJK UNIFIED IDEOGRAPH-#735A, IRGKangXi=0718.130, RSKangXi=94.12
735B CJK UNIFIED IDEOGRAPH-#735B, IRGKangXi=0718.160, RSKangXi=94.12
735C CJK UNIFIED IDEOGRAPH-#735C, IRGKangXi=0718.170, RSKangXi=94.12
735D CJK UNIFIED IDEOGRAPH-#735D, IRGKangXi=0718.210, RSKangXi=94.12, Def{devil}
735E CJK UNIFIED IDEOGRAPH-#735E, IRGKangXi=0718.240, RSKangXi=94.12, Def{name of a variety of dog; wild tribes in South China}
735F CJK UNIFIED IDEOGRAPH-#735F, IRGKangXi=0718.270, RSKangXi=94.12
7360 CJK UNIFIED IDEOGRAPH-#7360, IRGKangXi=0718.290, RSKangXi=94.12, Def{to hunt at night by torches}
7361 CJK UNIFIED IDEOGRAPH-#7361, IRGKangXi=0719.131, RSKangXi=94.12
7362 CJK UNIFIED IDEOGRAPH-#7362, IRGKangXi=0719.040, RSKangXi=94.12, Def{dog}
7363 CJK UNIFIED IDEOGRAPH-#7363, IRGKangXi=0719.131, RSKangXi=94.12, Def{beast, animal; bestial}
7364 CJK UNIFIED IDEOGRAPH-#7364, IRGKangXi=0719.131, RSKangXi=94.12
7365 CJK UNIFIED IDEOGRAPH-#7365, IRGKangXi=0719.200, RSKangXi=94.13
7366 CJK UNIFIED IDEOGRAPH-#7366, IRGKangXi=0719.230, RSKangXi=94.13
7367 CJK UNIFIED IDEOGRAPH-#7367, IRGKangXi=0719.240, RSKangXi=94.13, Def{rash; honest and straightforward}
7368 CJK UNIFIED IDEOGRAPH-#7368, IRGKangXi=0719.250, RSKangXi=94.13, Def{alone, single, solitary, only}
7369 CJK UNIFIED IDEOGRAPH-#7369, IRGKangXi=0719.270, RSKangXi=94.13
736A CJK UNIFIED IDEOGRAPH-#736A, IRGKangXi=0719.280, RSKangXi=94.13, Def{sly, cunning, crafty}
736B CJK UNIFIED IDEOGRAPH-#736B, IRGKangXi=0719.290, RSKangXi=94.13, Def{dog}
736C CJK UNIFIED IDEOGRAPH-#736C, IRGKangXi=0719.330, RSKangXi=94.13, Def{a fabulous monster}
736D CJK UNIFIED IDEOGRAPH-#736D, IRGKangXi=0720.071, RSKangXi=94.13, Def{otter}
736E CJK UNIFIED IDEOGRAPH-#736E, IRGKangXi=0720.090, RSKangXi=94.14, Def{hunt; autumn hunting; to capture with a fine net}
736F CJK UNIFIED IDEOGRAPH-#736F, IRGKangXi=0720.150, RSKangXi=94.14, Def{a tribe of Scythians which invaded China during the Hsia dynasty}
7370 CJK UNIFIED IDEOGRAPH-#7370, IRGKangXi=0720.160, RSKangXi=94.14, Def{ferocious appearance; hideous}
7371 CJK UNIFIED IDEOGRAPH-#7371, IRGKangXi=0720.170, RSKangXi=94.14, Def{a kind of otter}
7372 CJK UNIFIED IDEOGRAPH-#7372, IRGKangXi=0720.190, RSKangXi=94.14, Def{obtain, get, receive; seize}
7373 CJK UNIFIED IDEOGRAPH-#7373, IRGKangXi=0720.210, RSKangXi=94.14, Def{looking like a fierce dog; angry}
7374 CJK UNIFIED IDEOGRAPH-#7374, IRGKangXi=0720.220, RSKangXi=94.14, Def{mongoose}
7375 CJK UNIFIED IDEOGRAPH-#7375, IRGKangXi=0720.270, RSKangXi=94.15, Def{hunt; field sports}
7376 CJK UNIFIED IDEOGRAPH-#7376, IRGKangXi=0720.290, RSKangXi=94.15
7377 CJK UNIFIED IDEOGRAPH-#7377, IRGKangXi=0721.020, RSKangXi=94.15, Def{fierce, rude, uncivilized}
7378 CJK UNIFIED IDEOGRAPH-#7378, IRGKangXi=0721.030, RSKangXi=94.15, Def{beast, animal; bestial}
7379 CJK UNIFIED IDEOGRAPH-#7379, IRGKangXi=0721.060, RSKangXi=94.16, Def{a hound}
737A CJK UNIFIED IDEOGRAPH-#737A, IRGKangXi=0721.080, RSKangXi=94.16, Def{otter}
737B CJK UNIFIED IDEOGRAPH-#737B, IRGKangXi=0721.090, RSKangXi=94.16, Def{offer, present; show, display}
737C CJK UNIFIED IDEOGRAPH-#737C, IRGKangXi=0721.110, RSKangXi=94.17, Def{macacus monkey}
737D CJK UNIFIED IDEOGRAPH-#737D, IRGKangXi=0721.120, RSKangXi=94.17
737E CJK UNIFIED IDEOGRAPH-#737E, IRGKangXi=0721.210, RSKangXi=94.18, Def{the badger}
737F CJK UNIFIED IDEOGRAPH-#737F, IRGKangXi=0721.230, RSKangXi=94.18
7380 CJK UNIFIED IDEOGRAPH-#7380, IRGKangXi=0721.231, RSKangXi=94.19, Def{pig; lolo aborginal tribe}
7381 CJK UNIFIED IDEOGRAPH-#7381, IRGKangXi=0722.010, RSKangXi=94.20, Def{a dog with a long snout or muzzle}
7382 CJK UNIFIED IDEOGRAPH-#7382, IRGKangXi=0722.030, RSKangXi=94.20
7383 CJK UNIFIED IDEOGRAPH-#7383, IRGKangXi=0722.040, RSKangXi=94.20, Def{a large ape found in W. China}
7384 CJK UNIFIED IDEOGRAPH-#7384, IRGKangXi=0725.011, RSKangXi=95.0, Def{deep, profound, abstruse; KangXi radical 95}
7385 CJK UNIFIED IDEOGRAPH-#7385, IRGKangXi=0725.020, RSKangXi=95.4, Def{mysterious, subtle; exquisite}
7386 CJK UNIFIED IDEOGRAPH-#7386, IRGKangXi=0725.030, RSKangXi=95.5, Def{now, here; this; time, year}
7387 CJK UNIFIED IDEOGRAPH-#7387, IRGKangXi=0725.050, RSKangXi=95.6, Def{to lead; ratio; rate; limit}
7388 CJK UNIFIED IDEOGRAPH-#7388, IRGKangXi=0726.010, RSKangXi=95.6, Def{black}
7389 CJK UNIFIED IDEOGRAPH-#7389, IRGKangXi=0726.040, RSKangXi=96.0, Def{jade, precious stone, gem}
738A CJK UNIFIED IDEOGRAPH-#738A, IRGKangXi=0727.010, RSKangXi=96.0
738B CJK UNIFIED IDEOGRAPH-#738B, IRGKangXi=0727.020, RSKangXi=96.-1, Def{king, ruler; royal; surname}
738C CJK UNIFIED IDEOGRAPH-#738C, IRGKangXi=0727.040, RSKangXi=96.1
738D CJK UNIFIED IDEOGRAPH-#738D, IRGKangXi=0727.041, RSKangXi=4.4, Def{ill tempered; naughty}
738E CJK UNIFIED IDEOGRAPH-#738E, IRGKangXi=0727.070, RSKangXi=96.2, Def{jingling, tinkling}
738F CJK UNIFIED IDEOGRAPH-#738F, IRGKangXi=0727.080, RSKangXi=96.2
7390 CJK UNIFIED IDEOGRAPH-#7390, IRGKangXi=0727.100, RSKangXi=96.2
7391 CJK UNIFIED IDEOGRAPH-#7391, IRGKangXi=0727.101, RSKangXi=96.2, Def{pearl that is not quite round}
7392 CJK UNIFIED IDEOGRAPH-#7392, IRGKangXi=0727.120, RSKangXi=96.3
7393 CJK UNIFIED IDEOGRAPH-#7393, IRGKangXi=0727.160, RSKangXi=96.3, Def{pearly}
7394 CJK UNIFIED IDEOGRAPH-#7394, IRGKangXi=0727.190, RSKangXi=96.3, Def{green jade}
7395 CJK UNIFIED IDEOGRAPH-#7395, IRGKangXi=0727.200, RSKangXi=96.3, Def{inferior variety of gem}
7396 CJK UNIFIED IDEOGRAPH-#7396, IRGKangXi=0727.220, RSKangXi=96.3, AccountingNumeric=9, Def{black-colored jade}
7397 CJK UNIFIED IDEOGRAPH-#7397, IRGKangXi=0727.230, RSKangXi=96.3, Def{1/2 pr stone}
7398 CJK UNIFIED IDEOGRAPH-#7398, IRGKangXi=0727.251, RSKangXi=96.3, Def{court-dress jewels}
7399 CJK UNIFIED IDEOGRAPH-#7399, IRGKangXi=0727.251, RSKangXi=96.3
739A CJK UNIFIED IDEOGRAPH-#739A, IRGKangXi=0727.251, RSKangXi=96.3
739B CJK UNIFIED IDEOGRAPH-#739B, IRGKangXi=0727.251, RSKangXi=96.3, Def{agate; cornelian}
739C CJK UNIFIED IDEOGRAPH-#739C, IRGKangXi=0727.280, RSKangXi=96.4
739D CJK UNIFIED IDEOGRAPH-#739D, IRGKangXi=0727.290, RSKangXi=96.4
739E CJK UNIFIED IDEOGRAPH-#739E, IRGKangXi=0727.300, RSKangXi=96.4, Def{an inferior agate}
739F CJK UNIFIED IDEOGRAPH-#739F, IRGKangXi=0728.030, RSKangXi=96.4, Def{streaks in jade; gem}
73A0 CJK UNIFIED IDEOGRAPH-#73A0, IRGKangXi=0728.040, RSKangXi=96.4, Def{large jade tablet used by officials at court to indicate their ranks}
73A1 CJK UNIFIED IDEOGRAPH-#73A1, IRGKangXi=0728.050, RSKangXi=96.4
73A2 CJK UNIFIED IDEOGRAPH-#73A2, IRGKangXi=0728.060, RSKangXi=96.4, Def{(archaic) a kind of jade}
73A3 CJK UNIFIED IDEOGRAPH-#73A3, IRGKangXi=0728.070, RSKangXi=96.4
73A4 CJK UNIFIED IDEOGRAPH-#73A4, IRGKangXi=0728.080, RSKangXi=96.4, Def{a kind of gem inferior to jade}
73A5 CJK UNIFIED IDEOGRAPH-#73A5, IRGKangXi=0728.100, RSKangXi=96.4, Def{mysterious gem; pearl}
73A6 CJK UNIFIED IDEOGRAPH-#73A6, IRGKangXi=0728.120, RSKangXi=96.4, Def{broken piece of jade}
73A7 CJK UNIFIED IDEOGRAPH-#73A7, IRGKangXi=0728.130, RSKangXi=96.4, Def{reddish}
73A8 CJK UNIFIED IDEOGRAPH-#73A8, IRGKangXi=0728.140, RSKangXi=96.4, Def{two pieces of jade joined together}
73A9 CJK UNIFIED IDEOGRAPH-#73A9, IRGKangXi=0728.150, RSKangXi=96.4, Def{play with, joke, enjoy}
73AA CJK UNIFIED IDEOGRAPH-#73AA, IRGKangXi=0728.160, RSKangXi=96.4
73AB CJK UNIFIED IDEOGRAPH-#73AB, IRGKangXi=0728.170, RSKangXi=96.4, Def{rose}
73AC CJK UNIFIED IDEOGRAPH-#73AC, IRGKangXi=0728.180, RSKangXi=96.4
73AD CJK UNIFIED IDEOGRAPH-#73AD, IRGKangXi=0728.210, RSKangXi=96.4
73AE CJK UNIFIED IDEOGRAPH-#73AE, IRGKangXi=0728.211, RSKangXi=96.4, Def{type of jade; rare, valuable}
73AF CJK UNIFIED IDEOGRAPH-#73AF, IRGKangXi=0728.211, RSKangXi=96.4, Def{jade ring or bracelet; ring}
73B0 CJK UNIFIED IDEOGRAPH-#73B0, IRGKangXi=0728.211, RSKangXi=96.4, Def{appear, manifest, become visible}
73B1 CJK UNIFIED IDEOGRAPH-#73B1, IRGKangXi=0728.211, RSKangXi=96.4, Def{tinkling sound tinkling of pendant gems}
73B2 CJK UNIFIED IDEOGRAPH-#73B2, IRGKangXi=0728.230, RSKangXi=96.5, Def{tinkling of jade}
73B3 CJK UNIFIED IDEOGRAPH-#73B3, IRGKangXi=0728.240, RSKangXi=96.5, Def{tortoise shell}
73B4 CJK UNIFIED IDEOGRAPH-#73B4, IRGKangXi=0728.260, RSKangXi=96.5
73B5 CJK UNIFIED IDEOGRAPH-#73B5, IRGKangXi=0728.270, RSKangXi=96.5
73B6 CJK UNIFIED IDEOGRAPH-#73B6, IRGKangXi=0728.280, RSKangXi=96.5, Def{name of one kind of jade}
73B7 CJK UNIFIED IDEOGRAPH-#73B7, IRGKangXi=0728.300, RSKangXi=96.5, Def{flaw in gem; flaw in character}
73B8 CJK UNIFIED IDEOGRAPH-#73B8, IRGKangXi=0729.010, RSKangXi=96.5
73B9 CJK UNIFIED IDEOGRAPH-#73B9, IRGKangXi=0729.030, RSKangXi=96.5, Def{jadelike precious stone; jade-colored}
73BA CJK UNIFIED IDEOGRAPH-#73BA, IRGKangXi=0729.040, RSKangXi=96.5, Def{imperial signet, royal signet}
73BB CJK UNIFIED IDEOGRAPH-#73BB, IRGKangXi=0729.050, RSKangXi=96.5, Def{glass}
73BC CJK UNIFIED IDEOGRAPH-#73BC, IRGKangXi=0729.060, RSKangXi=96.5, Def{beautiful color of gem; flaw in}
73BD CJK UNIFIED IDEOGRAPH-#73BD, IRGKangXi=0729.070, RSKangXi=96.5
73BE CJK UNIFIED IDEOGRAPH-#73BE, IRGKangXi=0729.080, RSKangXi=96.5
73BF CJK UNIFIED IDEOGRAPH-#73BF, IRGKangXi=0729.090, RSKangXi=96.5
73C0 CJK UNIFIED IDEOGRAPH-#73C0, IRGKangXi=0729.100, RSKangXi=96.5, Def{amber}
73C1 CJK UNIFIED IDEOGRAPH-#73C1, IRGKangXi=0729.110, RSKangXi=96.5
73C2 CJK UNIFIED IDEOGRAPH-#73C2, IRGKangXi=0729.120, RSKangXi=96.5, Def{inferior kind of jade}
73C3 CJK UNIFIED IDEOGRAPH-#73C3, IRGKangXi=0729.130, RSKangXi=96.5
73C4 CJK UNIFIED IDEOGRAPH-#73C4, IRGKangXi=0729.150, RSKangXi=96.5
73C5 CJK UNIFIED IDEOGRAPH-#73C5, IRGKangXi=0729.160, RSKangXi=96.5
73C6 CJK UNIFIED IDEOGRAPH-#73C6, IRGKangXi=0729.180, RSKangXi=96.5
73C7 CJK UNIFIED IDEOGRAPH-#73C7, IRGKangXi=0729.200, RSKangXi=96.5
73C8 CJK UNIFIED IDEOGRAPH-#73C8, IRGKangXi=0729.210, RSKangXi=96.5, Def{an ornament attached to a woman's hairpin}
73C9 CJK UNIFIED IDEOGRAPH-#73C9, IRGKangXi=0729.220, RSKangXi=96.5, Def{stone resembling jade}
73CA CJK UNIFIED IDEOGRAPH-#73CA, IRGKangXi=0729.230, RSKangXi=96.5, Def{coral}
73CB CJK UNIFIED IDEOGRAPH-#73CB, IRGKangXi=0730.010, RSKangXi=96.5
73CC CJK UNIFIED IDEOGRAPH-#73CC, IRGKangXi=0730.020, RSKangXi=96.5, Def{ornament}
73CD CJK UNIFIED IDEOGRAPH-#73CD, IRGKangXi=0730.040, RSKangXi=96.5, Def{precious, valuable, rare}
73CE CJK UNIFIED IDEOGRAPH-#73CE, IRGKangXi=0730.060, RSKangXi=96.5, Def{precious, valuable, rare}
73CF CJK UNIFIED IDEOGRAPH-#73CF, IRGKangXi=0730.081, RSKangXi=96.5, Def{two pieces of jade joined together}
73D0 CJK UNIFIED IDEOGRAPH-#73D0, IRGKangXi=0730.081, RSKangXi=96.5, Def{enamel, cloissoné}
73D1 CJK UNIFIED IDEOGRAPH-#73D1, IRGKangXi=0730.081, RSKangXi=96.5, Def{a gem cut like dragon}
73D2 CJK UNIFIED IDEOGRAPH-#73D2, IRGKangXi=0730.090, RSKangXi=96.6
73D3 CJK UNIFIED IDEOGRAPH-#73D3, IRGKangXi=0730.110, RSKangXi=96.6, Def{two hemispherical objects used in divination}
73D4 CJK UNIFIED IDEOGRAPH-#73D4, IRGKangXi=0730.130, RSKangXi=96.6
73D5 CJK UNIFIED IDEOGRAPH-#73D5, IRGKangXi=0730.140, RSKangXi=96.6
73D6 CJK UNIFIED IDEOGRAPH-#73D6, IRGKangXi=0730.160, RSKangXi=96.6, Def{carat}
73D7 CJK UNIFIED IDEOGRAPH-#73D7, IRGKangXi=0730.170, RSKangXi=96.6
73D8 CJK UNIFIED IDEOGRAPH-#73D8, IRGKangXi=0730.180, RSKangXi=96.6
73D9 CJK UNIFIED IDEOGRAPH-#73D9, IRGKangXi=0730.190, RSKangXi=96.6, Def{precious stone; county in Sichuan}
73DA CJK UNIFIED IDEOGRAPH-#73DA, IRGKangXi=0730.210, RSKangXi=96.6
73DB CJK UNIFIED IDEOGRAPH-#73DB, IRGKangXi=0730.230, RSKangXi=96.6
73DC CJK UNIFIED IDEOGRAPH-#73DC, IRGKangXi=0730.240, RSKangXi=96.6
73DD CJK UNIFIED IDEOGRAPH-#73DD, IRGKangXi=0730.260, RSKangXi=96.6
73DE CJK UNIFIED IDEOGRAPH-#73DE, IRGKangXi=0730.270, RSKangXi=96.6, Def{kind of necklace}
73DF CJK UNIFIED IDEOGRAPH-#73DF, IRGKangXi=0730.280, RSKangXi=96.6
73E0 CJK UNIFIED IDEOGRAPH-#73E0, IRGKangXi=0730.290, RSKangXi=96.6, Def{precious stone, gem, jewel, pearl}
73E1 CJK UNIFIED IDEOGRAPH-#73E1, IRGKangXi=0731.010, RSKangXi=96.6, Def{variant of U+7434 琴, guqin or zither}
73E2 CJK UNIFIED IDEOGRAPH-#73E2, IRGKangXi=0731.050, RSKangXi=96.6, Def{precious stone}
73E3 CJK UNIFIED IDEOGRAPH-#73E3, IRGKangXi=0731.060, RSKangXi=96.6, Def{name of a kind of jade}
73E4 CJK UNIFIED IDEOGRAPH-#73E4, IRGKangXi=0731.070, RSKangXi=96.6, Def{treasure, jewel; precious, rare}
73E5 CJK UNIFIED IDEOGRAPH-#73E5, IRGKangXi=0731.080, RSKangXi=96.6, Def{ear ornament; stick, insert}
73E6 CJK UNIFIED IDEOGRAPH-#73E6, IRGKangXi=0731.110, RSKangXi=96.6, Def{a kind of jade}
73E7 CJK UNIFIED IDEOGRAPH-#73E7, IRGKangXi=0731.120, RSKangXi=96.6, Def{mother-of-pearl}
73E8 CJK UNIFIED IDEOGRAPH-#73E8, IRGKangXi=0731.130, RSKangXi=96.6
73E9 CJK UNIFIED IDEOGRAPH-#73E9, IRGKangXi=0731.140, RSKangXi=96.6, Def{the top gem of the pendants}
73EA CJK UNIFIED IDEOGRAPH-#73EA, IRGKangXi=0731.150, RSKangXi=96.6, Def{a jade table conferred upon feudal princes by the emperor as a symbol of dignity and authority}
73EB CJK UNIFIED IDEOGRAPH-#73EB, IRGKangXi=0731.160, RSKangXi=96.6
73EC CJK UNIFIED IDEOGRAPH-#73EC, IRGKangXi=0731.170, RSKangXi=96.6
73ED CJK UNIFIED IDEOGRAPH-#73ED, IRGKangXi=0731.190, RSKangXi=96.6, Def{class, group, grade; squad; job}
73EE CJK UNIFIED IDEOGRAPH-#73EE, IRGKangXi=0732.010, RSKangXi=96.6, Def{jade ornament}
73EF CJK UNIFIED IDEOGRAPH-#73EF, IRGKangXi=0732.021, RSKangXi=96.6
73F0 CJK UNIFIED IDEOGRAPH-#73F0, IRGKangXi=0732.021, RSKangXi=96.6, Def{pendant ornaments, earrings}
73F1 CJK UNIFIED IDEOGRAPH-#73F1, IRGKangXi=0732.021, RSKangXi=96.6, Def{a necklace made of precious stones}
73F2 CJK UNIFIED IDEOGRAPH-#73F2, IRGKangXi=0732.021, RSKangXi=96.6, Def{bright, glorious, splendid}
73F3 CJK UNIFIED IDEOGRAPH-#73F3, IRGKangXi=0732.030, RSKangXi=96.7
73F4 CJK UNIFIED IDEOGRAPH-#73F4, IRGKangXi=0732.050, RSKangXi=96.7
73F5 CJK UNIFIED IDEOGRAPH-#73F5, IRGKangXi=0732.060, RSKangXi=96.7
73F6 CJK UNIFIED IDEOGRAPH-#73F6, IRGKangXi=0732.070, RSKangXi=96.7
73F7 CJK UNIFIED IDEOGRAPH-#73F7, IRGKangXi=0732.080, RSKangXi=96.8, Def{an inferior gem}
73F8 CJK UNIFIED IDEOGRAPH-#73F8, IRGKangXi=0732.110, RSKangXi=96.7
73F9 CJK UNIFIED IDEOGRAPH-#73F9, IRGKangXi=0732.120, RSKangXi=96.7, Def{type of jade; pearl}
73FA CJK UNIFIED IDEOGRAPH-#73FA, IRGKangXi=0732.150, RSKangXi=96.7, Def{beautiful jade}
73FB CJK UNIFIED IDEOGRAPH-#73FB, IRGKangXi=0732.160, RSKangXi=96.7
73FC CJK UNIFIED IDEOGRAPH-#73FC, IRGKangXi=0732.180, RSKangXi=96.7
73FD CJK UNIFIED IDEOGRAPH-#73FD, IRGKangXi=0732.190, RSKangXi=96.7, Def{jade tablet}
73FE CJK UNIFIED IDEOGRAPH-#73FE, IRGKangXi=0732.220, RSKangXi=96.7, Def{appear, manifest, become visible}
73FF CJK UNIFIED IDEOGRAPH-#73FF, IRGKangXi=0732.240, RSKangXi=96.7
7400 CJK UNIFIED IDEOGRAPH-#7400, IRGKangXi=0732.250, RSKangXi=96.7, Def{gems of pearls formerly put into the mouth of a corpse}
7401 CJK UNIFIED IDEOGRAPH-#7401, IRGKangXi=0732.260, RSKangXi=96.7, Def{beautiful jade; star}
7402 CJK UNIFIED IDEOGRAPH-#7402, IRGKangXi=0732.280, RSKangXi=96.7
7403 CJK UNIFIED IDEOGRAPH-#7403, IRGKangXi=0732.290, RSKangXi=96.7, Def{ball, sphere, globe; round}
7404 CJK UNIFIED IDEOGRAPH-#7404, IRGKangXi=0732.300, RSKangXi=96.7, Def{scabbard; traces, reins}
7405 CJK UNIFIED IDEOGRAPH-#7405, IRGKangXi=0733.010, RSKangXi=96.7, Def{a variety of white carnelian; pure}
7406 CJK UNIFIED IDEOGRAPH-#7406, IRGKangXi=0733.040, RSKangXi=96.7, Def{reason, logic; manage}
7407 CJK UNIFIED IDEOGRAPH-#7407, IRGKangXi=0733.050, RSKangXi=96.7, Def{coarse variety of jasper or jade}
7408 CJK UNIFIED IDEOGRAPH-#7408, IRGKangXi=0733.060, RSKangXi=96.7
7409 CJK UNIFIED IDEOGRAPH-#7409, IRGKangXi=0733.080, RSKangXi=96.7, Def{sparkling stone; glazed, opaque}
740A CJK UNIFIED IDEOGRAPH-#740A, IRGKangXi=0733.090, RSKangXi=96.7, Def{a place in eastern Shandong}
740B CJK UNIFIED IDEOGRAPH-#740B, IRGKangXi=0733.120, RSKangXi=96.7
740C CJK UNIFIED IDEOGRAPH-#740C, IRGKangXi=0733.150, RSKangXi=96.7
740D CJK UNIFIED IDEOGRAPH-#740D, IRGKangXi=0733.151, RSKangXi=96.7
740E CJK UNIFIED IDEOGRAPH-#740E, IRGKangXi=0736.081, RSKangXi=96.7
740F CJK UNIFIED IDEOGRAPH-#740F, IRGKangXi=0736.081, RSKangXi=96.7, Def{vessel used to hold grain offerings}
7410 CJK UNIFIED IDEOGRAPH-#7410, IRGKangXi=0733.151, RSKangXi=96.7, Def{trifling, petty; troublesome}
7411 CJK UNIFIED IDEOGRAPH-#7411, IRGKangXi=0733.151, RSKangXi=96.7
7412 CJK UNIFIED IDEOGRAPH-#7412, IRGKangXi=0733.151, RSKangXi=96.7
7413 CJK UNIFIED IDEOGRAPH-#7413, IRGKangXi=0733.151, RSKangXi=96.7
7414 CJK UNIFIED IDEOGRAPH-#7414, IRGKangXi=0733.160, RSKangXi=96.8
7415 CJK UNIFIED IDEOGRAPH-#7415, IRGKangXi=0733.170, RSKangXi=96.8, Def{type of pearl; scabbard}
7416 CJK UNIFIED IDEOGRAPH-#7416, IRGKangXi=0734.030, RSKangXi=96.8, Def{carved jade wine cup}
7417 CJK UNIFIED IDEOGRAPH-#7417, IRGKangXi=0734.040, RSKangXi=96.8
7418 CJK UNIFIED IDEOGRAPH-#7418, IRGKangXi=0734.050, RSKangXi=96.8
7419 CJK UNIFIED IDEOGRAPH-#7419, IRGKangXi=0734.060, RSKangXi=96.8
741A CJK UNIFIED IDEOGRAPH-#741A, IRGKangXi=0734.090, RSKangXi=96.8, Def{girdle ornaments}
741B CJK UNIFIED IDEOGRAPH-#741B, IRGKangXi=0734.110, RSKangXi=96.8, Def{treasure, valuables}
741C CJK UNIFIED IDEOGRAPH-#741C, IRGKangXi=0734.120, RSKangXi=96.8
741D CJK UNIFIED IDEOGRAPH-#741D, IRGKangXi=0734.130, RSKangXi=96.8
741E CJK UNIFIED IDEOGRAPH-#741E, IRGKangXi=0734.140, RSKangXi=96.9
741F CJK UNIFIED IDEOGRAPH-#741F, IRGKangXi=0734.160, RSKangXi=96.8
7420 CJK UNIFIED IDEOGRAPH-#7420, IRGKangXi=0734.170, RSKangXi=96.8, Def{a gem used as ear plug; a jade earring}
7421 CJK UNIFIED IDEOGRAPH-#7421, IRGKangXi=0734.180, RSKangXi=96.8
7422 CJK UNIFIED IDEOGRAPH-#7422, IRGKangXi=0734.190, RSKangXi=96.8, Def{polish jade; cut jade}
7423 CJK UNIFIED IDEOGRAPH-#7423, IRGKangXi=0734.200, RSKangXi=96.8
7424 CJK UNIFIED IDEOGRAPH-#7424, IRGKangXi=0734.210, RSKangXi=96.8, Def{jade of jade being; tinkle}
7425 CJK UNIFIED IDEOGRAPH-#7425, IRGKangXi=0734.220, RSKangXi=96.8, Def{jewel in shape of tiger; amber}
7426 CJK UNIFIED IDEOGRAPH-#7426, IRGKangXi=0734.230, RSKangXi=96.8, Def{gem, precious stone, jade}
7427 CJK UNIFIED IDEOGRAPH-#7427, IRGKangXi=0734.250, RSKangXi=96.8
7428 CJK UNIFIED IDEOGRAPH-#7428, IRGKangXi=0734.260, RSKangXi=96.8, Def{beautiful jade, precious stones}
7429 CJK UNIFIED IDEOGRAPH-#7429, IRGKangXi=0734.270, RSKangXi=96.8
742A CJK UNIFIED IDEOGRAPH-#742A, IRGKangXi=0734.280, RSKangXi=96.8, Def{type of jade}
742B CJK UNIFIED IDEOGRAPH-#742B, IRGKangXi=0735.010, RSKangXi=96.8, Def{ornament}
742C CJK UNIFIED IDEOGRAPH-#742C, IRGKangXi=0735.020, RSKangXi=96.8, Def{the virtue of a gentleman; jade}
742D CJK UNIFIED IDEOGRAPH-#742D, IRGKangXi=0735.030, RSKangXi=96.8, Def{jade like stone}
742E CJK UNIFIED IDEOGRAPH-#742E, IRGKangXi=0735.040, RSKangXi=96.8, Def{octagonal piece of jade with hole in middle}
742F CJK UNIFIED IDEOGRAPH-#742F, IRGKangXi=0735.050, RSKangXi=96.8, Def{a jade tube used as an instrument}
7430 CJK UNIFIED IDEOGRAPH-#7430, IRGKangXi=0735.060, RSKangXi=96.8, Def{jewel, gem; glitter of gems}
7431 CJK UNIFIED IDEOGRAPH-#7431, IRGKangXi=0735.070, RSKangXi=96.8, Def{engrave, inlay, carve; exhaust}
7432 CJK UNIFIED IDEOGRAPH-#7432, IRGKangXi=0735.080, RSKangXi=96.8, Def{necklace}
7433 CJK UNIFIED IDEOGRAPH-#7433, IRGKangXi=0735.090, RSKangXi=96.8, Def{beautiful jade, gem}
7434 CJK UNIFIED IDEOGRAPH-#7434, IRGKangXi=0735.110, RSKangXi=96.8, Def{Chinese lute or guitar}
7435 CJK UNIFIED IDEOGRAPH-#7435, IRGKangXi=0736.010, RSKangXi=96.8, Def{guitar-like instrument}
7436 CJK UNIFIED IDEOGRAPH-#7436, IRGKangXi=0736.020, RSKangXi=96.8, Def{guitar-like instrument}
7437 CJK UNIFIED IDEOGRAPH-#7437, IRGKangXi=0736.070
7438 CJK UNIFIED IDEOGRAPH-#7438, IRGKangXi=0736.080, RSKangXi=96.8
7439 CJK UNIFIED IDEOGRAPH-#7439, IRGKangXi=0736.081, RSKangXi=96.8
743A CJK UNIFIED IDEOGRAPH-#743A, IRGKangXi=0736.081, RSKangXi=96.8, Def{enamel, cloissoné}
743B CJK UNIFIED IDEOGRAPH-#743B, IRGKangXi=0736.081, RSKangXi=96.8
743C CJK UNIFIED IDEOGRAPH-#743C, IRGKangXi=0736.081, RSKangXi=96.8, Def{jade; rare, precious; elegant; (Cant.) to coagulate}
743D CJK UNIFIED IDEOGRAPH-#743D, IRGKangXi=0736.090, RSKangXi=96.9
743E CJK UNIFIED IDEOGRAPH-#743E, IRGKangXi=0736.100, RSKangXi=96.9
743F CJK UNIFIED IDEOGRAPH-#743F, IRGKangXi=0736.110, RSKangXi=96.9, Def{bright, glorious, splendid}
7440 CJK UNIFIED IDEOGRAPH-#7440, IRGKangXi=0736.140, RSKangXi=96.9, Def{stone resembling jade; agate}
7441 CJK UNIFIED IDEOGRAPH-#7441, IRGKangXi=0736.150, RSKangXi=96.9, Def{fine piece of jade}
7442 CJK UNIFIED IDEOGRAPH-#7442, IRGKangXi=0736.180, RSKangXi=96.9
7443 CJK UNIFIED IDEOGRAPH-#7443, IRGKangXi=0736.190, RSKangXi=96.9
7444 CJK UNIFIED IDEOGRAPH-#7444, IRGKangXi=0736.200, RSKangXi=96.9, Def{a ornamental piece of jade several inches across with a hole in the center}
7445 CJK UNIFIED IDEOGRAPH-#7445, IRGKangXi=0736.210, RSKangXi=96.9
7446 CJK UNIFIED IDEOGRAPH-#7446, IRGKangXi=0736.220, RSKangXi=96.9
7447 CJK UNIFIED IDEOGRAPH-#7447, IRGKangXi=0736.230, RSKangXi=96.9, Def{tortoise shell}
7448 CJK UNIFIED IDEOGRAPH-#7448, IRGKangXi=0737.010, RSKangXi=96.9
7449 CJK UNIFIED IDEOGRAPH-#7449, IRGKangXi=0737.020, RSKangXi=96.9
744A CJK UNIFIED IDEOGRAPH-#744A, IRGKangXi=0737.030, RSKangXi=96.9
744B CJK UNIFIED IDEOGRAPH-#744B, IRGKangXi=0737.050, RSKangXi=96.9, Def{type of jade; rare, valuable}
744C CJK UNIFIED IDEOGRAPH-#744C, IRGKangXi=0737.060, RSKangXi=96.9, Def{a white opaque quartz used for ornaments}
744D CJK UNIFIED IDEOGRAPH-#744D, IRGKangXi=0737.070, RSKangXi=96.9
744E CJK UNIFIED IDEOGRAPH-#744E, IRGKangXi=0737.080, RSKangXi=96.9
744F CJK UNIFIED IDEOGRAPH-#744F, IRGKangXi=0737.090, RSKangXi=96.9
7450 CJK UNIFIED IDEOGRAPH-#7450, IRGKangXi=0737.100, RSKangXi=96.9
7451 CJK UNIFIED IDEOGRAPH-#7451, IRGKangXi=0737.110, RSKangXi=96.9, Def{carve, engrave, cut out, sculpt}
7452 CJK UNIFIED IDEOGRAPH-#7452, IRGKangXi=0737.120, RSKangXi=96.9
7453 CJK UNIFIED IDEOGRAPH-#7453, IRGKangXi=0737.130, RSKangXi=96.9
7454 CJK UNIFIED IDEOGRAPH-#7454, IRGKangXi=0737.150, RSKangXi=96.9
7455 CJK UNIFIED IDEOGRAPH-#7455, IRGKangXi=0737.180, RSKangXi=96.9, Def{flaw in gem; fault, defect}
7456 CJK UNIFIED IDEOGRAPH-#7456, IRGKangXi=0737.190, RSKangXi=96.9
7457 CJK UNIFIED IDEOGRAPH-#7457, IRGKangXi=0737.200, RSKangXi=96.9, Def{large ring of fine jade}
7458 CJK UNIFIED IDEOGRAPH-#7458, IRGKangXi=0738.020, RSKangXi=96.9
7459 CJK UNIFIED IDEOGRAPH-#7459, IRGKangXi=0738.030, RSKangXi=96.9, Def{agate; cornelian}
745A CJK UNIFIED IDEOGRAPH-#745A, IRGKangXi=0738.040, RSKangXi=96.9, Def{coral; person of virtue}
745B CJK UNIFIED IDEOGRAPH-#745B, IRGKangXi=0738.050, RSKangXi=96.9, Def{luster of gem; crystal}
745C CJK UNIFIED IDEOGRAPH-#745C, IRGKangXi=0738.070, RSKangXi=96.9, Def{flawless gem or jewel}
745D CJK UNIFIED IDEOGRAPH-#745D, IRGKangXi=0738.080, RSKangXi=96.9
745E CJK UNIFIED IDEOGRAPH-#745E, IRGKangXi=0738.090, RSKangXi=96.9, Def{felicitous omen; auspicious}
745F CJK UNIFIED IDEOGRAPH-#745F, IRGKangXi=0738.110, RSKangXi=96.9, Def{large stringed musical instrument; dignified, massive; sound of wind}
7460 CJK UNIFIED IDEOGRAPH-#7460, IRGKangXi=0738.190, RSKangXi=96.10, Def{precious stone}
7461 CJK UNIFIED IDEOGRAPH-#7461, IRGKangXi=0738.200, RSKangXi=96.10
7462 CJK UNIFIED IDEOGRAPH-#7462, IRGKangXi=0738.220, RSKangXi=96.10, Def{gem ornaments for belts}
7463 CJK UNIFIED IDEOGRAPH-#7463, IRGKangXi=0738.230, RSKangXi=96.10, Def{fragments; trifling, petty; troublesome}
7464 CJK UNIFIED IDEOGRAPH-#7464, IRGKangXi=0739.010, RSKangXi=96.10, Def{precious jade}
7465 CJK UNIFIED IDEOGRAPH-#7465, IRGKangXi=0739.030, RSKangXi=96.10
7466 CJK UNIFIED IDEOGRAPH-#7466, IRGKangXi=0739.040, RSKangXi=96.10
7467 CJK UNIFIED IDEOGRAPH-#7467, IRGKangXi=0739.050, RSKangXi=96.10
7468 CJK UNIFIED IDEOGRAPH-#7468, IRGKangXi=0739.060, RSKangXi=96.10, Def{jade look alike stone}
7469 CJK UNIFIED IDEOGRAPH-#7469, IRGKangXi=0739.080, RSKangXi=96.10, Def{lustre of gems; bright, lustrous}
746A CJK UNIFIED IDEOGRAPH-#746A, IRGKangXi=0739.090, RSKangXi=96.10, Def{agate; cornelian}
746B CJK UNIFIED IDEOGRAPH-#746B, IRGKangXi=0739.100, RSKangXi=96.10
746C CJK UNIFIED IDEOGRAPH-#746C, IRGKangXi=0739.120
746D CJK UNIFIED IDEOGRAPH-#746D, IRGKangXi=0739.130, RSKangXi=96.10, Def{a kind of jade}
746E CJK UNIFIED IDEOGRAPH-#746E, IRGKangXi=0739.140, RSKangXi=96.10
746F CJK UNIFIED IDEOGRAPH-#746F, IRGKangXi=0739.150, RSKangXi=96.10, Def{kind of white cornelian}
7470 CJK UNIFIED IDEOGRAPH-#7470, IRGKangXi=0739.160, RSKangXi=96.10, Def{extraordinary, fabulous; rose}
7471 CJK UNIFIED IDEOGRAPH-#7471, IRGKangXi=0740.030, RSKangXi=96.10, Def{a gem used as ear plug; a jade earring}
7472 CJK UNIFIED IDEOGRAPH-#7472, IRGKangXi=0740.040, RSKangXi=96.10, Def{tinkling sound tinkling of pendant gems}
7473 CJK UNIFIED IDEOGRAPH-#7473, IRGKangXi=0740.050, RSKangXi=96.10, Def{luster of gem; lustrous, bright}
7474 CJK UNIFIED IDEOGRAPH-#7474, IRGKangXi=0740.060, RSKangXi=96.10, Def{twin gems}
7475 CJK UNIFIED IDEOGRAPH-#7475, IRGKangXi=0740.070, RSKangXi=96.10
7476 CJK UNIFIED IDEOGRAPH-#7476, IRGKangXi=0740.111, RSKangXi=96.10, Def{precious jade}
7477 CJK UNIFIED IDEOGRAPH-#7477, IRGKangXi=0740.111, RSKangXi=96.10, Def{fine quality jade}
7478 CJK UNIFIED IDEOGRAPH-#7478, IRGKangXi=0740.111, RSKangXi=96.10
7479 CJK UNIFIED IDEOGRAPH-#7479, IRGKangXi=0740.120, RSKangXi=96.11
747A CJK UNIFIED IDEOGRAPH-#747A, IRGKangXi=0740.130, RSKangXi=96.11
747B CJK UNIFIED IDEOGRAPH-#747B, IRGKangXi=0740.140, RSKangXi=96.11
747C CJK UNIFIED IDEOGRAPH-#747C, IRGKangXi=0740.160, RSKangXi=96.11
747D CJK UNIFIED IDEOGRAPH-#747D, IRGKangXi=0740.170, RSKangXi=96.11, Def{tinkling of jade pendants}
747E CJK UNIFIED IDEOGRAPH-#747E, IRGKangXi=0740.180, RSKangXi=96.11, Def{brilliance of gems; fine jade}
747F CJK UNIFIED IDEOGRAPH-#747F, IRGKangXi=0740.190, RSKangXi=96.11, Def{a black stone like jade; jet}
7480 CJK UNIFIED IDEOGRAPH-#7480, IRGKangXi=0740.230, RSKangXi=96.11, Def{lustre of gems; glitter; shine}
7481 CJK UNIFIED IDEOGRAPH-#7481, IRGKangXi=0740.240, RSKangXi=96.11, Def{turquoise}
7482 CJK UNIFIED IDEOGRAPH-#7482, IRGKangXi=0740.250, RSKangXi=96.11, Def{jade ornament}
7483 CJK UNIFIED IDEOGRAPH-#7483, IRGKangXi=0740.260, RSKangXi=96.11, Def{glass}
7484 CJK UNIFIED IDEOGRAPH-#7484, IRGKangXi=0741.010, RSKangXi=96.11
7485 CJK UNIFIED IDEOGRAPH-#7485, IRGKangXi=0741.030, RSKangXi=96.11, Def{gem}
7486 CJK UNIFIED IDEOGRAPH-#7486, IRGKangXi=0741.040, RSKangXi=96.11, Def{beautiful jade; tinkle}
7487 CJK UNIFIED IDEOGRAPH-#7487, IRGKangXi=0741.050, RSKangXi=96.11, Def{beautiful jade; star}
7488 CJK UNIFIED IDEOGRAPH-#7488, IRGKangXi=0741.060, RSKangXi=96.11, Def{ancient musical instrument}
7489 CJK UNIFIED IDEOGRAPH-#7489, IRGKangXi=0741.080, RSKangXi=96.11, Def{a vessel used hold grain offerings}
748A CJK UNIFIED IDEOGRAPH-#748A, IRGKangXi=0741.100, RSKangXi=96.11, Def{reddish}
748B CJK UNIFIED IDEOGRAPH-#748B, IRGKangXi=0741.130, RSKangXi=96.11, Def{jade plaything; jade ornament}
748C CJK UNIFIED IDEOGRAPH-#748C, IRGKangXi=0741.210, RSKangXi=96.11
748D CJK UNIFIED IDEOGRAPH-#748D, IRGKangXi=0742.251, RSKangXi=96.12
748E CJK UNIFIED IDEOGRAPH-#748E, IRGKangXi=0741.221, RSKangXi=96.11, Def{a necklace made of precious stones}
748F CJK UNIFIED IDEOGRAPH-#748F, IRGKangXi=0741.230, RSKangXi=96.12
7490 CJK UNIFIED IDEOGRAPH-#7490, IRGKangXi=0741.240, RSKangXi=96.12, Def{beautiful variety of jade}
7491 CJK UNIFIED IDEOGRAPH-#7491, IRGKangXi=0741.250, RSKangXi=96.12
7492 CJK UNIFIED IDEOGRAPH-#7492, IRGKangXi=0741.260, RSKangXi=96.12
7493 CJK UNIFIED IDEOGRAPH-#7493, IRGKangXi=0741.270, RSKangXi=96.12
7494 CJK UNIFIED IDEOGRAPH-#7494, IRGKangXi=0741.290, RSKangXi=96.12
7495 CJK UNIFIED IDEOGRAPH-#7495, IRGKangXi=0741.300, RSKangXi=96.12
7496 CJK UNIFIED IDEOGRAPH-#7496, IRGKangXi=0741.320, RSKangXi=96.12
7497 CJK UNIFIED IDEOGRAPH-#7497, IRGKangXi=0741.350, RSKangXi=96.12
7498 CJK UNIFIED IDEOGRAPH-#7498, IRGKangXi=0741.360, RSKangXi=96.12, Def{luster of jade}
7499 CJK UNIFIED IDEOGRAPH-#7499, IRGKangXi=0742.020, RSKangXi=96.12
749A CJK UNIFIED IDEOGRAPH-#749A, IRGKangXi=0742.030, RSKangXi=96.12, Def{splendid}
749B CJK UNIFIED IDEOGRAPH-#749B, IRGKangXi=0742.050, RSKangXi=96.12
749C CJK UNIFIED IDEOGRAPH-#749C, IRGKangXi=0742.060, RSKangXi=96.12, Def{a semicircular jade ornament used as a pendant}
749D CJK UNIFIED IDEOGRAPH-#749D, IRGKangXi=0742.080, RSKangXi=96.12
749E CJK UNIFIED IDEOGRAPH-#749E, IRGKangXi=0742.090, RSKangXi=96.12, Def{unpolished gem, uncarved gem}
749F CJK UNIFIED IDEOGRAPH-#749F, IRGKangXi=0742.100, RSKangXi=96.12, Def{luster of gem}
74A0 CJK UNIFIED IDEOGRAPH-#74A0, IRGKangXi=0742.110, RSKangXi=96.12, Def{a piece of precious jade}
74A1 CJK UNIFIED IDEOGRAPH-#74A1, IRGKangXi=0742.120, RSKangXi=96.12, Def{jade look alike stone}
74A2 CJK UNIFIED IDEOGRAPH-#74A2, IRGKangXi=0742.130, RSKangXi=96.13, Def{precious stone}
74A3 CJK UNIFIED IDEOGRAPH-#74A3, IRGKangXi=0742.170, RSKangXi=96.12, Def{pearl that is not quite round}
74A4 CJK UNIFIED IDEOGRAPH-#74A4, IRGKangXi=0742.251, RSKangXi=96.12
74A5 CJK UNIFIED IDEOGRAPH-#74A5, IRGKangXi=0742.260, RSKangXi=96.13, Def{a kind of jade}
74A6 CJK UNIFIED IDEOGRAPH-#74A6, IRGKangXi=0742.270, RSKangXi=96.13, Def{fine quality jade}
74A7 CJK UNIFIED IDEOGRAPH-#74A7, IRGKangXi=0742.290, RSKangXi=96.13, Def{piece of jade with hole in it}
74A8 CJK UNIFIED IDEOGRAPH-#74A8, IRGKangXi=0742.300, RSKangXi=96.13, Def{gems; luster of gems; lustrous}
74A9 CJK UNIFIED IDEOGRAPH-#74A9, IRGKangXi=0743.010, RSKangXi=96.13, Def{jade ring; earrings; surname}
74AA CJK UNIFIED IDEOGRAPH-#74AA, IRGKangXi=0743.030, RSKangXi=96.13, Def{pearl pendants on coronet}
74AB CJK UNIFIED IDEOGRAPH-#74AB, IRGKangXi=0743.060, RSKangXi=96.13, Def{pendant ornaments, earrings}
74AC CJK UNIFIED IDEOGRAPH-#74AC, IRGKangXi=0743.070, RSKangXi=96.13
74AD CJK UNIFIED IDEOGRAPH-#74AD, IRGKangXi=0743.080, RSKangXi=96.13
74AE CJK UNIFIED IDEOGRAPH-#74AE, IRGKangXi=0743.120, RSKangXi=96.13
74AF CJK UNIFIED IDEOGRAPH-#74AF, IRGKangXi=0743.140, RSKangXi=96.13
74B0 CJK UNIFIED IDEOGRAPH-#74B0, IRGKangXi=0743.170, RSKangXi=96.13, Def{jade ring or bracelet; ring}
74B1 CJK UNIFIED IDEOGRAPH-#74B1, IRGKangXi=0743.180, RSKangXi=96.13
74B2 CJK UNIFIED IDEOGRAPH-#74B2, IRGKangXi=0743.200, RSKangXi=96.13, Def{pendant girdle ornament}
74B3 CJK UNIFIED IDEOGRAPH-#74B3, IRGKangXi=0744.021, RSKangXi=96.13
74B4 CJK UNIFIED IDEOGRAPH-#74B4, IRGKangXi=0744.021, RSKangXi=96.13
74B5 CJK UNIFIED IDEOGRAPH-#74B5, IRGKangXi=0744.030, RSKangXi=96.14, Def{beautiful jade}
74B6 CJK UNIFIED IDEOGRAPH-#74B6, IRGKangXi=0744.040, RSKangXi=96.14
74B7 CJK UNIFIED IDEOGRAPH-#74B7, IRGKangXi=0744.060, RSKangXi=96.14
74B8 CJK UNIFIED IDEOGRAPH-#74B8, IRGKangXi=0744.070, RSKangXi=96.14, Def{jade's streaks}
74B9 CJK UNIFIED IDEOGRAPH-#74B9, IRGKangXi=0744.090, RSKangXi=96.14
74BA CJK UNIFIED IDEOGRAPH-#74BA, IRGKangXi=0744.110, RSKangXi=96.14, Def{a crack, as in porcelain}
74BB CJK UNIFIED IDEOGRAPH-#74BB, IRGKangXi=0744.130, RSKangXi=96.14
74BC CJK UNIFIED IDEOGRAPH-#74BC, IRGKangXi=0744.140, RSKangXi=96.14
74BD CJK UNIFIED IDEOGRAPH-#74BD, IRGKangXi=0744.150, RSKangXi=96.14, Def{imperial signet, royal signet}
74BE CJK UNIFIED IDEOGRAPH-#74BE, IRGKangXi=0744.160, RSKangXi=96.14
74BF CJK UNIFIED IDEOGRAPH-#74BF, IRGKangXi=0744.170, RSKangXi=96.14, Def{fine jade}
74C0 CJK UNIFIED IDEOGRAPH-#74C0, IRGKangXi=0744.210, RSKangXi=96.14, Def{gem}
74C1 CJK UNIFIED IDEOGRAPH-#74C1, IRGKangXi=0744.250, RSKangXi=96.14
74C2 CJK UNIFIED IDEOGRAPH-#74C2, IRGKangXi=0744.260, RSKangXi=96.14
74C3 CJK UNIFIED IDEOGRAPH-#74C3, IRGKangXi=0744.270, RSKangXi=96.15
74C4 CJK UNIFIED IDEOGRAPH-#74C4, IRGKangXi=0744.280, RSKangXi=96.15
74C5 CJK UNIFIED IDEOGRAPH-#74C5, IRGKangXi=0744.290, RSKangXi=96.15
74C6 CJK UNIFIED IDEOGRAPH-#74C6, IRGKangXi=0744.300, RSKangXi=96.15
74C7 CJK UNIFIED IDEOGRAPH-#74C7, IRGKangXi=0744.310, RSKangXi=96.15
74C8 CJK UNIFIED IDEOGRAPH-#74C8, IRGKangXi=0744.320, RSKangXi=96.15, Def{glass}
74C9 CJK UNIFIED IDEOGRAPH-#74C9, IRGKangXi=0744.350, RSKangXi=96.15
74CA CJK UNIFIED IDEOGRAPH-#74CA, IRGKangXi=0744.360, RSKangXi=96.15, Def{jade; rare, precious; elegant}
74CB CJK UNIFIED IDEOGRAPH-#74CB, IRGKangXi=0745.040, RSKangXi=96.15
74CC CJK UNIFIED IDEOGRAPH-#74CC, IRGKangXi=0745.070, RSKangXi=96.16, Def{extraordinary, fabulous}
74CD CJK UNIFIED IDEOGRAPH-#74CD, IRGKangXi=0745.090, RSKangXi=96.16
74CE CJK UNIFIED IDEOGRAPH-#74CE, IRGKangXi=0745.100, RSKangXi=96.16
74CF CJK UNIFIED IDEOGRAPH-#74CF, IRGKangXi=0745.110, RSKangXi=96.16, Def{a gem cut like dragon}
74D0 CJK UNIFIED IDEOGRAPH-#74D0, IRGKangXi=0745.120, RSKangXi=96.16
74D1 CJK UNIFIED IDEOGRAPH-#74D1, IRGKangXi=0745.141, RSKangXi=96.16
74D2 CJK UNIFIED IDEOGRAPH-#74D2, IRGKangXi=0745.141, RSKangXi=96.16, Def{ceremonial libation cup}
74D3 CJK UNIFIED IDEOGRAPH-#74D3, IRGKangXi=0745.150, RSKangXi=96.17
74D4 CJK UNIFIED IDEOGRAPH-#74D4, IRGKangXi=0745.160, RSKangXi=96.17, Def{a necklace made of precious stones}
74D5 CJK UNIFIED IDEOGRAPH-#74D5, IRGKangXi=0745.180, RSKangXi=96.17
74D6 CJK UNIFIED IDEOGRAPH-#74D6, IRGKangXi=0745.190, RSKangXi=96.17, Def{inlay}
74D7 CJK UNIFIED IDEOGRAPH-#74D7, IRGKangXi=0745.240, RSKangXi=96.18
74D8 CJK UNIFIED IDEOGRAPH-#74D8, IRGKangXi=0745.260, RSKangXi=96.18, Def{jade}
74D9 CJK UNIFIED IDEOGRAPH-#74D9, IRGKangXi=0745.270, RSKangXi=96.18
74DA CJK UNIFIED IDEOGRAPH-#74DA, IRGKangXi=0745.290, RSKangXi=96.19, Def{ceremonial libation cup}
74DB CJK UNIFIED IDEOGRAPH-#74DB, IRGKangXi=0745.300, RSKangXi=96.20, Def{sceptre}
74DC CJK UNIFIED IDEOGRAPH-#74DC, IRGKangXi=0746.010, RSKangXi=97.0, Def{melon, gourd, cucumber; rad. 97}
74DD CJK UNIFIED IDEOGRAPH-#74DD, IRGKangXi=0746.020, RSKangXi=97.3
74DE CJK UNIFIED IDEOGRAPH-#74DE, IRGKangXi=0746.090, RSKangXi=97.5, Def{young melons just forming}
74DF CJK UNIFIED IDEOGRAPH-#74DF, IRGKangXi=0746.120, RSKangXi=97.5, Def{the bottle-gourd}
74E0 CJK UNIFIED IDEOGRAPH-#74E0, IRGKangXi=0746.200, RSKangXi=97.6, Def{bottle gourd; calabash; pot}
74E1 CJK UNIFIED IDEOGRAPH-#74E1, IRGKangXi=0747.080, RSKangXi=97.8
74E2 CJK UNIFIED IDEOGRAPH-#74E2, IRGKangXi=0747.200, RSKangXi=97.11, Def{ladle made from dried gourd}
74E3 CJK UNIFIED IDEOGRAPH-#74E3, IRGKangXi=0747.260, RSKangXi=97.14, Def{petal; segment; valves}
74E4 CJK UNIFIED IDEOGRAPH-#74E4, IRGKangXi=0747.300, RSKangXi=97.17, Def{flesh, core, pulp, pith}
74E5 CJK UNIFIED IDEOGRAPH-#74E5, IRGKangXi=0747.330, RSKangXi=97.19
74E6 CJK UNIFIED IDEOGRAPH-#74E6, IRGKangXi=0747.360, RSKangXi=98.0, Def{tile; earthenware pottery; girl}
74E7 CJK UNIFIED IDEOGRAPH-#74E7, IRGKangXi=0748.021, RSKangXi=98.2, Def{decagram}
74E8 CJK UNIFIED IDEOGRAPH-#74E8, IRGKangXi=0748.080, RSKangXi=98.3
74E9 CJK UNIFIED IDEOGRAPH-#74E9, IRGKangXi=0748.081, RSKangXi=98.3, Def{kilowatt; kilogram}
74EA CJK UNIFIED IDEOGRAPH-#74EA, IRGKangXi=0748.090, RSKangXi=98.4
74EB CJK UNIFIED IDEOGRAPH-#74EB, IRGKangXi=0748.100, RSKangXi=98.4
74EC CJK UNIFIED IDEOGRAPH-#74EC, IRGKangXi=0748.150, RSKangXi=98.4
74ED CJK UNIFIED IDEOGRAPH-#74ED, IRGKangXi=0748.160, RSKangXi=98.4
74EE CJK UNIFIED IDEOGRAPH-#74EE, IRGKangXi=0748.190, RSKangXi=98.4, Def{earthen jar; jar for ashes}
74EF CJK UNIFIED IDEOGRAPH-#74EF, IRGKangXi=0748.201, RSKangXi=98.4, Def{bowl, cup; small tray}
74F0 CJK UNIFIED IDEOGRAPH-#74F0, IRGKangXi=0748.201, RSKangXi=98.4, Def{a decigram, one-tenth of a gram}
74F1 CJK UNIFIED IDEOGRAPH-#74F1, IRGKangXi=0748.201, RSKangXi=98.4, Def{milligram}
74F2 CJK UNIFIED IDEOGRAPH-#74F2, IRGKangXi=0748.201, RSKangXi=98.4
74F3 CJK UNIFIED IDEOGRAPH-#74F3, IRGKangXi=0748.220, RSKangXi=98.5
74F4 CJK UNIFIED IDEOGRAPH-#74F4, IRGKangXi=0748.230, RSKangXi=98.5, Def{concave channels of tiling a long-necked jar}
74F5 CJK UNIFIED IDEOGRAPH-#74F5, IRGKangXi=0748.240, RSKangXi=98.5
74F6 CJK UNIFIED IDEOGRAPH-#74F6, IRGKangXi=0749.020, RSKangXi=98.6, Def{jug, pitcher, vase, jar, bottle}
74F7 CJK UNIFIED IDEOGRAPH-#74F7, IRGKangXi=0749.070, RSKangXi=98.6, Def{crockery, porcelain, chinaware}
74F8 CJK UNIFIED IDEOGRAPH-#74F8, IRGKangXi=0749.131, RSKangXi=98.6, Def{hectogram}
74F9 CJK UNIFIED IDEOGRAPH-#74F9, IRGKangXi=0749.140, RSKangXi=98.7, Def{(Cant.) to hide quickly; to dash}
74FA CJK UNIFIED IDEOGRAPH-#74FA, IRGKangXi=0749.230, RSKangXi=98.7
74FB CJK UNIFIED IDEOGRAPH-#74FB, IRGKangXi=0749.270, RSKangXi=98.7, Def{jar}
74FC CJK UNIFIED IDEOGRAPH-#74FC, IRGKangXi=0749.301, RSKangXi=98.7
74FD CJK UNIFIED IDEOGRAPH-#74FD, IRGKangXi=0749.360, RSKangXi=98.8
74FE CJK UNIFIED IDEOGRAPH-#74FE, IRGKangXi=0749.370, RSKangXi=98.8
74FF CJK UNIFIED IDEOGRAPH-#74FF, IRGKangXi=0749.450, RSKangXi=98.8, Def{jar, pot}
7500 CJK UNIFIED IDEOGRAPH-#7500, IRGKangXi=0750.020, RSKangXi=98.8, Def{jar}
7501 CJK UNIFIED IDEOGRAPH-#7501, IRGKangXi=0750.030, RSKangXi=98.8, Def{jug}
7502 CJK UNIFIED IDEOGRAPH-#7502, IRGKangXi=0750.150, RSKangXi=98.9, Def{(Cant.) 打甂爐, to instant-boil thin slices of meat and vegetables in a chafing dish at a dining table}
7503 CJK UNIFIED IDEOGRAPH-#7503, IRGKangXi=0750.190, RSKangXi=98.9, Def{brick wall of a well}
7504 CJK UNIFIED IDEOGRAPH-#7504, IRGKangXi=0750.230, RSKangXi=98.9, Def{to examine, discern; to grade; a surname}
7505 CJK UNIFIED IDEOGRAPH-#7505, IRGKangXi=0750.231, RSKangXi=98.9, Def{centigram}
7506 CJK UNIFIED IDEOGRAPH-#7506, IRGKangXi=0751.111, RSKangXi=98.9
7507 CJK UNIFIED IDEOGRAPH-#7507, IRGKangXi=0751.030, RSKangXi=98.10, Def{jar}
7508 CJK UNIFIED IDEOGRAPH-#7508, IRGKangXi=0751.090, RSKangXi=98.10
7509 CJK UNIFIED IDEOGRAPH-#7509, IRGKangXi=0751.100, RSKangXi=98.10
750A CJK UNIFIED IDEOGRAPH-#750A, IRGKangXi=0751.190, RSKangXi=98.11
750B CJK UNIFIED IDEOGRAPH-#750B, IRGKangXi=0751.200, RSKangXi=98.11, Def{a jar without ears}
750C CJK UNIFIED IDEOGRAPH-#750C, IRGKangXi=0751.220, RSKangXi=98.11, Def{bowl, cup; small tray}
750D CJK UNIFIED IDEOGRAPH-#750D, IRGKangXi=0751.230, RSKangXi=98.11, Def{rafters supporting roof tiles}
750E CJK UNIFIED IDEOGRAPH-#750E, IRGKangXi=0751.250, RSKangXi=98.11, Def{brick, square tile, slab}
750F CJK UNIFIED IDEOGRAPH-#750F, IRGKangXi=0752.050, RSKangXi=98.12, Def{a squat jar for holding wine, sauces etc.}
7510 CJK UNIFIED IDEOGRAPH-#7510, IRGKangXi=0752.070, RSKangXi=98.12
7511 CJK UNIFIED IDEOGRAPH-#7511, IRGKangXi=0752.110, RSKangXi=98.12, Def{boiler for steaming rice, pot}
7512 CJK UNIFIED IDEOGRAPH-#7512, IRGKangXi=0752.130, RSKangXi=98.12, Def{jar}
7513 CJK UNIFIED IDEOGRAPH-#7513, IRGKangXi=0752.170, RSKangXi=98.13, Def{glazed tiles, bricks}
7514 CJK UNIFIED IDEOGRAPH-#7514, IRGKangXi=0752.180, RSKangXi=98.13, Def{big jar}
7515 CJK UNIFIED IDEOGRAPH-#7515, IRGKangXi=0752.250, RSKangXi=98.13, Def{earthen jar; jar for ashes}
7516 CJK UNIFIED IDEOGRAPH-#7516, IRGKangXi=0752.270, RSKangXi=98.14, Def{a pot, pitcher; a small-mouthed clay vessel}
7517 CJK UNIFIED IDEOGRAPH-#7517, IRGKangXi=0753.040, RSKangXi=98.16, Def{earthenware vessel in two parts}
7518 CJK UNIFIED IDEOGRAPH-#7518, IRGKangXi=0753.190, RSKangXi=99.0, Def{sweetness; sweet, tasty}
7519 CJK UNIFIED IDEOGRAPH-#7519, IRGKangXi=0355.101, RSKangXi=56.5, Def{sugar product}
751A CJK UNIFIED IDEOGRAPH-#751A, IRGKangXi=0754.060, RSKangXi=99.4, Def{great extent; considerably}
751B CJK UNIFIED IDEOGRAPH-#751B, IRGKangXi=0754.110, RSKangXi=99.6, Def{sweet, sweetness}
751C CJK UNIFIED IDEOGRAPH-#751C, IRGKangXi=0754.130, RSKangXi=99.6, Def{sweet, sweetness}
751D CJK UNIFIED IDEOGRAPH-#751D, IRGKangXi=0754.150, RSKangXi=99.8
751E CJK UNIFIED IDEOGRAPH-#751E, IRGKangXi=0754.160, RSKangXi=99.8, Def{taste; experience, experiment}
751F CJK UNIFIED IDEOGRAPH-#751F, IRGKangXi=0754.260, RSKangXi=100.0, Def{life, living, lifetime; birth}
7520 CJK UNIFIED IDEOGRAPH-#7520, IRGKangXi=0755.040, RSKangXi=100.4
7521 CJK UNIFIED IDEOGRAPH-#7521, IRGKangXi=0755.050, RSKangXi=100.5, Def{abundant, numerous; crowd}
7522 CJK UNIFIED IDEOGRAPH-#7522, IRGKangXi=0755.090, RSKangXi=100.6, Def{give birth, bring forth, produce}
7523 CJK UNIFIED IDEOGRAPH-#7523, IRGKangXi=0755.111, RSKangXi=100.6, Def{give birth}
7524 CJK UNIFIED IDEOGRAPH-#7524, IRGKangXi=0755.120, RSKangXi=100.7, Def{drooping leaves; fringe soft, delicate}
7525 CJK UNIFIED IDEOGRAPH-#7525, IRGKangXi=0755.140, RSKangXi=100.7, Def{sister's child}
7526 CJK UNIFIED IDEOGRAPH-#7526, IRGKangXi=0755.150, RSKangXi=100.7, Def{be reborn; resuscitate, revive}
7527 CJK UNIFIED IDEOGRAPH-#7527, IRGKangXi=0755.201, RSKangXi=100.9
7528 CJK UNIFIED IDEOGRAPH-#7528, IRGKangXi=0755.240, RSKangXi=101.0, Def{use, employ, apply, operate; use}
7529 CJK UNIFIED IDEOGRAPH-#7529, IRGKangXi=0755.251, RSKangXi=101.0, Def{throw away, discard}
752A CJK UNIFIED IDEOGRAPH-#752A, IRGKangXi=0756.010, RSKangXi=101.1, Def{to loose, take off, get rid of}
752B CJK UNIFIED IDEOGRAPH-#752B, IRGKangXi=0756.020, RSKangXi=101.2, Def{begin; man, father; great; a distance of ten li}
752C CJK UNIFIED IDEOGRAPH-#752C, IRGKangXi=0756.030, RSKangXi=101.2, Def{path; river in Ningbo; Ningbo}
752D CJK UNIFIED IDEOGRAPH-#752D, IRGKangXi=0756.051, RSKangXi=101.4, Def{there is no need}
752E CJK UNIFIED IDEOGRAPH-#752E, IRGKangXi=0756.051, RSKangXi=20.7
752F CJK UNIFIED IDEOGRAPH-#752F, IRGKangXi=0756.080, RSKangXi=101.7, Def{peaceful}
7530 CJK UNIFIED IDEOGRAPH-#7530, IRGKangXi=0756.110, RSKangXi=102.0, Def{field, arable land, cultivated}
7531 CJK UNIFIED IDEOGRAPH-#7531, IRGKangXi=0757.010, RSKangXi=102.0, Def{cause, reason; from}
7532 CJK UNIFIED IDEOGRAPH-#7532, IRGKangXi=0758.010, RSKangXi=102.0, Def{armor, shell; fingernails; 1st heavenly stem}
7533 CJK UNIFIED IDEOGRAPH-#7533, IRGKangXi=0758.040, RSKangXi=102.0, Def{to state to a superior, report; extend; 9th terrestrial branch}
7534 CJK UNIFIED IDEOGRAPH-#7534, IRGKangXi=0759.001, RSKangXi=102.0, Def{(Cant.) cockroach}
7535 CJK UNIFIED IDEOGRAPH-#7535, IRGKangXi=0759.011, RSKangXi=73.1, Def{electricity; electric; lightning}
7536 CJK UNIFIED IDEOGRAPH-#7536, IRGKangXi=0759.010, RSKangXi=102.1
7537 CJK UNIFIED IDEOGRAPH-#7537, IRGKangXi=0759.020, RSKangXi=102.2, Def{male, man; son; baron; surname}
7538 CJK UNIFIED IDEOGRAPH-#7538, IRGKangXi=0759.040, RSKangXi=102.2, Def{suburbs of capital; govern; crops}
7539 CJK UNIFIED IDEOGRAPH-#7539, IRGKangXi=0759.060, RSKangXi=102.2
753A CJK UNIFIED IDEOGRAPH-#753A, IRGKangXi=0759.070, RSKangXi=102.2, Def{raised path between fields}
753B CJK UNIFIED IDEOGRAPH-#753B, IRGKangXi=0759.080, RSKangXi=102.3, Def{a painting, picture, drawing; to draw}
753C CJK UNIFIED IDEOGRAPH-#753C, IRGKangXi=0759.081, RSKangXi=102.2, Def{raised path between fields}
753D CJK UNIFIED IDEOGRAPH-#753D, IRGKangXi=0759.090, RSKangXi=102.3, Def{drain between fields, irrigation}
753E CJK UNIFIED IDEOGRAPH-#753E, IRGKangXi=0759.110, RSKangXi=102.3, Def{ground that has been under cultivation for one year; evil, calamity}
753F CJK UNIFIED IDEOGRAPH-#753F, IRGKangXi=0759.120, RSKangXi=102.3, Def{farming population}
7540 CJK UNIFIED IDEOGRAPH-#7540, IRGKangXi=0759.160, RSKangXi=102.3, Def{to give}
7541 CJK UNIFIED IDEOGRAPH-#7541, IRGKangXi=0759.180, RSKangXi=102.3, Def{to give to; to confer on}
7542 CJK UNIFIED IDEOGRAPH-#7542, IRGKangXi=0759.190, RSKangXi=102.3
7543 CJK UNIFIED IDEOGRAPH-#7543, IRGKangXi=0759.200, RSKangXi=102.3
7544 CJK UNIFIED IDEOGRAPH-#7544, IRGKangXi=0760.031, RSKangXi=102.3, Def{stop, halt; stay, detain, keep}
7545 CJK UNIFIED IDEOGRAPH-#7545, IRGKangXi=0760.031, RSKangXi=72.4, Def{smoothly, freely, unrestrained}
7546 CJK UNIFIED IDEOGRAPH-#7546, IRGKangXi=0760.060, RSKangXi=102.4, Def{Chinese land measure; fields}
7547 CJK UNIFIED IDEOGRAPH-#7547, IRGKangXi=0760.070, RSKangXi=102.4, Def{land}
7548 CJK UNIFIED IDEOGRAPH-#7548, IRGKangXi=0760.100, RSKangXi=102.4, Def{field; farm}
7549 CJK UNIFIED IDEOGRAPH-#7549, IRGKangXi=0760.110, RSKangXi=102.4
754A CJK UNIFIED IDEOGRAPH-#754A, IRGKangXi=0760.160, RSKangXi=102.4, Def{plow, cultivate}
754B CJK UNIFIED IDEOGRAPH-#754B, IRGKangXi=0760.170, RSKangXi=102.4, Def{till land, cultivate; hunt}
754C CJK UNIFIED IDEOGRAPH-#754C, IRGKangXi=0760.180, RSKangXi=102.4, Def{boundary, limit; domain; society; the world}
754D CJK UNIFIED IDEOGRAPH-#754D, IRGKangXi=0760.190, RSKangXi=102.4
754E CJK UNIFIED IDEOGRAPH-#754E, IRGKangXi=0760.200, RSKangXi=102.4, Def{a drain between fields, irrigation; to flow}
754F CJK UNIFIED IDEOGRAPH-#754F, IRGKangXi=0760.220, RSKangXi=102.4, Def{fear, dread, awe, reverence}
7550 CJK UNIFIED IDEOGRAPH-#7550, IRGKangXi=0760.330, RSKangXi=102.4, Def{to fill; a foll of cloth}
7551 CJK UNIFIED IDEOGRAPH-#7551, IRGKangXi=0760.341, RSKangXi=86.5, Def{dry (as opposed to rice) field; used in Japanese names}
7552 CJK UNIFIED IDEOGRAPH-#7552, IRGKangXi=0760.341, RSKangXi=102.4, Def{Chinese land measure; fields}
7553 CJK UNIFIED IDEOGRAPH-#7553, IRGKangXi=0760.341, RSKangXi=85.5, Def{rice field}
7554 CJK UNIFIED IDEOGRAPH-#7554, IRGKangXi=0760.370, RSKangXi=102.5, Def{boundary path dividing fields}
7555 CJK UNIFIED IDEOGRAPH-#7555, IRGKangXi=0760.380, RSKangXi=102.5
7556 CJK UNIFIED IDEOGRAPH-#7556, IRGKangXi=0761.020, RSKangXi=102.4
7557 CJK UNIFIED IDEOGRAPH-#7557, IRGKangXi=0761.030, RSKangXi=102.5
7558 CJK UNIFIED IDEOGRAPH-#7558, IRGKangXi=0761.040, RSKangXi=102.5
7559 CJK UNIFIED IDEOGRAPH-#7559, IRGKangXi=0761.050, RSKangXi=102.5, Def{stop, halt; stay, detain, keep}
755A CJK UNIFIED IDEOGRAPH-#755A, IRGKangXi=0761.060, RSKangXi=102.5, Def{straw basket, hamper}
755B CJK UNIFIED IDEOGRAPH-#755B, IRGKangXi=0761.070, RSKangXi=102.5, Def{border, boundary; raised path}
755C CJK UNIFIED IDEOGRAPH-#755C, IRGKangXi=0761.120, RSKangXi=102.5, Def{livestock, domestic animals}
755D CJK UNIFIED IDEOGRAPH-#755D, IRGKangXi=0761.140, RSKangXi=102.5, Def{Chinese land measure; fields}
755E CJK UNIFIED IDEOGRAPH-#755E, IRGKangXi=0761.191, RSKangXi=102.5
755F CJK UNIFIED IDEOGRAPH-#755F, IRGKangXi=0761.170, RSKangXi=102.5, Def{plough}
7560 CJK UNIFIED IDEOGRAPH-#7560, IRGKangXi=0761.191, RSKangXi=106.5, Def{garden, field, farm, plantation}
7561 CJK UNIFIED IDEOGRAPH-#7561, IRGKangXi=0761.200, RSKangXi=102.6
7562 CJK UNIFIED IDEOGRAPH-#7562, IRGKangXi=0761.210, RSKangXi=102.6, Def{end, finish, conclude; completed}
7563 CJK UNIFIED IDEOGRAPH-#7563, IRGKangXi=0762.050, RSKangXi=102.6
7564 CJK UNIFIED IDEOGRAPH-#7564, IRGKangXi=0762.070, RSKangXi=102.6, Def{place for worshipping the haven}
7565 CJK UNIFIED IDEOGRAPH-#7565, IRGKangXi=0762.090, RSKangXi=102.6, Def{approximately, roughly; outline}
7566 CJK UNIFIED IDEOGRAPH-#7566, IRGKangXi=0762.110, RSKangXi=102.6, Def{sections in vegetable farm}
7567 CJK UNIFIED IDEOGRAPH-#7567, IRGKangXi=0763.031, RSKangXi=102.6, Def{approximately, roughly; outline}
7568 CJK UNIFIED IDEOGRAPH-#7568, IRGKangXi=0763.031, RSKangXi=102.6
7569 CJK UNIFIED IDEOGRAPH-#7569, IRGKangXi=0763.031, RSKangXi=102.6
756A CJK UNIFIED IDEOGRAPH-#756A, IRGKangXi=0763.050, RSKangXi=102.7, Def{to take turns; a turn, a time; to repeat}
756B CJK UNIFIED IDEOGRAPH-#756B, IRGKangXi=0763.080, RSKangXi=102.7, Def{delineate, painting, picture, drawing; draw}
756C CJK UNIFIED IDEOGRAPH-#756C, IRGKangXi=0763.120, RSKangXi=102.7, Def{reclaimed field}
756D CJK UNIFIED IDEOGRAPH-#756D, IRGKangXi=0763.140, RSKangXi=102.7
756E CJK UNIFIED IDEOGRAPH-#756E, IRGKangXi=0763.160, RSKangXi=102.7
756F CJK UNIFIED IDEOGRAPH-#756F, IRGKangXi=0763.170, RSKangXi=102.7, Def{rustic; crude}
7570 CJK UNIFIED IDEOGRAPH-#7570, IRGKangXi=0763.180, RSKangXi=102.7, Def{different, unusual, strange}
7571 CJK UNIFIED IDEOGRAPH-#7571, IRGKangXi=0764.010, RSKangXi=102.9, Def{to detain; to entertain to keep; to put by}
7572 CJK UNIFIED IDEOGRAPH-#7572, IRGKangXi=0764.041, RSKangXi=102.7, Def{to cultivate land by first setting fire to it}
7573 CJK UNIFIED IDEOGRAPH-#7573, IRGKangXi=0764.041, RSKangXi=102.7, Def{repeat, duplicate; repetitious}
7574 CJK UNIFIED IDEOGRAPH-#7574, IRGKangXi=0764.041, RSKangXi=102.7, Def{farmland, arable land; category}
7575 CJK UNIFIED IDEOGRAPH-#7575, IRGKangXi=0764.060, RSKangXi=102.8, Def{delineate, painting, picture, drawing; draw}
7576 CJK UNIFIED IDEOGRAPH-#7576, IRGKangXi=0764.180, RSKangXi=102.8, Def{bear, accept, undertake; just}
7577 CJK UNIFIED IDEOGRAPH-#7577, IRGKangXi=0765.020, RSKangXi=102.8, Def{raised path between fields}
7578 CJK UNIFIED IDEOGRAPH-#7578, IRGKangXi=0765.030, RSKangXi=102.8, Def{odd, fractional, remainder, odds}
7579 CJK UNIFIED IDEOGRAPH-#7579, IRGKangXi=0765.040, RSKangXi=102.8
757A CJK UNIFIED IDEOGRAPH-#757A, IRGKangXi=0765.050, RSKangXi=102.8, Def{boundary, border}
757B CJK UNIFIED IDEOGRAPH-#757B, IRGKangXi=0765.100, RSKangXi=102.9
757C CJK UNIFIED IDEOGRAPH-#757C, IRGKangXi=0765.110, RSKangXi=102.9
757D CJK UNIFIED IDEOGRAPH-#757D, IRGKangXi=0765.120, RSKangXi=102.9, Def{ground}
757E CJK UNIFIED IDEOGRAPH-#757E, IRGKangXi=0766.070, RSKangXi=102.10, Def{fields divided by dikes}
757F CJK UNIFIED IDEOGRAPH-#757F, IRGKangXi=0766.080, RSKangXi=102.10, Def{imperial domain; area near capital}
7580 CJK UNIFIED IDEOGRAPH-#7580, IRGKangXi=0766.120, RSKangXi=102.11
7581 CJK UNIFIED IDEOGRAPH-#7581, IRGKangXi=0766.150, RSKangXi=102.11
7582 CJK UNIFIED IDEOGRAPH-#7582, IRGKangXi=0766.181, RSKangXi=102.11, Def{repeat, duplicate; repetitious}
7583 CJK UNIFIED IDEOGRAPH-#7583, IRGKangXi=0766.190, RSKangXi=102.12, Def{hamlet; area outside city}
7584 CJK UNIFIED IDEOGRAPH-#7584, IRGKangXi=0766.240, RSKangXi=102.12
7585 CJK UNIFIED IDEOGRAPH-#7585, IRGKangXi=0766.300, RSKangXi=102.13
7586 CJK UNIFIED IDEOGRAPH-#7586, IRGKangXi=0766.330, RSKangXi=102.14, Def{boundary, border, frontier}
7587 CJK UNIFIED IDEOGRAPH-#7587, IRGKangXi=0766.400, RSKangXi=102.14, Def{farmland, arable land; category}
7588 CJK UNIFIED IDEOGRAPH-#7588, IRGKangXi=0767.040, RSKangXi=102.15
7589 CJK UNIFIED IDEOGRAPH-#7589, IRGKangXi=0767.041, RSKangXi=102.17, Def{repeat, duplicate; repetitious}
758A CJK UNIFIED IDEOGRAPH-#758A, IRGKangXi=0767.090, RSKangXi=102.17, Def{repeat, duplicate; repetitious}
758B CJK UNIFIED IDEOGRAPH-#758B, IRGKangXi=0767.160, RSKangXi=103.0, Def{roll, bolt of cloth; foot}
758C CJK UNIFIED IDEOGRAPH-#758C, IRGKangXi=0767.190, RSKangXi=103.3
758D CJK UNIFIED IDEOGRAPH-#758D, IRGKangXi=0767.201, RSKangXi=103.5
758E CJK UNIFIED IDEOGRAPH-#758E, IRGKangXi=0767.220, RSKangXi=103.7, Def{neglect; careless, lax}
758F CJK UNIFIED IDEOGRAPH-#758F, IRGKangXi=0767.230, RSKangXi=103.7, Def{neglect; careless, lax}
7590 CJK UNIFIED IDEOGRAPH-#7590, IRGKangXi=0768.020, RSKangXi=103.9, Def{fall, stumble, falter; hindered}
7591 CJK UNIFIED IDEOGRAPH-#7591, IRGKangXi=0768.030, RSKangXi=103.9, Def{doubt, question, suspect}
7592 CJK UNIFIED IDEOGRAPH-#7592, IRGKangXi=0769.010, RSKangXi=104.0, Def{sick; KangXi radical 104}
7593 CJK UNIFIED IDEOGRAPH-#7593, IRGKangXi=0769.020, RSKangXi=104.2, Def{fatigued; (Cant.) paralysis of the foot}
7594 CJK UNIFIED IDEOGRAPH-#7594, IRGKangXi=0769.040, RSKangXi=104.2, Def{carbuncle, boil, ulcer}
7595 CJK UNIFIED IDEOGRAPH-#7595, IRGKangXi=0769.080, RSKangXi=104.2, Def{head sores}
7596 CJK UNIFIED IDEOGRAPH-#7596, IRGKangXi=0769.091, RSKangXi=104.2, Def{pimple, sore, boil}
7597 CJK UNIFIED IDEOGRAPH-#7597, IRGKangXi=0769.091, RSKangXi=104.2, Def{be healed, cured, recover}
7598 CJK UNIFIED IDEOGRAPH-#7598, IRGKangXi=0769.100, RSKangXi=104.3
7599 CJK UNIFIED IDEOGRAPH-#7599, IRGKangXi=0769.120, RSKangXi=104.3, Def{pimple, sore, boil, wart, pustule}
759A CJK UNIFIED IDEOGRAPH-#759A, IRGKangXi=0769.130, RSKangXi=104.3, Def{chronic disease, chronic illness; sorrow}
759B CJK UNIFIED IDEOGRAPH-#759B, IRGKangXi=0769.140, RSKangXi=104.3
759C CJK UNIFIED IDEOGRAPH-#759C, IRGKangXi=0769.190, RSKangXi=104.3
759D CJK UNIFIED IDEOGRAPH-#759D, IRGKangXi=0769.200, RSKangXi=104.3, Def{hernia, rupture}
759E CJK UNIFIED IDEOGRAPH-#759E, IRGKangXi=0769.220
759F CJK UNIFIED IDEOGRAPH-#759F, IRGKangXi=0769.221, RSKangXi=104.3, Def{intermittent fever; malaria}
75A0 CJK UNIFIED IDEOGRAPH-#75A0, IRGKangXi=0769.221, RSKangXi=104.3, Def{a sore, ulcer; pestilence}
75A1 CJK UNIFIED IDEOGRAPH-#75A1, IRGKangXi=0769.221, RSKangXi=104.4, Def{ulcers, sores; infection}
75A2 CJK UNIFIED IDEOGRAPH-#75A2, IRGKangXi=0769.240, RSKangXi=104.4, Def{aching of limbs, muscular pains}
75A3 CJK UNIFIED IDEOGRAPH-#75A3, IRGKangXi=0769.300, RSKangXi=104.4, Def{wart; tumor; goiter; papule}
75A4 CJK UNIFIED IDEOGRAPH-#75A4, IRGKangXi=0769.310, RSKangXi=104.4, Def{scar, cicatrix; birthmark}
75A5 CJK UNIFIED IDEOGRAPH-#75A5, IRGKangXi=0770.060, RSKangXi=104.4, Def{scabies, itch}
75A6 CJK UNIFIED IDEOGRAPH-#75A6, IRGKangXi=0770.080, RSKangXi=104.4
75A7 CJK UNIFIED IDEOGRAPH-#75A7, IRGKangXi=0770.110, RSKangXi=104.4, Def{sick}
75A8 CJK UNIFIED IDEOGRAPH-#75A8, IRGKangXi=0770.120, RSKangXi=104.4
75A9 CJK UNIFIED IDEOGRAPH-#75A9, IRGKangXi=0770.140, RSKangXi=104.4
75AA CJK UNIFIED IDEOGRAPH-#75AA, IRGKangXi=0770.170, RSKangXi=104.4
75AB CJK UNIFIED IDEOGRAPH-#75AB, IRGKangXi=0770.180, RSKangXi=104.4, Def{epidemic, plague, pestilence}
75AC CJK UNIFIED IDEOGRAPH-#75AC, IRGKangXi=0770.191, RSKangXi=104.4, Def{scrofulous lumps or swellings}
75AD CJK UNIFIED IDEOGRAPH-#75AD, IRGKangXi=0770.191, RSKangXi=104.4, Def{spasms or convulsions in young children, caused by indigestion}
75AE CJK UNIFIED IDEOGRAPH-#75AE, IRGKangXi=0770.191, RSKangXi=104.4, Def{tumor, boil, sore, wound}
75AF CJK UNIFIED IDEOGRAPH-#75AF, IRGKangXi=0770.191, RSKangXi=104.4, Def{crazy, insane, mentally ill}
75B0 CJK UNIFIED IDEOGRAPH-#75B0, IRGKangXi=0770.200, RSKangXi=104.5
75B1 CJK UNIFIED IDEOGRAPH-#75B1, IRGKangXi=0770.210, RSKangXi=104.5, Def{acne}
75B2 CJK UNIFIED IDEOGRAPH-#75B2, IRGKangXi=0770.230, RSKangXi=104.5, Def{feel tired, be exhausted; weak}
75B3 CJK UNIFIED IDEOGRAPH-#75B3, IRGKangXi=0770.240, RSKangXi=104.5, Def{childhood diseases}
75B4 CJK UNIFIED IDEOGRAPH-#75B4, IRGKangXi=0770.270, RSKangXi=104.5, Def{illness, sickness, disease; pain}
75B5 CJK UNIFIED IDEOGRAPH-#75B5, IRGKangXi=0770.280, RSKangXi=104.5, Def{flaw, fault, defect; disease}
75B6 CJK UNIFIED IDEOGRAPH-#75B6, IRGKangXi=0770.290, RSKangXi=104.5
75B7 CJK UNIFIED IDEOGRAPH-#75B7, IRGKangXi=0771.030
75B8 CJK UNIFIED IDEOGRAPH-#75B8, IRGKangXi=0771.040, RSKangXi=104.5, Def{jaundice; disorders of stomach}
75B9 CJK UNIFIED IDEOGRAPH-#75B9, IRGKangXi=0771.070, RSKangXi=104.5, Def{measles; rash; fever}
75BA CJK UNIFIED IDEOGRAPH-#75BA, IRGKangXi=0771.120, RSKangXi=104.4
75BB CJK UNIFIED IDEOGRAPH-#75BB, IRGKangXi=0771.130, RSKangXi=104.5
75BC CJK UNIFIED IDEOGRAPH-#75BC, IRGKangXi=0771.150, RSKangXi=104.5, Def{aches, pains; be fond of; love}
75BD CJK UNIFIED IDEOGRAPH-#75BD, IRGKangXi=0771.160, RSKangXi=104.5, Def{ulcer, carbuncle, abscess}
75BE CJK UNIFIED IDEOGRAPH-#75BE, IRGKangXi=0771.220, RSKangXi=104.5, Def{illness, disease, sickness; to hate}
75BF CJK UNIFIED IDEOGRAPH-#75BF, IRGKangXi=0771.340, RSKangXi=104.5, Def{prickly heat, rash}
75C0 CJK UNIFIED IDEOGRAPH-#75C0, IRGKangXi=0771.350, RSKangXi=104.5, Def{to crouch; a hunchback}
75C1 CJK UNIFIED IDEOGRAPH-#75C1, IRGKangXi=0771.360, RSKangXi=104.5, Def{chronic malaria}
75C2 CJK UNIFIED IDEOGRAPH-#75C2, IRGKangXi=0772.010, RSKangXi=104.5, Def{scab}
75C3 CJK UNIFIED IDEOGRAPH-#75C3, IRGKangXi=0772.030, RSKangXi=104.5, Def{indigestion; buboes, lymphatic inflammation}
75C4 CJK UNIFIED IDEOGRAPH-#75C4, IRGKangXi=0772.050, RSKangXi=104.5, Def{scrofulous swellings and sores, mumps}
75C5 CJK UNIFIED IDEOGRAPH-#75C5, IRGKangXi=0772.060, RSKangXi=104.5, Def{illness, sickness, disease}
75C6 CJK UNIFIED IDEOGRAPH-#75C6, IRGKangXi=0772.080, RSKangXi=104.5
75C7 CJK UNIFIED IDEOGRAPH-#75C7, IRGKangXi=0772.111, RSKangXi=104.5, Def{disease, illness, ailment}
75C8 CJK UNIFIED IDEOGRAPH-#75C8, IRGKangXi=0772.111, RSKangXi=104.5, Def{carbuncle, sore, ulcer, abscess}
75C9 CJK UNIFIED IDEOGRAPH-#75C9, IRGKangXi=0772.111, RSKangXi=104.5, Def{convulsions, fits}
75CA CJK UNIFIED IDEOGRAPH-#75CA, IRGKangXi=0772.120, RSKangXi=104.6, Def{be healed, be cured; recover}
75CB CJK UNIFIED IDEOGRAPH-#75CB, IRGKangXi=0772.150, RSKangXi=104.6
75CC CJK UNIFIED IDEOGRAPH-#75CC, IRGKangXi=0772.160, RSKangXi=104.6, Def{ache, be in pain; painful}
75CD CJK UNIFIED IDEOGRAPH-#75CD, IRGKangXi=0772.190, RSKangXi=104.6, Def{wound, bruise, sore}
75CE CJK UNIFIED IDEOGRAPH-#75CE, IRGKangXi=0772.230, RSKangXi=104.6
75CF CJK UNIFIED IDEOGRAPH-#75CF, IRGKangXi=0772.250, RSKangXi=104.6, Def{a bruise or contusion}
75D0 CJK UNIFIED IDEOGRAPH-#75D0, IRGKangXi=0772.280, RSKangXi=104.6, Def{whirlwind, cyclone, storm}
75D1 CJK UNIFIED IDEOGRAPH-#75D1, IRGKangXi=0772.300, RSKangXi=104.6
75D2 CJK UNIFIED IDEOGRAPH-#75D2, IRGKangXi=0773.040, RSKangXi=104.6, Def{itch}
75D3 CJK UNIFIED IDEOGRAPH-#75D3, IRGKangXi=0773.050, RSKangXi=104.6
75D4 CJK UNIFIED IDEOGRAPH-#75D4, IRGKangXi=0773.080, RSKangXi=104.6, Def{hemorrhoids, piles}
75D5 CJK UNIFIED IDEOGRAPH-#75D5, IRGKangXi=0773.120, RSKangXi=104.6, Def{scar; mark; trace}
75D6 CJK UNIFIED IDEOGRAPH-#75D6, IRGKangXi=0773.151, RSKangXi=104.6, Def{dumb}
75D7 CJK UNIFIED IDEOGRAPH-#75D7, IRGKangXi=0773.170, RSKangXi=104.7, Def{ill}
75D8 CJK UNIFIED IDEOGRAPH-#75D8, IRGKangXi=0773.180, RSKangXi=104.7, Def{smallpox}
75D9 CJK UNIFIED IDEOGRAPH-#75D9, IRGKangXi=0773.190, RSKangXi=104.7, Def{convulsions, fits}
75DA CJK UNIFIED IDEOGRAPH-#75DA, IRGKangXi=0773.250, RSKangXi=104.7, Def{asthma}
75DB CJK UNIFIED IDEOGRAPH-#75DB, IRGKangXi=0773.280, RSKangXi=104.7, Def{pain, ache; sorry, sad; bitter}
75DC CJK UNIFIED IDEOGRAPH-#75DC, IRGKangXi=0773.290, RSKangXi=104.7, Def{a scabby bald head}
75DD CJK UNIFIED IDEOGRAPH-#75DD, IRGKangXi=0773.310, RSKangXi=104.7
75DE CJK UNIFIED IDEOGRAPH-#75DE, IRGKangXi=0774.020, RSKangXi=104.7, Def{dyspepsia, spleen infection}
75DF CJK UNIFIED IDEOGRAPH-#75DF, IRGKangXi=0774.040, RSKangXi=104.7
75E0 CJK UNIFIED IDEOGRAPH-#75E0, IRGKangXi=0774.070, RSKangXi=104.7, Def{aching of limbs, muscular pains}
75E1 CJK UNIFIED IDEOGRAPH-#75E1, IRGKangXi=0774.080, RSKangXi=104.7, Def{a disease; an ailment}
75E2 CJK UNIFIED IDEOGRAPH-#75E2, IRGKangXi=0774.090, RSKangXi=104.7, Def{dysentery}
75E3 CJK UNIFIED IDEOGRAPH-#75E3, IRGKangXi=0774.140, RSKangXi=104.7, Def{spots, moles; birthmark}
75E4 CJK UNIFIED IDEOGRAPH-#75E4, IRGKangXi=0774.170, RSKangXi=104.7, Def{a swelling of the lymph nodes}
75E5 CJK UNIFIED IDEOGRAPH-#75E5, IRGKangXi=0774.180, RSKangXi=104.7
75E6 CJK UNIFIED IDEOGRAPH-#75E6, IRGKangXi=0774.251, RSKangXi=104.7
75E7 CJK UNIFIED IDEOGRAPH-#75E7, IRGKangXi=0774.251, RSKangXi=104.7, Def{cholera; colic}
75E8 CJK UNIFIED IDEOGRAPH-#75E8, IRGKangXi=0774.251, RSKangXi=104.7, Def{consumption; tuberculosis}
75E9 CJK UNIFIED IDEOGRAPH-#75E9, IRGKangXi=0774.251, RSKangXi=104.7, Def{thin, emaciated, lean; meager}
75EA CJK UNIFIED IDEOGRAPH-#75EA, IRGKangXi=0774.251, RSKangXi=104.7, Def{paralysis, numbness of limbs}
75EB CJK UNIFIED IDEOGRAPH-#75EB, IRGKangXi=0774.251, RSKangXi=104.7, Def{epilepsy, convulsions}
75EC CJK UNIFIED IDEOGRAPH-#75EC, IRGKangXi=0774.270, RSKangXi=104.8
75ED CJK UNIFIED IDEOGRAPH-#75ED, IRGKangXi=0774.280, RSKangXi=104.8, Def{menorrhagia}
75EE CJK UNIFIED IDEOGRAPH-#75EE, IRGKangXi=0774.290, RSKangXi=104.8, Def{a swelled belly; dropsical; to swell; inflated}
75EF CJK UNIFIED IDEOGRAPH-#75EF, IRGKangXi=0774.310, RSKangXi=104.8, Def{sick}
75F0 CJK UNIFIED IDEOGRAPH-#75F0, IRGKangXi=0774.320, RSKangXi=104.8, Def{phlegm, mucus, spittle}
75F1 CJK UNIFIED IDEOGRAPH-#75F1, IRGKangXi=0774.330, RSKangXi=104.8, Def{heat rash, prickly heat; ulcers}
75F2 CJK UNIFIED IDEOGRAPH-#75F2, IRGKangXi=0774.350, RSKangXi=104.8, Def{pock-marked; leprosy; measles}
75F3 CJK UNIFIED IDEOGRAPH-#75F3, IRGKangXi=0774.360, RSKangXi=104.8, Def{pock-marked; leprosy; measles}
75F4 CJK UNIFIED IDEOGRAPH-#75F4, IRGKangXi=0774.380, RSKangXi=104.8, Def{foolish, stupid, dumb, silly}
75F5 CJK UNIFIED IDEOGRAPH-#75F5, IRGKangXi=0775.010, RSKangXi=104.8, Def{a heart symptom}
75F6 CJK UNIFIED IDEOGRAPH-#75F6, IRGKangXi=0775.110, RSKangXi=104.8
75F7 CJK UNIFIED IDEOGRAPH-#75F7, IRGKangXi=0775.120, RSKangXi=104.8
75F8 CJK UNIFIED IDEOGRAPH-#75F8, IRGKangXi=0775.150, RSKangXi=104.8
75F9 CJK UNIFIED IDEOGRAPH-#75F9, IRGKangXi=0775.220, RSKangXi=104.8, Def{paralysis, numbness}
75FA CJK UNIFIED IDEOGRAPH-#75FA, IRGKangXi=0776.111, RSKangXi=104.8, Def{paralysis, numbness}
75FB CJK UNIFIED IDEOGRAPH-#75FB, IRGKangXi=0775.260, RSKangXi=104.8, Def{suffer}
75FC CJK UNIFIED IDEOGRAPH-#75FC, IRGKangXi=0775.280, RSKangXi=104.8, Def{chronic disease}
75FD CJK UNIFIED IDEOGRAPH-#75FD, IRGKangXi=0775.300, RSKangXi=104.8
75FE CJK UNIFIED IDEOGRAPH-#75FE, IRGKangXi=0775.320, RSKangXi=104.8, Def{chronic illness; dysentery}
75FF CJK UNIFIED IDEOGRAPH-#75FF, IRGKangXi=0775.330, RSKangXi=104.8, Def{paralysis; impotence}
7600 CJK UNIFIED IDEOGRAPH-#7600, IRGKangXi=0775.350, RSKangXi=104.8, Def{a hematoma, contusion; extravasted blood}
7601 CJK UNIFIED IDEOGRAPH-#7601, IRGKangXi=0776.020, RSKangXi=104.8, Def{feel tired, be weary, be worn out}
7602 CJK UNIFIED IDEOGRAPH-#7602, IRGKangXi=0776.050, RSKangXi=104.8, Def{dumb}
7603 CJK UNIFIED IDEOGRAPH-#7603, IRGKangXi=0776.060, RSKangXi=104.8, Def{sores from cold}
7604 CJK UNIFIED IDEOGRAPH-#7604, IRGKangXi=0776.080, RSKangXi=104.8
7605 CJK UNIFIED IDEOGRAPH-#7605, IRGKangXi=0776.111, RSKangXi=104.8, Def{to hate bitterly; drought; dry}
7606 CJK UNIFIED IDEOGRAPH-#7606, IRGKangXi=0776.111, RSKangXi=104.8
7607 CJK UNIFIED IDEOGRAPH-#7607, IRGKangXi=0776.130, RSKangXi=104.9, Def{dropsy of the leg}
7608 CJK UNIFIED IDEOGRAPH-#7608, IRGKangXi=0776.150, RSKangXi=104.9, Def{prolonged fever; chronic malaria}
7609 CJK UNIFIED IDEOGRAPH-#7609, IRGKangXi=0776.160, RSKangXi=104.9, Def{get well, recover}
760A CJK UNIFIED IDEOGRAPH-#760A, IRGKangXi=0776.180, RSKangXi=104.9, Def{warts, pimples}
760B CJK UNIFIED IDEOGRAPH-#760B, IRGKangXi=0776.200, RSKangXi=104.9, Def{crazy, insane, mentally ill}
760C CJK UNIFIED IDEOGRAPH-#760C, IRGKangXi=0776.210, RSKangXi=104.9, Def{severe; poisonous; dangerous; itch and other skin diseases}
760D CJK UNIFIED IDEOGRAPH-#760D, IRGKangXi=0776.250, RSKangXi=104.9, Def{ulcers, sores; infection}
760E CJK UNIFIED IDEOGRAPH-#760E, IRGKangXi=0776.270, RSKangXi=104.9
760F CJK UNIFIED IDEOGRAPH-#760F, IRGKangXi=0776.280, RSKangXi=104.9, Def{ill}
7610 CJK UNIFIED IDEOGRAPH-#7610, IRGKangXi=0776.340, RSKangXi=104.9, Def{to die in prison from cold and hunger; to treat with cruelty}
7611 CJK UNIFIED IDEOGRAPH-#7611, IRGKangXi=0776.380, RSKangXi=104.9
7612 CJK UNIFIED IDEOGRAPH-#7612, IRGKangXi=0777.020, RSKangXi=104.9
7613 CJK UNIFIED IDEOGRAPH-#7613, IRGKangXi=0777.050, RSKangXi=104.9, Def{paralysis, numbness of limbs}
7614 CJK UNIFIED IDEOGRAPH-#7614, IRGKangXi=0777.070, RSKangXi=104.9
7615 CJK UNIFIED IDEOGRAPH-#7615, IRGKangXi=0777.080, RSKangXi=104.9, Def{asthma; disese of the bowels}
7616 CJK UNIFIED IDEOGRAPH-#7616, IRGKangXi=0777.130, RSKangXi=104.9, Def{dumb, mute, unable speak}
7617 CJK UNIFIED IDEOGRAPH-#7617, IRGKangXi=0777.211, RSKangXi=104.9, Def{bury, inter}
7618 CJK UNIFIED IDEOGRAPH-#7618, IRGKangXi=0777.211, RSKangXi=104.9, Def{fistula, sore, ulcer, goiter}
7619 CJK UNIFIED IDEOGRAPH-#7619, IRGKangXi=0777.260, RSKangXi=104.10, Def{itch}
761A CJK UNIFIED IDEOGRAPH-#761A, IRGKangXi=0777.290, RSKangXi=104.10, Def{to hiccough; the humours of the body}
761B CJK UNIFIED IDEOGRAPH-#761B, IRGKangXi=0777.310, RSKangXi=104.10
761C CJK UNIFIED IDEOGRAPH-#761C, IRGKangXi=0777.350, RSKangXi=104.10, Def{a polypus}
761D CJK UNIFIED IDEOGRAPH-#761D, IRGKangXi=0778.010, RSKangXi=104.10, Def{illness; pain; neglect; useless}
761E CJK UNIFIED IDEOGRAPH-#761E, IRGKangXi=0778.020, RSKangXi=104.10, Def{bury, inter}
761F CJK UNIFIED IDEOGRAPH-#761F, IRGKangXi=0778.040, RSKangXi=104.10, Def{epidemic, plague, pestilence}
7620 CJK UNIFIED IDEOGRAPH-#7620, IRGKangXi=0778.090, RSKangXi=104.10, Def{thin, emaciated; barren}
7621 CJK UNIFIED IDEOGRAPH-#7621, IRGKangXi=0778.130, RSKangXi=104.10, Def{tumor, boil, sore, wound}
7622 CJK UNIFIED IDEOGRAPH-#7622, IRGKangXi=0778.150, RSKangXi=104.10, Def{scar, mole}
7623 CJK UNIFIED IDEOGRAPH-#7623, IRGKangXi=0778.170, RSKangXi=104.10
7624 CJK UNIFIED IDEOGRAPH-#7624, IRGKangXi=0778.180, RSKangXi=104.10, Def{tumor, lump, goiter}
7625 CJK UNIFIED IDEOGRAPH-#7625, IRGKangXi=0778.220, RSKangXi=104.10, Def{to recover from any disease; an epidemic}
7626 CJK UNIFIED IDEOGRAPH-#7626, IRGKangXi=0778.250, RSKangXi=104.10, Def{thin, emaciated, lean; meager}
7627 CJK UNIFIED IDEOGRAPH-#7627, IRGKangXi=0778.300, RSKangXi=104.10, Def{intermittent fever; malaria}
7628 CJK UNIFIED IDEOGRAPH-#7628, IRGKangXi=0778.310, RSKangXi=104.10, Def{mad; ill}
7629 CJK UNIFIED IDEOGRAPH-#7629, IRGKangXi=0779.041, RSKangXi=104.10, Def{pimples}
762A CJK UNIFIED IDEOGRAPH-#762A, IRGKangXi=0779.041, RSKangXi=104.10, Def{shrivelled up, dried up; vexed}
762B CJK UNIFIED IDEOGRAPH-#762B, IRGKangXi=0779.041, RSKangXi=104.10, Def{paralysis, palsy, numbness}
762C CJK UNIFIED IDEOGRAPH-#762C, IRGKangXi=0779.060
762D CJK UNIFIED IDEOGRAPH-#762D, IRGKangXi=0779.070, RSKangXi=104.11, Def{a whitlow}
762E CJK UNIFIED IDEOGRAPH-#762E, IRGKangXi=0779.090, RSKangXi=104.11
762F CJK UNIFIED IDEOGRAPH-#762F, IRGKangXi=0779.110, RSKangXi=104.11, Def{itch}
7630 CJK UNIFIED IDEOGRAPH-#7630, IRGKangXi=0779.150, RSKangXi=104.11, Def{scrofula, swellings}
7631 CJK UNIFIED IDEOGRAPH-#7631, IRGKangXi=0779.170, RSKangXi=104.11
7632 CJK UNIFIED IDEOGRAPH-#7632, IRGKangXi=0779.190, RSKangXi=104.11, Def{spasms or convulsions in young children, caused by indigestion}
7633 CJK UNIFIED IDEOGRAPH-#7633, IRGKangXi=0779.210, RSKangXi=104.11, Def{to be healed; to reform}
7634 CJK UNIFIED IDEOGRAPH-#7634, IRGKangXi=0779.230, RSKangXi=104.11, Def{malaria pestilential vapors}
7635 CJK UNIFIED IDEOGRAPH-#7635, IRGKangXi=0779.260, RSKangXi=104.11, Def{a wasting disease}
7636 CJK UNIFIED IDEOGRAPH-#7636, IRGKangXi=0779.270, RSKangXi=104.11, Def{to cough; to expectorate}
7637 CJK UNIFIED IDEOGRAPH-#7637, IRGKangXi=0779.280, RSKangXi=104.11
7638 CJK UNIFIED IDEOGRAPH-#7638, IRGKangXi=0779.320, RSKangXi=104.11, Def{lameness, paralysis of hands, leg}
7639 CJK UNIFIED IDEOGRAPH-#7639, IRGKangXi=0779.330, RSKangXi=104.11
763A CJK UNIFIED IDEOGRAPH-#763A, IRGKangXi=0779.340, RSKangXi=104.11, Def{anal fistula; tumor, sore}
763B CJK UNIFIED IDEOGRAPH-#763B, IRGKangXi=0779.350, RSKangXi=104.11, Def{fistula, sore, ulcer, goiter}
763C CJK UNIFIED IDEOGRAPH-#763C, IRGKangXi=0779.370, RSKangXi=104.11, Def{sickness; distress}
763D CJK UNIFIED IDEOGRAPH-#763D, IRGKangXi=0780.010, RSKangXi=104.11
763E CJK UNIFIED IDEOGRAPH-#763E, IRGKangXi=0781.101, RSKangXi=104.11, Def{rash; addiction, craving, habit}
763F CJK UNIFIED IDEOGRAPH-#763F, IRGKangXi=0780.091, RSKangXi=104.11, Def{swelling, goiter}
7640 CJK UNIFIED IDEOGRAPH-#7640, IRGKangXi=0780.120, RSKangXi=104.11, Def{jaundice}
7641 CJK UNIFIED IDEOGRAPH-#7641, IRGKangXi=0780.180, RSKangXi=104.12
7642 CJK UNIFIED IDEOGRAPH-#7642, IRGKangXi=0780.190, RSKangXi=104.12, Def{be healed, cured, recover}
7643 CJK UNIFIED IDEOGRAPH-#7643, IRGKangXi=0780.250, RSKangXi=104.12, Def{weakness, infirmity retention of urine}
7644 CJK UNIFIED IDEOGRAPH-#7644, IRGKangXi=0780.260, RSKangXi=104.12
7645 CJK UNIFIED IDEOGRAPH-#7645, IRGKangXi=0780.300, RSKangXi=104.12, Def{a swelling, tumor}
7646 CJK UNIFIED IDEOGRAPH-#7646, IRGKangXi=0780.320, RSKangXi=104.12, Def{consumption; tuberculosis}
7647 CJK UNIFIED IDEOGRAPH-#7647, IRGKangXi=0780.380, RSKangXi=104.12, Def{epilepsy, convulsions}
7648 CJK UNIFIED IDEOGRAPH-#7648, IRGKangXi=0780.400, RSKangXi=104.12, Def{abrogate, terminate, discard}
7649 CJK UNIFIED IDEOGRAPH-#7649, IRGKangXi=0780.410, RSKangXi=104.12, Def{to hate bitterly; drought; dry}
764A CJK UNIFIED IDEOGRAPH-#764A, IRGKangXi=0781.010, RSKangXi=104.11, Def{a disease of the heart}
764B CJK UNIFIED IDEOGRAPH-#764B, IRGKangXi=0781.101, RSKangXi=104.12
764C CJK UNIFIED IDEOGRAPH-#764C, IRGKangXi=0781.101, RSKangXi=104.12, Def{cancer; marmoset}
764D CJK UNIFIED IDEOGRAPH-#764D, IRGKangXi=0781.101, RSKangXi=104.12, Def{unhealthy marks on the skin}
764E CJK UNIFIED IDEOGRAPH-#764E, IRGKangXi=0781.101, RSKangXi=104.12, Def{epilepsy, convulsions}
764F CJK UNIFIED IDEOGRAPH-#764F, IRGKangXi=0781.110
7650 CJK UNIFIED IDEOGRAPH-#7650, IRGKangXi=0781.130, RSKangXi=104.13, Def{(Cant.) tired, exhausted}
7651 CJK UNIFIED IDEOGRAPH-#7651, IRGKangXi=0781.140
7652 CJK UNIFIED IDEOGRAPH-#7652, IRGKangXi=0781.160, RSKangXi=104.13, Def{get well, recover}
7653 CJK UNIFIED IDEOGRAPH-#7653, IRGKangXi=0781.180, RSKangXi=104.13
7654 CJK UNIFIED IDEOGRAPH-#7654, IRGKangXi=0781.190, RSKangXi=104.13, Def{hysterical}
7655 CJK UNIFIED IDEOGRAPH-#7655, IRGKangXi=0781.200, RSKangXi=104.13, Def{loss of the sense of smell}
7656 CJK UNIFIED IDEOGRAPH-#7656, IRGKangXi=0781.210, RSKangXi=104.13, Def{craving, weakness for; indigestion}
7657 CJK UNIFIED IDEOGRAPH-#7657, IRGKangXi=0781.250, RSKangXi=104.13
7658 CJK UNIFIED IDEOGRAPH-#7658, IRGKangXi=0781.270, RSKangXi=104.13, Def{a sore, ulcer; pestilence}
7659 CJK UNIFIED IDEOGRAPH-#7659, IRGKangXi=0781.320, RSKangXi=104.13, Def{ill}
765A CJK UNIFIED IDEOGRAPH-#765A, IRGKangXi=0781.350, RSKangXi=104.13
765B CJK UNIFIED IDEOGRAPH-#765B, IRGKangXi=0781.360, RSKangXi=104.13
765C CJK UNIFIED IDEOGRAPH-#765C, IRGKangXi=0781.410, RSKangXi=104.13, Def{erythema}
765D CJK UNIFIED IDEOGRAPH-#765D, IRGKangXi=0782.021, RSKangXi=104.13
765E CJK UNIFIED IDEOGRAPH-#765E, IRGKangXi=0782.021, RSKangXi=104.13, Def{leprosy, scabies, mange; shoddy}
765F CJK UNIFIED IDEOGRAPH-#765F, IRGKangXi=0782.140, RSKangXi=104.14, Def{shrivelled up, dried up; vexed}
7660 CJK UNIFIED IDEOGRAPH-#7660, IRGKangXi=0782.150, RSKangXi=104.14, Def{sick}
7661 CJK UNIFIED IDEOGRAPH-#7661, IRGKangXi=0782.180, RSKangXi=104.14, Def{silly, foolish, idiotic}
7662 CJK UNIFIED IDEOGRAPH-#7662, IRGKangXi=0782.311, RSKangXi=104.15, Def{itch}
7663 CJK UNIFIED IDEOGRAPH-#7663, IRGKangXi=0782.201, RSKangXi=104.14, Def{ringworms}
7664 CJK UNIFIED IDEOGRAPH-#7664, IRGKangXi=0782.210, RSKangXi=104.15, Def{pimple, sore, boil}
7665 CJK UNIFIED IDEOGRAPH-#7665, IRGKangXi=0782.280, RSKangXi=104.15, Def{obstruction of bowels}
7666 CJK UNIFIED IDEOGRAPH-#7666, IRGKangXi=0782.311, RSKangXi=104.15, Def{(Cant.) a mole (on the skin)}
7667 CJK UNIFIED IDEOGRAPH-#7667, IRGKangXi=0782.360, RSKangXi=104.16, Def{scrofulous lumps or swellings}
7668 CJK UNIFIED IDEOGRAPH-#7668, IRGKangXi=0782.370, RSKangXi=104.16, Def{quickly, suddenly; surname}
7669 CJK UNIFIED IDEOGRAPH-#7669, IRGKangXi=0782.410, RSKangXi=104.16, Def{leprosy, scabies, mange; shoddy}
766A CJK UNIFIED IDEOGRAPH-#766A, IRGKangXi=0783.011, RSKangXi=104.16, Def{spasms, convulsions, hysteria; (Cant.) infantile malnutrition}
766B CJK UNIFIED IDEOGRAPH-#766B, IRGKangXi=0783.011, RSKangXi=104.16, Def{crazy, mad; madness, mania, insan}
766C CJK UNIFIED IDEOGRAPH-#766C, IRGKangXi=0783.040, RSKangXi=104.17, Def{ringworms}
766D CJK UNIFIED IDEOGRAPH-#766D, IRGKangXi=0783.050, RSKangXi=104.17, Def{swelling, goiter}
766E CJK UNIFIED IDEOGRAPH-#766E, IRGKangXi=0783.060, RSKangXi=104.17, Def{rash; addiction, craving, habit}
766F CJK UNIFIED IDEOGRAPH-#766F, IRGKangXi=0783.090, RSKangXi=104.18, Def{thin, emaciated; worn, tired}
7670 CJK UNIFIED IDEOGRAPH-#7670, IRGKangXi=0783.130, RSKangXi=104.18, Def{carbuncle, sore, ulcer, abscess}
7671 CJK UNIFIED IDEOGRAPH-#7671, IRGKangXi=0783.160, RSKangXi=104.19, Def{paralysis, palsy, numbness}
7672 CJK UNIFIED IDEOGRAPH-#7672, IRGKangXi=0783.170, RSKangXi=104.19, Def{crazy, mad; madness, mania, insanity}
7673 CJK UNIFIED IDEOGRAPH-#7673, IRGKangXi=0783.241
7674 CJK UNIFIED IDEOGRAPH-#7674, IRGKangXi=0783.260, RSKangXi=104.23
7675 CJK UNIFIED IDEOGRAPH-#7675, IRGKangXi=0783.290, RSKangXi=104.25
7676 CJK UNIFIED IDEOGRAPH-#7676, IRGKangXi=0783.300, RSKangXi=105.0, Def{legs; KangXi radical 105}
7677 CJK UNIFIED IDEOGRAPH-#7677, IRGKangXi=0783.311, RSKangXi=105.3
7678 CJK UNIFIED IDEOGRAPH-#7678, IRGKangXi=0783.320, RSKangXi=105.4, Def{10th heavenly stem}
7679 CJK UNIFIED IDEOGRAPH-#7679, IRGKangXi=0784.010, RSKangXi=105.4
767A CJK UNIFIED IDEOGRAPH-#767A, IRGKangXi=0784.021, RSKangXi=105.4, Def{issue, dispatch, send out, emit}
767B CJK UNIFIED IDEOGRAPH-#767B, IRGKangXi=0784.070, RSKangXi=105.7, Def{rise, mount, board, climb}
767C CJK UNIFIED IDEOGRAPH-#767C, IRGKangXi=0784.100, RSKangXi=105.7, Def{issue, dispatch, send out, emit}
767D CJK UNIFIED IDEOGRAPH-#767D, IRGKangXi=0785.010, RSKangXi=106.0, Def{white; pure, unblemished; bright}
767E CJK UNIFIED IDEOGRAPH-#767E, IRGKangXi=0785.040, RSKangXi=106.1, PrimaryNumeric=100, Def{one hundred; numerous, many}
767F CJK UNIFIED IDEOGRAPH-#767F, IRGKangXi=0785.070, RSKangXi=106.1
7680 CJK UNIFIED IDEOGRAPH-#7680, IRGKangXi=0786.010, RSKangXi=106.2, Def{kernel, seed; enjoy, feast [?]}
7681 CJK UNIFIED IDEOGRAPH-#7681, IRGKangXi=0786.020, RSKangXi=106.2, Def{black; police runners, from the black clothes formerly worn by them}
7682 CJK UNIFIED IDEOGRAPH-#7682, IRGKangXi=0786.030, RSKangXi=106.2, Def{soap; black; menial servant}
7683 CJK UNIFIED IDEOGRAPH-#7683, IRGKangXi=0786.040, RSKangXi=106.2, Def{countenance, appearance}
7684 CJK UNIFIED IDEOGRAPH-#7684, IRGKangXi=0786.070, RSKangXi=106.3, Def{possessive, adjectival suffix}
7685 CJK UNIFIED IDEOGRAPH-#7685, IRGKangXi=0786.110, RSKangXi=106.4
7686 CJK UNIFIED IDEOGRAPH-#7686, IRGKangXi=0786.120, RSKangXi=106.4, Def{all, every, everybody}
7687 CJK UNIFIED IDEOGRAPH-#7687, IRGKangXi=0786.140, RSKangXi=106.4, Def{royal, imperial; ruler, superior}
7688 CJK UNIFIED IDEOGRAPH-#7688, IRGKangXi=0787.040, RSKangXi=106.4, Def{follow, comply with}
7689 CJK UNIFIED IDEOGRAPH-#7689, IRGKangXi=0787.070, RSKangXi=106.5
768A CJK UNIFIED IDEOGRAPH-#768A, IRGKangXi=0787.080, RSKangXi=106.5
768B CJK UNIFIED IDEOGRAPH-#768B, IRGKangXi=0787.100, RSKangXi=106.5, Def{the high land along a river}
768C CJK UNIFIED IDEOGRAPH-#768C, IRGKangXi=0788.010, RSKangXi=106.5
768D CJK UNIFIED IDEOGRAPH-#768D, IRGKangXi=0788.050, RSKangXi=106.5
768E CJK UNIFIED IDEOGRAPH-#768E, IRGKangXi=0788.080, RSKangXi=106.6, Def{white; bright, brilliant; clear}
768F CJK UNIFIED IDEOGRAPH-#768F, IRGKangXi=0788.090, RSKangXi=106.6
7690 CJK UNIFIED IDEOGRAPH-#7690, IRGKangXi=0788.110, RSKangXi=106.6, Def{the high land along a river}
7691 CJK UNIFIED IDEOGRAPH-#7691, IRGKangXi=0788.121, RSKangXi=106.6, Def{brilliant white}
7692 CJK UNIFIED IDEOGRAPH-#7692, IRGKangXi=0788.130, RSKangXi=106.7
7693 CJK UNIFIED IDEOGRAPH-#7693, IRGKangXi=0788.140, RSKangXi=106.7, Def{bright, luminous; clear; hoary}
7694 CJK UNIFIED IDEOGRAPH-#7694, IRGKangXi=0788.150, RSKangXi=106.7
7695 CJK UNIFIED IDEOGRAPH-#7695, IRGKangXi=0788.170, RSKangXi=106.7
7696 CJK UNIFIED IDEOGRAPH-#7696, IRGKangXi=0788.180, RSKangXi=106.7, Def{Anhui province}
7697 CJK UNIFIED IDEOGRAPH-#7697, IRGKangXi=0788.200, RSKangXi=106.8
7698 CJK UNIFIED IDEOGRAPH-#7698, IRGKangXi=0788.220, RSKangXi=106.8
7699 CJK UNIFIED IDEOGRAPH-#7699, IRGKangXi=0788.250, RSKangXi=106.8, Def{white; kind of date}
769A CJK UNIFIED IDEOGRAPH-#769A, IRGKangXi=0788.350, RSKangXi=106.10, Def{brilliant white}
769B CJK UNIFIED IDEOGRAPH-#769B, IRGKangXi=0789.010, RSKangXi=106.10
769C CJK UNIFIED IDEOGRAPH-#769C, IRGKangXi=0789.040, RSKangXi=106.10, Def{white, bright; clear, pure}
769D CJK UNIFIED IDEOGRAPH-#769D, IRGKangXi=0789.050, RSKangXi=106.10, Def{luminous; bright hoary, white}
769E CJK UNIFIED IDEOGRAPH-#769E, IRGKangXi=0789.060, RSKangXi=106.10, Def{bright, brilliant}
769F CJK UNIFIED IDEOGRAPH-#769F, IRGKangXi=0789.070, RSKangXi=106.11
76A0 CJK UNIFIED IDEOGRAPH-#76A0, IRGKangXi=0789.100, RSKangXi=106.11
76A1 CJK UNIFIED IDEOGRAPH-#76A1, IRGKangXi=0789.131, RSKangXi=106.11, Def{bright; brilliant}
76A2 CJK UNIFIED IDEOGRAPH-#76A2, IRGKangXi=0789.150, RSKangXi=106.12
76A3 CJK UNIFIED IDEOGRAPH-#76A3, IRGKangXi=0789.160, RSKangXi=106.12
76A4 CJK UNIFIED IDEOGRAPH-#76A4, IRGKangXi=0789.180, RSKangXi=106.12, Def{white, grey; corpulent}
76A5 CJK UNIFIED IDEOGRAPH-#76A5, IRGKangXi=0789.210, RSKangXi=106.12, Def{bright, brilliant}
76A6 CJK UNIFIED IDEOGRAPH-#76A6, IRGKangXi=0789.250, RSKangXi=106.13, Def{bright white; bright, clear}
76A7 CJK UNIFIED IDEOGRAPH-#76A7, IRGKangXi=0789.260, RSKangXi=106.13
76A8 CJK UNIFIED IDEOGRAPH-#76A8, IRGKangXi=0789.280, RSKangXi=106.13
76A9 CJK UNIFIED IDEOGRAPH-#76A9, IRGKangXi=0789.320, RSKangXi=106.14
76AA CJK UNIFIED IDEOGRAPH-#76AA, IRGKangXi=0790.010, RSKangXi=106.15
76AB CJK UNIFIED IDEOGRAPH-#76AB, IRGKangXi=0790.020, RSKangXi=106.15, Def{white}
76AC CJK UNIFIED IDEOGRAPH-#76AC, IRGKangXi=0790.040, RSKangXi=106.16
76AD CJK UNIFIED IDEOGRAPH-#76AD, IRGKangXi=0790.070, RSKangXi=106.18, Def{white; bright; clear; clean}
76AE CJK UNIFIED IDEOGRAPH-#76AE, IRGKangXi=0790.120, RSKangXi=107.0, Def{skin, hide, fur, feather; outer}
76AF CJK UNIFIED IDEOGRAPH-#76AF, IRGKangXi=0790.180, RSKangXi=107.3
76B0 CJK UNIFIED IDEOGRAPH-#76B0, IRGKangXi=0791.030, RSKangXi=107.5, Def{pimples}
76B1 CJK UNIFIED IDEOGRAPH-#76B1, IRGKangXi=0791.101, RSKangXi=107.5, Def{wrinkles, creases, folds}
76B2 CJK UNIFIED IDEOGRAPH-#76B2, IRGKangXi=0791.151, RSKangXi=107.6, Def{crack, chap}
76B3 CJK UNIFIED IDEOGRAPH-#76B3, IRGKangXi=0791.180, RSKangXi=107.7
76B4 CJK UNIFIED IDEOGRAPH-#76B4, IRGKangXi=0791.220, RSKangXi=107.7, Def{chapped, cracked}
76B5 CJK UNIFIED IDEOGRAPH-#76B5, IRGKangXi=0791.240, RSKangXi=107.8
76B6 CJK UNIFIED IDEOGRAPH-#76B6, IRGKangXi=0791.320, RSKangXi=107.9, Def{rough skin; rough}
76B7 CJK UNIFIED IDEOGRAPH-#76B7, IRGKangXi=0791.360, RSKangXi=107.9, Def{drum; excite, arouse}
76B8 CJK UNIFIED IDEOGRAPH-#76B8, IRGKangXi=0791.370, RSKangXi=107.9, Def{crack, chap}
76B9 CJK UNIFIED IDEOGRAPH-#76B9, IRGKangXi=0791.411, RSKangXi=107.9, Def{crack, chap}
76BA CJK UNIFIED IDEOGRAPH-#76BA, IRGKangXi=0791.460, RSKangXi=107.10, Def{wrinkles, creases, folds}
76BB CJK UNIFIED IDEOGRAPH-#76BB, IRGKangXi=0792.030, RSKangXi=107.11, Def{pimples, blotches}
76BC CJK UNIFIED IDEOGRAPH-#76BC, IRGKangXi=0792.111, RSKangXi=107.12
76BD CJK UNIFIED IDEOGRAPH-#76BD, IRGKangXi=0792.170, RSKangXi=107.13, Def{scurf}
76BE CJK UNIFIED IDEOGRAPH-#76BE, IRGKangXi=0792.230, RSKangXi=107.15
76BF CJK UNIFIED IDEOGRAPH-#76BF, IRGKangXi=0792.330, RSKangXi=108.0, Def{shallow container; rad. no. 108}
76C0 CJK UNIFIED IDEOGRAPH-#76C0, IRGKangXi=0792.350, RSKangXi=108.2
76C1 CJK UNIFIED IDEOGRAPH-#76C1, IRGKangXi=0792.351, RSKangXi=108.2
76C2 CJK UNIFIED IDEOGRAPH-#76C2, IRGKangXi=0792.400, RSKangXi=108.3, Def{basin; cup}
76C3 CJK UNIFIED IDEOGRAPH-#76C3, IRGKangXi=0793.010, RSKangXi=108.4, Def{glass, cup}
76C4 CJK UNIFIED IDEOGRAPH-#76C4, IRGKangXi=0793.030, RSKangXi=108.4
76C5 CJK UNIFIED IDEOGRAPH-#76C5, IRGKangXi=0793.040, RSKangXi=108.4, Def{small cup or bowl}
76C6 CJK UNIFIED IDEOGRAPH-#76C6, IRGKangXi=0793.050, RSKangXi=108.4, Def{basin, tub, pot, bowl}
76C7 CJK UNIFIED IDEOGRAPH-#76C7, IRGKangXi=0793.060, RSKangXi=108.4, Def{why not? would it not be better to?}
76C8 CJK UNIFIED IDEOGRAPH-#76C8, IRGKangXi=0793.070, RSKangXi=108.4, Def{fill; full, overflowing; surplus}
76C9 CJK UNIFIED IDEOGRAPH-#76C9, IRGKangXi=0793.110, RSKangXi=108.5
76CA CJK UNIFIED IDEOGRAPH-#76CA, IRGKangXi=0793.180, RSKangXi=108.5, Def{profit, benefit; advantage}
76CB CJK UNIFIED IDEOGRAPH-#76CB, IRGKangXi=0793.220, RSKangXi=108.5
76CC CJK UNIFIED IDEOGRAPH-#76CC, IRGKangXi=0794.010, RSKangXi=108.5, Def{bowl, basin, cup}
76CD CJK UNIFIED IDEOGRAPH-#76CD, IRGKangXi=0794.020, RSKangXi=108.5, Def{what? why not?}
76CE CJK UNIFIED IDEOGRAPH-#76CE, IRGKangXi=0794.030, RSKangXi=108.5, Def{cup; pot; bowl; abundant}
76CF CJK UNIFIED IDEOGRAPH-#76CF, IRGKangXi=0794.041, RSKangXi=108.5, Def{small cup or container}
76D0 CJK UNIFIED IDEOGRAPH-#76D0, IRGKangXi=0794.041, RSKangXi=108.5, Def{salt}
76D1 CJK UNIFIED IDEOGRAPH-#76D1, IRGKangXi=0794.041, RSKangXi=108.5, Def{supervise, control, direct}
76D2 CJK UNIFIED IDEOGRAPH-#76D2, IRGKangXi=0794.070, RSKangXi=108.6, Def{small box or case; casket}
76D3 CJK UNIFIED IDEOGRAPH-#76D3, IRGKangXi=0794.090, RSKangXi=108.6
76D4 CJK UNIFIED IDEOGRAPH-#76D4, IRGKangXi=0794.110, RSKangXi=108.6, Def{helmet; bowl; basin}
76D5 CJK UNIFIED IDEOGRAPH-#76D5, IRGKangXi=0794.130, RSKangXi=108.6
76D6 CJK UNIFIED IDEOGRAPH-#76D6, IRGKangXi=0794.150, RSKangXi=108.6, Def{cover, hide, protect}
76D7 CJK UNIFIED IDEOGRAPH-#76D7, IRGKangXi=0794.161, RSKangXi=108.6, Def{rob, steal; thief, bandit}
76D8 CJK UNIFIED IDEOGRAPH-#76D8, IRGKangXi=0794.161, RSKangXi=108.6, Def{tray, plate, dish; examine}
76D9 CJK UNIFIED IDEOGRAPH-#76D9, IRGKangXi=0794.170, RSKangXi=108.7, Def{a basket, square outside and round inside, used to hold boiled grain in State worship}
76DA CJK UNIFIED IDEOGRAPH-#76DA, IRGKangXi=0794.190, RSKangXi=108.7
76DB CJK UNIFIED IDEOGRAPH-#76DB, IRGKangXi=0794.200, RSKangXi=108.7, Def{abundant, flourishing; contain; fill}
76DC CJK UNIFIED IDEOGRAPH-#76DC, IRGKangXi=0794.210, RSKangXi=108.7, Def{rob, steal; thief, bandit}
76DD CJK UNIFIED IDEOGRAPH-#76DD, IRGKangXi=0795.120, RSKangXi=108.8, Def{drip}
76DE CJK UNIFIED IDEOGRAPH-#76DE, IRGKangXi=0795.130, RSKangXi=108.8, Def{small cup or container; classifier for lamps, etc.}
76DF CJK UNIFIED IDEOGRAPH-#76DF, IRGKangXi=0795.170, RSKangXi=108.8, Def{swear; oath, covenant, alliance}
76E0 CJK UNIFIED IDEOGRAPH-#76E0, IRGKangXi=0795.210, RSKangXi=108.9
76E1 CJK UNIFIED IDEOGRAPH-#76E1, IRGKangXi=0795.220, RSKangXi=108.9, Def{exhaust, use up; deplete}
76E2 CJK UNIFIED IDEOGRAPH-#76E2, IRGKangXi=0796.010, RSKangXi=108.9
76E3 CJK UNIFIED IDEOGRAPH-#76E3, IRGKangXi=0796.020, RSKangXi=108.9, Def{supervise, control, direct}
76E4 CJK UNIFIED IDEOGRAPH-#76E4, IRGKangXi=0796.090, RSKangXi=108.10, Def{tray, plate, dish; examine}
76E5 CJK UNIFIED IDEOGRAPH-#76E5, IRGKangXi=0796.120, RSKangXi=108.11, Def{wash}
76E6 CJK UNIFIED IDEOGRAPH-#76E6, IRGKangXi=0796.150, RSKangXi=108.11, Def{lid of a caldron; Buddhist cloister}
76E7 CJK UNIFIED IDEOGRAPH-#76E7, IRGKangXi=0797.060, RSKangXi=108.11, Def{cottage, hut; surname; black}
76E8 CJK UNIFIED IDEOGRAPH-#76E8, IRGKangXi=0797.110, RSKangXi=108.12
76E9 CJK UNIFIED IDEOGRAPH-#76E9, IRGKangXi=0797.130, RSKangXi=108.12, Def{callus}
76EA CJK UNIFIED IDEOGRAPH-#76EA, IRGKangXi=0797.150, RSKangXi=108.12, Def{to toss about; to swing; to rock}
76EB CJK UNIFIED IDEOGRAPH-#76EB, IRGKangXi=0798.050, RSKangXi=108.13
76EC CJK UNIFIED IDEOGRAPH-#76EC, IRGKangXi=0798.070, RSKangXi=108.13, Def{salt pit; leisure; pot; drink}
76ED CJK UNIFIED IDEOGRAPH-#76ED, IRGKangXi=0798.160, RSKangXi=108.15, Def{cruel}
76EE CJK UNIFIED IDEOGRAPH-#76EE, IRGKangXi=0798.250, RSKangXi=109.0, Def{eye; look, see; division, topic}
76EF CJK UNIFIED IDEOGRAPH-#76EF, IRGKangXi=0799.060, RSKangXi=109.2, Def{rivet gaze upon, keep eyes on}
76F0 CJK UNIFIED IDEOGRAPH-#76F0, IRGKangXi=0799.130, RSKangXi=109.3
76F1 CJK UNIFIED IDEOGRAPH-#76F1, IRGKangXi=0799.170, RSKangXi=109.3, Def{wide open eyes; to gaze in astonishment}
76F2 CJK UNIFIED IDEOGRAPH-#76F2, IRGKangXi=0800.010, RSKangXi=109.3, Def{blind; unperceptive, shortsighted}
76F3 CJK UNIFIED IDEOGRAPH-#76F3, IRGKangXi=0800.020, RSKangXi=109.3
76F4 CJK UNIFIED IDEOGRAPH-#76F4, IRGKangXi=0800.050, RSKangXi=109.3, Def{straight, erect, vertical}
76F5 CJK UNIFIED IDEOGRAPH-#76F5, IRGKangXi=0800.090, RSKangXi=109.3
76F6 CJK UNIFIED IDEOGRAPH-#76F6, IRGKangXi=0800.130, RSKangXi=109.4
76F7 CJK UNIFIED IDEOGRAPH-#76F7, IRGKangXi=0800.140, RSKangXi=109.4
76F8 CJK UNIFIED IDEOGRAPH-#76F8, IRGKangXi=0800.180, RSKangXi=109.4, Def{mutual, reciprocal, each other}
76F9 CJK UNIFIED IDEOGRAPH-#76F9, IRGKangXi=0801.060, RSKangXi=109.4, Def{to doze; to nap; to nod}
76FA CJK UNIFIED IDEOGRAPH-#76FA, IRGKangXi=0801.120, RSKangXi=109.4
76FB CJK UNIFIED IDEOGRAPH-#76FB, IRGKangXi=0801.140, RSKangXi=109.4, Def{glare; stare}
76FC CJK UNIFIED IDEOGRAPH-#76FC, IRGKangXi=0801.150, RSKangXi=109.4, Def{look, gaze; expect, hope for}
76FD CJK UNIFIED IDEOGRAPH-#76FD, IRGKangXi=0801.170, RSKangXi=109.4
76FE CJK UNIFIED IDEOGRAPH-#76FE, IRGKangXi=0801.190, RSKangXi=109.4, Def{shield, shield-shaped object; currency sign for Dutch guilder}
76FF CJK UNIFIED IDEOGRAPH-#76FF, IRGKangXi=0801.220, RSKangXi=109.4
7700 CJK UNIFIED IDEOGRAPH-#7700, IRGKangXi=0802.040, RSKangXi=109.4
7701 CJK UNIFIED IDEOGRAPH-#7701, IRGKangXi=0802.050, RSKangXi=109.4, Def{province; save, economize}
7702 CJK UNIFIED IDEOGRAPH-#7702, IRGKangXi=0802.090
7703 CJK UNIFIED IDEOGRAPH-#7703, IRGKangXi=0802.100, RSKangXi=109.4
7704 CJK UNIFIED IDEOGRAPH-#7704, IRGKangXi=0802.120, RSKangXi=109.4, Def{to look askance; looking dull}
7705 CJK UNIFIED IDEOGRAPH-#7705, IRGKangXi=0802.130, RSKangXi=109.4, Def{inlay; border}
7706 CJK UNIFIED IDEOGRAPH-#7706, IRGKangXi=0802.140, RSKangXi=109.4, Def{indistinct}
7707 CJK UNIFIED IDEOGRAPH-#7707, IRGKangXi=0802.170, RSKangXi=109.4, Def{blind in one eye; minute, minuscule}
7708 CJK UNIFIED IDEOGRAPH-#7708, IRGKangXi=0802.180, RSKangXi=109.4, Def{gloat, stare at; to delay, to loiter, to hinder}
7709 CJK UNIFIED IDEOGRAPH-#7709, IRGKangXi=0803.010, RSKangXi=109.4, Def{eyebrows; upper margin of book}
770A CJK UNIFIED IDEOGRAPH-#770A, IRGKangXi=0803.060, RSKangXi=109.4, Def{dim-sighted; dull, bewildered}
770B CJK UNIFIED IDEOGRAPH-#770B, IRGKangXi=0803.070, RSKangXi=109.4, Def{look, see; examine, scrutinize}
770C CJK UNIFIED IDEOGRAPH-#770C, IRGKangXi=0803.151, RSKangXi=109.4, Def{county, district, subdivision}
770D CJK UNIFIED IDEOGRAPH-#770D, IRGKangXi=0803.151, RSKangXi=109.4, Def{sunken}
770E CJK UNIFIED IDEOGRAPH-#770E, IRGKangXi=0803.180, RSKangXi=109.5, Def{look at, inspect, observe, see}
770F CJK UNIFIED IDEOGRAPH-#770F, IRGKangXi=0803.190
7710 CJK UNIFIED IDEOGRAPH-#7710, IRGKangXi=0803.200, RSKangXi=109.5
7711 CJK UNIFIED IDEOGRAPH-#7711, IRGKangXi=0803.230, RSKangXi=109.5, Def{sunken eyes; deep; abstruse}
7712 CJK UNIFIED IDEOGRAPH-#7712, IRGKangXi=0804.010, RSKangXi=109.5
7713 CJK UNIFIED IDEOGRAPH-#7713, IRGKangXi=0804.030, RSKangXi=109.5
7714 CJK UNIFIED IDEOGRAPH-#7714, IRGKangXi=0947.321, RSKangXi=109.5
7715 CJK UNIFIED IDEOGRAPH-#7715, IRGKangXi=0804.050, RSKangXi=109.5, Def{restraint}
7716 CJK UNIFIED IDEOGRAPH-#7716, IRGKangXi=0804.060, RSKangXi=109.5
7717 CJK UNIFIED IDEOGRAPH-#7717, IRGKangXi=0804.070, RSKangXi=109.5
7718 CJK UNIFIED IDEOGRAPH-#7718, IRGKangXi=0804.080, RSKangXi=109.5
7719 CJK UNIFIED IDEOGRAPH-#7719, IRGKangXi=0804.100, RSKangXi=109.5, Def{to gaze at}
771A CJK UNIFIED IDEOGRAPH-#771A, IRGKangXi=0804.110, RSKangXi=109.5, Def{disease of the eyes; crime, fault}
771B CJK UNIFIED IDEOGRAPH-#771B, IRGKangXi=0804.130, RSKangXi=109.5, Def{dim, dark, obscure; blind}
771C CJK UNIFIED IDEOGRAPH-#771C, IRGKangXi=0804.140, RSKangXi=109.5
771D CJK UNIFIED IDEOGRAPH-#771D, IRGKangXi=0804.150, RSKangXi=109.5
771E CJK UNIFIED IDEOGRAPH-#771E, IRGKangXi=0804.180, RSKangXi=109.5, Def{real, actual, true, genuine}
771F CJK UNIFIED IDEOGRAPH-#771F, IRGKangXi=0805.010, RSKangXi=109.5, Def{real, actual, true, genuine}
7720 CJK UNIFIED IDEOGRAPH-#7720, IRGKangXi=0805.040, RSKangXi=109.5, Def{close eyes, sleep; hibernate}
7721 CJK UNIFIED IDEOGRAPH-#7721, IRGKangXi=0805.060, RSKangXi=109.5, Def{(Cant.) blurred sight}
7722 CJK UNIFIED IDEOGRAPH-#7722, IRGKangXi=0805.080, RSKangXi=109.5, Def{eyes without brightness}
7723 CJK UNIFIED IDEOGRAPH-#7723, IRGKangXi=0805.100, RSKangXi=109.5, Def{prominent eyes}
7724 CJK UNIFIED IDEOGRAPH-#7724, IRGKangXi=0805.130, RSKangXi=109.5
7725 CJK UNIFIED IDEOGRAPH-#7725, IRGKangXi=0805.160, RSKangXi=109.5, Def{eye sockets; corner of the eyes}
7726 CJK UNIFIED IDEOGRAPH-#7726, IRGKangXi=0805.170, RSKangXi=109.5, Def{corner of the eyes, eyesockets}
7727 CJK UNIFIED IDEOGRAPH-#7727, IRGKangXi=0805.180, RSKangXi=109.5
7728 CJK UNIFIED IDEOGRAPH-#7728, IRGKangXi=0805.190, RSKangXi=109.5, Def{wink}
7729 CJK UNIFIED IDEOGRAPH-#7729, IRGKangXi=0805.200, RSKangXi=109.5, Def{to confuse; dizzy, dazed, disoriented}
772A CJK UNIFIED IDEOGRAPH-#772A, IRGKangXi=0805.220, RSKangXi=109.5
772B CJK UNIFIED IDEOGRAPH-#772B, IRGKangXi=0806.081, RSKangXi=109.5
772C CJK UNIFIED IDEOGRAPH-#772C, IRGKangXi=0806.081, RSKangXi=109.5, Def{faint, fuzzy, blurred}
772D CJK UNIFIED IDEOGRAPH-#772D, IRGKangXi=0806.090, RSKangXi=109.6, Def{evil look of deep-set eyes}
772E CJK UNIFIED IDEOGRAPH-#772E, IRGKangXi=0806.160, RSKangXi=109.6
772F CJK UNIFIED IDEOGRAPH-#772F, IRGKangXi=0806.210, RSKangXi=109.6, Def{be blinded}
7730 CJK UNIFIED IDEOGRAPH-#7730, IRGKangXi=0806.240, RSKangXi=109.6
7731 CJK UNIFIED IDEOGRAPH-#7731, IRGKangXi=0806.270, RSKangXi=109.6
7732 CJK UNIFIED IDEOGRAPH-#7732, IRGKangXi=0806.320, RSKangXi=109.6
7733 CJK UNIFIED IDEOGRAPH-#7733, IRGKangXi=0806.400, RSKangXi=109.6
7734 CJK UNIFIED IDEOGRAPH-#7734, IRGKangXi=0806.410, RSKangXi=109.6, Def{dazzled}
7735 CJK UNIFIED IDEOGRAPH-#7735, IRGKangXi=0807.010, RSKangXi=109.6, Def{eyes diseased and dim}
7736 CJK UNIFIED IDEOGRAPH-#7736, IRGKangXi=0807.030, RSKangXi=109.6, Def{eye socket; rim of eye}
7737 CJK UNIFIED IDEOGRAPH-#7737, IRGKangXi=0807.040, RSKangXi=109.6, Def{take interest in, care for}
7738 CJK UNIFIED IDEOGRAPH-#7738, IRGKangXi=0807.050, RSKangXi=109.6, Def{pupil of eye; eye}
7739 CJK UNIFIED IDEOGRAPH-#7739, IRGKangXi=0807.060, RSKangXi=109.6, Def{pupil}
773A CJK UNIFIED IDEOGRAPH-#773A, IRGKangXi=0807.070, RSKangXi=109.6, Def{look at, gaze at, scan, survey}
773B CJK UNIFIED IDEOGRAPH-#773B, IRGKangXi=0807.100, RSKangXi=109.6
773C CJK UNIFIED IDEOGRAPH-#773C, IRGKangXi=0807.110, RSKangXi=109.6, Def{eye; eyelet, hole, opening}
773D CJK UNIFIED IDEOGRAPH-#773D, IRGKangXi=0807.140, RSKangXi=109.6, Def{to gaze; to ogle to look at}
773E CJK UNIFIED IDEOGRAPH-#773E, IRGKangXi=0807.150, RSKangXi=109.6, Def{masses, people, multitude, crowd}
773F CJK UNIFIED IDEOGRAPH-#773F, IRGKangXi=0808.040, RSKangXi=109.5
7740 CJK UNIFIED IDEOGRAPH-#7740, IRGKangXi=0808.051, RSKangXi=109.6, Def{make move, take action}
7741 CJK UNIFIED IDEOGRAPH-#7741, IRGKangXi=0808.051, RSKangXi=109.6, Def{open eyes; stare}
7742 CJK UNIFIED IDEOGRAPH-#7742, IRGKangXi=0808.060, RSKangXi=109.7
7743 CJK UNIFIED IDEOGRAPH-#7743, IRGKangXi=0808.110, RSKangXi=109.7
7744 CJK UNIFIED IDEOGRAPH-#7744, IRGKangXi=0808.150, RSKangXi=109.7, Def{(Cant.) to glance}
7745 CJK UNIFIED IDEOGRAPH-#7745, IRGKangXi=0808.160, RSKangXi=109.7, Def{big-eyed}
7746 CJK UNIFIED IDEOGRAPH-#7746, IRGKangXi=0808.170, RSKangXi=109.7, Def{bright}
7747 CJK UNIFIED IDEOGRAPH-#7747, IRGKangXi=0808.250, RSKangXi=109.7, Def{look at, glance at; stare at}
7748 CJK UNIFIED IDEOGRAPH-#7748, IRGKangXi=0808.320, RSKangXi=109.7
7749 CJK UNIFIED IDEOGRAPH-#7749, IRGKangXi=0808.330, RSKangXi=109.7
774A CJK UNIFIED IDEOGRAPH-#774A, IRGKangXi=0808.410, RSKangXi=109.7, Def{see, look, gaze at; askance}
774B CJK UNIFIED IDEOGRAPH-#774B, IRGKangXi=0809.080, RSKangXi=109.7
774C CJK UNIFIED IDEOGRAPH-#774C, IRGKangXi=0809.120, RSKangXi=109.7
774D CJK UNIFIED IDEOGRAPH-#774D, IRGKangXi=0809.130, RSKangXi=109.7, Def{to look at fearfully; overly cautious}
774E CJK UNIFIED IDEOGRAPH-#774E, IRGKangXi=0809.140, RSKangXi=109.7, Def{to long for; to gaze at}
774F CJK UNIFIED IDEOGRAPH-#774F, IRGKangXi=0809.211, RSKangXi=109.7, Def{be tired, sleepy}
7750 CJK UNIFIED IDEOGRAPH-#7750, IRGKangXi=0809.211, RSKangXi=109.7, Def{squint at; sidelong glance}
7751 CJK UNIFIED IDEOGRAPH-#7751, IRGKangXi=0809.211, RSKangXi=109.7, Def{eyelid}
7752 CJK UNIFIED IDEOGRAPH-#7752, IRGKangXi=0809.220, RSKangXi=109.8, Def{to glance at, to peep; glittering; to shine}
7753 CJK UNIFIED IDEOGRAPH-#7753, IRGKangXi=0809.230, RSKangXi=109.8
7754 CJK UNIFIED IDEOGRAPH-#7754, IRGKangXi=0809.260, RSKangXi=109.8
7755 CJK UNIFIED IDEOGRAPH-#7755, IRGKangXi=0809.280, RSKangXi=109.8
7756 CJK UNIFIED IDEOGRAPH-#7756, IRGKangXi=0810.040, RSKangXi=109.8, Def{to stare straight ahead}
7757 CJK UNIFIED IDEOGRAPH-#7757, IRGKangXi=0810.050, RSKangXi=109.8, Def{a flash}
7758 CJK UNIFIED IDEOGRAPH-#7758, IRGKangXi=0810.070, RSKangXi=109.8, Def{round; stare}
7759 CJK UNIFIED IDEOGRAPH-#7759, IRGKangXi=0810.100, RSKangXi=109.8
775A CJK UNIFIED IDEOGRAPH-#775A, IRGKangXi=0810.120, RSKangXi=109.8, Def{corner of eye; stare}
775B CJK UNIFIED IDEOGRAPH-#775B, IRGKangXi=0810.130, RSKangXi=109.8, Def{eyeball; pupil of eye}
775C CJK UNIFIED IDEOGRAPH-#775C, IRGKangXi=0810.140, RSKangXi=109.8, Def{to open the eyes; stare}
775D CJK UNIFIED IDEOGRAPH-#775D, IRGKangXi=0810.150, RSKangXi=109.8
775E CJK UNIFIED IDEOGRAPH-#775E, IRGKangXi=0810.170, RSKangXi=109.8, Def{squint at; sidelong glance}
775F CJK UNIFIED IDEOGRAPH-#775F, IRGKangXi=0810.210, RSKangXi=109.8, Def{clear-eyed}
7760 CJK UNIFIED IDEOGRAPH-#7760, IRGKangXi=0810.220, RSKangXi=109.8, Def{to care for; love}
7761 CJK UNIFIED IDEOGRAPH-#7761, IRGKangXi=0810.230, RSKangXi=109.8, Def{sleep, doze}
7762 CJK UNIFIED IDEOGRAPH-#7762, IRGKangXi=0810.250, RSKangXi=109.8, Def{gaze at, stare at; uninhibited}
7763 CJK UNIFIED IDEOGRAPH-#7763, IRGKangXi=0810.310, RSKangXi=109.8, Def{supervise, oversee, direct}
7764 CJK UNIFIED IDEOGRAPH-#7764, IRGKangXi=0811.010, RSKangXi=109.8, Def{to look around, look askance}
7765 CJK UNIFIED IDEOGRAPH-#7765, IRGKangXi=0811.020, RSKangXi=109.8, Def{look askance at, glare at}
7766 CJK UNIFIED IDEOGRAPH-#7766, IRGKangXi=0811.030, RSKangXi=109.8, Def{friendly, amiable, peaceful}
7767 CJK UNIFIED IDEOGRAPH-#7767, IRGKangXi=0811.050, RSKangXi=109.8, Def{dull vision}
7768 CJK UNIFIED IDEOGRAPH-#7768, IRGKangXi=0811.080, RSKangXi=109.8, Def{look askance at, glare at; squint}
7769 CJK UNIFIED IDEOGRAPH-#7769, IRGKangXi=0811.090, RSKangXi=109.8
776A CJK UNIFIED IDEOGRAPH-#776A, IRGKangXi=0811.100, RSKangXi=109.8, Def{spy on}
776B CJK UNIFIED IDEOGRAPH-#776B, IRGKangXi=0811.120, RSKangXi=109.8, Def{eyelashes}
776C CJK UNIFIED IDEOGRAPH-#776C, IRGKangXi=0811.130, RSKangXi=109.8, Def{notice; pay attention to}
776D CJK UNIFIED IDEOGRAPH-#776D, IRGKangXi=0811.150, RSKangXi=109.8
776E CJK UNIFIED IDEOGRAPH-#776E, IRGKangXi=0811.210, RSKangXi=109.9
776F CJK UNIFIED IDEOGRAPH-#776F, IRGKangXi=0812.010, RSKangXi=109.9
7770 CJK UNIFIED IDEOGRAPH-#7770, IRGKangXi=0812.040, RSKangXi=109.9
7771 CJK UNIFIED IDEOGRAPH-#7771, IRGKangXi=0812.060, RSKangXi=109.9, Def{to gaze slowly; white appearance of the eyes}
7772 CJK UNIFIED IDEOGRAPH-#7772, IRGKangXi=0812.120, RSKangXi=109.9
7773 CJK UNIFIED IDEOGRAPH-#7773, IRGKangXi=0812.130, RSKangXi=109.9
7774 CJK UNIFIED IDEOGRAPH-#7774, IRGKangXi=0812.220, RSKangXi=109.9
7775 CJK UNIFIED IDEOGRAPH-#7775, IRGKangXi=0812.250, RSKangXi=109.9
7776 CJK UNIFIED IDEOGRAPH-#7776, IRGKangXi=0812.270, RSKangXi=109.9
7777 CJK UNIFIED IDEOGRAPH-#7777, IRGKangXi=0812.280, RSKangXi=109.9
7778 CJK UNIFIED IDEOGRAPH-#7778, IRGKangXi=0812.290, RSKangXi=109.9, Def{(Cant.) to close, shut}
7779 CJK UNIFIED IDEOGRAPH-#7779, IRGKangXi=0812.300, RSKangXi=109.9, Def{look at, gaze at; observe}
777A CJK UNIFIED IDEOGRAPH-#777A, IRGKangXi=0812.350, RSKangXi=109.9, Def{(Cant.) to watch}
777B CJK UNIFIED IDEOGRAPH-#777B, IRGKangXi=0812.420
777C CJK UNIFIED IDEOGRAPH-#777C, IRGKangXi=0812.430, RSKangXi=109.9
777D CJK UNIFIED IDEOGRAPH-#777D, IRGKangXi=0812.440, RSKangXi=109.9, Def{staring}
777E CJK UNIFIED IDEOGRAPH-#777E, IRGKangXi=0813.030, RSKangXi=109.9, Def{testicle}
777F CJK UNIFIED IDEOGRAPH-#777F, IRGKangXi=0813.040, RSKangXi=109.9, Def{shrewd, astute, clever, keen}
7780 CJK UNIFIED IDEOGRAPH-#7780, IRGKangXi=0813.090, RSKangXi=109.9, Def{to look at closely; nearsighted; dim; indistinct vision}
7781 CJK UNIFIED IDEOGRAPH-#7781, IRGKangXi=0813.110, RSKangXi=109.9
7782 CJK UNIFIED IDEOGRAPH-#7782, IRGKangXi=0813.120, RSKangXi=109.9
7783 CJK UNIFIED IDEOGRAPH-#7783, IRGKangXi=0813.140, RSKangXi=109.9
7784 CJK UNIFIED IDEOGRAPH-#7784, IRGKangXi=0813.161, RSKangXi=109.9, Def{take aim at; look at}
7785 CJK UNIFIED IDEOGRAPH-#7785, IRGKangXi=0813.161, RSKangXi=109.9, Def{see, look, gaze at}
7786 CJK UNIFIED IDEOGRAPH-#7786, IRGKangXi=0813.161, RSKangXi=109.12, Def{dim}
7787 CJK UNIFIED IDEOGRAPH-#7787, IRGKangXi=0813.170, RSKangXi=109.10, Def{to close (the eyes); to squint}
7788 CJK UNIFIED IDEOGRAPH-#7788, IRGKangXi=0813.210, RSKangXi=109.10
7789 CJK UNIFIED IDEOGRAPH-#7789, IRGKangXi=0814.030, RSKangXi=109.10
778A CJK UNIFIED IDEOGRAPH-#778A, IRGKangXi=0814.050, RSKangXi=109.10
778B CJK UNIFIED IDEOGRAPH-#778B, IRGKangXi=0814.060, RSKangXi=109.10, Def{glare with anger}
778C CJK UNIFIED IDEOGRAPH-#778C, IRGKangXi=0814.080, RSKangXi=109.10, Def{doze off; sleepy}
778D CJK UNIFIED IDEOGRAPH-#778D, IRGKangXi=0814.240, RSKangXi=109.10, Def{blind; no pupil in the eye}
778E CJK UNIFIED IDEOGRAPH-#778E, IRGKangXi=0814.290, RSKangXi=109.10, Def{blind, reckless; rash}
778F CJK UNIFIED IDEOGRAPH-#778F, IRGKangXi=0814.330, RSKangXi=109.10, Def{round}
7790 CJK UNIFIED IDEOGRAPH-#7790, IRGKangXi=0815.070, RSKangXi=109.10
7791 CJK UNIFIED IDEOGRAPH-#7791, IRGKangXi=0815.080, RSKangXi=109.10, Def{close eyes}
7792 CJK UNIFIED IDEOGRAPH-#7792, IRGKangXi=0815.181, RSKangXi=109.10, Def{deceive, lie; eyes half-closed}
7793 CJK UNIFIED IDEOGRAPH-#7793, IRGKangXi=0815.181, RSKangXi=109.10, Def{to sleep}
7794 CJK UNIFIED IDEOGRAPH-#7794, IRGKangXi=0815.200, RSKangXi=109.11
7795 CJK UNIFIED IDEOGRAPH-#7795, IRGKangXi=0815.210, RSKangXi=109.11, Def{cataract in the eye}
7796 CJK UNIFIED IDEOGRAPH-#7796, IRGKangXi=0815.320, RSKangXi=109.11, Def{a cataract or film over the eye}
7797 CJK UNIFIED IDEOGRAPH-#7797, IRGKangXi=0815.360, RSKangXi=109.11
7798 CJK UNIFIED IDEOGRAPH-#7798, IRGKangXi=0815.390, RSKangXi=109.11, Def{deeply-sunk eyes}
7799 CJK UNIFIED IDEOGRAPH-#7799, IRGKangXi=0815.400, RSKangXi=109.11
779A CJK UNIFIED IDEOGRAPH-#779A, IRGKangXi=0815.420, RSKangXi=109.11
779B CJK UNIFIED IDEOGRAPH-#779B, IRGKangXi=0816.010, RSKangXi=109.11
779C CJK UNIFIED IDEOGRAPH-#779C, IRGKangXi=0816.050, RSKangXi=109.11, Def{to see; to look at; to observe}
779D CJK UNIFIED IDEOGRAPH-#779D, IRGKangXi=0816.060, RSKangXi=109.11
779E CJK UNIFIED IDEOGRAPH-#779E, IRGKangXi=0816.090, RSKangXi=109.11, Def{deceive, lie; eyes half-closed}
779F CJK UNIFIED IDEOGRAPH-#779F, IRGKangXi=0816.100, RSKangXi=109.11, Def{glare at; look askance at; squint}
77A0 CJK UNIFIED IDEOGRAPH-#77A0, IRGKangXi=0816.110, RSKangXi=109.11, Def{look at, stare at, gaze at}
77A1 CJK UNIFIED IDEOGRAPH-#77A1, IRGKangXi=0816.120, RSKangXi=109.11
77A2 CJK UNIFIED IDEOGRAPH-#77A2, IRGKangXi=0816.211, RSKangXi=109.11, Def{eyesight obscured; to feel ashamed}
77A3 CJK UNIFIED IDEOGRAPH-#77A3, IRGKangXi=0816.211, RSKangXi=109.11
77A4 CJK UNIFIED IDEOGRAPH-#77A4, IRGKangXi=0816.250, RSKangXi=109.12, Def{to blink or twitch the eyes}
77A5 CJK UNIFIED IDEOGRAPH-#77A5, IRGKangXi=0817.010, RSKangXi=109.12, Def{take fleeting glance at}
77A6 CJK UNIFIED IDEOGRAPH-#77A6, IRGKangXi=0817.080, RSKangXi=109.12
77A7 CJK UNIFIED IDEOGRAPH-#77A7, IRGKangXi=0817.090, RSKangXi=109.12, Def{glance at, look at, see}
77A8 CJK UNIFIED IDEOGRAPH-#77A8, IRGKangXi=0817.100, RSKangXi=109.12
77A9 CJK UNIFIED IDEOGRAPH-#77A9, IRGKangXi=0817.170, RSKangXi=109.12, Def{watch carefully, stare at, focus on}
77AA CJK UNIFIED IDEOGRAPH-#77AA, IRGKangXi=0817.180, RSKangXi=109.12, Def{stare at}
77AB CJK UNIFIED IDEOGRAPH-#77AB, IRGKangXi=0817.200, RSKangXi=109.12, Def{look}
77AC CJK UNIFIED IDEOGRAPH-#77AC, IRGKangXi=0817.230, RSKangXi=109.12, Def{wink, blink; in a wink, a flash}
77AD CJK UNIFIED IDEOGRAPH-#77AD, IRGKangXi=0817.260, RSKangXi=109.12, Def{bright, clear; clear-sighted}
77AE CJK UNIFIED IDEOGRAPH-#77AE, IRGKangXi=0817.280, RSKangXi=109.12
77AF CJK UNIFIED IDEOGRAPH-#77AF, IRGKangXi=0817.310, RSKangXi=109.12, Def{to peep; to spy}
77B0 CJK UNIFIED IDEOGRAPH-#77B0, IRGKangXi=0818.010, RSKangXi=109.12, Def{watch, spy; overlook; look down}
77B1 CJK UNIFIED IDEOGRAPH-#77B1, IRGKangXi=0818.020, RSKangXi=109.12
77B2 CJK UNIFIED IDEOGRAPH-#77B2, IRGKangXi=0818.030, RSKangXi=109.12
77B3 CJK UNIFIED IDEOGRAPH-#77B3, IRGKangXi=0818.040, RSKangXi=109.12, Def{pupil of eye}
77B4 CJK UNIFIED IDEOGRAPH-#77B4, IRGKangXi=0818.070, RSKangXi=109.12
77B5 CJK UNIFIED IDEOGRAPH-#77B5, IRGKangXi=0818.090, RSKangXi=109.12, Def{to stare at}
77B6 CJK UNIFIED IDEOGRAPH-#77B6, IRGKangXi=0818.100, RSKangXi=109.12, Def{dim; blurred vision}
77B7 CJK UNIFIED IDEOGRAPH-#77B7, IRGKangXi=0818.191, RSKangXi=109.12
77B8 CJK UNIFIED IDEOGRAPH-#77B8, IRGKangXi=0818.200, RSKangXi=109.13
77B9 CJK UNIFIED IDEOGRAPH-#77B9, IRGKangXi=0818.210, RSKangXi=109.13, Def{clouded, obscure}
77BA CJK UNIFIED IDEOGRAPH-#77BA, IRGKangXi=0818.240, RSKangXi=109.13
77BB CJK UNIFIED IDEOGRAPH-#77BB, IRGKangXi=0818.360, RSKangXi=109.13, Def{look; look out for; respect}
77BC CJK UNIFIED IDEOGRAPH-#77BC, IRGKangXi=0819.020, RSKangXi=109.13, Def{eyelid}
77BD CJK UNIFIED IDEOGRAPH-#77BD, IRGKangXi=0819.030, RSKangXi=109.13, Def{blind; blind musician; stupid}
77BE CJK UNIFIED IDEOGRAPH-#77BE, IRGKangXi=0819.040, RSKangXi=109.13
77BF CJK UNIFIED IDEOGRAPH-#77BF, IRGKangXi=0819.050, RSKangXi=109.13, Def{surname}
77C0 CJK UNIFIED IDEOGRAPH-#77C0, IRGKangXi=0819.100, RSKangXi=109.13
77C1 CJK UNIFIED IDEOGRAPH-#77C1, IRGKangXi=0819.131, RSKangXi=109.13, Def{to look at; to gaze}
77C2 CJK UNIFIED IDEOGRAPH-#77C2, IRGKangXi=0819.131, RSKangXi=109.13
77C3 CJK UNIFIED IDEOGRAPH-#77C3, IRGKangXi=0819.230, RSKangXi=109.14
77C4 CJK UNIFIED IDEOGRAPH-#77C4, IRGKangXi=0819.260, RSKangXi=109.14
77C5 CJK UNIFIED IDEOGRAPH-#77C5, IRGKangXi=0819.270, RSKangXi=109.14
77C6 CJK UNIFIED IDEOGRAPH-#77C6, IRGKangXi=0819.280, RSKangXi=109.14
77C7 CJK UNIFIED IDEOGRAPH-#77C7, IRGKangXi=0819.290, RSKangXi=109.14, Def{stupid, ignorant; blind}
77C8 CJK UNIFIED IDEOGRAPH-#77C8, IRGKangXi=0820.030, RSKangXi=109.14, Def{dense, detailed, fine}
77C9 CJK UNIFIED IDEOGRAPH-#77C9, IRGKangXi=0820.040, RSKangXi=109.14, Def{an angry glare; to open the eyes with anger}
77CA CJK UNIFIED IDEOGRAPH-#77CA, IRGKangXi=0820.050, RSKangXi=109.14
77CB CJK UNIFIED IDEOGRAPH-#77CB, IRGKangXi=0820.231, RSKangXi=109.15, Def{(Cant.) to stare angrily}
77CC CJK UNIFIED IDEOGRAPH-#77CC, IRGKangXi=0820.130, RSKangXi=109.15
77CD CJK UNIFIED IDEOGRAPH-#77CD, IRGKangXi=0820.170, RSKangXi=109.15, Def{look about in fright or alarm}
77CE CJK UNIFIED IDEOGRAPH-#77CE, IRGKangXi=0820.190, RSKangXi=109.15
77CF CJK UNIFIED IDEOGRAPH-#77CF, IRGKangXi=0820.231, RSKangXi=109.15
77D0 CJK UNIFIED IDEOGRAPH-#77D0, IRGKangXi=0820.270, RSKangXi=109.16
77D1 CJK UNIFIED IDEOGRAPH-#77D1, IRGKangXi=0820.290, RSKangXi=109.16, Def{the pupil of the eye; to see}
77D2 CJK UNIFIED IDEOGRAPH-#77D2, IRGKangXi=0820.340, RSKangXi=109.16
77D3 CJK UNIFIED IDEOGRAPH-#77D3, IRGKangXi=0820.341, RSKangXi=109.16, Def{faint, fuzzy, blurred}
77D4 CJK UNIFIED IDEOGRAPH-#77D4, IRGKangXi=0821.040, RSKangXi=109.18
77D5 CJK UNIFIED IDEOGRAPH-#77D5, IRGKangXi=0821.100, RSKangXi=109.19, Def{to see, witness, inspect}
77D6 CJK UNIFIED IDEOGRAPH-#77D6, IRGKangXi=0821.110, RSKangXi=109.21
77D7 CJK UNIFIED IDEOGRAPH-#77D7, IRGKangXi=0821.120, RSKangXi=109.19, Def{straight, upright, erect, lofty}
77D8 CJK UNIFIED IDEOGRAPH-#77D8, IRGKangXi=0821.130, RSKangXi=109.20
77D9 CJK UNIFIED IDEOGRAPH-#77D9, IRGKangXi=0821.140, RSKangXi=109.20, Def{view}
77DA CJK UNIFIED IDEOGRAPH-#77DA, IRGKangXi=0821.170, RSKangXi=109.21, Def{watch carefully, stare at, focus on}
77DB CJK UNIFIED IDEOGRAPH-#77DB, IRGKangXi=0821.220, RSKangXi=110.0, Def{spear, lance; KangXi radical 110}
77DC CJK UNIFIED IDEOGRAPH-#77DC, IRGKangXi=0822.040, RSKangXi=110.4, Def{pity, feel sorry for, show sympat}
77DD CJK UNIFIED IDEOGRAPH-#77DD, IRGKangXi=0822.101, RSKangXi=110.5
77DE CJK UNIFIED IDEOGRAPH-#77DE, IRGKangXi=0822.140, RSKangXi=110.7, Def{bore with awl; bright, charming}
77DF CJK UNIFIED IDEOGRAPH-#77DF, IRGKangXi=0822.180, RSKangXi=110.7, Def{lance}
77E0 CJK UNIFIED IDEOGRAPH-#77E0, IRGKangXi=0822.260, RSKangXi=110.8
77E1 CJK UNIFIED IDEOGRAPH-#77E1, IRGKangXi=0823.320, RSKangXi=110.20
77E2 CJK UNIFIED IDEOGRAPH-#77E2, IRGKangXi=0823.340, RSKangXi=111.0, Def{arrow, dart; vow, swear}
77E3 CJK UNIFIED IDEOGRAPH-#77E3, IRGKangXi=0823.370, RSKangXi=111.2, Def{particle of completed action}
77E4 CJK UNIFIED IDEOGRAPH-#77E4, IRGKangXi=0823.400, RSKangXi=111.3
77E5 CJK UNIFIED IDEOGRAPH-#77E5, IRGKangXi=0824.010, RSKangXi=111.3, Def{know, perceive, comprehend}
77E6 CJK UNIFIED IDEOGRAPH-#77E6, IRGKangXi=0824.050, RSKangXi=111.4
77E7 CJK UNIFIED IDEOGRAPH-#77E7, IRGKangXi=0824.060, RSKangXi=111.4, Def{much more, still more; the gums}
77E8 CJK UNIFIED IDEOGRAPH-#77E8, IRGKangXi=0824.080, RSKangXi=111.4
77E9 CJK UNIFIED IDEOGRAPH-#77E9, IRGKangXi=0824.110, RSKangXi=111.5, Def{carpenter's square, ruler, rule}
77EA CJK UNIFIED IDEOGRAPH-#77EA, IRGKangXi=0824.190, RSKangXi=111.6
77EB CJK UNIFIED IDEOGRAPH-#77EB, IRGKangXi=0824.281, RSKangXi=111.6, Def{correct, rectify, straighten out}
77EC CJK UNIFIED IDEOGRAPH-#77EC, IRGKangXi=0824.300, RSKangXi=111.7, Def{a dwarf}
77ED CJK UNIFIED IDEOGRAPH-#77ED, IRGKangXi=0824.330, RSKangXi=111.7, Def{short; brief; deficient, lacking}
77EE CJK UNIFIED IDEOGRAPH-#77EE, IRGKangXi=0825.110, RSKangXi=111.8, Def{short, dwarf; low}
77EF CJK UNIFIED IDEOGRAPH-#77EF, IRGKangXi=0825.240, RSKangXi=111.12, Def{correct, rectify, straighten out}
77F0 CJK UNIFIED IDEOGRAPH-#77F0, IRGKangXi=0825.260, RSKangXi=111.12, Def{arrow with attached silk cord}
77F1 CJK UNIFIED IDEOGRAPH-#77F1, IRGKangXi=0825.270, RSKangXi=111.14, Def{measure, standard, criterion}
77F2 CJK UNIFIED IDEOGRAPH-#77F2, IRGKangXi=0825.280, RSKangXi=111.15
77F3 CJK UNIFIED IDEOGRAPH-#77F3, IRGKangXi=0827.010, RSKangXi=112.0, Def{stone, rock, mineral; rad. 112}
77F4 CJK UNIFIED IDEOGRAPH-#77F4, IRGKangXi=0827.040, RSKangXi=112.2, Def{anchor; (Cant.) a place}
77F5 CJK UNIFIED IDEOGRAPH-#77F5, IRGKangXi=0827.080, RSKangXi=112.2
77F6 CJK UNIFIED IDEOGRAPH-#77F6, IRGKangXi=0827.101, RSKangXi=112.2, Def{jetty; submerged rock; eddy}
77F7 CJK UNIFIED IDEOGRAPH-#77F7, IRGKangXi=0827.110, RSKangXi=112.3
77F8 CJK UNIFIED IDEOGRAPH-#77F8, IRGKangXi=0827.130, RSKangXi=112.3, Def{a rock or cliff}
77F9 CJK UNIFIED IDEOGRAPH-#77F9, IRGKangXi=0827.140, RSKangXi=112.3
77FA CJK UNIFIED IDEOGRAPH-#77FA, IRGKangXi=0827.160, RSKangXi=112.3, Def{(Cant.) to press steadily}
77FB CJK UNIFIED IDEOGRAPH-#77FB, IRGKangXi=0827.180, RSKangXi=112.3, Def{toil, slave away; busy}
77FC CJK UNIFIED IDEOGRAPH-#77FC, IRGKangXi=0827.190, RSKangXi=112.3, Def{stone bridge; stepping stones}
77FD CJK UNIFIED IDEOGRAPH-#77FD, IRGKangXi=0827.191, RSKangXi=112.3, Def{silicon}
77FE CJK UNIFIED IDEOGRAPH-#77FE, IRGKangXi=0827.191, RSKangXi=112.3, Def{alum}
77FF CJK UNIFIED IDEOGRAPH-#77FF, IRGKangXi=0827.191, RSKangXi=112.3, Def{mine; mineral, ore}
7800 CJK UNIFIED IDEOGRAPH-#7800, IRGKangXi=0827.191, RSKangXi=112.4, Def{brilliantly colored stone with veined patterns in it}
7801 CJK UNIFIED IDEOGRAPH-#7801, IRGKangXi=0827.191, RSKangXi=112.3, Def{number, numerals; yard; symbol}
7802 CJK UNIFIED IDEOGRAPH-#7802, IRGKangXi=0827.200, RSKangXi=112.4, Def{sand; pebbles, gravel; gritty}
7803 CJK UNIFIED IDEOGRAPH-#7803, IRGKangXi=0828.010, RSKangXi=112.4
7804 CJK UNIFIED IDEOGRAPH-#7804, IRGKangXi=0828.020, RSKangXi=112.4
7805 CJK UNIFIED IDEOGRAPH-#7805, IRGKangXi=0828.040, RSKangXi=112.4
7806 CJK UNIFIED IDEOGRAPH-#7806, IRGKangXi=0828.060, RSKangXi=112.4, Def{1/2 pr stone}
7807 CJK UNIFIED IDEOGRAPH-#7807, IRGKangXi=0828.070, RSKangXi=112.4, Def{a stone resembling jade, alabaster}
7808 CJK UNIFIED IDEOGRAPH-#7808, IRGKangXi=0828.080
7809 CJK UNIFIED IDEOGRAPH-#7809, IRGKangXi=0828.100, RSKangXi=112.4
780A CJK UNIFIED IDEOGRAPH-#780A, IRGKangXi=0828.130, RSKangXi=112.4
780B CJK UNIFIED IDEOGRAPH-#780B, IRGKangXi=0828.150, RSKangXi=112.4
780C CJK UNIFIED IDEOGRAPH-#780C, IRGKangXi=0828.160, RSKangXi=112.4, Def{to build, pile up; stone steps, brick walk}
780D CJK UNIFIED IDEOGRAPH-#780D, IRGKangXi=0828.170, RSKangXi=112.4, Def{hack, chop, cut, fell}
780E CJK UNIFIED IDEOGRAPH-#780E, IRGKangXi=0828.180, RSKangXi=112.4
780F CJK UNIFIED IDEOGRAPH-#780F, IRGKangXi=0828.190, RSKangXi=112.4
7810 CJK UNIFIED IDEOGRAPH-#7810, IRGKangXi=0828.200, RSKangXi=112.4, Def{(Cant.) to nod one's head; to shake, sway}
7811 CJK UNIFIED IDEOGRAPH-#7811, IRGKangXi=0828.210, RSKangXi=112.4, Def{to grind, to calender, to polish; to roll with a stone roller}
7812 CJK UNIFIED IDEOGRAPH-#7812, IRGKangXi=0828.220, RSKangXi=112.4, Def{arsenic}
7813 CJK UNIFIED IDEOGRAPH-#7813, IRGKangXi=0828.240, RSKangXi=112.4
7814 CJK UNIFIED IDEOGRAPH-#7814, IRGKangXi=0828.241, RSKangXi=112.6, Def{grind, rub; study, research}
7815 CJK UNIFIED IDEOGRAPH-#7815, IRGKangXi=0828.241, RSKangXi=112.4, Def{break, smash; broken, busted}
7816 CJK UNIFIED IDEOGRAPH-#7816, IRGKangXi=0828.241, RSKangXi=112.4, Def{tile, brick}
7817 CJK UNIFIED IDEOGRAPH-#7817, IRGKangXi=0828.241, RSKangXi=112.4, Def{giant clam, tridacna gigas}
7818 CJK UNIFIED IDEOGRAPH-#7818, IRGKangXi=0828.241, RSKangXi=112.4, Def{a kind of farm tool}
7819 CJK UNIFIED IDEOGRAPH-#7819, IRGKangXi=0829.331, RSKangXi=112.4
781A CJK UNIFIED IDEOGRAPH-#781A, IRGKangXi=0828.241, RSKangXi=112.4, Def{inkstone}
781B CJK UNIFIED IDEOGRAPH-#781B, IRGKangXi=0828.241, RSKangXi=112.4
781C CJK UNIFIED IDEOGRAPH-#781C, IRGKangXi=0828.241, RSKangXi=112.4, Def{an organic compound}
781D CJK UNIFIED IDEOGRAPH-#781D, IRGKangXi=0828.250, RSKangXi=112.5, Def{balance weights}
781E CJK UNIFIED IDEOGRAPH-#781E, IRGKangXi=0828.260, RSKangXi=112.5, Def{to smash rock}
781F CJK UNIFIED IDEOGRAPH-#781F, IRGKangXi=0828.270, RSKangXi=112.5, Def{stone tablet; monument}
7820 CJK UNIFIED IDEOGRAPH-#7820, IRGKangXi=0828.280, RSKangXi=112.5, Def{rocky, hilly, uneven}
7821 CJK UNIFIED IDEOGRAPH-#7821, IRGKangXi=0828.310, RSKangXi=112.5
7822 CJK UNIFIED IDEOGRAPH-#7822, IRGKangXi=0828.320, RSKangXi=112.5, Def{pile of stones}
7823 CJK UNIFIED IDEOGRAPH-#7823, IRGKangXi=0828.350, RSKangXi=112.5, Def{a stone roller; a heavy stone, a weight, a plummet}
7824 CJK UNIFIED IDEOGRAPH-#7824, IRGKangXi=0828.360, RSKangXi=112.5
7825 CJK UNIFIED IDEOGRAPH-#7825, IRGKangXi=0828.370, RSKangXi=112.5, Def{a whetstone; to polish}
7826 CJK UNIFIED IDEOGRAPH-#7826, IRGKangXi=0828.420, RSKangXi=112.5, Def{stockade, fort, military outpost; brothel}
7827 CJK UNIFIED IDEOGRAPH-#7827, IRGKangXi=0828.430, RSKangXi=112.5, Def{anvil; flat stone; exe}
7828 CJK UNIFIED IDEOGRAPH-#7828, IRGKangXi=0829.010, RSKangXi=112.5
7829 CJK UNIFIED IDEOGRAPH-#7829, IRGKangXi=0829.040, RSKangXi=112.5
782A CJK UNIFIED IDEOGRAPH-#782A, IRGKangXi=0829.060, RSKangXi=112.5
782B CJK UNIFIED IDEOGRAPH-#782B, IRGKangXi=0829.070, RSKangXi=112.5
782C CJK UNIFIED IDEOGRAPH-#782C, IRGKangXi=0829.080, RSKangXi=112.5, Def{big stone}
782D CJK UNIFIED IDEOGRAPH-#782D, IRGKangXi=0829.110, RSKangXi=112.5, Def{stone probe; pierce; counsel}
782E CJK UNIFIED IDEOGRAPH-#782E, IRGKangXi=0829.120, RSKangXi=112.5, Def{arrow-tip}
782F CJK UNIFIED IDEOGRAPH-#782F, IRGKangXi=0829.160, RSKangXi=112.5, Def{to make a loud sound}
7830 CJK UNIFIED IDEOGRAPH-#7830, IRGKangXi=0829.180, RSKangXi=112.5, Def{sound of crashing stones, bang!}
7831 CJK UNIFIED IDEOGRAPH-#7831, IRGKangXi=0829.220, RSKangXi=112.5
7832 CJK UNIFIED IDEOGRAPH-#7832, IRGKangXi=0829.240, RSKangXi=112.5, Def{gun, cannon}
7833 CJK UNIFIED IDEOGRAPH-#7833, IRGKangXi=0829.270, RSKangXi=112.5, Def{rocky}
7834 CJK UNIFIED IDEOGRAPH-#7834, IRGKangXi=0829.280, RSKangXi=112.5, Def{break, ruin, destroy; rout}
7835 CJK UNIFIED IDEOGRAPH-#7835, IRGKangXi=0829.331, RSKangXi=112.5, Def{(Cant.) port (Eng. loan-word), 西矺 a sideboard (Eng. loan-word)}
7836 CJK UNIFIED IDEOGRAPH-#7836, IRGKangXi=0829.331, RSKangXi=112.5
7837 CJK UNIFIED IDEOGRAPH-#7837, IRGKangXi=0829.331, RSKangXi=112.5, Def{arsenic}
7838 CJK UNIFIED IDEOGRAPH-#7838, IRGKangXi=0829.331, RSKangXi=112.5, Def{smash, crush, break; pound, mash}
7839 CJK UNIFIED IDEOGRAPH-#7839, IRGKangXi=0830.131, RSKangXi=112.5, Def{astatine}
783A CJK UNIFIED IDEOGRAPH-#783A, IRGKangXi=0829.331, RSKangXi=112.5, Def{whetstone; sharpen}
783B CJK UNIFIED IDEOGRAPH-#783B, IRGKangXi=0829.331, RSKangXi=212.5, Def{grind, sharpen; mill}
783C CJK UNIFIED IDEOGRAPH-#783C, IRGKangXi=0829.331, RSKangXi=112.5, Def{concrete}
783D CJK UNIFIED IDEOGRAPH-#783D, IRGKangXi=0829.331, RSKangXi=112.5
783E CJK UNIFIED IDEOGRAPH-#783E, IRGKangXi=0829.331, RSKangXi=112.5, Def{gravel, pebbles}
783F CJK UNIFIED IDEOGRAPH-#783F, IRGKangXi=0829.331, RSKangXi=112.5, Def{mine; mineral, ore}
7840 CJK UNIFIED IDEOGRAPH-#7840, IRGKangXi=0829.331, RSKangXi=112.5, Def{foundation stone, plinth}
7841 CJK UNIFIED IDEOGRAPH-#7841, IRGKangXi=0829.331, RSKangXi=112.5, Def{the sound of stones knocking together}
7842 CJK UNIFIED IDEOGRAPH-#7842, IRGKangXi=0829.350, RSKangXi=112.6
7843 CJK UNIFIED IDEOGRAPH-#7843, IRGKangXi=0829.360, RSKangXi=112.6, Def{a red mole; cinnabar}
7844 CJK UNIFIED IDEOGRAPH-#7844, IRGKangXi=0829.380, RSKangXi=112.6
7845 CJK UNIFIED IDEOGRAPH-#7845, IRGKangXi=0829.400, RSKangXi=112.6, Def{silicon}
7846 CJK UNIFIED IDEOGRAPH-#7846, IRGKangXi=0829.490, RSKangXi=112.6
7847 CJK UNIFIED IDEOGRAPH-#7847, IRGKangXi=0829.510, RSKangXi=112.6, Def{a kind of mineral}
7848 CJK UNIFIED IDEOGRAPH-#7848, IRGKangXi=0829.540, RSKangXi=112.6
7849 CJK UNIFIED IDEOGRAPH-#7849, IRGKangXi=0829.560, RSKangXi=112.6, Def{bones of a thin horse}
784A CJK UNIFIED IDEOGRAPH-#784A, IRGKangXi=0829.570, RSKangXi=112.6
784B CJK UNIFIED IDEOGRAPH-#784B, IRGKangXi=0830.010
784C CJK UNIFIED IDEOGRAPH-#784C, IRGKangXi=0830.020, RSKangXi=112.6
784D CJK UNIFIED IDEOGRAPH-#784D, IRGKangXi=0830.040, RSKangXi=112.6, Def{strike}
784E CJK UNIFIED IDEOGRAPH-#784E, IRGKangXi=0830.060, RSKangXi=112.6, Def{whetstone}
784F CJK UNIFIED IDEOGRAPH-#784F, IRGKangXi=0830.080, RSKangXi=112.6, Def{grind}
7850 CJK UNIFIED IDEOGRAPH-#7850, IRGKangXi=0830.090, RSKangXi=112.6, Def{variant of U+6D1E 洞, cave; chamber; pit}
7851 CJK UNIFIED IDEOGRAPH-#7851, IRGKangXi=0830.130, RSKangXi=112.6
7852 CJK UNIFIED IDEOGRAPH-#7852, IRGKangXi=0830.131, RSKangXi=112.6, Def{selenium}
7853 CJK UNIFIED IDEOGRAPH-#7853, IRGKangXi=0830.131, RSKangXi=112.6
7854 CJK UNIFIED IDEOGRAPH-#7854, IRGKangXi=0830.131, RSKangXi=112.6
7855 CJK UNIFIED IDEOGRAPH-#7855, IRGKangXi=0830.131, RSKangXi=112.6, Def{great, eminent; large, big}
7856 CJK UNIFIED IDEOGRAPH-#7856, IRGKangXi=0830.131, RSKangXi=112.6, Def{(archaic) town in Hebei province}
7857 CJK UNIFIED IDEOGRAPH-#7857, IRGKangXi=0830.131, RSKangXi=112.6, Def{barren land; sandy soil}
7858 CJK UNIFIED IDEOGRAPH-#7858, IRGKangXi=0830.131, RSKangXi=112.6
7859 CJK UNIFIED IDEOGRAPH-#7859, IRGKangXi=0830.131, RSKangXi=112.6, Def{stone mill; grind; break apart}
785A CJK UNIFIED IDEOGRAPH-#785A, IRGKangXi=0830.131, RSKangXi=112.12
785B CJK UNIFIED IDEOGRAPH-#785B, IRGKangXi=0830.131, RSKangXi=112.6
785C CJK UNIFIED IDEOGRAPH-#785C, IRGKangXi=0830.140, RSKangXi=112.7, Def{the sound of stones knocking together}
785D CJK UNIFIED IDEOGRAPH-#785D, IRGKangXi=0830.150, RSKangXi=112.7, Def{saltpeter, niter; to tan}
785E CJK UNIFIED IDEOGRAPH-#785E, IRGKangXi=0830.170, RSKangXi=112.7
785F CJK UNIFIED IDEOGRAPH-#785F, IRGKangXi=0830.200, RSKangXi=112.7, Def{(Cant.) to slip; to work and polish gems}
7860 CJK UNIFIED IDEOGRAPH-#7860, IRGKangXi=0830.210, RSKangXi=112.7
7861 CJK UNIFIED IDEOGRAPH-#7861, IRGKangXi=0830.240, RSKangXi=112.7
7862 CJK UNIFIED IDEOGRAPH-#7862, IRGKangXi=0830.250, RSKangXi=112.7
7863 CJK UNIFIED IDEOGRAPH-#7863, IRGKangXi=0830.280, RSKangXi=112.7
7864 CJK UNIFIED IDEOGRAPH-#7864, IRGKangXi=0830.300, RSKangXi=112.7, Def{(archaic) town in Hebei province}
7865 CJK UNIFIED IDEOGRAPH-#7865, IRGKangXi=0830.340, RSKangXi=112.7
7866 CJK UNIFIED IDEOGRAPH-#7866, IRGKangXi=0830.350, RSKangXi=112.7
7867 CJK UNIFIED IDEOGRAPH-#7867, IRGKangXi=0830.380, RSKangXi=112.7, Def{a grindstone; (same as U+7850 硐) a cave, cavern}
7868 CJK UNIFIED IDEOGRAPH-#7868, IRGKangXi=0831.010, RSKangXi=112.7, Def{giant clam, Tridacna gigas}
7869 CJK UNIFIED IDEOGRAPH-#7869, IRGKangXi=0831.020, RSKangXi=112.7
786A CJK UNIFIED IDEOGRAPH-#786A, IRGKangXi=0831.030, RSKangXi=112.7
786B CJK UNIFIED IDEOGRAPH-#786B, IRGKangXi=0831.040, RSKangXi=112.7, Def{sulfur}
786C CJK UNIFIED IDEOGRAPH-#786C, IRGKangXi=0831.050, RSKangXi=112.7, Def{hard, firm, strong; obstinate}
786D CJK UNIFIED IDEOGRAPH-#786D, IRGKangXi=0831.131, RSKangXi=112.7, Def{a crude saltpetre}
786E CJK UNIFIED IDEOGRAPH-#786E, IRGKangXi=0831.070, RSKangXi=112.7, Def{sure, certain; real, true}
786F CJK UNIFIED IDEOGRAPH-#786F, IRGKangXi=0831.080, RSKangXi=112.7, Def{inkstone}
7870 CJK UNIFIED IDEOGRAPH-#7870, IRGKangXi=0831.090, RSKangXi=112.7
7871 CJK UNIFIED IDEOGRAPH-#7871, IRGKangXi=0831.100, RSKangXi=112.7
7872 CJK UNIFIED IDEOGRAPH-#7872, IRGKangXi=0831.131, RSKangXi=112.7
7873 CJK UNIFIED IDEOGRAPH-#7873, IRGKangXi=0831.131, RSKangXi=112.7
7874 CJK UNIFIED IDEOGRAPH-#7874, IRGKangXi=0832.211, RSKangXi=112.7
7875 CJK UNIFIED IDEOGRAPH-#7875, IRGKangXi=0831.131, RSKangXi=112.7
7876 CJK UNIFIED IDEOGRAPH-#7876, IRGKangXi=0831.131, RSKangXi=112.7
7877 CJK UNIFIED IDEOGRAPH-#7877, IRGKangXi=0831.131, RSKangXi=112.7, Def{alkaline, alkali, lye, salt}
7878 CJK UNIFIED IDEOGRAPH-#7878, IRGKangXi=0831.160, RSKangXi=112.8, Def{thick-lipped; a grindstone}
7879 CJK UNIFIED IDEOGRAPH-#7879, IRGKangXi=0831.170, RSKangXi=112.8
787A CJK UNIFIED IDEOGRAPH-#787A, IRGKangXi=0831.180, RSKangXi=112.8
787B CJK UNIFIED IDEOGRAPH-#787B, IRGKangXi=0831.200, RSKangXi=112.8
787C CJK UNIFIED IDEOGRAPH-#787C, IRGKangXi=0831.230, RSKangXi=112.8, Def{borax, boron}
787D CJK UNIFIED IDEOGRAPH-#787D, IRGKangXi=0831.250, RSKangXi=112.8
787E CJK UNIFIED IDEOGRAPH-#787E, IRGKangXi=0831.260, RSKangXi=112.9, Def{weight}
787F CJK UNIFIED IDEOGRAPH-#787F, IRGKangXi=0831.280, RSKangXi=112.8
7880 CJK UNIFIED IDEOGRAPH-#7880, IRGKangXi=0831.290, RSKangXi=112.8
7881 CJK UNIFIED IDEOGRAPH-#7881, IRGKangXi=0831.300, RSKangXi=112.8, Def{chess; any game similar to chess}
7882 CJK UNIFIED IDEOGRAPH-#7882, IRGKangXi=0831.320, RSKangXi=112.8
7883 CJK UNIFIED IDEOGRAPH-#7883, IRGKangXi=0831.360, RSKangXi=112.8
7884 CJK UNIFIED IDEOGRAPH-#7884, IRGKangXi=0831.370, RSKangXi=112.8
7885 CJK UNIFIED IDEOGRAPH-#7885, IRGKangXi=0831.410, RSKangXi=112.8
7886 CJK UNIFIED IDEOGRAPH-#7886, IRGKangXi=0831.420, RSKangXi=112.8, Def{arrow-tip}
7887 CJK UNIFIED IDEOGRAPH-#7887, IRGKangXi=0831.440, RSKangXi=112.8, Def{anchor}
7888 CJK UNIFIED IDEOGRAPH-#7888, IRGKangXi=0831.470
7889 CJK UNIFIED IDEOGRAPH-#7889, IRGKangXi=0831.480, RSKangXi=112.8, Def{room made of stone; watchtower}
788A CJK UNIFIED IDEOGRAPH-#788A, IRGKangXi=0832.010, RSKangXi=112.8
788B CJK UNIFIED IDEOGRAPH-#788B, IRGKangXi=0832.020, RSKangXi=112.8
788C CJK UNIFIED IDEOGRAPH-#788C, IRGKangXi=0832.030, RSKangXi=112.8, Def{rough, uneven, rocky; mediocre}
788D CJK UNIFIED IDEOGRAPH-#788D, IRGKangXi=0832.040, RSKangXi=112.8, Def{obstruct, hinder, block, deter}
788E CJK UNIFIED IDEOGRAPH-#788E, IRGKangXi=0832.050, RSKangXi=112.8, Def{break, smash; broken, busted}
788F CJK UNIFIED IDEOGRAPH-#788F, IRGKangXi=0832.080, RSKangXi=112.8, Def{coloured}
7890 CJK UNIFIED IDEOGRAPH-#7890, IRGKangXi=0832.090, RSKangXi=112.8
7891 CJK UNIFIED IDEOGRAPH-#7891, IRGKangXi=0832.100, RSKangXi=112.8, Def{stone tablet; gravestone}
7892 CJK UNIFIED IDEOGRAPH-#7892, IRGKangXi=0832.130, RSKangXi=112.8
7893 CJK UNIFIED IDEOGRAPH-#7893, IRGKangXi=0832.150, RSKangXi=112.8, Def{pestle}
7894 CJK UNIFIED IDEOGRAPH-#7894, IRGKangXi=0832.160, RSKangXi=112.8, Def{1/2 pr stone}
7895 CJK UNIFIED IDEOGRAPH-#7895, IRGKangXi=0832.170, RSKangXi=112.8, Def{a cape, spit, promontory}
7896 CJK UNIFIED IDEOGRAPH-#7896, IRGKangXi=0832.180, RSKangXi=112.8
7897 CJK UNIFIED IDEOGRAPH-#7897, IRGKangXi=0832.211, RSKangXi=112.8, Def{bowl, small dish}
7898 CJK UNIFIED IDEOGRAPH-#7898, IRGKangXi=0832.211, RSKangXi=112.8, Def{iodine}
7899 CJK UNIFIED IDEOGRAPH-#7899, IRGKangXi=0832.211, RSKangXi=112.8
789A CJK UNIFIED IDEOGRAPH-#789A, IRGKangXi=0832.211, RSKangXi=112.8, Def{suburb}
789B CJK UNIFIED IDEOGRAPH-#789B, IRGKangXi=0832.211, RSKangXi=112.8, Def{sand and gravel}
789C CJK UNIFIED IDEOGRAPH-#789C, IRGKangXi=0832.211, RSKangXi=112.8, Def{gritty}
789D CJK UNIFIED IDEOGRAPH-#789D, IRGKangXi=0832.230, RSKangXi=112.9
789E CJK UNIFIED IDEOGRAPH-#789E, IRGKangXi=0832.250, RSKangXi=112.9, Def{room made of stone; watchtower}
789F CJK UNIFIED IDEOGRAPH-#789F, IRGKangXi=0832.260, RSKangXi=112.9, Def{small dish, plate}
78A0 CJK UNIFIED IDEOGRAPH-#78A0, IRGKangXi=0832.280, RSKangXi=112.9
78A1 CJK UNIFIED IDEOGRAPH-#78A1, IRGKangXi=0832.300, RSKangXi=112.9, Def{stone roller used to level fields}
78A2 CJK UNIFIED IDEOGRAPH-#78A2, IRGKangXi=0832.340, RSKangXi=112.9
78A3 CJK UNIFIED IDEOGRAPH-#78A3, IRGKangXi=0833.010, RSKangXi=112.9, Def{stone tablet}
78A4 CJK UNIFIED IDEOGRAPH-#78A4, IRGKangXi=0833.030, RSKangXi=112.9
78A5 CJK UNIFIED IDEOGRAPH-#78A5, IRGKangXi=0833.050, RSKangXi=112.9
78A6 CJK UNIFIED IDEOGRAPH-#78A6, IRGKangXi=0833.060, RSKangXi=112.9
78A7 CJK UNIFIED IDEOGRAPH-#78A7, IRGKangXi=0833.090, RSKangXi=112.9, Def{jade; green, blue}
78A8 CJK UNIFIED IDEOGRAPH-#78A8, IRGKangXi=0833.110, RSKangXi=112.9
78A9 CJK UNIFIED IDEOGRAPH-#78A9, IRGKangXi=0833.130, RSKangXi=112.9, Def{great, eminent; large, big}
78AA CJK UNIFIED IDEOGRAPH-#78AA, IRGKangXi=0833.140, RSKangXi=112.9, Def{stone slab used for washing clothes; an anvil}
78AB CJK UNIFIED IDEOGRAPH-#78AB, IRGKangXi=0833.150, RSKangXi=112.9
78AC CJK UNIFIED IDEOGRAPH-#78AC, IRGKangXi=0833.160, RSKangXi=112.9, Def{whetstone}
78AD CJK UNIFIED IDEOGRAPH-#78AD, IRGKangXi=0833.170, RSKangXi=112.9, Def{brilliantly colored stone with veined patterns in it}
78AE CJK UNIFIED IDEOGRAPH-#78AE, IRGKangXi=0833.210, RSKangXi=112.9
78AF CJK UNIFIED IDEOGRAPH-#78AF, IRGKangXi=0833.250, RSKangXi=112.9, Def{agate, cornelian}
78B0 CJK UNIFIED IDEOGRAPH-#78B0, IRGKangXi=0832.211, RSKangXi=112.8, Def{collide, bump into}
78B1 CJK UNIFIED IDEOGRAPH-#78B1, IRGKangXi=0833.291, RSKangXi=112.9, Def{alkaline, alkali, lye, salt}
78B2 CJK UNIFIED IDEOGRAPH-#78B2, IRGKangXi=0833.291, RSKangXi=112.9, Def{tellurium}
78B3 CJK UNIFIED IDEOGRAPH-#78B3, IRGKangXi=0833.291, RSKangXi=112.9, Def{carbon}
78B4 CJK UNIFIED IDEOGRAPH-#78B4, IRGKangXi=0833.291, RSKangXi=112.9, Def{chipped edge of a container}
78B5 CJK UNIFIED IDEOGRAPH-#78B5, IRGKangXi=0833.291, RSKangXi=112.9
78B6 CJK UNIFIED IDEOGRAPH-#78B6, IRGKangXi=0833.291, RSKangXi=112.9, Def{a flood-gate, a water-gate}
78B7 CJK UNIFIED IDEOGRAPH-#78B7, IRGKangXi=0833.291, RSKangXi=112.9
78B8 CJK UNIFIED IDEOGRAPH-#78B8, IRGKangXi=0833.291, RSKangXi=112.9, Def{an organic compound}
78B9 CJK UNIFIED IDEOGRAPH-#78B9, IRGKangXi=0833.291, RSKangXi=112.9
78BA CJK UNIFIED IDEOGRAPH-#78BA, IRGKangXi=0833.310, RSKangXi=112.10, Def{sure, certain; real, true}
78BB CJK UNIFIED IDEOGRAPH-#78BB, IRGKangXi=0833.320, RSKangXi=112.10, Def{solid}
78BC CJK UNIFIED IDEOGRAPH-#78BC, IRGKangXi=0833.330, RSKangXi=112.10, Def{number, numerals; yard; symbol}
78BD CJK UNIFIED IDEOGRAPH-#78BD, IRGKangXi=0834.010, RSKangXi=112.10
78BE CJK UNIFIED IDEOGRAPH-#78BE, IRGKangXi=0834.020, RSKangXi=112.10, Def{roller, crush; roll}
78BF CJK UNIFIED IDEOGRAPH-#78BF, IRGKangXi=0834.100, RSKangXi=112.10
78C0 CJK UNIFIED IDEOGRAPH-#78C0, IRGKangXi=0834.120, RSKangXi=112.10
78C1 CJK UNIFIED IDEOGRAPH-#78C1, IRGKangXi=0834.140, RSKangXi=112.10, Def{magnetic; magnetism; porcelain}
78C2 CJK UNIFIED IDEOGRAPH-#78C2, IRGKangXi=0834.150, RSKangXi=112.10
78C3 CJK UNIFIED IDEOGRAPH-#78C3, IRGKangXi=0834.160, RSKangXi=112.10
78C4 CJK UNIFIED IDEOGRAPH-#78C4, IRGKangXi=0834.170, RSKangXi=112.10
78C5 CJK UNIFIED IDEOGRAPH-#78C5, IRGKangXi=0834.180, RSKangXi=112.10, Def{pound; weigh}
78C6 CJK UNIFIED IDEOGRAPH-#78C6, IRGKangXi=0834.210, RSKangXi=112.10
78C7 CJK UNIFIED IDEOGRAPH-#78C7, IRGKangXi=0834.220, RSKangXi=112.10, Def{arsenic}
78C8 CJK UNIFIED IDEOGRAPH-#78C8, IRGKangXi=0834.240, RSKangXi=112.10
78C9 CJK UNIFIED IDEOGRAPH-#78C9, IRGKangXi=0834.250, RSKangXi=112.10, Def{the stone base or plinth of a pillar}
78CA CJK UNIFIED IDEOGRAPH-#78CA, IRGKangXi=0834.260, RSKangXi=112.10, Def{pile of rocks or stones; great}
78CB CJK UNIFIED IDEOGRAPH-#78CB, IRGKangXi=0834.270, RSKangXi=112.10, Def{polish, buff; scrutinize}
78CC CJK UNIFIED IDEOGRAPH-#78CC, IRGKangXi=0834.290, RSKangXi=112.10
78CD CJK UNIFIED IDEOGRAPH-#78CD, IRGKangXi=0834.300, RSKangXi=112.10
78CE CJK UNIFIED IDEOGRAPH-#78CE, IRGKangXi=0834.310, RSKangXi=112.10, Def{mountain stream, creek}
78CF CJK UNIFIED IDEOGRAPH-#78CF, IRGKangXi=0834.320, RSKangXi=112.10
78D0 CJK UNIFIED IDEOGRAPH-#78D0, IRGKangXi=0834.330, RSKangXi=112.10, Def{large rock, boulder; firm}
78D1 CJK UNIFIED IDEOGRAPH-#78D1, IRGKangXi=0834.340, RSKangXi=112.10, Def{stone mill; grind; break apart}
78D2 CJK UNIFIED IDEOGRAPH-#78D2, IRGKangXi=0835.010, RSKangXi=112.10, Def{to fall from or into}
78D3 CJK UNIFIED IDEOGRAPH-#78D3, IRGKangXi=0835.020, RSKangXi=112.10, Def{to throw (a stone)}
78D4 CJK UNIFIED IDEOGRAPH-#78D4, IRGKangXi=0835.040, RSKangXi=112.10, Def{to dismember, tear apart; downward stroke slanting right}
78D5 CJK UNIFIED IDEOGRAPH-#78D5, IRGKangXi=0835.050, RSKangXi=112.10, Def{hit; collide, knock into; sound}
78D6 CJK UNIFIED IDEOGRAPH-#78D6, IRGKangXi=0835.060, RSKangXi=112.10
78D7 CJK UNIFIED IDEOGRAPH-#78D7, IRGKangXi=0835.061, RSKangXi=112.10
78D8 CJK UNIFIED IDEOGRAPH-#78D8, IRGKangXi=0835.061, RSKangXi=112.10
78D9 CJK UNIFIED IDEOGRAPH-#78D9, IRGKangXi=0835.061, RSKangXi=112.10, Def{roller}
78DA CJK UNIFIED IDEOGRAPH-#78DA, IRGKangXi=0835.070, RSKangXi=112.11, Def{tile, brick}
78DB CJK UNIFIED IDEOGRAPH-#78DB, IRGKangXi=0835.080, RSKangXi=112.11, Def{cliff}
78DC CJK UNIFIED IDEOGRAPH-#78DC, IRGKangXi=0835.130, RSKangXi=112.10
78DD CJK UNIFIED IDEOGRAPH-#78DD, IRGKangXi=0835.140, RSKangXi=112.11
78DE CJK UNIFIED IDEOGRAPH-#78DE, IRGKangXi=0835.150, RSKangXi=112.11
78DF CJK UNIFIED IDEOGRAPH-#78DF, IRGKangXi=0835.180, RSKangXi=112.11, Def{mediocre; busy; occupied; roller}
78E0 CJK UNIFIED IDEOGRAPH-#78E0, IRGKangXi=0835.200, RSKangXi=112.11, Def{sal ammoniac; sand; pebble}
78E1 CJK UNIFIED IDEOGRAPH-#78E1, IRGKangXi=0835.250, RSKangXi=112.11, Def{cliff, ledge, bank; step}
78E2 CJK UNIFIED IDEOGRAPH-#78E2, IRGKangXi=0835.260, RSKangXi=112.11, Def{(Cant.) to grind; a roller}
78E3 CJK UNIFIED IDEOGRAPH-#78E3, IRGKangXi=0835.270, RSKangXi=112.11, Def{gritty}
78E4 CJK UNIFIED IDEOGRAPH-#78E4, IRGKangXi=0835.310, RSKangXi=112.11
78E5 CJK UNIFIED IDEOGRAPH-#78E5, IRGKangXi=0835.330, RSKangXi=112.11, Def{a heap of stones; boulders}
78E6 CJK UNIFIED IDEOGRAPH-#78E6, IRGKangXi=0835.360, RSKangXi=112.11
78E7 CJK UNIFIED IDEOGRAPH-#78E7, IRGKangXi=0835.380, RSKangXi=112.11, Def{sand and gravel; rocks exposed at low tide; to crush}
78E8 CJK UNIFIED IDEOGRAPH-#78E8, IRGKangXi=0835.390, RSKangXi=112.11, Def{grind; polish; rub; wear out; a millstone}
78E9 CJK UNIFIED IDEOGRAPH-#78E9, IRGKangXi=0835.400, RSKangXi=112.11
78EA CJK UNIFIED IDEOGRAPH-#78EA, IRGKangXi=0835.420, RSKangXi=112.11, Def{a high mountain; precipitous}
78EB CJK UNIFIED IDEOGRAPH-#78EB, IRGKangXi=0836.010, RSKangXi=112.11
78EC CJK UNIFIED IDEOGRAPH-#78EC, IRGKangXi=0836.020, RSKangXi=112.11, Def{musical instrument; musical stone}
78ED CJK UNIFIED IDEOGRAPH-#78ED, IRGKangXi=0836.060, RSKangXi=112.11
78EE CJK UNIFIED IDEOGRAPH-#78EE, IRGKangXi=0836.091, RSKangXi=112.11
78EF CJK UNIFIED IDEOGRAPH-#78EF, IRGKangXi=0836.130, RSKangXi=112.12, Def{jetty; submerged rock; eddy}
78F0 CJK UNIFIED IDEOGRAPH-#78F0, IRGKangXi=0836.140, RSKangXi=112.12
78F1 CJK UNIFIED IDEOGRAPH-#78F1, IRGKangXi=0836.170, RSKangXi=112.12
78F2 CJK UNIFIED IDEOGRAPH-#78F2, IRGKangXi=0836.180, RSKangXi=112.12
78F3 CJK UNIFIED IDEOGRAPH-#78F3, IRGKangXi=0836.240, RSKangXi=112.12
78F4 CJK UNIFIED IDEOGRAPH-#78F4, IRGKangXi=0836.260, RSKangXi=112.12, Def{steps on ledge, cliff, or hill}
78F5 CJK UNIFIED IDEOGRAPH-#78F5, IRGKangXi=0836.270, RSKangXi=112.12, Def{brook, mountain stream}
78F6 CJK UNIFIED IDEOGRAPH-#78F6, IRGKangXi=0836.280, RSKangXi=112.12
78F7 CJK UNIFIED IDEOGRAPH-#78F7, IRGKangXi=0836.290, RSKangXi=112.12, Def{phosphorus; water rushing between}
78F8 CJK UNIFIED IDEOGRAPH-#78F8, IRGKangXi=0836.300, RSKangXi=112.12
78F9 CJK UNIFIED IDEOGRAPH-#78F9, IRGKangXi=0836.320, RSKangXi=112.12
78FA CJK UNIFIED IDEOGRAPH-#78FA, IRGKangXi=0836.350, RSKangXi=112.12, Def{sulphur; brimstone}
78FB CJK UNIFIED IDEOGRAPH-#78FB, IRGKangXi=0836.390, RSKangXi=112.12, Def{a tributary of the Wei river in Shanxi}
78FC CJK UNIFIED IDEOGRAPH-#78FC, IRGKangXi=0836.410, RSKangXi=112.12
78FD CJK UNIFIED IDEOGRAPH-#78FD, IRGKangXi=0837.010, RSKangXi=112.12, Def{barren land; sandy soil}
78FE CJK UNIFIED IDEOGRAPH-#78FE, IRGKangXi=0837.020, RSKangXi=112.12
78FF CJK UNIFIED IDEOGRAPH-#78FF, IRGKangXi=0837.050, RSKangXi=112.12
7900 CJK UNIFIED IDEOGRAPH-#7900, IRGKangXi=0837.091, RSKangXi=112.12
7901 CJK UNIFIED IDEOGRAPH-#7901, IRGKangXi=0837.091, RSKangXi=112.12, Def{reef; jetty; submerged rocks}
7902 CJK UNIFIED IDEOGRAPH-#7902, IRGKangXi=0837.091, RSKangXi=112.12
7903 CJK UNIFIED IDEOGRAPH-#7903, IRGKangXi=0837.091
7904 CJK UNIFIED IDEOGRAPH-#7904, IRGKangXi=0837.091, RSKangXi=112.12, Def{place in Sichuan province}
7905 CJK UNIFIED IDEOGRAPH-#7905, IRGKangXi=0837.091, RSKangXi=112.12
7906 CJK UNIFIED IDEOGRAPH-#7906, IRGKangXi=0837.100, RSKangXi=112.13, Def{alkaline, alkali, lye, salt}
7907 CJK UNIFIED IDEOGRAPH-#7907, IRGKangXi=0837.120, RSKangXi=112.13
7908 CJK UNIFIED IDEOGRAPH-#7908, IRGKangXi=0837.140, RSKangXi=112.13
7909 CJK UNIFIED IDEOGRAPH-#7909, IRGKangXi=0837.150, RSKangXi=112.13
790A CJK UNIFIED IDEOGRAPH-#790A, IRGKangXi=0837.160, RSKangXi=112.13
790B CJK UNIFIED IDEOGRAPH-#790B, IRGKangXi=0837.200, RSKangXi=112.13
790C CJK UNIFIED IDEOGRAPH-#790C, IRGKangXi=0837.220, RSKangXi=112.13
790D CJK UNIFIED IDEOGRAPH-#790D, IRGKangXi=0837.270, RSKangXi=112.13
790E CJK UNIFIED IDEOGRAPH-#790E, IRGKangXi=0837.290, RSKangXi=112.13, Def{foundation stone, plinth}
790F CJK UNIFIED IDEOGRAPH-#790F, IRGKangXi=0837.300, RSKangXi=112.13
7910 CJK UNIFIED IDEOGRAPH-#7910, IRGKangXi=0837.320, RSKangXi=112.13
7911 CJK UNIFIED IDEOGRAPH-#7911, IRGKangXi=0837.330, RSKangXi=112.13
7912 CJK UNIFIED IDEOGRAPH-#7912, IRGKangXi=0837.340, RSKangXi=112.13
7913 CJK UNIFIED IDEOGRAPH-#7913, IRGKangXi=0837.350, RSKangXi=112.13
7914 CJK UNIFIED IDEOGRAPH-#7914, IRGKangXi=0837.370, RSKangXi=112.13
7915 CJK UNIFIED IDEOGRAPH-#7915, IRGKangXi=0837.411, RSKangXi=112.13
7916 CJK UNIFIED IDEOGRAPH-#7916, IRGKangXi=0838.051, RSKangXi=112.13
7917 CJK UNIFIED IDEOGRAPH-#7917, IRGKangXi=0837.420, RSKangXi=112.14
7918 CJK UNIFIED IDEOGRAPH-#7918, IRGKangXi=0837.440, RSKangXi=112.14
7919 CJK UNIFIED IDEOGRAPH-#7919, IRGKangXi=0837.460, RSKangXi=112.14, Def{obstruct, hinder, block, deter}
791A CJK UNIFIED IDEOGRAPH-#791A, IRGKangXi=0837.470, RSKangXi=112.14
791B CJK UNIFIED IDEOGRAPH-#791B, IRGKangXi=0837.480, RSKangXi=112.14
791C CJK UNIFIED IDEOGRAPH-#791C, IRGKangXi=0838.010, RSKangXi=112.14
791D CJK UNIFIED IDEOGRAPH-#791D, IRGKangXi=0838.020, RSKangXi=112.14
791E CJK UNIFIED IDEOGRAPH-#791E, IRGKangXi=0838.050, RSKangXi=112.14
791F CJK UNIFIED IDEOGRAPH-#791F, IRGKangXi=0838.051, RSKangXi=112.14, Def{ancient ballista for throwing heavy stones; a cannon, a gun}
7920 CJK UNIFIED IDEOGRAPH-#7920, IRGKangXi=0838.051, RSKangXi=112.14
7921 CJK UNIFIED IDEOGRAPH-#7921, IRGKangXi=0838.051, RSKangXi=112.14, Def{fill, extend}
7922 CJK UNIFIED IDEOGRAPH-#7922, IRGKangXi=0838.261, RSKangXi=112.15
7923 CJK UNIFIED IDEOGRAPH-#7923, IRGKangXi=0838.060, RSKangXi=112.15
7924 CJK UNIFIED IDEOGRAPH-#7924, IRGKangXi=0838.070, RSKangXi=112.15
7925 CJK UNIFIED IDEOGRAPH-#7925, IRGKangXi=0838.080, RSKangXi=112.15
7926 CJK UNIFIED IDEOGRAPH-#7926, IRGKangXi=0838.160, RSKangXi=112.15, Def{mine; mineral, ore}
7927 CJK UNIFIED IDEOGRAPH-#7927, IRGKangXi=0838.200, RSKangXi=112.15, Def{roll}
7928 CJK UNIFIED IDEOGRAPH-#7928, IRGKangXi=0838.210, RSKangXi=112.15
7929 CJK UNIFIED IDEOGRAPH-#7929, IRGKangXi=0838.220, RSKangXi=112.15
792A CJK UNIFIED IDEOGRAPH-#792A, IRGKangXi=0838.230, RSKangXi=112.15, Def{whetstone; sharpen}
792B CJK UNIFIED IDEOGRAPH-#792B, IRGKangXi=0838.240, RSKangXi=112.15, Def{gravel, pebbles, potsherds}
792C CJK UNIFIED IDEOGRAPH-#792C, IRGKangXi=0838.250, RSKangXi=112.15, Def{alum}
792D CJK UNIFIED IDEOGRAPH-#792D, IRGKangXi=0838.270, RSKangXi=112.16
792E CJK UNIFIED IDEOGRAPH-#792E, IRGKangXi=0838.290, RSKangXi=112.16, Def{ancient ballista for throwing heavy stones a cannon, a gun}
792F CJK UNIFIED IDEOGRAPH-#792F, IRGKangXi=0838.310, RSKangXi=112.16
7930 CJK UNIFIED IDEOGRAPH-#7930, IRGKangXi=0838.320, RSKangXi=112.16
7931 CJK UNIFIED IDEOGRAPH-#7931, IRGKangXi=0838.350, RSKangXi=112.16, Def{grind, sharpen; mill}
7932 CJK UNIFIED IDEOGRAPH-#7932, IRGKangXi=0838.381
7933 CJK UNIFIED IDEOGRAPH-#7933, IRGKangXi=0838.381, Def{name of place in shan xi province}
7934 CJK UNIFIED IDEOGRAPH-#7934, IRGKangXi=0839.050, RSKangXi=112.16, Def{fill, extend}
7935 CJK UNIFIED IDEOGRAPH-#7935, IRGKangXi=0839.051, RSKangXi=112.17, Def{arsenic}
7936 CJK UNIFIED IDEOGRAPH-#7936, IRGKangXi=0839.091, RSKangXi=112.18, Def{a jug, a pitcher, a jar, a pot}
7937 CJK UNIFIED IDEOGRAPH-#7937, IRGKangXi=0839.091, RSKangXi=112.18
7938 CJK UNIFIED IDEOGRAPH-#7938, IRGKangXi=0839.120, RSKangXi=112.19
7939 CJK UNIFIED IDEOGRAPH-#7939, IRGKangXi=0839.140, RSKangXi=112.20
793A CJK UNIFIED IDEOGRAPH-#793A, IRGKangXi=0839.200, RSKangXi=113.0, Def{show, manifest; demonstrate}
793B CJK UNIFIED IDEOGRAPH-#793B, IRGKangXi=0839.201, RSKangXi=113.0, Def{cult; radical number 113}
793C CJK UNIFIED IDEOGRAPH-#793C, IRGKangXi=0839.220, RSKangXi=113.1, Def{social custom; manners; courtesy}
793D CJK UNIFIED IDEOGRAPH-#793D, IRGKangXi=0839.250, RSKangXi=113.2, Def{blessings, happiness}
793E CJK UNIFIED IDEOGRAPH-#793E, IRGKangXi=0839.260, RSKangXi=113.3, Def{god of the soil and altars to him; group of families; company, society}
793F CJK UNIFIED IDEOGRAPH-#793F, IRGKangXi=0839.300, RSKangXi=113.3, Def{sacrifice}
7940 CJK UNIFIED IDEOGRAPH-#7940, IRGKangXi=0840.010, RSKangXi=113.3, Def{to sacrifice, worship}
7941 CJK UNIFIED IDEOGRAPH-#7941, IRGKangXi=0840.030, RSKangXi=113.3, Def{pray; numerous, ample, abundant}
7942 CJK UNIFIED IDEOGRAPH-#7942, IRGKangXi=0840.031, RSKangXi=113.3, Def{he (honorific form, generally used for the Abrahamic God)}
7943 CJK UNIFIED IDEOGRAPH-#7943, IRGKangXi=0840.031, RSKangXi=113.3, Def{a sacrifice at the beginning of a military campaign}
7944 CJK UNIFIED IDEOGRAPH-#7944, IRGKangXi=0840.050, RSKangXi=113.4
7945 CJK UNIFIED IDEOGRAPH-#7945, IRGKangXi=0840.060, RSKangXi=113.4, Def{calamities, disasters; ormazda}
7946 CJK UNIFIED IDEOGRAPH-#7946, IRGKangXi=0840.070, RSKangXi=113.4, Def{Ormazda, god of the Zoroastrians; extended to god of the Manicheans}
7947 CJK UNIFIED IDEOGRAPH-#7947, IRGKangXi=0840.080, RSKangXi=113.4, Def{the spirit of the earth; (used for U+53EA 只) only, merely, but}
7948 CJK UNIFIED IDEOGRAPH-#7948, IRGKangXi=0840.090, RSKangXi=113.4, Def{pray; entreat, beseech}
7949 CJK UNIFIED IDEOGRAPH-#7949, IRGKangXi=0840.100, RSKangXi=113.4, Def{happiness, blessings, good luck}
794A CJK UNIFIED IDEOGRAPH-#794A, IRGKangXi=0840.120, RSKangXi=113.4, Def{river in Shandong; space inside}
794B CJK UNIFIED IDEOGRAPH-#794B, IRGKangXi=0840.140, RSKangXi=113.4
794C CJK UNIFIED IDEOGRAPH-#794C, IRGKangXi=0841.020, RSKangXi=113.4
794D CJK UNIFIED IDEOGRAPH-#794D, IRGKangXi=0841.031, RSKangXi=113.4
794E CJK UNIFIED IDEOGRAPH-#794E, IRGKangXi=0841.031, RSKangXi=113.4, Def{excellent}
794F CJK UNIFIED IDEOGRAPH-#794F, IRGKangXi=0841.040, RSKangXi=113.5, Def{shrine}
7950 CJK UNIFIED IDEOGRAPH-#7950, IRGKangXi=0841.050, RSKangXi=113.5, Def{divine intervention, protection}
7951 CJK UNIFIED IDEOGRAPH-#7951, IRGKangXi=0841.070, RSKangXi=113.5
7952 CJK UNIFIED IDEOGRAPH-#7952, IRGKangXi=0841.090, RSKangXi=113.5
7953 CJK UNIFIED IDEOGRAPH-#7953, IRGKangXi=0841.120, RSKangXi=113.5, Def{exorcise, remove evil; clean}
7954 CJK UNIFIED IDEOGRAPH-#7954, IRGKangXi=0841.160, RSKangXi=113.5, Def{worship one's ancestors; entomb}
7955 CJK UNIFIED IDEOGRAPH-#7955, IRGKangXi=0841.170, RSKangXi=113.5, Def{mysterious, secret, abstruse}
7956 CJK UNIFIED IDEOGRAPH-#7956, IRGKangXi=0841.180, RSKangXi=113.5, Def{ancestor, forefather; grandfather}
7957 CJK UNIFIED IDEOGRAPH-#7957, IRGKangXi=0841.200, RSKangXi=113.5, Def{respect, look up to, revere}
7958 CJK UNIFIED IDEOGRAPH-#7958, IRGKangXi=0841.220, RSKangXi=113.5, Def{to calculate}
7959 CJK UNIFIED IDEOGRAPH-#7959, IRGKangXi=0842.121, RSKangXi=113.5, Def{demon}
795A CJK UNIFIED IDEOGRAPH-#795A, IRGKangXi=0841.240, RSKangXi=113.5, Def{throne; bless; blessing, happiness}
795B CJK UNIFIED IDEOGRAPH-#795B, IRGKangXi=0841.260, RSKangXi=113.5, Def{expel, disperse, exorcise}
795C CJK UNIFIED IDEOGRAPH-#795C, IRGKangXi=0841.270, RSKangXi=113.5, Def{blessing, happiness, prosperity}
795D CJK UNIFIED IDEOGRAPH-#795D, IRGKangXi=0842.010, RSKangXi=113.5, Def{pray for happiness or blessings}
795E CJK UNIFIED IDEOGRAPH-#795E, IRGKangXi=0842.030, RSKangXi=113.5, Def{spirit, god, supernatural being}
795F CJK UNIFIED IDEOGRAPH-#795F, IRGKangXi=0842.050, RSKangXi=113.5, Def{evil spirit; evil influence}
7960 CJK UNIFIED IDEOGRAPH-#7960, IRGKangXi=0842.060, RSKangXi=113.5, Def{ancestral temple; offer sacrifice}
7961 CJK UNIFIED IDEOGRAPH-#7961, IRGKangXi=0842.070, RSKangXi=113.5
7962 CJK UNIFIED IDEOGRAPH-#7962, IRGKangXi=0842.100, RSKangXi=113.5, Def{one's deceased father; used as a synonym for U+4F60 你 when referring to deity}
7963 CJK UNIFIED IDEOGRAPH-#7963, IRGKangXi=0842.130, RSKangXi=113.6
7964 CJK UNIFIED IDEOGRAPH-#7964, IRGKangXi=0842.150, RSKangXi=113.6
7965 CJK UNIFIED IDEOGRAPH-#7965, IRGKangXi=0842.160, RSKangXi=113.6, Def{good luck, good omen; happiness}
7966 CJK UNIFIED IDEOGRAPH-#7966, IRGKangXi=0842.190, RSKangXi=113.7, Def{happiness; good fortune good luck; blessing; bliss}
7967 CJK UNIFIED IDEOGRAPH-#7967, IRGKangXi=0842.200, RSKangXi=113.6, Def{an ancestral hall}
7968 CJK UNIFIED IDEOGRAPH-#7968, IRGKangXi=0843.010, RSKangXi=113.6, Def{slip of paper or bamboo; ticket}
7969 CJK UNIFIED IDEOGRAPH-#7969, IRGKangXi=0843.020, RSKangXi=113.6
796A CJK UNIFIED IDEOGRAPH-#796A, IRGKangXi=0843.040, RSKangXi=113.6
796B CJK UNIFIED IDEOGRAPH-#796B, IRGKangXi=0843.050, RSKangXi=113.6, Def{triennial sacrifice to one's ancestors}
796C CJK UNIFIED IDEOGRAPH-#796C, IRGKangXi=0843.060, RSKangXi=113.6
796D CJK UNIFIED IDEOGRAPH-#796D, IRGKangXi=0843.070, RSKangXi=113.6, Def{sacrifice to, worship}
796E CJK UNIFIED IDEOGRAPH-#796E, IRGKangXi=0843.081, RSKangXi=113.6
796F CJK UNIFIED IDEOGRAPH-#796F, IRGKangXi=0843.081, RSKangXi=113.6, Def{lucky, auspicious, good omen}
7970 CJK UNIFIED IDEOGRAPH-#7970, IRGKangXi=0843.120, RSKangXi=113.7
7971 CJK UNIFIED IDEOGRAPH-#7971, IRGKangXi=0843.140, RSKangXi=113.7
7972 CJK UNIFIED IDEOGRAPH-#7972, IRGKangXi=0843.160, RSKangXi=113.7, Def{ominous or sinister spirit; vigor}
7973 CJK UNIFIED IDEOGRAPH-#7973, IRGKangXi=0843.190, RSKangXi=113.7
7974 CJK UNIFIED IDEOGRAPH-#7974, IRGKangXi=0843.200, RSKangXi=113.7
7975 CJK UNIFIED IDEOGRAPH-#7975, IRGKangXi=0843.210, RSKangXi=113.7
7976 CJK UNIFIED IDEOGRAPH-#7976, IRGKangXi=0843.261, RSKangXi=113.7
7977 CJK UNIFIED IDEOGRAPH-#7977, IRGKangXi=0843.261, RSKangXi=113.7, Def{pray; entreat, beg, plead; prayer}
7978 CJK UNIFIED IDEOGRAPH-#7978, IRGKangXi=0843.261, RSKangXi=113.7, Def{misfortune, calamity, disaster}
7979 CJK UNIFIED IDEOGRAPH-#7979, IRGKangXi=0843.290, RSKangXi=113.8
797A CJK UNIFIED IDEOGRAPH-#797A, IRGKangXi=0843.320, RSKangXi=113.8, Def{good luck, good fortune}
797B CJK UNIFIED IDEOGRAPH-#797B, IRGKangXi=0843.340, RSKangXi=113.8
797C CJK UNIFIED IDEOGRAPH-#797C, IRGKangXi=0844.040, RSKangXi=113.8, Def{libation}
797D CJK UNIFIED IDEOGRAPH-#797D, IRGKangXi=0844.060, RSKangXi=113.8
797E CJK UNIFIED IDEOGRAPH-#797E, IRGKangXi=0844.070, RSKangXi=113.8
797F CJK UNIFIED IDEOGRAPH-#797F, IRGKangXi=0844.080, RSKangXi=113.8, Def{blessing, happiness, prosperity}
7980 CJK UNIFIED IDEOGRAPH-#7980, IRGKangXi=0844.090, RSKangXi=113.8, Def{report to, petition}
7981 CJK UNIFIED IDEOGRAPH-#7981, IRGKangXi=0844.100, RSKangXi=113.8, Def{restrict, prohibit, forbid}
7982 CJK UNIFIED IDEOGRAPH-#7982, IRGKangXi=0844.110, RSKangXi=113.8, Def{to pray; prayer}
7983 CJK UNIFIED IDEOGRAPH-#7983, IRGKangXi=0844.140, RSKangXi=113.8
7984 CJK UNIFIED IDEOGRAPH-#7984, IRGKangXi=0844.171, RSKangXi=113.7, Def{blessing, happiness, prosperity}
7985 CJK UNIFIED IDEOGRAPH-#7985, IRGKangXi=0844.171, RSKangXi=113.8, Def{meditation, contemplation (DKW: 24787')}
7986 CJK UNIFIED IDEOGRAPH-#7986, IRGKangXi=0844.171
7987 CJK UNIFIED IDEOGRAPH-#7987, IRGKangXi=0844.180, RSKangXi=113.9
7988 CJK UNIFIED IDEOGRAPH-#7988, IRGKangXi=0844.190, RSKangXi=113.9
7989 CJK UNIFIED IDEOGRAPH-#7989, IRGKangXi=0844.200, RSKangXi=113.9
798A CJK UNIFIED IDEOGRAPH-#798A, IRGKangXi=0844.230, RSKangXi=113.9, Def{semi-annual ceremony of purification}
798B CJK UNIFIED IDEOGRAPH-#798B, IRGKangXi=0844.240, RSKangXi=113.9, Def{offer sacrifice; sacrifice}
798C CJK UNIFIED IDEOGRAPH-#798C, IRGKangXi=0844.300, RSKangXi=113.9
798D CJK UNIFIED IDEOGRAPH-#798D, IRGKangXi=0844.310, RSKangXi=113.9, Def{misfortune, calamity, disaster}
798E CJK UNIFIED IDEOGRAPH-#798E, IRGKangXi=0845.010, RSKangXi=113.9, Def{lucky, auspicious, good omen}
798F CJK UNIFIED IDEOGRAPH-#798F, IRGKangXi=0845.020, RSKangXi=113.9, Def{happiness, good fortune, blessing}
7990 CJK UNIFIED IDEOGRAPH-#7990, IRGKangXi=0845.040, RSKangXi=113.9
7991 CJK UNIFIED IDEOGRAPH-#7991, IRGKangXi=0845.050, RSKangXi=113.9, Def{happy; used in historical names}
7992 CJK UNIFIED IDEOGRAPH-#7992, IRGKangXi=0845.060, RSKangXi=113.9
7993 CJK UNIFIED IDEOGRAPH-#7993, IRGKangXi=0845.070, RSKangXi=113.9, Def{to drive out demons, etc., as was done at the new-year}
7994 CJK UNIFIED IDEOGRAPH-#7994, IRGKangXi=0845.080, RSKangXi=113.9, Def{happiness; peace; good fortune}
7995 CJK UNIFIED IDEOGRAPH-#7995, IRGKangXi=0845.100, RSKangXi=113.9, Def{excellent, rare; beautiful, fine}
7996 CJK UNIFIED IDEOGRAPH-#7996, IRGKangXi=0845.110, RSKangXi=113.9, Def{sacrifice}
7997 CJK UNIFIED IDEOGRAPH-#7997, IRGKangXi=0845.120, RSKangXi=113.9
7998 CJK UNIFIED IDEOGRAPH-#7998, IRGKangXi=0845.130, RSKangXi=113.9, Def{imperial ancestor worship}
7999 CJK UNIFIED IDEOGRAPH-#7999, IRGKangXi=0845.161, RSKangXi=113.9
799A CJK UNIFIED IDEOGRAPH-#799A, IRGKangXi=0845.170, RSKangXi=113.10, Def{place name}
799B CJK UNIFIED IDEOGRAPH-#799B, IRGKangXi=0845.180, RSKangXi=113.10, Def{to receive blessings in a sincere spirit}
799C CJK UNIFIED IDEOGRAPH-#799C, IRGKangXi=0845.190, RSKangXi=113.10, Def{sacrifice}
799D CJK UNIFIED IDEOGRAPH-#799D, IRGKangXi=0845.220, RSKangXi=113.10
799E CJK UNIFIED IDEOGRAPH-#799E, IRGKangXi=0846.010, RSKangXi=113.10
799F CJK UNIFIED IDEOGRAPH-#799F, IRGKangXi=0846.030, RSKangXi=113.10
79A0 CJK UNIFIED IDEOGRAPH-#79A0, IRGKangXi=0846.050, RSKangXi=113.10, Def{happy}
79A1 CJK UNIFIED IDEOGRAPH-#79A1, IRGKangXi=0846.060, RSKangXi=113.10, Def{a sacrifice at the beginning of a military campaign or on the 2nd and 16th day of the lunar month}
79A2 CJK UNIFIED IDEOGRAPH-#79A2, IRGKangXi=0846.091, RSKangXi=113.10, Def{surname}
79A3 CJK UNIFIED IDEOGRAPH-#79A3, IRGKangXi=0846.091, RSKangXi=113.10
79A4 CJK UNIFIED IDEOGRAPH-#79A4, IRGKangXi=0846.150, RSKangXi=113.11, Def{surname Xuan}
79A5 CJK UNIFIED IDEOGRAPH-#79A5, IRGKangXi=0846.220, RSKangXi=113.11
79A6 CJK UNIFIED IDEOGRAPH-#79A6, IRGKangXi=0846.230, RSKangXi=113.11, Def{defend, resist, hold out against}
79A7 CJK UNIFIED IDEOGRAPH-#79A7, IRGKangXi=0846.300, RSKangXi=113.12, Def{happiness; congratulations}
79A8 CJK UNIFIED IDEOGRAPH-#79A8, IRGKangXi=0846.330, RSKangXi=113.12, Def{pray for good fortune}
79A9 CJK UNIFIED IDEOGRAPH-#79A9, IRGKangXi=0846.340, RSKangXi=113.12
79AA CJK UNIFIED IDEOGRAPH-#79AA, IRGKangXi=0846.360, RSKangXi=113.12, Def{meditation, contemplation (dhyana); to level ground for altar; abdicate}
79AB CJK UNIFIED IDEOGRAPH-#79AB, IRGKangXi=0846.370, RSKangXi=113.12, Def{sacrifice offered at the end of the three years' mourning the death of a parent}
79AC CJK UNIFIED IDEOGRAPH-#79AC, IRGKangXi=0847.040, RSKangXi=113.13
79AD CJK UNIFIED IDEOGRAPH-#79AD, IRGKangXi=0847.060, RSKangXi=113.13
79AE CJK UNIFIED IDEOGRAPH-#79AE, IRGKangXi=0847.070, RSKangXi=113.13, Def{social custom; manners; courtesy; rites}
79AF CJK UNIFIED IDEOGRAPH-#79AF, IRGKangXi=0847.120, RSKangXi=113.13
79B0 CJK UNIFIED IDEOGRAPH-#79B0, IRGKangXi=0847.150, RSKangXi=113.14, Def{one's deceased father}
79B1 CJK UNIFIED IDEOGRAPH-#79B1, IRGKangXi=0847.160, RSKangXi=113.14, Def{pray; entreat, beg, plead; prayer}
79B2 CJK UNIFIED IDEOGRAPH-#79B2, IRGKangXi=0847.230, RSKangXi=113.15
79B3 CJK UNIFIED IDEOGRAPH-#79B3, IRGKangXi=0847.290, RSKangXi=113.17, Def{pray or sacrifice, exorcise}
79B4 CJK UNIFIED IDEOGRAPH-#79B4, IRGKangXi=0847.310, RSKangXi=113.17, Def{sacrifice}
79B5 CJK UNIFIED IDEOGRAPH-#79B5, IRGKangXi=0847.320, RSKangXi=113.18
79B6 CJK UNIFIED IDEOGRAPH-#79B6, IRGKangXi=0847.330, RSKangXi=113.19
79B7 CJK UNIFIED IDEOGRAPH-#79B7, IRGKangXi=0847.340, RSKangXi=113.19
79B8 CJK UNIFIED IDEOGRAPH-#79B8, IRGKangXi=0848.010, RSKangXi=114.0, Def{rump; KangXi radical 114}
79B9 CJK UNIFIED IDEOGRAPH-#79B9, IRGKangXi=0848.020, RSKangXi=114.4, Def{legendary hsia dynasty founder}
79BA CJK UNIFIED IDEOGRAPH-#79BA, IRGKangXi=0848.050, RSKangXi=114.4, Def{district; mountain in Zhejiang}
79BB CJK UNIFIED IDEOGRAPH-#79BB, IRGKangXi=0848.070, RSKangXi=114.6, Def{rare beast; strange; elegant}
79BC CJK UNIFIED IDEOGRAPH-#79BC, IRGKangXi=0848.110, RSKangXi=114.7
79BD CJK UNIFIED IDEOGRAPH-#79BD, IRGKangXi=0848.130, RSKangXi=114.8, Def{birds, fowl; surname;; capture}
79BE CJK UNIFIED IDEOGRAPH-#79BE, IRGKangXi=0848.180, RSKangXi=115.0, Def{grain still on stalk; rice plant}
79BF CJK UNIFIED IDEOGRAPH-#79BF, IRGKangXi=0849.020, RSKangXi=115.2, Def{bald, bare, stripped}
79C0 CJK UNIFIED IDEOGRAPH-#79C0, IRGKangXi=0849.030, RSKangXi=115.2, Def{ear of grain; flowering, luxuriant; refined, elegant, graceful}
79C1 CJK UNIFIED IDEOGRAPH-#79C1, IRGKangXi=0849.050, RSKangXi=115.2, Def{private, personal; secret}
79C2 CJK UNIFIED IDEOGRAPH-#79C2, IRGKangXi=0849.060, RSKangXi=115.2
79C3 CJK UNIFIED IDEOGRAPH-#79C3, IRGKangXi=0849.081, RSKangXi=115.2, Def{bald}
79C4 CJK UNIFIED IDEOGRAPH-#79C4, IRGKangXi=0849.090, RSKangXi=115.3, Def{to hoe}
79C5 CJK UNIFIED IDEOGRAPH-#79C5, IRGKangXi=0849.110, RSKangXi=115.3
79C6 CJK UNIFIED IDEOGRAPH-#79C6, IRGKangXi=0849.140, RSKangXi=115.3, Def{straw; stalk of grain}
79C7 CJK UNIFIED IDEOGRAPH-#79C7, IRGKangXi=0849.150, RSKangXi=115.3, Def{skill, ability in handicraft a craft, an art, a calling; a trade; an accomplishment}
79C8 CJK UNIFIED IDEOGRAPH-#79C8, IRGKangXi=0849.160, RSKangXi=115.3, Def{non-glutinous long grain rice}
79C9 CJK UNIFIED IDEOGRAPH-#79C9, IRGKangXi=0849.210, RSKangXi=115.3, Def{grasp, hold; bundle; authority}
79CA CJK UNIFIED IDEOGRAPH-#79CA, IRGKangXi=0850.010, RSKangXi=115.3, Def{year; new-years; person's age}
79CB CJK UNIFIED IDEOGRAPH-#79CB, IRGKangXi=0850.060, RSKangXi=115.4, Def{autumn, fall; year}
79CC CJK UNIFIED IDEOGRAPH-#79CC, IRGKangXi=0850.110, RSKangXi=86.5, Def{(same as U+79CB 秋) autumn, fall; year}
79CD CJK UNIFIED IDEOGRAPH-#79CD, IRGKangXi=0850.120, RSKangXi=115.4, Def{seed; race, breed; to plant}
79CE CJK UNIFIED IDEOGRAPH-#79CE, IRGKangXi=0850.130, RSKangXi=115.4
79CF CJK UNIFIED IDEOGRAPH-#79CF, IRGKangXi=0850.160, RSKangXi=115.4, Def{to waste, to destroy, to diminish; hence it came to mean, a rat}
79D0 CJK UNIFIED IDEOGRAPH-#79D0, IRGKangXi=0850.190, RSKangXi=115.4, Def{to weed}
79D1 CJK UNIFIED IDEOGRAPH-#79D1, IRGKangXi=0850.200, RSKangXi=115.4, Def{section, department, science}
79D2 CJK UNIFIED IDEOGRAPH-#79D2, IRGKangXi=0850.220, RSKangXi=115.4, Def{beard of grain or corn; a second}
79D3 CJK UNIFIED IDEOGRAPH-#79D3, IRGKangXi=0850.230, RSKangXi=115.4
79D4 CJK UNIFIED IDEOGRAPH-#79D4, IRGKangXi=0850.240, RSKangXi=115.4, Def{non-glutinous rice}
79D5 CJK UNIFIED IDEOGRAPH-#79D5, IRGKangXi=0850.280, RSKangXi=115.4, Def{empty grain or rice husk, chaff}
79D6 CJK UNIFIED IDEOGRAPH-#79D6, IRGKangXi=0850.290, RSKangXi=115.4
79D7 CJK UNIFIED IDEOGRAPH-#79D7, IRGKangXi=0851.040, RSKangXi=115.4
79D8 CJK UNIFIED IDEOGRAPH-#79D8, IRGKangXi=0851.120, RSKangXi=115.5, Def{secret, mysterious, abstruse}
79D9 CJK UNIFIED IDEOGRAPH-#79D9, IRGKangXi=0851.130, RSKangXi=115.5
79DA CJK UNIFIED IDEOGRAPH-#79DA, IRGKangXi=0851.150, RSKangXi=115.5
79DB CJK UNIFIED IDEOGRAPH-#79DB, IRGKangXi=0851.160, RSKangXi=115.5
79DC CJK UNIFIED IDEOGRAPH-#79DC, IRGKangXi=0851.170, RSKangXi=115.5
79DD CJK UNIFIED IDEOGRAPH-#79DD, IRGKangXi=0851.180, RSKangXi=115.5, Def{(Cant.) excessively thin}
79DE CJK UNIFIED IDEOGRAPH-#79DE, IRGKangXi=0851.220, RSKangXi=115.5
79DF CJK UNIFIED IDEOGRAPH-#79DF, IRGKangXi=0851.230, RSKangXi=115.5, Def{rent, lease; rental; tax}
79E0 CJK UNIFIED IDEOGRAPH-#79E0, IRGKangXi=0851.240, RSKangXi=115.5, Def{millet}
79E1 CJK UNIFIED IDEOGRAPH-#79E1, IRGKangXi=0851.250, RSKangXi=115.5
79E2 CJK UNIFIED IDEOGRAPH-#79E2, IRGKangXi=0851.260, RSKangXi=115.5
79E3 CJK UNIFIED IDEOGRAPH-#79E3, IRGKangXi=0851.270, RSKangXi=115.5, Def{fodder, horse feed; feed horse}
79E4 CJK UNIFIED IDEOGRAPH-#79E4, IRGKangXi=0851.280, RSKangXi=115.5, Def{balance, scale, steelyard}
79E5 CJK UNIFIED IDEOGRAPH-#79E5, IRGKangXi=0851.290, RSKangXi=115.5
79E6 CJK UNIFIED IDEOGRAPH-#79E6, IRGKangXi=0851.300, RSKangXi=115.5, Def{feudal state of Qin; the Qin dynasty (from which the name 'China' comes)}
79E7 CJK UNIFIED IDEOGRAPH-#79E7, IRGKangXi=0851.320, RSKangXi=115.5, Def{rice seedlings, young rice plants}
79E8 CJK UNIFIED IDEOGRAPH-#79E8, IRGKangXi=0851.330, RSKangXi=115.5
79E9 CJK UNIFIED IDEOGRAPH-#79E9, IRGKangXi=0851.340, RSKangXi=115.5, Def{order; orderly; salary; decade}
79EA CJK UNIFIED IDEOGRAPH-#79EA, IRGKangXi=0852.020, RSKangXi=115.5, Def{only, merely}
79EB CJK UNIFIED IDEOGRAPH-#79EB, IRGKangXi=0852.030, RSKangXi=115.5, Def{glutinous variety of millet}
79EC CJK UNIFIED IDEOGRAPH-#79EC, IRGKangXi=0852.040, RSKangXi=115.5, Def{black millet}
79ED CJK UNIFIED IDEOGRAPH-#79ED, IRGKangXi=0852.050, RSKangXi=115.5, Def{one thousand millions, sometimes used for one hundred millions}
79EE CJK UNIFIED IDEOGRAPH-#79EE, IRGKangXi=0852.101, RSKangXi=115.5
79EF CJK UNIFIED IDEOGRAPH-#79EF, IRGKangXi=0852.101, RSKangXi=115.5, Def{accumulate, store up, amass}
79F0 CJK UNIFIED IDEOGRAPH-#79F0, IRGKangXi=0852.101, RSKangXi=115.5, Def{call; name, brand; address; say}
79F1 CJK UNIFIED IDEOGRAPH-#79F1, IRGKangXi=0852.110, RSKangXi=115.6
79F2 CJK UNIFIED IDEOGRAPH-#79F2, IRGKangXi=0852.150, RSKangXi=115.6
79F3 CJK UNIFIED IDEOGRAPH-#79F3, IRGKangXi=0852.160, RSKangXi=115.6
79F4 CJK UNIFIED IDEOGRAPH-#79F4, IRGKangXi=0852.190
79F5 CJK UNIFIED IDEOGRAPH-#79F5, IRGKangXi=0852.200, RSKangXi=115.6
79F6 CJK UNIFIED IDEOGRAPH-#79F6, IRGKangXi=0852.240, RSKangXi=115.6
79F7 CJK UNIFIED IDEOGRAPH-#79F7, IRGKangXi=0852.280, RSKangXi=115.6
79F8 CJK UNIFIED IDEOGRAPH-#79F8, IRGKangXi=0852.330, RSKangXi=115.6, Def{stalks of millet, corn}
79F9 CJK UNIFIED IDEOGRAPH-#79F9, IRGKangXi=0852.350, RSKangXi=115.6
79FA CJK UNIFIED IDEOGRAPH-#79FA, IRGKangXi=0853.020, RSKangXi=115.6
79FB CJK UNIFIED IDEOGRAPH-#79FB, IRGKangXi=0853.040, RSKangXi=115.6, Def{change place, shift; move about}
79FC CJK UNIFIED IDEOGRAPH-#79FC, IRGKangXi=0853.081, RSKangXi=115.6
79FD CJK UNIFIED IDEOGRAPH-#79FD, IRGKangXi=0853.081, RSKangXi=115.6, Def{dirty, unclean; immoral, obscene}
79FE CJK UNIFIED IDEOGRAPH-#79FE, IRGKangXi=0853.081, RSKangXi=115.13, Def{thick, lush, in clusters}
79FF CJK UNIFIED IDEOGRAPH-#79FF, IRGKangXi=0853.090, RSKangXi=115.7
7A00 CJK UNIFIED IDEOGRAPH-#7A00, IRGKangXi=0853.100, RSKangXi=115.7, Def{rare, unusual, scarce; sparse}
7A01 CJK UNIFIED IDEOGRAPH-#7A01, IRGKangXi=0853.120, RSKangXi=115.7
7A02 CJK UNIFIED IDEOGRAPH-#7A02, IRGKangXi=0853.130, RSKangXi=115.7, Def{grass; weeds}
7A03 CJK UNIFIED IDEOGRAPH-#7A03, IRGKangXi=0853.200, RSKangXi=115.7
7A04 CJK UNIFIED IDEOGRAPH-#7A04, IRGKangXi=0853.210, RSKangXi=115.7
7A05 CJK UNIFIED IDEOGRAPH-#7A05, IRGKangXi=0853.220, RSKangXi=115.7, Def{taxes, revenue, duty; tax}
7A06 CJK UNIFIED IDEOGRAPH-#7A06, IRGKangXi=0853.230, RSKangXi=115.6, Def{wild grain}
7A07 CJK UNIFIED IDEOGRAPH-#7A07, IRGKangXi=0854.020, RSKangXi=115.7, Def{to bind, as faggots of sheaves}
7A08 CJK UNIFIED IDEOGRAPH-#7A08, IRGKangXi=0854.030, RSKangXi=115.7, Def{stalk of grain; straw}
7A09 CJK UNIFIED IDEOGRAPH-#7A09, IRGKangXi=0854.040, RSKangXi=115.7, Def{non-glutinous rice}
7A0A CJK UNIFIED IDEOGRAPH-#7A0A, IRGKangXi=0854.080, RSKangXi=115.7, Def{darnels, tares}
7A0B CJK UNIFIED IDEOGRAPH-#7A0B, IRGKangXi=0854.100, RSKangXi=115.7, Def{journey, trip; schedule, agenda}
7A0C CJK UNIFIED IDEOGRAPH-#7A0C, IRGKangXi=0854.110, RSKangXi=115.7, Def{glutinous rice}
7A0D CJK UNIFIED IDEOGRAPH-#7A0D, IRGKangXi=0854.120, RSKangXi=115.7, Def{little, slightly; rather}
7A0E CJK UNIFIED IDEOGRAPH-#7A0E, IRGKangXi=0854.201, RSKangXi=115.7, Def{taxes}
7A0F CJK UNIFIED IDEOGRAPH-#7A0F, IRGKangXi=0854.210, RSKangXi=115.8, Def{a kind of rice plant; shaking and waving of the rice plant}
7A10 CJK UNIFIED IDEOGRAPH-#7A10, IRGKangXi=0854.270, RSKangXi=115.8
7A11 CJK UNIFIED IDEOGRAPH-#7A11, IRGKangXi=0854.290, RSKangXi=115.8, Def{rice}
7A12 CJK UNIFIED IDEOGRAPH-#7A12, IRGKangXi=0854.300, RSKangXi=115.8
7A13 CJK UNIFIED IDEOGRAPH-#7A13, IRGKangXi=0854.330, RSKangXi=115.8
7A14 CJK UNIFIED IDEOGRAPH-#7A14, IRGKangXi=0854.340, RSKangXi=115.8, Def{ripe grain; harvest; to know, be familiar with}
7A15 CJK UNIFIED IDEOGRAPH-#7A15, IRGKangXi=0854.350, RSKangXi=115.8
7A16 CJK UNIFIED IDEOGRAPH-#7A16, IRGKangXi=0855.010, RSKangXi=115.8
7A17 CJK UNIFIED IDEOGRAPH-#7A17, IRGKangXi=0855.020, RSKangXi=115.8, Def{darnels, weeds, tares small}
7A18 CJK UNIFIED IDEOGRAPH-#7A18, IRGKangXi=0855.070, RSKangXi=115.8, Def{a full year, an anniversary}
7A19 CJK UNIFIED IDEOGRAPH-#7A19, IRGKangXi=0855.080, RSKangXi=115.8, Def{grain ready for grinding}
7A1A CJK UNIFIED IDEOGRAPH-#7A1A, IRGKangXi=0855.090, RSKangXi=115.8, Def{young, immature; childhood}
7A1B CJK UNIFIED IDEOGRAPH-#7A1B, IRGKangXi=0855.100, RSKangXi=115.8, Def{bind}
7A1C CJK UNIFIED IDEOGRAPH-#7A1C, IRGKangXi=0855.120, RSKangXi=115.8, Def{corner, edge, angle; square block}
7A1D CJK UNIFIED IDEOGRAPH-#7A1D, IRGKangXi=0855.140, RSKangXi=115.8
7A1E CJK UNIFIED IDEOGRAPH-#7A1E, IRGKangXi=0855.150, RSKangXi=115.8, Def{grain ready for grinding; grain}
7A1F CJK UNIFIED IDEOGRAPH-#7A1F, IRGKangXi=0855.160, RSKangXi=115.8, Def{report to, petition}
7A20 CJK UNIFIED IDEOGRAPH-#7A20, IRGKangXi=0855.190, RSKangXi=115.8, Def{dense, crowded, packed; soupy}
7A21 CJK UNIFIED IDEOGRAPH-#7A21, IRGKangXi=0855.200, RSKangXi=115.8
7A22 CJK UNIFIED IDEOGRAPH-#7A22, IRGKangXi=0855.210, RSKangXi=115.8
7A23 CJK UNIFIED IDEOGRAPH-#7A23, IRGKangXi=0855.311, RSKangXi=195.5, Def{revive, to rise again; collect}
7A24 CJK UNIFIED IDEOGRAPH-#7A24, IRGKangXi=0855.311, RSKangXi=115.8
7A25 CJK UNIFIED IDEOGRAPH-#7A25, IRGKangXi=0855.311, RSKangXi=72.9
7A26 CJK UNIFIED IDEOGRAPH-#7A26, IRGKangXi=0855.330, RSKangXi=115.9
7A27 CJK UNIFIED IDEOGRAPH-#7A27, IRGKangXi=0855.380, RSKangXi=115.9
7A28 CJK UNIFIED IDEOGRAPH-#7A28, IRGKangXi=0855.390, RSKangXi=115.9
7A29 CJK UNIFIED IDEOGRAPH-#7A29, IRGKangXi=0855.410, RSKangXi=115.9
7A2A CJK UNIFIED IDEOGRAPH-#7A2A, IRGKangXi=0855.420, RSKangXi=115.9
7A2B CJK UNIFIED IDEOGRAPH-#7A2B, IRGKangXi=0856.060, RSKangXi=115.9
7A2C CJK UNIFIED IDEOGRAPH-#7A2C, IRGKangXi=0856.080, RSKangXi=115.9, Def{glutinous, sticky}
7A2D CJK UNIFIED IDEOGRAPH-#7A2D, IRGKangXi=0856.090, RSKangXi=115.9, Def{stalk of grain, rice, corn, hemp}
7A2E CJK UNIFIED IDEOGRAPH-#7A2E, IRGKangXi=0856.160, RSKangXi=115.9, Def{seed; race; offspring; to plant}
7A2F CJK UNIFIED IDEOGRAPH-#7A2F, IRGKangXi=0856.210, RSKangXi=115.9
7A30 CJK UNIFIED IDEOGRAPH-#7A30, IRGKangXi=0856.230, RSKangXi=115.9
7A31 CJK UNIFIED IDEOGRAPH-#7A31, IRGKangXi=0856.240, RSKangXi=115.9, Def{call; name, brand; address; say}
7A32 CJK UNIFIED IDEOGRAPH-#7A32, IRGKangXi=0856.321, RSKangXi=115.9, Def{rice growing in field, rice plant}
7A33 CJK UNIFIED IDEOGRAPH-#7A33, IRGKangXi=0856.321, RSKangXi=115.9, Def{stable, firm, solid, steady}
7A34 CJK UNIFIED IDEOGRAPH-#7A34, IRGKangXi=0857.070, RSKangXi=115.10
7A35 CJK UNIFIED IDEOGRAPH-#7A35, IRGKangXi=0857.160, RSKangXi=115.10
7A36 CJK UNIFIED IDEOGRAPH-#7A36, IRGKangXi=0857.170, RSKangXi=115.10
7A37 CJK UNIFIED IDEOGRAPH-#7A37, IRGKangXi=0857.190, RSKangXi=115.10, Def{god of cereals; minister of agriculture}
7A38 CJK UNIFIED IDEOGRAPH-#7A38, IRGKangXi=0857.210, RSKangXi=115.10
7A39 CJK UNIFIED IDEOGRAPH-#7A39, IRGKangXi=0857.250, RSKangXi=115.10
7A3A CJK UNIFIED IDEOGRAPH-#7A3A, IRGKangXi=0857.260, RSKangXi=115.10, Def{variant of 穉 U+7A49, young grain; young, tender}
7A3B CJK UNIFIED IDEOGRAPH-#7A3B, IRGKangXi=0857.290, RSKangXi=115.10, Def{rice growing in field, rice plant}
7A3C CJK UNIFIED IDEOGRAPH-#7A3C, IRGKangXi=0857.300, RSKangXi=115.10, Def{sow grain; sheaves of grain}
7A3D CJK UNIFIED IDEOGRAPH-#7A3D, IRGKangXi=0858.131, RSKangXi=115.10, Def{examine, investigate; delay}
7A3E CJK UNIFIED IDEOGRAPH-#7A3E, IRGKangXi=0858.030, RSKangXi=115.10, Def{draft, manuscript, rough copy}
7A3F CJK UNIFIED IDEOGRAPH-#7A3F, IRGKangXi=0858.040, RSKangXi=115.10, Def{draft, manuscript, rough copy}
7A40 CJK UNIFIED IDEOGRAPH-#7A40, IRGKangXi=0858.050, RSKangXi=115.10, Def{corn, grain, cereal; lucky}
7A41 CJK UNIFIED IDEOGRAPH-#7A41, IRGKangXi=0858.070, RSKangXi=115.10
7A42 CJK UNIFIED IDEOGRAPH-#7A42, IRGKangXi=0858.131, RSKangXi=115.10, Def{ear of grain; tassel; Guangzhou}
7A43 CJK UNIFIED IDEOGRAPH-#7A43, IRGKangXi=0858.131, RSKangXi=115.10
7A44 CJK UNIFIED IDEOGRAPH-#7A44, IRGKangXi=0858.250, RSKangXi=115.11, Def{panicled millet}
7A45 CJK UNIFIED IDEOGRAPH-#7A45, IRGKangXi=0859.020, RSKangXi=115.11, Def{chaff, bran, husks of grain, from which comes: --poor, remiss}
7A46 CJK UNIFIED IDEOGRAPH-#7A46, IRGKangXi=0859.040, RSKangXi=115.11, Def{majestic, solemn, reverent; calm}
7A47 CJK UNIFIED IDEOGRAPH-#7A47, IRGKangXi=0859.130, RSKangXi=115.11, Def{deccan grass, a barnyard grass}
7A48 CJK UNIFIED IDEOGRAPH-#7A48, IRGKangXi=0859.140, RSKangXi=115.11, Def{millet}
7A49 CJK UNIFIED IDEOGRAPH-#7A49, IRGKangXi=0859.180, RSKangXi=115.12, Def{young grain; young, tender}
7A4A CJK UNIFIED IDEOGRAPH-#7A4A, IRGKangXi=0859.190, RSKangXi=115.11, Def{plough deep; sown slowly}
7A4B CJK UNIFIED IDEOGRAPH-#7A4B, IRGKangXi=0859.200, RSKangXi=115.11, Def{rice}
7A4C CJK UNIFIED IDEOGRAPH-#7A4C, IRGKangXi=0859.210, RSKangXi=115.11, Def{revive, to rise again; collect}
7A4D CJK UNIFIED IDEOGRAPH-#7A4D, IRGKangXi=0859.240, RSKangXi=115.11, Def{accumulate, store up, amass}
7A4E CJK UNIFIED IDEOGRAPH-#7A4E, IRGKangXi=0859.250, RSKangXi=115.11, Def{rice tassel; sharp point; clever}
7A4F CJK UNIFIED IDEOGRAPH-#7A4F, IRGKangXi=0860.041, RSKangXi=115.11, Def{calm, quiet, peace; moderation}
7A50 CJK UNIFIED IDEOGRAPH-#7A50, IRGKangXi=0860.041, RSKangXi=115.11, Def{fall, autumn}
7A51 CJK UNIFIED IDEOGRAPH-#7A51, IRGKangXi=0860.041, RSKangXi=115.11, Def{farm, harvest grain; stingy}
7A52 CJK UNIFIED IDEOGRAPH-#7A52, IRGKangXi=0860.041, RSKangXi=115.11
7A53 CJK UNIFIED IDEOGRAPH-#7A53, IRGKangXi=0860.050, RSKangXi=115.12
7A54 CJK UNIFIED IDEOGRAPH-#7A54, IRGKangXi=0860.070, RSKangXi=115.12
7A55 CJK UNIFIED IDEOGRAPH-#7A55, IRGKangXi=0860.100, RSKangXi=115.12
7A56 CJK UNIFIED IDEOGRAPH-#7A56, IRGKangXi=0860.150, RSKangXi=115.12
7A57 CJK UNIFIED IDEOGRAPH-#7A57, IRGKangXi=0860.190, RSKangXi=115.12, Def{ear of grain; tassel; Guangzhou}
7A58 CJK UNIFIED IDEOGRAPH-#7A58, IRGKangXi=0860.230, RSKangXi=115.12
7A59 CJK UNIFIED IDEOGRAPH-#7A59, IRGKangXi=0860.240, RSKangXi=115.12
7A5A CJK UNIFIED IDEOGRAPH-#7A5A, IRGKangXi=0860.250, RSKangXi=115.12
7A5B CJK UNIFIED IDEOGRAPH-#7A5B, IRGKangXi=0860.270, RSKangXi=115.12
7A5C CJK UNIFIED IDEOGRAPH-#7A5C, IRGKangXi=0860.290, RSKangXi=115.12, Def{rice}
7A5D CJK UNIFIED IDEOGRAPH-#7A5D, IRGKangXi=0860.311, RSKangXi=115.12
7A5E CJK UNIFIED IDEOGRAPH-#7A5E, IRGKangXi=0860.311, RSKangXi=115.12
7A5F CJK UNIFIED IDEOGRAPH-#7A5F, IRGKangXi=0860.320, RSKangXi=115.13, Def{ear of grain; ripe grain}
7A60 CJK UNIFIED IDEOGRAPH-#7A60, IRGKangXi=0860.410, RSKangXi=115.13, Def{thick, lush, in clusters}
7A61 CJK UNIFIED IDEOGRAPH-#7A61, IRGKangXi=0860.420, RSKangXi=115.13, Def{farm, harvest grain; stingy}
7A62 CJK UNIFIED IDEOGRAPH-#7A62, IRGKangXi=0861.020, RSKangXi=115.13, Def{dirty, unclean; immoral, obscene}
7A63 CJK UNIFIED IDEOGRAPH-#7A63, IRGKangXi=0861.051, RSKangXi=115.13, Def{stalks of grain; lush, abundant}
7A64 CJK UNIFIED IDEOGRAPH-#7A64, IRGKangXi=0861.070, RSKangXi=115.14, Def{glutinous rice}
7A65 CJK UNIFIED IDEOGRAPH-#7A65, IRGKangXi=0861.080, RSKangXi=115.14
7A66 CJK UNIFIED IDEOGRAPH-#7A66, IRGKangXi=0861.090, RSKangXi=115.14
7A67 CJK UNIFIED IDEOGRAPH-#7A67, IRGKangXi=0861.120, RSKangXi=115.14, Def{sheaf}
7A68 CJK UNIFIED IDEOGRAPH-#7A68, IRGKangXi=0861.130, RSKangXi=115.14, Def{ruined, decayed; disintegrate}
7A69 CJK UNIFIED IDEOGRAPH-#7A69, IRGKangXi=0861.140, RSKangXi=115.14, Def{stable, firm, solid, steady}
7A6A CJK UNIFIED IDEOGRAPH-#7A6A, IRGKangXi=0861.150, RSKangXi=115.14, Def{to praise}
7A6B CJK UNIFIED IDEOGRAPH-#7A6B, IRGKangXi=0861.160, RSKangXi=115.14, Def{harvest, cut grain}
7A6C CJK UNIFIED IDEOGRAPH-#7A6C, IRGKangXi=0861.280, RSKangXi=115.15
7A6D CJK UNIFIED IDEOGRAPH-#7A6D, IRGKangXi=0861.300, RSKangXi=115.15, Def{wild grain}
7A6E CJK UNIFIED IDEOGRAPH-#7A6E, IRGKangXi=0861.370, RSKangXi=115.15, Def{weed}
7A6F CJK UNIFIED IDEOGRAPH-#7A6F, IRGKangXi=0861.391, RSKangXi=115.15
7A70 CJK UNIFIED IDEOGRAPH-#7A70, IRGKangXi=0861.460, RSKangXi=115.17, Def{stalks of grain; lush, abundant}
7A71 CJK UNIFIED IDEOGRAPH-#7A71, IRGKangXi=0862.070, RSKangXi=115.18
7A72 CJK UNIFIED IDEOGRAPH-#7A72, IRGKangXi=0862.110, RSKangXi=115.19
7A73 CJK UNIFIED IDEOGRAPH-#7A73, IRGKangXi=0862.120, RSKangXi=115.17
7A74 CJK UNIFIED IDEOGRAPH-#7A74, IRGKangXi=0862.200, RSKangXi=116.0, Def{cave, den, hole; KangXi radical 116}
7A75 CJK UNIFIED IDEOGRAPH-#7A75, IRGKangXi=0862.220, RSKangXi=116.1, Def{deep hollow;, gouge, dig out}
7A76 CJK UNIFIED IDEOGRAPH-#7A76, IRGKangXi=0862.240, RSKangXi=116.2, Def{examine, investigate}
7A77 CJK UNIFIED IDEOGRAPH-#7A77, IRGKangXi=0862.271, RSKangXi=116.2, Def{poor, destitute, impoverished}
7A78 CJK UNIFIED IDEOGRAPH-#7A78, IRGKangXi=0862.280, RSKangXi=116.3, Def{the gloom of the grave a tomb or grave; death}
7A79 CJK UNIFIED IDEOGRAPH-#7A79, IRGKangXi=0862.290, RSKangXi=116.3, Def{high and vast; elevated; arched}
7A7A CJK UNIFIED IDEOGRAPH-#7A7A, IRGKangXi=0863.010, RSKangXi=116.3, Def{empty, hollow, bare, deserted}
7A7B CJK UNIFIED IDEOGRAPH-#7A7B, IRGKangXi=0863.030, RSKangXi=116.3
7A7C CJK UNIFIED IDEOGRAPH-#7A7C, IRGKangXi=0863.110, RSKangXi=116.4
7A7D CJK UNIFIED IDEOGRAPH-#7A7D, IRGKangXi=0863.150, RSKangXi=116.4, Def{hole; pitfall, trap}
7A7E CJK UNIFIED IDEOGRAPH-#7A7E, IRGKangXi=0863.170, RSKangXi=116.4
7A7F CJK UNIFIED IDEOGRAPH-#7A7F, IRGKangXi=0863.180, RSKangXi=116.4, Def{penetrate, pierce, drill; wear}
7A80 CJK UNIFIED IDEOGRAPH-#7A80, IRGKangXi=0863.200, RSKangXi=116.4, Def{to bury}
7A81 CJK UNIFIED IDEOGRAPH-#7A81, IRGKangXi=0863.210, RSKangXi=116.4, Def{suddenly, abruptly, unexpectedly}
7A82 CJK UNIFIED IDEOGRAPH-#7A82, IRGKangXi=0864.010, RSKangXi=116.4
7A83 CJK UNIFIED IDEOGRAPH-#7A83, IRGKangXi=0864.121, RSKangXi=116.4, Def{secretly, stealthily; steal; thief}
7A84 CJK UNIFIED IDEOGRAPH-#7A84, IRGKangXi=0864.140, RSKangXi=116.5, Def{narrow, tight; narrow-minded}
7A85 CJK UNIFIED IDEOGRAPH-#7A85, IRGKangXi=0864.170, RSKangXi=116.5, Def{far, deep; sunken eyes; sad}
7A86 CJK UNIFIED IDEOGRAPH-#7A86, IRGKangXi=0864.180, RSKangXi=116.5, Def{to put a coffin in a grave}
7A87 CJK UNIFIED IDEOGRAPH-#7A87, IRGKangXi=0864.200, RSKangXi=116.5
7A88 CJK UNIFIED IDEOGRAPH-#7A88, IRGKangXi=0864.220, RSKangXi=116.5, Def{obscure, secluded; refined}
7A89 CJK UNIFIED IDEOGRAPH-#7A89, IRGKangXi=0864.230, RSKangXi=116.5, Def{(Cant.) to hide things, to conceal}
7A8A CJK UNIFIED IDEOGRAPH-#7A8A, IRGKangXi=0864.260, RSKangXi=116.5, Def{pit, vault; store in pit; (Cant.) 手窊, the arm}
7A8B CJK UNIFIED IDEOGRAPH-#7A8B, IRGKangXi=0864.280, RSKangXi=116.5
7A8C CJK UNIFIED IDEOGRAPH-#7A8C, IRGKangXi=0864.290, RSKangXi=116.5, Def{pit, vault; store in pit}
7A8D CJK UNIFIED IDEOGRAPH-#7A8D, IRGKangXi=0864.381, RSKangXi=116.5, Def{hole, opening, aperture}
7A8E CJK UNIFIED IDEOGRAPH-#7A8E, IRGKangXi=0864.381, RSKangXi=116.5, Def{deep; distant}
7A8F CJK UNIFIED IDEOGRAPH-#7A8F, IRGKangXi=0865.070, RSKangXi=116.6
7A90 CJK UNIFIED IDEOGRAPH-#7A90, IRGKangXi=0865.080, RSKangXi=116.6
7A91 CJK UNIFIED IDEOGRAPH-#7A91, IRGKangXi=0865.090, RSKangXi=116.6, Def{kiln; coal mine pit}
7A92 CJK UNIFIED IDEOGRAPH-#7A92, IRGKangXi=0865.110, RSKangXi=116.6, Def{stop up, obstruct}
7A93 CJK UNIFIED IDEOGRAPH-#7A93, IRGKangXi=0865.120, RSKangXi=116.6, Def{window}
7A94 CJK UNIFIED IDEOGRAPH-#7A94, IRGKangXi=0865.130, RSKangXi=116.6, Def{corner}
7A95 CJK UNIFIED IDEOGRAPH-#7A95, IRGKangXi=0865.140, RSKangXi=116.6, Def{slender; quiet and modest, charming}
7A96 CJK UNIFIED IDEOGRAPH-#7A96, IRGKangXi=0865.310, RSKangXi=116.7, Def{pit, cellar}
7A97 CJK UNIFIED IDEOGRAPH-#7A97, IRGKangXi=0865.320, RSKangXi=116.7, Def{window}
7A98 CJK UNIFIED IDEOGRAPH-#7A98, IRGKangXi=0865.350, RSKangXi=116.7, Def{embarrassed; hard-pressed}
7A99 CJK UNIFIED IDEOGRAPH-#7A99, IRGKangXi=0866.010, RSKangXi=116.7
7A9A CJK UNIFIED IDEOGRAPH-#7A9A, IRGKangXi=0866.030, RSKangXi=116.7
7A9B CJK UNIFIED IDEOGRAPH-#7A9B, IRGKangXi=0866.260, RSKangXi=116.7
7A9C CJK UNIFIED IDEOGRAPH-#7A9C, IRGKangXi=0866.281, RSKangXi=116.7, Def{run away; revise, edit; expel}
7A9D CJK UNIFIED IDEOGRAPH-#7A9D, IRGKangXi=0866.281, RSKangXi=116.7, Def{nest; cave, den; hiding place}
7A9E CJK UNIFIED IDEOGRAPH-#7A9E, IRGKangXi=0866.320, RSKangXi=116.8, Def{pit}
7A9F CJK UNIFIED IDEOGRAPH-#7A9F, IRGKangXi=0866.330, RSKangXi=116.8, Def{hole, cave; cellar; underground}
7AA0 CJK UNIFIED IDEOGRAPH-#7AA0, IRGKangXi=0866.370, RSKangXi=116.8, Def{nest; hole, indention; den}
7AA1 CJK UNIFIED IDEOGRAPH-#7AA1, IRGKangXi=0866.390, RSKangXi=116.8
7AA2 CJK UNIFIED IDEOGRAPH-#7AA2, IRGKangXi=0866.400, RSKangXi=116.8
7AA3 CJK UNIFIED IDEOGRAPH-#7AA3, IRGKangXi=0866.420, RSKangXi=116.8, Def{to rush out of a den; rustling, whispering}
7AA4 CJK UNIFIED IDEOGRAPH-#7AA4, IRGKangXi=0866.440, RSKangXi=116.8
7AA5 CJK UNIFIED IDEOGRAPH-#7AA5, IRGKangXi=0866.551, RSKangXi=116.8, Def{peep, watch, spy on, pry}
7AA6 CJK UNIFIED IDEOGRAPH-#7AA6, IRGKangXi=0866.551, RSKangXi=116.8, Def{surname; hole, burrow; corrupt}
7AA7 CJK UNIFIED IDEOGRAPH-#7AA7, IRGKangXi=0866.551, RSKangXi=116.8
7AA8 CJK UNIFIED IDEOGRAPH-#7AA8, IRGKangXi=0866.590, RSKangXi=116.9, Def{a cellar, a store-room}
7AA9 CJK UNIFIED IDEOGRAPH-#7AA9, IRGKangXi=0866.600, RSKangXi=116.9, Def{nest; cave, den; hiding place}
7AAA CJK UNIFIED IDEOGRAPH-#7AAA, IRGKangXi=0866.610, RSKangXi=116.9, Def{hollow; pit; depression; swamp}
7AAB CJK UNIFIED IDEOGRAPH-#7AAB, IRGKangXi=0866.620, RSKangXi=116.9
7AAC CJK UNIFIED IDEOGRAPH-#7AAC, IRGKangXi=0867.010, RSKangXi=116.9, Def{a small door or window; a hole in the wall to cut through a wall}
7AAD CJK UNIFIED IDEOGRAPH-#7AAD, IRGKangXi=0867.091, RSKangXi=116.9, Def{poor, impoverished}
7AAE CJK UNIFIED IDEOGRAPH-#7AAE, IRGKangXi=0867.100, RSKangXi=116.10, Def{poor, destitute, impoverished}
7AAF CJK UNIFIED IDEOGRAPH-#7AAF, IRGKangXi=0867.110, RSKangXi=116.10, Def{kiln; coal mine pit}
7AB0 CJK UNIFIED IDEOGRAPH-#7AB0, IRGKangXi=0867.120, RSKangXi=116.10, Def{brick kiln; furnace; coal mine pit}
7AB1 CJK UNIFIED IDEOGRAPH-#7AB1, IRGKangXi=0867.140, RSKangXi=116.10
7AB2 CJK UNIFIED IDEOGRAPH-#7AB2, IRGKangXi=0867.170, RSKangXi=116.10
7AB3 CJK UNIFIED IDEOGRAPH-#7AB3, IRGKangXi=0867.180, RSKangXi=116.10, Def{dirty, useless, weak, powerless; cracked, a flaw}
7AB4 CJK UNIFIED IDEOGRAPH-#7AB4, IRGKangXi=0867.350, RSKangXi=116.10, Def{glance at, look at; wink at}
7AB5 CJK UNIFIED IDEOGRAPH-#7AB5, IRGKangXi=0867.440, RSKangXi=116.11, Def{deep; distant}
7AB6 CJK UNIFIED IDEOGRAPH-#7AB6, IRGKangXi=0867.460, RSKangXi=116.11, Def{poor, impoverished}
7AB7 CJK UNIFIED IDEOGRAPH-#7AB7, IRGKangXi=0868.010, RSKangXi=116.11
7AB8 CJK UNIFIED IDEOGRAPH-#7AB8, IRGKangXi=0868.030, RSKangXi=116.11, Def{faint sound, whisper}
7AB9 CJK UNIFIED IDEOGRAPH-#7AB9, IRGKangXi=0868.040, RSKangXi=116.11
7ABA CJK UNIFIED IDEOGRAPH-#7ABA, IRGKangXi=0868.050, RSKangXi=116.11, Def{peep, watch, spy on, pry}
7ABB CJK UNIFIED IDEOGRAPH-#7ABB, IRGKangXi=0868.070, RSKangXi=116.11, Def{window}
7ABC CJK UNIFIED IDEOGRAPH-#7ABC, IRGKangXi=0868.170, RSKangXi=116.11
7ABD CJK UNIFIED IDEOGRAPH-#7ABD, IRGKangXi=0868.211, RSKangXi=116.11, Def{empty; vacant}
7ABE CJK UNIFIED IDEOGRAPH-#7ABE, IRGKangXi=0868.250, RSKangXi=116.12, Def{hole; hallow; empty}
7ABF CJK UNIFIED IDEOGRAPH-#7ABF, IRGKangXi=0868.300, RSKangXi=116.12, Def{mine shaft; cavity, hole}
7AC0 CJK UNIFIED IDEOGRAPH-#7AC0, IRGKangXi=0868.320, RSKangXi=116.12
7AC1 CJK UNIFIED IDEOGRAPH-#7AC1, IRGKangXi=0868.330, RSKangXi=116.12, Def{bore}
7AC2 CJK UNIFIED IDEOGRAPH-#7AC2, IRGKangXi=0868.340
7AC3 CJK UNIFIED IDEOGRAPH-#7AC3, IRGKangXi=0868.471, RSKangXi=116.12, Def{furnace; kitchen range}
7AC4 CJK UNIFIED IDEOGRAPH-#7AC4, IRGKangXi=0869.010, RSKangXi=116.13, Def{run away; revise, edit; expel}
7AC5 CJK UNIFIED IDEOGRAPH-#7AC5, IRGKangXi=0869.030, RSKangXi=116.13, Def{hole, opening, aperture}
7AC6 CJK UNIFIED IDEOGRAPH-#7AC6, IRGKangXi=0869.090, RSKangXi=116.14, Def{exhausted; impoverished; poor}
7AC7 CJK UNIFIED IDEOGRAPH-#7AC7, IRGKangXi=0869.180, RSKangXi=116.15, Def{surname; hole, burrow; corrupt}
7AC8 CJK UNIFIED IDEOGRAPH-#7AC8, IRGKangXi=0869.260, RSKangXi=116.16, Def{furnace; kitchen stove}
7AC9 CJK UNIFIED IDEOGRAPH-#7AC9, IRGKangXi=0869.280, RSKangXi=116.16, Def{a hole; a cleft; empty}
7ACA CJK UNIFIED IDEOGRAPH-#7ACA, IRGKangXi=0870.080, RSKangXi=116.17, Def{secretly, stealthily; steal; thief}
7ACB CJK UNIFIED IDEOGRAPH-#7ACB, IRGKangXi=0870.170, RSKangXi=117.0, Def{stand; let stand; establish, set}
7ACC CJK UNIFIED IDEOGRAPH-#7ACC, IRGKangXi=0870.190, RSKangXi=117.2
7ACD CJK UNIFIED IDEOGRAPH-#7ACD, IRGKangXi=0870.201, RSKangXi=117.2, Def{decaliter}
7ACE CJK UNIFIED IDEOGRAPH-#7ACE, IRGKangXi=0870.220, RSKangXi=117.3
7ACF CJK UNIFIED IDEOGRAPH-#7ACF, IRGKangXi=0870.231, RSKangXi=117.3, Def{kiloliter}
7AD0 CJK UNIFIED IDEOGRAPH-#7AD0, IRGKangXi=0870.250, RSKangXi=117.4
7AD1 CJK UNIFIED IDEOGRAPH-#7AD1, IRGKangXi=0870.270, RSKangXi=117.4, Def{be vast and endless; broad}
7AD2 CJK UNIFIED IDEOGRAPH-#7AD2, IRGKangXi=0870.271, RSKangXi=117.4, Def{strange, unusual, uncanny, occult}
7AD3 CJK UNIFIED IDEOGRAPH-#7AD3, IRGKangXi=0870.271, RSKangXi=117.4, Def{milliliter}
7AD4 CJK UNIFIED IDEOGRAPH-#7AD4, IRGKangXi=0870.271, RSKangXi=117.4, Def{litre}
7AD5 CJK UNIFIED IDEOGRAPH-#7AD5, IRGKangXi=0870.271, RSKangXi=117.4, Def{deciliter}
7AD6 CJK UNIFIED IDEOGRAPH-#7AD6, IRGKangXi=0870.271, RSKangXi=117.4, Def{perpendicular, vertical; erect}
7AD7 CJK UNIFIED IDEOGRAPH-#7AD7, IRGKangXi=0870.271, RSKangXi=117.4
7AD8 CJK UNIFIED IDEOGRAPH-#7AD8, IRGKangXi=0870.280, RSKangXi=117.5
7AD9 CJK UNIFIED IDEOGRAPH-#7AD9, IRGKangXi=0870.290, RSKangXi=117.5, Def{stand up; a stand, station}
7ADA CJK UNIFIED IDEOGRAPH-#7ADA, IRGKangXi=0870.310, RSKangXi=117.5, Def{stand and wait for long time}
7ADB CJK UNIFIED IDEOGRAPH-#7ADB, IRGKangXi=0870.330, RSKangXi=117.5
7ADC CJK UNIFIED IDEOGRAPH-#7ADC, IRGKangXi=0870.380, RSKangXi=117.5, Def{dragon; symbolic of emperor}
7ADD CJK UNIFIED IDEOGRAPH-#7ADD, IRGKangXi=0870.390, RSKangXi=117.5, Def{to combine, annex; also, what's more}
7ADE CJK UNIFIED IDEOGRAPH-#7ADE, IRGKangXi=0871.031, RSKangXi=117.5, Def{contend, vie, compete}
7ADF CJK UNIFIED IDEOGRAPH-#7ADF, IRGKangXi=0871.040, RSKangXi=117.6, Def{finally, after all, at last}
7AE0 CJK UNIFIED IDEOGRAPH-#7AE0, IRGKangXi=0871.080, RSKangXi=117.6, Def{composition; chapter, section}
7AE1 CJK UNIFIED IDEOGRAPH-#7AE1, IRGKangXi=0871.121, RSKangXi=117.6, Def{hectoliter}
7AE2 CJK UNIFIED IDEOGRAPH-#7AE2, IRGKangXi=0871.150, RSKangXi=117.7, Def{wait for, wait until, as soon as}
7AE3 CJK UNIFIED IDEOGRAPH-#7AE3, IRGKangXi=0871.180, RSKangXi=117.7, Def{terminate, end, finish; quit}
7AE4 CJK UNIFIED IDEOGRAPH-#7AE4, IRGKangXi=0871.190, RSKangXi=117.7
7AE5 CJK UNIFIED IDEOGRAPH-#7AE5, IRGKangXi=0871.200, RSKangXi=117.7, Def{child, boy, servant boy; virgin}
7AE6 CJK UNIFIED IDEOGRAPH-#7AE6, IRGKangXi=0872.010, RSKangXi=117.7, Def{revere, respect, be in awe of}
7AE7 CJK UNIFIED IDEOGRAPH-#7AE7, IRGKangXi=0872.080, RSKangXi=117.7
7AE8 CJK UNIFIED IDEOGRAPH-#7AE8, IRGKangXi=0872.130, RSKangXi=117.8
7AE9 CJK UNIFIED IDEOGRAPH-#7AE9, IRGKangXi=0872.140, RSKangXi=117.8
7AEA CJK UNIFIED IDEOGRAPH-#7AEA, IRGKangXi=0872.170, RSKangXi=117.8, Def{perpendicular, vertical; erect}
7AEB CJK UNIFIED IDEOGRAPH-#7AEB, IRGKangXi=0872.180, RSKangXi=117.8
7AEC CJK UNIFIED IDEOGRAPH-#7AEC, IRGKangXi=0872.260, RSKangXi=117.9
7AED CJK UNIFIED IDEOGRAPH-#7AED, IRGKangXi=0872.290, RSKangXi=117.9, Def{put forth great effort; exhaust}
7AEE CJK UNIFIED IDEOGRAPH-#7AEE, IRGKangXi=0872.300, RSKangXi=117.11
7AEF CJK UNIFIED IDEOGRAPH-#7AEF, IRGKangXi=0872.320, RSKangXi=117.9, Def{end, extreme; head; beginning}
7AF0 CJK UNIFIED IDEOGRAPH-#7AF0, IRGKangXi=0873.011, RSKangXi=117.9, Def{centiliter}
7AF1 CJK UNIFIED IDEOGRAPH-#7AF1, IRGKangXi=0873.070, RSKangXi=117.11
7AF2 CJK UNIFIED IDEOGRAPH-#7AF2, IRGKangXi=0873.080, RSKangXi=117.12
7AF3 CJK UNIFIED IDEOGRAPH-#7AF3, IRGKangXi=0873.090, RSKangXi=117.12
7AF4 CJK UNIFIED IDEOGRAPH-#7AF4, IRGKangXi=0873.110, RSKangXi=117.12
7AF5 CJK UNIFIED IDEOGRAPH-#7AF5, IRGKangXi=0873.170, RSKangXi=117.13
7AF6 CJK UNIFIED IDEOGRAPH-#7AF6, IRGKangXi=0873.220, RSKangXi=117.15, Def{contend, vie, compete}
7AF7 CJK UNIFIED IDEOGRAPH-#7AF7, IRGKangXi=0873.230, RSKangXi=117.15
7AF8 CJK UNIFIED IDEOGRAPH-#7AF8, IRGKangXi=0873.290, RSKangXi=117.17, Def{contend, vie, compete}
7AF9 CJK UNIFIED IDEOGRAPH-#7AF9, IRGKangXi=0877.010, RSKangXi=118.0, Def{bamboo; flute; KangXi radical 118}
7AFA CJK UNIFIED IDEOGRAPH-#7AFA, IRGKangXi=0877.020, RSKangXi=118.2, Def{India; bamboo; surname}
7AFB CJK UNIFIED IDEOGRAPH-#7AFB, IRGKangXi=0877.040, RSKangXi=118.2
7AFC CJK UNIFIED IDEOGRAPH-#7AFC, IRGKangXi=0877.080, RSKangXi=118.3, Def{bamboo cover for boat}
7AFD CJK UNIFIED IDEOGRAPH-#7AFD, IRGKangXi=0877.110, RSKangXi=118.3, Def{ancient woodwind instrument}
7AFE CJK UNIFIED IDEOGRAPH-#7AFE, IRGKangXi=0878.020, RSKangXi=118.3, Def{flute}
7AFF CJK UNIFIED IDEOGRAPH-#7AFF, IRGKangXi=0878.030, RSKangXi=118.3, Def{bamboo pole; penis}
7B00 CJK UNIFIED IDEOGRAPH-#7B00, IRGKangXi=0878.070, RSKangXi=118.3
7B01 CJK UNIFIED IDEOGRAPH-#7B01, IRGKangXi=0878.081, RSKangXi=118.3
7B02 CJK UNIFIED IDEOGRAPH-#7B02, IRGKangXi=0878.081, RSKangXi=118.3
7B03 CJK UNIFIED IDEOGRAPH-#7B03, IRGKangXi=0878.081, RSKangXi=118.3, Def{deep, true, sincere, genuine}
7B04 CJK UNIFIED IDEOGRAPH-#7B04, IRGKangXi=0878.090, RSKangXi=118.6, Def{hairpin; fifteen year old girl}
7B05 CJK UNIFIED IDEOGRAPH-#7B05, IRGKangXi=0878.110, RSKangXi=118.4
7B06 CJK UNIFIED IDEOGRAPH-#7B06, IRGKangXi=0878.130, RSKangXi=118.4, Def{bamboo fence}
7B07 CJK UNIFIED IDEOGRAPH-#7B07, IRGKangXi=0878.160, RSKangXi=118.4
7B08 CJK UNIFIED IDEOGRAPH-#7B08, IRGKangXi=0878.170, RSKangXi=118.4, Def{bamboo box used carry books}
7B09 CJK UNIFIED IDEOGRAPH-#7B09, IRGKangXi=0878.180, RSKangXi=118.4
7B0A CJK UNIFIED IDEOGRAPH-#7B0A, IRGKangXi=0878.200, RSKangXi=118.4, Def{ladle, bamboo skimmer}
7B0B CJK UNIFIED IDEOGRAPH-#7B0B, IRGKangXi=0878.210, RSKangXi=118.4, Def{bamboo shoots}
7B0C CJK UNIFIED IDEOGRAPH-#7B0C, IRGKangXi=0878.260, RSKangXi=118.4
7B0D CJK UNIFIED IDEOGRAPH-#7B0D, IRGKangXi=0878.270, RSKangXi=118.4
7B0E CJK UNIFIED IDEOGRAPH-#7B0E, IRGKangXi=0878.290, RSKangXi=118.4
7B0F CJK UNIFIED IDEOGRAPH-#7B0F, IRGKangXi=0878.300, RSKangXi=118.4, Def{tablet held by someone having authority}
7B10 CJK UNIFIED IDEOGRAPH-#7B10, IRGKangXi=0879.010, RSKangXi=118.4, Def{bamboos placed across wooden frames on which grain may be stored in damp climates}
7B11 CJK UNIFIED IDEOGRAPH-#7B11, IRGKangXi=0879.030, RSKangXi=118.4, Def{smile, laugh, giggle; snicker}
7B12 CJK UNIFIED IDEOGRAPH-#7B12, IRGKangXi=0879.060, RSKangXi=118.4
7B13 CJK UNIFIED IDEOGRAPH-#7B13, IRGKangXi=0879.070, RSKangXi=118.4, Def{to comb; a fine-toothed comb}
7B14 CJK UNIFIED IDEOGRAPH-#7B14, IRGKangXi=0879.080, RSKangXi=118.4, Def{writing brush; write; stroke}
7B15 CJK UNIFIED IDEOGRAPH-#7B15, IRGKangXi=0879.191, RSKangXi=118.4, Def{bamboo water pipe}
7B16 CJK UNIFIED IDEOGRAPH-#7B16, IRGKangXi=0879.210, RSKangXi=118.5
7B17 CJK UNIFIED IDEOGRAPH-#7B17, IRGKangXi=0879.260, RSKangXi=118.5
7B18 CJK UNIFIED IDEOGRAPH-#7B18, IRGKangXi=0879.270, RSKangXi=118.5
7B19 CJK UNIFIED IDEOGRAPH-#7B19, IRGKangXi=0879.290, RSKangXi=118.5, Def{small gourd-shaped musical instrument}
7B1A CJK UNIFIED IDEOGRAPH-#7B1A, IRGKangXi=0879.310, RSKangXi=118.5
7B1B CJK UNIFIED IDEOGRAPH-#7B1B, IRGKangXi=0879.330, RSKangXi=118.5, Def{bamboo flute; whistle}
7B1C CJK UNIFIED IDEOGRAPH-#7B1C, IRGKangXi=0880.020, RSKangXi=118.5
7B1D CJK UNIFIED IDEOGRAPH-#7B1D, IRGKangXi=0880.030, RSKangXi=118.5
7B1E CJK UNIFIED IDEOGRAPH-#7B1E, IRGKangXi=0880.040, RSKangXi=118.5, Def{bamboo rod used for beatings}
7B1F CJK UNIFIED IDEOGRAPH-#7B1F, IRGKangXi=0880.060, RSKangXi=118.5
7B20 CJK UNIFIED IDEOGRAPH-#7B20, IRGKangXi=0880.070, RSKangXi=118.5, Def{bamboo hat; bamboo covering}
7B21 CJK UNIFIED IDEOGRAPH-#7B21, IRGKangXi=0880.090, RSKangXi=118.5
7B22 CJK UNIFIED IDEOGRAPH-#7B22, IRGKangXi=0880.100, RSKangXi=118.5
7B23 CJK UNIFIED IDEOGRAPH-#7B23, IRGKangXi=0880.110, RSKangXi=118.5
7B24 CJK UNIFIED IDEOGRAPH-#7B24, IRGKangXi=0880.140, RSKangXi=118.5, Def{a broom, a besom}
7B25 CJK UNIFIED IDEOGRAPH-#7B25, IRGKangXi=0880.170, RSKangXi=118.5, Def{a hamper, wicker basket}
7B26 CJK UNIFIED IDEOGRAPH-#7B26, IRGKangXi=0880.180, RSKangXi=118.5, Def{i.d. tag, tally, symbol, charm}
7B27 CJK UNIFIED IDEOGRAPH-#7B27, IRGKangXi=0880.210, RSKangXi=118.5, Def{to entwine around; check (a current) with a weir}
7B28 CJK UNIFIED IDEOGRAPH-#7B28, IRGKangXi=0880.220, RSKangXi=118.5, Def{foolish, stupid, dull; awkward}
7B29 CJK UNIFIED IDEOGRAPH-#7B29, IRGKangXi=0881.010, RSKangXi=118.5
7B2A CJK UNIFIED IDEOGRAPH-#7B2A, IRGKangXi=0881.020, RSKangXi=118.5, Def{a coarse mat of rushes or bamboo}
7B2B CJK UNIFIED IDEOGRAPH-#7B2B, IRGKangXi=0881.030, RSKangXi=118.5, Def{bed boards, sleeping mat}
7B2C CJK UNIFIED IDEOGRAPH-#7B2C, IRGKangXi=0881.040, RSKangXi=118.5, Def{sequence, number; grade, degree}
7B2D CJK UNIFIED IDEOGRAPH-#7B2D, IRGKangXi=0881.050, RSKangXi=118.5, Def{bamboo screen}
7B2E CJK UNIFIED IDEOGRAPH-#7B2E, IRGKangXi=0881.060, RSKangXi=118.5, Def{boards which support tiles on roof}
7B2F CJK UNIFIED IDEOGRAPH-#7B2F, IRGKangXi=0881.070, RSKangXi=118.5, Def{a bird-cage}
7B30 CJK UNIFIED IDEOGRAPH-#7B30, IRGKangXi=0881.080, RSKangXi=118.5, Def{curtain}
7B31 CJK UNIFIED IDEOGRAPH-#7B31, IRGKangXi=0881.090, RSKangXi=118.5, Def{a basket trap for fish, placed in the opening of a weir}
7B32 CJK UNIFIED IDEOGRAPH-#7B32, IRGKangXi=0881.100, RSKangXi=118.5, Def{basket}
7B33 CJK UNIFIED IDEOGRAPH-#7B33, IRGKangXi=0881.110, RSKangXi=118.5, Def{a reed leaf whistle}
7B34 CJK UNIFIED IDEOGRAPH-#7B34, IRGKangXi=0881.120, RSKangXi=118.5, Def{an arrow shaft}
7B35 CJK UNIFIED IDEOGRAPH-#7B35, IRGKangXi=0881.130, RSKangXi=118.5, Def{a bamboo form; a model}
7B36 CJK UNIFIED IDEOGRAPH-#7B36, IRGKangXi=0881.150, RSKangXi=118.5
7B37 CJK UNIFIED IDEOGRAPH-#7B37, IRGKangXi=0881.251, RSKangXi=118.5
7B38 CJK UNIFIED IDEOGRAPH-#7B38, IRGKangXi=0881.251, RSKangXi=118.5, Def{flat basket for grain}
7B39 CJK UNIFIED IDEOGRAPH-#7B39, IRGKangXi=0881.251, RSKangXi=118.5, Def{small bamboo}
7B3A CJK UNIFIED IDEOGRAPH-#7B3A, IRGKangXi=0881.251, RSKangXi=118.5, Def{note, memo; stationery; comments}
7B3B CJK UNIFIED IDEOGRAPH-#7B3B, IRGKangXi=0881.251, RSKangXi=118.5
7B3C CJK UNIFIED IDEOGRAPH-#7B3C, IRGKangXi=0881.251, RSKangXi=118.5, Def{cage; cage-like basket}
7B3D CJK UNIFIED IDEOGRAPH-#7B3D, IRGKangXi=0881.251, RSKangXi=118.5
7B3E CJK UNIFIED IDEOGRAPH-#7B3E, IRGKangXi=0884.181, RSKangXi=118.6, Def{bamboo container for food}
7B3F CJK UNIFIED IDEOGRAPH-#7B3F, IRGKangXi=0882.010, RSKangXi=118.6
7B40 CJK UNIFIED IDEOGRAPH-#7B40, IRGKangXi=0882.040, RSKangXi=118.6
7B41 CJK UNIFIED IDEOGRAPH-#7B41, IRGKangXi=0882.050, RSKangXi=118.6, Def{a bamboo frame on which silkworms spin their cocoons}
7B42 CJK UNIFIED IDEOGRAPH-#7B42, IRGKangXi=0882.110, RSKangXi=118.6
7B43 CJK UNIFIED IDEOGRAPH-#7B43, IRGKangXi=0882.140, RSKangXi=118.6
7B44 CJK UNIFIED IDEOGRAPH-#7B44, IRGKangXi=0882.150, RSKangXi=118.6
7B45 CJK UNIFIED IDEOGRAPH-#7B45, IRGKangXi=0882.180, RSKangXi=118.6, Def{bamboo brush; halberd}
7B46 CJK UNIFIED IDEOGRAPH-#7B46, IRGKangXi=0882.190, RSKangXi=118.6, Def{writing brush; write; stroke}
7B47 CJK UNIFIED IDEOGRAPH-#7B47, IRGKangXi=0882.200, RSKangXi=118.6, Def{bamboo name; bamboo staff}
7B48 CJK UNIFIED IDEOGRAPH-#7B48, IRGKangXi=0882.220, RSKangXi=118.6, Def{arrow end}
7B49 CJK UNIFIED IDEOGRAPH-#7B49, IRGKangXi=0882.240, RSKangXi=118.6, Def{rank, grade; wait; equal; 'etc.'}
7B4A CJK UNIFIED IDEOGRAPH-#7B4A, IRGKangXi=0882.250, RSKangXi=118.6, Def{bamboo rope; bamboo object used}
7B4B CJK UNIFIED IDEOGRAPH-#7B4B, IRGKangXi=0882.260, RSKangXi=118.6, Def{muscles; tendons}
7B4C CJK UNIFIED IDEOGRAPH-#7B4C, IRGKangXi=0882.280, RSKangXi=118.6, Def{bamboo fish trap}
7B4D CJK UNIFIED IDEOGRAPH-#7B4D, IRGKangXi=0883.020, RSKangXi=118.6, Def{bamboo shoot; joint; tendon}
7B4E CJK UNIFIED IDEOGRAPH-#7B4E, IRGKangXi=0883.050, RSKangXi=118.6
7B4F CJK UNIFIED IDEOGRAPH-#7B4F, IRGKangXi=0883.070, RSKangXi=118.6, Def{raft}
7B50 CJK UNIFIED IDEOGRAPH-#7B50, IRGKangXi=0883.080, RSKangXi=118.6, Def{bamboo basket or chest}
7B51 CJK UNIFIED IDEOGRAPH-#7B51, IRGKangXi=0883.090, RSKangXi=118.6, Def{ancient lute; build}
7B52 CJK UNIFIED IDEOGRAPH-#7B52, IRGKangXi=0883.110, RSKangXi=118.6, Def{thick piece of bamboo; pipe}
7B53 CJK UNIFIED IDEOGRAPH-#7B53, IRGKangXi=0883.120, RSKangXi=118.6, Def{a hairpin on which the hair is bound at the back of the head. 15 of age}
7B54 CJK UNIFIED IDEOGRAPH-#7B54, IRGKangXi=0883.130, RSKangXi=118.6, Def{answer, reply; return; assent to}
7B55 CJK UNIFIED IDEOGRAPH-#7B55, IRGKangXi=0883.170, RSKangXi=118.6
7B56 CJK UNIFIED IDEOGRAPH-#7B56, IRGKangXi=0883.180, RSKangXi=118.6, Def{scheme, plan; to whip; urge}
7B57 CJK UNIFIED IDEOGRAPH-#7B57, IRGKangXi=0884.060, RSKangXi=118.6
7B58 CJK UNIFIED IDEOGRAPH-#7B58, IRGKangXi=0884.120, RSKangXi=118.6
7B59 CJK UNIFIED IDEOGRAPH-#7B59, IRGKangXi=0884.181, RSKangXi=118.6
7B5A CJK UNIFIED IDEOGRAPH-#7B5A, IRGKangXi=0884.181, RSKangXi=118.6, Def{wicker, bamboo}
7B5B CJK UNIFIED IDEOGRAPH-#7B5B, IRGKangXi=0884.181, RSKangXi=118.6, Def{sieve, filter, screen; sift}
7B5C CJK UNIFIED IDEOGRAPH-#7B5C, IRGKangXi=0884.181, RSKangXi=118.6, Def{tall bamboo}
7B5D CJK UNIFIED IDEOGRAPH-#7B5D, IRGKangXi=0884.181, RSKangXi=118.6, Def{stringed musical instrument; kite}
7B5E CJK UNIFIED IDEOGRAPH-#7B5E, IRGKangXi=0884.200, RSKangXi=118.7
7B5F CJK UNIFIED IDEOGRAPH-#7B5F, IRGKangXi=0884.210, RSKangXi=118.7
7B60 CJK UNIFIED IDEOGRAPH-#7B60, IRGKangXi=0884.220, RSKangXi=118.7, Def{bamboo skin; bamboo}
7B61 CJK UNIFIED IDEOGRAPH-#7B61, IRGKangXi=0884.260, RSKangXi=118.7
7B62 CJK UNIFIED IDEOGRAPH-#7B62, IRGKangXi=0884.270, RSKangXi=118.7, Def{rake}
7B63 CJK UNIFIED IDEOGRAPH-#7B63, IRGKangXi=0884.310, RSKangXi=118.7
7B64 CJK UNIFIED IDEOGRAPH-#7B64, IRGKangXi=0884.370, RSKangXi=118.7, Def{young bamboo}
7B65 CJK UNIFIED IDEOGRAPH-#7B65, IRGKangXi=0885.040, RSKangXi=118.7, Def{round-shaped bamboo basket for holding rice}
7B66 CJK UNIFIED IDEOGRAPH-#7B66, IRGKangXi=0885.100, RSKangXi=118.7, Def{a key; to be in charge; a pipe}
7B67 CJK UNIFIED IDEOGRAPH-#7B67, IRGKangXi=0885.120, RSKangXi=118.7, Def{bamboo water pipe}
7B68 CJK UNIFIED IDEOGRAPH-#7B68, IRGKangXi=0885.140, RSKangXi=118.7
7B69 CJK UNIFIED IDEOGRAPH-#7B69, IRGKangXi=0885.150, RSKangXi=118.7, Def{bamboo pipe; fish hook}
7B6A CJK UNIFIED IDEOGRAPH-#7B6A, IRGKangXi=0885.170, RSKangXi=118.7
7B6B CJK UNIFIED IDEOGRAPH-#7B6B, IRGKangXi=0885.180, RSKangXi=118.7
7B6C CJK UNIFIED IDEOGRAPH-#7B6C, IRGKangXi=0885.200, RSKangXi=118.7, Def{reed of a loom}
7B6D CJK UNIFIED IDEOGRAPH-#7B6D, IRGKangXi=0885.220, RSKangXi=118.7, Def{an ancient device for working with numbers; count, calculate, figure}
7B6E CJK UNIFIED IDEOGRAPH-#7B6E, IRGKangXi=0885.230, RSKangXi=118.7, Def{divination with stalks of plants; divining rod}
7B6F CJK UNIFIED IDEOGRAPH-#7B6F, IRGKangXi=0885.240, RSKangXi=118.7, Def{chopsticks, tongs}
7B70 CJK UNIFIED IDEOGRAPH-#7B70, IRGKangXi=0885.270, RSKangXi=118.7, Def{cable}
7B71 CJK UNIFIED IDEOGRAPH-#7B71, IRGKangXi=0886.020, RSKangXi=118.7, Def{dwarf bamboo; diminutive in person's name}
7B72 CJK UNIFIED IDEOGRAPH-#7B72, IRGKangXi=0886.030, RSKangXi=118.7, Def{basket, bucket}
7B73 CJK UNIFIED IDEOGRAPH-#7B73, IRGKangXi=0886.040, RSKangXi=118.7
7B74 CJK UNIFIED IDEOGRAPH-#7B74, IRGKangXi=0886.050, RSKangXi=118.7, Def{type of grass used in divination; to divine; pincers}
7B75 CJK UNIFIED IDEOGRAPH-#7B75, IRGKangXi=0886.060, RSKangXi=118.7, Def{feast}
7B76 CJK UNIFIED IDEOGRAPH-#7B76, IRGKangXi=0886.231, RSKangXi=118.7
7B77 CJK UNIFIED IDEOGRAPH-#7B77, IRGKangXi=0886.231, RSKangXi=118.7, Def{chopsticks}
7B78 CJK UNIFIED IDEOGRAPH-#7B78, IRGKangXi=0886.231, RSKangXi=118.7, Def{name of a place in Honan}
7B79 CJK UNIFIED IDEOGRAPH-#7B79, IRGKangXi=0886.231, RSKangXi=118.7, Def{chip, tally, token; raise money}
7B7A CJK UNIFIED IDEOGRAPH-#7B7A, IRGKangXi=0886.231, RSKangXi=118.7, Def{bamboo basket or chest}
7B7B CJK UNIFIED IDEOGRAPH-#7B7B, IRGKangXi=0886.231, RSKangXi=118.7, Def{place name in Hunan province}
7B7C CJK UNIFIED IDEOGRAPH-#7B7C, IRGKangXi=0886.231, RSKangXi=118.7, Def{tall bamboo}
7B7D CJK UNIFIED IDEOGRAPH-#7B7D, IRGKangXi=0886.231, RSKangXi=118.7
7B7E CJK UNIFIED IDEOGRAPH-#7B7E, IRGKangXi=0886.231, RSKangXi=118.7, Def{sign, endorse; slip of paper}
7B7F CJK UNIFIED IDEOGRAPH-#7B7F, IRGKangXi=0886.231, RSKangXi=118.7
7B80 CJK UNIFIED IDEOGRAPH-#7B80, IRGKangXi=0886.231, RSKangXi=118.7, Def{simple, terse, succinct, a letter}
7B81 CJK UNIFIED IDEOGRAPH-#7B81, IRGKangXi=0886.240, RSKangXi=118.8
7B82 CJK UNIFIED IDEOGRAPH-#7B82, IRGKangXi=0886.250, RSKangXi=118.8
7B83 CJK UNIFIED IDEOGRAPH-#7B83, IRGKangXi=0886.270, RSKangXi=118.8
7B84 CJK UNIFIED IDEOGRAPH-#7B84, IRGKangXi=0886.310, RSKangXi=118.8
7B85 CJK UNIFIED IDEOGRAPH-#7B85, IRGKangXi=0886.320, RSKangXi=118.8
7B86 CJK UNIFIED IDEOGRAPH-#7B86, IRGKangXi=0886.340, RSKangXi=118.8, Def{fine-toothed comb; comb hair}
7B87 CJK UNIFIED IDEOGRAPH-#7B87, IRGKangXi=0886.360, RSKangXi=118.8, Def{numerary adjunct, piece; single}
7B88 CJK UNIFIED IDEOGRAPH-#7B88, IRGKangXi=0886.380, RSKangXi=118.8
7B89 CJK UNIFIED IDEOGRAPH-#7B89, IRGKangXi=0887.020, RSKangXi=118.8
7B8A CJK UNIFIED IDEOGRAPH-#7B8A, IRGKangXi=0887.030, RSKangXi=118.8
7B8B CJK UNIFIED IDEOGRAPH-#7B8B, IRGKangXi=0887.040, RSKangXi=118.8, Def{note, memo; stationery; comments}
7B8C CJK UNIFIED IDEOGRAPH-#7B8C, IRGKangXi=0887.110, RSKangXi=118.8
7B8D CJK UNIFIED IDEOGRAPH-#7B8D, IRGKangXi=0887.120, RSKangXi=118.8, Def{hoop; bind, surround}
7B8E CJK UNIFIED IDEOGRAPH-#7B8E, IRGKangXi=0887.140, RSKangXi=118.8, Def{ancient woodwind instrument}
7B8F CJK UNIFIED IDEOGRAPH-#7B8F, IRGKangXi=0887.150, RSKangXi=118.8, Def{stringed musical instrument; kite}
7B90 CJK UNIFIED IDEOGRAPH-#7B90, IRGKangXi=0887.170, RSKangXi=118.8, Def{to draw a bamboo bow or crossbow}
7B91 CJK UNIFIED IDEOGRAPH-#7B91, IRGKangXi=0887.180, RSKangXi=118.8, Def{fan}
7B92 CJK UNIFIED IDEOGRAPH-#7B92, IRGKangXi=0887.210, RSKangXi=118.8, Def{broom}
7B93 CJK UNIFIED IDEOGRAPH-#7B93, IRGKangXi=0887.220, RSKangXi=118.8, Def{book}
7B94 CJK UNIFIED IDEOGRAPH-#7B94, IRGKangXi=0887.240, RSKangXi=118.8, Def{reed screen; frame for growing silkworms}
7B95 CJK UNIFIED IDEOGRAPH-#7B95, IRGKangXi=0887.250, RSKangXi=118.8, Def{sieve; dust pan, garbage bag}
7B96 CJK UNIFIED IDEOGRAPH-#7B96, IRGKangXi=0888.020, RSKangXi=118.8
7B97 CJK UNIFIED IDEOGRAPH-#7B97, IRGKangXi=0888.030, RSKangXi=118.8, Def{count, calculate, figure; plan}
7B98 CJK UNIFIED IDEOGRAPH-#7B98, IRGKangXi=0888.040, RSKangXi=118.8, Def{fine bamboo}
7B99 CJK UNIFIED IDEOGRAPH-#7B99, IRGKangXi=0888.060, RSKangXi=118.8, Def{quiver}
7B9A CJK UNIFIED IDEOGRAPH-#7B9A, IRGKangXi=0888.070, RSKangXi=118.8, Def{brief note; official communique}
7B9B CJK UNIFIED IDEOGRAPH-#7B9B, IRGKangXi=0888.080, RSKangXi=118.8, Def{bugle}
7B9C CJK UNIFIED IDEOGRAPH-#7B9C, IRGKangXi=0888.090, RSKangXi=118.8, Def{ancient string music instrument}
7B9D CJK UNIFIED IDEOGRAPH-#7B9D, IRGKangXi=0888.100, RSKangXi=118.8, Def{tweezers, pliers, tongs, pincers}
7B9E CJK UNIFIED IDEOGRAPH-#7B9E, IRGKangXi=0888.110, RSKangXi=118.8
7B9F CJK UNIFIED IDEOGRAPH-#7B9F, IRGKangXi=0889.010, RSKangXi=118.8
7BA0 CJK UNIFIED IDEOGRAPH-#7BA0, IRGKangXi=0889.020, RSKangXi=118.8, Def{horse whip; flog}
7BA1 CJK UNIFIED IDEOGRAPH-#7BA1, IRGKangXi=0889.060, RSKangXi=118.8, Def{pipe, tube, duct; woodwind music}
7BA2 CJK UNIFIED IDEOGRAPH-#7BA2, IRGKangXi=0889.080, RSKangXi=118.8
7BA3 CJK UNIFIED IDEOGRAPH-#7BA3, IRGKangXi=0889.090, RSKangXi=118.8
7BA4 CJK UNIFIED IDEOGRAPH-#7BA4, IRGKangXi=0889.130, RSKangXi=118.8
7BA5 CJK UNIFIED IDEOGRAPH-#7BA5, IRGKangXi=0889.321, RSKangXi=118.8
7BA6 CJK UNIFIED IDEOGRAPH-#7BA6, IRGKangXi=0889.321, RSKangXi=118.8, Def{bed mat; mat}
7BA7 CJK UNIFIED IDEOGRAPH-#7BA7, IRGKangXi=0889.321, RSKangXi=118.8, Def{rattan box, suitcase, or case}
7BA8 CJK UNIFIED IDEOGRAPH-#7BA8, IRGKangXi=0889.321, RSKangXi=118.8, Def{bamboo sheath, bamboo shoots}
7BA9 CJK UNIFIED IDEOGRAPH-#7BA9, IRGKangXi=0889.321, RSKangXi=118.8, Def{bamboo basket}
7BAA CJK UNIFIED IDEOGRAPH-#7BAA, IRGKangXi=0889.321, RSKangXi=118.8, Def{small bamboo basket for holding}
7BAB CJK UNIFIED IDEOGRAPH-#7BAB, IRGKangXi=0889.321, RSKangXi=118.8, Def{bamboo flute}
7BAC CJK UNIFIED IDEOGRAPH-#7BAC, IRGKangXi=0889.330, RSKangXi=118.9, Def{the cuticle of the bamboo a broad-leaved bamboo}
7BAD CJK UNIFIED IDEOGRAPH-#7BAD, IRGKangXi=0889.340, RSKangXi=118.9, Def{arrow; type of bamboo}
7BAE CJK UNIFIED IDEOGRAPH-#7BAE, IRGKangXi=0890.060, RSKangXi=118.9
7BAF CJK UNIFIED IDEOGRAPH-#7BAF, IRGKangXi=0890.090, RSKangXi=118.9, Def{bamboo palanquin}
7BB0 CJK UNIFIED IDEOGRAPH-#7BB0, IRGKangXi=0890.130, RSKangXi=118.9
7BB1 CJK UNIFIED IDEOGRAPH-#7BB1, IRGKangXi=0890.160, RSKangXi=118.9, Def{case, box, chest, trunk}
7BB2 CJK UNIFIED IDEOGRAPH-#7BB2, IRGKangXi=0890.190, RSKangXi=118.9
7BB3 CJK UNIFIED IDEOGRAPH-#7BB3, IRGKangXi=0890.200, RSKangXi=118.9, Def{bamboo mat used to protect carriage passengers from dust (vulgar form)}
7BB4 CJK UNIFIED IDEOGRAPH-#7BB4, IRGKangXi=0890.210, RSKangXi=118.9, Def{needle, probe; admon}
7BB5 CJK UNIFIED IDEOGRAPH-#7BB5, IRGKangXi=0890.230, RSKangXi=118.9
7BB6 CJK UNIFIED IDEOGRAPH-#7BB6, IRGKangXi=0890.250, RSKangXi=118.9
7BB7 CJK UNIFIED IDEOGRAPH-#7BB7, IRGKangXi=0890.280, RSKangXi=118.9
7BB8 CJK UNIFIED IDEOGRAPH-#7BB8, IRGKangXi=0891.030, RSKangXi=118.9, Def{chopsticks}
7BB9 CJK UNIFIED IDEOGRAPH-#7BB9, IRGKangXi=0891.060, RSKangXi=118.9
7BBA CJK UNIFIED IDEOGRAPH-#7BBA, IRGKangXi=0891.070, RSKangXi=118.9
7BBB CJK UNIFIED IDEOGRAPH-#7BBB, IRGKangXi=0891.080, RSKangXi=118.9
7BBC CJK UNIFIED IDEOGRAPH-#7BBC, IRGKangXi=0891.090, RSKangXi=118.9
7BBD CJK UNIFIED IDEOGRAPH-#7BBD, IRGKangXi=0891.110, RSKangXi=118.9
7BBE CJK UNIFIED IDEOGRAPH-#7BBE, IRGKangXi=0891.120, RSKangXi=118.9, Def{musical instrument like pan-pipes, bamboo flute}
7BBF CJK UNIFIED IDEOGRAPH-#7BBF, IRGKangXi=0891.200, RSKangXi=118.9
7BC0 CJK UNIFIED IDEOGRAPH-#7BC0, IRGKangXi=0891.240, RSKangXi=118.7, Def{knot, node, joint; section}
7BC1 CJK UNIFIED IDEOGRAPH-#7BC1, IRGKangXi=0892.060, RSKangXi=118.9, Def{bamboo grove; bamboo}
7BC2 CJK UNIFIED IDEOGRAPH-#7BC2, IRGKangXi=0892.070, RSKangXi=118.9
7BC3 CJK UNIFIED IDEOGRAPH-#7BC3, IRGKangXi=0892.080, RSKangXi=118.9
7BC4 CJK UNIFIED IDEOGRAPH-#7BC4, IRGKangXi=0892.100, RSKangXi=118.9, Def{pattern, model, rule, law}
7BC5 CJK UNIFIED IDEOGRAPH-#7BC5, IRGKangXi=0892.120, RSKangXi=118.9
7BC6 CJK UNIFIED IDEOGRAPH-#7BC6, IRGKangXi=0892.130, RSKangXi=118.9, Def{seal script; seal, official stamp}
7BC7 CJK UNIFIED IDEOGRAPH-#7BC7, IRGKangXi=0892.140, RSKangXi=118.9, Def{chapter, section, essay, article}
7BC8 CJK UNIFIED IDEOGRAPH-#7BC8, IRGKangXi=0892.150, RSKangXi=118.9
7BC9 CJK UNIFIED IDEOGRAPH-#7BC9, IRGKangXi=0892.180, RSKangXi=118.10, Def{build, erect; building}
7BCA CJK UNIFIED IDEOGRAPH-#7BCA, IRGKangXi=0892.240, RSKangXi=118.9
7BCB CJK UNIFIED IDEOGRAPH-#7BCB, IRGKangXi=0893.010, RSKangXi=118.9, Def{ratton box, suitcase, or case}
7BCC CJK UNIFIED IDEOGRAPH-#7BCC, IRGKangXi=0893.020, RSKangXi=118.9, Def{ancient music instrument; harp}
7BCD CJK UNIFIED IDEOGRAPH-#7BCD, IRGKangXi=0893.040, RSKangXi=118.9
7BCE CJK UNIFIED IDEOGRAPH-#7BCE, IRGKangXi=0893.220, RSKangXi=118.9
7BCF CJK UNIFIED IDEOGRAPH-#7BCF, IRGKangXi=0893.291, RSKangXi=118.9, Def{inlay, set in; fall into; rugged}
7BD0 CJK UNIFIED IDEOGRAPH-#7BD0, IRGKangXi=0893.291, RSKangXi=118.9
7BD1 CJK UNIFIED IDEOGRAPH-#7BD1, IRGKangXi=0893.291, RSKangXi=118.9, Def{a bamboo basket for carrying earth}
7BD2 CJK UNIFIED IDEOGRAPH-#7BD2, IRGKangXi=0893.291, RSKangXi=118.9
7BD3 CJK UNIFIED IDEOGRAPH-#7BD3, IRGKangXi=0893.291, RSKangXi=118.9, Def{bamboo basket}
7BD4 CJK UNIFIED IDEOGRAPH-#7BD4, IRGKangXi=0893.300, RSKangXi=118.10, Def{tall bamboo}
7BD5 CJK UNIFIED IDEOGRAPH-#7BD5, IRGKangXi=0893.320, RSKangXi=118.10
7BD6 CJK UNIFIED IDEOGRAPH-#7BD6, IRGKangXi=0893.370, RSKangXi=118.10
7BD7 CJK UNIFIED IDEOGRAPH-#7BD7, IRGKangXi=0893.390, RSKangXi=118.10
7BD8 CJK UNIFIED IDEOGRAPH-#7BD8, IRGKangXi=0893.400, RSKangXi=118.10, Def{a utensil used to filter wine; a filter}
7BD9 CJK UNIFIED IDEOGRAPH-#7BD9, IRGKangXi=0893.440, RSKangXi=118.10, Def{pole used punt boat}
7BDA CJK UNIFIED IDEOGRAPH-#7BDA, IRGKangXi=0893.450, RSKangXi=118.10, Def{round or oval covered-baskets with short legs}
7BDB CJK UNIFIED IDEOGRAPH-#7BDB, IRGKangXi=0894.030, RSKangXi=118.10, Def{cuticle of bamboo plant}
7BDC CJK UNIFIED IDEOGRAPH-#7BDC, IRGKangXi=0894.040, RSKangXi=118.10
7BDD CJK UNIFIED IDEOGRAPH-#7BDD, IRGKangXi=0894.050, RSKangXi=118.10, Def{bamboo basket; bamboo frame}
7BDE CJK UNIFIED IDEOGRAPH-#7BDE, IRGKangXi=0894.060, RSKangXi=118.10
7BDF CJK UNIFIED IDEOGRAPH-#7BDF, IRGKangXi=0894.110, RSKangXi=118.10
7BE0 CJK UNIFIED IDEOGRAPH-#7BE0, IRGKangXi=0894.130, RSKangXi=118.10, Def{dwarf bamboo; diminutive in person's name}
7BE1 CJK UNIFIED IDEOGRAPH-#7BE1, IRGKangXi=0894.150, RSKangXi=118.10, Def{usurp}
7BE2 CJK UNIFIED IDEOGRAPH-#7BE2, IRGKangXi=0894.180, RSKangXi=118.10, Def{the name of bamboo hat}
7BE3 CJK UNIFIED IDEOGRAPH-#7BE3, IRGKangXi=0894.210, RSKangXi=118.10
7BE4 CJK UNIFIED IDEOGRAPH-#7BE4, IRGKangXi=0894.290, RSKangXi=118.10, Def{deep, true, sincere, genuine}
7BE5 CJK UNIFIED IDEOGRAPH-#7BE5, IRGKangXi=0894.370, RSKangXi=118.10, Def{bugle, 觱篥 bìlì Tatar (Tartar) horn}
7BE6 CJK UNIFIED IDEOGRAPH-#7BE6, IRGKangXi=0895.040, RSKangXi=118.10, Def{fine-toothed comb; comb hair}
7BE7 CJK UNIFIED IDEOGRAPH-#7BE7, IRGKangXi=0895.050, RSKangXi=118.10
7BE8 CJK UNIFIED IDEOGRAPH-#7BE8, IRGKangXi=0895.060, RSKangXi=118.10, Def{coarse bamboo mat; ugly}
7BE9 CJK UNIFIED IDEOGRAPH-#7BE9, IRGKangXi=0895.070, RSKangXi=118.10, Def{sieve, filter, screen; sift}
7BEA CJK UNIFIED IDEOGRAPH-#7BEA, IRGKangXi=0895.080, RSKangXi=118.10, Def{a bamboo flute with seven holes}
7BEB CJK UNIFIED IDEOGRAPH-#7BEB, IRGKangXi=0895.110, RSKangXi=118.10
7BEC CJK UNIFIED IDEOGRAPH-#7BEC, IRGKangXi=0895.180, RSKangXi=118.10
7BED CJK UNIFIED IDEOGRAPH-#7BED, IRGKangXi=0895.190, RSKangXi=118.10, Def{cage; cage-like basket}
7BEE CJK UNIFIED IDEOGRAPH-#7BEE, IRGKangXi=0895.341, RSKangXi=118.10, Def{basket}
7BEF CJK UNIFIED IDEOGRAPH-#7BEF, IRGKangXi=0895.341, RSKangXi=118.10
7BF0 CJK UNIFIED IDEOGRAPH-#7BF0, IRGKangXi=0895.350, RSKangXi=118.11, Def{a bamboo basket}
7BF1 CJK UNIFIED IDEOGRAPH-#7BF1, IRGKangXi=0895.360, RSKangXi=118.11, Def{bamboo or wooden fence; hedge}
7BF2 CJK UNIFIED IDEOGRAPH-#7BF2, IRGKangXi=0895.370, RSKangXi=118.11, Def{broomstick}
7BF3 CJK UNIFIED IDEOGRAPH-#7BF3, IRGKangXi=0895.390, RSKangXi=118.11, Def{wicker, bamboo}
7BF4 CJK UNIFIED IDEOGRAPH-#7BF4, IRGKangXi=0895.420, RSKangXi=118.11, Def{bamboo flute; whistle}
7BF5 CJK UNIFIED IDEOGRAPH-#7BF5, IRGKangXi=0896.020, RSKangXi=118.11
7BF6 CJK UNIFIED IDEOGRAPH-#7BF6, IRGKangXi=0896.070, RSKangXi=118.11
7BF7 CJK UNIFIED IDEOGRAPH-#7BF7, IRGKangXi=0896.080, RSKangXi=118.11, Def{awning, covering; sail; boat}
7BF8 CJK UNIFIED IDEOGRAPH-#7BF8, IRGKangXi=0896.110, RSKangXi=118.11, Def{a basket, hod, scuttle; a hairclasp}
7BF9 CJK UNIFIED IDEOGRAPH-#7BF9, IRGKangXi=0896.130, RSKangXi=118.11, Def{to collect; edit; a bamboo basket}
7BFA CJK UNIFIED IDEOGRAPH-#7BFA, IRGKangXi=0896.160, RSKangXi=118.11
7BFB CJK UNIFIED IDEOGRAPH-#7BFB, IRGKangXi=0896.170, RSKangXi=118.11
7BFC CJK UNIFIED IDEOGRAPH-#7BFC, IRGKangXi=0896.180, RSKangXi=118.11, Def{mountain sedan chair; (Cant.) a simple container without a cover}
7BFD CJK UNIFIED IDEOGRAPH-#7BFD, IRGKangXi=0896.190, RSKangXi=118.11
7BFE CJK UNIFIED IDEOGRAPH-#7BFE, IRGKangXi=0896.200, RSKangXi=118.11, Def{bamboo splints or slats}
7BFF CJK UNIFIED IDEOGRAPH-#7BFF, IRGKangXi=0896.220, RSKangXi=118.11
7C00 CJK UNIFIED IDEOGRAPH-#7C00, IRGKangXi=0896.230, RSKangXi=118.11, Def{bed mat; mat}
7C01 CJK UNIFIED IDEOGRAPH-#7C01, IRGKangXi=0896.240, RSKangXi=118.11, Def{sieve; to sift, to strain}
7C02 CJK UNIFIED IDEOGRAPH-#7C02, IRGKangXi=0896.250, RSKangXi=118.11
7C03 CJK UNIFIED IDEOGRAPH-#7C03, IRGKangXi=0897.070, RSKangXi=118.11, Def{side room}
7C04 CJK UNIFIED IDEOGRAPH-#7C04, IRGKangXi=0897.090, RSKangXi=118.11
7C05 CJK UNIFIED IDEOGRAPH-#7C05, IRGKangXi=0897.140, RSKangXi=118.11
7C06 CJK UNIFIED IDEOGRAPH-#7C06, IRGKangXi=0898.371, RSKangXi=118.11, Def{reed}
7C07 CJK UNIFIED IDEOGRAPH-#7C07, IRGKangXi=0897.160, RSKangXi=118.11, Def{swarm, crowd together, cluster}
7C08 CJK UNIFIED IDEOGRAPH-#7C08, IRGKangXi=0897.170, RSKangXi=118.11, Def{bamboo mat used to protect carriage passengers from dust}
7C09 CJK UNIFIED IDEOGRAPH-#7C09, IRGKangXi=0897.230, RSKangXi=118.11, Def{deputy, subordinate; concubine}
7C0A CJK UNIFIED IDEOGRAPH-#7C0A, IRGKangXi=0897.240, RSKangXi=118.11
7C0B CJK UNIFIED IDEOGRAPH-#7C0B, IRGKangXi=0897.270, RSKangXi=118.11, Def{a square basket of bamboo for holding grain used at sacrifices, feast}
7C0C CJK UNIFIED IDEOGRAPH-#7C0C, IRGKangXi=0897.360, RSKangXi=118.11, Def{(of flower petals) falling}
7C0D CJK UNIFIED IDEOGRAPH-#7C0D, IRGKangXi=0897.370, RSKangXi=118.11, Def{bamboo basket}
7C0E CJK UNIFIED IDEOGRAPH-#7C0E, IRGKangXi=0897.380, RSKangXi=118.11
7C0F CJK UNIFIED IDEOGRAPH-#7C0F, IRGKangXi=0898.010, RSKangXi=118.11, Def{a box, a basket}
7C10 CJK UNIFIED IDEOGRAPH-#7C10, IRGKangXi=0898.280, RSKangXi=118.11
7C11 CJK UNIFIED IDEOGRAPH-#7C11, IRGKangXi=0898.350, RSKangXi=118.10, Def{a coat raincoat}
7C12 CJK UNIFIED IDEOGRAPH-#7C12, IRGKangXi=0898.371, RSKangXi=118.11, Def{usurp}
7C13 CJK UNIFIED IDEOGRAPH-#7C13, IRGKangXi=0898.371, RSKangXi=118.11, Def{a bamboo whisk; the broken end of a bamboo stalk}
7C14 CJK UNIFIED IDEOGRAPH-#7C14, IRGKangXi=0898.371, RSKangXi=118.11, Def{a coat raincoat}
7C15 CJK UNIFIED IDEOGRAPH-#7C15, IRGKangXi=0898.371, Def{(Cant.) thorn}
7C16 CJK UNIFIED IDEOGRAPH-#7C16, IRGKangXi=0898.371, RSKangXi=118.11, Def{bamboo trap for catching fish}
7C17 CJK UNIFIED IDEOGRAPH-#7C17, IRGKangXi=0898.371, RSKangXi=118.11, Def{a weir, fish trap, fish pond}
7C18 CJK UNIFIED IDEOGRAPH-#7C18, IRGKangXi=0898.371, Def{musical instrument like pan-pipes, bamboo flute}
7C19 CJK UNIFIED IDEOGRAPH-#7C19, IRGKangXi=0898.380, RSKangXi=118.12
7C1A CJK UNIFIED IDEOGRAPH-#7C1A, IRGKangXi=0898.390
7C1B CJK UNIFIED IDEOGRAPH-#7C1B, IRGKangXi=0898.440, RSKangXi=118.12, Def{sieve; to sift; to strain}
7C1C CJK UNIFIED IDEOGRAPH-#7C1C, IRGKangXi=0898.470, RSKangXi=118.12, Def{bamboo}
7C1D CJK UNIFIED IDEOGRAPH-#7C1D, IRGKangXi=0898.520, RSKangXi=118.12
7C1E CJK UNIFIED IDEOGRAPH-#7C1E, IRGKangXi=0899.010, RSKangXi=118.12, Def{small bamboo basket for holding}
7C1F CJK UNIFIED IDEOGRAPH-#7C1F, IRGKangXi=0899.020, RSKangXi=118.12, Def{bamboo mat}
7C20 CJK UNIFIED IDEOGRAPH-#7C20, IRGKangXi=0899.090, RSKangXi=118.12, Def{an ancient vessel used for holding boiled grain}
7C21 CJK UNIFIED IDEOGRAPH-#7C21, IRGKangXi=0901.281, RSKangXi=118.12, Def{simple, terse, succinct; letter}
7C22 CJK UNIFIED IDEOGRAPH-#7C22, IRGKangXi=0899.160, RSKangXi=118.12
7C23 CJK UNIFIED IDEOGRAPH-#7C23, IRGKangXi=0899.190, RSKangXi=118.12, Def{a bamboo basket for carrying earth}
7C24 CJK UNIFIED IDEOGRAPH-#7C24, IRGKangXi=0899.220, RSKangXi=118.12
7C25 CJK UNIFIED IDEOGRAPH-#7C25, IRGKangXi=0899.230, RSKangXi=118.12, Def{a large pipe; a farm tool}
7C26 CJK UNIFIED IDEOGRAPH-#7C26, IRGKangXi=0899.250, RSKangXi=118.12, Def{large umbrella with a long handle, used for street stalls}
7C27 CJK UNIFIED IDEOGRAPH-#7C27, IRGKangXi=0900.110, RSKangXi=118.12, Def{reed of woodwind instrument}
7C28 CJK UNIFIED IDEOGRAPH-#7C28, IRGKangXi=0900.240, RSKangXi=118.12, Def{a beam for hanging bells or drums}
7C29 CJK UNIFIED IDEOGRAPH-#7C29, IRGKangXi=0900.250, RSKangXi=118.12
7C2A CJK UNIFIED IDEOGRAPH-#7C2A, IRGKangXi=0900.280, RSKangXi=118.12, Def{hairpin, clasp; wear in hair}
7C2B CJK UNIFIED IDEOGRAPH-#7C2B, IRGKangXi=0900.320, RSKangXi=118.12, Def{musical instrument like pan-pipes, bamboo flute}
7C2C CJK UNIFIED IDEOGRAPH-#7C2C, IRGKangXi=0901.020, RSKangXi=118.12
7C2D CJK UNIFIED IDEOGRAPH-#7C2D, IRGKangXi=0901.080, RSKangXi=118.12
7C2E CJK UNIFIED IDEOGRAPH-#7C2E, IRGKangXi=0901.281, RSKangXi=118.12
7C2F CJK UNIFIED IDEOGRAPH-#7C2F, IRGKangXi=0901.281, RSKangXi=118.12
7C30 CJK UNIFIED IDEOGRAPH-#7C30, IRGKangXi=0901.281, RSKangXi=118.12, Def{bamboo raft}
7C31 CJK UNIFIED IDEOGRAPH-#7C31, IRGKangXi=0901.281, RSKangXi=118.12
7C32 CJK UNIFIED IDEOGRAPH-#7C32, IRGKangXi=0901.281
7C33 CJK UNIFIED IDEOGRAPH-#7C33, IRGKangXi=0901.290, RSKangXi=118.13
7C34 CJK UNIFIED IDEOGRAPH-#7C34, IRGKangXi=0901.320, RSKangXi=118.13
7C35 CJK UNIFIED IDEOGRAPH-#7C35, IRGKangXi=0901.330, RSKangXi=118.13, Def{fine bamboo}
7C36 CJK UNIFIED IDEOGRAPH-#7C36, IRGKangXi=0901.370, RSKangXi=118.13
7C37 CJK UNIFIED IDEOGRAPH-#7C37, IRGKangXi=0901.440, RSKangXi=118.13, Def{eaves of house; brim}
7C38 CJK UNIFIED IDEOGRAPH-#7C38, IRGKangXi=0901.460, RSKangXi=118.13, Def{winnower}
7C39 CJK UNIFIED IDEOGRAPH-#7C39, IRGKangXi=0901.470, RSKangXi=118.13, Def{tall bamboo}
7C3A CJK UNIFIED IDEOGRAPH-#7C3A, IRGKangXi=0901.480, RSKangXi=118.13
7C3B CJK UNIFIED IDEOGRAPH-#7C3B, IRGKangXi=0901.490, RSKangXi=118.13, Def{empty}
7C3C CJK UNIFIED IDEOGRAPH-#7C3C, IRGKangXi=0902.010, RSKangXi=118.13
7C3D CJK UNIFIED IDEOGRAPH-#7C3D, IRGKangXi=0902.020, RSKangXi=118.13, Def{sign, endorse; slip of paper}
7C3E CJK UNIFIED IDEOGRAPH-#7C3E, IRGKangXi=0902.040, RSKangXi=118.13, Def{a blind, screen, curtain}
7C3F CJK UNIFIED IDEOGRAPH-#7C3F, IRGKangXi=0902.110, RSKangXi=118.13, Def{register, account book, notebook}
7C40 CJK UNIFIED IDEOGRAPH-#7C40, IRGKangXi=0902.321, RSKangXi=118.13, Def{recite, read; style of calligraphy}
7C41 CJK UNIFIED IDEOGRAPH-#7C41, IRGKangXi=0902.321, RSKangXi=118.13, Def{bamboo flute; pipe; various sound}
7C42 CJK UNIFIED IDEOGRAPH-#7C42, IRGKangXi=0902.321, RSKangXi=118.13
7C43 CJK UNIFIED IDEOGRAPH-#7C43, IRGKangXi=0902.330, RSKangXi=118.14, Def{basket}
7C44 CJK UNIFIED IDEOGRAPH-#7C44, IRGKangXi=0902.370, Def{a basket for carrying earth}
7C45 CJK UNIFIED IDEOGRAPH-#7C45, IRGKangXi=0902.390, RSKangXi=118.14
7C46 CJK UNIFIED IDEOGRAPH-#7C46, IRGKangXi=0902.400, RSKangXi=118.14
7C47 CJK UNIFIED IDEOGRAPH-#7C47, IRGKangXi=0902.420, RSKangXi=118.14
7C48 CJK UNIFIED IDEOGRAPH-#7C48, IRGKangXi=0902.500, RSKangXi=118.14
7C49 CJK UNIFIED IDEOGRAPH-#7C49, IRGKangXi=0902.530, RSKangXi=118.14
7C4A CJK UNIFIED IDEOGRAPH-#7C4A, IRGKangXi=0903.040, RSKangXi=118.14, Def{long}
7C4B CJK UNIFIED IDEOGRAPH-#7C4B, IRGKangXi=0903.050, RSKangXi=118.14
7C4C CJK UNIFIED IDEOGRAPH-#7C4C, IRGKangXi=0903.080, RSKangXi=118.14, Def{chip, tally, token; raise money}
7C4D CJK UNIFIED IDEOGRAPH-#7C4D, IRGKangXi=0903.090, RSKangXi=118.14, Def{record, register, list; census}
7C4E CJK UNIFIED IDEOGRAPH-#7C4E, IRGKangXi=0903.191, RSKangXi=118.14
7C4F CJK UNIFIED IDEOGRAPH-#7C4F, IRGKangXi=0903.191, RSKangXi=118.14, Def{flag}
7C50 CJK UNIFIED IDEOGRAPH-#7C50, IRGKangXi=0903.240, RSKangXi=118.15, Def{climbing plants, vines, cane}
7C51 CJK UNIFIED IDEOGRAPH-#7C51, IRGKangXi=1425.250, RSKangXi=118.15, Def{to feed, to provide for delicacies, dainties}
7C52 CJK UNIFIED IDEOGRAPH-#7C52, IRGKangXi=0903.330, RSKangXi=118.15
7C53 CJK UNIFIED IDEOGRAPH-#7C53, IRGKangXi=0903.380, RSKangXi=118.15, Def{sieve; basket}
7C54 CJK UNIFIED IDEOGRAPH-#7C54, IRGKangXi=0903.390, RSKangXi=118.15, Def{bamboo basket}
7C55 CJK UNIFIED IDEOGRAPH-#7C55, IRGKangXi=0904.040, RSKangXi=118.14
7C56 CJK UNIFIED IDEOGRAPH-#7C56, IRGKangXi=0904.201, RSKangXi=118.14, Def{tally; lot; marker}
7C57 CJK UNIFIED IDEOGRAPH-#7C57, IRGKangXi=0904.250, RSKangXi=118.16
7C58 CJK UNIFIED IDEOGRAPH-#7C58, IRGKangXi=0904.260, RSKangXi=118.16, Def{climbing plants, vines, cane}
7C59 CJK UNIFIED IDEOGRAPH-#7C59, IRGKangXi=0904.270, RSKangXi=118.16, Def{book}
7C5A CJK UNIFIED IDEOGRAPH-#7C5A, IRGKangXi=0904.290, RSKangXi=118.16, Def{bamboo; the handle of the spear}
7C5B CJK UNIFIED IDEOGRAPH-#7C5B, IRGKangXi=0904.340, RSKangXi=118.16, Def{surname}
7C5C CJK UNIFIED IDEOGRAPH-#7C5C, IRGKangXi=0904.350, RSKangXi=118.16, Def{bamboo sheath, bamboo shoots}
7C5D CJK UNIFIED IDEOGRAPH-#7C5D, IRGKangXi=0904.370, RSKangXi=118.16, Def{a tube to hold chopsticks}
7C5E CJK UNIFIED IDEOGRAPH-#7C5E, IRGKangXi=0904.430, RSKangXi=118.16, Def{a fence}
7C5F CJK UNIFIED IDEOGRAPH-#7C5F, IRGKangXi=0904.440, RSKangXi=118.16, Def{bamboo flute; pipe; various sound}
7C60 CJK UNIFIED IDEOGRAPH-#7C60, IRGKangXi=0904.450, RSKangXi=118.16, Def{cage; cage-like basket}
7C61 CJK UNIFIED IDEOGRAPH-#7C61, IRGKangXi=0905.101, RSKangXi=118.16
7C62 CJK UNIFIED IDEOGRAPH-#7C62, IRGKangXi=0905.130, RSKangXi=118.17
7C63 CJK UNIFIED IDEOGRAPH-#7C63, IRGKangXi=0905.150, RSKangXi=118.17, Def{bow case}
7C64 CJK UNIFIED IDEOGRAPH-#7C64, IRGKangXi=0905.160, RSKangXi=118.17, Def{tally; lot; marker}
7C65 CJK UNIFIED IDEOGRAPH-#7C65, IRGKangXi=0905.180, RSKangXi=118.17, Def{key; woodwind instrument}
7C66 CJK UNIFIED IDEOGRAPH-#7C66, IRGKangXi=0905.220, RSKangXi=118.17
7C67 CJK UNIFIED IDEOGRAPH-#7C67, IRGKangXi=0905.240, RSKangXi=118.17, Def{crude bamboo mat}
7C68 CJK UNIFIED IDEOGRAPH-#7C68, IRGKangXi=0905.311, RSKangXi=118.17, Def{trousseau}
7C69 CJK UNIFIED IDEOGRAPH-#7C69, IRGKangXi=0905.370, RSKangXi=118.19, Def{bamboo container for food}
7C6A CJK UNIFIED IDEOGRAPH-#7C6A, IRGKangXi=0906.031, RSKangXi=118.18, Def{a weir of bamboo to catch fish or crabs}
7C6B CJK UNIFIED IDEOGRAPH-#7C6B, IRGKangXi=0906.040, RSKangXi=118.19
7C6C CJK UNIFIED IDEOGRAPH-#7C6C, IRGKangXi=0906.050, RSKangXi=118.19, Def{bamboo or wooden fence; hedge}
7C6D CJK UNIFIED IDEOGRAPH-#7C6D, IRGKangXi=0906.060, RSKangXi=118.19
7C6E CJK UNIFIED IDEOGRAPH-#7C6E, IRGKangXi=0906.070, RSKangXi=118.19, Def{bamboo basket}
7C6F CJK UNIFIED IDEOGRAPH-#7C6F, IRGKangXi=0906.130, RSKangXi=118.20, Def{bamboo chest; tubular bamboo case}
7C70 CJK UNIFIED IDEOGRAPH-#7C70, IRGKangXi=0906.150, RSKangXi=118.20
7C71 CJK UNIFIED IDEOGRAPH-#7C71, IRGKangXi=0906.260, RSKangXi=118.24
7C72 CJK UNIFIED IDEOGRAPH-#7C72, IRGKangXi=0906.301, RSKangXi=118.26, Def{appeal; request; implore}
7C73 CJK UNIFIED IDEOGRAPH-#7C73, IRGKangXi=0906.310, RSKangXi=119.0, Def{hulled or husked uncooked rice}
7C74 CJK UNIFIED IDEOGRAPH-#7C74, IRGKangXi=0906.350, RSKangXi=119.2, Def{purchase grains; store grain}
7C75 CJK UNIFIED IDEOGRAPH-#7C75, IRGKangXi=0906.360, RSKangXi=119.2, Def{dm (decimetre, decimeter)}
7C76 CJK UNIFIED IDEOGRAPH-#7C76, IRGKangXi=0906.361, RSKangXi=119.2
7C77 CJK UNIFIED IDEOGRAPH-#7C77, IRGKangXi=0906.370, RSKangXi=119.3
7C78 CJK UNIFIED IDEOGRAPH-#7C78, IRGKangXi=0906.380, RSKangXi=119.3, Def{powdery substance}
7C79 CJK UNIFIED IDEOGRAPH-#7C79, IRGKangXi=0906.400, RSKangXi=119.3, Def{cake}
7C7A CJK UNIFIED IDEOGRAPH-#7C7A, IRGKangXi=0906.410, RSKangXi=119.3
7C7B CJK UNIFIED IDEOGRAPH-#7C7B, IRGKangXi=0907.030, RSKangXi=37.6, Def{class, group, kind, category}
7C7C CJK UNIFIED IDEOGRAPH-#7C7C, IRGKangXi=0907.040, RSKangXi=119.3, Def{non-glutinous long grain rice}
7C7D CJK UNIFIED IDEOGRAPH-#7C7D, IRGKangXi=0907.051, RSKangXi=119.3, Def{seed, pip, pit, stone}
7C7E CJK UNIFIED IDEOGRAPH-#7C7E, IRGKangXi=0907.051, RSKangXi=119.3, Def{unhulled rice}
7C7F CJK UNIFIED IDEOGRAPH-#7C7F, IRGKangXi=0907.051, RSKangXi=119.3
7C80 CJK UNIFIED IDEOGRAPH-#7C80, IRGKangXi=0907.051, RSKangXi=119.3
7C81 CJK UNIFIED IDEOGRAPH-#7C81, IRGKangXi=0907.051, RSKangXi=119.3, Def{kilometre}
7C82 CJK UNIFIED IDEOGRAPH-#7C82, IRGKangXi=0907.051, RSKangXi=119.3, Def{surname}
7C83 CJK UNIFIED IDEOGRAPH-#7C83, IRGKangXi=0907.060, RSKangXi=119.4, Def{empty husks of grain}
7C84 CJK UNIFIED IDEOGRAPH-#7C84, IRGKangXi=0907.100, RSKangXi=119.4
7C85 CJK UNIFIED IDEOGRAPH-#7C85, IRGKangXi=0907.110, RSKangXi=119.4
7C86 CJK UNIFIED IDEOGRAPH-#7C86, IRGKangXi=0907.120, RSKangXi=119.4, Def{coarse}
7C87 CJK UNIFIED IDEOGRAPH-#7C87, IRGKangXi=0907.130, RSKangXi=119.4
7C88 CJK UNIFIED IDEOGRAPH-#7C88, IRGKangXi=0907.140, RSKangXi=119.4
7C89 CJK UNIFIED IDEOGRAPH-#7C89, IRGKangXi=0907.160, RSKangXi=119.4, Def{powder, face powder; plaster}
7C8A CJK UNIFIED IDEOGRAPH-#7C8A, IRGKangXi=0907.180, RSKangXi=119.4
7C8B CJK UNIFIED IDEOGRAPH-#7C8B, IRGKangXi=0907.200, RSKangXi=119.4, Def{pure; unadulterated; select}
7C8C CJK UNIFIED IDEOGRAPH-#7C8C, IRGKangXi=0907.211, RSKangXi=119.4
7C8D CJK UNIFIED IDEOGRAPH-#7C8D, IRGKangXi=0907.211, RSKangXi=119.4, Def{millimetre}
7C8E CJK UNIFIED IDEOGRAPH-#7C8E, IRGKangXi=0907.211, RSKangXi=119.4, Def{metre}
7C8F CJK UNIFIED IDEOGRAPH-#7C8F, IRGKangXi=0907.211, RSKangXi=119.4
7C90 CJK UNIFIED IDEOGRAPH-#7C90, IRGKangXi=0907.211, RSKangXi=119.4
7C91 CJK UNIFIED IDEOGRAPH-#7C91, IRGKangXi=0907.211, RSKangXi=119.4, Def{tsamba (food in Tibet)}
7C92 CJK UNIFIED IDEOGRAPH-#7C92, IRGKangXi=0907.220, RSKangXi=119.5, Def{grain; small particle}
7C93 CJK UNIFIED IDEOGRAPH-#7C93, IRGKangXi=0907.250, RSKangXi=119.5
7C94 CJK UNIFIED IDEOGRAPH-#7C94, IRGKangXi=0907.280, RSKangXi=119.5, Def{cakes made from rice flour twisted into rings}
7C95 CJK UNIFIED IDEOGRAPH-#7C95, IRGKangXi=0907.300, RSKangXi=119.5, Def{lees, dregs, sediments left after distilling liquor}
7C96 CJK UNIFIED IDEOGRAPH-#7C96, IRGKangXi=0907.360, RSKangXi=119.5
7C97 CJK UNIFIED IDEOGRAPH-#7C97, IRGKangXi=0907.370, RSKangXi=119.5, Def{rough, thick, course; rude}
7C98 CJK UNIFIED IDEOGRAPH-#7C98, IRGKangXi=0907.400, RSKangXi=119.5, Def{viscous, mucous; glutinous}
7C99 CJK UNIFIED IDEOGRAPH-#7C99, IRGKangXi=0908.040, RSKangXi=119.5
7C9A CJK UNIFIED IDEOGRAPH-#7C9A, IRGKangXi=0908.070, RSKangXi=119.5
7C9B CJK UNIFIED IDEOGRAPH-#7C9B, IRGKangXi=0908.100, RSKangXi=129.6, Def{pay respects; reverently}
7C9C CJK UNIFIED IDEOGRAPH-#7C9C, IRGKangXi=0908.110, RSKangXi=119.5, Def{sell grains}
7C9D CJK UNIFIED IDEOGRAPH-#7C9D, IRGKangXi=0908.121, RSKangXi=119.5, Def{unpolished rice; brown rice}
7C9E CJK UNIFIED IDEOGRAPH-#7C9E, IRGKangXi=0908.130, RSKangXi=119.6, Def{to mash rice}
7C9F CJK UNIFIED IDEOGRAPH-#7C9F, IRGKangXi=0908.140, RSKangXi=119.6, Def{unhusked millet; grain}
7CA0 CJK UNIFIED IDEOGRAPH-#7CA0, IRGKangXi=0908.210, RSKangXi=119.6
7CA1 CJK UNIFIED IDEOGRAPH-#7CA1, IRGKangXi=0908.250, RSKangXi=119.6
7CA2 CJK UNIFIED IDEOGRAPH-#7CA2, IRGKangXi=0908.290, RSKangXi=119.6, Def{grain offered in ritual sacrifice; millet}
7CA3 CJK UNIFIED IDEOGRAPH-#7CA3, IRGKangXi=0908.320, RSKangXi=119.5
7CA4 CJK UNIFIED IDEOGRAPH-#7CA4, IRGKangXi=0908.330, RSKangXi=119.6, Def{Guangdong and Guangxi provinces; initial particle}
7CA5 CJK UNIFIED IDEOGRAPH-#7CA5, IRGKangXi=0908.360, RSKangXi=119.6, Def{rice gruel, congee}
7CA6 CJK UNIFIED IDEOGRAPH-#7CA6, IRGKangXi=0909.010, RSKangXi=119.6, Def{phosphorus}
7CA7 CJK UNIFIED IDEOGRAPH-#7CA7, IRGKangXi=0909.070, RSKangXi=119.6, Def{toilet; make-up; dress up; adorn}
7CA8 CJK UNIFIED IDEOGRAPH-#7CA8, IRGKangXi=0909.071, RSKangXi=119.6, Def{hectometre}
7CA9 CJK UNIFIED IDEOGRAPH-#7CA9, IRGKangXi=0909.071, RSKangXi=119.6
7CAA CJK UNIFIED IDEOGRAPH-#7CAA, IRGKangXi=0909.071, RSKangXi=119.6, Def{manure, dung, shit, excrement, night soil}
7CAB CJK UNIFIED IDEOGRAPH-#7CAB, IRGKangXi=0909.071, RSKangXi=119.6
7CAC CJK UNIFIED IDEOGRAPH-#7CAC, IRGKangXi=0909.071, RSKangXi=119.6
7CAD CJK UNIFIED IDEOGRAPH-#7CAD, IRGKangXi=0909.071, RSKangXi=119.6
7CAE CJK UNIFIED IDEOGRAPH-#7CAE, IRGKangXi=0909.100, RSKangXi=119.7, Def{food, grain, provisions}
7CAF CJK UNIFIED IDEOGRAPH-#7CAF, IRGKangXi=0909.130, RSKangXi=119.7
7CB0 CJK UNIFIED IDEOGRAPH-#7CB0, IRGKangXi=0909.180, RSKangXi=119.7
7CB1 CJK UNIFIED IDEOGRAPH-#7CB1, IRGKangXi=0909.200, RSKangXi=119.7, Def{better varieties of millet}
7CB2 CJK UNIFIED IDEOGRAPH-#7CB2, IRGKangXi=0909.230, RSKangXi=119.7, Def{polish; bright, radiant; smiling}
7CB3 CJK UNIFIED IDEOGRAPH-#7CB3, IRGKangXi=0909.240, RSKangXi=119.7, Def{non-glutinous rice}
7CB4 CJK UNIFIED IDEOGRAPH-#7CB4, IRGKangXi=0909.311, RSKangXi=119.7
7CB5 CJK UNIFIED IDEOGRAPH-#7CB5, IRGKangXi=0909.311, RSKangXi=119.7, Def{Guangdong and Guangxi provinces; initial particle}
7CB6 CJK UNIFIED IDEOGRAPH-#7CB6, IRGKangXi=0909.320, RSKangXi=119.8
7CB7 CJK UNIFIED IDEOGRAPH-#7CB7, IRGKangXi=0909.330, RSKangXi=119.8
7CB8 CJK UNIFIED IDEOGRAPH-#7CB8, IRGKangXi=0909.360, RSKangXi=119.8
7CB9 CJK UNIFIED IDEOGRAPH-#7CB9, IRGKangXi=0909.390, RSKangXi=119.8, Def{pure; unadulterated; select}
7CBA CJK UNIFIED IDEOGRAPH-#7CBA, IRGKangXi=0910.010, RSKangXi=119.8, Def{polished rice or millet}
7CBB CJK UNIFIED IDEOGRAPH-#7CBB, IRGKangXi=0910.030, RSKangXi=119.8, Def{provisions}
7CBC CJK UNIFIED IDEOGRAPH-#7CBC, IRGKangXi=0910.040, RSKangXi=119.8
7CBD CJK UNIFIED IDEOGRAPH-#7CBD, IRGKangXi=0910.060, RSKangXi=119.8, Def{dumpling made of glutinous rice}
7CBE CJK UNIFIED IDEOGRAPH-#7CBE, IRGKangXi=0910.100, RSKangXi=119.8, Def{essence; semen; spirit}
7CBF CJK UNIFIED IDEOGRAPH-#7CBF, IRGKangXi=0910.110, RSKangXi=119.8, Def{rice cake}
7CC0 CJK UNIFIED IDEOGRAPH-#7CC0, IRGKangXi=0910.201, RSKangXi=119.7
7CC1 CJK UNIFIED IDEOGRAPH-#7CC1, IRGKangXi=0910.201, RSKangXi=119.8, Def{a grain of rice; rice gruel mixed with meat}
7CC2 CJK UNIFIED IDEOGRAPH-#7CC2, IRGKangXi=0910.210, RSKangXi=119.9
7CC3 CJK UNIFIED IDEOGRAPH-#7CC3, IRGKangXi=0910.240, RSKangXi=119.9
7CC4 CJK UNIFIED IDEOGRAPH-#7CC4, IRGKangXi=0910.250, RSKangXi=119.9
7CC5 CJK UNIFIED IDEOGRAPH-#7CC5, IRGKangXi=0910.310, RSKangXi=119.9, Def{blend, mix; mixed}
7CC6 CJK UNIFIED IDEOGRAPH-#7CC6, IRGKangXi=0910.350, RSKangXi=119.9
7CC7 CJK UNIFIED IDEOGRAPH-#7CC7, IRGKangXi=0911.060, RSKangXi=119.9, Def{dried rice, dry provisions}
7CC8 CJK UNIFIED IDEOGRAPH-#7CC8, IRGKangXi=0911.070, RSKangXi=119.9, Def{sacrificial rice; rations; pay}
7CC9 CJK UNIFIED IDEOGRAPH-#7CC9, IRGKangXi=0911.080, RSKangXi=119.9, Def{dumpling made of glutinous rice}
7CCA CJK UNIFIED IDEOGRAPH-#7CCA, IRGKangXi=0911.090, RSKangXi=119.9, Def{paste, stick on with paste}
7CCB CJK UNIFIED IDEOGRAPH-#7CCB, IRGKangXi=0911.140, RSKangXi=119.9
7CCC CJK UNIFIED IDEOGRAPH-#7CCC, IRGKangXi=0911.241, RSKangXi=119.9
7CCD CJK UNIFIED IDEOGRAPH-#7CCD, IRGKangXi=0911.241, RSKangXi=119.9, Def{food made of crushed and cooked rice}
7CCE CJK UNIFIED IDEOGRAPH-#7CCE, IRGKangXi=0911.241, RSKangXi=119.9, Def{(J) centimetre}
7CCF CJK UNIFIED IDEOGRAPH-#7CCF, IRGKangXi=0911.280, RSKangXi=119.10, Def{rice grits left after hulling}
7CD0 CJK UNIFIED IDEOGRAPH-#7CD0, IRGKangXi=0911.290, RSKangXi=119.10
7CD1 CJK UNIFIED IDEOGRAPH-#7CD1, IRGKangXi=0911.310, RSKangXi=119.10
7CD2 CJK UNIFIED IDEOGRAPH-#7CD2, IRGKangXi=0911.330, RSKangXi=119.10, Def{food for a journey; cakes}
7CD3 CJK UNIFIED IDEOGRAPH-#7CD3, IRGKangXi=0911.350, RSKangXi=119.10, Def{grain, corn}
7CD4 CJK UNIFIED IDEOGRAPH-#7CD4, IRGKangXi=0911.360, RSKangXi=119.10, Def{juice}
7CD5 CJK UNIFIED IDEOGRAPH-#7CD5, IRGKangXi=0911.370, RSKangXi=119.10, Def{cakes, pastry}
7CD6 CJK UNIFIED IDEOGRAPH-#7CD6, IRGKangXi=0911.380, RSKangXi=119.10, Def{sugar; candy; sweets}
7CD7 CJK UNIFIED IDEOGRAPH-#7CD7, IRGKangXi=0911.390, RSKangXi=119.10, Def{parched wheat or rice; broken grain}
7CD8 CJK UNIFIED IDEOGRAPH-#7CD8, IRGKangXi=0912.101, RSKangXi=119.10
7CD9 CJK UNIFIED IDEOGRAPH-#7CD9, IRGKangXi=0912.110, RSKangXi=119.11, Def{coarse, harsh, rough, unpolished rice}
7CDA CJK UNIFIED IDEOGRAPH-#7CDA, IRGKangXi=0912.120, RSKangXi=119.11
7CDB CJK UNIFIED IDEOGRAPH-#7CDB, IRGKangXi=0912.200, RSKangXi=119.11
7CDC CJK UNIFIED IDEOGRAPH-#7CDC, IRGKangXi=0912.210, RSKangXi=119.11, Def{rice gruel, congee; mashed}
7CDD CJK UNIFIED IDEOGRAPH-#7CDD, IRGKangXi=0912.250, RSKangXi=119.11, Def{scattered (grains of rice); mixed}
7CDE CJK UNIFIED IDEOGRAPH-#7CDE, IRGKangXi=0912.260, RSKangXi=119.11, Def{manure, dung, night soil}
7CDF CJK UNIFIED IDEOGRAPH-#7CDF, IRGKangXi=0912.300, RSKangXi=119.11, Def{sediment, dregs; pickle}
7CE0 CJK UNIFIED IDEOGRAPH-#7CE0, IRGKangXi=0912.310, RSKangXi=119.11, Def{chaff, bran, husks; poor}
7CE1 CJK UNIFIED IDEOGRAPH-#7CE1, IRGKangXi=0912.380, RSKangXi=119.11, Def{starch; paste. to starch}
7CE2 CJK UNIFIED IDEOGRAPH-#7CE2, IRGKangXi=0912.391, RSKangXi=119.11, Def{rice snacks}
7CE3 CJK UNIFIED IDEOGRAPH-#7CE3, IRGKangXi=0912.410, RSKangXi=119.12
7CE4 CJK UNIFIED IDEOGRAPH-#7CE4, IRGKangXi=0912.420, Def{fried round cakes of wheat flour}
7CE5 CJK UNIFIED IDEOGRAPH-#7CE5, IRGKangXi=0913.030, RSKangXi=119.12
7CE6 CJK UNIFIED IDEOGRAPH-#7CE6, IRGKangXi=0913.060, RSKangXi=119.12
7CE7 CJK UNIFIED IDEOGRAPH-#7CE7, IRGKangXi=0913.070, RSKangXi=119.12, Def{food, grain, provisions}
7CE8 CJK UNIFIED IDEOGRAPH-#7CE8, IRGKangXi=0913.090, RSKangXi=119.11, Def{starch; paste. to starch}
7CE9 CJK UNIFIED IDEOGRAPH-#7CE9, IRGKangXi=0913.170, RSKangXi=119.13
7CEA CJK UNIFIED IDEOGRAPH-#7CEA, IRGKangXi=0913.180, RSKangXi=119.13
7CEB CJK UNIFIED IDEOGRAPH-#7CEB, IRGKangXi=0913.210, RSKangXi=119.13
7CEC CJK UNIFIED IDEOGRAPH-#7CEC, IRGKangXi=0913.431, RSKangXi=119.13
7CED CJK UNIFIED IDEOGRAPH-#7CED, IRGKangXi=0913.341, RSKangXi=119.13, Def{rice dumpling}
7CEE CJK UNIFIED IDEOGRAPH-#7CEE, IRGKangXi=0913.370, RSKangXi=119.14
7CEF CJK UNIFIED IDEOGRAPH-#7CEF, IRGKangXi=0913.390, RSKangXi=119.14, Def{glutinous rice; glutinous, sticky}
7CF0 CJK UNIFIED IDEOGRAPH-#7CF0, IRGKangXi=0913.410, RSKangXi=119.14, Def{rice ball}
7CF1 CJK UNIFIED IDEOGRAPH-#7CF1, IRGKangXi=0913.450, RSKangXi=119.16, Def{fermenting grain; yeast}
7CF2 CJK UNIFIED IDEOGRAPH-#7CF2, IRGKangXi=0913.470, RSKangXi=119.15, Def{unpolished rice; brown rice}
7CF3 CJK UNIFIED IDEOGRAPH-#7CF3, IRGKangXi=0914.221, RSKangXi=119.16
7CF4 CJK UNIFIED IDEOGRAPH-#7CF4, IRGKangXi=0913.540, RSKangXi=119.16, Def{purchase grains; store grain}
7CF5 CJK UNIFIED IDEOGRAPH-#7CF5, IRGKangXi=0914.070, RSKangXi=119.17, Def{fermenting grain; grain which has sprouted; yeast}
7CF6 CJK UNIFIED IDEOGRAPH-#7CF6, IRGKangXi=0914.150, RSKangXi=119.19, Def{sell grains}
7CF7 CJK UNIFIED IDEOGRAPH-#7CF7, IRGKangXi=0914.230, RSKangXi=119.21
7CF8 CJK UNIFIED IDEOGRAPH-#7CF8, IRGKangXi=0915.010, RSKangXi=120.0, Def{silk; KangXi radical 120}
7CF9 CJK UNIFIED IDEOGRAPH-#7CF9, IRGKangXi=0915.011, RSKangXi=120.0, Def{silk; KangXi radical 120}
7CFA CJK UNIFIED IDEOGRAPH-#7CFA, IRGKangXi=0915.030, RSKangXi=120.1, Def{to collaborate; to band together}
7CFB CJK UNIFIED IDEOGRAPH-#7CFB, IRGKangXi=0915.040, RSKangXi=120.1, Def{system; line, link, connection}
7CFC CJK UNIFIED IDEOGRAPH-#7CFC, IRGKangXi=0915.060, RSKangXi=120.2
7CFD CJK UNIFIED IDEOGRAPH-#7CFD, IRGKangXi=0915.070, RSKangXi=120.2
7CFE CJK UNIFIED IDEOGRAPH-#7CFE, IRGKangXi=0915.080, RSKangXi=120.2, Def{investigate, inspect}
7CFF CJK UNIFIED IDEOGRAPH-#7CFF, IRGKangXi=0915.090, RSKangXi=120.2
7D00 CJK UNIFIED IDEOGRAPH-#7D00, IRGKangXi=0915.130, RSKangXi=120.3, Def{record, annal, historical account}
7D01 CJK UNIFIED IDEOGRAPH-#7D01, IRGKangXi=0916.121, RSKangXi=120.3
7D02 CJK UNIFIED IDEOGRAPH-#7D02, IRGKangXi=0915.180, RSKangXi=120.3, Def{name of an emperor; saddle part}
7D03 CJK UNIFIED IDEOGRAPH-#7D03, IRGKangXi=0915.200, RSKangXi=120.3, Def{a cord}
7D04 CJK UNIFIED IDEOGRAPH-#7D04, IRGKangXi=0915.210, RSKangXi=120.3, Def{treaty, agreement, covenant}
7D05 CJK UNIFIED IDEOGRAPH-#7D05, IRGKangXi=0916.010, RSKangXi=120.3, Def{red, vermillion; blush, flush}
7D06 CJK UNIFIED IDEOGRAPH-#7D06, IRGKangXi=0916.020, RSKangXi=120.3, Def{bend, turn, twist; distort}
7D07 CJK UNIFIED IDEOGRAPH-#7D07, IRGKangXi=0916.030, RSKangXi=120.3, Def{inferior silk; tassel, fringe}
7D08 CJK UNIFIED IDEOGRAPH-#7D08, IRGKangXi=0916.040, RSKangXi=120.3, Def{white silk, fine silk; gauze}
7D09 CJK UNIFIED IDEOGRAPH-#7D09, IRGKangXi=0916.050, RSKangXi=120.3, Def{thread needle, sew stitch, string}
7D0A CJK UNIFIED IDEOGRAPH-#7D0A, IRGKangXi=0916.150, RSKangXi=120.4, Def{confused, disorder}
7D0B CJK UNIFIED IDEOGRAPH-#7D0B, IRGKangXi=0916.160, RSKangXi=120.4, Def{line, streak, stripe; wrinkle}
7D0C CJK UNIFIED IDEOGRAPH-#7D0C, IRGKangXi=0916.170, RSKangXi=120.4
7D0D CJK UNIFIED IDEOGRAPH-#7D0D, IRGKangXi=0916.180, RSKangXi=120.4, Def{admit, take, receive, accept}
7D0E CJK UNIFIED IDEOGRAPH-#7D0E, IRGKangXi=0916.200, RSKangXi=120.4
7D0F CJK UNIFIED IDEOGRAPH-#7D0F, IRGKangXi=0916.210, RSKangXi=120.4
7D10 CJK UNIFIED IDEOGRAPH-#7D10, IRGKangXi=0916.220, RSKangXi=120.4, Def{knot; button; handle, knob; tie}
7D11 CJK UNIFIED IDEOGRAPH-#7D11, IRGKangXi=0917.020, RSKangXi=120.4, Def{fresh}
7D12 CJK UNIFIED IDEOGRAPH-#7D12, IRGKangXi=0917.040, RSKangXi=120.4
7D13 CJK UNIFIED IDEOGRAPH-#7D13, IRGKangXi=0917.050, RSKangXi=120.4, Def{loosen, relax, relieve; extricate}
7D14 CJK UNIFIED IDEOGRAPH-#7D14, IRGKangXi=0917.060, RSKangXi=120.4, Def{pure, clean, simple}
7D15 CJK UNIFIED IDEOGRAPH-#7D15, IRGKangXi=0917.100, RSKangXi=120.4, Def{spoiled silk; hem of dress}
7D16 CJK UNIFIED IDEOGRAPH-#7D16, IRGKangXi=0917.150, RSKangXi=120.4, Def{a rope for leading cattle or horse}
7D17 CJK UNIFIED IDEOGRAPH-#7D17, IRGKangXi=0917.180, RSKangXi=120.4, Def{gauze, thin silk; yarn, thread}
7D18 CJK UNIFIED IDEOGRAPH-#7D18, IRGKangXi=0917.200, RSKangXi=120.4, Def{string; vast, expansive}
7D19 CJK UNIFIED IDEOGRAPH-#7D19, IRGKangXi=0918.040, RSKangXi=120.4, Def{paper}
7D1A CJK UNIFIED IDEOGRAPH-#7D1A, IRGKangXi=0918.050, RSKangXi=120.4, Def{level, rank, class; grade}
7D1B CJK UNIFIED IDEOGRAPH-#7D1B, IRGKangXi=0918.060, RSKangXi=120.4, Def{in disorder, scattered, tangled}
7D1C CJK UNIFIED IDEOGRAPH-#7D1C, IRGKangXi=0918.070, RSKangXi=120.4, Def{confused, in disorder; numerous}
7D1D CJK UNIFIED IDEOGRAPH-#7D1D, IRGKangXi=0918.080, RSKangXi=120.4, Def{weave, lay warp}
7D1E CJK UNIFIED IDEOGRAPH-#7D1E, IRGKangXi=0918.090, RSKangXi=120.4, Def{a fringe}
7D1F CJK UNIFIED IDEOGRAPH-#7D1F, IRGKangXi=0918.100, RSKangXi=120.4, Def{a sash; to tie}
7D20 CJK UNIFIED IDEOGRAPH-#7D20, IRGKangXi=0918.110, RSKangXi=120.4, Def{white (silk); plain; vegetarian; formerly; normally}
7D21 CJK UNIFIED IDEOGRAPH-#7D21, IRGKangXi=0918.150, RSKangXi=120.4, Def{spin, reel, weave; reeled pongee}
7D22 CJK UNIFIED IDEOGRAPH-#7D22, IRGKangXi=0918.160, RSKangXi=120.4, Def{large rope, cable; rules, laws; to demand, to exact; to search, inquire; isolated}
7D23 CJK UNIFIED IDEOGRAPH-#7D23, IRGKangXi=0919.160, RSKangXi=120.4
7D24 CJK UNIFIED IDEOGRAPH-#7D24, IRGKangXi=0919.170, RSKangXi=120.4
7D25 CJK UNIFIED IDEOGRAPH-#7D25, IRGKangXi=0919.171, RSKangXi=120.4, Def{tie, fasten, bind}
7D26 CJK UNIFIED IDEOGRAPH-#7D26, IRGKangXi=0919.171, RSKangXi=120.4
7D27 CJK UNIFIED IDEOGRAPH-#7D27, IRGKangXi=0919.171, RSKangXi=120.4, Def{tense, tight, taut; firm, secure}
7D28 CJK UNIFIED IDEOGRAPH-#7D28, IRGKangXi=0919.180, RSKangXi=120.5
7D29 CJK UNIFIED IDEOGRAPH-#7D29, IRGKangXi=0919.250, RSKangXi=120.5, Def{to sew}
7D2A CJK UNIFIED IDEOGRAPH-#7D2A, IRGKangXi=0919.280, RSKangXi=120.5
7D2B CJK UNIFIED IDEOGRAPH-#7D2B, IRGKangXi=0919.290, RSKangXi=120.5, Def{purple, violet; amethyst; surname}
7D2C CJK UNIFIED IDEOGRAPH-#7D2C, IRGKangXi=0919.300, RSKangXi=120.5, Def{kind of thin silk}
7D2D CJK UNIFIED IDEOGRAPH-#7D2D, IRGKangXi=0919.320, RSKangXi=120.5
7D2E CJK UNIFIED IDEOGRAPH-#7D2E, IRGKangXi=0919.330, RSKangXi=120.5, Def{tie, fasten, bind}
7D2F CJK UNIFIED IDEOGRAPH-#7D2F, IRGKangXi=0919.350, RSKangXi=120.5, Def{tired; implicate, involve; bother}
7D30 CJK UNIFIED IDEOGRAPH-#7D30, IRGKangXi=0919.360, RSKangXi=120.5, Def{fine, tiny; slender, thin}
7D31 CJK UNIFIED IDEOGRAPH-#7D31, IRGKangXi=0919.370, RSKangXi=120.5, Def{ribbon or cord used attach ornaments}
7D32 CJK UNIFIED IDEOGRAPH-#7D32, IRGKangXi=0920.010, RSKangXi=120.5, Def{bridle; halter}
7D33 CJK UNIFIED IDEOGRAPH-#7D33, IRGKangXi=0920.020, RSKangXi=120.5, Def{girdle; tie, bind; gentry}
7D34 CJK UNIFIED IDEOGRAPH-#7D34, IRGKangXi=0920.050, RSKangXi=120.5
7D35 CJK UNIFIED IDEOGRAPH-#7D35, IRGKangXi=0920.070, RSKangXi=120.5, Def{ramie; sack cloth}
7D36 CJK UNIFIED IDEOGRAPH-#7D36, IRGKangXi=0920.090, RSKangXi=120.5
7D37 CJK UNIFIED IDEOGRAPH-#7D37, IRGKangXi=0920.140, RSKangXi=120.5
7D38 CJK UNIFIED IDEOGRAPH-#7D38, IRGKangXi=0920.150, RSKangXi=120.5
7D39 CJK UNIFIED IDEOGRAPH-#7D39, IRGKangXi=0920.160, RSKangXi=120.5, Def{continue, carry on; hand down; to join}
7D3A CJK UNIFIED IDEOGRAPH-#7D3A, IRGKangXi=0920.180, RSKangXi=120.5, Def{dark blue or reddish color}
7D3B CJK UNIFIED IDEOGRAPH-#7D3B, IRGKangXi=0920.190, RSKangXi=120.5
7D3C CJK UNIFIED IDEOGRAPH-#7D3C, IRGKangXi=0920.200, RSKangXi=120.5, Def{large rope; rope attached to bier}
7D3D CJK UNIFIED IDEOGRAPH-#7D3D, IRGKangXi=0920.220, RSKangXi=120.5, Def{a strand of silk}
7D3E CJK UNIFIED IDEOGRAPH-#7D3E, IRGKangXi=0920.230, RSKangXi=120.5, Def{turns or twist; a switch}
7D3F CJK UNIFIED IDEOGRAPH-#7D3F, IRGKangXi=0920.240, RSKangXi=120.5, Def{cheat, fool, pretend}
7D40 CJK UNIFIED IDEOGRAPH-#7D40, IRGKangXi=0920.250, RSKangXi=120.5, Def{sew, stitch; insufficient}
7D41 CJK UNIFIED IDEOGRAPH-#7D41, IRGKangXi=0920.260, RSKangXi=120.5, Def{rough, indelicate silk}
7D42 CJK UNIFIED IDEOGRAPH-#7D42, IRGKangXi=0921.010, RSKangXi=120.5, Def{end; finally, in the end}
7D43 CJK UNIFIED IDEOGRAPH-#7D43, IRGKangXi=0921.110, RSKangXi=120.5, Def{string on musical instrument}
7D44 CJK UNIFIED IDEOGRAPH-#7D44, IRGKangXi=0921.120, RSKangXi=120.5, Def{class; section, department}
7D45 CJK UNIFIED IDEOGRAPH-#7D45, IRGKangXi=0921.130, RSKangXi=120.5, Def{unlined garment, dust coat}
7D46 CJK UNIFIED IDEOGRAPH-#7D46, IRGKangXi=0921.140, RSKangXi=120.5, Def{loop, catch; fetter, shackle}
7D47 CJK UNIFIED IDEOGRAPH-#7D47, IRGKangXi=0921.150, RSKangXi=120.5
7D48 CJK UNIFIED IDEOGRAPH-#7D48, IRGKangXi=0921.160, RSKangXi=120.5
7D49 CJK UNIFIED IDEOGRAPH-#7D49, IRGKangXi=0921.170, RSKangXi=120.5
7D4A CJK UNIFIED IDEOGRAPH-#7D4A, IRGKangXi=0921.230, RSKangXi=120.5
7D4B CJK UNIFIED IDEOGRAPH-#7D4B, IRGKangXi=0921.291, RSKangXi=120.5
7D4C CJK UNIFIED IDEOGRAPH-#7D4C, IRGKangXi=0921.291, RSKangXi=120.5, Def{classic works; pass through}
7D4D CJK UNIFIED IDEOGRAPH-#7D4D, IRGKangXi=0921.300, RSKangXi=120.6, Def{to lay the warp; to weave}
7D4E CJK UNIFIED IDEOGRAPH-#7D4E, IRGKangXi=0921.320, RSKangXi=120.6, Def{baste}
7D4F CJK UNIFIED IDEOGRAPH-#7D4F, IRGKangXi=0921.330, RSKangXi=120.6, Def{rope, cable; reins; to tie up, bind}
7D50 CJK UNIFIED IDEOGRAPH-#7D50, IRGKangXi=0921.340, RSKangXi=120.6, Def{knot, tie; join, connect}
7D51 CJK UNIFIED IDEOGRAPH-#7D51, IRGKangXi=0921.360, RSKangXi=120.6
7D52 CJK UNIFIED IDEOGRAPH-#7D52, IRGKangXi=0921.370, RSKangXi=120.6
7D53 CJK UNIFIED IDEOGRAPH-#7D53, IRGKangXi=0921.390, RSKangXi=120.6, Def{obstructed; hindered}
7D54 CJK UNIFIED IDEOGRAPH-#7D54, IRGKangXi=0922.010, RSKangXi=120.6
7D55 CJK UNIFIED IDEOGRAPH-#7D55, IRGKangXi=0922.040, RSKangXi=120.6, Def{cut, sever, break off, terminate}
7D56 CJK UNIFIED IDEOGRAPH-#7D56, IRGKangXi=0922.080, RSKangXi=120.6, Def{fine silks; floss}
7D57 CJK UNIFIED IDEOGRAPH-#7D57, IRGKangXi=0922.100, RSKangXi=120.6
7D58 CJK UNIFIED IDEOGRAPH-#7D58, IRGKangXi=0922.110, RSKangXi=120.6
7D59 CJK UNIFIED IDEOGRAPH-#7D59, IRGKangXi=0922.140, RSKangXi=120.6
7D5A CJK UNIFIED IDEOGRAPH-#7D5A, IRGKangXi=0922.150, RSKangXi=120.6, Def{a rope}
7D5B CJK UNIFIED IDEOGRAPH-#7D5B, IRGKangXi=0922.160, RSKangXi=120.7, Def{silk braid, sash}
7D5C CJK UNIFIED IDEOGRAPH-#7D5C, IRGKangXi=0922.190, RSKangXi=120.6, Def{a marking line; ascertain, assess; measure}
7D5D CJK UNIFIED IDEOGRAPH-#7D5D, IRGKangXi=0922.200, RSKangXi=120.6, Def{trousers; breeches leggings; drawers}
7D5E CJK UNIFIED IDEOGRAPH-#7D5E, IRGKangXi=0922.210, RSKangXi=120.6, Def{twist, wring; intertwine; winch}
7D5F CJK UNIFIED IDEOGRAPH-#7D5F, IRGKangXi=0922.220, RSKangXi=120.6
7D60 CJK UNIFIED IDEOGRAPH-#7D60, IRGKangXi=0922.230, RSKangXi=120.6
7D61 CJK UNIFIED IDEOGRAPH-#7D61, IRGKangXi=0922.260, RSKangXi=120.6, Def{enmesh, wrap around; web, net}
7D62 CJK UNIFIED IDEOGRAPH-#7D62, IRGKangXi=0923.010, RSKangXi=120.6, Def{variegated, adorned; brilliant}
7D63 CJK UNIFIED IDEOGRAPH-#7D63, IRGKangXi=0923.030, RSKangXi=120.6, Def{to baste for sewing; to connect}
7D64 CJK UNIFIED IDEOGRAPH-#7D64, IRGKangXi=0923.040, RSKangXi=120.6
7D65 CJK UNIFIED IDEOGRAPH-#7D65, IRGKangXi=0923.050, RSKangXi=120.6, Def{to harness a horse a board in front of a carriage for the driver to lean on}
7D66 CJK UNIFIED IDEOGRAPH-#7D66, IRGKangXi=0923.060, RSKangXi=120.6, Def{give; by, for}
7D67 CJK UNIFIED IDEOGRAPH-#7D67, IRGKangXi=0923.070, RSKangXi=120.6
7D68 CJK UNIFIED IDEOGRAPH-#7D68, IRGKangXi=0923.090, RSKangXi=120.6, Def{silk, cotton, or woolen fabric}
7D69 CJK UNIFIED IDEOGRAPH-#7D69, IRGKangXi=0923.110, RSKangXi=120.6
7D6A CJK UNIFIED IDEOGRAPH-#7D6A, IRGKangXi=0923.120, RSKangXi=120.6, Def{matting; coverlet; cloudy}
7D6B CJK UNIFIED IDEOGRAPH-#7D6B, IRGKangXi=0923.130, RSKangXi=120.6
7D6C CJK UNIFIED IDEOGRAPH-#7D6C, IRGKangXi=0923.140, RSKangXi=120.6
7D6D CJK UNIFIED IDEOGRAPH-#7D6D, IRGKangXi=0923.160, RSKangXi=120.6
7D6E CJK UNIFIED IDEOGRAPH-#7D6E, IRGKangXi=0923.170, RSKangXi=120.6, Def{waste cotton, raw silk or cotton}
7D6F CJK UNIFIED IDEOGRAPH-#7D6F, IRGKangXi=0923.180, RSKangXi=120.6
7D70 CJK UNIFIED IDEOGRAPH-#7D70, IRGKangXi=0923.190, RSKangXi=120.6, Def{white hempen cloth worn by mourners}
7D71 CJK UNIFIED IDEOGRAPH-#7D71, IRGKangXi=0924.020, RSKangXi=120.6, Def{govern, command, control; unite}
7D72 CJK UNIFIED IDEOGRAPH-#7D72, IRGKangXi=0924.030, RSKangXi=120.6, Def{silk; fine thread; wire; strings}
7D73 CJK UNIFIED IDEOGRAPH-#7D73, IRGKangXi=0924.040, RSKangXi=120.6, Def{deep red; river in Shanxi provinc}
7D74 CJK UNIFIED IDEOGRAPH-#7D74, IRGKangXi=0924.130, RSKangXi=120.6
7D75 CJK UNIFIED IDEOGRAPH-#7D75, IRGKangXi=0924.161, RSKangXi=120.6, Def{draw, sketch, paint}
7D76 CJK UNIFIED IDEOGRAPH-#7D76, IRGKangXi=0924.161, RSKangXi=120.6, Def{cut}
7D77 CJK UNIFIED IDEOGRAPH-#7D77, IRGKangXi=0924.161, RSKangXi=120.6, Def{confine, tie up; imprison, shackle}
7D78 CJK UNIFIED IDEOGRAPH-#7D78, IRGKangXi=0924.170, RSKangXi=120.7
7D79 CJK UNIFIED IDEOGRAPH-#7D79, IRGKangXi=0924.210, RSKangXi=120.7, Def{kind of thick stiff silk}
7D7A CJK UNIFIED IDEOGRAPH-#7D7A, IRGKangXi=0924.220, RSKangXi=120.7, Def{fine linen; fine hemp fiber}
7D7B CJK UNIFIED IDEOGRAPH-#7D7B, IRGKangXi=0924.230, RSKangXi=120.7, Def{mourning}
7D7C CJK UNIFIED IDEOGRAPH-#7D7C, IRGKangXi=0924.240, RSKangXi=120.7
7D7D CJK UNIFIED IDEOGRAPH-#7D7D, IRGKangXi=0924.250, RSKangXi=120.7, Def{a silk gauze}
7D7E CJK UNIFIED IDEOGRAPH-#7D7E, IRGKangXi=0924.260, RSKangXi=120.7
7D7F CJK UNIFIED IDEOGRAPH-#7D7F, IRGKangXi=0924.280, RSKangXi=120.7, Def{urgent}
7D80 CJK UNIFIED IDEOGRAPH-#7D80, IRGKangXi=0924.310, RSKangXi=120.7, Def{a kind of sackcloth}
7D81 CJK UNIFIED IDEOGRAPH-#7D81, IRGKangXi=0924.340, RSKangXi=120.7, Def{bind, tie, fasten}
7D82 CJK UNIFIED IDEOGRAPH-#7D82, IRGKangXi=0924.350, RSKangXi=120.7, Def{govern, command, control; unite}
7D83 CJK UNIFIED IDEOGRAPH-#7D83, IRGKangXi=0924.360, RSKangXi=120.7, Def{raw silk fabric}
7D84 CJK UNIFIED IDEOGRAPH-#7D84, IRGKangXi=0925.010, RSKangXi=120.7
7D85 CJK UNIFIED IDEOGRAPH-#7D85, IRGKangXi=0925.030, RSKangXi=120.7, Def{thread}
7D86 CJK UNIFIED IDEOGRAPH-#7D86, IRGKangXi=0925.040, RSKangXi=120.7, Def{well rope}
7D87 CJK UNIFIED IDEOGRAPH-#7D87, IRGKangXi=0925.060, RSKangXi=120.7
7D88 CJK UNIFIED IDEOGRAPH-#7D88, IRGKangXi=0925.070, RSKangXi=120.7, Def{coarse pongee, kind of heavy silk}
7D89 CJK UNIFIED IDEOGRAPH-#7D89, IRGKangXi=0925.090, RSKangXi=120.7, Def{embroider; embroidery; ornament}
7D8A CJK UNIFIED IDEOGRAPH-#7D8A, IRGKangXi=0925.100, RSKangXi=120.7
7D8B CJK UNIFIED IDEOGRAPH-#7D8B, IRGKangXi=0925.110, RSKangXi=120.7
7D8C CJK UNIFIED IDEOGRAPH-#7D8C, IRGKangXi=0925.130, RSKangXi=120.7, Def{cloth}
7D8D CJK UNIFIED IDEOGRAPH-#7D8D, IRGKangXi=0925.150, RSKangXi=120.7, Def{rope}
7D8E CJK UNIFIED IDEOGRAPH-#7D8E, IRGKangXi=0925.160, RSKangXi=120.7, Def{silk braided cord}
7D8F CJK UNIFIED IDEOGRAPH-#7D8F, IRGKangXi=0925.170, RSKangXi=120.7, Def{soothe, appease, pacify; carriage harness}
7D90 CJK UNIFIED IDEOGRAPH-#7D90, IRGKangXi=0925.200, RSKangXi=120.7, Def{a kind of fine silk fabric}
7D91 CJK UNIFIED IDEOGRAPH-#7D91, IRGKangXi=0925.220, RSKangXi=120.7, Def{coil, roll, bundle, tie up}
7D92 CJK UNIFIED IDEOGRAPH-#7D92, IRGKangXi=0925.230, RSKangXi=120.7
7D93 CJK UNIFIED IDEOGRAPH-#7D93, IRGKangXi=0925.240, RSKangXi=120.7, Def{classic works; pass through}
7D94 CJK UNIFIED IDEOGRAPH-#7D94, IRGKangXi=0926.010, RSKangXi=120.7
7D95 CJK UNIFIED IDEOGRAPH-#7D95, IRGKangXi=0926.020, RSKangXi=120.7
7D96 CJK UNIFIED IDEOGRAPH-#7D96, IRGKangXi=0926.070, RSKangXi=120.7, Def{the hanging flap in the front of a hat}
7D97 CJK UNIFIED IDEOGRAPH-#7D97, IRGKangXi=0926.201, RSKangXi=120.7
7D98 CJK UNIFIED IDEOGRAPH-#7D98, IRGKangXi=0926.130, RSKangXi=120.7
7D99 CJK UNIFIED IDEOGRAPH-#7D99, IRGKangXi=0926.201, RSKangXi=120.7, Def{continue, maintain, carry on}
7D9A CJK UNIFIED IDEOGRAPH-#7D9A, IRGKangXi=0926.201, RSKangXi=120.7, Def{continue, carry on; succeed}
7D9B CJK UNIFIED IDEOGRAPH-#7D9B, IRGKangXi=0926.201, RSKangXi=120.7
7D9C CJK UNIFIED IDEOGRAPH-#7D9C, IRGKangXi=0926.210, RSKangXi=120.8, Def{arrange threads for weaving}
7D9D CJK UNIFIED IDEOGRAPH-#7D9D, IRGKangXi=0926.230, RSKangXi=120.8, Def{to stop; adjusted, in order}
7D9E CJK UNIFIED IDEOGRAPH-#7D9E, IRGKangXi=0926.240, RSKangXi=120.8
7D9F CJK UNIFIED IDEOGRAPH-#7D9F, IRGKangXi=0926.260, RSKangXi=120.8
7DA0 CJK UNIFIED IDEOGRAPH-#7DA0, IRGKangXi=0926.270, RSKangXi=120.8, Def{green; chlorine}
7DA1 CJK UNIFIED IDEOGRAPH-#7DA1, IRGKangXi=0926.310, RSKangXi=120.8
7DA2 CJK UNIFIED IDEOGRAPH-#7DA2, IRGKangXi=0926.320, RSKangXi=120.8, Def{silk cloth, satin damask}
7DA3 CJK UNIFIED IDEOGRAPH-#7DA3, IRGKangXi=0926.360, RSKangXi=120.8, Def{affectionate, solicitous}
7DA4 CJK UNIFIED IDEOGRAPH-#7DA4, IRGKangXi=0926.370, RSKangXi=120.8
7DA5 CJK UNIFIED IDEOGRAPH-#7DA5, IRGKangXi=0926.400, RSKangXi=120.8
7DA6 CJK UNIFIED IDEOGRAPH-#7DA6, IRGKangXi=0926.410, RSKangXi=120.8, Def{dark grey. variegated. superlative}
7DA7 CJK UNIFIED IDEOGRAPH-#7DA7, IRGKangXi=0927.030, RSKangXi=120.8
7DA8 CJK UNIFIED IDEOGRAPH-#7DA8, IRGKangXi=0927.040, RSKangXi=120.8
7DA9 CJK UNIFIED IDEOGRAPH-#7DA9, IRGKangXi=0927.060, RSKangXi=120.8
7DAA CJK UNIFIED IDEOGRAPH-#7DAA, IRGKangXi=0927.080, RSKangXi=120.8, Def{dark red}
7DAB CJK UNIFIED IDEOGRAPH-#7DAB, IRGKangXi=0927.100, RSKangXi=120.8, Def{line, thread, wire; clue}
7DAC CJK UNIFIED IDEOGRAPH-#7DAC, IRGKangXi=0927.120, RSKangXi=120.8, Def{silk ribbon attached as a seal}
7DAD CJK UNIFIED IDEOGRAPH-#7DAD, IRGKangXi=0927.150, RSKangXi=120.8, Def{maintain, preserve, safeguard}
7DAE CJK UNIFIED IDEOGRAPH-#7DAE, IRGKangXi=0927.160, RSKangXi=120.8, Def{embroidered banner}
7DAF CJK UNIFIED IDEOGRAPH-#7DAF, IRGKangXi=0927.200, RSKangXi=120.8, Def{to braid, twist; twisted or braided}
7DB0 CJK UNIFIED IDEOGRAPH-#7DB0, IRGKangXi=0927.230, RSKangXi=120.8, Def{to string together, to bind up}
7DB1 CJK UNIFIED IDEOGRAPH-#7DB1, IRGKangXi=0927.240, RSKangXi=120.8, Def{heavy rope, hawser; main points}
7DB2 CJK UNIFIED IDEOGRAPH-#7DB2, IRGKangXi=0928.010, RSKangXi=120.8, Def{net, web; network}
7DB3 CJK UNIFIED IDEOGRAPH-#7DB3, IRGKangXi=0928.020, RSKangXi=120.8, Def{a cloth to carry an infant on the back; to tie; to bind}
7DB4 CJK UNIFIED IDEOGRAPH-#7DB4, IRGKangXi=0928.030, RSKangXi=120.8, Def{patch together, link, connect}
7DB5 CJK UNIFIED IDEOGRAPH-#7DB5, IRGKangXi=0928.040, RSKangXi=120.8, Def{varicolored silk; variegated}
7DB6 CJK UNIFIED IDEOGRAPH-#7DB6, IRGKangXi=0928.050, RSKangXi=120.8
7DB7 CJK UNIFIED IDEOGRAPH-#7DB7, IRGKangXi=0928.060, RSKangXi=120.8
7DB8 CJK UNIFIED IDEOGRAPH-#7DB8, IRGKangXi=0928.070, RSKangXi=120.8, Def{green silk thread or tassel}
7DB9 CJK UNIFIED IDEOGRAPH-#7DB9, IRGKangXi=0928.090, RSKangXi=120.8, Def{skein; tuft, lock; wrinkle}
7DBA CJK UNIFIED IDEOGRAPH-#7DBA, IRGKangXi=0928.100, RSKangXi=120.8, Def{fine thin silk; elegant, beautifu}
7DBB CJK UNIFIED IDEOGRAPH-#7DBB, IRGKangXi=0928.110, RSKangXi=120.8, Def{ripped seam, rend, crack}
7DBC CJK UNIFIED IDEOGRAPH-#7DBC, IRGKangXi=0928.130, RSKangXi=120.8
7DBD CJK UNIFIED IDEOGRAPH-#7DBD, IRGKangXi=0928.140, RSKangXi=120.8, Def{graceful, delicate; spacious}
7DBE CJK UNIFIED IDEOGRAPH-#7DBE, IRGKangXi=0928.160, RSKangXi=120.8, Def{thin silk, damask silk}
7DBF CJK UNIFIED IDEOGRAPH-#7DBF, IRGKangXi=0928.170, RSKangXi=120.8, Def{cotton wad; wool; soft, downy}
7DC0 CJK UNIFIED IDEOGRAPH-#7DC0, IRGKangXi=0928.180, RSKangXi=120.8
7DC1 CJK UNIFIED IDEOGRAPH-#7DC1, IRGKangXi=0928.190, RSKangXi=120.8, Def{to join, to splice, to braid}
7DC2 CJK UNIFIED IDEOGRAPH-#7DC2, IRGKangXi=0928.200, RSKangXi=120.8
7DC3 CJK UNIFIED IDEOGRAPH-#7DC3, IRGKangXi=0929.010, RSKangXi=120.8, Def{perpendicular, erect}
7DC4 CJK UNIFIED IDEOGRAPH-#7DC4, IRGKangXi=0929.020, RSKangXi=120.8, Def{cord; woven belt; hem; hemming}
7DC5 CJK UNIFIED IDEOGRAPH-#7DC5, IRGKangXi=0929.030, RSKangXi=120.8, Def{silk of purplish color}
7DC6 CJK UNIFIED IDEOGRAPH-#7DC6, IRGKangXi=0929.040, RSKangXi=120.8
7DC7 CJK UNIFIED IDEOGRAPH-#7DC7, IRGKangXi=0929.050, RSKangXi=120.8, Def{black silk}
7DC8 CJK UNIFIED IDEOGRAPH-#7DC8, IRGKangXi=0929.060, RSKangXi=120.8
7DC9 CJK UNIFIED IDEOGRAPH-#7DC9, IRGKangXi=0929.070, RSKangXi=120.8
7DCA CJK UNIFIED IDEOGRAPH-#7DCA, IRGKangXi=0929.080, RSKangXi=120.8, Def{tense, tight, taut; firm, secure}
7DCB CJK UNIFIED IDEOGRAPH-#7DCB, IRGKangXi=0929.090, RSKangXi=120.8, Def{scarlet, dark red, crimson; purple}
7DCC CJK UNIFIED IDEOGRAPH-#7DCC, IRGKangXi=0929.100, RSKangXi=120.8, Def{tassels hanging from hat}
7DCD CJK UNIFIED IDEOGRAPH-#7DCD, IRGKangXi=0929.120, RSKangXi=120.8, Def{variant of 緡 U+7DE1, a fishing-line; cord; string of coins; a paper or straw string}
7DCE CJK UNIFIED IDEOGRAPH-#7DCE, IRGKangXi=0929.130, RSKangXi=120.8, Def{seam}
7DCF CJK UNIFIED IDEOGRAPH-#7DCF, IRGKangXi=0929.240, RSKangXi=120.8, Def{collect; overall, altogether}
7DD0 CJK UNIFIED IDEOGRAPH-#7DD0, IRGKangXi=0929.291, RSKangXi=120.8
7DD1 CJK UNIFIED IDEOGRAPH-#7DD1, IRGKangXi=0929.291, RSKangXi=120.8, Def{green; chlorine}
7DD2 CJK UNIFIED IDEOGRAPH-#7DD2, IRGKangXi=0929.291, RSKangXi=120.8, Def{end of thread; thread}
7DD3 CJK UNIFIED IDEOGRAPH-#7DD3, IRGKangXi=0933.061, RSKangXi=120.9
7DD4 CJK UNIFIED IDEOGRAPH-#7DD4, IRGKangXi=0929.291, RSKangXi=120.8, Def{the piece of leather used for soles on Chinese shoes; a patch}
7DD5 CJK UNIFIED IDEOGRAPH-#7DD5, IRGKangXi=0929.291, RSKangXi=120.8
7DD6 CJK UNIFIED IDEOGRAPH-#7DD6, IRGKangXi=0929.300, RSKangXi=120.9, Def{end of thread; thread, clue}
7DD7 CJK UNIFIED IDEOGRAPH-#7DD7, IRGKangXi=0929.330, RSKangXi=120.9, Def{light-yellow color}
7DD8 CJK UNIFIED IDEOGRAPH-#7DD8, IRGKangXi=0930.020, RSKangXi=120.9, Def{seal, close; bind; letter}
7DD9 CJK UNIFIED IDEOGRAPH-#7DD9, IRGKangXi=0930.030, RSKangXi=120.9, Def{the woof of a woven item}
7DDA CJK UNIFIED IDEOGRAPH-#7DDA, IRGKangXi=0930.050, RSKangXi=120.9, Def{thread, line, wire; clue}
7DDB CJK UNIFIED IDEOGRAPH-#7DDB, IRGKangXi=0930.070, RSKangXi=120.9
7DDC CJK UNIFIED IDEOGRAPH-#7DDC, IRGKangXi=0930.080, RSKangXi=120.9, Def{cotton wad; wool; soft, downy}
7DDD CJK UNIFIED IDEOGRAPH-#7DDD, IRGKangXi=0930.090, RSKangXi=120.9, Def{to sew in close stitches}
7DDE CJK UNIFIED IDEOGRAPH-#7DDE, IRGKangXi=0930.100, RSKangXi=120.9, Def{satin}
7DDF CJK UNIFIED IDEOGRAPH-#7DDF, IRGKangXi=0930.130, RSKangXi=120.9
7DE0 CJK UNIFIED IDEOGRAPH-#7DE0, IRGKangXi=0930.140, RSKangXi=120.9, Def{tie, join, connect; connection}
7DE1 CJK UNIFIED IDEOGRAPH-#7DE1, IRGKangXi=0930.150, RSKangXi=120.9, Def{a fishing-line; cord; string of coins; a paper or straw string}
7DE2 CJK UNIFIED IDEOGRAPH-#7DE2, IRGKangXi=0930.160, RSKangXi=120.9
7DE3 CJK UNIFIED IDEOGRAPH-#7DE3, IRGKangXi=0930.190, RSKangXi=120.9, Def{hem, margin; reason, cause; karma, fate}
7DE4 CJK UNIFIED IDEOGRAPH-#7DE4, IRGKangXi=0930.200, RSKangXi=120.9, Def{cord}
7DE5 CJK UNIFIED IDEOGRAPH-#7DE5, IRGKangXi=0931.020, RSKangXi=120.9, Def{swaddling}
7DE6 CJK UNIFIED IDEOGRAPH-#7DE6, IRGKangXi=0931.030, RSKangXi=120.9, Def{coarse cotton cloth used for mourning}
7DE7 CJK UNIFIED IDEOGRAPH-#7DE7, IRGKangXi=0931.060, RSKangXi=120.9
7DE8 CJK UNIFIED IDEOGRAPH-#7DE8, IRGKangXi=0931.080, RSKangXi=120.9, Def{knit, weave; arrange; compile}
7DE9 CJK UNIFIED IDEOGRAPH-#7DE9, IRGKangXi=0931.120, RSKangXi=120.9, Def{slow, leisurely; to postpone, delay}
7DEA CJK UNIFIED IDEOGRAPH-#7DEA, IRGKangXi=0931.140, RSKangXi=120.9, Def{a rope}
7DEB CJK UNIFIED IDEOGRAPH-#7DEB, IRGKangXi=0931.150, RSKangXi=120.9
7DEC CJK UNIFIED IDEOGRAPH-#7DEC, IRGKangXi=0931.180, RSKangXi=120.9, Def{distant, remote; think of}
7DED CJK UNIFIED IDEOGRAPH-#7DED, IRGKangXi=0931.210, RSKangXi=120.9
7DEE CJK UNIFIED IDEOGRAPH-#7DEE, IRGKangXi=0933.061, RSKangXi=120.9
7DEF CJK UNIFIED IDEOGRAPH-#7DEF, IRGKangXi=0931.260, RSKangXi=120.9, Def{woof; parallels of latitude}
7DF0 CJK UNIFIED IDEOGRAPH-#7DF0, IRGKangXi=0931.270, RSKangXi=120.9, Def{net}
7DF1 CJK UNIFIED IDEOGRAPH-#7DF1, IRGKangXi=0931.280, RSKangXi=120.9, Def{cord binding on hilt of sword}
7DF2 CJK UNIFIED IDEOGRAPH-#7DF2, IRGKangXi=0932.020, RSKangXi=120.9, Def{indistinct, dim; minute; distant}
7DF3 CJK UNIFIED IDEOGRAPH-#7DF3, IRGKangXi=0932.030, RSKangXi=120.9
7DF4 CJK UNIFIED IDEOGRAPH-#7DF4, IRGKangXi=0932.040, RSKangXi=120.9, Def{practice, drill, exercise, train}
7DF5 CJK UNIFIED IDEOGRAPH-#7DF5, IRGKangXi=0932.070, RSKangXi=120.9, Def{net}
7DF6 CJK UNIFIED IDEOGRAPH-#7DF6, IRGKangXi=0932.080, RSKangXi=120.9, Def{hem; plait, braid, queue}
7DF7 CJK UNIFIED IDEOGRAPH-#7DF7, IRGKangXi=0932.100, RSKangXi=120.9
7DF8 CJK UNIFIED IDEOGRAPH-#7DF8, IRGKangXi=0932.120, RSKangXi=120.9
7DF9 CJK UNIFIED IDEOGRAPH-#7DF9, IRGKangXi=0932.130, RSKangXi=120.9, Def{reddish color, red, brown}
7DFA CJK UNIFIED IDEOGRAPH-#7DFA, IRGKangXi=0932.140, RSKangXi=120.9
7DFB CJK UNIFIED IDEOGRAPH-#7DFB, IRGKangXi=0932.150, RSKangXi=120.9, Def{delicate, fine; dense}
7DFC CJK UNIFIED IDEOGRAPH-#7DFC, IRGKangXi=0932.160, RSKangXi=120.9, Def{variant of 縕 U+7E15, tangled hemp, raveled silk; vague, confused}
7DFD CJK UNIFIED IDEOGRAPH-#7DFD, IRGKangXi=0932.240, RSKangXi=120.9
7DFE CJK UNIFIED IDEOGRAPH-#7DFE, IRGKangXi=0932.310, RSKangXi=120.9
7DFF CJK UNIFIED IDEOGRAPH-#7DFF, IRGKangXi=0932.360, RSKangXi=120.9
7E00 CJK UNIFIED IDEOGRAPH-#7E00, IRGKangXi=0933.061, RSKangXi=120.9
7E01 CJK UNIFIED IDEOGRAPH-#7E01, IRGKangXi=0933.061, RSKangXi=120.9, Def{hem}
7E02 CJK UNIFIED IDEOGRAPH-#7E02, IRGKangXi=0933.061, Def{collect; overall, altogether}
7E03 CJK UNIFIED IDEOGRAPH-#7E03, IRGKangXi=0933.061, RSKangXi=120.9
7E04 CJK UNIFIED IDEOGRAPH-#7E04, IRGKangXi=0933.061, RSKangXi=120.9, Def{rope, string, cord; control}
7E05 CJK UNIFIED IDEOGRAPH-#7E05, IRGKangXi=0933.061, RSKangXi=120.9, Def{to threaten, intimidate}
7E06 CJK UNIFIED IDEOGRAPH-#7E06, IRGKangXi=0933.061, RSKangXi=120.9, Def{a rope}
7E07 CJK UNIFIED IDEOGRAPH-#7E07, IRGKangXi=0933.061, RSKangXi=120.9, Def{decoration}
7E08 CJK UNIFIED IDEOGRAPH-#7E08, IRGKangXi=0933.090, RSKangXi=120.10, Def{entangle, entwine, coil}
7E09 CJK UNIFIED IDEOGRAPH-#7E09, IRGKangXi=0933.130, RSKangXi=120.10, Def{red silk}
7E0A CJK UNIFIED IDEOGRAPH-#7E0A, IRGKangXi=0933.140, RSKangXi=120.10, Def{hang, strangle}
7E0B CJK UNIFIED IDEOGRAPH-#7E0B, IRGKangXi=0933.160, RSKangXi=120.10, Def{climb down rope; hang by rope}
7E0C CJK UNIFIED IDEOGRAPH-#7E0C, IRGKangXi=0933.170, RSKangXi=120.10
7E0D CJK UNIFIED IDEOGRAPH-#7E0D, IRGKangXi=0933.190, RSKangXi=120.10
7E0E CJK UNIFIED IDEOGRAPH-#7E0E, IRGKangXi=0933.210, RSKangXi=120.10
7E0F CJK UNIFIED IDEOGRAPH-#7E0F, IRGKangXi=0933.220, RSKangXi=120.10, Def{purse}
7E10 CJK UNIFIED IDEOGRAPH-#7E10, IRGKangXi=0933.230, RSKangXi=120.10, Def{crepe, crape, wrinkles, creases}
7E11 CJK UNIFIED IDEOGRAPH-#7E11, IRGKangXi=0933.260, RSKangXi=120.10, Def{fine silk}
7E12 CJK UNIFIED IDEOGRAPH-#7E12, IRGKangXi=0933.270, RSKangXi=120.10, Def{to twist}
7E13 CJK UNIFIED IDEOGRAPH-#7E13, IRGKangXi=0933.280, RSKangXi=120.10, Def{orange or reddish-yellow silk}
7E14 CJK UNIFIED IDEOGRAPH-#7E14, IRGKangXi=0933.320, RSKangXi=120.10
7E15 CJK UNIFIED IDEOGRAPH-#7E15, IRGKangXi=0933.330, RSKangXi=120.10, Def{tangled hemp, raveled silk; vague, confused}
7E16 CJK UNIFIED IDEOGRAPH-#7E16, IRGKangXi=0933.350, RSKangXi=120.10
7E17 CJK UNIFIED IDEOGRAPH-#7E17, IRGKangXi=0933.370, RSKangXi=120.10, Def{sackcloth worn on breast during}
7E18 CJK UNIFIED IDEOGRAPH-#7E18, IRGKangXi=0934.010, RSKangXi=120.10
7E19 CJK UNIFIED IDEOGRAPH-#7E19, IRGKangXi=0934.070, RSKangXi=120.10
7E1A CJK UNIFIED IDEOGRAPH-#7E1A, IRGKangXi=0934.090, RSKangXi=120.10, Def{band}
7E1B CJK UNIFIED IDEOGRAPH-#7E1B, IRGKangXi=0934.100, RSKangXi=120.10, Def{to tie}
7E1C CJK UNIFIED IDEOGRAPH-#7E1C, IRGKangXi=0934.120, RSKangXi=120.10
7E1D CJK UNIFIED IDEOGRAPH-#7E1D, IRGKangXi=0934.140, RSKangXi=120.10, Def{detailed, fine; closely woven}
7E1E CJK UNIFIED IDEOGRAPH-#7E1E, IRGKangXi=0934.160, RSKangXi=120.10, Def{white raw silk}
7E1F CJK UNIFIED IDEOGRAPH-#7E1F, IRGKangXi=0934.180, RSKangXi=120.10, Def{decorative, adorned, elegant}
7E20 CJK UNIFIED IDEOGRAPH-#7E20, IRGKangXi=0934.190, RSKangXi=120.10, Def{crepe}
7E21 CJK UNIFIED IDEOGRAPH-#7E21, IRGKangXi=0934.200, RSKangXi=120.10, Def{matter, affair}
7E22 CJK UNIFIED IDEOGRAPH-#7E22, IRGKangXi=0934.220, RSKangXi=120.10, Def{bind, tie up, restrain; cord}
7E23 CJK UNIFIED IDEOGRAPH-#7E23, IRGKangXi=0934.230, RSKangXi=120.10, Def{county, district, subdivision}
7E24 CJK UNIFIED IDEOGRAPH-#7E24, IRGKangXi=0935.050, RSKangXi=120.10
7E25 CJK UNIFIED IDEOGRAPH-#7E25, IRGKangXi=0935.060, RSKangXi=120.10
7E26 CJK UNIFIED IDEOGRAPH-#7E26, IRGKangXi=0935.181, RSKangXi=120.10, Def{indulge in, give free reign to}
7E27 CJK UNIFIED IDEOGRAPH-#7E27, IRGKangXi=0935.181, RSKangXi=120.10, Def{silk cord, ribbon}
7E28 CJK UNIFIED IDEOGRAPH-#7E28, IRGKangXi=0935.181, RSKangXi=120.10
7E29 CJK UNIFIED IDEOGRAPH-#7E29, IRGKangXi=0935.190, RSKangXi=120.11
7E2A CJK UNIFIED IDEOGRAPH-#7E2A, IRGKangXi=0935.200, RSKangXi=120.11
7E2B CJK UNIFIED IDEOGRAPH-#7E2B, IRGKangXi=0935.210, RSKangXi=120.11, Def{sew, mend}
7E2C CJK UNIFIED IDEOGRAPH-#7E2C, IRGKangXi=0935.240, RSKangXi=120.11
7E2D CJK UNIFIED IDEOGRAPH-#7E2D, IRGKangXi=0935.260, RSKangXi=120.11, Def{a bridal veil; to tie; to bind}
7E2E CJK UNIFIED IDEOGRAPH-#7E2E, IRGKangXi=0935.270, RSKangXi=120.11, Def{contract, draw in, reduce}
7E2F CJK UNIFIED IDEOGRAPH-#7E2F, IRGKangXi=0935.280, RSKangXi=120.11, Def{long}
7E30 CJK UNIFIED IDEOGRAPH-#7E30, IRGKangXi=0935.300, RSKangXi=120.11, Def{band for the hair}
7E31 CJK UNIFIED IDEOGRAPH-#7E31, IRGKangXi=0935.310, RSKangXi=120.11, Def{indulge in, give free reign to}
7E32 CJK UNIFIED IDEOGRAPH-#7E32, IRGKangXi=0935.340, RSKangXi=120.11, Def{a chain or rope used bind criminals}
7E33 CJK UNIFIED IDEOGRAPH-#7E33, IRGKangXi=0936.020, RSKangXi=120.11, Def{wrap}
7E34 CJK UNIFIED IDEOGRAPH-#7E34, IRGKangXi=0936.050, RSKangXi=120.11, Def{tow line}
7E35 CJK UNIFIED IDEOGRAPH-#7E35, IRGKangXi=0936.070, RSKangXi=120.11, Def{plain silk; simple, plain}
7E36 CJK UNIFIED IDEOGRAPH-#7E36, IRGKangXi=0936.090, RSKangXi=120.11, Def{confine, tie up; imprison, shackle}
7E37 CJK UNIFIED IDEOGRAPH-#7E37, IRGKangXi=0936.100, RSKangXi=120.11, Def{thread; detailed, precise}
7E38 CJK UNIFIED IDEOGRAPH-#7E38, IRGKangXi=0936.140, RSKangXi=120.11
7E39 CJK UNIFIED IDEOGRAPH-#7E39, IRGKangXi=0936.150, RSKangXi=120.11, Def{light blue silk; dim; misty}
7E3A CJK UNIFIED IDEOGRAPH-#7E3A, IRGKangXi=0936.160, RSKangXi=120.11, Def{to tangle, knot, kink, get twisted; to get complicated}
7E3B CJK UNIFIED IDEOGRAPH-#7E3B, IRGKangXi=0936.170, RSKangXi=120.11, Def{halter for ox; tie up, harness}
7E3C CJK UNIFIED IDEOGRAPH-#7E3C, IRGKangXi=0936.200, RSKangXi=120.11
7E3D CJK UNIFIED IDEOGRAPH-#7E3D, IRGKangXi=0936.210, RSKangXi=120.11, Def{collect; overall, altogether}
7E3E CJK UNIFIED IDEOGRAPH-#7E3E, IRGKangXi=0936.230, RSKangXi=120.11, Def{spin; achievements}
7E3F CJK UNIFIED IDEOGRAPH-#7E3F, IRGKangXi=0936.250, RSKangXi=120.11, Def{streamer}
7E40 CJK UNIFIED IDEOGRAPH-#7E40, IRGKangXi=0936.260, RSKangXi=120.11
7E41 CJK UNIFIED IDEOGRAPH-#7E41, IRGKangXi=0937.010, RSKangXi=120.11, Def{complicated, complex, difficult}
7E42 CJK UNIFIED IDEOGRAPH-#7E42, IRGKangXi=0937.030, RSKangXi=120.11
7E43 CJK UNIFIED IDEOGRAPH-#7E43, IRGKangXi=0937.040, RSKangXi=120.11, Def{bind, draw firmly, strap}
7E44 CJK UNIFIED IDEOGRAPH-#7E44, IRGKangXi=0937.050, RSKangXi=120.11, Def{be; particle; sigh, alas}
7E45 CJK UNIFIED IDEOGRAPH-#7E45, IRGKangXi=0937.060, RSKangXi=120.11, Def{draw, reel silk from cocoons; elegant compositions}
7E46 CJK UNIFIED IDEOGRAPH-#7E46, IRGKangXi=0937.080, RSKangXi=120.11, Def{wind around, bind; prepare}
7E47 CJK UNIFIED IDEOGRAPH-#7E47, IRGKangXi=0937.090, RSKangXi=120.11, Def{reason, cause}
7E48 CJK UNIFIED IDEOGRAPH-#7E48, IRGKangXi=0937.100, RSKangXi=120.12, Def{string of copper coins; swaddling clothes}
7E49 CJK UNIFIED IDEOGRAPH-#7E49, IRGKangXi=0938.060, RSKangXi=120.11
7E4A CJK UNIFIED IDEOGRAPH-#7E4A, IRGKangXi=0938.141, RSKangXi=120.11, Def{fine, delicate; minute; graceful}
7E4B CJK UNIFIED IDEOGRAPH-#7E4B, IRGKangXi=0938.141, RSKangXi=120.13, Def{attach, connect, unite, fasten}
7E4C CJK UNIFIED IDEOGRAPH-#7E4C, IRGKangXi=0938.141, RSKangXi=120.11
7E4D CJK UNIFIED IDEOGRAPH-#7E4D, IRGKangXi=0938.141, RSKangXi=120.11, Def{embroider; embroidery; ornament}
7E4E CJK UNIFIED IDEOGRAPH-#7E4E, IRGKangXi=0938.150, RSKangXi=120.12
7E4F CJK UNIFIED IDEOGRAPH-#7E4F, IRGKangXi=0938.180, RSKangXi=120.12
7E50 CJK UNIFIED IDEOGRAPH-#7E50, IRGKangXi=0938.190, RSKangXi=120.12, Def{fine cloth}
7E51 CJK UNIFIED IDEOGRAPH-#7E51, IRGKangXi=0938.230, RSKangXi=120.12
7E52 CJK UNIFIED IDEOGRAPH-#7E52, IRGKangXi=0938.250, RSKangXi=120.12, Def{silk fabrics; surname}
7E53 CJK UNIFIED IDEOGRAPH-#7E53, IRGKangXi=0938.280, RSKangXi=120.12
7E54 CJK UNIFIED IDEOGRAPH-#7E54, IRGKangXi=0938.290, RSKangXi=120.12, Def{weave, knit; organize, unite}
7E55 CJK UNIFIED IDEOGRAPH-#7E55, IRGKangXi=0938.340, RSKangXi=120.12, Def{repair, mend; rewrite, transcribe}
7E56 CJK UNIFIED IDEOGRAPH-#7E56, IRGKangXi=0938.370, RSKangXi=120.12, Def{umbrella, parasol, parachute}
7E57 CJK UNIFIED IDEOGRAPH-#7E57, IRGKangXi=0939.020, RSKangXi=120.12
7E58 CJK UNIFIED IDEOGRAPH-#7E58, IRGKangXi=0939.030, RSKangXi=120.12, Def{rope}
7E59 CJK UNIFIED IDEOGRAPH-#7E59, IRGKangXi=0939.060, RSKangXi=120.12, Def{to interpret; to flap, flutter in the wind}
7E5A CJK UNIFIED IDEOGRAPH-#7E5A, IRGKangXi=0939.090, RSKangXi=120.12, Def{wind round, rap around, bind}
7E5B CJK UNIFIED IDEOGRAPH-#7E5B, IRGKangXi=0939.100, RSKangXi=120.12
7E5C CJK UNIFIED IDEOGRAPH-#7E5C, IRGKangXi=0939.110, RSKangXi=120.12
7E5D CJK UNIFIED IDEOGRAPH-#7E5D, IRGKangXi=0939.130, RSKangXi=120.12
7E5E CJK UNIFIED IDEOGRAPH-#7E5E, IRGKangXi=0939.140, RSKangXi=120.12, Def{entwine; wind around; surround}
7E5F CJK UNIFIED IDEOGRAPH-#7E5F, IRGKangXi=0939.150, RSKangXi=120.12
7E60 CJK UNIFIED IDEOGRAPH-#7E60, IRGKangXi=0939.170, RSKangXi=120.12, Def{hang}
7E61 CJK UNIFIED IDEOGRAPH-#7E61, IRGKangXi=0939.180, RSKangXi=120.12, Def{embroider; embroidery; ornament}
7E62 CJK UNIFIED IDEOGRAPH-#7E62, IRGKangXi=0939.190, RSKangXi=120.12, Def{draw, sketch, paint}
7E63 CJK UNIFIED IDEOGRAPH-#7E63, IRGKangXi=0939.230, RSKangXi=120.12, Def{obstinate; perverse}
7E64 CJK UNIFIED IDEOGRAPH-#7E64, IRGKangXi=0939.300, RSKangXi=120.12, Def{edit}
7E65 CJK UNIFIED IDEOGRAPH-#7E65, IRGKangXi=0939.310, RSKangXi=120.12
7E66 CJK UNIFIED IDEOGRAPH-#7E66, IRGKangXi=0940.031, RSKangXi=120.13, Def{string of copper coins; swaddling}
7E67 CJK UNIFIED IDEOGRAPH-#7E67, IRGKangXi=0940.031, RSKangXi=120.12
7E68 CJK UNIFIED IDEOGRAPH-#7E68, IRGKangXi=0941.271, RSKangXi=120.13, Def{a knot (of a rope)}
7E69 CJK UNIFIED IDEOGRAPH-#7E69, IRGKangXi=0940.040, RSKangXi=120.13, Def{rope, string, cord; measure, restrain}
7E6A CJK UNIFIED IDEOGRAPH-#7E6A, IRGKangXi=0940.060, RSKangXi=120.13, Def{draw, sketch, paint}
7E6B CJK UNIFIED IDEOGRAPH-#7E6B, IRGKangXi=0940.070, RSKangXi=120.13, Def{attach, connect, unite, fasten}
7E6C CJK UNIFIED IDEOGRAPH-#7E6C, IRGKangXi=0940.090, RSKangXi=120.13
7E6D CJK UNIFIED IDEOGRAPH-#7E6D, IRGKangXi=0940.110, RSKangXi=120.13, Def{cocoon; callus, blister}
7E6E CJK UNIFIED IDEOGRAPH-#7E6E, IRGKangXi=0940.170, RSKangXi=120.13, Def{reins, bridle}
7E6F CJK UNIFIED IDEOGRAPH-#7E6F, IRGKangXi=0940.200, RSKangXi=120.13, Def{noose; hang death; tie, bind}
7E70 CJK UNIFIED IDEOGRAPH-#7E70, IRGKangXi=0940.210, RSKangXi=120.13, Def{to reel silk from cocoons}
7E71 CJK UNIFIED IDEOGRAPH-#7E71, IRGKangXi=0940.230, RSKangXi=120.12
7E72 CJK UNIFIED IDEOGRAPH-#7E72, IRGKangXi=0940.240, RSKangXi=120.13, Def{to work as a tailor, and do washing-for a living}
7E73 CJK UNIFIED IDEOGRAPH-#7E73, IRGKangXi=0940.280, RSKangXi=120.13, Def{deliver, submit; hand over}
7E74 CJK UNIFIED IDEOGRAPH-#7E74, IRGKangXi=0941.010, RSKangXi=120.13, Def{a kind of fishing-net}
7E75 CJK UNIFIED IDEOGRAPH-#7E75, IRGKangXi=0941.040, RSKangXi=120.13
7E76 CJK UNIFIED IDEOGRAPH-#7E76, IRGKangXi=0941.100, RSKangXi=120.13
7E77 CJK UNIFIED IDEOGRAPH-#7E77, IRGKangXi=0941.110, RSKangXi=120.13
7E78 CJK UNIFIED IDEOGRAPH-#7E78, IRGKangXi=0941.140, RSKangXi=120.13, Def{hem or border of a garment; tassel}
7E79 CJK UNIFIED IDEOGRAPH-#7E79, IRGKangXi=0941.150, RSKangXi=120.13, Def{to unravel or unreel silk; to interpret, explain}
7E7A CJK UNIFIED IDEOGRAPH-#7E7A, IRGKangXi=0941.220, RSKangXi=120.13
7E7B CJK UNIFIED IDEOGRAPH-#7E7B, IRGKangXi=0941.330, RSKangXi=120.14, Def{fine silk guaze; torn piece of silk}
7E7C CJK UNIFIED IDEOGRAPH-#7E7C, IRGKangXi=0941.340, RSKangXi=120.14, Def{continue, maintain, carry on}
7E7D CJK UNIFIED IDEOGRAPH-#7E7D, IRGKangXi=0942.020, RSKangXi=120.14, Def{flourishing, thriving, abundant}
7E7E CJK UNIFIED IDEOGRAPH-#7E7E, IRGKangXi=0942.090, RSKangXi=120.14, Def{attached to, inseparable; entangled}
7E7F CJK UNIFIED IDEOGRAPH-#7E7F, IRGKangXi=0942.120, RSKangXi=120.14, Def{(same as U+8964 襤) clothes without hem; ragged garments; sloppily dressed}
7E80 CJK UNIFIED IDEOGRAPH-#7E80, IRGKangXi=0942.130, RSKangXi=120.14
7E81 CJK UNIFIED IDEOGRAPH-#7E81, IRGKangXi=0942.140, RSKangXi=120.14, Def{light red, pink}
7E82 CJK UNIFIED IDEOGRAPH-#7E82, IRGKangXi=0942.150, RSKangXi=120.14, Def{edit, compile; topknot, chignon}
7E83 CJK UNIFIED IDEOGRAPH-#7E83, IRGKangXi=0942.251, RSKangXi=120.14
7E84 CJK UNIFIED IDEOGRAPH-#7E84, IRGKangXi=0943.071, RSKangXi=120.15
7E85 CJK UNIFIED IDEOGRAPH-#7E85, IRGKangXi=0942.260, RSKangXi=120.15
7E86 CJK UNIFIED IDEOGRAPH-#7E86, IRGKangXi=0942.290, RSKangXi=120.15, Def{cord}
7E87 CJK UNIFIED IDEOGRAPH-#7E87, IRGKangXi=0942.300, RSKangXi=120.15, Def{knot; blemish, flaw, wicked}
7E88 CJK UNIFIED IDEOGRAPH-#7E88, IRGKangXi=0942.310, RSKangXi=120.15, Def{patterned silk; tie knot}
7E89 CJK UNIFIED IDEOGRAPH-#7E89, IRGKangXi=0942.330, RSKangXi=120.15
7E8A CJK UNIFIED IDEOGRAPH-#7E8A, IRGKangXi=0942.360, RSKangXi=120.15, Def{cotton; silk}
7E8B CJK UNIFIED IDEOGRAPH-#7E8B, IRGKangXi=0942.370, RSKangXi=120.15
7E8C CJK UNIFIED IDEOGRAPH-#7E8C, IRGKangXi=0942.400, RSKangXi=120.15, Def{continue, carry on; succeed}
7E8D CJK UNIFIED IDEOGRAPH-#7E8D, IRGKangXi=0942.430, RSKangXi=120.15, Def{bind, wind about; link, join}
7E8E CJK UNIFIED IDEOGRAPH-#7E8E, IRGKangXi=0943.020, RSKangXi=120.15, Def{fine, delicate; minute; graceful}
7E8F CJK UNIFIED IDEOGRAPH-#7E8F, IRGKangXi=0943.030, RSKangXi=120.15, Def{wrap, wind around; tie, bind}
7E90 CJK UNIFIED IDEOGRAPH-#7E90, IRGKangXi=0943.071, RSKangXi=120.15
7E91 CJK UNIFIED IDEOGRAPH-#7E91, IRGKangXi=0943.110, RSKangXi=120.16, Def{to soften hemp by boiling; thread}
7E92 CJK UNIFIED IDEOGRAPH-#7E92, IRGKangXi=0943.150, RSKangXi=120.16, Def{wrap, wind around; tie, bind}
7E93 CJK UNIFIED IDEOGRAPH-#7E93, IRGKangXi=0943.240, RSKangXi=120.17, Def{a chin strap, tassel; to annoy, bother}
7E94 CJK UNIFIED IDEOGRAPH-#7E94, IRGKangXi=0943.270, RSKangXi=120.17, Def{talent, ability; just, only}
7E95 CJK UNIFIED IDEOGRAPH-#7E95, IRGKangXi=0943.280, RSKangXi=120.17, Def{belt}
7E96 CJK UNIFIED IDEOGRAPH-#7E96, IRGKangXi=0943.290, RSKangXi=120.17, Def{fine, delicate; minute; graceful}
7E97 CJK UNIFIED IDEOGRAPH-#7E97, IRGKangXi=0943.350, RSKangXi=120.18
7E98 CJK UNIFIED IDEOGRAPH-#7E98, IRGKangXi=0944.070, RSKangXi=120.19, Def{continue, carry on, succeed}
7E99 CJK UNIFIED IDEOGRAPH-#7E99, IRGKangXi=0944.090, RSKangXi=120.19
7E9A CJK UNIFIED IDEOGRAPH-#7E9A, IRGKangXi=0944.100, RSKangXi=120.19, Def{long; dangling; kerchief; rope}
7E9B CJK UNIFIED IDEOGRAPH-#7E9B, IRGKangXi=0944.110, RSKangXi=120.19, Def{a banner, a streamer}
7E9C CJK UNIFIED IDEOGRAPH-#7E9C, IRGKangXi=0944.180, RSKangXi=120.21, Def{hawser, heavy-duty rope, cable}
7E9D CJK UNIFIED IDEOGRAPH-#7E9D, IRGKangXi=0944.210, RSKangXi=120.21
7E9E CJK UNIFIED IDEOGRAPH-#7E9E, IRGKangXi=0944.240, RSKangXi=120.23
7E9F CJK UNIFIED IDEOGRAPH-#7E9F, IRGKangXi=0944.251, RSKangXi=120.0, Def{silk; KangXi radical 120}
7EA0 CJK UNIFIED IDEOGRAPH-#7EA0, IRGKangXi=0944.251, RSKangXi=120.2, Def{investigate, inspect}
7EA1 CJK UNIFIED IDEOGRAPH-#7EA1, IRGKangXi=0944.251, RSKangXi=120.3, Def{bend, turn, twist; distort}
7EA2 CJK UNIFIED IDEOGRAPH-#7EA2, IRGKangXi=0944.251, RSKangXi=120.3, Def{red, vermillion; blush, flush}
7EA3 CJK UNIFIED IDEOGRAPH-#7EA3, IRGKangXi=0944.251, RSKangXi=120.3, Def{name of an emperor; saddle part}
7EA4 CJK UNIFIED IDEOGRAPH-#7EA4, IRGKangXi=0944.251, RSKangXi=120.3, Def{fine, delicate; minute; graceful}
7EA5 CJK UNIFIED IDEOGRAPH-#7EA5, IRGKangXi=0944.251, RSKangXi=120.3, Def{inferior silk; tassel, fringe}
7EA6 CJK UNIFIED IDEOGRAPH-#7EA6, IRGKangXi=0944.251, RSKangXi=120.3, Def{treaty, agreement, covenant}
7EA7 CJK UNIFIED IDEOGRAPH-#7EA7, IRGKangXi=0944.251, RSKangXi=120.3, Def{level, rank, class; grade}
7EA8 CJK UNIFIED IDEOGRAPH-#7EA8, IRGKangXi=0944.251, RSKangXi=120.3, Def{white silk, fine silk; gauze}
7EA9 CJK UNIFIED IDEOGRAPH-#7EA9, IRGKangXi=0944.251, RSKangXi=120.3, Def{cotton; silk}
7EAA CJK UNIFIED IDEOGRAPH-#7EAA, IRGKangXi=0944.251, RSKangXi=120.3, Def{record, annal, historical account}
7EAB CJK UNIFIED IDEOGRAPH-#7EAB, IRGKangXi=0944.251, RSKangXi=120.3, Def{thread needle, sew stitch, string}
7EAC CJK UNIFIED IDEOGRAPH-#7EAC, IRGKangXi=0944.251, RSKangXi=120.4, Def{woof; parallels of latitude}
7EAD CJK UNIFIED IDEOGRAPH-#7EAD, IRGKangXi=0944.251, RSKangXi=120.4, Def{confused, in disorder; numerous}
7EAE CJK UNIFIED IDEOGRAPH-#7EAE, IRGKangXi=0944.251, RSKangXi=120.4, Def{string; vast, expansive}
7EAF CJK UNIFIED IDEOGRAPH-#7EAF, IRGKangXi=0944.251, RSKangXi=120.4, Def{pure, clean, simple}
7EB0 CJK UNIFIED IDEOGRAPH-#7EB0, IRGKangXi=0944.251, RSKangXi=120.4, Def{spoiled silk; hem of dress; mista}
7EB1 CJK UNIFIED IDEOGRAPH-#7EB1, IRGKangXi=0944.251, RSKangXi=120.4, Def{gauze, thin silk; yarn, thread}
7EB2 CJK UNIFIED IDEOGRAPH-#7EB2, IRGKangXi=0944.251, RSKangXi=120.4, Def{heavy rope, hawser; main points}
7EB3 CJK UNIFIED IDEOGRAPH-#7EB3, IRGKangXi=0944.251, RSKangXi=120.4, Def{admit, take, receive, accept}
7EB4 CJK UNIFIED IDEOGRAPH-#7EB4, IRGKangXi=0944.251, RSKangXi=120.4, Def{weave, lay warp}
7EB5 CJK UNIFIED IDEOGRAPH-#7EB5, IRGKangXi=0944.251, RSKangXi=120.4, Def{indulge in, give free reign to}
7EB6 CJK UNIFIED IDEOGRAPH-#7EB6, IRGKangXi=0944.251, RSKangXi=120.4, Def{green silk thread or tassel}
7EB7 CJK UNIFIED IDEOGRAPH-#7EB7, IRGKangXi=0944.251, RSKangXi=120.4, Def{in disorder, scattered, tangled}
7EB8 CJK UNIFIED IDEOGRAPH-#7EB8, IRGKangXi=0944.251, RSKangXi=120.4, Def{paper}
7EB9 CJK UNIFIED IDEOGRAPH-#7EB9, IRGKangXi=0944.251, RSKangXi=120.4, Def{line, streak, stripe; wrinkle}
7EBA CJK UNIFIED IDEOGRAPH-#7EBA, IRGKangXi=0944.251, RSKangXi=120.4, Def{spin, reel, weave; reeled pongee}
7EBB CJK UNIFIED IDEOGRAPH-#7EBB, IRGKangXi=0944.251, RSKangXi=120.4, Def{ramie; sack cloth}
7EBC CJK UNIFIED IDEOGRAPH-#7EBC, IRGKangXi=0944.251, RSKangXi=120.4, Def{a rope for leading cattle or horse}
7EBD CJK UNIFIED IDEOGRAPH-#7EBD, IRGKangXi=0944.251, RSKangXi=120.4, Def{knot; button; handle, knob; tie}
7EBE CJK UNIFIED IDEOGRAPH-#7EBE, IRGKangXi=0944.251, RSKangXi=120.4, Def{loosen, relax, relieve; extricate}
7EBF CJK UNIFIED IDEOGRAPH-#7EBF, IRGKangXi=0944.251, RSKangXi=120.5, Def{line, thread, wire; clue}
7EC0 CJK UNIFIED IDEOGRAPH-#7EC0, IRGKangXi=0944.251, RSKangXi=120.5, Def{dark blue or reddish color}
7EC1 CJK UNIFIED IDEOGRAPH-#7EC1, IRGKangXi=0944.251, RSKangXi=120.5, Def{to contract, draw in, reduce, shorten}
7EC2 CJK UNIFIED IDEOGRAPH-#7EC2, IRGKangXi=0944.251, RSKangXi=120.5, Def{ribbon or cord used attach ornaments}
7EC3 CJK UNIFIED IDEOGRAPH-#7EC3, IRGKangXi=0944.251, RSKangXi=120.5, Def{to practice, drill, exercise, train}
7EC4 CJK UNIFIED IDEOGRAPH-#7EC4, IRGKangXi=0944.251, RSKangXi=120.5, Def{class; section, department}
7EC5 CJK UNIFIED IDEOGRAPH-#7EC5, IRGKangXi=0944.251, RSKangXi=120.5, Def{girdle; tie, bind; gentry}
7EC6 CJK UNIFIED IDEOGRAPH-#7EC6, IRGKangXi=0944.251, RSKangXi=120.5, Def{fine, tiny; slender, thin}
7EC7 CJK UNIFIED IDEOGRAPH-#7EC7, IRGKangXi=0944.251, RSKangXi=120.5, Def{weave, knit; organize, unite}
7EC8 CJK UNIFIED IDEOGRAPH-#7EC8, IRGKangXi=0944.251, RSKangXi=120.5, Def{end; finally, in the end}
7EC9 CJK UNIFIED IDEOGRAPH-#7EC9, IRGKangXi=0944.251, RSKangXi=120.5, Def{crepe, crape, wrinkles, creases}
7ECA CJK UNIFIED IDEOGRAPH-#7ECA, IRGKangXi=0944.251, RSKangXi=120.5, Def{loop, catch; fetter, shackle}
7ECB CJK UNIFIED IDEOGRAPH-#7ECB, IRGKangXi=0944.251, RSKangXi=120.5, Def{large rope; rope attached to bier}
7ECC CJK UNIFIED IDEOGRAPH-#7ECC, IRGKangXi=0944.251, RSKangXi=120.5, Def{sew, stitch; insufficient}
7ECD CJK UNIFIED IDEOGRAPH-#7ECD, IRGKangXi=0944.251, RSKangXi=120.5, Def{continue, carry on; join}
7ECE CJK UNIFIED IDEOGRAPH-#7ECE, IRGKangXi=0944.251, RSKangXi=120.5, Def{to unravel or unreel silk; to interpret}
7ECF CJK UNIFIED IDEOGRAPH-#7ECF, IRGKangXi=0944.251, RSKangXi=120.5, Def{classic works; pass through}
7ED0 CJK UNIFIED IDEOGRAPH-#7ED0, IRGKangXi=0944.251, RSKangXi=120.5, Def{cheat, fool, pretend}
7ED1 CJK UNIFIED IDEOGRAPH-#7ED1, IRGKangXi=0944.251, RSKangXi=120.6, Def{bind, tie, fasten}
7ED2 CJK UNIFIED IDEOGRAPH-#7ED2, IRGKangXi=0944.251, RSKangXi=120.6, Def{silk, cotton, or woolen fabric}
7ED3 CJK UNIFIED IDEOGRAPH-#7ED3, IRGKangXi=0944.251, RSKangXi=120.6, Def{knot, tie; join, connect}
7ED4 CJK UNIFIED IDEOGRAPH-#7ED4, IRGKangXi=0944.251, RSKangXi=120.6, Def{trousers}
7ED5 CJK UNIFIED IDEOGRAPH-#7ED5, IRGKangXi=0944.251, RSKangXi=120.6, Def{entwine; wind around; surround}
7ED6 CJK UNIFIED IDEOGRAPH-#7ED6, IRGKangXi=0944.251, RSKangXi=120.6, Def{white hempen cloth worn by mourners}
7ED7 CJK UNIFIED IDEOGRAPH-#7ED7, IRGKangXi=0944.251, RSKangXi=120.6, Def{baste}
7ED8 CJK UNIFIED IDEOGRAPH-#7ED8, IRGKangXi=0944.251, RSKangXi=120.6, Def{draw, sketch, paint}
7ED9 CJK UNIFIED IDEOGRAPH-#7ED9, IRGKangXi=0944.251, RSKangXi=120.6, Def{give; by, for}
7EDA CJK UNIFIED IDEOGRAPH-#7EDA, IRGKangXi=0944.251, RSKangXi=120.6, Def{variegated, adorned; brilliant}
7EDB CJK UNIFIED IDEOGRAPH-#7EDB, IRGKangXi=0944.251, RSKangXi=120.6, Def{deep red; river in Shanxi provinc}
7EDC CJK UNIFIED IDEOGRAPH-#7EDC, IRGKangXi=0944.251, RSKangXi=120.6, Def{enmesh, wrap around; web, net}
7EDD CJK UNIFIED IDEOGRAPH-#7EDD, IRGKangXi=0944.251, RSKangXi=120.6, Def{to cut, sever, break off, terminate}
7EDE CJK UNIFIED IDEOGRAPH-#7EDE, IRGKangXi=0944.251, RSKangXi=120.6, Def{twist, wring; intertwine; winch}
7EDF CJK UNIFIED IDEOGRAPH-#7EDF, IRGKangXi=0944.251, RSKangXi=120.6, Def{govern, command, control; unite}
7EE0 CJK UNIFIED IDEOGRAPH-#7EE0, IRGKangXi=0944.251, RSKangXi=120.7, Def{well rope}
7EE1 CJK UNIFIED IDEOGRAPH-#7EE1, IRGKangXi=0944.251, RSKangXi=120.7, Def{raw silk fabric}
7EE2 CJK UNIFIED IDEOGRAPH-#7EE2, IRGKangXi=0944.251, RSKangXi=120.7, Def{kind of thick stiff silk}
7EE3 CJK UNIFIED IDEOGRAPH-#7EE3, IRGKangXi=0944.251, RSKangXi=120.7, Def{embroider; embroidery; ornament}
7EE4 CJK UNIFIED IDEOGRAPH-#7EE4, IRGKangXi=0944.251, RSKangXi=120.7, Def{cloth}
7EE5 CJK UNIFIED IDEOGRAPH-#7EE5, IRGKangXi=0944.251, RSKangXi=120.7, Def{soothe, appease, pacify}
7EE6 CJK UNIFIED IDEOGRAPH-#7EE6, IRGKangXi=0944.251, RSKangXi=120.7, Def{silk cord, ribbon}
7EE7 CJK UNIFIED IDEOGRAPH-#7EE7, IRGKangXi=0944.251, RSKangXi=120.7, Def{continue, maintain, carry on}
7EE8 CJK UNIFIED IDEOGRAPH-#7EE8, IRGKangXi=0944.251, RSKangXi=120.7, Def{coarse pongee, kind of heavy silk}
7EE9 CJK UNIFIED IDEOGRAPH-#7EE9, IRGKangXi=0944.251, RSKangXi=120.8, Def{spin; achievements}
7EEA CJK UNIFIED IDEOGRAPH-#7EEA, IRGKangXi=0944.251, RSKangXi=120.8, Def{end of thread; thread, clue}
7EEB CJK UNIFIED IDEOGRAPH-#7EEB, IRGKangXi=0944.251, RSKangXi=120.8, Def{thin silk, damask silk}
7EEC CJK UNIFIED IDEOGRAPH-#7EEC, IRGKangXi=0944.251
7EED CJK UNIFIED IDEOGRAPH-#7EED, IRGKangXi=0944.251, RSKangXi=120.8, Def{continue, carry on; succeed}
7EEE CJK UNIFIED IDEOGRAPH-#7EEE, IRGKangXi=0944.251, RSKangXi=120.8, Def{fine thin silk; elegant, beautifu}
7EEF CJK UNIFIED IDEOGRAPH-#7EEF, IRGKangXi=0944.251, RSKangXi=120.8, Def{scarlet, dark red, crimson; purpl}
7EF0 CJK UNIFIED IDEOGRAPH-#7EF0, IRGKangXi=0944.251, RSKangXi=120.8, Def{graceful, delicate; spacious}
7EF1 CJK UNIFIED IDEOGRAPH-#7EF1, IRGKangXi=0944.251, RSKangXi=120.8, Def{the piece of leather used for soles on Chinese shoes; a patch}
7EF2 CJK UNIFIED IDEOGRAPH-#7EF2, IRGKangXi=0944.251, RSKangXi=120.8, Def{cord; woven belt; hem; hemming}
7EF3 CJK UNIFIED IDEOGRAPH-#7EF3, IRGKangXi=0944.251, RSKangXi=120.8, Def{rope, string, cord; control}
7EF4 CJK UNIFIED IDEOGRAPH-#7EF4, IRGKangXi=0944.251, RSKangXi=120.8, Def{maintain, preserve, safeguard}
7EF5 CJK UNIFIED IDEOGRAPH-#7EF5, IRGKangXi=0944.251, RSKangXi=120.8, Def{cotton wad; wool; soft, downy}
7EF6 CJK UNIFIED IDEOGRAPH-#7EF6, IRGKangXi=0944.251, RSKangXi=120.8, Def{silk ribbon attached as a seal}
7EF7 CJK UNIFIED IDEOGRAPH-#7EF7, IRGKangXi=0944.251, RSKangXi=120.8, Def{bind, draw firmly, strap}
7EF8 CJK UNIFIED IDEOGRAPH-#7EF8, IRGKangXi=0944.251, RSKangXi=120.8, Def{silk cloth, satin damask}
7EF9 CJK UNIFIED IDEOGRAPH-#7EF9, IRGKangXi=0944.251, RSKangXi=120.8, Def{to braid, twist; twisted or braided}
7EFA CJK UNIFIED IDEOGRAPH-#7EFA, IRGKangXi=0944.251, RSKangXi=120.8, Def{skein; tuft, lock; wrinkle}
7EFB CJK UNIFIED IDEOGRAPH-#7EFB, IRGKangXi=0944.251, RSKangXi=120.8, Def{affectionate, solicitous}
7EFC CJK UNIFIED IDEOGRAPH-#7EFC, IRGKangXi=0944.251, RSKangXi=120.8, Def{arrange threads for weaving}
7EFD CJK UNIFIED IDEOGRAPH-#7EFD, IRGKangXi=0944.251, RSKangXi=120.8, Def{ripped seam, rend, crack}
7EFE CJK UNIFIED IDEOGRAPH-#7EFE, IRGKangXi=0944.251, RSKangXi=120.8, Def{to string together, to bind up}
7EFF CJK UNIFIED IDEOGRAPH-#7EFF, IRGKangXi=0944.251, RSKangXi=120.8, Def{green; chlorine}
7F00 CJK UNIFIED IDEOGRAPH-#7F00, IRGKangXi=0944.251, RSKangXi=120.8, Def{patch together, link, connect}
7F01 CJK UNIFIED IDEOGRAPH-#7F01, IRGKangXi=0944.251, RSKangXi=120.8, Def{black silk}
7F02 CJK UNIFIED IDEOGRAPH-#7F02, IRGKangXi=0944.251, RSKangXi=120.9, Def{the woof of a woven item}
7F03 CJK UNIFIED IDEOGRAPH-#7F03, IRGKangXi=0944.251, RSKangXi=120.9, Def{light-yellow color}
7F04 CJK UNIFIED IDEOGRAPH-#7F04, IRGKangXi=0944.251, RSKangXi=120.9, Def{seal, close; bind; letter}
7F05 CJK UNIFIED IDEOGRAPH-#7F05, IRGKangXi=0944.251, RSKangXi=120.9, Def{distant, remote; think of}
7F06 CJK UNIFIED IDEOGRAPH-#7F06, IRGKangXi=0944.251, RSKangXi=120.9, Def{hawser, heavy-duty rope, cable}
7F07 CJK UNIFIED IDEOGRAPH-#7F07, IRGKangXi=0944.251, RSKangXi=120.9, Def{reddish color, red, brown}
7F08 CJK UNIFIED IDEOGRAPH-#7F08, IRGKangXi=0944.251, RSKangXi=120.9, Def{indistinct, dim; minute; distant}
7F09 CJK UNIFIED IDEOGRAPH-#7F09, IRGKangXi=0944.251, RSKangXi=120.9, Def{to sew in close stitches}
7F0A CJK UNIFIED IDEOGRAPH-#7F0A, IRGKangXi=0944.251, RSKangXi=120.10, Def{tangled hemp, raveled silk; vague, confused}
7F0B CJK UNIFIED IDEOGRAPH-#7F0B, IRGKangXi=0944.251, RSKangXi=120.9, Def{draw, sketch, paint}
7F0C CJK UNIFIED IDEOGRAPH-#7F0C, IRGKangXi=0944.251, RSKangXi=120.9, Def{coarse cotton cloth used for mourning}
7F0D CJK UNIFIED IDEOGRAPH-#7F0D, IRGKangXi=0944.251, RSKangXi=120.8
7F0E CJK UNIFIED IDEOGRAPH-#7F0E, IRGKangXi=0944.251, RSKangXi=120.9, Def{satin}
7F0F CJK UNIFIED IDEOGRAPH-#7F0F, IRGKangXi=0944.251, RSKangXi=120.9, Def{hem; plait, braid, queue}
7F10 CJK UNIFIED IDEOGRAPH-#7F10, IRGKangXi=0944.251, RSKangXi=120.9
7F11 CJK UNIFIED IDEOGRAPH-#7F11, IRGKangXi=0944.251, RSKangXi=120.9, Def{cord binding on hilt of sword}
7F12 CJK UNIFIED IDEOGRAPH-#7F12, IRGKangXi=0944.251, RSKangXi=120.9, Def{climb down rope; hang by rope}
7F13 CJK UNIFIED IDEOGRAPH-#7F13, IRGKangXi=0944.251, RSKangXi=120.9, Def{slow, leisurely; to postpone, delay}
7F14 CJK UNIFIED IDEOGRAPH-#7F14, IRGKangXi=0944.251, RSKangXi=120.9, Def{tie, join, connect; connection}
7F15 CJK UNIFIED IDEOGRAPH-#7F15, IRGKangXi=0944.251, RSKangXi=120.9, Def{thread; detailed, precise}
7F16 CJK UNIFIED IDEOGRAPH-#7F16, IRGKangXi=0944.251, RSKangXi=120.9, Def{knit, weave; arrange; compile}
7F17 CJK UNIFIED IDEOGRAPH-#7F17, IRGKangXi=0944.251, RSKangXi=120.9, Def{fishing-line; cord; string of coi}
7F18 CJK UNIFIED IDEOGRAPH-#7F18, IRGKangXi=0944.251, RSKangXi=120.9, Def{hem, margin; reason, cause; fate}
7F19 CJK UNIFIED IDEOGRAPH-#7F19, IRGKangXi=0944.251, RSKangXi=120.10, Def{red silk}
7F1A CJK UNIFIED IDEOGRAPH-#7F1A, IRGKangXi=0944.251, RSKangXi=120.10, Def{to tie}
7F1B CJK UNIFIED IDEOGRAPH-#7F1B, IRGKangXi=0944.251, RSKangXi=120.10, Def{decorative, adorned, elegant}
7F1C CJK UNIFIED IDEOGRAPH-#7F1C, IRGKangXi=0944.251, RSKangXi=120.10, Def{detailed, fine; closely woven}
7F1D CJK UNIFIED IDEOGRAPH-#7F1D, IRGKangXi=0944.251, RSKangXi=120.10, Def{sew, mend}
7F1E CJK UNIFIED IDEOGRAPH-#7F1E, IRGKangXi=0944.251, RSKangXi=120.10, Def{sackcloth worn on breast during}
7F1F CJK UNIFIED IDEOGRAPH-#7F1F, IRGKangXi=0944.251, RSKangXi=120.10, Def{white raw silk}
7F20 CJK UNIFIED IDEOGRAPH-#7F20, IRGKangXi=0944.251, RSKangXi=120.10, Def{wrap, wind around; tie, bind}
7F21 CJK UNIFIED IDEOGRAPH-#7F21, IRGKangXi=0944.251, RSKangXi=120.10, Def{a bridal veil; to tie; to bind}
7F22 CJK UNIFIED IDEOGRAPH-#7F22, IRGKangXi=0944.251, RSKangXi=120.10, Def{hang, strangle}
7F23 CJK UNIFIED IDEOGRAPH-#7F23, IRGKangXi=0944.251, RSKangXi=120.10, Def{fine silk}
7F24 CJK UNIFIED IDEOGRAPH-#7F24, IRGKangXi=0944.251, RSKangXi=120.10, Def{flourishing, thriving, abundant}
7F25 CJK UNIFIED IDEOGRAPH-#7F25, IRGKangXi=0944.251, RSKangXi=120.11, Def{light blue silk; dim; misty}
7F26 CJK UNIFIED IDEOGRAPH-#7F26, IRGKangXi=0944.251, RSKangXi=120.11, Def{plain silk; simple, plain}
7F27 CJK UNIFIED IDEOGRAPH-#7F27, IRGKangXi=0944.251, RSKangXi=120.11, Def{a chain or rope used bind criminals}
7F28 CJK UNIFIED IDEOGRAPH-#7F28, IRGKangXi=0944.251, RSKangXi=120.11, Def{a chin strap; tassel; to annoy, bother}
7F29 CJK UNIFIED IDEOGRAPH-#7F29, IRGKangXi=0944.251, RSKangXi=120.11, Def{contract, draw in, reduce}
7F2A CJK UNIFIED IDEOGRAPH-#7F2A, IRGKangXi=0944.251, RSKangXi=120.11, Def{wind around, bind; prepare}
7F2B CJK UNIFIED IDEOGRAPH-#7F2B, IRGKangXi=0944.251, RSKangXi=120.11, Def{draw, reel}
7F2C CJK UNIFIED IDEOGRAPH-#7F2C, IRGKangXi=0944.251, RSKangXi=120.12, Def{patterned silk; tie knot}
7F2D CJK UNIFIED IDEOGRAPH-#7F2D, IRGKangXi=0944.251, RSKangXi=120.12, Def{wind round, rap around, bind}
7F2E CJK UNIFIED IDEOGRAPH-#7F2E, IRGKangXi=0944.251, RSKangXi=120.12, Def{repair, mend; rewrite, transcribe}
7F2F CJK UNIFIED IDEOGRAPH-#7F2F, IRGKangXi=0944.251, RSKangXi=120.12, Def{silk fabrics; surname}
7F30 CJK UNIFIED IDEOGRAPH-#7F30, IRGKangXi=0944.251, RSKangXi=120.13, Def{reins, bridle}
7F31 CJK UNIFIED IDEOGRAPH-#7F31, IRGKangXi=0944.251, RSKangXi=120.13, Def{attached to, inseparable; entangl}
7F32 CJK UNIFIED IDEOGRAPH-#7F32, IRGKangXi=0944.251, RSKangXi=120.13, Def{to reel}
7F33 CJK UNIFIED IDEOGRAPH-#7F33, IRGKangXi=0944.251, RSKangXi=120.13, Def{noose; hang death; tie, bind}
7F34 CJK UNIFIED IDEOGRAPH-#7F34, IRGKangXi=0944.251, RSKangXi=120.13, Def{deliver, submit; hand over}
7F35 CJK UNIFIED IDEOGRAPH-#7F35, IRGKangXi=0944.251, RSKangXi=120.16, Def{continue, carry on, succeed}
7F36 CJK UNIFIED IDEOGRAPH-#7F36, IRGKangXi=0944.260, RSKangXi=121.0, Def{earthen crock or jar; rad. 121}
7F37 CJK UNIFIED IDEOGRAPH-#7F37, IRGKangXi=0944.271, RSKangXi=121.2, Def{lay down; retire from office}
7F38 CJK UNIFIED IDEOGRAPH-#7F38, IRGKangXi=0944.280, RSKangXi=121.3, Def{earthen jug, crock, cistern}
7F39 CJK UNIFIED IDEOGRAPH-#7F39, IRGKangXi=0944.330, RSKangXi=121.4, Def{(Cant.) to cook}
7F3A CJK UNIFIED IDEOGRAPH-#7F3A, IRGKangXi=0945.040, RSKangXi=121.4, Def{be short of, lack; gap, deficit}
7F3B CJK UNIFIED IDEOGRAPH-#7F3B, IRGKangXi=0945.050, RSKangXi=121.5, Def{pottery, earthenware}
7F3C CJK UNIFIED IDEOGRAPH-#7F3C, IRGKangXi=0945.061, RSKangXi=121.4
7F3D CJK UNIFIED IDEOGRAPH-#7F3D, IRGKangXi=0945.171, RSKangXi=121.5, Def{earthenware basin; alms bowl}
7F3E CJK UNIFIED IDEOGRAPH-#7F3E, IRGKangXi=0945.240, RSKangXi=121.6, Def{jar, bottle}
7F3F CJK UNIFIED IDEOGRAPH-#7F3F, IRGKangXi=0945.250, RSKangXi=121.6
7F40 CJK UNIFIED IDEOGRAPH-#7F40, IRGKangXi=0945.251
7F41 CJK UNIFIED IDEOGRAPH-#7F41, IRGKangXi=0945.360, Def{a cistern; an earthenware jar of large dimensions; a vat; a crock}
7F42 CJK UNIFIED IDEOGRAPH-#7F42, IRGKangXi=0945.381, RSKangXi=121.8, Def{long necked jar or bottle}
7F43 CJK UNIFIED IDEOGRAPH-#7F43, IRGKangXi=0945.440, RSKangXi=121.10, Def{long necked jar or bottle}
7F44 CJK UNIFIED IDEOGRAPH-#7F44, IRGKangXi=0945.450, RSKangXi=121.11, Def{exhaust, run out, use up; empty}
7F45 CJK UNIFIED IDEOGRAPH-#7F45, IRGKangXi=0945.470, RSKangXi=121.11, Def{crack, fissure, split}
7F46 CJK UNIFIED IDEOGRAPH-#7F46, IRGKangXi=0945.491, RSKangXi=121.11, Def{jar, jug, pitcher, pot}
7F47 CJK UNIFIED IDEOGRAPH-#7F47, IRGKangXi=0945.510, RSKangXi=121.12, Def{a goblet; a bottle, a wine-jar}
7F48 CJK UNIFIED IDEOGRAPH-#7F48, IRGKangXi=0945.521, RSKangXi=121.12, Def{an earthenware jar, a jug}
7F49 CJK UNIFIED IDEOGRAPH-#7F49, IRGKangXi=0945.521, RSKangXi=121.12, Def{(Cant.) a pot}
7F4A CJK UNIFIED IDEOGRAPH-#7F4A, IRGKangXi=0945.530, RSKangXi=121.13
7F4B CJK UNIFIED IDEOGRAPH-#7F4B, IRGKangXi=0946.020, RSKangXi=121.13, Def{earthen jar; jar for ashes}
7F4C CJK UNIFIED IDEOGRAPH-#7F4C, IRGKangXi=0946.060, RSKangXi=121.14, Def{long necked jar or bottle}
7F4D CJK UNIFIED IDEOGRAPH-#7F4D, IRGKangXi=0946.080, RSKangXi=121.15, Def{large earthenware wine jar}
7F4E CJK UNIFIED IDEOGRAPH-#7F4E, IRGKangXi=0946.110, RSKangXi=121.16, Def{an earthenware jar, a jug}
7F4F CJK UNIFIED IDEOGRAPH-#7F4F, IRGKangXi=0946.120, RSKangXi=121.16, Def{earthen stand for wine jug}
7F50 CJK UNIFIED IDEOGRAPH-#7F50, IRGKangXi=0946.160, RSKangXi=121.18, Def{jar, jug, pitcher, pot}
7F51 CJK UNIFIED IDEOGRAPH-#7F51, IRGKangXi=0946.200, RSKangXi=122.0, Def{net; network; KangXi radical 122}
7F52 CJK UNIFIED IDEOGRAPH-#7F52, IRGKangXi=0946.241, RSKangXi=122.0, Def{Radical 122}
7F53 CJK UNIFIED IDEOGRAPH-#7F53, IRGKangXi=0946.241, RSKangXi=122.0
7F54 CJK UNIFIED IDEOGRAPH-#7F54, IRGKangXi=0946.300, RSKangXi=122.3, Def{net; deceive; libel; negative}
7F55 CJK UNIFIED IDEOGRAPH-#7F55, IRGKangXi=0946.350, RSKangXi=122.3, Def{rare, scarce; surname}
7F56 CJK UNIFIED IDEOGRAPH-#7F56, IRGKangXi=0947.031, RSKangXi=122.3, Def{kwukyel}
7F57 CJK UNIFIED IDEOGRAPH-#7F57, IRGKangXi=0947.031, RSKangXi=122.3, Def{net for catching birds; gauze}
7F58 CJK UNIFIED IDEOGRAPH-#7F58, IRGKangXi=0947.070, RSKangXi=122.4, Def{screen used in ancient times}
7F59 CJK UNIFIED IDEOGRAPH-#7F59, IRGKangXi=0947.101, RSKangXi=122.4, Def{deep}
7F5A CJK UNIFIED IDEOGRAPH-#7F5A, IRGKangXi=0947.101, RSKangXi=122.4, Def{penalty, fine; punish, penalize}
7F5B CJK UNIFIED IDEOGRAPH-#7F5B, IRGKangXi=0947.180, RSKangXi=122.5, Def{large fishing net}
7F5C CJK UNIFIED IDEOGRAPH-#7F5C, IRGKangXi=0947.210, RSKangXi=122.5
7F5D CJK UNIFIED IDEOGRAPH-#7F5D, IRGKangXi=0947.220, RSKangXi=122.5, Def{net for catching rabbits}
7F5E CJK UNIFIED IDEOGRAPH-#7F5E, IRGKangXi=0947.240, RSKangXi=122.5
7F5F CJK UNIFIED IDEOGRAPH-#7F5F, IRGKangXi=0947.250, RSKangXi=122.5, Def{net; snare; pressure come or go}
7F60 CJK UNIFIED IDEOGRAPH-#7F60, IRGKangXi=0947.270, RSKangXi=122.5, Def{animal trap}
7F61 CJK UNIFIED IDEOGRAPH-#7F61, IRGKangXi=0947.280, RSKangXi=122.5, Def{the name of a certain stars; the god who is supposed to live in them}
7F62 CJK UNIFIED IDEOGRAPH-#7F62, IRGKangXi=0947.321, RSKangXi=122.5, Def{cease, finish, stop; give up}
7F63 CJK UNIFIED IDEOGRAPH-#7F63, IRGKangXi=0947.370, RSKangXi=122.6, Def{hinder, disturb, obstruct}
7F64 CJK UNIFIED IDEOGRAPH-#7F64, IRGKangXi=0947.450, RSKangXi=122.7
7F65 CJK UNIFIED IDEOGRAPH-#7F65, IRGKangXi=0947.460, RSKangXi=122.7, Def{impede}
7F66 CJK UNIFIED IDEOGRAPH-#7F66, IRGKangXi=0948.020, RSKangXi=122.7, Def{net}
7F67 CJK UNIFIED IDEOGRAPH-#7F67, IRGKangXi=0948.050, RSKangXi=122.8, Def{a heap, lump}
7F68 CJK UNIFIED IDEOGRAPH-#7F68, IRGKangXi=0948.080, RSKangXi=122.8, Def{medical compress; fish net}
7F69 CJK UNIFIED IDEOGRAPH-#7F69, IRGKangXi=0948.090, RSKangXi=122.8, Def{basket for catching fish; cover}
7F6A CJK UNIFIED IDEOGRAPH-#7F6A, IRGKangXi=0948.130, RSKangXi=122.8, Def{crime, sin, vice; evil; hardship}
7F6B CJK UNIFIED IDEOGRAPH-#7F6B, IRGKangXi=0948.170, RSKangXi=122.8, Def{hinder}
7F6C CJK UNIFIED IDEOGRAPH-#7F6C, IRGKangXi=0948.180, RSKangXi=122.8
7F6D CJK UNIFIED IDEOGRAPH-#7F6D, IRGKangXi=0948.190, RSKangXi=122.8, Def{drag-net made of fine mesh}
7F6E CJK UNIFIED IDEOGRAPH-#7F6E, IRGKangXi=0948.200, RSKangXi=122.8, Def{place, lay out; set aside}
7F6F CJK UNIFIED IDEOGRAPH-#7F6F, IRGKangXi=0948.300, RSKangXi=122.9
7F70 CJK UNIFIED IDEOGRAPH-#7F70, IRGKangXi=0948.330, RSKangXi=122.9, Def{penalty, fine; punish, penalize}
7F71 CJK UNIFIED IDEOGRAPH-#7F71, IRGKangXi=0948.340, RSKangXi=122.9, Def{fishing net}
7F72 CJK UNIFIED IDEOGRAPH-#7F72, IRGKangXi=0948.370, RSKangXi=122.8, Def{public office}
7F73 CJK UNIFIED IDEOGRAPH-#7F73, IRGKangXi=0948.390, RSKangXi=122.9, Def{wooden screen}
7F74 CJK UNIFIED IDEOGRAPH-#7F74, IRGKangXi=0949.021, RSKangXi=122.9, Def{brown bear, ursus arctos}
7F75 CJK UNIFIED IDEOGRAPH-#7F75, IRGKangXi=0949.050, RSKangXi=122.10, Def{accuse, blame, curse, scold}
7F76 CJK UNIFIED IDEOGRAPH-#7F76, IRGKangXi=0949.070, RSKangXi=122.10, Def{fishing trap}
7F77 CJK UNIFIED IDEOGRAPH-#7F77, IRGKangXi=0949.080, RSKangXi=122.10, Def{cease, finish, stop; give up}
7F78 CJK UNIFIED IDEOGRAPH-#7F78, IRGKangXi=0949.121, RSKangXi=122.10, Def{penalty, fine; punish, penalize}
7F79 CJK UNIFIED IDEOGRAPH-#7F79, IRGKangXi=0949.160, RSKangXi=122.11, Def{sorrow, grief; incur, meet with}
7F7A CJK UNIFIED IDEOGRAPH-#7F7A, IRGKangXi=0949.190, RSKangXi=122.11
7F7B CJK UNIFIED IDEOGRAPH-#7F7B, IRGKangXi=0949.200, RSKangXi=122.11, Def{net}
7F7C CJK UNIFIED IDEOGRAPH-#7F7C, IRGKangXi=0949.271, RSKangXi=122.11
7F7D CJK UNIFIED IDEOGRAPH-#7F7D, IRGKangXi=0949.300, RSKangXi=122.12, Def{a kind of woolen fabric}
7F7E CJK UNIFIED IDEOGRAPH-#7F7E, IRGKangXi=0949.330, RSKangXi=122.12, Def{a large square net, lowered and raised from the bank of the river}
7F7F CJK UNIFIED IDEOGRAPH-#7F7F, IRGKangXi=0949.350, RSKangXi=122.12, Def{net catch birds}
7F80 CJK UNIFIED IDEOGRAPH-#7F80, IRGKangXi=0949.371, RSKangXi=122.12, Def{fishing trap}
7F81 CJK UNIFIED IDEOGRAPH-#7F81, IRGKangXi=0949.371, RSKangXi=122.12, Def{halter; restrain, hold, control}
7F82 CJK UNIFIED IDEOGRAPH-#7F82, IRGKangXi=0950.030, RSKangXi=122.13, Def{to trap, snare}
7F83 CJK UNIFIED IDEOGRAPH-#7F83, IRGKangXi=0950.080, RSKangXi=122.14, Def{cover-cloth, cover with cloth}
7F84 CJK UNIFIED IDEOGRAPH-#7F84, IRGKangXi=0950.090, RSKangXi=122.14
7F85 CJK UNIFIED IDEOGRAPH-#7F85, IRGKangXi=0950.120, RSKangXi=122.14, Def{net for catching birds; gauze}
7F86 CJK UNIFIED IDEOGRAPH-#7F86, IRGKangXi=0950.130, RSKangXi=122.14, Def{brown bear, ursus arctos}
7F87 CJK UNIFIED IDEOGRAPH-#7F87, IRGKangXi=0950.260, RSKangXi=122.17, Def{inn; lodge; travel}
7F88 CJK UNIFIED IDEOGRAPH-#7F88, IRGKangXi=0950.320, RSKangXi=122.19, Def{halter; restrain, hold, control}
7F89 CJK UNIFIED IDEOGRAPH-#7F89, IRGKangXi=0950.350, RSKangXi=122.19
7F8A CJK UNIFIED IDEOGRAPH-#7F8A, IRGKangXi=0950.380, RSKangXi=123.0, Def{sheep, goat; KangXi radical 123}
7F8B CJK UNIFIED IDEOGRAPH-#7F8B, IRGKangXi=0951.020, RSKangXi=123.1, Def{bleat of sheep; surname}
7F8C CJK UNIFIED IDEOGRAPH-#7F8C, IRGKangXi=0951.030, RSKangXi=123.2, Def{Qiang nationality; surname}
7F8D CJK UNIFIED IDEOGRAPH-#7F8D, IRGKangXi=0951.090, RSKangXi=123.3
7F8E CJK UNIFIED IDEOGRAPH-#7F8E, IRGKangXi=0951.100, RSKangXi=123.3, Def{beautiful, pretty; pleasing}
7F8F CJK UNIFIED IDEOGRAPH-#7F8F, IRGKangXi=0951.110, RSKangXi=123.3
7F90 CJK UNIFIED IDEOGRAPH-#7F90, IRGKangXi=0951.120, RSKangXi=123.3, Def{to lead, guide}
7F91 CJK UNIFIED IDEOGRAPH-#7F91, IRGKangXi=0951.151, RSKangXi=123.3, Def{a guide to goodness}
7F92 CJK UNIFIED IDEOGRAPH-#7F92, IRGKangXi=0951.160, RSKangXi=123.4
7F93 CJK UNIFIED IDEOGRAPH-#7F93, IRGKangXi=0951.170, RSKangXi=123.4, Def{dried meat}
7F94 CJK UNIFIED IDEOGRAPH-#7F94, IRGKangXi=0951.230, RSKangXi=123.4, Def{lamb, kid}
7F95 CJK UNIFIED IDEOGRAPH-#7F95, IRGKangXi=0952.180, RSKangXi=123.5
7F96 CJK UNIFIED IDEOGRAPH-#7F96, IRGKangXi=0951.260, RSKangXi=123.4, Def{a black ram}
7F97 CJK UNIFIED IDEOGRAPH-#7F97, IRGKangXi=0951.300, RSKangXi=123.4, Def{tribes in West China; strong; educated; obstinate; a particle}
7F98 CJK UNIFIED IDEOGRAPH-#7F98, IRGKangXi=0951.310, RSKangXi=123.4, Def{ram}
7F99 CJK UNIFIED IDEOGRAPH-#7F99, IRGKangXi=0951.331, RSKangXi=123.4
7F9A CJK UNIFIED IDEOGRAPH-#7F9A, IRGKangXi=0951.390, RSKangXi=123.5, Def{species of antelope}
7F9B CJK UNIFIED IDEOGRAPH-#7F9B, IRGKangXi=0951.420, RSKangXi=123.5
7F9C CJK UNIFIED IDEOGRAPH-#7F9C, IRGKangXi=0952.010, RSKangXi=123.5, Def{lamb}
7F9D CJK UNIFIED IDEOGRAPH-#7F9D, IRGKangXi=0952.030, RSKangXi=123.5, Def{ram, he-goat}
7F9E CJK UNIFIED IDEOGRAPH-#7F9E, IRGKangXi=0952.040, RSKangXi=123.5, Def{disgrace, shame; ashamed; shy}
7F9F CJK UNIFIED IDEOGRAPH-#7F9F, IRGKangXi=0952.091, RSKangXi=123.5, Def{hydroxide}
7FA0 CJK UNIFIED IDEOGRAPH-#7FA0, IRGKangXi=0952.110, RSKangXi=123.6
7FA1 CJK UNIFIED IDEOGRAPH-#7FA1, IRGKangXi=0952.230, RSKangXi=123.6, Def{envy, admire; praise; covet}
7FA2 CJK UNIFIED IDEOGRAPH-#7FA2, IRGKangXi=0952.240, RSKangXi=123.6, Def{fine woolen fabrics}
7FA3 CJK UNIFIED IDEOGRAPH-#7FA3, IRGKangXi=0952.250, RSKangXi=123.7, Def{(same as U+7FA4 群) group, crowd, multitude, mob}
7FA4 CJK UNIFIED IDEOGRAPH-#7FA4, IRGKangXi=0952.260, RSKangXi=123.7, Def{(same as U+7FA3 羣) group, crowd, multitude, mob}
7FA5 CJK UNIFIED IDEOGRAPH-#7FA5, IRGKangXi=0952.270, RSKangXi=123.7, Def{hydroxyl group}
7FA6 CJK UNIFIED IDEOGRAPH-#7FA6, IRGKangXi=0952.280, RSKangXi=123.7
7FA7 CJK UNIFIED IDEOGRAPH-#7FA7, IRGKangXi=0952.290, RSKangXi=123.7, Def{carboxyl group}
7FA8 CJK UNIFIED IDEOGRAPH-#7FA8, IRGKangXi=0952.310, RSKangXi=123.7, Def{envy, admire; praise; covet}
7FA9 CJK UNIFIED IDEOGRAPH-#7FA9, IRGKangXi=0952.320, RSKangXi=123.7, Def{right conduct, righteousness}
7FAA CJK UNIFIED IDEOGRAPH-#7FAA, IRGKangXi=0953.081, RSKangXi=123.7
7FAB CJK UNIFIED IDEOGRAPH-#7FAB, IRGKangXi=0953.100, RSKangXi=123.8, Def{the skeleton of a sheep}
7FAC CJK UNIFIED IDEOGRAPH-#7FAC, IRGKangXi=0953.210, RSKangXi=123.9
7FAD CJK UNIFIED IDEOGRAPH-#7FAD, IRGKangXi=0953.250, RSKangXi=123.9, Def{good}
7FAE CJK UNIFIED IDEOGRAPH-#7FAE, IRGKangXi=0953.280, RSKangXi=123.9, Def{soup, broth}
7FAF CJK UNIFIED IDEOGRAPH-#7FAF, IRGKangXi=0953.290, RSKangXi=123.9, Def{wether, castrated ram; deer skin}
7FB0 CJK UNIFIED IDEOGRAPH-#7FB0, IRGKangXi=0953.311, RSKangXi=123.9
7FB1 CJK UNIFIED IDEOGRAPH-#7FB1, IRGKangXi=0953.350, RSKangXi=123.10, Def{sheep}
7FB2 CJK UNIFIED IDEOGRAPH-#7FB2, IRGKangXi=0953.400, RSKangXi=123.10, Def{ancient emperor; breath, vapor}
7FB3 CJK UNIFIED IDEOGRAPH-#7FB3, IRGKangXi=0954.050, RSKangXi=123.12
7FB4 CJK UNIFIED IDEOGRAPH-#7FB4, IRGKangXi=0954.080, RSKangXi=123.12, Def{rank odour of sheep or goats}
7FB5 CJK UNIFIED IDEOGRAPH-#7FB5, IRGKangXi=0954.130, RSKangXi=123.12, Def{spirit}
7FB6 CJK UNIFIED IDEOGRAPH-#7FB6, IRGKangXi=0954.210, RSKangXi=123.13, Def{rank odor}
7FB7 CJK UNIFIED IDEOGRAPH-#7FB7, IRGKangXi=0954.230, RSKangXi=123.13
7FB8 CJK UNIFIED IDEOGRAPH-#7FB8, IRGKangXi=0954.240, RSKangXi=123.13, Def{weak, lean, emaciated, exhausted}
7FB9 CJK UNIFIED IDEOGRAPH-#7FB9, IRGKangXi=0954.250, RSKangXi=123.13, Def{soup, broth}
7FBA CJK UNIFIED IDEOGRAPH-#7FBA, IRGKangXi=0954.280, RSKangXi=123.14
7FBB CJK UNIFIED IDEOGRAPH-#7FBB, IRGKangXi=0954.320, RSKangXi=123.15
7FBC CJK UNIFIED IDEOGRAPH-#7FBC, IRGKangXi=0954.330, RSKangXi=123.15, Def{confuse, mix, interpolate}
7FBD CJK UNIFIED IDEOGRAPH-#7FBD, IRGKangXi=0955.010, RSKangXi=124.0, Def{feather, plume; wings; rad. 124}
7FBE CJK UNIFIED IDEOGRAPH-#7FBE, IRGKangXi=0955.090, RSKangXi=124.3
7FBF CJK UNIFIED IDEOGRAPH-#7FBF, IRGKangXi=0955.100, RSKangXi=124.3, Def{legendary archer}
7FC0 CJK UNIFIED IDEOGRAPH-#7FC0, IRGKangXi=0955.180, RSKangXi=124.4, Def{fly upward}
7FC1 CJK UNIFIED IDEOGRAPH-#7FC1, IRGKangXi=0955.210, RSKangXi=124.4, Def{old man; father, father-in-law}
7FC2 CJK UNIFIED IDEOGRAPH-#7FC2, IRGKangXi=0955.220, RSKangXi=124.4
7FC3 CJK UNIFIED IDEOGRAPH-#7FC3, IRGKangXi=0955.250, RSKangXi=124.4, Def{fly}
7FC4 CJK UNIFIED IDEOGRAPH-#7FC4, IRGKangXi=0955.270, RSKangXi=124.4, Def{winds; fins}
7FC5 CJK UNIFIED IDEOGRAPH-#7FC5, IRGKangXi=0955.280, RSKangXi=124.4, Def{wings; fin}
7FC6 CJK UNIFIED IDEOGRAPH-#7FC6, IRGKangXi=0956.030, RSKangXi=124.4, Def{color green; kingfisher}
7FC7 CJK UNIFIED IDEOGRAPH-#7FC7, IRGKangXi=0956.040, RSKangXi=124.5
7FC8 CJK UNIFIED IDEOGRAPH-#7FC8, IRGKangXi=0956.050, RSKangXi=124.5
7FC9 CJK UNIFIED IDEOGRAPH-#7FC9, IRGKangXi=0956.080, RSKangXi=124.5
7FCA CJK UNIFIED IDEOGRAPH-#7FCA, IRGKangXi=0956.090, RSKangXi=124.5, Def{flying; assist, help; respect}
7FCB CJK UNIFIED IDEOGRAPH-#7FCB, IRGKangXi=0956.100, RSKangXi=124.5
7FCC CJK UNIFIED IDEOGRAPH-#7FCC, IRGKangXi=0956.110, RSKangXi=124.5, Def{bright; daybreak, dawn; the next day}
7FCD CJK UNIFIED IDEOGRAPH-#7FCD, IRGKangXi=0956.150, RSKangXi=124.5
7FCE CJK UNIFIED IDEOGRAPH-#7FCE, IRGKangXi=0956.160, RSKangXi=124.5, Def{feather; plume; wing}
7FCF CJK UNIFIED IDEOGRAPH-#7FCF, IRGKangXi=0956.180, RSKangXi=124.5, Def{the sound of the wind; to soar}
7FD0 CJK UNIFIED IDEOGRAPH-#7FD0, IRGKangXi=0956.190, RSKangXi=124.5
7FD1 CJK UNIFIED IDEOGRAPH-#7FD1, IRGKangXi=0956.200, RSKangXi=124.5
7FD2 CJK UNIFIED IDEOGRAPH-#7FD2, IRGKangXi=0956.230, RSKangXi=124.5, Def{practice; flapping wings}
7FD3 CJK UNIFIED IDEOGRAPH-#7FD3, IRGKangXi=0956.370, RSKangXi=124.6
7FD4 CJK UNIFIED IDEOGRAPH-#7FD4, IRGKangXi=0956.400, RSKangXi=124.6, Def{soar, glide, hover; detailed}
7FD5 CJK UNIFIED IDEOGRAPH-#7FD5, IRGKangXi=0956.420, RSKangXi=124.6, Def{agree}
7FD6 CJK UNIFIED IDEOGRAPH-#7FD6, IRGKangXi=0956.430, RSKangXi=124.6, Def{ksc extension 3108}
7FD7 CJK UNIFIED IDEOGRAPH-#7FD7, IRGKangXi=0956.440, RSKangXi=124.6
7FD8 CJK UNIFIED IDEOGRAPH-#7FD8, IRGKangXi=0957.091, RSKangXi=124.6, Def{turn up, lift, elevate, raise}
7FD9 CJK UNIFIED IDEOGRAPH-#7FD9, IRGKangXi=0957.091, RSKangXi=124.6
7FDA CJK UNIFIED IDEOGRAPH-#7FDA, IRGKangXi=0957.091, RSKangXi=124.6
7FDB CJK UNIFIED IDEOGRAPH-#7FDB, IRGKangXi=0957.150, RSKangXi=124.7, Def{look of rumpled feathers; bedraggled; hasty; rapid flight}
7FDC CJK UNIFIED IDEOGRAPH-#7FDC, IRGKangXi=0957.220, RSKangXi=124.7
7FDD CJK UNIFIED IDEOGRAPH-#7FDD, IRGKangXi=0957.260, RSKangXi=124.7
7FDE CJK UNIFIED IDEOGRAPH-#7FDE, IRGKangXi=0957.300, RSKangXi=124.8
7FDF CJK UNIFIED IDEOGRAPH-#7FDF, IRGKangXi=0957.320, RSKangXi=124.8, Def{surname; a kind of pheasant; plumes}
7FE0 CJK UNIFIED IDEOGRAPH-#7FE0, IRGKangXi=0957.360, RSKangXi=124.8, Def{color green; kingfisher}
7FE1 CJK UNIFIED IDEOGRAPH-#7FE1, IRGKangXi=0957.370, RSKangXi=124.8, Def{kingfisher; emerald, jade}
7FE2 CJK UNIFIED IDEOGRAPH-#7FE2, IRGKangXi=0957.390, RSKangXi=124.8
7FE3 CJK UNIFIED IDEOGRAPH-#7FE3, IRGKangXi=0957.430, RSKangXi=124.8, Def{feathers used decorate coffin; large wooden fan}
7FE4 CJK UNIFIED IDEOGRAPH-#7FE4, IRGKangXi=0958.020, RSKangXi=124.8
7FE5 CJK UNIFIED IDEOGRAPH-#7FE5, IRGKangXi=0958.060, RSKangXi=124.9, Def{to soar; to take off}
7FE6 CJK UNIFIED IDEOGRAPH-#7FE6, IRGKangXi=0958.110, RSKangXi=124.9, Def{scissors; cut, clip; annhilate}
7FE7 CJK UNIFIED IDEOGRAPH-#7FE7, IRGKangXi=0958.130, RSKangXi=124.9
7FE8 CJK UNIFIED IDEOGRAPH-#7FE8, IRGKangXi=0958.180, RSKangXi=124.9
7FE9 CJK UNIFIED IDEOGRAPH-#7FE9, IRGKangXi=0958.190, RSKangXi=124.9, Def{fly, flutter}
7FEA CJK UNIFIED IDEOGRAPH-#7FEA, IRGKangXi=0958.210, RSKangXi=124.9, Def{flutter}
7FEB CJK UNIFIED IDEOGRAPH-#7FEB, IRGKangXi=0958.230, RSKangXi=124.9, Def{careless, play; a legendary archer}
7FEC CJK UNIFIED IDEOGRAPH-#7FEC, IRGKangXi=0958.250, RSKangXi=124.9, Def{pheasant; variegated; to fly}
7FED CJK UNIFIED IDEOGRAPH-#7FED, IRGKangXi=0958.260, RSKangXi=124.9
7FEE CJK UNIFIED IDEOGRAPH-#7FEE, IRGKangXi=0958.390, RSKangXi=124.10, Def{stem of feather; quill}
7FEF CJK UNIFIED IDEOGRAPH-#7FEF, IRGKangXi=0958.410, RSKangXi=124.10, Def{glistening plumage; reflection of the sun on water}
7FF0 CJK UNIFIED IDEOGRAPH-#7FF0, IRGKangXi=0958.430, RSKangXi=124.10, Def{writing brush, pen, pencil}
7FF1 CJK UNIFIED IDEOGRAPH-#7FF1, IRGKangXi=0959.101, RSKangXi=124.10, Def{soar, roam}
7FF2 CJK UNIFIED IDEOGRAPH-#7FF2, IRGKangXi=0959.140, RSKangXi=124.11
7FF3 CJK UNIFIED IDEOGRAPH-#7FF3, IRGKangXi=0959.150, RSKangXi=124.11, Def{shade, screen; to hide, screen}
7FF4 CJK UNIFIED IDEOGRAPH-#7FF4, IRGKangXi=0959.160, RSKangXi=124.11
7FF5 CJK UNIFIED IDEOGRAPH-#7FF5, IRGKangXi=0959.190, RSKangXi=196.6
7FF6 CJK UNIFIED IDEOGRAPH-#7FF6, IRGKangXi=0959.201, RSKangXi=124.11
7FF7 CJK UNIFIED IDEOGRAPH-#7FF7, IRGKangXi=0959.210, RSKangXi=124.12
7FF8 CJK UNIFIED IDEOGRAPH-#7FF8, IRGKangXi=0959.250, RSKangXi=124.12
7FF9 CJK UNIFIED IDEOGRAPH-#7FF9, IRGKangXi=0959.270, RSKangXi=124.12, Def{turn up, lift, elevate, raise}
7FFA CJK UNIFIED IDEOGRAPH-#7FFA, IRGKangXi=0959.280, RSKangXi=124.12, Def{soar, roam}
7FFB CJK UNIFIED IDEOGRAPH-#7FFB, IRGKangXi=0959.310, RSKangXi=124.12, Def{flip over, upset, capsize}
7FFC CJK UNIFIED IDEOGRAPH-#7FFC, IRGKangXi=0959.340, RSKangXi=124.12, Def{wings; fins on fish; shelter}
7FFD CJK UNIFIED IDEOGRAPH-#7FFD, IRGKangXi=0960.080, RSKangXi=124.13, Def{whir}
7FFE CJK UNIFIED IDEOGRAPH-#7FFE, IRGKangXi=0960.090, RSKangXi=124.13, Def{fly; to flit}
7FFF CJK UNIFIED IDEOGRAPH-#7FFF, IRGKangXi=0960.130, RSKangXi=124.14, Def{streamer adorned with feathers}
8000 CJK UNIFIED IDEOGRAPH-#8000, IRGKangXi=0960.140, RSKangXi=124.14, Def{shine, sparkle, dazzle; glory}
8001 CJK UNIFIED IDEOGRAPH-#8001, IRGKangXi=0960.250, RSKangXi=125.0, Def{old, aged; experienced}
8002 CJK UNIFIED IDEOGRAPH-#8002, IRGKangXi=0960.251, RSKangXi=125.-2, Def{variant of radical 125}
8003 CJK UNIFIED IDEOGRAPH-#8003, IRGKangXi=0960.270, RSKangXi=125.0, Def{examine, test; investigate}
8004 CJK UNIFIED IDEOGRAPH-#8004, IRGKangXi=0960.320, RSKangXi=125.4, Def{elderly person; very old, senile}
8005 CJK UNIFIED IDEOGRAPH-#8005, IRGKangXi=0961.010, RSKangXi=125.4, Def{that which; he who; those who}
8006 CJK UNIFIED IDEOGRAPH-#8006, IRGKangXi=0961.020, RSKangXi=125.4, Def{man of sixty; aged, old}
8007 CJK UNIFIED IDEOGRAPH-#8007, IRGKangXi=0961.070, RSKangXi=125.5, Def{wrinkled face of the elderly}
8008 CJK UNIFIED IDEOGRAPH-#8008, IRGKangXi=0961.080, RSKangXi=125.5, Def{old age}
8009 CJK UNIFIED IDEOGRAPH-#8009, IRGKangXi=0961.081, RSKangXi=125.5, Def{old age}
800A CJK UNIFIED IDEOGRAPH-#800A, IRGKangXi=0961.100, RSKangXi=125.6
800B CJK UNIFIED IDEOGRAPH-#800B, IRGKangXi=0961.110, RSKangXi=125.6, Def{aged; in one's eighties}
800C CJK UNIFIED IDEOGRAPH-#800C, IRGKangXi=0961.180, RSKangXi=126.0, Def{and; and then; and yet; but}
800D CJK UNIFIED IDEOGRAPH-#800D, IRGKangXi=0961.220, RSKangXi=126.3, Def{frolic, play, amuse, play with}
800E CJK UNIFIED IDEOGRAPH-#800E, IRGKangXi=0961.240, RSKangXi=126.3, Def{weak, pliable, soft, yielding}
800F CJK UNIFIED IDEOGRAPH-#800F, IRGKangXi=0961.250, RSKangXi=126.3, Def{whiskers}
8010 CJK UNIFIED IDEOGRAPH-#8010, IRGKangXi=0962.010, RSKangXi=126.3, Def{endure, bear; resist; patient}
8011 CJK UNIFIED IDEOGRAPH-#8011, IRGKangXi=0962.020, RSKangXi=126.3, Def{specialized; concentrated}
8012 CJK UNIFIED IDEOGRAPH-#8012, IRGKangXi=0962.160, RSKangXi=127.0, Def{handle of plow; plow; rad. 127}
8013 CJK UNIFIED IDEOGRAPH-#8013, IRGKangXi=0962.180, RSKangXi=127.2
8014 CJK UNIFIED IDEOGRAPH-#8014, IRGKangXi=0962.200, RSKangXi=127.3, Def{to hoe up the earth around plants}
8015 CJK UNIFIED IDEOGRAPH-#8015, IRGKangXi=0962.230, RSKangXi=127.4, Def{plow, cultivate}
8016 CJK UNIFIED IDEOGRAPH-#8016, IRGKangXi=0962.250, RSKangXi=127.4
8017 CJK UNIFIED IDEOGRAPH-#8017, IRGKangXi=0963.010, RSKangXi=127.4, Def{consume, use up; waste, squander}
8018 CJK UNIFIED IDEOGRAPH-#8018, IRGKangXi=0963.020, RSKangXi=127.4, Def{weed}
8019 CJK UNIFIED IDEOGRAPH-#8019, IRGKangXi=0963.030, RSKangXi=127.4, Def{rake}
801A CJK UNIFIED IDEOGRAPH-#801A, IRGKangXi=0963.050, RSKangXi=127.5
801B CJK UNIFIED IDEOGRAPH-#801B, IRGKangXi=0963.060, RSKangXi=127.5
801C CJK UNIFIED IDEOGRAPH-#801C, IRGKangXi=0963.070, RSKangXi=127.5, Def{spade-shaped tool; plow}
801D CJK UNIFIED IDEOGRAPH-#801D, IRGKangXi=0963.090, RSKangXi=127.5
801E CJK UNIFIED IDEOGRAPH-#801E, IRGKangXi=0963.100, RSKangXi=127.5, Def{flail}
801F CJK UNIFIED IDEOGRAPH-#801F, IRGKangXi=0963.110, RSKangXi=127.5
8020 CJK UNIFIED IDEOGRAPH-#8020, IRGKangXi=0963.130, RSKangXi=127.6, Def{till, dig}
8021 CJK UNIFIED IDEOGRAPH-#8021, IRGKangXi=0963.160, RSKangXi=127.7, Def{hoe}
8022 CJK UNIFIED IDEOGRAPH-#8022, IRGKangXi=0963.191, RSKangXi=127.7, Def{a kind of farm tool}
8023 CJK UNIFIED IDEOGRAPH-#8023, IRGKangXi=0963.270, RSKangXi=127.8
8024 CJK UNIFIED IDEOGRAPH-#8024, IRGKangXi=0963.340, RSKangXi=127.8, Def{plough}
8025 CJK UNIFIED IDEOGRAPH-#8025, IRGKangXi=0963.341, RSKangXi=127.8, Def{farm tool}
8026 CJK UNIFIED IDEOGRAPH-#8026, IRGKangXi=0964.060, RSKangXi=127.9, Def{plow side by side; team of two}
8027 CJK UNIFIED IDEOGRAPH-#8027, IRGKangXi=0964.071, RSKangXi=127.9, Def{drill for sowing grain}
8028 CJK UNIFIED IDEOGRAPH-#8028, IRGKangXi=0964.130, RSKangXi=127.10, Def{hoe, rake; weed}
8029 CJK UNIFIED IDEOGRAPH-#8029, IRGKangXi=0964.140, RSKangXi=127.10, Def{to plough. to sow}
802A CJK UNIFIED IDEOGRAPH-#802A, IRGKangXi=0964.161, RSKangXi=127.10, Def{plow, cultivate}
802B CJK UNIFIED IDEOGRAPH-#802B, IRGKangXi=0964.200, RSKangXi=127.11
802C CJK UNIFIED IDEOGRAPH-#802C, IRGKangXi=0964.220, RSKangXi=127.11, Def{drill for sowing grain}
802D CJK UNIFIED IDEOGRAPH-#802D, IRGKangXi=0964.260, RSKangXi=127.12, Def{plow, cultivate}
802E CJK UNIFIED IDEOGRAPH-#802E, IRGKangXi=0964.280, RSKangXi=127.12, Def{a kind of farm tool}
802F CJK UNIFIED IDEOGRAPH-#802F, IRGKangXi=0964.360
8030 CJK UNIFIED IDEOGRAPH-#8030, IRGKangXi=0964.390, RSKangXi=127.15, Def{toothless rake for drawing earth over newly sown grain}
8031 CJK UNIFIED IDEOGRAPH-#8031, IRGKangXi=0965.011, RSKangXi=127.16, Def{a kind of farm tool}
8032 CJK UNIFIED IDEOGRAPH-#8032, IRGKangXi=0965.011, RSKangXi=127.16
8033 CJK UNIFIED IDEOGRAPH-#8033, IRGKangXi=0965.050, RSKangXi=128.0, Def{ear; merely, only; handle}
8034 CJK UNIFIED IDEOGRAPH-#8034, IRGKangXi=0965.060, RSKangXi=128.1
8035 CJK UNIFIED IDEOGRAPH-#8035, IRGKangXi=0965.110, RSKangXi=128.2
8036 CJK UNIFIED IDEOGRAPH-#8036, IRGKangXi=0965.120, RSKangXi=128.3, Def{used in transliteration}
8037 CJK UNIFIED IDEOGRAPH-#8037, IRGKangXi=0965.150, RSKangXi=128.3, Def{ears hanging down}
8038 CJK UNIFIED IDEOGRAPH-#8038, IRGKangXi=0966.010, RSKangXi=128.4, Def{urge on; rise up; stir, excite}
8039 CJK UNIFIED IDEOGRAPH-#8039, IRGKangXi=0966.040, RSKangXi=128.4
803A CJK UNIFIED IDEOGRAPH-#803A, IRGKangXi=0966.050, RSKangXi=128.4, Def{non-standard variant of 職 U+8077, duty, profession; office, post}
803B CJK UNIFIED IDEOGRAPH-#803B, IRGKangXi=0966.060, RSKangXi=128.4, Def{shame, humiliation; ashamed}
803C CJK UNIFIED IDEOGRAPH-#803C, IRGKangXi=0966.080, RSKangXi=128.4, Def{ears without rim}
803D CJK UNIFIED IDEOGRAPH-#803D, IRGKangXi=0966.110, RSKangXi=128.4, Def{indulge in; be negligent}
803E CJK UNIFIED IDEOGRAPH-#803E, IRGKangXi=0966.130, RSKangXi=128.4, Def{deafness}
803F CJK UNIFIED IDEOGRAPH-#803F, IRGKangXi=0966.140, RSKangXi=128.4, Def{bright, shining; have guts}
8040 CJK UNIFIED IDEOGRAPH-#8040, IRGKangXi=0966.171, RSKangXi=128.4
8041 CJK UNIFIED IDEOGRAPH-#8041, IRGKangXi=0966.171, RSKangXi=128.4
8042 CJK UNIFIED IDEOGRAPH-#8042, IRGKangXi=0966.171, RSKangXi=128.4, Def{whisper; surname}
8043 CJK UNIFIED IDEOGRAPH-#8043, IRGKangXi=0966.190, RSKangXi=128.5, Def{ears without rims; a personal name}
8044 CJK UNIFIED IDEOGRAPH-#8044, IRGKangXi=0966.200, RSKangXi=128.5
8045 CJK UNIFIED IDEOGRAPH-#8045, IRGKangXi=0966.230, RSKangXi=128.5
8046 CJK UNIFIED IDEOGRAPH-#8046, IRGKangXi=0966.240, RSKangXi=128.5, Def{listen, hear}
8047 CJK UNIFIED IDEOGRAPH-#8047, IRGKangXi=0966.250, RSKangXi=128.5
8048 CJK UNIFIED IDEOGRAPH-#8048, IRGKangXi=0966.270, RSKangXi=128.5
8049 CJK UNIFIED IDEOGRAPH-#8049, IRGKangXi=0966.280, RSKangXi=128.5
804A CJK UNIFIED IDEOGRAPH-#804A, IRGKangXi=0967.010, RSKangXi=128.5, Def{somewhat, slightly, at least}
804B CJK UNIFIED IDEOGRAPH-#804B, IRGKangXi=0967.051, RSKangXi=128.5, Def{deaf}
804C CJK UNIFIED IDEOGRAPH-#804C, IRGKangXi=0967.051, RSKangXi=128.5, Def{duty, profession; office, post}
804D CJK UNIFIED IDEOGRAPH-#804D, IRGKangXi=0967.051, RSKangXi=128.5, Def{earwax}
804E CJK UNIFIED IDEOGRAPH-#804E, IRGKangXi=0967.070, RSKangXi=128.6
804F CJK UNIFIED IDEOGRAPH-#804F, IRGKangXi=0967.080, RSKangXi=128.6
8050 CJK UNIFIED IDEOGRAPH-#8050, IRGKangXi=0967.090, RSKangXi=128.6
8051 CJK UNIFIED IDEOGRAPH-#8051, IRGKangXi=0967.100, RSKangXi=128.6
8052 CJK UNIFIED IDEOGRAPH-#8052, IRGKangXi=0967.110, RSKangXi=128.6, Def{clamor, din, hubbub}
8053 CJK UNIFIED IDEOGRAPH-#8053, IRGKangXi=0967.161, RSKangXi=128.6
8054 CJK UNIFIED IDEOGRAPH-#8054, IRGKangXi=0967.161, RSKangXi=128.6, Def{connect, join; associate, ally}
8055 CJK UNIFIED IDEOGRAPH-#8055, IRGKangXi=0967.190, RSKangXi=128.7
8056 CJK UNIFIED IDEOGRAPH-#8056, IRGKangXi=0967.220, RSKangXi=128.7, Def{holy, sacred; sage}
8057 CJK UNIFIED IDEOGRAPH-#8057, IRGKangXi=0967.270, RSKangXi=128.7
8058 CJK UNIFIED IDEOGRAPH-#8058, IRGKangXi=0967.290, RSKangXi=128.7, Def{engage, employ; betroth}
8059 CJK UNIFIED IDEOGRAPH-#8059, IRGKangXi=0967.380, RSKangXi=128.8
805A CJK UNIFIED IDEOGRAPH-#805A, IRGKangXi=0967.410, RSKangXi=128.8, Def{assemble, meet together, collect}
805B CJK UNIFIED IDEOGRAPH-#805B, IRGKangXi=0968.010, RSKangXi=128.8
805C CJK UNIFIED IDEOGRAPH-#805C, IRGKangXi=0968.030, RSKangXi=128.8
805D CJK UNIFIED IDEOGRAPH-#805D, IRGKangXi=0968.070, RSKangXi=128.8, Def{to cut the left ears of the slain}
805E CJK UNIFIED IDEOGRAPH-#805E, IRGKangXi=0968.110, RSKangXi=128.8, Def{hear; smell; make known; news}
805F CJK UNIFIED IDEOGRAPH-#805F, IRGKangXi=0968.180, RSKangXi=128.8, Def{son-in-law; husband}
8060 CJK UNIFIED IDEOGRAPH-#8060, IRGKangXi=0968.190, RSKangXi=128.6
8061 CJK UNIFIED IDEOGRAPH-#8061, IRGKangXi=0968.210, RSKangXi=128.8, Def{intelligent, clever, bright}
8062 CJK UNIFIED IDEOGRAPH-#8062, IRGKangXi=0968.221, RSKangXi=128.8, Def{certainly, definitely}
8063 CJK UNIFIED IDEOGRAPH-#8063, IRGKangXi=0968.221, RSKangXi=128.8
8064 CJK UNIFIED IDEOGRAPH-#8064, IRGKangXi=0968.270, RSKangXi=128.9
8065 CJK UNIFIED IDEOGRAPH-#8065, IRGKangXi=0968.300, RSKangXi=128.9
8066 CJK UNIFIED IDEOGRAPH-#8066, IRGKangXi=0968.320, RSKangXi=128.9, Def{the hearing, to listen; astute; clever; quick of apprehension}
8067 CJK UNIFIED IDEOGRAPH-#8067, IRGKangXi=0968.330, RSKangXi=128.9
8068 CJK UNIFIED IDEOGRAPH-#8068, IRGKangXi=0968.391, RSKangXi=128.9, Def{connect, join; associate, ally}
8069 CJK UNIFIED IDEOGRAPH-#8069, IRGKangXi=0968.391, RSKangXi=128.9, Def{deaf}
806A CJK UNIFIED IDEOGRAPH-#806A, IRGKangXi=0968.391, RSKangXi=128.9, Def{intelligent, clever, bright}
806B CJK UNIFIED IDEOGRAPH-#806B, IRGKangXi=0968.391, Def{connect, join; associate, ally}
806C CJK UNIFIED IDEOGRAPH-#806C, IRGKangXi=0968.450, RSKangXi=128.10
806D CJK UNIFIED IDEOGRAPH-#806D, IRGKangXi=0969.030, RSKangXi=128.10
806E CJK UNIFIED IDEOGRAPH-#806E, IRGKangXi=0969.041, Def{connect, join; associate, ally}
806F CJK UNIFIED IDEOGRAPH-#806F, IRGKangXi=0969.050, RSKangXi=128.11, Def{connect, join; associate, ally}
8070 CJK UNIFIED IDEOGRAPH-#8070, IRGKangXi=0969.060, RSKangXi=128.11, Def{intelligent, clever, bright}
8071 CJK UNIFIED IDEOGRAPH-#8071, IRGKangXi=0969.110, RSKangXi=128.11, Def{bent and twisted; too complicated}
8072 CJK UNIFIED IDEOGRAPH-#8072, IRGKangXi=0969.180, RSKangXi=128.11, Def{sound, voice, noise; tone; music}
8073 CJK UNIFIED IDEOGRAPH-#8073, IRGKangXi=0969.200, RSKangXi=128.11, Def{urge on; rise up; stir, excite; to raise up; lofty}
8074 CJK UNIFIED IDEOGRAPH-#8074, IRGKangXi=0969.221, RSKangXi=128.12, Def{hear, listen; understand; obey}
8075 CJK UNIFIED IDEOGRAPH-#8075, IRGKangXi=0969.240, RSKangXi=128.12, Def{deaf}
8076 CJK UNIFIED IDEOGRAPH-#8076, IRGKangXi=0969.280, RSKangXi=128.12, Def{whisper; surname}
8077 CJK UNIFIED IDEOGRAPH-#8077, IRGKangXi=0970.040, RSKangXi=128.12, Def{duty, profession; office, post}
8078 CJK UNIFIED IDEOGRAPH-#8078, IRGKangXi=0970.130, RSKangXi=128.13
8079 CJK UNIFIED IDEOGRAPH-#8079, IRGKangXi=0970.160, RSKangXi=128.14, Def{earwax}
807A CJK UNIFIED IDEOGRAPH-#807A, IRGKangXi=0970.170, RSKangXi=128.14
807B CJK UNIFIED IDEOGRAPH-#807B, IRGKangXi=0970.200, RSKangXi=128.14, Def{death of a disembodied spirit; depraved}
807C CJK UNIFIED IDEOGRAPH-#807C, IRGKangXi=0970.211, Def{hear, listen; understand; obey}
807D CJK UNIFIED IDEOGRAPH-#807D, IRGKangXi=0970.240, RSKangXi=128.16, Def{hear, listen; understand; obey}
807E CJK UNIFIED IDEOGRAPH-#807E, IRGKangXi=0970.260, RSKangXi=128.16, Def{deaf}
807F CJK UNIFIED IDEOGRAPH-#807F, IRGKangXi=0971.010, RSKangXi=129.0, Def{writing brush, pencil; thereupon}
8080 CJK UNIFIED IDEOGRAPH-#8080, IRGKangXi=0971.021, RSKangXi=129.-2, Def{pen; radical number 129}
8081 CJK UNIFIED IDEOGRAPH-#8081, IRGKangXi=0971.060, RSKangXi=129.4
8082 CJK UNIFIED IDEOGRAPH-#8082, IRGKangXi=0971.070, RSKangXi=129.4
8083 CJK UNIFIED IDEOGRAPH-#8083, IRGKangXi=0971.071, RSKangXi=129.4, Def{pay respects; reverently}
8084 CJK UNIFIED IDEOGRAPH-#8084, IRGKangXi=0971.100, RSKangXi=129.7, Def{learn, practice, study; toil}
8085 CJK UNIFIED IDEOGRAPH-#8085, IRGKangXi=0971.110, RSKangXi=129.7, Def{pay respects; reverently}
8086 CJK UNIFIED IDEOGRAPH-#8086, IRGKangXi=0971.150, RSKangXi=129.7, AccountingNumeric=4, Def{indulge; excess; numeral four; particle meaning now, therefore; shop}
8087 CJK UNIFIED IDEOGRAPH-#8087, IRGKangXi=0972.020, RSKangXi=129.8, Def{begin, commence, originate}
8088 CJK UNIFIED IDEOGRAPH-#8088, IRGKangXi=0972.030, RSKangXi=129.8, Def{to commence; to found; to devise. at first. to originate. to strike}
8089 CJK UNIFIED IDEOGRAPH-#8089, IRGKangXi=0973.010, RSKangXi=130.0, Def{flesh; meat; KangXi radical 130}
808A CJK UNIFIED IDEOGRAPH-#808A, IRGKangXi=0973.040, RSKangXi=130.1
808B CJK UNIFIED IDEOGRAPH-#808B, IRGKangXi=0973.050, RSKangXi=130.2, Def{ribs; chest}
808C CJK UNIFIED IDEOGRAPH-#808C, IRGKangXi=0973.070, RSKangXi=130.2, Def{muscle tissue; meat on bones}
808D CJK UNIFIED IDEOGRAPH-#808D, IRGKangXi=0973.090, RSKangXi=130.2
808E CJK UNIFIED IDEOGRAPH-#808E, IRGKangXi=0973.110, RSKangXi=130.2
808F CJK UNIFIED IDEOGRAPH-#808F, IRGKangXi=0973.151, RSKangXi=130.2, Def{copulate, expletive (fuck)}
8090 CJK UNIFIED IDEOGRAPH-#8090, IRGKangXi=0973.170, RSKangXi=130.3, Def{armpit, arms}
8091 CJK UNIFIED IDEOGRAPH-#8091, IRGKangXi=0973.180, RSKangXi=130.3
8092 CJK UNIFIED IDEOGRAPH-#8092, IRGKangXi=0973.190, RSKangXi=130.3
8093 CJK UNIFIED IDEOGRAPH-#8093, IRGKangXi=0973.210, RSKangXi=130.3, Def{region between heart and diaphragm}
8094 CJK UNIFIED IDEOGRAPH-#8094, IRGKangXi=0973.230, RSKangXi=130.3
8095 CJK UNIFIED IDEOGRAPH-#8095, IRGKangXi=0973.240, RSKangXi=130.3, Def{tough, strong, hard}
8096 CJK UNIFIED IDEOGRAPH-#8096, IRGKangXi=0973.250, RSKangXi=130.3, Def{look like, resemble, be like}
8097 CJK UNIFIED IDEOGRAPH-#8097, IRGKangXi=0974.020, RSKangXi=130.3
8098 CJK UNIFIED IDEOGRAPH-#8098, IRGKangXi=0974.040, RSKangXi=130.3, Def{the elbow; help a person shoulder a load}
8099 CJK UNIFIED IDEOGRAPH-#8099, IRGKangXi=0974.050, RSKangXi=130.3, Def{a small worm; to twist; to surround; empty}
809A CJK UNIFIED IDEOGRAPH-#809A, IRGKangXi=0974.060, RSKangXi=130.3, Def{belly; abdomen; bowels}
809B CJK UNIFIED IDEOGRAPH-#809B, IRGKangXi=0974.070, RSKangXi=130.3, Def{anus}
809C CJK UNIFIED IDEOGRAPH-#809C, IRGKangXi=0974.080, RSKangXi=130.3, Def{to sacrifice on two successive days}
809D CJK UNIFIED IDEOGRAPH-#809D, IRGKangXi=0974.090, RSKangXi=130.3, Def{liver}
809E CJK UNIFIED IDEOGRAPH-#809E, IRGKangXi=0974.120, RSKangXi=130.3
809F CJK UNIFIED IDEOGRAPH-#809F, IRGKangXi=0974.131, RSKangXi=130.3, Def{an organic compound}
80A0 CJK UNIFIED IDEOGRAPH-#80A0, IRGKangXi=0974.131, RSKangXi=130.3, Def{intestines; emotions; sausage}
80A1 CJK UNIFIED IDEOGRAPH-#80A1, IRGKangXi=0974.170, RSKangXi=130.4, Def{thighs, haunches, rump; share}
80A2 CJK UNIFIED IDEOGRAPH-#80A2, IRGKangXi=0974.180, RSKangXi=130.4, Def{human limbs; animal feet}
80A3 CJK UNIFIED IDEOGRAPH-#80A3, IRGKangXi=0974.200, RSKangXi=130.4
80A4 CJK UNIFIED IDEOGRAPH-#80A4, IRGKangXi=0974.220, RSKangXi=130.4, Def{skin; superficial, shallow}
80A5 CJK UNIFIED IDEOGRAPH-#80A5, IRGKangXi=0974.230, RSKangXi=130.4, Def{fat, plump, obese; fertile}
80A6 CJK UNIFIED IDEOGRAPH-#80A6, IRGKangXi=0975.010, RSKangXi=130.4, Def{large head; many; high; to divide, to distribute}
80A7 CJK UNIFIED IDEOGRAPH-#80A7, IRGKangXi=0975.070, RSKangXi=130.4, Def{embryo; unfinished things}
80A8 CJK UNIFIED IDEOGRAPH-#80A8, IRGKangXi=0975.090, RSKangXi=130.4, Def{to swell; fat, swollen}
80A9 CJK UNIFIED IDEOGRAPH-#80A9, IRGKangXi=0975.100, RSKangXi=130.4, Def{shoulders; to shoulder; bear}
80AA CJK UNIFIED IDEOGRAPH-#80AA, IRGKangXi=0975.120, RSKangXi=130.4, Def{animal fat}
80AB CJK UNIFIED IDEOGRAPH-#80AB, IRGKangXi=0975.130, RSKangXi=130.4, Def{the gizzard of a fowl; honest, sincere}
80AC CJK UNIFIED IDEOGRAPH-#80AC, IRGKangXi=0975.140, RSKangXi=130.4, Def{wart; tumor; goiter; papule}
80AD CJK UNIFIED IDEOGRAPH-#80AD, IRGKangXi=0975.150, RSKangXi=130.4, Def{fat; seal (moon radical DKW: 14342 is different)}
80AE CJK UNIFIED IDEOGRAPH-#80AE, IRGKangXi=0975.160, RSKangXi=130.4, Def{dirty}
80AF CJK UNIFIED IDEOGRAPH-#80AF, IRGKangXi=0976.010, RSKangXi=130.4, Def{willing; consent to, permit}
80B0 CJK UNIFIED IDEOGRAPH-#80B0, IRGKangXi=0976.040, RSKangXi=130.4
80B1 CJK UNIFIED IDEOGRAPH-#80B1, IRGKangXi=0976.080, RSKangXi=130.4, Def{forearm}
80B2 CJK UNIFIED IDEOGRAPH-#80B2, IRGKangXi=0976.140, RSKangXi=130.4, Def{produce, give birth to; educate}
80B3 CJK UNIFIED IDEOGRAPH-#80B3, IRGKangXi=0976.160, RSKangXi=130.4, Def{the corners of the mouth, the lips}
80B4 CJK UNIFIED IDEOGRAPH-#80B4, IRGKangXi=0976.180, RSKangXi=130.4, Def{cooked or prepared meat}
80B5 CJK UNIFIED IDEOGRAPH-#80B5, IRGKangXi=0976.190, RSKangXi=130.4, Def{table}
80B6 CJK UNIFIED IDEOGRAPH-#80B6, IRGKangXi=0976.200, RSKangXi=130.4, Def{(Cant.) leg, thigh}
80B7 CJK UNIFIED IDEOGRAPH-#80B7, IRGKangXi=0976.210, RSKangXi=130.4, Def{area between waist and hips}
80B8 CJK UNIFIED IDEOGRAPH-#80B8, IRGKangXi=0976.220, RSKangXi=130.4, Def{spread out; smilling or laughing}
80B9 CJK UNIFIED IDEOGRAPH-#80B9, IRGKangXi=0976.230, RSKangXi=130.4, Def{(Cant.) vulgar, abusive term for female sex organ, cunt}
80BA CJK UNIFIED IDEOGRAPH-#80BA, IRGKangXi=0976.240, RSKangXi=130.4, Def{lungs}
80BB CJK UNIFIED IDEOGRAPH-#80BB, IRGKangXi=0976.030, RSKangXi=130.4
80BC CJK UNIFIED IDEOGRAPH-#80BC, IRGKangXi=0977.041, RSKangXi=130.4, Def{hydrazine}
80BD CJK UNIFIED IDEOGRAPH-#80BD, IRGKangXi=0977.041, RSKangXi=130.4, Def{a chemical compound}
80BE CJK UNIFIED IDEOGRAPH-#80BE, IRGKangXi=0977.041, RSKangXi=130.4, Def{kidneys; testes, gizzard}
80BF CJK UNIFIED IDEOGRAPH-#80BF, IRGKangXi=0977.041, RSKangXi=130.4, Def{swell; swollen; swelling}
80C0 CJK UNIFIED IDEOGRAPH-#80C0, IRGKangXi=0977.041, RSKangXi=130.4, Def{swell, inflate, expand}
80C1 CJK UNIFIED IDEOGRAPH-#80C1, IRGKangXi=0977.041, RSKangXi=130.4, Def{ribs, armpits; flank; threaten}
80C2 CJK UNIFIED IDEOGRAPH-#80C2, IRGKangXi=0977.050, RSKangXi=130.5
80C3 CJK UNIFIED IDEOGRAPH-#80C3, IRGKangXi=0977.060, RSKangXi=130.5, Def{stomach; gizzard of fowl}
80C4 CJK UNIFIED IDEOGRAPH-#80C4, IRGKangXi=0977.070, RSKangXi=130.5, Def{helmet, headpiece; descendant}
80C5 CJK UNIFIED IDEOGRAPH-#80C5, IRGKangXi=0977.100, RSKangXi=130.5
80C6 CJK UNIFIED IDEOGRAPH-#80C6, IRGKangXi=0977.120, RSKangXi=130.5, Def{gall bladder; bravery, courage}
80C7 CJK UNIFIED IDEOGRAPH-#80C7, IRGKangXi=0977.140, RSKangXi=130.5
80C8 CJK UNIFIED IDEOGRAPH-#80C8, IRGKangXi=0977.150, RSKangXi=130.5
80C9 CJK UNIFIED IDEOGRAPH-#80C9, IRGKangXi=0977.170, RSKangXi=130.5
80CA CJK UNIFIED IDEOGRAPH-#80CA, IRGKangXi=0977.180, RSKangXi=130.5, Def{yoke}
80CB CJK UNIFIED IDEOGRAPH-#80CB, IRGKangXi=0977.200, RSKangXi=130.5
80CC CJK UNIFIED IDEOGRAPH-#80CC, IRGKangXi=0977.210, RSKangXi=130.5, Def{back; back side; behind; betray}
80CD CJK UNIFIED IDEOGRAPH-#80CD, IRGKangXi=0978.010, RSKangXi=130.5
80CE CJK UNIFIED IDEOGRAPH-#80CE, IRGKangXi=0978.020, RSKangXi=130.5, Def{unborn child, embryo, fetus}
80CF CJK UNIFIED IDEOGRAPH-#80CF, IRGKangXi=0978.030, RSKangXi=130.5, Def{meat}
80D0 CJK UNIFIED IDEOGRAPH-#80D0, IRGKangXi=0978.060, RSKangXi=130.5
80D1 CJK UNIFIED IDEOGRAPH-#80D1, IRGKangXi=0978.070, RSKangXi=130.5, Def{the limbs; the upper arm; wings of birds; legs of animals}
80D2 CJK UNIFIED IDEOGRAPH-#80D2, IRGKangXi=0978.100, RSKangXi=130.5
80D3 CJK UNIFIED IDEOGRAPH-#80D3, IRGKangXi=0978.110, RSKangXi=130.5, Def{fat}
80D4 CJK UNIFIED IDEOGRAPH-#80D4, IRGKangXi=0978.120, RSKangXi=130.5, Def{rotten meat; bones of dead animals}
80D5 CJK UNIFIED IDEOGRAPH-#80D5, IRGKangXi=0978.130, RSKangXi=130.5
80D6 CJK UNIFIED IDEOGRAPH-#80D6, IRGKangXi=0978.140, RSKangXi=130.5, Def{fat, obese; fatty}
80D7 CJK UNIFIED IDEOGRAPH-#80D7, IRGKangXi=0978.160, RSKangXi=130.5, Def{pustules of any kind, a rash or eruption.measles; various kinds of fever}
80D8 CJK UNIFIED IDEOGRAPH-#80D8, IRGKangXi=0978.180, RSKangXi=130.5
80D9 CJK UNIFIED IDEOGRAPH-#80D9, IRGKangXi=0978.190, RSKangXi=130.5, Def{meat offered in sacrifice to one's ancestors}
80DA CJK UNIFIED IDEOGRAPH-#80DA, IRGKangXi=0979.030, RSKangXi=130.5, Def{embryo; unfinished things}
80DB CJK UNIFIED IDEOGRAPH-#80DB, IRGKangXi=0979.050, RSKangXi=130.5, Def{the shoulder, shoulder blade}
80DC CJK UNIFIED IDEOGRAPH-#80DC, IRGKangXi=0979.070, RSKangXi=130.5, Def{victory; excel, be better than}
80DD CJK UNIFIED IDEOGRAPH-#80DD, IRGKangXi=0979.080, RSKangXi=130.5, Def{callous, corn}
80DE CJK UNIFIED IDEOGRAPH-#80DE, IRGKangXi=0979.090, RSKangXi=130.5, Def{womb, placenta, fetal membrane}
80DF CJK UNIFIED IDEOGRAPH-#80DF, IRGKangXi=0979.100, RSKangXi=130.5
80E0 CJK UNIFIED IDEOGRAPH-#80E0, IRGKangXi=0979.110, RSKangXi=130.5, Def{open; throw away}
80E1 CJK UNIFIED IDEOGRAPH-#80E1, IRGKangXi=0979.120, RSKangXi=130.5, Def{recklessly, foolishly; wildly}
80E2 CJK UNIFIED IDEOGRAPH-#80E2, IRGKangXi=0979.130, RSKangXi=130.5
80E3 CJK UNIFIED IDEOGRAPH-#80E3, IRGKangXi=0980.030, RSKangXi=130.5
80E4 CJK UNIFIED IDEOGRAPH-#80E4, IRGKangXi=0980.040, RSKangXi=130.5, Def{heir, successor; progeny, posterity}
80E5 CJK UNIFIED IDEOGRAPH-#80E5, IRGKangXi=0980.060, RSKangXi=130.5, Def{all, together, mutually}
80E6 CJK UNIFIED IDEOGRAPH-#80E6, IRGKangXi=0980.090, RSKangXi=130.5, Def{the navel}
80E7 CJK UNIFIED IDEOGRAPH-#80E7, IRGKangXi=0980.141, RSKangXi=130.5, Def{condition or appearance of moon}
80E8 CJK UNIFIED IDEOGRAPH-#80E8, IRGKangXi=0980.141, RSKangXi=130.5, Def{a kind of protein}
80E9 CJK UNIFIED IDEOGRAPH-#80E9, IRGKangXi=0980.141, RSKangXi=130.5, Def{an organic compound}
80EA CJK UNIFIED IDEOGRAPH-#80EA, IRGKangXi=0980.141, RSKangXi=130.5, Def{arrange in order; display}
80EB CJK UNIFIED IDEOGRAPH-#80EB, IRGKangXi=0980.141, RSKangXi=130.5, Def{shinbone; calf of leg}
80EC CJK UNIFIED IDEOGRAPH-#80EC, IRGKangXi=0980.141, RSKangXi=130.5, Def{a disease's name in Chinese medicine}
80ED CJK UNIFIED IDEOGRAPH-#80ED, IRGKangXi=0980.170, RSKangXi=130.6, Def{rouge, cosmetics}
80EE CJK UNIFIED IDEOGRAPH-#80EE, IRGKangXi=0980.190, RSKangXi=130.6, Def{to swell}
80EF CJK UNIFIED IDEOGRAPH-#80EF, IRGKangXi=0980.210, RSKangXi=130.6, Def{pelvis; groin; thighs}
80F0 CJK UNIFIED IDEOGRAPH-#80F0, IRGKangXi=0980.220, RSKangXi=130.6, Def{pancreas; soap}
80F1 CJK UNIFIED IDEOGRAPH-#80F1, IRGKangXi=0980.230, RSKangXi=130.6, Def{bladder}
80F2 CJK UNIFIED IDEOGRAPH-#80F2, IRGKangXi=0980.240, RSKangXi=130.6
80F3 CJK UNIFIED IDEOGRAPH-#80F3, IRGKangXi=0980.250, RSKangXi=130.6, Def{armpit, arms}
80F4 CJK UNIFIED IDEOGRAPH-#80F4, IRGKangXi=0980.260, RSKangXi=130.6, Def{the large intestine; the body}
80F5 CJK UNIFIED IDEOGRAPH-#80F5, IRGKangXi=0980.270, RSKangXi=130.6, Def{(Cant.) 芙胵, the gizzard and liver of domestic fowl}
80F6 CJK UNIFIED IDEOGRAPH-#80F6, IRGKangXi=0981.030, RSKangXi=130.6, Def{glue, gum, resin, rubber; sound; shin bone}
80F7 CJK UNIFIED IDEOGRAPH-#80F7, IRGKangXi=0981.040, RSKangXi=130.6, Def{breast, chest, thorax; clamor}
80F8 CJK UNIFIED IDEOGRAPH-#80F8, IRGKangXi=0981.050, RSKangXi=130.6, Def{breast, bosom, chest; thorax}
80F9 CJK UNIFIED IDEOGRAPH-#80F9, IRGKangXi=0981.070, RSKangXi=130.6, Def{cooked; well-done}
80FA CJK UNIFIED IDEOGRAPH-#80FA, IRGKangXi=0981.090, RSKangXi=130.6, Def{amine}
80FB CJK UNIFIED IDEOGRAPH-#80FB, IRGKangXi=0981.120, RSKangXi=130.6
80FC CJK UNIFIED IDEOGRAPH-#80FC, IRGKangXi=0981.150, RSKangXi=130.6, Def{callus, calluses}
80FD CJK UNIFIED IDEOGRAPH-#80FD, IRGKangXi=0981.160, RSKangXi=130.6, Def{to be able; can, permitted to; ability}
80FE CJK UNIFIED IDEOGRAPH-#80FE, IRGKangXi=0981.180, RSKangXi=130.6, Def{minced meat; to cut meat into pieces}
80FF CJK UNIFIED IDEOGRAPH-#80FF, IRGKangXi=0981.190, RSKangXi=130.6
8100 CJK UNIFIED IDEOGRAPH-#8100, IRGKangXi=0981.200, RSKangXi=130.6
8101 CJK UNIFIED IDEOGRAPH-#8101, IRGKangXi=0981.230, RSKangXi=130.6, Def{to offer flesh in sacrifice}
8102 CJK UNIFIED IDEOGRAPH-#8102, IRGKangXi=0981.240, RSKangXi=130.6, Def{fat, grease, lard; grease}
8103 CJK UNIFIED IDEOGRAPH-#8103, IRGKangXi=0981.250, RSKangXi=130.6, Def{gland}
8104 CJK UNIFIED IDEOGRAPH-#8104, IRGKangXi=0982.010
8105 CJK UNIFIED IDEOGRAPH-#8105, IRGKangXi=0982.020, RSKangXi=130.6, Def{ribs; armpits; flank; threaten}
8106 CJK UNIFIED IDEOGRAPH-#8106, IRGKangXi=0982.030, RSKangXi=130.6, Def{crisp; fragile, frail; brittle}
8107 CJK UNIFIED IDEOGRAPH-#8107, IRGKangXi=0982.040, RSKangXi=130.6, Def{ribs, armpits; flank; threaten}
8108 CJK UNIFIED IDEOGRAPH-#8108, IRGKangXi=0982.050, RSKangXi=130.6, Def{blood vessels, veins, arteries}
8109 CJK UNIFIED IDEOGRAPH-#8109, IRGKangXi=0982.060, RSKangXi=130.6, Def{blood vessels, veins, arteries}
810A CJK UNIFIED IDEOGRAPH-#810A, IRGKangXi=0982.080, RSKangXi=130.6, Def{spine, backbone; ridge}
810B CJK UNIFIED IDEOGRAPH-#810B, IRGKangXi=0982.171, RSKangXi=130.6
810C CJK UNIFIED IDEOGRAPH-#810C, IRGKangXi=0982.171, RSKangXi=130.6, Def{(Cant.) female breast; milk}
810D CJK UNIFIED IDEOGRAPH-#810D, IRGKangXi=0982.171, RSKangXi=130.6, Def{minced meat or fish}
810E CJK UNIFIED IDEOGRAPH-#810E, IRGKangXi=0982.171, RSKangXi=130.6, Def{an organic compound}
810F CJK UNIFIED IDEOGRAPH-#810F, IRGKangXi=0982.171, RSKangXi=130.6, Def{internal organs, viscera; dirty}
8110 CJK UNIFIED IDEOGRAPH-#8110, IRGKangXi=0982.171, RSKangXi=130.6, Def{abdominal area of crab; navel}
8111 CJK UNIFIED IDEOGRAPH-#8111, IRGKangXi=0982.171, RSKangXi=130.6, Def{brain}
8112 CJK UNIFIED IDEOGRAPH-#8112, IRGKangXi=0982.171, RSKangXi=130.6, Def{open; throw away}
8113 CJK UNIFIED IDEOGRAPH-#8113, IRGKangXi=0982.171, RSKangXi=130.6, Def{pus}
8114 CJK UNIFIED IDEOGRAPH-#8114, IRGKangXi=0982.171, RSKangXi=130.6, Def{small lump of meat; sliced meat}
8115 CJK UNIFIED IDEOGRAPH-#8115, IRGKangXi=0982.180, RSKangXi=130.7
8116 CJK UNIFIED IDEOGRAPH-#8116, IRGKangXi=0982.200, RSKangXi=130.7, Def{neck}
8117 CJK UNIFIED IDEOGRAPH-#8117, IRGKangXi=0982.210, RSKangXi=130.7, Def{coinciding, agreeing}
8118 CJK UNIFIED IDEOGRAPH-#8118, IRGKangXi=0982.220, RSKangXi=130.7, Def{internal cavity of stomach}
8119 CJK UNIFIED IDEOGRAPH-#8119, IRGKangXi=0982.230, RSKangXi=130.7
811A CJK UNIFIED IDEOGRAPH-#811A, IRGKangXi=0983.010, RSKangXi=130.7, Def{leg, foot; base, leg, foundation}
811B CJK UNIFIED IDEOGRAPH-#811B, IRGKangXi=0983.020, RSKangXi=130.7, Def{shinbone; calf of leg}
811C CJK UNIFIED IDEOGRAPH-#811C, IRGKangXi=0983.030, RSKangXi=130.7
811D CJK UNIFIED IDEOGRAPH-#811D, IRGKangXi=0983.050, RSKangXi=130.7, Def{distend}
811E CJK UNIFIED IDEOGRAPH-#811E, IRGKangXi=0983.060, RSKangXi=130.7, Def{minced meat; trifles}
811F CJK UNIFIED IDEOGRAPH-#811F, IRGKangXi=0983.100, RSKangXi=130.7
8120 CJK UNIFIED IDEOGRAPH-#8120, IRGKangXi=0983.140, RSKangXi=130.7
8121 CJK UNIFIED IDEOGRAPH-#8121, IRGKangXi=0983.150, RSKangXi=130.7, Def{strips of dried meat, jerky; stiff and straight}
8122 CJK UNIFIED IDEOGRAPH-#8122, IRGKangXi=0983.220, RSKangXi=130.7, Def{flesh}
8123 CJK UNIFIED IDEOGRAPH-#8123, IRGKangXi=0983.230, RSKangXi=130.7, Def{lips}
8124 CJK UNIFIED IDEOGRAPH-#8124, IRGKangXi=0983.250, RSKangXi=130.7, Def{raw meat for sacrifice}
8125 CJK UNIFIED IDEOGRAPH-#8125, IRGKangXi=0984.010, RSKangXi=130.7
8126 CJK UNIFIED IDEOGRAPH-#8126, IRGKangXi=0984.020, RSKangXi=130.7, Def{used in 'lede', slovenly}
8127 CJK UNIFIED IDEOGRAPH-#8127, IRGKangXi=0984.040, RSKangXi=130.7, Def{reduce, contract; exploit; reproductive organ of infant}
8128 CJK UNIFIED IDEOGRAPH-#8128, IRGKangXi=0984.050, RSKangXi=130.7
8129 CJK UNIFIED IDEOGRAPH-#8129, IRGKangXi=0984.080, RSKangXi=130.7, Def{dried meat (used as teachers payment in ancient times)}
812A CJK UNIFIED IDEOGRAPH-#812A, IRGKangXi=0984.090, RSKangXi=130.7, Def{erysipelas; sloughing of an ulcer}
812B CJK UNIFIED IDEOGRAPH-#812B, IRGKangXi=0984.120, RSKangXi=130.7, Def{take off, peel off, strip}
812C CJK UNIFIED IDEOGRAPH-#812C, IRGKangXi=0984.130, RSKangXi=130.7, Def{a bladder}
812D CJK UNIFIED IDEOGRAPH-#812D, IRGKangXi=0984.140, RSKangXi=130.7
812E CJK UNIFIED IDEOGRAPH-#812E, IRGKangXi=0984.150, RSKangXi=130.7
812F CJK UNIFIED IDEOGRAPH-#812F, IRGKangXi=0985.010, RSKangXi=130.7, Def{dried meat; preserved fruits}
8130 CJK UNIFIED IDEOGRAPH-#8130, IRGKangXi=0985.020, RSKangXi=130.7, Def{the neck}
8131 CJK UNIFIED IDEOGRAPH-#8131, IRGKangXi=0985.111, RSKangXi=130.7, Def{take off}
8132 CJK UNIFIED IDEOGRAPH-#8132, IRGKangXi=0985.111, RSKangXi=130.7, Def{urea}
8133 CJK UNIFIED IDEOGRAPH-#8133, IRGKangXi=0985.111, RSKangXi=130.7, Def{brain}
8134 CJK UNIFIED IDEOGRAPH-#8134, IRGKangXi=0985.111, RSKangXi=130.7
8135 CJK UNIFIED IDEOGRAPH-#8135, IRGKangXi=0985.111, RSKangXi=130.7, Def{thighs, haunches, rump; share}
8136 CJK UNIFIED IDEOGRAPH-#8136, IRGKangXi=0985.111, RSKangXi=130.7, Def{lines}
8137 CJK UNIFIED IDEOGRAPH-#8137, IRGKangXi=0985.111, RSKangXi=130.7, Def{(Cant.) tongue}
8138 CJK UNIFIED IDEOGRAPH-#8138, IRGKangXi=0985.111, RSKangXi=130.7, Def{face; cheek; reputation}
8139 CJK UNIFIED IDEOGRAPH-#8139, IRGKangXi=0985.140, RSKangXi=130.8, Def{swell, inflate, expand}
813A CJK UNIFIED IDEOGRAPH-#813A, IRGKangXi=0985.160, RSKangXi=130.8
813B CJK UNIFIED IDEOGRAPH-#813B, IRGKangXi=0985.170, RSKangXi=130.8
813C CJK UNIFIED IDEOGRAPH-#813C, IRGKangXi=0985.200, RSKangXi=130.8
813D CJK UNIFIED IDEOGRAPH-#813D, IRGKangXi=0985.220, RSKangXi=130.8, Def{(Cant.) a child's penis}
813E CJK UNIFIED IDEOGRAPH-#813E, IRGKangXi=0985.230, RSKangXi=130.8, Def{spleen, pancreas; disposition}
813F CJK UNIFIED IDEOGRAPH-#813F, IRGKangXi=0985.250, RSKangXi=130.8
8140 CJK UNIFIED IDEOGRAPH-#8140, IRGKangXi=0985.270, RSKangXi=130.8
8141 CJK UNIFIED IDEOGRAPH-#8141, IRGKangXi=0985.290, RSKangXi=130.8, Def{callus}
8142 CJK UNIFIED IDEOGRAPH-#8142, IRGKangXi=0985.300, RSKangXi=130.8
8143 CJK UNIFIED IDEOGRAPH-#8143, IRGKangXi=0986.020, RSKangXi=130.8
8144 CJK UNIFIED IDEOGRAPH-#8144, IRGKangXi=0986.050, RSKangXi=130.8
8145 CJK UNIFIED IDEOGRAPH-#8145, IRGKangXi=0986.080, RSKangXi=130.8
8146 CJK UNIFIED IDEOGRAPH-#8146, IRGKangXi=0986.150, RSKangXi=130.8, Def{prosperous; good; protruding}
8147 CJK UNIFIED IDEOGRAPH-#8147, IRGKangXi=0986.180, RSKangXi=130.8
8148 CJK UNIFIED IDEOGRAPH-#8148, IRGKangXi=0986.220, RSKangXi=130.8, Def{an organic compound}
8149 CJK UNIFIED IDEOGRAPH-#8149, IRGKangXi=0986.250, RSKangXi=130.8, Def{nipple, pap}
814A CJK UNIFIED IDEOGRAPH-#814A, IRGKangXi=0986.270, RSKangXi=130.8, Def{year end sacrifice; dried meat}
814B CJK UNIFIED IDEOGRAPH-#814B, IRGKangXi=0986.280, RSKangXi=130.8, Def{armpit}
814C CJK UNIFIED IDEOGRAPH-#814C, IRGKangXi=0986.290, RSKangXi=130.8, Def{salt, pickle; be dirty}
814D CJK UNIFIED IDEOGRAPH-#814D, IRGKangXi=0986.310, RSKangXi=130.8, Def{soft}
814E CJK UNIFIED IDEOGRAPH-#814E, IRGKangXi=0987.020, RSKangXi=130.8, Def{kidneys; testes, gizzard}
814F CJK UNIFIED IDEOGRAPH-#814F, IRGKangXi=0987.030, RSKangXi=130.8
8150 CJK UNIFIED IDEOGRAPH-#8150, IRGKangXi=0987.050, RSKangXi=130.8, Def{rot, decay, spoil; rotten}
8151 CJK UNIFIED IDEOGRAPH-#8151, IRGKangXi=0987.060, RSKangXi=130.8, Def{bowels, entrails, internal organs}
8152 CJK UNIFIED IDEOGRAPH-#8152, IRGKangXi=0987.070, RSKangXi=130.8, Def{game}
8153 CJK UNIFIED IDEOGRAPH-#8153, IRGKangXi=0987.090, RSKangXi=130.8, Def{calf; avoid; be ill; wither}
8154 CJK UNIFIED IDEOGRAPH-#8154, IRGKangXi=0987.100, RSKangXi=130.8, Def{chest cavity; hollow in body}
8155 CJK UNIFIED IDEOGRAPH-#8155, IRGKangXi=0987.110, RSKangXi=130.8, Def{wrist}
8156 CJK UNIFIED IDEOGRAPH-#8156, IRGKangXi=0987.150, RSKangXi=130.8, Def{peptone}
8157 CJK UNIFIED IDEOGRAPH-#8157, IRGKangXi=0987.231, RSKangXi=130.8
8158 CJK UNIFIED IDEOGRAPH-#8158, IRGKangXi=0987.231, RSKangXi=130.11
8159 CJK UNIFIED IDEOGRAPH-#8159, IRGKangXi=0987.231, RSKangXi=130.8, Def{an organic compound}
815A CJK UNIFIED IDEOGRAPH-#815A, IRGKangXi=0987.231, RSKangXi=130.8, Def{buttock}
815B CJK UNIFIED IDEOGRAPH-#815B, IRGKangXi=0987.270, RSKangXi=130.9
815C CJK UNIFIED IDEOGRAPH-#815C, IRGKangXi=0987.280, RSKangXi=130.9, Def{quickening of the foetus}
815D CJK UNIFIED IDEOGRAPH-#815D, IRGKangXi=0988.010, RSKangXi=130.9
815E CJK UNIFIED IDEOGRAPH-#815E, IRGKangXi=0988.030, RSKangXi=130.9
815F CJK UNIFIED IDEOGRAPH-#815F, IRGKangXi=0988.060, RSKangXi=130.9, Def{vagina}
8160 CJK UNIFIED IDEOGRAPH-#8160, IRGKangXi=0988.090, RSKangXi=130.9, Def{between the skin and the flesh}
8161 CJK UNIFIED IDEOGRAPH-#8161, IRGKangXi=0988.100, RSKangXi=130.9, Def{lines}
8162 CJK UNIFIED IDEOGRAPH-#8162, IRGKangXi=0988.110, RSKangXi=130.9, Def{the collar-bone}
8163 CJK UNIFIED IDEOGRAPH-#8163, IRGKangXi=0988.120, RSKangXi=130.9
8164 CJK UNIFIED IDEOGRAPH-#8164, IRGKangXi=0988.160, RSKangXi=130.9
8165 CJK UNIFIED IDEOGRAPH-#8165, IRGKangXi=0988.170, RSKangXi=130.9, Def{raw meat; rank, strong-smelling}
8166 CJK UNIFIED IDEOGRAPH-#8166, IRGKangXi=0988.200, RSKangXi=130.9, Def{brain}
8167 CJK UNIFIED IDEOGRAPH-#8167, IRGKangXi=0988.210, RSKangXi=130.9, Def{insertion point in acupuncture; acupoint}
8168 CJK UNIFIED IDEOGRAPH-#8168, IRGKangXi=0988.240, RSKangXi=130.9
8169 CJK UNIFIED IDEOGRAPH-#8169, IRGKangXi=0989.010, RSKangXi=130.9, Def{(Cant.) fatty meat on a cow's belly; abdomen; to boil meat}
816A CJK UNIFIED IDEOGRAPH-#816A, IRGKangXi=0989.030, RSKangXi=130.9
816B CJK UNIFIED IDEOGRAPH-#816B, IRGKangXi=0989.050, RSKangXi=130.9, Def{swell; swollen; swelling}
816C CJK UNIFIED IDEOGRAPH-#816C, IRGKangXi=0989.070, RSKangXi=130.9, Def{(Cant.) greasy, oily}
816D CJK UNIFIED IDEOGRAPH-#816D, IRGKangXi=0989.080, RSKangXi=130.9, Def{palate, roof of mouth}
816E CJK UNIFIED IDEOGRAPH-#816E, IRGKangXi=0989.100, RSKangXi=130.9, Def{lower part of face; jaw; gills of a fish}
816F CJK UNIFIED IDEOGRAPH-#816F, IRGKangXi=0989.120, RSKangXi=130.9, Def{strong}
8170 CJK UNIFIED IDEOGRAPH-#8170, IRGKangXi=0989.130, RSKangXi=130.9, Def{waist; kidney}
8171 CJK UNIFIED IDEOGRAPH-#8171, IRGKangXi=0989.160, RSKangXi=130.9, Def{tendons}
8172 CJK UNIFIED IDEOGRAPH-#8172, IRGKangXi=0989.170, RSKangXi=130.9
8173 CJK UNIFIED IDEOGRAPH-#8173, IRGKangXi=0989.200, RSKangXi=130.9, Def{foot; base, leg, foundation}
8174 CJK UNIFIED IDEOGRAPH-#8174, IRGKangXi=0989.210, RSKangXi=130.9, Def{fat; fertile, rich; plump, soft}
8175 CJK UNIFIED IDEOGRAPH-#8175, IRGKangXi=0989.250, RSKangXi=130.9
8176 CJK UNIFIED IDEOGRAPH-#8176, IRGKangXi=0989.260, RSKangXi=130.9, Def{meat}
8177 CJK UNIFIED IDEOGRAPH-#8177, IRGKangXi=0989.280, RSKangXi=130.9
8178 CJK UNIFIED IDEOGRAPH-#8178, IRGKangXi=0990.010, RSKangXi=130.9, Def{intestines; emotions; sausage}
8179 CJK UNIFIED IDEOGRAPH-#8179, IRGKangXi=0990.020, RSKangXi=130.9, Def{stomach, belly, abdomen; inside}
817A CJK UNIFIED IDEOGRAPH-#817A, IRGKangXi=0990.131, RSKangXi=130.9, Def{gland}
817B CJK UNIFIED IDEOGRAPH-#817B, IRGKangXi=0990.131, RSKangXi=130.9, Def{greasy, oily, dirty; smooth}
817C CJK UNIFIED IDEOGRAPH-#817C, IRGKangXi=0990.131, RSKangXi=130.9, Def{modest}
817D CJK UNIFIED IDEOGRAPH-#817D, IRGKangXi=0990.131, RSKangXi=130.9, Def{fat}
817E CJK UNIFIED IDEOGRAPH-#817E, IRGKangXi=0990.131, RSKangXi=130.9, Def{fly; gallop; run; prance; rise}
817F CJK UNIFIED IDEOGRAPH-#817F, IRGKangXi=0990.140, RSKangXi=130.10, Def{legs, thighs}
8180 CJK UNIFIED IDEOGRAPH-#8180, IRGKangXi=0990.150, RSKangXi=130.10, Def{upper arm; shoulder; wing}
8181 CJK UNIFIED IDEOGRAPH-#8181, IRGKangXi=0990.160, RSKangXi=130.10, Def{(Cant.) 小膁, loins, side of body}
8182 CJK UNIFIED IDEOGRAPH-#8182, IRGKangXi=0990.210, RSKangXi=130.10, Def{backbone, spinal column}
8183 CJK UNIFIED IDEOGRAPH-#8183, IRGKangXi=0990.220, RSKangXi=130.10, Def{fat}
8184 CJK UNIFIED IDEOGRAPH-#8184, IRGKangXi=0990.230, RSKangXi=130.10, Def{to become emaciated}
8185 CJK UNIFIED IDEOGRAPH-#8185, IRGKangXi=0990.250, RSKangXi=130.10
8186 CJK UNIFIED IDEOGRAPH-#8186, IRGKangXi=0990.300, RSKangXi=130.10, Def{the corp of a bird or fowl; fat}
8187 CJK UNIFIED IDEOGRAPH-#8187, IRGKangXi=0990.330, RSKangXi=130.10, Def{swell}
8188 CJK UNIFIED IDEOGRAPH-#8188, IRGKangXi=0991.030, RSKangXi=130.10, Def{diaphragm}
8189 CJK UNIFIED IDEOGRAPH-#8189, IRGKangXi=0991.040, RSKangXi=130.10, Def{(Cant.) the smell of oily food that's gone bad}
818A CJK UNIFIED IDEOGRAPH-#818A, IRGKangXi=0991.130, RSKangXi=130.10, Def{shoulders, upper arms}
818B CJK UNIFIED IDEOGRAPH-#818B, IRGKangXi=0991.220, RSKangXi=130.10, Def{fat}
818C CJK UNIFIED IDEOGRAPH-#818C, IRGKangXi=0991.250, RSKangXi=130.10, Def{to become emaciated}
818D CJK UNIFIED IDEOGRAPH-#818D, IRGKangXi=0991.270, RSKangXi=130.10, Def{(Cant.) 膍胵, gizzard and liver of domestic animals}
818E CJK UNIFIED IDEOGRAPH-#818E, IRGKangXi=0991.290, RSKangXi=130.10
818F CJK UNIFIED IDEOGRAPH-#818F, IRGKangXi=0992.010, RSKangXi=130.10, Def{grease, fat; paste, ointment}
8190 CJK UNIFIED IDEOGRAPH-#8190, IRGKangXi=0992.030, RSKangXi=130.10
8191 CJK UNIFIED IDEOGRAPH-#8191, IRGKangXi=0992.071, RSKangXi=130.10, Def{the kneecap}
8192 CJK UNIFIED IDEOGRAPH-#8192, IRGKangXi=0992.080, RSKangXi=130.11
8193 CJK UNIFIED IDEOGRAPH-#8193, IRGKangXi=0992.100, RSKangXi=130.11, Def{intestines; emotions; sausage}
8194 CJK UNIFIED IDEOGRAPH-#8194, IRGKangXi=0992.110, RSKangXi=130.11
8195 CJK UNIFIED IDEOGRAPH-#8195, IRGKangXi=0992.150, RSKangXi=130.11, Def{hollow}
8196 CJK UNIFIED IDEOGRAPH-#8196, IRGKangXi=0992.190, RSKangXi=130.11
8197 CJK UNIFIED IDEOGRAPH-#8197, IRGKangXi=0992.230, RSKangXi=130.11, Def{ugly and fat; too fat to move}
8198 CJK UNIFIED IDEOGRAPH-#8198, IRGKangXi=0992.240, RSKangXi=130.11, Def{fat; rump}
8199 CJK UNIFIED IDEOGRAPH-#8199, IRGKangXi=0992.250, RSKangXi=130.11, Def{callous skin on the feet}
819A CJK UNIFIED IDEOGRAPH-#819A, IRGKangXi=0992.280, RSKangXi=130.11, Def{skin; superficial, shallow}
819B CJK UNIFIED IDEOGRAPH-#819B, IRGKangXi=0992.300, RSKangXi=130.11, Def{chest; hollow space, cavity}
819C CJK UNIFIED IDEOGRAPH-#819C, IRGKangXi=0993.010, RSKangXi=130.11, Def{membrane; to kneel and worship}
819D CJK UNIFIED IDEOGRAPH-#819D, IRGKangXi=0993.040, RSKangXi=130.11, Def{knee}
819E CJK UNIFIED IDEOGRAPH-#819E, IRGKangXi=0993.060, RSKangXi=130.11
819F CJK UNIFIED IDEOGRAPH-#819F, IRGKangXi=0993.070, RSKangXi=130.11, Def{fat}
81A0 CJK UNIFIED IDEOGRAPH-#81A0, IRGKangXi=0993.080, RSKangXi=130.11, Def{glue, gum, resin, rubber}
81A1 CJK UNIFIED IDEOGRAPH-#81A1, IRGKangXi=0993.090, RSKangXi=130.11
81A2 CJK UNIFIED IDEOGRAPH-#81A2, IRGKangXi=0993.110, RSKangXi=130.11
81A3 CJK UNIFIED IDEOGRAPH-#81A3, IRGKangXi=0993.160, RSKangXi=130.11, Def{vagina}
81A4 CJK UNIFIED IDEOGRAPH-#81A4, IRGKangXi=0993.201, RSKangXi=130.11
81A5 CJK UNIFIED IDEOGRAPH-#81A5, IRGKangXi=0996.111, RSKangXi=130.12, Def{(Cant.) eggs of birds or reptiles; testicles}
81A6 CJK UNIFIED IDEOGRAPH-#81A6, IRGKangXi=0994.010, RSKangXi=130.12
81A7 CJK UNIFIED IDEOGRAPH-#81A7, IRGKangXi=0994.020, RSKangXi=130.12
81A8 CJK UNIFIED IDEOGRAPH-#81A8, IRGKangXi=0994.040, RSKangXi=130.12, Def{to swell; swollen, bloated, inflated}
81A9 CJK UNIFIED IDEOGRAPH-#81A9, IRGKangXi=0994.050, RSKangXi=130.12, Def{greasy, oily, dirty; smooth}
81AA CJK UNIFIED IDEOGRAPH-#81AA, IRGKangXi=0994.070, RSKangXi=130.12, Def{pork}
81AB CJK UNIFIED IDEOGRAPH-#81AB, IRGKangXi=0994.080, RSKangXi=130.12, Def{the fat covering the intestines; the omentum}
81AC CJK UNIFIED IDEOGRAPH-#81AC, IRGKangXi=0994.090, RSKangXi=130.12
81AD CJK UNIFIED IDEOGRAPH-#81AD, IRGKangXi=0994.100, RSKangXi=130.12
81AE CJK UNIFIED IDEOGRAPH-#81AE, IRGKangXi=0994.130, RSKangXi=130.12
81AF CJK UNIFIED IDEOGRAPH-#81AF, IRGKangXi=0994.190, RSKangXi=130.12
81B0 CJK UNIFIED IDEOGRAPH-#81B0, IRGKangXi=0994.250, RSKangXi=130.12, Def{to cook meat for a sacrifice or offering}
81B1 CJK UNIFIED IDEOGRAPH-#81B1, IRGKangXi=0994.300, RSKangXi=130.12, Def{(Cant.) the smell of oily food that's gone bad}
81B2 CJK UNIFIED IDEOGRAPH-#81B2, IRGKangXi=0994.330, RSKangXi=130.12, Def{(medicine) the three divisions of the viscera}
81B3 CJK UNIFIED IDEOGRAPH-#81B3, IRGKangXi=0995.010, RSKangXi=130.12, Def{meals, provisions, board}
81B4 CJK UNIFIED IDEOGRAPH-#81B4, IRGKangXi=0995.040, RSKangXi=130.12, Def{fine}
81B5 CJK UNIFIED IDEOGRAPH-#81B5, IRGKangXi=0996.111, RSKangXi=130.12, Def{pancreas}
81B6 CJK UNIFIED IDEOGRAPH-#81B6, IRGKangXi=0995.111, RSKangXi=74.12, Def{(Cant.) liver}
81B7 CJK UNIFIED IDEOGRAPH-#81B7, IRGKangXi=0995.130, RSKangXi=130.13, Def{soup}
81B8 CJK UNIFIED IDEOGRAPH-#81B8, IRGKangXi=0995.140, RSKangXi=130.13
81B9 CJK UNIFIED IDEOGRAPH-#81B9, IRGKangXi=0995.150, RSKangXi=130.13
81BA CJK UNIFIED IDEOGRAPH-#81BA, IRGKangXi=0995.170, RSKangXi=130.13, Def{breast, chest; undertake, bear}
81BB CJK UNIFIED IDEOGRAPH-#81BB, IRGKangXi=0995.190, RSKangXi=130.13, Def{a rank odor; a technical term from Chinese medicine for the center of the chest}
81BC CJK UNIFIED IDEOGRAPH-#81BC, IRGKangXi=0995.200, RSKangXi=130.13
81BD CJK UNIFIED IDEOGRAPH-#81BD, IRGKangXi=0995.230, RSKangXi=130.13, Def{gall bladder; bravery, courage}
81BE CJK UNIFIED IDEOGRAPH-#81BE, IRGKangXi=0996.030, RSKangXi=130.13, Def{minced meat or fish}
81BF CJK UNIFIED IDEOGRAPH-#81BF, IRGKangXi=0996.040, RSKangXi=130.13, Def{pus}
81C0 CJK UNIFIED IDEOGRAPH-#81C0, IRGKangXi=0996.050, RSKangXi=130.13, Def{buttocks}
81C1 CJK UNIFIED IDEOGRAPH-#81C1, IRGKangXi=0996.060, RSKangXi=130.13, Def{calf of the leg}
81C2 CJK UNIFIED IDEOGRAPH-#81C2, IRGKangXi=0996.090, RSKangXi=130.13, Def{arm}
81C3 CJK UNIFIED IDEOGRAPH-#81C3, IRGKangXi=0996.110, RSKangXi=130.13, Def{swell up; swelling; fat}
81C4 CJK UNIFIED IDEOGRAPH-#81C4, IRGKangXi=0996.120, RSKangXi=130.13, Def{palate}
81C5 CJK UNIFIED IDEOGRAPH-#81C5, IRGKangXi=0996.130, RSKangXi=130.13
81C6 CJK UNIFIED IDEOGRAPH-#81C6, IRGKangXi=0996.140, RSKangXi=130.13, Def{chest, breast, bosom; thought}
81C7 CJK UNIFIED IDEOGRAPH-#81C7, IRGKangXi=0996.150, RSKangXi=130.13, Def{fat, rich; a stew of fish}
81C8 CJK UNIFIED IDEOGRAPH-#81C8, IRGKangXi=0996.160, RSKangXi=130.13, Def{year end sacrifice; dried meat}
81C9 CJK UNIFIED IDEOGRAPH-#81C9, IRGKangXi=0996.170, RSKangXi=130.13, Def{face; cheek; reputation}
81CA CJK UNIFIED IDEOGRAPH-#81CA, IRGKangXi=0996.180, RSKangXi=130.13, Def{rank; rancid; frowzy, fetid; bashful}
81CB CJK UNIFIED IDEOGRAPH-#81CB, IRGKangXi=0996.230, RSKangXi=130.13
81CC CJK UNIFIED IDEOGRAPH-#81CC, IRGKangXi=0996.241, RSKangXi=130.13, Def{dropsical swelling; puffy bloated}
81CD CJK UNIFIED IDEOGRAPH-#81CD, IRGKangXi=0996.250, RSKangXi=130.14, Def{abdominal area of crab; navel}
81CE CJK UNIFIED IDEOGRAPH-#81CE, IRGKangXi=0996.300, RSKangXi=130.14
81CF CJK UNIFIED IDEOGRAPH-#81CF, IRGKangXi=0997.020, RSKangXi=130.14, Def{the kneecap}
81D0 CJK UNIFIED IDEOGRAPH-#81D0, IRGKangXi=0997.030, RSKangXi=130.14, Def{broth}
81D1 CJK UNIFIED IDEOGRAPH-#81D1, IRGKangXi=0997.100, RSKangXi=130.14, Def{soft}
81D2 CJK UNIFIED IDEOGRAPH-#81D2, IRGKangXi=0997.130, RSKangXi=130.14
81D3 CJK UNIFIED IDEOGRAPH-#81D3, IRGKangXi=0998.021, RSKangXi=130.14, Def{internal organs, viscera}
81D4 CJK UNIFIED IDEOGRAPH-#81D4, IRGKangXi=0997.230, RSKangXi=130.15
81D5 CJK UNIFIED IDEOGRAPH-#81D5, IRGKangXi=0997.240, RSKangXi=130.15, Def{fat; gross, sleek}
81D6 CJK UNIFIED IDEOGRAPH-#81D6, IRGKangXi=0997.250, RSKangXi=130.16
81D7 CJK UNIFIED IDEOGRAPH-#81D7, IRGKangXi=0997.270, RSKangXi=130.15
81D8 CJK UNIFIED IDEOGRAPH-#81D8, IRGKangXi=0997.300, RSKangXi=130.15, Def{year end sacrifice; dried meat}
81D9 CJK UNIFIED IDEOGRAPH-#81D9, IRGKangXi=0998.030, RSKangXi=130.16, Def{rouge, cosmetics}
81DA CJK UNIFIED IDEOGRAPH-#81DA, IRGKangXi=0998.120, RSKangXi=130.16, Def{arrange in order; display}
81DB CJK UNIFIED IDEOGRAPH-#81DB, IRGKangXi=0998.130, RSKangXi=130.16, Def{broth}
81DC CJK UNIFIED IDEOGRAPH-#81DC, IRGKangXi=0998.141, RSKangXi=130.16, Def{dirty; filthy}
81DD CJK UNIFIED IDEOGRAPH-#81DD, IRGKangXi=0998.150, RSKangXi=130.17, Def{be bare; nude}
81DE CJK UNIFIED IDEOGRAPH-#81DE, IRGKangXi=0998.270, RSKangXi=130.18
81DF CJK UNIFIED IDEOGRAPH-#81DF, IRGKangXi=0998.290, RSKangXi=130.18, Def{internal organs, viscera}
81E0 CJK UNIFIED IDEOGRAPH-#81E0, IRGKangXi=0998.310, RSKangXi=130.19, Def{small lump of meat; sliced meat}
81E1 CJK UNIFIED IDEOGRAPH-#81E1, IRGKangXi=0999.030, RSKangXi=130.19
81E2 CJK UNIFIED IDEOGRAPH-#81E2, IRGKangXi=0999.071, RSKangXi=130.19, Def{dirty; filthy}
81E3 CJK UNIFIED IDEOGRAPH-#81E3, IRGKangXi=0999.130, RSKangXi=131.0, Def{minister, statesman, official}
81E4 CJK UNIFIED IDEOGRAPH-#81E4, IRGKangXi=0999.160, RSKangXi=131.2, Def{hard; wise}
81E5 CJK UNIFIED IDEOGRAPH-#81E5, IRGKangXi=0999.170, RSKangXi=131.2, Def{lie down; crouch}
81E6 CJK UNIFIED IDEOGRAPH-#81E6, IRGKangXi=0999.220, RSKangXi=131.6
81E7 CJK UNIFIED IDEOGRAPH-#81E7, IRGKangXi=0999.230, RSKangXi=131.8, Def{good, right, generous; command}
81E8 CJK UNIFIED IDEOGRAPH-#81E8, IRGKangXi=0999.240, RSKangXi=131.11, Def{draw near, approach; descend}
81E9 CJK UNIFIED IDEOGRAPH-#81E9, IRGKangXi=1000.010, RSKangXi=131.11
81EA CJK UNIFIED IDEOGRAPH-#81EA, IRGKangXi=1000.070, RSKangXi=132.0, Def{self, private, personal; from}
81EB CJK UNIFIED IDEOGRAPH-#81EB, IRGKangXi=1000.110, RSKangXi=132.1
81EC CJK UNIFIED IDEOGRAPH-#81EC, IRGKangXi=1000.190, RSKangXi=132.4, Def{law, rule; door post}
81ED CJK UNIFIED IDEOGRAPH-#81ED, IRGKangXi=1000.200, RSKangXi=132.4, Def{smell, stink, emit foul odor}
81EE CJK UNIFIED IDEOGRAPH-#81EE, IRGKangXi=1000.230, RSKangXi=132.6
81EF CJK UNIFIED IDEOGRAPH-#81EF, IRGKangXi=1000.240, RSKangXi=132.6, Def{to praise; to bless high; eminent; (Cant.) a marsh, pool}
81F0 CJK UNIFIED IDEOGRAPH-#81F0, IRGKangXi=1000.250, RSKangXi=132.6
81F1 CJK UNIFIED IDEOGRAPH-#81F1, IRGKangXi=1000.280, RSKangXi=132.9
81F2 CJK UNIFIED IDEOGRAPH-#81F2, IRGKangXi=1000.320, RSKangXi=132.10, Def{jumpy; jittery; worried; to grasp}
81F3 CJK UNIFIED IDEOGRAPH-#81F3, IRGKangXi=1001.110, RSKangXi=133.0, Def{reach, arrive; extremely, very}
81F4 CJK UNIFIED IDEOGRAPH-#81F4, IRGKangXi=1001.211, RSKangXi=133.3, Def{send, deliver, present; cause}
81F5 CJK UNIFIED IDEOGRAPH-#81F5, IRGKangXi=1001.220, RSKangXi=133.6
81F6 CJK UNIFIED IDEOGRAPH-#81F6, IRGKangXi=1001.240, RSKangXi=133.6
81F7 CJK UNIFIED IDEOGRAPH-#81F7, IRGKangXi=1002.010, RSKangXi=133.6
81F8 CJK UNIFIED IDEOGRAPH-#81F8, IRGKangXi=1002.020, RSKangXi=133.6
81F9 CJK UNIFIED IDEOGRAPH-#81F9, IRGKangXi=1002.040, RSKangXi=133.7
81FA CJK UNIFIED IDEOGRAPH-#81FA, IRGKangXi=1002.050, RSKangXi=133.8, Def{tower, lookout; stage, platform}
81FB CJK UNIFIED IDEOGRAPH-#81FB, IRGKangXi=1002.110, RSKangXi=133.10, Def{reach, arrive; utmost, superior}
81FC CJK UNIFIED IDEOGRAPH-#81FC, IRGKangXi=1003.010, RSKangXi=134.0, Def{mortar; bone joint socket}
81FD CJK UNIFIED IDEOGRAPH-#81FD, IRGKangXi=1003.040, RSKangXi=134.2, Def{a pit, a hole}
81FE CJK UNIFIED IDEOGRAPH-#81FE, IRGKangXi=1003.050, RSKangXi=134.2, Def{moment, instant, short while}
81FF CJK UNIFIED IDEOGRAPH-#81FF, IRGKangXi=1003.060, RSKangXi=134.3, Def{to separate the grain from the husk}
8200 CJK UNIFIED IDEOGRAPH-#8200, IRGKangXi=1003.090, RSKangXi=134.4, Def{dip, ladle; ladle}
8201 CJK UNIFIED IDEOGRAPH-#8201, IRGKangXi=1003.130, RSKangXi=134.4, Def{carry on one's shoulder}
8202 CJK UNIFIED IDEOGRAPH-#8202, IRGKangXi=1003.200, RSKangXi=134.5, Def{grind in mortar}
8203 CJK UNIFIED IDEOGRAPH-#8203, IRGKangXi=1004.060, RSKangXi=134.6, Def{a shoe; the sole of a shoe; magpie}
8204 CJK UNIFIED IDEOGRAPH-#8204, IRGKangXi=1004.071, RSKangXi=134.6, Def{a shoe; the sole of a shoe; magpie}
8205 CJK UNIFIED IDEOGRAPH-#8205, IRGKangXi=1004.090, RSKangXi=134.7, Def{mother's brother, uncle}
8206 CJK UNIFIED IDEOGRAPH-#8206, IRGKangXi=1004.121, RSKangXi=12.12, Def{cart, palanquin, sedan chair}
8207 CJK UNIFIED IDEOGRAPH-#8207, IRGKangXi=1004.130, RSKangXi=134.8, Def{and; with; to; for; give, grant}
8208 CJK UNIFIED IDEOGRAPH-#8208, IRGKangXi=1005.050, RSKangXi=134.9, Def{thrive, prosper, flourish}
8209 CJK UNIFIED IDEOGRAPH-#8209, IRGKangXi=1005.091, RSKangXi=134.10, Def{raise, lift up; recommend}
820A CJK UNIFIED IDEOGRAPH-#820A, IRGKangXi=1006.010, RSKangXi=134.12, Def{old, ancient; former, past}
820B CJK UNIFIED IDEOGRAPH-#820B, IRGKangXi=1006.060, RSKangXi=134.13, Def{split; (Cant.) a mark, trace}
820C CJK UNIFIED IDEOGRAPH-#820C, IRGKangXi=1006.220, RSKangXi=135.0, Def{tongue; clapper of bell; KangXi radical 135}
820D CJK UNIFIED IDEOGRAPH-#820D, IRGKangXi=1006.230, RSKangXi=135.2, Def{house, dwelling; dwell, reside}
820E CJK UNIFIED IDEOGRAPH-#820E, IRGKangXi=1006.231, RSKangXi=135.2, Def{house, dwelling; dwell, reside}
820F CJK UNIFIED IDEOGRAPH-#820F, IRGKangXi=1006.231, RSKangXi=135.2
8210 CJK UNIFIED IDEOGRAPH-#8210, IRGKangXi=1007.030, RSKangXi=135.4, Def{lick with tongue}
8211 CJK UNIFIED IDEOGRAPH-#8211, IRGKangXi=1007.080, RSKangXi=135.5
8212 CJK UNIFIED IDEOGRAPH-#8212, IRGKangXi=1007.110, RSKangXi=135.6, Def{open up, unfold, stretch out; comfortable, easy}
8213 CJK UNIFIED IDEOGRAPH-#8213, IRGKangXi=1007.160, RSKangXi=135.8, Def{to lick}
8214 CJK UNIFIED IDEOGRAPH-#8214, IRGKangXi=1007.180, RSKangXi=135.8, Def{lick with tongue; taste}
8215 CJK UNIFIED IDEOGRAPH-#8215, IRGKangXi=1007.201, RSKangXi=135.8, Def{to stick out the tongue}
8216 CJK UNIFIED IDEOGRAPH-#8216, IRGKangXi=1007.221, RSKangXi=135.9, Def{store, shop}
8217 CJK UNIFIED IDEOGRAPH-#8217, IRGKangXi=1007.221, RSKangXi=135.9, Def{store, shop}
8218 CJK UNIFIED IDEOGRAPH-#8218, IRGKangXi=1007.250, RSKangXi=135.10, Def{a mansion; a building}
8219 CJK UNIFIED IDEOGRAPH-#8219, IRGKangXi=1008.030, RSKangXi=135.12
821A CJK UNIFIED IDEOGRAPH-#821A, IRGKangXi=1008.050, RSKangXi=135.13, Def{to put out the tongue}
821B CJK UNIFIED IDEOGRAPH-#821B, IRGKangXi=1008.090, RSKangXi=136.0, Def{oppose, deviate, be contrary to}
821C CJK UNIFIED IDEOGRAPH-#821C, IRGKangXi=1008.100, RSKangXi=136.6, Def{legendary ruler}
821D CJK UNIFIED IDEOGRAPH-#821D, IRGKangXi=1008.150, RSKangXi=136.7, Def{linch-pin}
821E CJK UNIFIED IDEOGRAPH-#821E, IRGKangXi=1008.160, RSKangXi=136.8, Def{dance, posture, prance; brandish}
821F CJK UNIFIED IDEOGRAPH-#821F, IRGKangXi=1008.240, RSKangXi=137.0, Def{boat, ship; KangXi radical 137}
8220 CJK UNIFIED IDEOGRAPH-#8220, IRGKangXi=1009.020, RSKangXi=137.2, Def{long narrow knife-shaped boat}
8221 CJK UNIFIED IDEOGRAPH-#8221, IRGKangXi=1009.080, RSKangXi=137.3, Def{boat, ship}
8222 CJK UNIFIED IDEOGRAPH-#8222, IRGKangXi=1009.121, RSKangXi=137.3, Def{sampan}
8223 CJK UNIFIED IDEOGRAPH-#8223, IRGKangXi=1009.121, RSKangXi=137.3, Def{to moor a boat to the bank}
8224 CJK UNIFIED IDEOGRAPH-#8224, IRGKangXi=1009.121, RSKangXi=137.3
8225 CJK UNIFIED IDEOGRAPH-#8225, IRGKangXi=1009.140, RSKangXi=137.4
8226 CJK UNIFIED IDEOGRAPH-#8226, IRGKangXi=1009.190, RSKangXi=137.4, Def{(Cant.) rudder}
8227 CJK UNIFIED IDEOGRAPH-#8227, IRGKangXi=1009.230, RSKangXi=137.4
8228 CJK UNIFIED IDEOGRAPH-#8228, IRGKangXi=1009.240, RSKangXi=137.4, Def{a sampan}
8229 CJK UNIFIED IDEOGRAPH-#8229, IRGKangXi=1009.260, RSKangXi=137.4, Def{boat, ship, vessel}
822A CJK UNIFIED IDEOGRAPH-#822A, IRGKangXi=1009.270, RSKangXi=137.4, Def{sail; navigate; ship, boat}
822B CJK UNIFIED IDEOGRAPH-#822B, IRGKangXi=1009.280, RSKangXi=137.4, Def{fancy boat, yacht}
822C CJK UNIFIED IDEOGRAPH-#822C, IRGKangXi=1009.300, RSKangXi=137.4, Def{sort, manner, kind, category}
822D CJK UNIFIED IDEOGRAPH-#822D, IRGKangXi=1010.020, RSKangXi=137.4
822E CJK UNIFIED IDEOGRAPH-#822E, IRGKangXi=1010.021, RSKangXi=137.4, Def{bow or prow of boat}
822F CJK UNIFIED IDEOGRAPH-#822F, IRGKangXi=1010.021, RSKangXi=137.4
8230 CJK UNIFIED IDEOGRAPH-#8230, IRGKangXi=1010.021, RSKangXi=137.4, Def{warship}
8231 CJK UNIFIED IDEOGRAPH-#8231, IRGKangXi=1010.021, RSKangXi=137.4, Def{hold of ship; cabin}
8232 CJK UNIFIED IDEOGRAPH-#8232, IRGKangXi=1010.030, RSKangXi=137.5, Def{small boat with windows; houseboat}
8233 CJK UNIFIED IDEOGRAPH-#8233, IRGKangXi=1010.070, RSKangXi=137.5, Def{stern of ship}
8234 CJK UNIFIED IDEOGRAPH-#8234, IRGKangXi=1010.080, RSKangXi=137.5
8235 CJK UNIFIED IDEOGRAPH-#8235, IRGKangXi=1010.100, RSKangXi=137.5, Def{rudder, helm}
8236 CJK UNIFIED IDEOGRAPH-#8236, IRGKangXi=1010.120, RSKangXi=137.5, Def{large, ocean-going vessel}
8237 CJK UNIFIED IDEOGRAPH-#8237, IRGKangXi=1010.130, RSKangXi=137.5, Def{the sides of a boat, bulwarks; a gunwale}
8238 CJK UNIFIED IDEOGRAPH-#8238, IRGKangXi=1010.140, RSKangXi=137.5, Def{large boat, barge}
8239 CJK UNIFIED IDEOGRAPH-#8239, IRGKangXi=1010.170, RSKangXi=137.5, Def{ship, boat, vessel}
823A CJK UNIFIED IDEOGRAPH-#823A, IRGKangXi=1010.210, RSKangXi=137.5, Def{place name in Taiwan, Taipei; a boat}
823B CJK UNIFIED IDEOGRAPH-#823B, IRGKangXi=1010.221, RSKangXi=137.5, Def{bow or prow of boat}
823C CJK UNIFIED IDEOGRAPH-#823C, IRGKangXi=1010.240, RSKangXi=137.6
823D CJK UNIFIED IDEOGRAPH-#823D, IRGKangXi=1010.310, RSKangXi=137.6
823E CJK UNIFIED IDEOGRAPH-#823E, IRGKangXi=1010.351, RSKangXi=137.6, Def{(Cant.) equipment on a ship}
823F CJK UNIFIED IDEOGRAPH-#823F, IRGKangXi=1010.351, RSKangXi=137.6
8240 CJK UNIFIED IDEOGRAPH-#8240, IRGKangXi=1010.360, RSKangXi=137.7, Def{a sampan, lighter, barge}
8241 CJK UNIFIED IDEOGRAPH-#8241, IRGKangXi=1010.370, RSKangXi=137.7
8242 CJK UNIFIED IDEOGRAPH-#8242, IRGKangXi=1011.010, RSKangXi=137.7
8243 CJK UNIFIED IDEOGRAPH-#8243, IRGKangXi=1011.020, RSKangXi=137.7
8244 CJK UNIFIED IDEOGRAPH-#8244, IRGKangXi=1011.030, RSKangXi=137.7, Def{stern of a vessel}
8245 CJK UNIFIED IDEOGRAPH-#8245, IRGKangXi=1011.060, RSKangXi=137.7, Def{a despatch boat}
8246 CJK UNIFIED IDEOGRAPH-#8246, IRGKangXi=1011.070, RSKangXi=137.7
8247 CJK UNIFIED IDEOGRAPH-#8247, IRGKangXi=1011.080, RSKangXi=137.7, Def{small boat, dugout, punt}
8248 CJK UNIFIED IDEOGRAPH-#8248, IRGKangXi=1011.121, RSKangXi=137.7
8249 CJK UNIFIED IDEOGRAPH-#8249, IRGKangXi=1011.121, RSKangXi=137.7
824A CJK UNIFIED IDEOGRAPH-#824A, IRGKangXi=1011.130, RSKangXi=137.8
824B CJK UNIFIED IDEOGRAPH-#824B, IRGKangXi=1011.150, RSKangXi=137.8, Def{small boat}
824C CJK UNIFIED IDEOGRAPH-#824C, IRGKangXi=1011.220, Def{to caulk}
824D CJK UNIFIED IDEOGRAPH-#824D, IRGKangXi=1011.271, RSKangXi=137.8
824E CJK UNIFIED IDEOGRAPH-#824E, IRGKangXi=1011.320, RSKangXi=137.9, Def{fast boat}
824F CJK UNIFIED IDEOGRAPH-#824F, IRGKangXi=1011.370, RSKangXi=137.9
8250 CJK UNIFIED IDEOGRAPH-#8250, IRGKangXi=1011.390, RSKangXi=137.9
8251 CJK UNIFIED IDEOGRAPH-#8251, IRGKangXi=1011.430, RSKangXi=137.9, Def{small boat}
8252 CJK UNIFIED IDEOGRAPH-#8252, IRGKangXi=1011.440, RSKangXi=137.9
8253 CJK UNIFIED IDEOGRAPH-#8253, IRGKangXi=1011.450, RSKangXi=137.9
8254 CJK UNIFIED IDEOGRAPH-#8254, IRGKangXi=1011.511, RSKangXi=137.9, Def{(Cant.) boat}
8255 CJK UNIFIED IDEOGRAPH-#8255, IRGKangXi=1011.540, RSKangXi=137.10, Def{two boats fastened side by side}
8256 CJK UNIFIED IDEOGRAPH-#8256, IRGKangXi=1012.080, RSKangXi=137.10, Def{raft; boat; skiff}
8257 CJK UNIFIED IDEOGRAPH-#8257, IRGKangXi=1012.090, RSKangXi=137.10, Def{bow of junk}
8258 CJK UNIFIED IDEOGRAPH-#8258, IRGKangXi=1012.110, RSKangXi=137.10, Def{counter for ships, vessels}
8259 CJK UNIFIED IDEOGRAPH-#8259, IRGKangXi=1012.131, RSKangXi=137.10, Def{hold of ship; cabin}
825A CJK UNIFIED IDEOGRAPH-#825A, IRGKangXi=1012.200, RSKangXi=137.11, Def{ship}
825B CJK UNIFIED IDEOGRAPH-#825B, IRGKangXi=1012.220, RSKangXi=137.11
825C CJK UNIFIED IDEOGRAPH-#825C, IRGKangXi=1012.260, RSKangXi=137.11, Def{a long narrow vessel with two masts; (Cant.) a rudder}
825D CJK UNIFIED IDEOGRAPH-#825D, IRGKangXi=1012.281, RSKangXi=137.11
825E CJK UNIFIED IDEOGRAPH-#825E, IRGKangXi=1012.350, RSKangXi=137.12
825F CJK UNIFIED IDEOGRAPH-#825F, IRGKangXi=1012.410, RSKangXi=137.12, Def{ancient warship}
8260 CJK UNIFIED IDEOGRAPH-#8260, IRGKangXi=1012.441, RSKangXi=137.12
8261 CJK UNIFIED IDEOGRAPH-#8261, IRGKangXi=1012.450, RSKangXi=137.13
8262 CJK UNIFIED IDEOGRAPH-#8262, IRGKangXi=1012.460, RSKangXi=137.13, Def{a mast; a yard-arm or boom}
8263 CJK UNIFIED IDEOGRAPH-#8263, IRGKangXi=1012.510, RSKangXi=137.13, Def{stern oar, scull [?]}
8264 CJK UNIFIED IDEOGRAPH-#8264, IRGKangXi=1012.520, RSKangXi=137.13, Def{to moor a boat to the bank}
8265 CJK UNIFIED IDEOGRAPH-#8265, IRGKangXi=1012.540, Def{an oar or paddle. to row}
8266 CJK UNIFIED IDEOGRAPH-#8266, IRGKangXi=1013.010, RSKangXi=137.14, Def{warship}
8267 CJK UNIFIED IDEOGRAPH-#8267, IRGKangXi=1013.030, RSKangXi=137.14
8268 CJK UNIFIED IDEOGRAPH-#8268, IRGKangXi=1013.040, RSKangXi=137.14, Def{long and narrow war-boat}
8269 CJK UNIFIED IDEOGRAPH-#8269, IRGKangXi=1013.050, RSKangXi=137.14, Def{tholepin}
826A CJK UNIFIED IDEOGRAPH-#826A, IRGKangXi=1013.090, RSKangXi=137.15, Def{oar, scull; row}
826B CJK UNIFIED IDEOGRAPH-#826B, IRGKangXi=1013.110, RSKangXi=137.16, Def{bow or prow of boat}
826C CJK UNIFIED IDEOGRAPH-#826C, IRGKangXi=1013.160, RSKangXi=137.17
826D CJK UNIFIED IDEOGRAPH-#826D, IRGKangXi=1013.180, RSKangXi=137.18, Def{ship}
826E CJK UNIFIED IDEOGRAPH-#826E, IRGKangXi=1013.220, RSKangXi=138.0, Def{seventh of eight diagrams}
826F CJK UNIFIED IDEOGRAPH-#826F, IRGKangXi=1013.230, RSKangXi=138.1, Def{good, virtuous, respectable}
8270 CJK UNIFIED IDEOGRAPH-#8270, IRGKangXi=1013.261, RSKangXi=29.6, Def{difficult, hard; distressing}
8271 CJK UNIFIED IDEOGRAPH-#8271, IRGKangXi=1013.290, RSKangXi=138.11, Def{difficult, hard; distressing}
8272 CJK UNIFIED IDEOGRAPH-#8272, IRGKangXi=1014.020, RSKangXi=139.0, Def{color, tint, hue, shade; form, body; beauty, desire for beauty}
8273 CJK UNIFIED IDEOGRAPH-#8273, IRGKangXi=1014.041, RSKangXi=139.4, Def{beautiful, sexy, voluptuous}
8274 CJK UNIFIED IDEOGRAPH-#8274, IRGKangXi=1014.060, RSKangXi=139.5, Def{the countenance changing}
8275 CJK UNIFIED IDEOGRAPH-#8275, IRGKangXi=1014.081, RSKangXi=139.8
8276 CJK UNIFIED IDEOGRAPH-#8276, IRGKangXi=1014.200, RSKangXi=139.13, Def{beautiful, sexy, voluptuous}
8277 CJK UNIFIED IDEOGRAPH-#8277, IRGKangXi=1014.240, RSKangXi=139.18, Def{beautiful, sexy, voluptuous}
8278 CJK UNIFIED IDEOGRAPH-#8278, IRGKangXi=1017.010, RSKangXi=140.0, Def{grass; KangXi radical 140}
8279 CJK UNIFIED IDEOGRAPH-#8279, IRGKangXi=1017.011, RSKangXi=140.0, Def{grass; radical number 140}
827A CJK UNIFIED IDEOGRAPH-#827A, IRGKangXi=1017.031, RSKangXi=140.1, Def{art; talent, ability; craft}
827B CJK UNIFIED IDEOGRAPH-#827B, IRGKangXi=1017.040, RSKangXi=140.2
827C CJK UNIFIED IDEOGRAPH-#827C, IRGKangXi=1017.050, RSKangXi=140.2
827D CJK UNIFIED IDEOGRAPH-#827D, IRGKangXi=1017.070, RSKangXi=140.2
827E CJK UNIFIED IDEOGRAPH-#827E, IRGKangXi=1017.090, RSKangXi=140.2, Def{artemisia, mugwort; translit.}
827F CJK UNIFIED IDEOGRAPH-#827F, IRGKangXi=1017.100, RSKangXi=140.2
8280 CJK UNIFIED IDEOGRAPH-#8280, IRGKangXi=1017.130, RSKangXi=140.2, Def{clover; pea}
8281 CJK UNIFIED IDEOGRAPH-#8281, IRGKangXi=1017.150, RSKangXi=140.2
8282 CJK UNIFIED IDEOGRAPH-#8282, IRGKangXi=1017.191, RSKangXi=140.2, Def{knot, node, joint; section}
8283 CJK UNIFIED IDEOGRAPH-#8283, IRGKangXi=1017.220, RSKangXi=140.3, Def{luxuriant growth}
8284 CJK UNIFIED IDEOGRAPH-#8284, IRGKangXi=1017.230, RSKangXi=140.3
8285 CJK UNIFIED IDEOGRAPH-#8285, IRGKangXi=1018.010, RSKangXi=140.3
8286 CJK UNIFIED IDEOGRAPH-#8286, IRGKangXi=1019.061, RSKangXi=140.3
8287 CJK UNIFIED IDEOGRAPH-#8287, IRGKangXi=1018.040, RSKangXi=140.3
8288 CJK UNIFIED IDEOGRAPH-#8288, IRGKangXi=1019.061, RSKangXi=123.1, Def{bleat of sheep; surname}
8289 CJK UNIFIED IDEOGRAPH-#8289, IRGKangXi=1018.060, RSKangXi=140.3
828A CJK UNIFIED IDEOGRAPH-#828A, IRGKangXi=1018.070, RSKangXi=140.3, Def{exuberant and vigorous foliage}
828B CJK UNIFIED IDEOGRAPH-#828B, IRGKangXi=1018.080, RSKangXi=140.3, Def{taro}
828C CJK UNIFIED IDEOGRAPH-#828C, IRGKangXi=1018.090, RSKangXi=140.3
828D CJK UNIFIED IDEOGRAPH-#828D, IRGKangXi=1018.120, RSKangXi=140.3, Def{peony; water chestnuts}
828E CJK UNIFIED IDEOGRAPH-#828E, IRGKangXi=1018.160, RSKangXi=140.3, Def{a kind of herb}
828F CJK UNIFIED IDEOGRAPH-#828F, IRGKangXi=1018.170, RSKangXi=140.3
8290 CJK UNIFIED IDEOGRAPH-#8290, IRGKangXi=1018.180, RSKangXi=140.3
8291 CJK UNIFIED IDEOGRAPH-#8291, IRGKangXi=1018.190, RSKangXi=140.3, Def{white millet}
8292 CJK UNIFIED IDEOGRAPH-#8292, IRGKangXi=1018.200, RSKangXi=140.3, Def{Miscanthus sinensis}
8293 CJK UNIFIED IDEOGRAPH-#8293, IRGKangXi=1018.220, RSKangXi=140.3
8294 CJK UNIFIED IDEOGRAPH-#8294, IRGKangXi=1019.010, RSKangXi=140.3, Def{a general term for plants}
8295 CJK UNIFIED IDEOGRAPH-#8295, IRGKangXi=1019.020, RSKangXi=140.3
8296 CJK UNIFIED IDEOGRAPH-#8296, IRGKangXi=1019.060, RSKangXi=140.3
8297 CJK UNIFIED IDEOGRAPH-#8297, IRGKangXi=1019.061, RSKangXi=140.3, Def{fragrant smell of grain; aromatic}
8298 CJK UNIFIED IDEOGRAPH-#8298, IRGKangXi=1019.080, RSKangXi=140.4
8299 CJK UNIFIED IDEOGRAPH-#8299, IRGKangXi=1019.090, RSKangXi=140.4, Def{hibiscus}
829A CJK UNIFIED IDEOGRAPH-#829A, IRGKangXi=1019.100, RSKangXi=140.4, Def{green sprout; foolish}
829B CJK UNIFIED IDEOGRAPH-#829B, IRGKangXi=1019.110, RSKangXi=140.4
829C CJK UNIFIED IDEOGRAPH-#829C, IRGKangXi=1019.130, RSKangXi=140.4, Def{luxurious growth of weeds}
829D CJK UNIFIED IDEOGRAPH-#829D, IRGKangXi=1019.150, RSKangXi=140.4, Def{sesame; a purplish or brown mushroom thought to have miraculous powers; 'a divine and relicitous plant' (Karlgren)}
829E CJK UNIFIED IDEOGRAPH-#829E, IRGKangXi=1019.160, RSKangXi=140.4
829F CJK UNIFIED IDEOGRAPH-#829F, IRGKangXi=1019.170, RSKangXi=140.4, Def{mow, cut; weed out; scythe}
82A0 CJK UNIFIED IDEOGRAPH-#82A0, IRGKangXi=1019.180, RSKangXi=140.4
82A1 CJK UNIFIED IDEOGRAPH-#82A1, IRGKangXi=1019.210, RSKangXi=140.4, Def{plant allied to the waterlily}
82A2 CJK UNIFIED IDEOGRAPH-#82A2, IRGKangXi=1019.220, RSKangXi=140.4
82A3 CJK UNIFIED IDEOGRAPH-#82A3, IRGKangXi=1019.260, RSKangXi=140.4, Def{medicinal plant}
82A4 CJK UNIFIED IDEOGRAPH-#82A4, IRGKangXi=1019.300, RSKangXi=140.4
82A5 CJK UNIFIED IDEOGRAPH-#82A5, IRGKangXi=1019.310, RSKangXi=140.4, Def{mustard plant; mustard; tiny}
82A6 CJK UNIFIED IDEOGRAPH-#82A6, IRGKangXi=1020.010, RSKangXi=140.4, Def{rushes, reeds}
82A7 CJK UNIFIED IDEOGRAPH-#82A7, IRGKangXi=1020.020, RSKangXi=140.4, Def{chestnut oak}
82A8 CJK UNIFIED IDEOGRAPH-#82A8, IRGKangXi=1020.040, RSKangXi=140.4, Def{name of a plant, the roots are used for various purposes}
82A9 CJK UNIFIED IDEOGRAPH-#82A9, IRGKangXi=1020.090, RSKangXi=140.4, Def{salt marsh plant}
82AA CJK UNIFIED IDEOGRAPH-#82AA, IRGKangXi=1020.100, RSKangXi=140.4, Def{celery}
82AB CJK UNIFIED IDEOGRAPH-#82AB, IRGKangXi=1020.120, RSKangXi=140.4, Def{daphne genkwa, poisonous plant}
82AC CJK UNIFIED IDEOGRAPH-#82AC, IRGKangXi=1020.130, RSKangXi=140.4, Def{fragrance, aroma; perfume}
82AD CJK UNIFIED IDEOGRAPH-#82AD, IRGKangXi=1020.150, RSKangXi=140.4, Def{plantain or banana palm; fragrant}
82AE CJK UNIFIED IDEOGRAPH-#82AE, IRGKangXi=1020.160, RSKangXi=140.4, Def{tiny, small; water's edge}
82AF CJK UNIFIED IDEOGRAPH-#82AF, IRGKangXi=1020.170, RSKangXi=140.4, Def{pith from rush (juncus effusus)}
82B0 CJK UNIFIED IDEOGRAPH-#82B0, IRGKangXi=1020.180, RSKangXi=140.4, Def{water caltrop}
82B1 CJK UNIFIED IDEOGRAPH-#82B1, IRGKangXi=1020.210, RSKangXi=140.4, Def{flower; blossoms}
82B2 CJK UNIFIED IDEOGRAPH-#82B2, IRGKangXi=1021.010, RSKangXi=140.4
82B3 CJK UNIFIED IDEOGRAPH-#82B3, IRGKangXi=1021.020, RSKangXi=140.4, Def{fragrant; virtuous; beautiful}
82B4 CJK UNIFIED IDEOGRAPH-#82B4, IRGKangXi=1021.030, RSKangXi=140.4
82B5 CJK UNIFIED IDEOGRAPH-#82B5, IRGKangXi=1021.040, RSKangXi=140.4
82B6 CJK UNIFIED IDEOGRAPH-#82B6, IRGKangXi=1021.050, RSKangXi=140.4
82B7 CJK UNIFIED IDEOGRAPH-#82B7, IRGKangXi=1021.060, RSKangXi=140.4, Def{angelica, type of iris}
82B8 CJK UNIFIED IDEOGRAPH-#82B8, IRGKangXi=1021.070, RSKangXi=140.4, Def{rue, herb used to keep insects away; to cut grass or weeds; art, talent, ability, craft, technique, performance, acting, trick, stunt}
82B9 CJK UNIFIED IDEOGRAPH-#82B9, IRGKangXi=1021.080, RSKangXi=140.4, Def{celery}
82BA CJK UNIFIED IDEOGRAPH-#82BA, IRGKangXi=1021.090, RSKangXi=140.4
82BB CJK UNIFIED IDEOGRAPH-#82BB, IRGKangXi=1021.100, RSKangXi=140.4, Def{mow, cut grass; hay, fodder}
82BC CJK UNIFIED IDEOGRAPH-#82BC, IRGKangXi=1021.110, RSKangXi=140.4, Def{to choose; to select; greens}
82BD CJK UNIFIED IDEOGRAPH-#82BD, IRGKangXi=1021.130, RSKangXi=140.4, Def{bud, sprout, shoot}
82BE CJK UNIFIED IDEOGRAPH-#82BE, IRGKangXi=1021.140, RSKangXi=140.4, Def{flower; small; little; lush}
82BF CJK UNIFIED IDEOGRAPH-#82BF, IRGKangXi=1021.150, RSKangXi=140.5, Def{grass which has been cut and regrown; wild grass}
82C0 CJK UNIFIED IDEOGRAPH-#82C0, IRGKangXi=1021.170, RSKangXi=140.4
82C1 CJK UNIFIED IDEOGRAPH-#82C1, IRGKangXi=1022.070, RSKangXi=140.4, Def{medicinal herb}
82C2 CJK UNIFIED IDEOGRAPH-#82C2, IRGKangXi=1022.080, RSKangXi=140.4
82C3 CJK UNIFIED IDEOGRAPH-#82C3, IRGKangXi=1022.140, RSKangXi=140.4
82C4 CJK UNIFIED IDEOGRAPH-#82C4, IRGKangXi=1022.181, RSKangXi=140.4, Def{benzyl}
82C5 CJK UNIFIED IDEOGRAPH-#82C5, IRGKangXi=1022.181, RSKangXi=140.4, Def{cut off, reap, mow; sickle}
82C6 CJK UNIFIED IDEOGRAPH-#82C6, IRGKangXi=1022.181, RSKangXi=140.4
82C7 CJK UNIFIED IDEOGRAPH-#82C7, IRGKangXi=1022.181, RSKangXi=140.4, Def{reed}
82C8 CJK UNIFIED IDEOGRAPH-#82C8, IRGKangXi=1022.181, RSKangXi=140.4, Def{a kind of plant}
82C9 CJK UNIFIED IDEOGRAPH-#82C9, IRGKangXi=1022.181, RSKangXi=140.4
82CA CJK UNIFIED IDEOGRAPH-#82CA, IRGKangXi=1022.181, RSKangXi=140.4, Def{an organic compound}
82CB CJK UNIFIED IDEOGRAPH-#82CB, IRGKangXi=1022.181, RSKangXi=140.4, Def{amaranth}
82CC CJK UNIFIED IDEOGRAPH-#82CC, IRGKangXi=1022.181, RSKangXi=140.4, Def{averrhora carambola; surname}
82CD CJK UNIFIED IDEOGRAPH-#82CD, IRGKangXi=1022.181, RSKangXi=140.4, Def{blue; green}
82CE CJK UNIFIED IDEOGRAPH-#82CE, IRGKangXi=1022.181, RSKangXi=140.4, Def{china grass, ramie}
82CF CJK UNIFIED IDEOGRAPH-#82CF, IRGKangXi=1022.181, RSKangXi=140.4, Def{revive, resurrect; a species of thyme; transliteration of 'Soviet'}
82D0 CJK UNIFIED IDEOGRAPH-#82D0, IRGKangXi=1022.190, RSKangXi=140.5, Def{sequence, number; grade, degree}
82D1 CJK UNIFIED IDEOGRAPH-#82D1, IRGKangXi=1022.210, RSKangXi=140.5, Def{pasture, park, garden; mansion}
82D2 CJK UNIFIED IDEOGRAPH-#82D2, IRGKangXi=1022.230, RSKangXi=140.5, Def{lush; successively, in order}
82D3 CJK UNIFIED IDEOGRAPH-#82D3, IRGKangXi=1022.240, RSKangXi=140.5, Def{fungus, tuber; licorice}
82D4 CJK UNIFIED IDEOGRAPH-#82D4, IRGKangXi=1022.250, RSKangXi=140.5, Def{moss, lichen}
82D5 CJK UNIFIED IDEOGRAPH-#82D5, IRGKangXi=1022.260, RSKangXi=140.5, Def{rush plant}
82D6 CJK UNIFIED IDEOGRAPH-#82D6, IRGKangXi=1022.270, RSKangXi=140.5
82D7 CJK UNIFIED IDEOGRAPH-#82D7, IRGKangXi=1022.280, RSKangXi=140.5, Def{sprouts; Miao nationality}
82D8 CJK UNIFIED IDEOGRAPH-#82D8, IRGKangXi=1022.300, RSKangXi=140.5, Def{Indian mallow}
82D9 CJK UNIFIED IDEOGRAPH-#82D9, IRGKangXi=1022.310, RSKangXi=140.5, Def{a pig-sty; a kind of medicinal plant}
82DA CJK UNIFIED IDEOGRAPH-#82DA, IRGKangXi=1022.320, RSKangXi=140.5
82DB CJK UNIFIED IDEOGRAPH-#82DB, IRGKangXi=1022.330, RSKangXi=140.5, Def{small, petty; harsh, rigorous}
82DC CJK UNIFIED IDEOGRAPH-#82DC, IRGKangXi=1023.020, RSKangXi=140.5, Def{clover}
82DD CJK UNIFIED IDEOGRAPH-#82DD, IRGKangXi=1023.030, RSKangXi=140.5
82DE CJK UNIFIED IDEOGRAPH-#82DE, IRGKangXi=1023.040, RSKangXi=140.5, Def{a variety of rush; firm, enduring; to burst forth}
82DF CJK UNIFIED IDEOGRAPH-#82DF, IRGKangXi=1023.050, RSKangXi=140.5, Def{careless, frivolous; illicit; grammatical particle: if, but, if only; surname; grass name; distinguish DKW 30853 (ji4)}
82E0 CJK UNIFIED IDEOGRAPH-#82E0, IRGKangXi=1023.070, RSKangXi=140.5
82E1 CJK UNIFIED IDEOGRAPH-#82E1, IRGKangXi=1023.080, RSKangXi=140.5, Def{barley}
82E2 CJK UNIFIED IDEOGRAPH-#82E2, IRGKangXi=1023.090, RSKangXi=140.5, Def{barley; coix agretis}
82E3 CJK UNIFIED IDEOGRAPH-#82E3, IRGKangXi=1023.100, RSKangXi=140.5, Def{kind of lettuce}
82E4 CJK UNIFIED IDEOGRAPH-#82E4, IRGKangXi=1023.110, RSKangXi=140.5, Def{kohl rabi}
82E5 CJK UNIFIED IDEOGRAPH-#82E5, IRGKangXi=1023.120, RSKangXi=140.5, Def{if, supposing, assuming; similar}
82E6 CJK UNIFIED IDEOGRAPH-#82E6, IRGKangXi=1023.160, RSKangXi=140.5, Def{bitter; hardship, suffering}
82E7 CJK UNIFIED IDEOGRAPH-#82E7, IRGKangXi=1024.010, RSKangXi=140.5, Def{China grass, ramie (Boehmeria nivea)}
82E8 CJK UNIFIED IDEOGRAPH-#82E8, IRGKangXi=1024.020, RSKangXi=140.5
82E9 CJK UNIFIED IDEOGRAPH-#82E9, IRGKangXi=1024.030, RSKangXi=140.5
82EA CJK UNIFIED IDEOGRAPH-#82EA, IRGKangXi=1024.040, RSKangXi=140.5, Def{bright; shining, splendid}
82EB CJK UNIFIED IDEOGRAPH-#82EB, IRGKangXi=1024.050, RSKangXi=140.5, Def{rush or straw matting}
82EC CJK UNIFIED IDEOGRAPH-#82EC, IRGKangXi=1024.060, RSKangXi=140.5
82ED CJK UNIFIED IDEOGRAPH-#82ED, IRGKangXi=1024.070, RSKangXi=140.5
82EE CJK UNIFIED IDEOGRAPH-#82EE, IRGKangXi=1024.080, RSKangXi=140.5
82EF CJK UNIFIED IDEOGRAPH-#82EF, IRGKangXi=1024.090, RSKangXi=140.5, Def{benzene; luxuriant}
82F0 CJK UNIFIED IDEOGRAPH-#82F0, IRGKangXi=1024.100, RSKangXi=140.5
82F1 CJK UNIFIED IDEOGRAPH-#82F1, IRGKangXi=1024.110, RSKangXi=140.5, Def{petal, flower, leaf; brave, a hero; England, English}
82F2 CJK UNIFIED IDEOGRAPH-#82F2, IRGKangXi=1024.120, RSKangXi=140.5
82F3 CJK UNIFIED IDEOGRAPH-#82F3, IRGKangXi=1024.140, RSKangXi=140.5, Def{Petasites japonicus}
82F4 CJK UNIFIED IDEOGRAPH-#82F4, IRGKangXi=1024.160, RSKangXi=140.5, Def{sackcloth; female hemp plant}
82F5 CJK UNIFIED IDEOGRAPH-#82F5, IRGKangXi=1025.040, RSKangXi=140.5
82F6 CJK UNIFIED IDEOGRAPH-#82F6, IRGKangXi=1025.050, RSKangXi=140.5, Def{weary; tired}
82F7 CJK UNIFIED IDEOGRAPH-#82F7, IRGKangXi=1025.070, RSKangXi=140.5, Def{licorice}
82F8 CJK UNIFIED IDEOGRAPH-#82F8, IRGKangXi=1025.090, RSKangXi=140.5
82F9 CJK UNIFIED IDEOGRAPH-#82F9, IRGKangXi=1025.100, RSKangXi=140.5, Def{artemisia; duckweed; apple}
82FA CJK UNIFIED IDEOGRAPH-#82FA, IRGKangXi=1025.110, RSKangXi=140.5, Def{berries}
82FB CJK UNIFIED IDEOGRAPH-#82FB, IRGKangXi=1025.120, RSKangXi=140.5, Def{kind of herb; type of grass}
82FC CJK UNIFIED IDEOGRAPH-#82FC, IRGKangXi=1025.130, RSKangXi=140.5
82FD CJK UNIFIED IDEOGRAPH-#82FD, IRGKangXi=1025.140, RSKangXi=140.5, Def{bulrush, Zizania latifolia}
82FE CJK UNIFIED IDEOGRAPH-#82FE, IRGKangXi=1025.150, RSKangXi=140.5, Def{smell, fragrance, aroma}
82FF CJK UNIFIED IDEOGRAPH-#82FF, IRGKangXi=1025.170, RSKangXi=140.5
8300 CJK UNIFIED IDEOGRAPH-#8300, IRGKangXi=1025.180, RSKangXi=140.5, Def{overgrown with grass, weedy}
8301 CJK UNIFIED IDEOGRAPH-#8301, IRGKangXi=1025.190, RSKangXi=140.5, Def{to sprout, flourish; sprouts appearing above-ground; vigorous}
8302 CJK UNIFIED IDEOGRAPH-#8302, IRGKangXi=1025.200, RSKangXi=140.5, Def{thick, lush, dense; talented}
8303 CJK UNIFIED IDEOGRAPH-#8303, IRGKangXi=1026.010, RSKangXi=140.5, Def{surname; bee-like insect}
8304 CJK UNIFIED IDEOGRAPH-#8304, IRGKangXi=1026.020, RSKangXi=140.5, Def{eggplant}
8305 CJK UNIFIED IDEOGRAPH-#8305, IRGKangXi=1026.040, RSKangXi=140.5, Def{reeds, rushes, grass; surname}
8306 CJK UNIFIED IDEOGRAPH-#8306, IRGKangXi=1026.060, RSKangXi=140.5, Def{species of grass, water mallows}
8307 CJK UNIFIED IDEOGRAPH-#8307, IRGKangXi=1026.070, RSKangXi=140.5, Def{grass, thatch}
8308 CJK UNIFIED IDEOGRAPH-#8308, IRGKangXi=1026.080, RSKangXi=140.5, Def{a plant yielding a red dye}
8309 CJK UNIFIED IDEOGRAPH-#8309, IRGKangXi=1026.090, RSKangXi=140.5, Def{white jasmine}
830A CJK UNIFIED IDEOGRAPH-#830A, IRGKangXi=1027.010, RSKangXi=140.5
830B CJK UNIFIED IDEOGRAPH-#830B, IRGKangXi=1027.040, RSKangXi=140.5
830C CJK UNIFIED IDEOGRAPH-#830C, IRGKangXi=1027.050, RSKangXi=140.5, Def{name of a district in Shandong}
830D CJK UNIFIED IDEOGRAPH-#830D, IRGKangXi=1027.120, RSKangXi=140.5, Def{to be circumspect, cautious in ones behaviour (distinguish DKW 30790 gou3)}
830E CJK UNIFIED IDEOGRAPH-#830E, IRGKangXi=1027.201, RSKangXi=140.5, Def{stem, stalk}
830F CJK UNIFIED IDEOGRAPH-#830F, IRGKangXi=1027.201, RSKangXi=140.5, Def{tall grass; water-weeds}
8310 CJK UNIFIED IDEOGRAPH-#8310, IRGKangXi=1027.201, RSKangXi=140.5
8311 CJK UNIFIED IDEOGRAPH-#8311, IRGKangXi=1027.201, RSKangXi=140.6, Def{the convovulvus; parasitic plants such as mistletoe; Ribes ambiguum}
8312 CJK UNIFIED IDEOGRAPH-#8312, IRGKangXi=1031.381, RSKangXi=140.6
8313 CJK UNIFIED IDEOGRAPH-#8313, IRGKangXi=1027.201
8314 CJK UNIFIED IDEOGRAPH-#8314, IRGKangXi=1027.201, RSKangXi=140.5, Def{grave, tomb, cemetery}
8315 CJK UNIFIED IDEOGRAPH-#8315, IRGKangXi=1027.201, RSKangXi=140.5, Def{alone; without friends or relativ}
8316 CJK UNIFIED IDEOGRAPH-#8316, IRGKangXi=1027.210, RSKangXi=140.6, Def{allium victorialis}
8317 CJK UNIFIED IDEOGRAPH-#8317, IRGKangXi=1027.220, RSKangXi=140.6, Def{tea; tea plant}
8318 CJK UNIFIED IDEOGRAPH-#8318, IRGKangXi=1027.230, RSKangXi=140.6, Def{a scallion, small onion}
8319 CJK UNIFIED IDEOGRAPH-#8319, IRGKangXi=1027.250, RSKangXi=140.6
831A CJK UNIFIED IDEOGRAPH-#831A, IRGKangXi=1027.260, RSKangXi=140.6, Def{an organic compound}
831B CJK UNIFIED IDEOGRAPH-#831B, IRGKangXi=1027.270, RSKangXi=140.6, Def{ranunculus}
831C CJK UNIFIED IDEOGRAPH-#831C, IRGKangXi=1027.280, RSKangXi=140.6, Def{madder, rubia cordifolia; reeds}
831D CJK UNIFIED IDEOGRAPH-#831D, IRGKangXi=1027.330, RSKangXi=140.7
831E CJK UNIFIED IDEOGRAPH-#831E, IRGKangXi=1027.340, RSKangXi=140.6, Def{fragrant plant; angelica}
831F CJK UNIFIED IDEOGRAPH-#831F, IRGKangXi=1027.370, RSKangXi=140.6
8320 CJK UNIFIED IDEOGRAPH-#8320, IRGKangXi=1027.390, RSKangXi=140.6, Def{to weed; to eradicate}
8321 CJK UNIFIED IDEOGRAPH-#8321, IRGKangXi=1027.400, RSKangXi=140.6
8322 CJK UNIFIED IDEOGRAPH-#8322, IRGKangXi=1028.050, RSKangXi=140.6, Def{sedges; rushes}
8323 CJK UNIFIED IDEOGRAPH-#8323, IRGKangXi=1036.190, RSKangXi=140.7, Def{mat, matting}
8324 CJK UNIFIED IDEOGRAPH-#8324, IRGKangXi=1028.080, RSKangXi=140.6
8325 CJK UNIFIED IDEOGRAPH-#8325, IRGKangXi=1028.090, RSKangXi=140.6
8326 CJK UNIFIED IDEOGRAPH-#8326, IRGKangXi=1028.100, RSKangXi=140.6, Def{thorns, prickles}
8327 CJK UNIFIED IDEOGRAPH-#8327, IRGKangXi=1028.120, RSKangXi=140.6, Def{cocoon; callus, blister}
8328 CJK UNIFIED IDEOGRAPH-#8328, IRGKangXi=1028.130, RSKangXi=140.6, Def{thatching; caltrop, Tribulus terrestris}
8329 CJK UNIFIED IDEOGRAPH-#8329, IRGKangXi=1028.140, RSKangXi=140.6
832A CJK UNIFIED IDEOGRAPH-#832A, IRGKangXi=1028.150, RSKangXi=140.6
832B CJK UNIFIED IDEOGRAPH-#832B, IRGKangXi=1028.170, RSKangXi=140.6, Def{vast, boundless, widespread}
832C CJK UNIFIED IDEOGRAPH-#832C, IRGKangXi=1028.190, RSKangXi=140.6, Def{harvest}
832D CJK UNIFIED IDEOGRAPH-#832D, IRGKangXi=1028.210, RSKangXi=140.6, Def{an aquatic grass, the stalks of which are eaten as a vegetable}
832E CJK UNIFIED IDEOGRAPH-#832E, IRGKangXi=1028.230, RSKangXi=140.6
832F CJK UNIFIED IDEOGRAPH-#832F, IRGKangXi=1028.240, RSKangXi=140.6, Def{china root; medicinal fungus}
8330 CJK UNIFIED IDEOGRAPH-#8330, IRGKangXi=1028.260, RSKangXi=140.6
8331 CJK UNIFIED IDEOGRAPH-#8331, IRGKangXi=1028.280, RSKangXi=140.6, Def{dogwood}
8332 CJK UNIFIED IDEOGRAPH-#8332, IRGKangXi=1028.290, RSKangXi=140.6, Def{now, here; this; time, year}
8333 CJK UNIFIED IDEOGRAPH-#8333, IRGKangXi=1029.010, RSKangXi=140.6
8334 CJK UNIFIED IDEOGRAPH-#8334, IRGKangXi=1029.020, RSKangXi=140.6, Def{fennel, aniseed}
8335 CJK UNIFIED IDEOGRAPH-#8335, IRGKangXi=1029.030, RSKangXi=140.6, Def{a cushion, mattress; wormwood; Skimmia japon}
8336 CJK UNIFIED IDEOGRAPH-#8336, IRGKangXi=1029.040, RSKangXi=140.6, Def{tea}
8337 CJK UNIFIED IDEOGRAPH-#8337, IRGKangXi=1029.050, RSKangXi=140.6, Def{flutter; flower}
8338 CJK UNIFIED IDEOGRAPH-#8338, IRGKangXi=1029.070, RSKangXi=140.6, Def{soft, downy; buds, sprouts}
8339 CJK UNIFIED IDEOGRAPH-#8339, IRGKangXi=1029.100, RSKangXi=140.6, Def{roots; vegetables; eat; bear}
833A CJK UNIFIED IDEOGRAPH-#833A, IRGKangXi=1029.110, RSKangXi=140.6
833B CJK UNIFIED IDEOGRAPH-#833B, IRGKangXi=1029.130, RSKangXi=140.6
833C CJK UNIFIED IDEOGRAPH-#833C, IRGKangXi=1029.140, RSKangXi=140.6, Def{Chrysanthemum coronarium}
833D CJK UNIFIED IDEOGRAPH-#833D, IRGKangXi=1029.150, RSKangXi=140.6
833E CJK UNIFIED IDEOGRAPH-#833E, IRGKangXi=1022.181, RSKangXi=140.4
833F CJK UNIFIED IDEOGRAPH-#833F, IRGKangXi=1029.170, RSKangXi=140.6
8340 CJK UNIFIED IDEOGRAPH-#8340, IRGKangXi=1029.180, RSKangXi=140.6, Def{surname; ancient state; plant}
8341 CJK UNIFIED IDEOGRAPH-#8341, IRGKangXi=1030.010, RSKangXi=140.6, Def{celery}
8342 CJK UNIFIED IDEOGRAPH-#8342, IRGKangXi=1030.040, RSKangXi=140.6
8343 CJK UNIFIED IDEOGRAPH-#8343, IRGKangXi=1030.050, RSKangXi=140.6, Def{aromatic herb; fine cloth}
8344 CJK UNIFIED IDEOGRAPH-#8344, IRGKangXi=1030.060, RSKangXi=140.6, Def{roots}
8345 CJK UNIFIED IDEOGRAPH-#8345, IRGKangXi=1030.080, RSKangXi=140.6, Def{answer: small bean; thick}
8346 CJK UNIFIED IDEOGRAPH-#8346, IRGKangXi=1030.110, RSKangXi=18.8, Def{thorns; brambles; my wife; cane}
8347 CJK UNIFIED IDEOGRAPH-#8347, IRGKangXi=1030.140, RSKangXi=140.6, Def{a water plant, Nymphoides peltalum}
8348 CJK UNIFIED IDEOGRAPH-#8348, IRGKangXi=1030.150, RSKangXi=140.6
8349 CJK UNIFIED IDEOGRAPH-#8349, IRGKangXi=1030.170, RSKangXi=140.6, Def{grass, straw, thatch, herbs}
834A CJK UNIFIED IDEOGRAPH-#834A, IRGKangXi=1031.381, RSKangXi=140.6, Def{thorns; brambles; my wife; cane}
834B CJK UNIFIED IDEOGRAPH-#834B, IRGKangXi=1031.010, RSKangXi=140.6
834C CJK UNIFIED IDEOGRAPH-#834C, IRGKangXi=1031.020, RSKangXi=140.6
834D CJK UNIFIED IDEOGRAPH-#834D, IRGKangXi=1031.030, RSKangXi=140.6, Def{buckwheat; herbal medicine}
834E CJK UNIFIED IDEOGRAPH-#834E, IRGKangXi=1031.040, RSKangXi=140.6
834F CJK UNIFIED IDEOGRAPH-#834F, IRGKangXi=1031.050, RSKangXi=140.6, Def{beans; soft, pliable; herb}
8350 CJK UNIFIED IDEOGRAPH-#8350, IRGKangXi=1031.060, RSKangXi=140.6, Def{repeat, reoccur; recommend}
8351 CJK UNIFIED IDEOGRAPH-#8351, IRGKangXi=1031.070, RSKangXi=140.6, Def{sprouts; tares}
8352 CJK UNIFIED IDEOGRAPH-#8352, IRGKangXi=1031.080, RSKangXi=140.6, Def{wasteland, desert; uncultivated}
8353 CJK UNIFIED IDEOGRAPH-#8353, IRGKangXi=1031.180, RSKangXi=140.8
8354 CJK UNIFIED IDEOGRAPH-#8354, IRGKangXi=1031.210, RSKangXi=140.6, Def{lichee}
8355 CJK UNIFIED IDEOGRAPH-#8355, IRGKangXi=1031.260, RSKangXi=140.6
8356 CJK UNIFIED IDEOGRAPH-#8356, IRGKangXi=1031.310, RSKangXi=140.6, Def{betel pepper}
8357 CJK UNIFIED IDEOGRAPH-#8357, IRGKangXi=1031.360, RSKangXi=140.6
8358 CJK UNIFIED IDEOGRAPH-#8358, IRGKangXi=1031.381, RSKangXi=140.6, Def{village, hamlet; villa; surname}
8359 CJK UNIFIED IDEOGRAPH-#8359, IRGKangXi=1036.401, RSKangXi=140.6, Def{plantago major}
835A CJK UNIFIED IDEOGRAPH-#835A, IRGKangXi=1031.381, RSKangXi=140.6, Def{pods of leguminous plants; pods}
835B CJK UNIFIED IDEOGRAPH-#835B, IRGKangXi=1031.381, RSKangXi=140.6, Def{fuel, firewood; stubble; Wikstroemia japonica}
835C CJK UNIFIED IDEOGRAPH-#835C, IRGKangXi=1031.381, RSKangXi=140.6, Def{species of bean; piper longtum}
835D CJK UNIFIED IDEOGRAPH-#835D, IRGKangXi=1031.381, RSKangXi=140.9
835E CJK UNIFIED IDEOGRAPH-#835E, IRGKangXi=1031.381, RSKangXi=140.6, Def{buckwheat}
835F CJK UNIFIED IDEOGRAPH-#835F, IRGKangXi=1031.381, RSKangXi=140.6, Def{luxuriant, flourishing, abundant}
8360 CJK UNIFIED IDEOGRAPH-#8360, IRGKangXi=1031.381, RSKangXi=140.6, Def{water-chestnuts; caltrop}
8361 CJK UNIFIED IDEOGRAPH-#8361, IRGKangXi=1031.381, RSKangXi=140.7, Def{pond, pool; wash away, cleanse}
8362 CJK UNIFIED IDEOGRAPH-#8362, IRGKangXi=1031.381, RSKangXi=140.6
8363 CJK UNIFIED IDEOGRAPH-#8363, IRGKangXi=1031.381, RSKangXi=140.6, Def{glory, honor; flourish, prosper}
8364 CJK UNIFIED IDEOGRAPH-#8364, IRGKangXi=1031.381, RSKangXi=140.6, Def{meat diet; strong smelling}
8365 CJK UNIFIED IDEOGRAPH-#8365, IRGKangXi=1031.381, RSKangXi=140.6, Def{a county in Henan; the rising and dashing of waves}
8366 CJK UNIFIED IDEOGRAPH-#8366, IRGKangXi=1031.381, RSKangXi=140.6, Def{brindled ox; brindled in color}
8367 CJK UNIFIED IDEOGRAPH-#8367, IRGKangXi=1031.381, RSKangXi=140.6, Def{shine, shimmer; shining, dazzling}
8368 CJK UNIFIED IDEOGRAPH-#8368, IRGKangXi=1031.381, RSKangXi=140.6, Def{nettle}
8369 CJK UNIFIED IDEOGRAPH-#8369, IRGKangXi=1031.381, RSKangXi=140.6, Def{a kind of weed; faithfulness}
836A CJK UNIFIED IDEOGRAPH-#836A, IRGKangXi=1031.381, RSKangXi=140.6, Def{aromatic grass; iris, flower}
836B CJK UNIFIED IDEOGRAPH-#836B, IRGKangXi=1036.401, RSKangXi=140.7, Def{shade, shelter; protect}
836C CJK UNIFIED IDEOGRAPH-#836C, IRGKangXi=1031.381, RSKangXi=140.6, Def{a plant name}
836D CJK UNIFIED IDEOGRAPH-#836D, IRGKangXi=1031.381, RSKangXi=140.6, Def{herb}
836E CJK UNIFIED IDEOGRAPH-#836E, IRGKangXi=1031.381, RSKangXi=140.6, Def{grass}
836F CJK UNIFIED IDEOGRAPH-#836F, IRGKangXi=1031.381, RSKangXi=140.6, Def{leaf of Dahurian angelica plant; medicine}
8370 CJK UNIFIED IDEOGRAPH-#8370, IRGKangXi=1031.390, RSKangXi=140.7
8371 CJK UNIFIED IDEOGRAPH-#8371, IRGKangXi=1031.400, RSKangXi=140.7
8372 CJK UNIFIED IDEOGRAPH-#8372, IRGKangXi=1031.430, RSKangXi=140.7
8373 CJK UNIFIED IDEOGRAPH-#8373, IRGKangXi=1032.010, RSKangXi=140.7, Def{beans, peas; bean-shaped}
8374 CJK UNIFIED IDEOGRAPH-#8374, IRGKangXi=1032.040, RSKangXi=140.7
8375 CJK UNIFIED IDEOGRAPH-#8375, IRGKangXi=1032.060, RSKangXi=140.7, Def{polemonium}
8376 CJK UNIFIED IDEOGRAPH-#8376, IRGKangXi=1032.100, RSKangXi=140.7
8377 CJK UNIFIED IDEOGRAPH-#8377, IRGKangXi=1032.130, RSKangXi=140.7, Def{lotus, water lily, holland}
8378 CJK UNIFIED IDEOGRAPH-#8378, IRGKangXi=1032.140, RSKangXi=140.7, Def{water chestnut}
8379 CJK UNIFIED IDEOGRAPH-#8379, IRGKangXi=1032.160, RSKangXi=140.7
837A CJK UNIFIED IDEOGRAPH-#837A, IRGKangXi=1032.170, RSKangXi=140.7
837B CJK UNIFIED IDEOGRAPH-#837B, IRGKangXi=1032.180, RSKangXi=140.7, Def{reed, Miscanthus saccariflorus}
837C CJK UNIFIED IDEOGRAPH-#837C, IRGKangXi=1032.210, RSKangXi=140.7, Def{bitter vegetable}
837D CJK UNIFIED IDEOGRAPH-#837D, IRGKangXi=1032.220, RSKangXi=140.7, Def{coriander}
837E CJK UNIFIED IDEOGRAPH-#837E, IRGKangXi=1032.230, RSKangXi=140.7
837F CJK UNIFIED IDEOGRAPH-#837F, IRGKangXi=1032.240, RSKangXi=140.7
8380 CJK UNIFIED IDEOGRAPH-#8380, IRGKangXi=1032.250, RSKangXi=140.7, Def{to farm; a farmer; agriculture}
8381 CJK UNIFIED IDEOGRAPH-#8381, IRGKangXi=1032.260, RSKangXi=140.7
8382 CJK UNIFIED IDEOGRAPH-#8382, IRGKangXi=1033.040, RSKangXi=140.7
8383 CJK UNIFIED IDEOGRAPH-#8383, IRGKangXi=1033.050, RSKangXi=140.7
8384 CJK UNIFIED IDEOGRAPH-#8384, IRGKangXi=1033.100, RSKangXi=140.7
8385 CJK UNIFIED IDEOGRAPH-#8385, IRGKangXi=1033.110, RSKangXi=140.7, Def{attend, be present; arrive at}
8386 CJK UNIFIED IDEOGRAPH-#8386, IRGKangXi=1033.120, RSKangXi=140.7, Def{a kind of legendary tree}
8387 CJK UNIFIED IDEOGRAPH-#8387, IRGKangXi=1033.130, RSKangXi=140.7
8388 CJK UNIFIED IDEOGRAPH-#8388, IRGKangXi=1033.180, RSKangXi=140.7
8389 CJK UNIFIED IDEOGRAPH-#8389, IRGKangXi=1033.210, RSKangXi=140.7, Def{white jasmine}
838A CJK UNIFIED IDEOGRAPH-#838A, IRGKangXi=1033.220, RSKangXi=140.7, Def{village, hamlet; villa; surname}
838B CJK UNIFIED IDEOGRAPH-#838B, IRGKangXi=1033.280, RSKangXi=140.7
838C CJK UNIFIED IDEOGRAPH-#838C, IRGKangXi=1033.300, RSKangXi=140.7
838D CJK UNIFIED IDEOGRAPH-#838D, IRGKangXi=1033.310, RSKangXi=140.7
838E CJK UNIFIED IDEOGRAPH-#838E, IRGKangXi=1033.320, RSKangXi=140.7, Def{kind of sedge grass, used anciently for raincoats}
838F CJK UNIFIED IDEOGRAPH-#838F, IRGKangXi=1033.330, RSKangXi=140.7
8390 CJK UNIFIED IDEOGRAPH-#8390, IRGKangXi=1033.350, RSKangXi=140.7
8391 CJK UNIFIED IDEOGRAPH-#8391, IRGKangXi=1034.020, RSKangXi=140.7
8392 CJK UNIFIED IDEOGRAPH-#8392, IRGKangXi=1034.030, RSKangXi=140.7, Def{hemp-like plant; taro; herb}
8393 CJK UNIFIED IDEOGRAPH-#8393, IRGKangXi=1034.040, RSKangXi=140.7, Def{moss; edible berries}
8394 CJK UNIFIED IDEOGRAPH-#8394, IRGKangXi=1034.050, RSKangXi=140.7
8395 CJK UNIFIED IDEOGRAPH-#8395, IRGKangXi=1034.070, RSKangXi=140.7, Def{a water plant, Nymphoides peltalum}
8396 CJK UNIFIED IDEOGRAPH-#8396, IRGKangXi=1034.090, RSKangXi=140.7, Def{stem, stalk}
8397 CJK UNIFIED IDEOGRAPH-#8397, IRGKangXi=1034.100, RSKangXi=140.7
8398 CJK UNIFIED IDEOGRAPH-#8398, IRGKangXi=1034.130, RSKangXi=140.7, Def{long; numerous; a marsh plant whose root is used for medicine}
8399 CJK UNIFIED IDEOGRAPH-#8399, IRGKangXi=1034.140, RSKangXi=140.7, Def{species of water plant}
839A CJK UNIFIED IDEOGRAPH-#839A, IRGKangXi=1034.160, RSKangXi=140.7, Def{bamboo mat; feast, banquet}
839B CJK UNIFIED IDEOGRAPH-#839B, IRGKangXi=1034.170, RSKangXi=140.7, Def{stalks of grasses, etc.}
839C CJK UNIFIED IDEOGRAPH-#839C, IRGKangXi=1034.180, RSKangXi=140.7, Def{Avena nuda; a bamboo basket}
839D CJK UNIFIED IDEOGRAPH-#839D, IRGKangXi=1034.190, RSKangXi=140.7, Def{to chop straw fine for animals}
839E CJK UNIFIED IDEOGRAPH-#839E, IRGKangXi=1034.200, RSKangXi=140.7, Def{smiling; a kind of aquatic herb, clubrush, Scirpus lacustris}
839F CJK UNIFIED IDEOGRAPH-#839F, IRGKangXi=1034.210, RSKangXi=140.7, Def{a bud}
83A0 CJK UNIFIED IDEOGRAPH-#83A0, IRGKangXi=1034.220, RSKangXi=140.7, Def{weeds, tares; undesirable, evil}
83A1 CJK UNIFIED IDEOGRAPH-#83A1, IRGKangXi=1035.010, RSKangXi=140.7
83A2 CJK UNIFIED IDEOGRAPH-#83A2, IRGKangXi=1035.040, RSKangXi=140.7, Def{pods of leguminous plants; pods}
83A3 CJK UNIFIED IDEOGRAPH-#83A3, IRGKangXi=1036.401, RSKangXi=140.7
83A4 CJK UNIFIED IDEOGRAPH-#83A4, IRGKangXi=1035.060, RSKangXi=140.7
83A5 CJK UNIFIED IDEOGRAPH-#83A5, IRGKangXi=1035.070, RSKangXi=140.7
83A6 CJK UNIFIED IDEOGRAPH-#83A6, IRGKangXi=1035.080, RSKangXi=140.7
83A7 CJK UNIFIED IDEOGRAPH-#83A7, IRGKangXi=1035.090, RSKangXi=140.7, Def{edible greens; amaranth}
83A8 CJK UNIFIED IDEOGRAPH-#83A8, IRGKangXi=1035.100, RSKangXi=140.7, Def{herb, Scopolia japonica}
83A9 CJK UNIFIED IDEOGRAPH-#83A9, IRGKangXi=1035.110, RSKangXi=140.7, Def{membrane lining inside of reed}
83AA CJK UNIFIED IDEOGRAPH-#83AA, IRGKangXi=1035.120, RSKangXi=140.7, Def{artemisia}
83AB CJK UNIFIED IDEOGRAPH-#83AB, IRGKangXi=1035.130, RSKangXi=140.7, Def{do not, is not, can not; negative}
83AC CJK UNIFIED IDEOGRAPH-#83AC, IRGKangXi=1035.230, RSKangXi=140.7
83AD CJK UNIFIED IDEOGRAPH-#83AD, IRGKangXi=1035.240, RSKangXi=140.9
83AE CJK UNIFIED IDEOGRAPH-#83AE, IRGKangXi=1036.050, RSKangXi=140.7
83AF CJK UNIFIED IDEOGRAPH-#83AF, IRGKangXi=1036.401, RSKangXi=140.7
83B0 CJK UNIFIED IDEOGRAPH-#83B0, IRGKangXi=1036.401, RSKangXi=140.7
83B1 CJK UNIFIED IDEOGRAPH-#83B1, IRGKangXi=1036.401, RSKangXi=140.7, Def{goosefoot, weed; fallow field}
83B2 CJK UNIFIED IDEOGRAPH-#83B2, IRGKangXi=1042.261, RSKangXi=140.8, Def{lotus, water lily; paradise}
83B3 CJK UNIFIED IDEOGRAPH-#83B3, IRGKangXi=1036.401, RSKangXi=140.7, Def{transplant; plant; dill, Anethum graveolens}
83B4 CJK UNIFIED IDEOGRAPH-#83B4, IRGKangXi=1036.401, RSKangXi=140.7, Def{lettuce}
83B5 CJK UNIFIED IDEOGRAPH-#83B5, IRGKangXi=1042.261, RSKangXi=140.7, Def{dodder; creeper}
83B6 CJK UNIFIED IDEOGRAPH-#83B6, IRGKangXi=1036.401, RSKangXi=140.7, Def{vine}
83B7 CJK UNIFIED IDEOGRAPH-#83B7, IRGKangXi=1036.401, RSKangXi=140.7, Def{obtain, get, receive; seize}
83B8 CJK UNIFIED IDEOGRAPH-#83B8, IRGKangXi=1036.401, RSKangXi=140.7, Def{caryopteris divaricata}
83B9 CJK UNIFIED IDEOGRAPH-#83B9, IRGKangXi=1036.401, RSKangXi=140.7, Def{luster of gems; bright, lustrous}
83BA CJK UNIFIED IDEOGRAPH-#83BA, IRGKangXi=1036.401, RSKangXi=140.7, Def{oriole, green finch; Sylvia species (various)}
83BB CJK UNIFIED IDEOGRAPH-#83BB, IRGKangXi=1036.401, RSKangXi=21.9, Def{late}
83BC CJK UNIFIED IDEOGRAPH-#83BC, IRGKangXi=1036.401, RSKangXi=140.7, Def{an edible water plant-brasenia}
83BD CJK UNIFIED IDEOGRAPH-#83BD, IRGKangXi=1036.410, RSKangXi=140.8, Def{thicket, underbrush; poisonous}
83BE CJK UNIFIED IDEOGRAPH-#83BE, IRGKangXi=1036.420, RSKangXi=140.8
83BF CJK UNIFIED IDEOGRAPH-#83BF, IRGKangXi=1036.430, RSKangXi=140.8, Def{thorn}
83C0 CJK UNIFIED IDEOGRAPH-#83C0, IRGKangXi=1036.440, RSKangXi=140.8, Def{luxuriance of growth}
83C1 CJK UNIFIED IDEOGRAPH-#83C1, IRGKangXi=1036.450, RSKangXi=140.8, Def{flower of leek family; turnip}
83C2 CJK UNIFIED IDEOGRAPH-#83C2, IRGKangXi=1036.470, RSKangXi=140.8
83C3 CJK UNIFIED IDEOGRAPH-#83C3, IRGKangXi=1036.490, RSKangXi=140.8
83C4 CJK UNIFIED IDEOGRAPH-#83C4, IRGKangXi=1036.500, RSKangXi=140.8
83C5 CJK UNIFIED IDEOGRAPH-#83C5, IRGKangXi=1036.510, RSKangXi=140.8, Def{coarse grass, themedia forskali}
83C6 CJK UNIFIED IDEOGRAPH-#83C6, IRGKangXi=1037.040, RSKangXi=140.8, Def{jungle}
83C7 CJK UNIFIED IDEOGRAPH-#83C7, IRGKangXi=1037.050, RSKangXi=140.8, Def{mushrooms}
83C8 CJK UNIFIED IDEOGRAPH-#83C8, IRGKangXi=1037.080, RSKangXi=140.8
83C9 CJK UNIFIED IDEOGRAPH-#83C9, IRGKangXi=1037.100, RSKangXi=140.8, Def{the green bamboo; greenish bamboo}
83CA CJK UNIFIED IDEOGRAPH-#83CA, IRGKangXi=1037.110, RSKangXi=140.8, Def{chrysanthemum}
83CB CJK UNIFIED IDEOGRAPH-#83CB, IRGKangXi=1037.120, RSKangXi=140.8
83CC CJK UNIFIED IDEOGRAPH-#83CC, IRGKangXi=1037.140, RSKangXi=140.8, Def{mushroom; germ, microbe}
83CD CJK UNIFIED IDEOGRAPH-#83CD, IRGKangXi=1037.150, RSKangXi=140.8
83CE CJK UNIFIED IDEOGRAPH-#83CE, IRGKangXi=1037.180, RSKangXi=140.8, Def{beautiful jade; bamboo}
83CF CJK UNIFIED IDEOGRAPH-#83CF, IRGKangXi=1037.200, RSKangXi=140.8, Def{river in Shandong province}
83D0 CJK UNIFIED IDEOGRAPH-#83D0, IRGKangXi=1037.220, RSKangXi=140.8, Def{a thicket}
83D1 CJK UNIFIED IDEOGRAPH-#83D1, IRGKangXi=1037.240, RSKangXi=140.8, Def{to weed grass; land which has been under cultivation for one year}
83D2 CJK UNIFIED IDEOGRAPH-#83D2, IRGKangXi=1037.280, RSKangXi=140.8
83D3 CJK UNIFIED IDEOGRAPH-#83D3, IRGKangXi=1037.290, RSKangXi=140.8, Def{fruits, nuts, berries}
83D4 CJK UNIFIED IDEOGRAPH-#83D4, IRGKangXi=1037.310, RSKangXi=140.8, Def{turnip}
83D5 CJK UNIFIED IDEOGRAPH-#83D5, IRGKangXi=1038.020, RSKangXi=140.8
83D6 CJK UNIFIED IDEOGRAPH-#83D6, IRGKangXi=1038.030, RSKangXi=140.8, Def{iris, sweet flag, calamus}
83D7 CJK UNIFIED IDEOGRAPH-#83D7, IRGKangXi=1038.040, RSKangXi=140.8
83D8 CJK UNIFIED IDEOGRAPH-#83D8, IRGKangXi=1038.060, RSKangXi=140.8, Def{celery, cabbage}
83D9 CJK UNIFIED IDEOGRAPH-#83D9, IRGKangXi=1038.080, RSKangXi=140.8
83DA CJK UNIFIED IDEOGRAPH-#83DA, IRGKangXi=1038.090, RSKangXi=140.8
83DB CJK UNIFIED IDEOGRAPH-#83DB, IRGKangXi=1038.120, RSKangXi=140.8
83DC CJK UNIFIED IDEOGRAPH-#83DC, IRGKangXi=1038.130, RSKangXi=140.8, Def{vegetables; dish, order; food}
83DD CJK UNIFIED IDEOGRAPH-#83DD, IRGKangXi=1038.150, RSKangXi=140.8
83DE CJK UNIFIED IDEOGRAPH-#83DE, IRGKangXi=1038.170, RSKangXi=140.8
83DF CJK UNIFIED IDEOGRAPH-#83DF, IRGKangXi=1038.180, RSKangXi=140.8, Def{dodder; creeper}
83E0 CJK UNIFIED IDEOGRAPH-#83E0, IRGKangXi=1038.190, RSKangXi=140.8, Def{spinach and similar greens}
83E1 CJK UNIFIED IDEOGRAPH-#83E1, IRGKangXi=1038.220, RSKangXi=140.8, Def{buds, lotus buds}
83E2 CJK UNIFIED IDEOGRAPH-#83E2, IRGKangXi=1038.240, RSKangXi=140.8, Def{to incubate; to brood; to hatch}
83E3 CJK UNIFIED IDEOGRAPH-#83E3, IRGKangXi=1038.250, RSKangXi=140.8
83E4 CJK UNIFIED IDEOGRAPH-#83E4, IRGKangXi=1038.260, RSKangXi=140.8
83E5 CJK UNIFIED IDEOGRAPH-#83E5, IRGKangXi=1038.300, RSKangXi=140.8
83E6 CJK UNIFIED IDEOGRAPH-#83E6, IRGKangXi=1038.310, RSKangXi=140.8
83E7 CJK UNIFIED IDEOGRAPH-#83E7, IRGKangXi=1038.320, RSKangXi=140.8
83E8 CJK UNIFIED IDEOGRAPH-#83E8, IRGKangXi=1038.340, RSKangXi=140.8
83E9 CJK UNIFIED IDEOGRAPH-#83E9, IRGKangXi=1038.350, RSKangXi=140.8, Def{herb, aromatic plant}
83EA CJK UNIFIED IDEOGRAPH-#83EA, IRGKangXi=1039.010, RSKangXi=140.8
83EB CJK UNIFIED IDEOGRAPH-#83EB, IRGKangXi=1039.020, RSKangXi=140.8, Def{celery, aconite}
83EC CJK UNIFIED IDEOGRAPH-#83EC, IRGKangXi=1039.080, RSKangXi=140.8
83ED CJK UNIFIED IDEOGRAPH-#83ED, IRGKangXi=1039.090, RSKangXi=140.8
83EE CJK UNIFIED IDEOGRAPH-#83EE, IRGKangXi=1039.130, RSKangXi=140.8
83EF CJK UNIFIED IDEOGRAPH-#83EF, IRGKangXi=1039.140, RSKangXi=140.8, Def{flowery; illustrious; Chinese}
83F0 CJK UNIFIED IDEOGRAPH-#83F0, IRGKangXi=1039.180, RSKangXi=140.8, Def{wild rice; Zizania latifolia}
83F1 CJK UNIFIED IDEOGRAPH-#83F1, IRGKangXi=1039.200, RSKangXi=140.8, Def{water-chestnut, water caltrop}
83F2 CJK UNIFIED IDEOGRAPH-#83F2, IRGKangXi=1039.220, RSKangXi=140.8, Def{fragrant, luxuriant; the Philippines}
83F3 CJK UNIFIED IDEOGRAPH-#83F3, IRGKangXi=1039.290, RSKangXi=140.8
83F4 CJK UNIFIED IDEOGRAPH-#83F4, IRGKangXi=1039.300, RSKangXi=140.8, Def{small Buddhist monastery}
83F5 CJK UNIFIED IDEOGRAPH-#83F5, IRGKangXi=1040.040, RSKangXi=140.8
83F6 CJK UNIFIED IDEOGRAPH-#83F6, IRGKangXi=1040.060, RSKangXi=140.8, Def{species of water plant; flower}
83F7 CJK UNIFIED IDEOGRAPH-#83F7, IRGKangXi=1040.070, RSKangXi=140.8
83F8 CJK UNIFIED IDEOGRAPH-#83F8, IRGKangXi=1040.080, RSKangXi=140.8, Def{to fade; withered or dried leaves; tobacco (used for U+70DF 烟 and U+7159 煙)}
83F9 CJK UNIFIED IDEOGRAPH-#83F9, IRGKangXi=1040.090, RSKangXi=140.8, Def{salted or pickled vegetables}
83FA CJK UNIFIED IDEOGRAPH-#83FA, IRGKangXi=1040.100, RSKangXi=140.8
83FB CJK UNIFIED IDEOGRAPH-#83FB, IRGKangXi=1040.110, RSKangXi=140.8, Def{artemisia; (Cant.) a flower-bud}
83FC CJK UNIFIED IDEOGRAPH-#83FC, IRGKangXi=1040.130, RSKangXi=140.8, Def{rush or sedge}
83FD CJK UNIFIED IDEOGRAPH-#83FD, IRGKangXi=1040.140, RSKangXi=140.8, Def{beans and peas, collectively}
83FE CJK UNIFIED IDEOGRAPH-#83FE, IRGKangXi=1040.150, RSKangXi=140.8, Def{beet}
83FF CJK UNIFIED IDEOGRAPH-#83FF, IRGKangXi=1040.160, RSKangXi=140.8
8400 CJK UNIFIED IDEOGRAPH-#8400, IRGKangXi=1040.170, RSKangXi=140.8
8401 CJK UNIFIED IDEOGRAPH-#8401, IRGKangXi=1040.210, RSKangXi=140.8, Def{kind of grasses}
8402 CJK UNIFIED IDEOGRAPH-#8402, IRGKangXi=1040.240, RSKangXi=140.8
8403 CJK UNIFIED IDEOGRAPH-#8403, IRGKangXi=1040.250, RSKangXi=140.8, Def{dense, thick, close-set; to collect together}
8404 CJK UNIFIED IDEOGRAPH-#8404, IRGKangXi=1040.260, RSKangXi=140.8, Def{grapes}
8405 CJK UNIFIED IDEOGRAPH-#8405, IRGKangXi=1040.270, Def{spring; wanton}
8406 CJK UNIFIED IDEOGRAPH-#8406, IRGKangXi=1040.290, RSKangXi=140.8, Def{the castor-oil plant also used for other plants}
8407 CJK UNIFIED IDEOGRAPH-#8407, IRGKangXi=1040.300, RSKangXi=140.8, Def{averrhora carambola; surname}
8408 CJK UNIFIED IDEOGRAPH-#8408, IRGKangXi=1040.310, RSKangXi=140.8
8409 CJK UNIFIED IDEOGRAPH-#8409, IRGKangXi=1040.350, RSKangXi=140.8
840A CJK UNIFIED IDEOGRAPH-#840A, IRGKangXi=1041.020, RSKangXi=140.8, Def{goosefoot, weed; fallow field}
840B CJK UNIFIED IDEOGRAPH-#840B, IRGKangXi=1041.040, RSKangXi=140.8, Def{luxuriant foliage; crowded}
840C CJK UNIFIED IDEOGRAPH-#840C, IRGKangXi=1041.050, RSKangXi=140.8, Def{bud, sprout}
840D CJK UNIFIED IDEOGRAPH-#840D, IRGKangXi=1041.070, RSKangXi=140.8, Def{duckweed; wandering, traveling}
840E CJK UNIFIED IDEOGRAPH-#840E, IRGKangXi=1041.100, RSKangXi=140.8, Def{wither, wilt}
840F CJK UNIFIED IDEOGRAPH-#840F, IRGKangXi=1041.110, RSKangXi=140.8, Def{lotus}
8410 CJK UNIFIED IDEOGRAPH-#8410, IRGKangXi=1041.120, RSKangXi=140.8, Def{lucky plant}
8411 CJK UNIFIED IDEOGRAPH-#8411, IRGKangXi=1041.130, RSKangXi=140.8, Def{grass used for making mats; Huanpu, place famous for robbers}
8412 CJK UNIFIED IDEOGRAPH-#8412, IRGKangXi=1041.180, RSKangXi=140.8
8413 CJK UNIFIED IDEOGRAPH-#8413, IRGKangXi=1041.200, RSKangXi=140.8
8414 CJK UNIFIED IDEOGRAPH-#8414, IRGKangXi=1041.340, RSKangXi=140.8
8415 CJK UNIFIED IDEOGRAPH-#8415, IRGKangXi=1042.090, RSKangXi=140.8, Def{water-chestnuts; caltrop}
8416 CJK UNIFIED IDEOGRAPH-#8416, IRGKangXi=1042.250, RSKangXi=140.8
8417 CJK UNIFIED IDEOGRAPH-#8417, IRGKangXi=1042.261, RSKangXi=140.8
8418 CJK UNIFIED IDEOGRAPH-#8418, IRGKangXi=1042.261, RSKangXi=140.8, Def{naphthalene}
8419 CJK UNIFIED IDEOGRAPH-#8419, IRGKangXi=1042.261, RSKangXi=140.8
841A CJK UNIFIED IDEOGRAPH-#841A, IRGKangXi=1042.261, RSKangXi=140.16
841B CJK UNIFIED IDEOGRAPH-#841B, IRGKangXi=1042.261, RSKangXi=140.8
841C CJK UNIFIED IDEOGRAPH-#841C, IRGKangXi=1042.261, RSKangXi=140.8, Def{C5H8}
841D CJK UNIFIED IDEOGRAPH-#841D, IRGKangXi=1042.261, RSKangXi=140.8, Def{type of creeping plant; turnip}
841E CJK UNIFIED IDEOGRAPH-#841E, IRGKangXi=1042.261, RSKangXi=140.8
841F CJK UNIFIED IDEOGRAPH-#841F, IRGKangXi=1042.261, RSKangXi=140.8
8420 CJK UNIFIED IDEOGRAPH-#8420, IRGKangXi=1042.261, RSKangXi=140.8, Def{bud, sprout}
8421 CJK UNIFIED IDEOGRAPH-#8421, IRGKangXi=1042.261, RSKangXi=140.8
8422 CJK UNIFIED IDEOGRAPH-#8422, IRGKangXi=1042.261, RSKangXi=140.8
8423 CJK UNIFIED IDEOGRAPH-#8423, IRGKangXi=1042.261, RSKangXi=140.8
8424 CJK UNIFIED IDEOGRAPH-#8424, IRGKangXi=1042.261, RSKangXi=140.8, Def{glow-worm, luminous insect}
8425 CJK UNIFIED IDEOGRAPH-#8425, IRGKangXi=1042.261, RSKangXi=140.8, Def{encampment, barracks; manage}
8426 CJK UNIFIED IDEOGRAPH-#8426, IRGKangXi=1042.261, RSKangXi=140.8, Def{entangle, entwine, coil}
8427 CJK UNIFIED IDEOGRAPH-#8427, IRGKangXi=1042.261, RSKangXi=140.8, Def{common artemisia; dejected}
8428 CJK UNIFIED IDEOGRAPH-#8428, IRGKangXi=1047.671, RSKangXi=140.9, Def{Buddhist gods or immortals}
8429 CJK UNIFIED IDEOGRAPH-#8429, IRGKangXi=1042.270, RSKangXi=140.9, Def{scandent hop; tree}
842A CJK UNIFIED IDEOGRAPH-#842A, IRGKangXi=1042.280, RSKangXi=140.9
842B CJK UNIFIED IDEOGRAPH-#842B, IRGKangXi=1042.320, RSKangXi=140.9
842C CJK UNIFIED IDEOGRAPH-#842C, IRGKangXi=1042.330, RSKangXi=140.9, AccountingNumeric=10000, Def{ten thousand; innumerable}
842D CJK UNIFIED IDEOGRAPH-#842D, IRGKangXi=1042.370, RSKangXi=140.9
842E CJK UNIFIED IDEOGRAPH-#842E, IRGKangXi=1042.380, RSKangXi=140.9
842F CJK UNIFIED IDEOGRAPH-#842F, IRGKangXi=1042.390, RSKangXi=140.9
8430 CJK UNIFIED IDEOGRAPH-#8430, IRGKangXi=1042.400, RSKangXi=140.9
8431 CJK UNIFIED IDEOGRAPH-#8431, IRGKangXi=1042.410, RSKangXi=140.9, Def{day-lily, hemerocallisflava}
8432 CJK UNIFIED IDEOGRAPH-#8432, IRGKangXi=1042.420, RSKangXi=140.9, Def{the day-lily, Hemerocallis flava}
8433 CJK UNIFIED IDEOGRAPH-#8433, IRGKangXi=1042.430, RSKangXi=140.9
8434 CJK UNIFIED IDEOGRAPH-#8434, IRGKangXi=1042.440, RSKangXi=140.9, Def{medicinal poison plant}
8435 CJK UNIFIED IDEOGRAPH-#8435, IRGKangXi=1042.470, RSKangXi=140.9, Def{lettuce}
8436 CJK UNIFIED IDEOGRAPH-#8436, IRGKangXi=1043.010, RSKangXi=140.9
8437 CJK UNIFIED IDEOGRAPH-#8437, IRGKangXi=1043.030, RSKangXi=140.9
8438 CJK UNIFIED IDEOGRAPH-#8438, IRGKangXi=1043.050, RSKangXi=140.9, Def{dogwood}
8439 CJK UNIFIED IDEOGRAPH-#8439, IRGKangXi=1043.070, RSKangXi=140.9, Def{grass}
843A CJK UNIFIED IDEOGRAPH-#843A, IRGKangXi=1043.080, RSKangXi=140.9
843B CJK UNIFIED IDEOGRAPH-#843B, IRGKangXi=1043.090, RSKangXi=140.9
843C CJK UNIFIED IDEOGRAPH-#843C, IRGKangXi=1043.100, RSKangXi=140.9, Def{the stem and calyx of a flower; a younger brother}
843D CJK UNIFIED IDEOGRAPH-#843D, IRGKangXi=1043.110, RSKangXi=140.9, Def{fall, drop; net income, surplus}
843E CJK UNIFIED IDEOGRAPH-#843E, IRGKangXi=1043.130, RSKangXi=140.9
843F CJK UNIFIED IDEOGRAPH-#843F, IRGKangXi=1043.150, RSKangXi=140.9
8440 CJK UNIFIED IDEOGRAPH-#8440, IRGKangXi=1043.160, RSKangXi=140.9
8441 CJK UNIFIED IDEOGRAPH-#8441, IRGKangXi=1043.180, RSKangXi=140.9, Def{ginger}
8442 CJK UNIFIED IDEOGRAPH-#8442, IRGKangXi=1043.220, RSKangXi=140.9
8443 CJK UNIFIED IDEOGRAPH-#8443, IRGKangXi=1043.240, RSKangXi=140.9
8444 CJK UNIFIED IDEOGRAPH-#8444, IRGKangXi=1043.250, RSKangXi=140.9, Def{mat}
8445 CJK UNIFIED IDEOGRAPH-#8445, IRGKangXi=1043.290, RSKangXi=140.9
8446 CJK UNIFIED IDEOGRAPH-#8446, IRGKangXi=1043.300, RSKangXi=140.9, Def{reserve, preserve; conceal}
8447 CJK UNIFIED IDEOGRAPH-#8447, IRGKangXi=1043.330, RSKangXi=140.9
8448 CJK UNIFIED IDEOGRAPH-#8448, IRGKangXi=1044.020, RSKangXi=140.9
8449 CJK UNIFIED IDEOGRAPH-#8449, IRGKangXi=1044.030, RSKangXi=140.9, Def{leaf, petal; page of book; period}
844A CJK UNIFIED IDEOGRAPH-#844A, IRGKangXi=1044.040, RSKangXi=140.9, Def{cottage}
844B CJK UNIFIED IDEOGRAPH-#844B, IRGKangXi=1044.090, RSKangXi=140.9
844C CJK UNIFIED IDEOGRAPH-#844C, IRGKangXi=1044.100, RSKangXi=140.9
844D CJK UNIFIED IDEOGRAPH-#844D, IRGKangXi=1044.110, RSKangXi=140.9, Def{plant}
844E CJK UNIFIED IDEOGRAPH-#844E, IRGKangXi=1044.130, RSKangXi=140.9, Def{Humulus japonicus}
844F CJK UNIFIED IDEOGRAPH-#844F, IRGKangXi=1044.140, RSKangXi=140.9
8450 CJK UNIFIED IDEOGRAPH-#8450, IRGKangXi=1044.150, RSKangXi=140.9
8451 CJK UNIFIED IDEOGRAPH-#8451, IRGKangXi=1044.160, RSKangXi=140.9, Def{the rape-turnip}
8452 CJK UNIFIED IDEOGRAPH-#8452, IRGKangXi=1044.180, RSKangXi=140.9, Def{herb}
8453 CJK UNIFIED IDEOGRAPH-#8453, IRGKangXi=1044.190, RSKangXi=140.9, Def{vegetable}
8454 CJK UNIFIED IDEOGRAPH-#8454, IRGKangXi=1044.200, RSKangXi=140.9
8455 CJK UNIFIED IDEOGRAPH-#8455, IRGKangXi=1044.220, RSKangXi=140.9
8456 CJK UNIFIED IDEOGRAPH-#8456, IRGKangXi=1044.250, RSKangXi=140.9
8457 CJK UNIFIED IDEOGRAPH-#8457, IRGKangXi=1044.260, RSKangXi=140.8, Def{manifest; (Cant.) to wear}
8458 CJK UNIFIED IDEOGRAPH-#8458, IRGKangXi=1045.030, RSKangXi=140.9
8459 CJK UNIFIED IDEOGRAPH-#8459, IRGKangXi=1045.040, RSKangXi=140.9, Def{feather cockscomb (Celosia argentea)}
845A CJK UNIFIED IDEOGRAPH-#845A, IRGKangXi=1045.060, RSKangXi=140.9, Def{mulberry fruit}
845B CJK UNIFIED IDEOGRAPH-#845B, IRGKangXi=1045.100, RSKangXi=140.9, Def{edible bean; surname}
845C CJK UNIFIED IDEOGRAPH-#845C, IRGKangXi=1045.110, RSKangXi=140.9, Def{smilax china}
845D CJK UNIFIED IDEOGRAPH-#845D, IRGKangXi=1045.120, RSKangXi=140.9
845E CJK UNIFIED IDEOGRAPH-#845E, IRGKangXi=1045.140, RSKangXi=140.9
845F CJK UNIFIED IDEOGRAPH-#845F, IRGKangXi=1045.170, RSKangXi=140.9
8460 CJK UNIFIED IDEOGRAPH-#8460, IRGKangXi=1045.180, RSKangXi=140.9, Def{ginseng}
8461 CJK UNIFIED IDEOGRAPH-#8461, IRGKangXi=1045.200, RSKangXi=140.9, Def{grapes}
8462 CJK UNIFIED IDEOGRAPH-#8462, IRGKangXi=1045.220, RSKangXi=140.9, Def{cover, hide, protect}
8463 CJK UNIFIED IDEOGRAPH-#8463, IRGKangXi=1045.230, RSKangXi=140.9, Def{direct, supervise; surname}
8464 CJK UNIFIED IDEOGRAPH-#8464, IRGKangXi=1045.260, RSKangXi=140.9, Def{grass}
8465 CJK UNIFIED IDEOGRAPH-#8465, IRGKangXi=1045.270, RSKangXi=140.9
8466 CJK UNIFIED IDEOGRAPH-#8466, IRGKangXi=1045.280, RSKangXi=140.9, Def{reed}
8467 CJK UNIFIED IDEOGRAPH-#8467, IRGKangXi=1045.290, RSKangXi=140.9
8468 CJK UNIFIED IDEOGRAPH-#8468, IRGKangXi=1045.310, RSKangXi=140.9
8469 CJK UNIFIED IDEOGRAPH-#8469, IRGKangXi=1045.320, RSKangXi=140.9, Def{flowers}
846A CJK UNIFIED IDEOGRAPH-#846A, IRGKangXi=1045.330, RSKangXi=140.9
846B CJK UNIFIED IDEOGRAPH-#846B, IRGKangXi=1045.340, RSKangXi=140.9, Def{bottle-gourd}
846C CJK UNIFIED IDEOGRAPH-#846C, IRGKangXi=1046.050, RSKangXi=140.9, Def{bury, inter}
846D CJK UNIFIED IDEOGRAPH-#846D, IRGKangXi=1046.100, RSKangXi=140.9, Def{bulrush, reed; flute, whistle}
846E CJK UNIFIED IDEOGRAPH-#846E, IRGKangXi=1046.110, RSKangXi=140.9
846F CJK UNIFIED IDEOGRAPH-#846F, IRGKangXi=1046.120, RSKangXi=140.9, Def{orris root; leaf of the iris; medicine}
8470 CJK UNIFIED IDEOGRAPH-#8470, IRGKangXi=1046.140, RSKangXi=140.9
8471 CJK UNIFIED IDEOGRAPH-#8471, IRGKangXi=1046.150, RSKangXi=140.9, Def{scallions, leeks, green onions}
8472 CJK UNIFIED IDEOGRAPH-#8472, IRGKangXi=1046.170, RSKangXi=140.9
8473 CJK UNIFIED IDEOGRAPH-#8473, IRGKangXi=1046.180, RSKangXi=140.9, Def{luxuriant, flourishing; used for various plants}
8474 CJK UNIFIED IDEOGRAPH-#8474, IRGKangXi=1046.190, RSKangXi=140.9
8475 CJK UNIFIED IDEOGRAPH-#8475, IRGKangXi=1046.200, RSKangXi=140.9, Def{sunflower; measure}
8476 CJK UNIFIED IDEOGRAPH-#8476, IRGKangXi=1046.210, RSKangXi=140.9, Def{Draba nemerosa bebe carpa}
8477 CJK UNIFIED IDEOGRAPH-#8477, IRGKangXi=1046.230, RSKangXi=140.9, Def{meat diet; strong smelling}
8478 CJK UNIFIED IDEOGRAPH-#8478, IRGKangXi=1046.250, RSKangXi=140.9, Def{afraid, bashful}
8479 CJK UNIFIED IDEOGRAPH-#8479, IRGKangXi=1046.260, RSKangXi=140.9, Def{kind of chrysanthemum, xanthium}
847A CJK UNIFIED IDEOGRAPH-#847A, IRGKangXi=1047.010, RSKangXi=140.9, Def{thatch; fix, repair; pile up}
847B CJK UNIFIED IDEOGRAPH-#847B, IRGKangXi=1047.020, RSKangXi=140.9
847C CJK UNIFIED IDEOGRAPH-#847C, IRGKangXi=1047.030, RSKangXi=140.9
847D CJK UNIFIED IDEOGRAPH-#847D, IRGKangXi=1047.040, RSKangXi=140.9, Def{type of grain, Polygala japonica}
847E CJK UNIFIED IDEOGRAPH-#847E, IRGKangXi=1047.090, RSKangXi=140.9, Def{(Cant.) a bad smell}
847F CJK UNIFIED IDEOGRAPH-#847F, IRGKangXi=1047.100, RSKangXi=140.9
8480 CJK UNIFIED IDEOGRAPH-#8480, IRGKangXi=1047.120, RSKangXi=140.9
8481 CJK UNIFIED IDEOGRAPH-#8481, IRGKangXi=1047.671, RSKangXi=140.9
8482 CJK UNIFIED IDEOGRAPH-#8482, IRGKangXi=1047.320, RSKangXi=140.9, Def{peduncle or stem of plants}
8483 CJK UNIFIED IDEOGRAPH-#8483, IRGKangXi=1047.370, RSKangXi=140.9
8484 CJK UNIFIED IDEOGRAPH-#8484, IRGKangXi=1047.671, RSKangXi=140.9
8485 CJK UNIFIED IDEOGRAPH-#8485, IRGKangXi=1047.671, RSKangXi=140.9
8486 CJK UNIFIED IDEOGRAPH-#8486, IRGKangXi=1047.671, RSKangXi=140.9
8487 CJK UNIFIED IDEOGRAPH-#8487, IRGKangXi=1047.671, RSKangXi=140.9, Def{finish, complete; solve; complete}
8488 CJK UNIFIED IDEOGRAPH-#8488, IRGKangXi=1047.671, RSKangXi=140.9, Def{an organic compound}
8489 CJK UNIFIED IDEOGRAPH-#8489, IRGKangXi=1047.671, RSKangXi=140.9, Def{edible amaranth; straw basket}
848A CJK UNIFIED IDEOGRAPH-#848A, IRGKangXi=1047.671, RSKangXi=21.11
848B CJK UNIFIED IDEOGRAPH-#848B, IRGKangXi=1047.671, RSKangXi=140.9, Def{surname; hydropyrum latifalium}
848C CJK UNIFIED IDEOGRAPH-#848C, IRGKangXi=1047.671, RSKangXi=140.9, Def{artemisia stelleriana}
848D CJK UNIFIED IDEOGRAPH-#848D, IRGKangXi=1047.671, RSKangXi=140.9
848E CJK UNIFIED IDEOGRAPH-#848E, IRGKangXi=1047.671, RSKangXi=140.9
848F CJK UNIFIED IDEOGRAPH-#848F, IRGKangXi=1047.671, RSKangXi=140.9
8490 CJK UNIFIED IDEOGRAPH-#8490, IRGKangXi=1047.710, RSKangXi=140.10, Def{collect, gather, assemble; seek; spring hunt; assemble for war}
8491 CJK UNIFIED IDEOGRAPH-#8491, IRGKangXi=1048.010, RSKangXi=140.10
8492 CJK UNIFIED IDEOGRAPH-#8492, IRGKangXi=1048.030, RSKangXi=140.10
8493 CJK UNIFIED IDEOGRAPH-#8493, IRGKangXi=1048.040, RSKangXi=140.10, Def{an edible water; plant-brasenia}
8494 CJK UNIFIED IDEOGRAPH-#8494, IRGKangXi=1048.050, RSKangXi=140.10, Def{transplant; plant; dill, Anethum graveolens}
8495 CJK UNIFIED IDEOGRAPH-#8495, IRGKangXi=1048.070, RSKangXi=140.10
8496 CJK UNIFIED IDEOGRAPH-#8496, IRGKangXi=1048.100, RSKangXi=140.10, Def{plant name}
8497 CJK UNIFIED IDEOGRAPH-#8497, IRGKangXi=1048.120, RSKangXi=140.10
8498 CJK UNIFIED IDEOGRAPH-#8498, IRGKangXi=1048.140, RSKangXi=140.10
8499 CJK UNIFIED IDEOGRAPH-#8499, IRGKangXi=1048.150, RSKangXi=140.10, Def{cover; ignorant; suffer; mongolia}
849A CJK UNIFIED IDEOGRAPH-#849A, IRGKangXi=1048.180, RSKangXi=140.10
849B CJK UNIFIED IDEOGRAPH-#849B, IRGKangXi=1048.210, RSKangXi=140.10
849C CJK UNIFIED IDEOGRAPH-#849C, IRGKangXi=1048.220, RSKangXi=140.10, Def{garlic}
849D CJK UNIFIED IDEOGRAPH-#849D, IRGKangXi=1048.240, RSKangXi=140.10
849E CJK UNIFIED IDEOGRAPH-#849E, IRGKangXi=1048.250, RSKangXi=140.10, Def{reach, arrive; manage}
849F CJK UNIFIED IDEOGRAPH-#849F, IRGKangXi=1048.260, RSKangXi=140.10, Def{betel pepper; Amorphophallus konjac}
84A0 CJK UNIFIED IDEOGRAPH-#84A0, IRGKangXi=1048.310, RSKangXi=140.10
84A1 CJK UNIFIED IDEOGRAPH-#84A1, IRGKangXi=1048.320, RSKangXi=140.10, Def{burdock, herb}
84A2 CJK UNIFIED IDEOGRAPH-#84A2, IRGKangXi=1048.340, RSKangXi=140.10
84A3 CJK UNIFIED IDEOGRAPH-#84A3, IRGKangXi=1049.010, RSKangXi=140.10
84A4 CJK UNIFIED IDEOGRAPH-#84A4, IRGKangXi=1049.020, RSKangXi=140.10
84A5 CJK UNIFIED IDEOGRAPH-#84A5, IRGKangXi=1049.030, RSKangXi=140.10
84A6 CJK UNIFIED IDEOGRAPH-#84A6, IRGKangXi=1049.080, RSKangXi=140.10, Def{to measure; to calculate}
84A7 CJK UNIFIED IDEOGRAPH-#84A7, IRGKangXi=1049.140, RSKangXi=140.10
84A8 CJK UNIFIED IDEOGRAPH-#84A8, IRGKangXi=1049.160, RSKangXi=140.10, Def{lush vegetation, luxuriant growth}
84A9 CJK UNIFIED IDEOGRAPH-#84A9, IRGKangXi=1049.190, RSKangXi=140.10
84AA CJK UNIFIED IDEOGRAPH-#84AA, IRGKangXi=1049.200, RSKangXi=140.10
84AB CJK UNIFIED IDEOGRAPH-#84AB, IRGKangXi=1049.210, RSKangXi=140.10
84AC CJK UNIFIED IDEOGRAPH-#84AC, IRGKangXi=1049.220, RSKangXi=140.10
84AD CJK UNIFIED IDEOGRAPH-#84AD, IRGKangXi=1049.240, RSKangXi=140.10, Def{to cut grass; hay; fodder}
84AE CJK UNIFIED IDEOGRAPH-#84AE, IRGKangXi=1049.260, RSKangXi=140.10
84AF CJK UNIFIED IDEOGRAPH-#84AF, IRGKangXi=1049.270, RSKangXi=140.10, Def{a rush, of which various things are made}
84B0 CJK UNIFIED IDEOGRAPH-#84B0, IRGKangXi=1049.280, RSKangXi=140.10
84B1 CJK UNIFIED IDEOGRAPH-#84B1, IRGKangXi=1049.360, RSKangXi=140.10, Def{gambling game with dice}
84B2 CJK UNIFIED IDEOGRAPH-#84B2, IRGKangXi=1049.370, RSKangXi=140.10, Def{type of rush; vine}
84B3 CJK UNIFIED IDEOGRAPH-#84B3, IRGKangXi=1050.020, RSKangXi=140.10
84B4 CJK UNIFIED IDEOGRAPH-#84B4, IRGKangXi=1050.030, RSKangXi=140.10, Def{seed (capsule)}
84B5 CJK UNIFIED IDEOGRAPH-#84B5, IRGKangXi=1050.040, RSKangXi=140.10
84B6 CJK UNIFIED IDEOGRAPH-#84B6, IRGKangXi=1050.050, RSKangXi=140.10
84B7 CJK UNIFIED IDEOGRAPH-#84B7, IRGKangXi=1050.060, RSKangXi=140.10
84B8 CJK UNIFIED IDEOGRAPH-#84B8, IRGKangXi=1050.070, RSKangXi=140.10, Def{steam; evaporate}
84B9 CJK UNIFIED IDEOGRAPH-#84B9, IRGKangXi=1050.100, RSKangXi=140.10, Def{reed, phragmites communis}
84BA CJK UNIFIED IDEOGRAPH-#84BA, IRGKangXi=1050.110, RSKangXi=140.10, Def{furze; gorse}
84BB CJK UNIFIED IDEOGRAPH-#84BB, IRGKangXi=1050.120, RSKangXi=140.10, Def{rushes}
84BC CJK UNIFIED IDEOGRAPH-#84BC, IRGKangXi=1050.160, RSKangXi=140.10, Def{blue; green}
84BD CJK UNIFIED IDEOGRAPH-#84BD, IRGKangXi=1050.200, RSKangXi=140.10, Def{anthracene}
84BE CJK UNIFIED IDEOGRAPH-#84BE, IRGKangXi=1050.220, RSKangXi=140.10
84BF CJK UNIFIED IDEOGRAPH-#84BF, IRGKangXi=1050.250, RSKangXi=140.10, Def{mugwort, artemisia; give off}
84C0 CJK UNIFIED IDEOGRAPH-#84C0, IRGKangXi=1050.260, RSKangXi=140.10, Def{aromatic grass; iris, flower}
84C1 CJK UNIFIED IDEOGRAPH-#84C1, IRGKangXi=1050.300, RSKangXi=140.10, Def{abundant, luxuriant vegetation}
84C2 CJK UNIFIED IDEOGRAPH-#84C2, IRGKangXi=1050.310, RSKangXi=140.10, Def{lucky place}
84C3 CJK UNIFIED IDEOGRAPH-#84C3, IRGKangXi=1051.010, RSKangXi=140.10
84C4 CJK UNIFIED IDEOGRAPH-#84C4, IRGKangXi=1051.020, RSKangXi=140.10, Def{store, save, hoard, gather}
84C5 CJK UNIFIED IDEOGRAPH-#84C5, IRGKangXi=1051.040, RSKangXi=140.10
84C6 CJK UNIFIED IDEOGRAPH-#84C6, IRGKangXi=1051.050, RSKangXi=140.10, Def{straw mat, mat}
84C7 CJK UNIFIED IDEOGRAPH-#84C7, IRGKangXi=1051.060, RSKangXi=140.10, Def{follicles of plants}
84C8 CJK UNIFIED IDEOGRAPH-#84C8, IRGKangXi=1051.070, RSKangXi=140.10
84C9 CJK UNIFIED IDEOGRAPH-#84C9, IRGKangXi=1051.080, RSKangXi=140.10, Def{hibiscus; Chengdu, Sichuan}
84CA CJK UNIFIED IDEOGRAPH-#84CA, IRGKangXi=1051.100, RSKangXi=140.10, Def{luxuriant vegetation; lush}
84CB CJK UNIFIED IDEOGRAPH-#84CB, IRGKangXi=1051.120, RSKangXi=140.10, Def{cover, hide, protect}
84CC CJK UNIFIED IDEOGRAPH-#84CC, IRGKangXi=1051.140, RSKangXi=140.10, Def{pretend; crouch}
84CD CJK UNIFIED IDEOGRAPH-#84CD, IRGKangXi=1051.160, RSKangXi=140.10, Def{milfoil, plant used in divination}
84CE CJK UNIFIED IDEOGRAPH-#84CE, IRGKangXi=1051.180, RSKangXi=140.10
84CF CJK UNIFIED IDEOGRAPH-#84CF, IRGKangXi=1051.200, RSKangXi=140.10, Def{fruit of plant; melon}
84D0 CJK UNIFIED IDEOGRAPH-#84D0, IRGKangXi=1051.220, RSKangXi=140.10, Def{straw bed mat; rushes}
84D1 CJK UNIFIED IDEOGRAPH-#84D1, IRGKangXi=1051.230, RSKangXi=140.10, Def{rain coat made of straw, coir, etc.}
84D2 CJK UNIFIED IDEOGRAPH-#84D2, IRGKangXi=1051.260, RSKangXi=140.10
84D3 CJK UNIFIED IDEOGRAPH-#84D3, IRGKangXi=1051.270, RSKangXi=140.10, Def{bud}
84D4 CJK UNIFIED IDEOGRAPH-#84D4, IRGKangXi=1051.350, RSKangXi=140.10
84D5 CJK UNIFIED IDEOGRAPH-#84D5, IRGKangXi=1052.030, RSKangXi=140.10
84D6 CJK UNIFIED IDEOGRAPH-#84D6, IRGKangXi=1052.051, RSKangXi=140.10, Def{castor-oil plant, Ricinus commumis}
84D7 CJK UNIFIED IDEOGRAPH-#84D7, IRGKangXi=1052.051, RSKangXi=140.10, Def{a plant; five-fold}
84D8 CJK UNIFIED IDEOGRAPH-#84D8, IRGKangXi=1052.051, RSKangXi=140.10
84D9 CJK UNIFIED IDEOGRAPH-#84D9, IRGKangXi=1052.051, RSKangXi=140.10, Def{a mat, matting}
84DA CJK UNIFIED IDEOGRAPH-#84DA, IRGKangXi=1052.051, RSKangXi=140.10, Def{oxalic (used in compounds)}
84DB CJK UNIFIED IDEOGRAPH-#84DB, IRGKangXi=1052.051, RSKangXi=140.10
84DC CJK UNIFIED IDEOGRAPH-#84DC, IRGKangXi=1052.051, RSKangXi=140.10
84DD CJK UNIFIED IDEOGRAPH-#84DD, IRGKangXi=1052.051, RSKangXi=140.10, Def{blue; indigo plant; surname}
84DE CJK UNIFIED IDEOGRAPH-#84DE, IRGKangXi=1052.051
84DF CJK UNIFIED IDEOGRAPH-#84DF, IRGKangXi=1052.051, RSKangXi=140.10, Def{circium, thistles; surname}
84E0 CJK UNIFIED IDEOGRAPH-#84E0, IRGKangXi=1056.121, RSKangXi=140.10, Def{gracilaria verrucosa}
84E1 CJK UNIFIED IDEOGRAPH-#84E1, IRGKangXi=1052.051, RSKangXi=140.10
84E2 CJK UNIFIED IDEOGRAPH-#84E2, IRGKangXi=1056.121, Def{(Cant.) brake, fern}
84E3 CJK UNIFIED IDEOGRAPH-#84E3, IRGKangXi=1052.051, RSKangXi=140.10, Def{yam}
84E4 CJK UNIFIED IDEOGRAPH-#84E4, IRGKangXi=1052.051, RSKangXi=140.10
84E5 CJK UNIFIED IDEOGRAPH-#84E5, IRGKangXi=1052.051, RSKangXi=140.10, Def{polish}
84E6 CJK UNIFIED IDEOGRAPH-#84E6, IRGKangXi=1052.051, RSKangXi=187.10, Def{suddenly, quickly, abruptly}
84E7 CJK UNIFIED IDEOGRAPH-#84E7, IRGKangXi=1052.060, RSKangXi=140.11, Def{bamboo basket; weeder; rake}
84E8 CJK UNIFIED IDEOGRAPH-#84E8, IRGKangXi=1052.070, RSKangXi=140.11
84E9 CJK UNIFIED IDEOGRAPH-#84E9, IRGKangXi=1052.080, RSKangXi=140.11
84EA CJK UNIFIED IDEOGRAPH-#84EA, IRGKangXi=1052.090, RSKangXi=140.11, Def{paper-plant; Aralia papyrifera}
84EB CJK UNIFIED IDEOGRAPH-#84EB, IRGKangXi=1052.130, RSKangXi=140.11, Def{dock}
84EC CJK UNIFIED IDEOGRAPH-#84EC, IRGKangXi=1052.140, RSKangXi=140.11, Def{type of raspberry; fairyland}
84ED CJK UNIFIED IDEOGRAPH-#84ED, IRGKangXi=1052.150, RSKangXi=140.11
84EE CJK UNIFIED IDEOGRAPH-#84EE, IRGKangXi=1052.160, RSKangXi=140.11, Def{lotus, water lily; paradise}
84EF CJK UNIFIED IDEOGRAPH-#84EF, IRGKangXi=1052.190, RSKangXi=140.11, Def{medicinal herb}
84F0 CJK UNIFIED IDEOGRAPH-#84F0, IRGKangXi=1052.200, RSKangXi=140.11, Def{to increase five-fold}
84F1 CJK UNIFIED IDEOGRAPH-#84F1, IRGKangXi=1047.671, RSKangXi=140.11
84F2 CJK UNIFIED IDEOGRAPH-#84F2, IRGKangXi=1052.250, RSKangXi=140.11
84F3 CJK UNIFIED IDEOGRAPH-#84F3, IRGKangXi=1052.270, RSKangXi=140.11
84F4 CJK UNIFIED IDEOGRAPH-#84F4, IRGKangXi=1052.290, RSKangXi=140.11, Def{edible water plant, bracenia}
84F5 CJK UNIFIED IDEOGRAPH-#84F5, IRGKangXi=1052.300, RSKangXi=140.11
84F6 CJK UNIFIED IDEOGRAPH-#84F6, IRGKangXi=1052.310, RSKangXi=140.11
84F7 CJK UNIFIED IDEOGRAPH-#84F7, IRGKangXi=1052.320, RSKangXi=140.11, Def{motherwort, various plants of the genus Leonurus, such as L. sibiricus and L. artemesia}
84F8 CJK UNIFIED IDEOGRAPH-#84F8, IRGKangXi=1052.330, RSKangXi=140.11
84F9 CJK UNIFIED IDEOGRAPH-#84F9, IRGKangXi=1052.340, RSKangXi=140.11
84FA CJK UNIFIED IDEOGRAPH-#84FA, IRGKangXi=1052.370, RSKangXi=140.11, Def{art; talent, ability; craft}
84FB CJK UNIFIED IDEOGRAPH-#84FB, IRGKangXi=1053.010, RSKangXi=140.11, Def{(Cant.) classifier for hair}
84FC CJK UNIFIED IDEOGRAPH-#84FC, IRGKangXi=1053.020, RSKangXi=140.11, Def{smartweed, polygonum}
84FD CJK UNIFIED IDEOGRAPH-#84FD, IRGKangXi=1053.030, RSKangXi=140.11, Def{species of bean; piper longtum}
84FE CJK UNIFIED IDEOGRAPH-#84FE, IRGKangXi=1053.050, RSKangXi=140.11
84FF CJK UNIFIED IDEOGRAPH-#84FF, IRGKangXi=1053.060, RSKangXi=140.11, Def{clover, lucerne}
8500 CJK UNIFIED IDEOGRAPH-#8500, IRGKangXi=1053.070, RSKangXi=140.11, Def{screen}
8501 CJK UNIFIED IDEOGRAPH-#8501, IRGKangXi=1053.100, RSKangXi=140.11
8502 CJK UNIFIED IDEOGRAPH-#8502, IRGKangXi=1053.110, RSKangXi=140.11, Def{basket, hod}
8503 CJK UNIFIED IDEOGRAPH-#8503, IRGKangXi=1053.130, RSKangXi=140.11, Def{(Cant.) roots of plants}
8504 CJK UNIFIED IDEOGRAPH-#8504, IRGKangXi=1053.150, RSKangXi=140.11
8505 CJK UNIFIED IDEOGRAPH-#8505, IRGKangXi=1053.160, RSKangXi=140.11
8506 CJK UNIFIED IDEOGRAPH-#8506, IRGKangXi=1053.190, RSKangXi=140.11, Def{water-chestnut, water caltrop}
8507 CJK UNIFIED IDEOGRAPH-#8507, IRGKangXi=1053.230, RSKangXi=140.11, Def{luxuriant growth; extreme; to reach}
8508 CJK UNIFIED IDEOGRAPH-#8508, IRGKangXi=1053.240, RSKangXi=140.11
8509 CJK UNIFIED IDEOGRAPH-#8509, IRGKangXi=1053.260, RSKangXi=140.11, Def{earth up}
850A CJK UNIFIED IDEOGRAPH-#850A, IRGKangXi=1053.270, RSKangXi=140.11
850B CJK UNIFIED IDEOGRAPH-#850B, IRGKangXi=1053.290, RSKangXi=140.11
850C CJK UNIFIED IDEOGRAPH-#850C, IRGKangXi=1053.320, RSKangXi=140.11, Def{vegetables}
850D CJK UNIFIED IDEOGRAPH-#850D, IRGKangXi=1053.330, RSKangXi=140.11
850E CJK UNIFIED IDEOGRAPH-#850E, IRGKangXi=1053.360, RSKangXi=140.11
850F CJK UNIFIED IDEOGRAPH-#850F, IRGKangXi=1053.370, RSKangXi=140.11
8510 CJK UNIFIED IDEOGRAPH-#8510, IRGKangXi=1054.020, RSKangXi=140.11
8511 CJK UNIFIED IDEOGRAPH-#8511, IRGKangXi=1054.030, RSKangXi=140.11, Def{disdain, disregard; slight}
8512 CJK UNIFIED IDEOGRAPH-#8512, IRGKangXi=1054.050, RSKangXi=140.11
8513 CJK UNIFIED IDEOGRAPH-#8513, IRGKangXi=1054.060, RSKangXi=140.11, Def{creeping plants, tendrils, vines}
8514 CJK UNIFIED IDEOGRAPH-#8514, IRGKangXi=1054.070, RSKangXi=140.11, Def{radish; other root vegetables}
8515 CJK UNIFIED IDEOGRAPH-#8515, IRGKangXi=1054.110, RSKangXi=140.11, Def{peduncle or stem of plants}
8516 CJK UNIFIED IDEOGRAPH-#8516, IRGKangXi=1054.120, RSKangXi=140.11
8517 CJK UNIFIED IDEOGRAPH-#8517, IRGKangXi=1054.160, RSKangXi=140.11, Def{sugar cane}
8518 CJK UNIFIED IDEOGRAPH-#8518, IRGKangXi=1054.170, RSKangXi=140.11, Def{ginseng; huge}
8519 CJK UNIFIED IDEOGRAPH-#8519, IRGKangXi=1054.230, RSKangXi=140.11
851A CJK UNIFIED IDEOGRAPH-#851A, IRGKangXi=1054.270, RSKangXi=140.11, Def{luxuriant, thick; ornamental}
851B CJK UNIFIED IDEOGRAPH-#851B, IRGKangXi=1054.300, RSKangXi=140.11, Def{a small orchid-like plant it bears white flowers a dendrobium}
851C CJK UNIFIED IDEOGRAPH-#851C, IRGKangXi=1054.330, RSKangXi=140.11
851D CJK UNIFIED IDEOGRAPH-#851D, IRGKangXi=1054.340, RSKangXi=140.11
851E CJK UNIFIED IDEOGRAPH-#851E, IRGKangXi=1054.350, RSKangXi=140.11, Def{Artemisia stelleriana}
851F CJK UNIFIED IDEOGRAPH-#851F, IRGKangXi=1054.370, RSKangXi=140.11, Def{frame on which silkworms spin}
8520 CJK UNIFIED IDEOGRAPH-#8520, IRGKangXi=1055.010, RSKangXi=140.11
8521 CJK UNIFIED IDEOGRAPH-#8521, IRGKangXi=1055.030, RSKangXi=140.11, Def{surname; species of tortoise}
8522 CJK UNIFIED IDEOGRAPH-#8522, IRGKangXi=1055.050, RSKangXi=140.11
8523 CJK UNIFIED IDEOGRAPH-#8523, IRGKangXi=1055.060, RSKangXi=140.11, Def{surname; Hydropyrum latifalium}
8524 CJK UNIFIED IDEOGRAPH-#8524, IRGKangXi=1055.090, RSKangXi=140.11
8525 CJK UNIFIED IDEOGRAPH-#8525, IRGKangXi=1055.110, RSKangXi=140.11, Def{scallions, onions, leeks}
8526 CJK UNIFIED IDEOGRAPH-#8526, IRGKangXi=1055.140, RSKangXi=140.11, Def{the convovulvus; parasitic plants such as mistletoe; Ribes ambiguum}
8527 CJK UNIFIED IDEOGRAPH-#8527, IRGKangXi=1055.160, RSKangXi=140.11
8528 CJK UNIFIED IDEOGRAPH-#8528, IRGKangXi=1055.180, RSKangXi=140.11
8529 CJK UNIFIED IDEOGRAPH-#8529, IRGKangXi=1055.190, RSKangXi=140.11
852A CJK UNIFIED IDEOGRAPH-#852A, IRGKangXi=1055.200, RSKangXi=140.11
852B CJK UNIFIED IDEOGRAPH-#852B, IRGKangXi=1055.230, RSKangXi=140.11, Def{withered, faded, decayed; calm}
852C CJK UNIFIED IDEOGRAPH-#852C, IRGKangXi=1055.250, RSKangXi=140.11, Def{vegetables, greens}
852D CJK UNIFIED IDEOGRAPH-#852D, IRGKangXi=1055.260, RSKangXi=140.11, Def{shade, shelter; protect}
852E CJK UNIFIED IDEOGRAPH-#852E, IRGKangXi=1055.270, RSKangXi=140.11
852F CJK UNIFIED IDEOGRAPH-#852F, IRGKangXi=1055.350, RSKangXi=140.11, Def{a variety of artemisia}
8530 CJK UNIFIED IDEOGRAPH-#8530, IRGKangXi=1056.100, RSKangXi=140.11
8531 CJK UNIFIED IDEOGRAPH-#8531, IRGKangXi=1048.090, RSKangXi=140.10
8532 CJK UNIFIED IDEOGRAPH-#8532, IRGKangXi=1056.121, RSKangXi=140.11, Def{nutmeg}
8533 CJK UNIFIED IDEOGRAPH-#8533, IRGKangXi=1056.121, RSKangXi=140.11
8534 CJK UNIFIED IDEOGRAPH-#8534, IRGKangXi=1056.121, RSKangXi=140.11, Def{hemp; sesame; applied to other plants furnishing textile fibres}
8535 CJK UNIFIED IDEOGRAPH-#8535, IRGKangXi=1056.121, RSKangXi=140.11, Def{hide, conceal; hoard, store up}
8536 CJK UNIFIED IDEOGRAPH-#8536, IRGKangXi=1056.121, RSKangXi=140.11
8537 CJK UNIFIED IDEOGRAPH-#8537, IRGKangXi=1056.121, RSKangXi=140.11, Def{rose}
8538 CJK UNIFIED IDEOGRAPH-#8538, IRGKangXi=1056.121, RSKangXi=140.11, Def{counter for plant}
8539 CJK UNIFIED IDEOGRAPH-#8539, IRGKangXi=1056.121, RSKangXi=140.11, Def{wild vine, vitis pentaphylla}
853A CJK UNIFIED IDEOGRAPH-#853A, IRGKangXi=1056.121, RSKangXi=140.11, Def{rush used for making mats; surnam}
853B CJK UNIFIED IDEOGRAPH-#853B, IRGKangXi=1056.121, RSKangXi=140.11, Def{肉豆蔻 nutmeg, 豆蔻 cardamon}
853C CJK UNIFIED IDEOGRAPH-#853C, IRGKangXi=1056.121, RSKangXi=140.11, Def{lush; affable, friendly}
853D CJK UNIFIED IDEOGRAPH-#853D, IRGKangXi=1056.150, RSKangXi=140.12, Def{cover, hide, conceal; shelter}
853E CJK UNIFIED IDEOGRAPH-#853E, IRGKangXi=1056.190, RSKangXi=140.12, Def{kind of bramble}
853F CJK UNIFIED IDEOGRAPH-#853F, IRGKangXi=1056.220, RSKangXi=140.12, Def{surname; place name}
8540 CJK UNIFIED IDEOGRAPH-#8540, IRGKangXi=1056.250, RSKangXi=140.12
8541 CJK UNIFIED IDEOGRAPH-#8541, IRGKangXi=1056.260, RSKangXi=140.12, Def{nettle}
8542 CJK UNIFIED IDEOGRAPH-#8542, IRGKangXi=1056.310, RSKangXi=140.12, Def{sesame}
8543 CJK UNIFIED IDEOGRAPH-#8543, IRGKangXi=1056.330, RSKangXi=140.12, Def{foreign things}
8544 CJK UNIFIED IDEOGRAPH-#8544, IRGKangXi=1056.430, RSKangXi=140.12
8545 CJK UNIFIED IDEOGRAPH-#8545, IRGKangXi=1057.020, RSKangXi=140.12
8546 CJK UNIFIED IDEOGRAPH-#8546, IRGKangXi=1057.060, RSKangXi=140.12, Def{finish, complete; solve; complete}
8547 CJK UNIFIED IDEOGRAPH-#8547, IRGKangXi=1057.080, RSKangXi=140.12
8548 CJK UNIFIED IDEOGRAPH-#8548, IRGKangXi=1057.090, RSKangXi=140.12, Def{mushrooms, fungus; mildew, mold}
8549 CJK UNIFIED IDEOGRAPH-#8549, IRGKangXi=1057.180, RSKangXi=140.12, Def{banana; plantain}
854A CJK UNIFIED IDEOGRAPH-#854A, IRGKangXi=1057.200, RSKangXi=140.12, Def{unopened flowers, flower buds}
854B CJK UNIFIED IDEOGRAPH-#854B, IRGKangXi=1057.210, RSKangXi=140.12, Def{unopened flowers, flower buds}
854C CJK UNIFIED IDEOGRAPH-#854C, IRGKangXi=1057.220, RSKangXi=140.12
854D CJK UNIFIED IDEOGRAPH-#854D, IRGKangXi=1057.240, RSKangXi=140.12
854E CJK UNIFIED IDEOGRAPH-#854E, IRGKangXi=1057.270, RSKangXi=140.12, Def{buckwheat}
854F CJK UNIFIED IDEOGRAPH-#854F, IRGKangXi=1057.300, RSKangXi=140.12
8550 CJK UNIFIED IDEOGRAPH-#8550, IRGKangXi=1057.330, RSKangXi=140.12, Def{splendor, glory; China}
8551 CJK UNIFIED IDEOGRAPH-#8551, IRGKangXi=1057.350, RSKangXi=140.12, Def{valeriana villosa, climbing plant}
8552 CJK UNIFIED IDEOGRAPH-#8552, IRGKangXi=1057.360, RSKangXi=140.12, Def{a plant name}
8553 CJK UNIFIED IDEOGRAPH-#8553, IRGKangXi=1057.390, RSKangXi=140.12, Def{rue, an herb used keep insects away}
8554 CJK UNIFIED IDEOGRAPH-#8554, IRGKangXi=1057.410, RSKangXi=140.12
8555 CJK UNIFIED IDEOGRAPH-#8555, IRGKangXi=1057.420, RSKangXi=140.12, Def{caryopteris divaricata}
8556 CJK UNIFIED IDEOGRAPH-#8556, IRGKangXi=1057.430, RSKangXi=140.12
8557 CJK UNIFIED IDEOGRAPH-#8557, IRGKangXi=1058.020, RSKangXi=140.12, Def{leucacene}
8558 CJK UNIFIED IDEOGRAPH-#8558, IRGKangXi=1058.030, RSKangXi=140.12, Def{fuel, firewood; stubble}
8559 CJK UNIFIED IDEOGRAPH-#8559, IRGKangXi=1058.060, RSKangXi=140.12, Def{species of fragrant orchid}
855A CJK UNIFIED IDEOGRAPH-#855A, IRGKangXi=1058.080, RSKangXi=140.12, Def{the calyx of a flower; younger brother}
855B CJK UNIFIED IDEOGRAPH-#855B, IRGKangXi=1058.100, RSKangXi=140.12
855C CJK UNIFIED IDEOGRAPH-#855C, IRGKangXi=1058.130, RSKangXi=140.12
855D CJK UNIFIED IDEOGRAPH-#855D, IRGKangXi=1058.140, RSKangXi=140.12, Def{handful}
855E CJK UNIFIED IDEOGRAPH-#855E, IRGKangXi=1058.150, RSKangXi=140.12, Def{little, small, tiny; petty}
855F CJK UNIFIED IDEOGRAPH-#855F, IRGKangXi=1058.160, RSKangXi=140.12
8560 CJK UNIFIED IDEOGRAPH-#8560, IRGKangXi=1058.190, RSKangXi=140.12
8561 CJK UNIFIED IDEOGRAPH-#8561, IRGKangXi=1058.250, RSKangXi=140.12, Def{hemp seeds; plant with abundant}
8562 CJK UNIFIED IDEOGRAPH-#8562, IRGKangXi=1058.280, RSKangXi=140.12, Def{edible amaranth; straw basket}
8563 CJK UNIFIED IDEOGRAPH-#8563, IRGKangXi=1058.310, RSKangXi=140.12, Def{hibiscus}
8564 CJK UNIFIED IDEOGRAPH-#8564, IRGKangXi=1058.350, RSKangXi=140.12, Def{drooping leaves; fringe soft, delicate}
8565 CJK UNIFIED IDEOGRAPH-#8565, IRGKangXi=1058.360, RSKangXi=140.12
8566 CJK UNIFIED IDEOGRAPH-#8566, IRGKangXi=1058.370, RSKangXi=140.12
8567 CJK UNIFIED IDEOGRAPH-#8567, IRGKangXi=1058.390, RSKangXi=140.12
8568 CJK UNIFIED IDEOGRAPH-#8568, IRGKangXi=1058.410, RSKangXi=140.12, Def{pteris aquilina, common bracken}
8569 CJK UNIFIED IDEOGRAPH-#8569, IRGKangXi=1058.420, RSKangXi=140.12, Def{pond, pool; wash away, cleanse}
856A CJK UNIFIED IDEOGRAPH-#856A, IRGKangXi=1059.020, RSKangXi=140.12, Def{luxurious growth of weeds}
856B CJK UNIFIED IDEOGRAPH-#856B, IRGKangXi=1059.060, RSKangXi=140.12
856C CJK UNIFIED IDEOGRAPH-#856C, IRGKangXi=1059.080, RSKangXi=140.12
856D CJK UNIFIED IDEOGRAPH-#856D, IRGKangXi=1059.100, RSKangXi=140.12, Def{common artemisia; sighing of wind; mournful; dejected}
856E CJK UNIFIED IDEOGRAPH-#856E, IRGKangXi=1059.110, RSKangXi=140.12
856F CJK UNIFIED IDEOGRAPH-#856F, IRGKangXi=1059.250, RSKangXi=140.12
8570 CJK UNIFIED IDEOGRAPH-#8570, IRGKangXi=1059.291, RSKangXi=140.12, Def{the hippuris or mare's tail plant}
8571 CJK UNIFIED IDEOGRAPH-#8571, IRGKangXi=1059.291, RSKangXi=140.12
8572 CJK UNIFIED IDEOGRAPH-#8572, IRGKangXi=1059.291, RSKangXi=140.12, Def{variety of artemisia seek}
8573 CJK UNIFIED IDEOGRAPH-#8573, IRGKangXi=1059.291, RSKangXi=140.12, Def{agueweed}
8574 CJK UNIFIED IDEOGRAPH-#8574, IRGKangXi=1059.291, RSKangXi=140.14, Def{to collect, gather, store; profound}
8575 CJK UNIFIED IDEOGRAPH-#8575, IRGKangXi=1059.291, RSKangXi=140.12
8576 CJK UNIFIED IDEOGRAPH-#8576, IRGKangXi=1059.330, RSKangXi=140.13
8577 CJK UNIFIED IDEOGRAPH-#8577, IRGKangXi=1059.340, RSKangXi=140.13, Def{yam}
8578 CJK UNIFIED IDEOGRAPH-#8578, IRGKangXi=1059.350, RSKangXi=140.13, Def{water lily's leaf}
8579 CJK UNIFIED IDEOGRAPH-#8579, IRGKangXi=1059.380, RSKangXi=140.13, Def{Ipomoea aquatica used as a vegetable}
857A CJK UNIFIED IDEOGRAPH-#857A, IRGKangXi=1059.400, RSKangXi=140.13
857B CJK UNIFIED IDEOGRAPH-#857B, IRGKangXi=1059.410, RSKangXi=140.13
857C CJK UNIFIED IDEOGRAPH-#857C, IRGKangXi=1059.430, RSKangXi=140.13
857D CJK UNIFIED IDEOGRAPH-#857D, IRGKangXi=1059.450, RSKangXi=140.13
857E CJK UNIFIED IDEOGRAPH-#857E, IRGKangXi=1059.480, RSKangXi=140.13, Def{buds, unopened flowers}
857F CJK UNIFIED IDEOGRAPH-#857F, IRGKangXi=1059.510, RSKangXi=140.13
8580 CJK UNIFIED IDEOGRAPH-#8580, IRGKangXi=1059.520, RSKangXi=140.13, Def{the hippuris or mare's tail plant}
8581 CJK UNIFIED IDEOGRAPH-#8581, IRGKangXi=1060.010, RSKangXi=140.13, Def{vine}
8582 CJK UNIFIED IDEOGRAPH-#8582, IRGKangXi=1060.040, RSKangXi=140.13
8583 CJK UNIFIED IDEOGRAPH-#8583, IRGKangXi=1060.070, RSKangXi=140.13
8584 CJK UNIFIED IDEOGRAPH-#8584, IRGKangXi=1060.120, RSKangXi=140.13, Def{thin, slight, weak; poor, stingy}
8585 CJK UNIFIED IDEOGRAPH-#8585, IRGKangXi=1060.140, RSKangXi=140.13, Def{to weed; to eradicate}
8586 CJK UNIFIED IDEOGRAPH-#8586, IRGKangXi=1060.160, RSKangXi=140.13, Def{to cover; to hide; to conceal}
8587 CJK UNIFIED IDEOGRAPH-#8587, IRGKangXi=1060.210, RSKangXi=140.13, Def{Osmunda regalis, a species of fern}
8588 CJK UNIFIED IDEOGRAPH-#8588, IRGKangXi=1060.220, RSKangXi=140.13, Def{luxuriant, flourishing, abundant}
8589 CJK UNIFIED IDEOGRAPH-#8589, IRGKangXi=1060.230, RSKangXi=140.13, Def{dirty, unclean; immoral, obscene}
858A CJK UNIFIED IDEOGRAPH-#858A, IRGKangXi=1060.240, RSKangXi=140.13, Def{circium, thistles; surname}
858B CJK UNIFIED IDEOGRAPH-#858B, IRGKangXi=1060.280, RSKangXi=140.13
858C CJK UNIFIED IDEOGRAPH-#858C, IRGKangXi=1060.290, RSKangXi=140.13, Def{fragrant smell of grain; aromatic}
858D CJK UNIFIED IDEOGRAPH-#858D, IRGKangXi=1060.310, RSKangXi=140.13
858E CJK UNIFIED IDEOGRAPH-#858E, IRGKangXi=1061.030, RSKangXi=140.13
858F CJK UNIFIED IDEOGRAPH-#858F, IRGKangXi=1061.040, RSKangXi=140.13, Def{seed of job's tears; lotus seed}
8590 CJK UNIFIED IDEOGRAPH-#8590, IRGKangXi=1061.070, RSKangXi=140.13, Def{spinach}
8591 CJK UNIFIED IDEOGRAPH-#8591, IRGKangXi=1061.090, RSKangXi=140.13, Def{ginger}
8592 CJK UNIFIED IDEOGRAPH-#8592, IRGKangXi=1061.100, RSKangXi=140.13
8593 CJK UNIFIED IDEOGRAPH-#8593, IRGKangXi=1061.110, RSKangXi=140.13, Def{ginseng}
8594 CJK UNIFIED IDEOGRAPH-#8594, IRGKangXi=1061.120, RSKangXi=140.13, Def{rose}
8595 CJK UNIFIED IDEOGRAPH-#8595, IRGKangXi=1061.130, RSKangXi=140.13
8596 CJK UNIFIED IDEOGRAPH-#8596, IRGKangXi=1061.150, RSKangXi=140.13, Def{empty, hungry-looking}
8597 CJK UNIFIED IDEOGRAPH-#8597, IRGKangXi=1061.180, RSKangXi=140.13, Def{garden; park, orchard}
8598 CJK UNIFIED IDEOGRAPH-#8598, IRGKangXi=1061.190, RSKangXi=140.13, Def{plantago major}
8599 CJK UNIFIED IDEOGRAPH-#8599, IRGKangXi=1061.200, RSKangXi=140.13, Def{weed; shave}
859A CJK UNIFIED IDEOGRAPH-#859A, IRGKangXi=1061.210, RSKangXi=140.13
859B CJK UNIFIED IDEOGRAPH-#859B, IRGKangXi=1061.220, RSKangXi=140.13, Def{kind of marsh grass; feudal state}
859C CJK UNIFIED IDEOGRAPH-#859C, IRGKangXi=1061.240, RSKangXi=140.13, Def{evergreen shrubs, ligusticum}
859D CJK UNIFIED IDEOGRAPH-#859D, IRGKangXi=1061.260, RSKangXi=140.13
859E CJK UNIFIED IDEOGRAPH-#859E, IRGKangXi=1061.280, RSKangXi=140.13
859F CJK UNIFIED IDEOGRAPH-#859F, IRGKangXi=1061.300, RSKangXi=140.13, Def{vine}
85A0 CJK UNIFIED IDEOGRAPH-#85A0, IRGKangXi=1061.310, RSKangXi=140.13
85A1 CJK UNIFIED IDEOGRAPH-#85A1, IRGKangXi=1059.291, RSKangXi=140.13
85A2 CJK UNIFIED IDEOGRAPH-#85A2, IRGKangXi=1061.380, RSKangXi=140.13, Def{woody climbing plant}
85A3 CJK UNIFIED IDEOGRAPH-#85A3, IRGKangXi=1061.390, RSKangXi=140.13
85A4 CJK UNIFIED IDEOGRAPH-#85A4, IRGKangXi=1061.400, RSKangXi=140.13, Def{allium bakeri; shallots, scallion}
85A5 CJK UNIFIED IDEOGRAPH-#85A5, IRGKangXi=1062.010, RSKangXi=140.13
85A6 CJK UNIFIED IDEOGRAPH-#85A6, IRGKangXi=1062.020, RSKangXi=140.13, Def{offer, present; recommend}
85A7 CJK UNIFIED IDEOGRAPH-#85A7, IRGKangXi=1062.060, RSKangXi=140.13, Def{dried food}
85A8 CJK UNIFIED IDEOGRAPH-#85A8, IRGKangXi=1062.070, RSKangXi=140.13, Def{death of prince; swarming}
85A9 CJK UNIFIED IDEOGRAPH-#85A9, IRGKangXi=1062.080, RSKangXi=140.14, Def{transliteration of 'sat' in 'bodhisattva,' etc.}
85AA CJK UNIFIED IDEOGRAPH-#85AA, IRGKangXi=1062.090, RSKangXi=140.13, Def{fuel, firewood; salary}
85AB CJK UNIFIED IDEOGRAPH-#85AB, IRGKangXi=1062.441, RSKangXi=140.13, Def{a medicinal herb; to cauterize}
85AC CJK UNIFIED IDEOGRAPH-#85AC, IRGKangXi=1062.441, RSKangXi=140.13, Def{drugs, pharmaceuticals, medicine}
85AD CJK UNIFIED IDEOGRAPH-#85AD, IRGKangXi=1062.441, RSKangXi=140.14
85AE CJK UNIFIED IDEOGRAPH-#85AE, IRGKangXi=1062.441, RSKangXi=140.13, Def{marsh, swamp; wild country}
85AF CJK UNIFIED IDEOGRAPH-#85AF, IRGKangXi=1062.450, RSKangXi=140.14, Def{yam, tuber, potato}
85B0 CJK UNIFIED IDEOGRAPH-#85B0, IRGKangXi=1062.460, RSKangXi=140.14, Def{a medicinal herb; to cauterize}
85B1 CJK UNIFIED IDEOGRAPH-#85B1, IRGKangXi=1062.470, RSKangXi=140.14
85B2 CJK UNIFIED IDEOGRAPH-#85B2, IRGKangXi=1062.480, RSKangXi=140.14
85B3 CJK UNIFIED IDEOGRAPH-#85B3, IRGKangXi=1062.490, RSKangXi=140.14, Def{name of a herb; surname; (Cant.) a plant stem}
85B4 CJK UNIFIED IDEOGRAPH-#85B4, IRGKangXi=1062.500, RSKangXi=140.14, Def{China grass, ramie (Boehmeria nivea)}
85B5 CJK UNIFIED IDEOGRAPH-#85B5, IRGKangXi=1062.510, RSKangXi=140.14
85B6 CJK UNIFIED IDEOGRAPH-#85B6, IRGKangXi=1062.520, RSKangXi=140.14, Def{to bury, to stop up; dirty, filthy}
85B7 CJK UNIFIED IDEOGRAPH-#85B7, IRGKangXi=1063.020, RSKangXi=140.14
85B8 CJK UNIFIED IDEOGRAPH-#85B8, IRGKangXi=1063.030, RSKangXi=140.14, Def{duckweed}
85B9 CJK UNIFIED IDEOGRAPH-#85B9, IRGKangXi=1063.040, RSKangXi=140.14, Def{cyperus rotundus, type of sedge}
85BA CJK UNIFIED IDEOGRAPH-#85BA, IRGKangXi=1063.080, RSKangXi=140.14, Def{water-chestnuts; caltrop}
85BB CJK UNIFIED IDEOGRAPH-#85BB, IRGKangXi=1063.100, RSKangXi=140.14
85BC CJK UNIFIED IDEOGRAPH-#85BC, IRGKangXi=1063.120, RSKangXi=140.14
85BD CJK UNIFIED IDEOGRAPH-#85BD, IRGKangXi=1063.140, RSKangXi=140.14, Def{a bright blue orchid that grows in south China}
85BE CJK UNIFIED IDEOGRAPH-#85BE, IRGKangXi=1063.180, RSKangXi=140.14, Def{luxuriant growth of flower}
85BF CJK UNIFIED IDEOGRAPH-#85BF, IRGKangXi=1063.190, RSKangXi=140.14, Def{flower}
85C0 CJK UNIFIED IDEOGRAPH-#85C0, IRGKangXi=1063.210, RSKangXi=140.14
85C1 CJK UNIFIED IDEOGRAPH-#85C1, IRGKangXi=1063.220, RSKangXi=140.14, Def{straw, hay; dry, withered}
85C2 CJK UNIFIED IDEOGRAPH-#85C2, IRGKangXi=1063.240, RSKangXi=140.14
85C3 CJK UNIFIED IDEOGRAPH-#85C3, IRGKangXi=1063.280, RSKangXi=140.14
85C4 CJK UNIFIED IDEOGRAPH-#85C4, IRGKangXi=1063.310, RSKangXi=140.14, Def{edible fern}
85C5 CJK UNIFIED IDEOGRAPH-#85C5, IRGKangXi=1063.320, RSKangXi=140.14
85C6 CJK UNIFIED IDEOGRAPH-#85C6, IRGKangXi=1063.330, RSKangXi=140.14
85C7 CJK UNIFIED IDEOGRAPH-#85C7, IRGKangXi=1063.340, RSKangXi=140.14, Def{fine}
85C8 CJK UNIFIED IDEOGRAPH-#85C8, IRGKangXi=1063.360, RSKangXi=140.14
85C9 CJK UNIFIED IDEOGRAPH-#85C9, IRGKangXi=1063.420, RSKangXi=140.14, Def{mat, pad; rely on; pretext}
85CA CJK UNIFIED IDEOGRAPH-#85CA, IRGKangXi=1064.040, RSKangXi=140.14, Def{a kind of bean with flat pods}
85CB CJK UNIFIED IDEOGRAPH-#85CB, IRGKangXi=1064.060, RSKangXi=140.14
85CC CJK UNIFIED IDEOGRAPH-#85CC, IRGKangXi=1064.150, RSKangXi=140.14
85CD CJK UNIFIED IDEOGRAPH-#85CD, IRGKangXi=1064.160, RSKangXi=140.14, Def{blue; indigo plant; surname}
85CE CJK UNIFIED IDEOGRAPH-#85CE, IRGKangXi=1064.200, RSKangXi=140.14, Def{a kind of weed; faithfulness}
85CF CJK UNIFIED IDEOGRAPH-#85CF, IRGKangXi=1064.220, RSKangXi=140.14, Def{hide, conceal; hoard, store up}
85D0 CJK UNIFIED IDEOGRAPH-#85D0, IRGKangXi=1064.260, RSKangXi=140.14, Def{disregard, slight, disdain}
85D1 CJK UNIFIED IDEOGRAPH-#85D1, IRGKangXi=1064.270, RSKangXi=140.14
85D2 CJK UNIFIED IDEOGRAPH-#85D2, IRGKangXi=1064.290, RSKangXi=140.14
85D3 CJK UNIFIED IDEOGRAPH-#85D3, IRGKangXi=1064.421, RSKangXi=140.14, Def{moss, lichen}
85D4 CJK UNIFIED IDEOGRAPH-#85D4, IRGKangXi=1064.421, RSKangXi=140.15
85D5 CJK UNIFIED IDEOGRAPH-#85D5, IRGKangXi=1065.020, RSKangXi=140.15, Def{lotus root}
85D6 CJK UNIFIED IDEOGRAPH-#85D6, IRGKangXi=1065.060, RSKangXi=140.15
85D7 CJK UNIFIED IDEOGRAPH-#85D7, IRGKangXi=1065.160, RSKangXi=140.15
85D8 CJK UNIFIED IDEOGRAPH-#85D8, IRGKangXi=1065.170, RSKangXi=140.15, Def{madder}
85D9 CJK UNIFIED IDEOGRAPH-#85D9, IRGKangXi=1065.210, RSKangXi=140.15, Def{dogwood}
85DA CJK UNIFIED IDEOGRAPH-#85DA, IRGKangXi=1065.250, RSKangXi=140.15, Def{water plant}
85DB CJK UNIFIED IDEOGRAPH-#85DB, IRGKangXi=1065.270, RSKangXi=140.15
85DC CJK UNIFIED IDEOGRAPH-#85DC, IRGKangXi=1065.300, RSKangXi=140.15, Def{Chenopodium album, pigweed}
85DD CJK UNIFIED IDEOGRAPH-#85DD, IRGKangXi=1065.340, RSKangXi=140.15, Def{art; talent, ability; craft}
85DE CJK UNIFIED IDEOGRAPH-#85DE, IRGKangXi=1065.390, RSKangXi=140.15
85DF CJK UNIFIED IDEOGRAPH-#85DF, IRGKangXi=1065.400, RSKangXi=140.15, Def{vine, creeper; to wind}
85E0 CJK UNIFIED IDEOGRAPH-#85E0, IRGKangXi=1065.410, RSKangXi=140.15
85E1 CJK UNIFIED IDEOGRAPH-#85E1, IRGKangXi=1065.420, RSKangXi=140.15
85E2 CJK UNIFIED IDEOGRAPH-#85E2, IRGKangXi=1065.440, RSKangXi=140.15
85E3 CJK UNIFIED IDEOGRAPH-#85E3, IRGKangXi=1065.450, RSKangXi=140.15
85E4 CJK UNIFIED IDEOGRAPH-#85E4, IRGKangXi=1065.460, RSKangXi=140.15, Def{rattan, cane; creeper plant}
85E5 CJK UNIFIED IDEOGRAPH-#85E5, IRGKangXi=1065.470, RSKangXi=140.15, Def{drugs, pharmaceuticals, medicine}
85E6 CJK UNIFIED IDEOGRAPH-#85E6, IRGKangXi=1066.010, RSKangXi=140.15, Def{edible mushrooms}
85E7 CJK UNIFIED IDEOGRAPH-#85E7, IRGKangXi=1066.020, RSKangXi=140.15
85E8 CJK UNIFIED IDEOGRAPH-#85E8, IRGKangXi=1066.030, RSKangXi=140.15
85E9 CJK UNIFIED IDEOGRAPH-#85E9, IRGKangXi=1066.050, RSKangXi=140.15, Def{fence; boundary; outlying border}
85EA CJK UNIFIED IDEOGRAPH-#85EA, IRGKangXi=1066.070, RSKangXi=140.15, Def{marsh, swamp; wild country; clump of trees or bushes}
85EB CJK UNIFIED IDEOGRAPH-#85EB, IRGKangXi=1066.080, RSKangXi=140.15
85EC CJK UNIFIED IDEOGRAPH-#85EC, IRGKangXi=1066.090, RSKangXi=140.15
85ED CJK UNIFIED IDEOGRAPH-#85ED, IRGKangXi=1066.110, RSKangXi=140.15
85EE CJK UNIFIED IDEOGRAPH-#85EE, IRGKangXi=1066.130, RSKangXi=140.16
85EF CJK UNIFIED IDEOGRAPH-#85EF, IRGKangXi=1066.140, RSKangXi=140.15
85F0 CJK UNIFIED IDEOGRAPH-#85F0, IRGKangXi=1066.150, RSKangXi=140.15
85F1 CJK UNIFIED IDEOGRAPH-#85F1, IRGKangXi=1066.200, RSKangXi=140.15
85F2 CJK UNIFIED IDEOGRAPH-#85F2, IRGKangXi=1066.371, RSKangXi=140.15
85F3 CJK UNIFIED IDEOGRAPH-#85F3, IRGKangXi=1066.371, RSKangXi=140.15
85F4 CJK UNIFIED IDEOGRAPH-#85F4, IRGKangXi=1066.371, RSKangXi=140.15, Def{collect}
85F5 CJK UNIFIED IDEOGRAPH-#85F5, IRGKangXi=1066.371, RSKangXi=140.15
85F6 CJK UNIFIED IDEOGRAPH-#85F6, IRGKangXi=1066.400, RSKangXi=140.16, Def{a kind of plant}
85F7 CJK UNIFIED IDEOGRAPH-#85F7, IRGKangXi=1067.010, RSKangXi=140.16, Def{yam, tuber, potato}
85F8 CJK UNIFIED IDEOGRAPH-#85F8, IRGKangXi=1067.020, RSKangXi=140.16
85F9 CJK UNIFIED IDEOGRAPH-#85F9, IRGKangXi=1067.070, RSKangXi=140.16, Def{lush; affable, friendly}
85FA CJK UNIFIED IDEOGRAPH-#85FA, IRGKangXi=1067.090, RSKangXi=140.16, Def{rush used in making mats; surname}
85FB CJK UNIFIED IDEOGRAPH-#85FB, IRGKangXi=1067.110, RSKangXi=140.16, Def{splendid, magnificent; algae}
85FC CJK UNIFIED IDEOGRAPH-#85FC, IRGKangXi=1067.120, RSKangXi=140.16
85FD CJK UNIFIED IDEOGRAPH-#85FD, IRGKangXi=1067.140, RSKangXi=140.16
85FE CJK UNIFIED IDEOGRAPH-#85FE, IRGKangXi=1067.150, RSKangXi=140.16, Def{shade}
85FF CJK UNIFIED IDEOGRAPH-#85FF, IRGKangXi=1067.160, RSKangXi=140.16, Def{lophanthus rugosus, betony}
8600 CJK UNIFIED IDEOGRAPH-#8600, IRGKangXi=1067.180, RSKangXi=140.16, Def{falling leaves and barks}
8601 CJK UNIFIED IDEOGRAPH-#8601, IRGKangXi=1067.190, RSKangXi=140.16
8602 CJK UNIFIED IDEOGRAPH-#8602, IRGKangXi=1067.200, RSKangXi=140.16, Def{stamen or pistil}
8603 CJK UNIFIED IDEOGRAPH-#8603, IRGKangXi=1067.210, RSKangXi=140.16
8604 CJK UNIFIED IDEOGRAPH-#8604, IRGKangXi=1067.270, RSKangXi=140.16, Def{variety of artemisia seek}
8605 CJK UNIFIED IDEOGRAPH-#8605, IRGKangXi=1068.020, RSKangXi=140.16, Def{a fragrant plant the root is medicinal}
8606 CJK UNIFIED IDEOGRAPH-#8606, IRGKangXi=1068.050, RSKangXi=140.16, Def{rushes, reeds}
8607 CJK UNIFIED IDEOGRAPH-#8607, IRGKangXi=1068.070, RSKangXi=140.16, Def{revive, resurrect; a species of thyme; transliteration of 'Soviet'}
8608 CJK UNIFIED IDEOGRAPH-#8608, IRGKangXi=1068.090
8609 CJK UNIFIED IDEOGRAPH-#8609, IRGKangXi=1068.130, RSKangXi=140.16
860A CJK UNIFIED IDEOGRAPH-#860A, IRGKangXi=1068.140, RSKangXi=140.16, Def{collect, gather, store; profound; (Budd.) skandha}
860B CJK UNIFIED IDEOGRAPH-#860B, IRGKangXi=1068.150, RSKangXi=140.16, Def{apple}
860C CJK UNIFIED IDEOGRAPH-#860C, IRGKangXi=1068.180, RSKangXi=140.16
860D CJK UNIFIED IDEOGRAPH-#860D, IRGKangXi=1068.360, RSKangXi=140.16
860E CJK UNIFIED IDEOGRAPH-#860E, IRGKangXi=1068.430, RSKangXi=140.16
860F CJK UNIFIED IDEOGRAPH-#860F, IRGKangXi=1069.050, RSKangXi=140.16
8610 CJK UNIFIED IDEOGRAPH-#8610, IRGKangXi=1069.061, RSKangXi=140.16
8611 CJK UNIFIED IDEOGRAPH-#8611, IRGKangXi=1069.061, RSKangXi=140.16, Def{type of edible mushroom}
8612 CJK UNIFIED IDEOGRAPH-#8612, IRGKangXi=1069.061, RSKangXi=140.17, Def{265:143}
8613 CJK UNIFIED IDEOGRAPH-#8613, IRGKangXi=1069.061, RSKangXi=140.16, Def{thyme; revive, resurrect; soviet}
8614 CJK UNIFIED IDEOGRAPH-#8614, IRGKangXi=1069.061, RSKangXi=140.16
8615 CJK UNIFIED IDEOGRAPH-#8615, IRGKangXi=1070.321, RSKangXi=140.17
8616 CJK UNIFIED IDEOGRAPH-#8616, IRGKangXi=1069.070, RSKangXi=140.17, Def{stump, sprout}
8617 CJK UNIFIED IDEOGRAPH-#8617, IRGKangXi=1069.080, RSKangXi=140.17, Def{stump, sprout}
8618 CJK UNIFIED IDEOGRAPH-#8618, IRGKangXi=1069.090, RSKangXi=140.17, Def{a kind of wild ginger}
8619 CJK UNIFIED IDEOGRAPH-#8619, IRGKangXi=1069.120, RSKangXi=140.17
861A CJK UNIFIED IDEOGRAPH-#861A, IRGKangXi=1069.130, RSKangXi=140.17, Def{moss, lichen}
861B CJK UNIFIED IDEOGRAPH-#861B, IRGKangXi=1069.150, RSKangXi=140.17
861C CJK UNIFIED IDEOGRAPH-#861C, IRGKangXi=1069.170, RSKangXi=140.17
861D CJK UNIFIED IDEOGRAPH-#861D, IRGKangXi=1069.190, RSKangXi=140.17
861E CJK UNIFIED IDEOGRAPH-#861E, IRGKangXi=1069.200, RSKangXi=140.17, Def{wild vine, vitis pentaphylla}
861F CJK UNIFIED IDEOGRAPH-#861F, IRGKangXi=1069.230, RSKangXi=140.17
8620 CJK UNIFIED IDEOGRAPH-#8620, IRGKangXi=1069.240, RSKangXi=140.17
8621 CJK UNIFIED IDEOGRAPH-#8621, IRGKangXi=1069.250, RSKangXi=140.17
8622 CJK UNIFIED IDEOGRAPH-#8622, IRGKangXi=1069.280, RSKangXi=140.16, Def{tall grass; water-weeds}
8623 CJK UNIFIED IDEOGRAPH-#8623, IRGKangXi=1069.320, RSKangXi=140.17
8624 CJK UNIFIED IDEOGRAPH-#8624, IRGKangXi=1069.330, RSKangXi=140.14, Def{flower, blossoms}
8625 CJK UNIFIED IDEOGRAPH-#8625, IRGKangXi=1069.360, RSKangXi=140.17
8626 CJK UNIFIED IDEOGRAPH-#8626, IRGKangXi=1069.390, RSKangXi=140.17
8627 CJK UNIFIED IDEOGRAPH-#8627, IRGKangXi=1069.400, RSKangXi=140.17, Def{a plant which resembles wheat but has no edible grain}
8628 CJK UNIFIED IDEOGRAPH-#8628, IRGKangXi=1070.020, Def{luxuriant vegetation}
8629 CJK UNIFIED IDEOGRAPH-#8629, IRGKangXi=1070.030, RSKangXi=140.17, Def{Artemisia stellariana}
862A CJK UNIFIED IDEOGRAPH-#862A, IRGKangXi=1070.060, RSKangXi=140.17
862B CJK UNIFIED IDEOGRAPH-#862B, IRGKangXi=1070.070, RSKangXi=140.17
862C CJK UNIFIED IDEOGRAPH-#862C, IRGKangXi=1070.080, RSKangXi=140.17
862D CJK UNIFIED IDEOGRAPH-#862D, IRGKangXi=1070.110, RSKangXi=140.17, Def{orchid; elegant, graceful}
862E CJK UNIFIED IDEOGRAPH-#862E, IRGKangXi=1070.120, RSKangXi=140.17
862F CJK UNIFIED IDEOGRAPH-#862F, IRGKangXi=1070.240, RSKangXi=108.16, Def{to toss about; to swing; to rock}
8630 CJK UNIFIED IDEOGRAPH-#8630, IRGKangXi=1070.321, RSKangXi=140.17
8631 CJK UNIFIED IDEOGRAPH-#8631, IRGKangXi=1070.360, RSKangXi=140.19
8632 CJK UNIFIED IDEOGRAPH-#8632, IRGKangXi=1070.370, RSKangXi=140.18
8633 CJK UNIFIED IDEOGRAPH-#8633, IRGKangXi=1070.420, RSKangXi=140.18
8634 CJK UNIFIED IDEOGRAPH-#8634, IRGKangXi=1071.020, RSKangXi=140.18, Def{young shoots of the rapeturnip}
8635 CJK UNIFIED IDEOGRAPH-#8635, IRGKangXi=1071.030, RSKangXi=140.18
8636 CJK UNIFIED IDEOGRAPH-#8636, IRGKangXi=1071.050, RSKangXi=140.18
8637 CJK UNIFIED IDEOGRAPH-#8637, IRGKangXi=1072.071, RSKangXi=140.18, Def{one-legged monster; walrus}
8638 CJK UNIFIED IDEOGRAPH-#8638, IRGKangXi=1071.210, RSKangXi=140.19, Def{dip (a brush); remarry}
8639 CJK UNIFIED IDEOGRAPH-#8639, IRGKangXi=1071.230, RSKangXi=140.19
863A CJK UNIFIED IDEOGRAPH-#863A, IRGKangXi=1071.270, RSKangXi=140.19, Def{gracilaria verrucosa}
863B CJK UNIFIED IDEOGRAPH-#863B, IRGKangXi=1071.280, RSKangXi=140.19
863C CJK UNIFIED IDEOGRAPH-#863C, IRGKangXi=1071.300, RSKangXi=140.19
863D CJK UNIFIED IDEOGRAPH-#863D, IRGKangXi=1071.310, RSKangXi=140.19, Def{a creeper}
863E CJK UNIFIED IDEOGRAPH-#863E, IRGKangXi=1071.340, RSKangXi=140.19
863F CJK UNIFIED IDEOGRAPH-#863F, IRGKangXi=1071.370, RSKangXi=140.19, Def{type of creeping plant; turnip}
8640 CJK UNIFIED IDEOGRAPH-#8640, IRGKangXi=1071.380, RSKangXi=140.19, Def{minced pickles; leeks; mix; salt}
8641 CJK UNIFIED IDEOGRAPH-#8641, IRGKangXi=1071.201, RSKangXi=140.19
8642 CJK UNIFIED IDEOGRAPH-#8642, IRGKangXi=1072.080, RSKangXi=140.20
8643 CJK UNIFIED IDEOGRAPH-#8643, IRGKangXi=1072.120, RSKangXi=140.20
8644 CJK UNIFIED IDEOGRAPH-#8644, IRGKangXi=1072.241, RSKangXi=140.20
8645 CJK UNIFIED IDEOGRAPH-#8645, IRGKangXi=1072.241, RSKangXi=140.20
8646 CJK UNIFIED IDEOGRAPH-#8646, IRGKangXi=1072.250, RSKangXi=140.21, Def{entwine; basket for carrying dirt}
8647 CJK UNIFIED IDEOGRAPH-#8647, IRGKangXi=1072.270, RSKangXi=140.21
8648 CJK UNIFIED IDEOGRAPH-#8648, IRGKangXi=1072.280, RSKangXi=140.21
8649 CJK UNIFIED IDEOGRAPH-#8649, IRGKangXi=1072.290
864A CJK UNIFIED IDEOGRAPH-#864A, IRGKangXi=1072.440, RSKangXi=140.23
864B CJK UNIFIED IDEOGRAPH-#864B, IRGKangXi=1072.560, RSKangXi=140.25, Def{asparagus a variety of red-stalked millet}
864C CJK UNIFIED IDEOGRAPH-#864C, IRGKangXi=1072.580, RSKangXi=140.25
864D CJK UNIFIED IDEOGRAPH-#864D, IRGKangXi=1073.010, RSKangXi=141.0, Def{tiger; KangXi radical 141}
864E CJK UNIFIED IDEOGRAPH-#864E, IRGKangXi=1073.030, RSKangXi=141.2, Def{tiger; brave, fierce; surname}
864F CJK UNIFIED IDEOGRAPH-#864F, IRGKangXi=1073.071, RSKangXi=141.2, Def{to capture, imprison, seize; a prison}
8650 CJK UNIFIED IDEOGRAPH-#8650, IRGKangXi=1073.090, RSKangXi=141.3, Def{cruel, harsh, oppressive}
8651 CJK UNIFIED IDEOGRAPH-#8651, IRGKangXi=1073.130, RSKangXi=61.6, Def{be concerned, worry about}
8652 CJK UNIFIED IDEOGRAPH-#8652, IRGKangXi=1073.140, RSKangXi=141.4, Def{an amphibious beast resembling a tiger with one horn; place name}
8653 CJK UNIFIED IDEOGRAPH-#8653, IRGKangXi=1073.160, RSKangXi=141.4, Def{roar}
8654 CJK UNIFIED IDEOGRAPH-#8654, IRGKangXi=1073.170, RSKangXi=141.4, Def{act with reverence; reverent}
8655 CJK UNIFIED IDEOGRAPH-#8655, IRGKangXi=1073.250, RSKangXi=141.5, Def{place, locale; department}
8656 CJK UNIFIED IDEOGRAPH-#8656, IRGKangXi=1074.010, RSKangXi=141.5, Def{to cry; to shout; to howl}
8657 CJK UNIFIED IDEOGRAPH-#8657, IRGKangXi=1074.020, RSKangXi=141.5
8658 CJK UNIFIED IDEOGRAPH-#8658, IRGKangXi=1074.030, RSKangXi=141.5
8659 CJK UNIFIED IDEOGRAPH-#8659, IRGKangXi=1074.040, RSKangXi=141.5
865A CJK UNIFIED IDEOGRAPH-#865A, IRGKangXi=1074.101, RSKangXi=141.5, Def{false}
865B CJK UNIFIED IDEOGRAPH-#865B, IRGKangXi=1074.110, RSKangXi=141.6, Def{false, worthless; empty, hollow}
865C CJK UNIFIED IDEOGRAPH-#865C, IRGKangXi=1074.130, RSKangXi=141.6, Def{to capture, imprison, seize; a prison}
865D CJK UNIFIED IDEOGRAPH-#865D, IRGKangXi=1074.170, RSKangXi=141.6
865E CJK UNIFIED IDEOGRAPH-#865E, IRGKangXi=1074.240, RSKangXi=141.7, Def{concerned about, anxious, worried}
865F CJK UNIFIED IDEOGRAPH-#865F, IRGKangXi=1074.290, RSKangXi=141.7, Def{mark, sign; symbol; number}
8660 CJK UNIFIED IDEOGRAPH-#8660, IRGKangXi=1075.050, RSKangXi=141.8
8661 CJK UNIFIED IDEOGRAPH-#8661, IRGKangXi=1075.080, RSKangXi=141.8, Def{support structure for bell}
8662 CJK UNIFIED IDEOGRAPH-#8662, IRGKangXi=1075.170, RSKangXi=141.9, Def{name of ancient feudal State in Shenxi and Hunan}
8663 CJK UNIFIED IDEOGRAPH-#8663, IRGKangXi=1075.180, RSKangXi=141.9, Def{cruel, violent, passionate}
8664 CJK UNIFIED IDEOGRAPH-#8664, IRGKangXi=1075.250, RSKangXi=141.10
8665 CJK UNIFIED IDEOGRAPH-#8665, IRGKangXi=1075.310, RSKangXi=141.10
8666 CJK UNIFIED IDEOGRAPH-#8666, IRGKangXi=1075.400, RSKangXi=141.10
8667 CJK UNIFIED IDEOGRAPH-#8667, IRGKangXi=1075.420, RSKangXi=141.11, Def{lose, fail; damage; deficient}
8668 CJK UNIFIED IDEOGRAPH-#8668, IRGKangXi=1075.430, RSKangXi=141.11
8669 CJK UNIFIED IDEOGRAPH-#8669, IRGKangXi=1075.530, RSKangXi=141.12, Def{fright}
866A CJK UNIFIED IDEOGRAPH-#866A, IRGKangXi=1076.170, RSKangXi=141.20
866B CJK UNIFIED IDEOGRAPH-#866B, IRGKangXi=1076.190, RSKangXi=142.0, Def{insects, worms; KangXi radical 142}
866C CJK UNIFIED IDEOGRAPH-#866C, IRGKangXi=1076.200, RSKangXi=142.1, Def{young dragon}
866D CJK UNIFIED IDEOGRAPH-#866D, IRGKangXi=1076.220, RSKangXi=142.2
866E CJK UNIFIED IDEOGRAPH-#866E, IRGKangXi=1076.230, RSKangXi=142.2, Def{louse eggs, nits}
866F CJK UNIFIED IDEOGRAPH-#866F, IRGKangXi=1076.240, RSKangXi=142.2, Def{young dragon}
8670 CJK UNIFIED IDEOGRAPH-#8670, IRGKangXi=1076.250, RSKangXi=142.2
8671 CJK UNIFIED IDEOGRAPH-#8671, IRGKangXi=1076.260, RSKangXi=142.2, Def{louse; bug; parasite}
8672 CJK UNIFIED IDEOGRAPH-#8672, IRGKangXi=1076.291, RSKangXi=142.2
8673 CJK UNIFIED IDEOGRAPH-#8673, IRGKangXi=1076.300, RSKangXi=142.3
8674 CJK UNIFIED IDEOGRAPH-#8674, IRGKangXi=1076.310, RSKangXi=142.3
8675 CJK UNIFIED IDEOGRAPH-#8675, IRGKangXi=1076.320, RSKangXi=142.3
8676 CJK UNIFIED IDEOGRAPH-#8676, IRGKangXi=1076.330, RSKangXi=142.3
8677 CJK UNIFIED IDEOGRAPH-#8677, IRGKangXi=1076.340, RSKangXi=142.3, Def{worm}
8678 CJK UNIFIED IDEOGRAPH-#8678, IRGKangXi=1076.360, RSKangXi=142.3
8679 CJK UNIFIED IDEOGRAPH-#8679, IRGKangXi=1076.400, RSKangXi=142.3, Def{rainbow}
867A CJK UNIFIED IDEOGRAPH-#867A, IRGKangXi=1077.030, RSKangXi=142.3, Def{large poisonous snake}
867B CJK UNIFIED IDEOGRAPH-#867B, IRGKangXi=1077.060, RSKangXi=142.3, Def{horsefly, gadfly}
867C CJK UNIFIED IDEOGRAPH-#867C, IRGKangXi=1077.111, RSKangXi=142.3, Def{a flea; species of beetle}
867D CJK UNIFIED IDEOGRAPH-#867D, IRGKangXi=1077.111, RSKangXi=142.3, Def{although, even if}
867E CJK UNIFIED IDEOGRAPH-#867E, IRGKangXi=1077.111, RSKangXi=142.3, Def{shrimp, prawn}
867F CJK UNIFIED IDEOGRAPH-#867F, IRGKangXi=1077.111, RSKangXi=142.3, Def{a kind of scorpion}
8680 CJK UNIFIED IDEOGRAPH-#8680, IRGKangXi=1077.111, RSKangXi=184.6, Def{nibble away; erode; eclipse}
8681 CJK UNIFIED IDEOGRAPH-#8681, IRGKangXi=1077.111, RSKangXi=142.3, Def{ants}
8682 CJK UNIFIED IDEOGRAPH-#8682, IRGKangXi=1077.111, RSKangXi=142.3, Def{ant; leech}
8683 CJK UNIFIED IDEOGRAPH-#8683, IRGKangXi=1077.111, RSKangXi=142.3
8684 CJK UNIFIED IDEOGRAPH-#8684, IRGKangXi=1077.120, RSKangXi=142.4
8685 CJK UNIFIED IDEOGRAPH-#8685, IRGKangXi=1077.130, RSKangXi=142.4
8686 CJK UNIFIED IDEOGRAPH-#8686, IRGKangXi=1077.140, RSKangXi=142.4
8687 CJK UNIFIED IDEOGRAPH-#8687, IRGKangXi=1077.150, RSKangXi=142.4
8688 CJK UNIFIED IDEOGRAPH-#8688, IRGKangXi=1077.160, RSKangXi=142.6
8689 CJK UNIFIED IDEOGRAPH-#8689, IRGKangXi=1077.170, RSKangXi=142.4, Def{variant of 蚊 U+868A, a mosquito, gnat}
868A CJK UNIFIED IDEOGRAPH-#868A, IRGKangXi=1077.180, RSKangXi=142.4, Def{mosquito; gnat}
868B CJK UNIFIED IDEOGRAPH-#868B, IRGKangXi=1077.200, RSKangXi=142.4, Def{gnat, mosquito}
868C CJK UNIFIED IDEOGRAPH-#868C, IRGKangXi=1077.210, RSKangXi=142.4, Def{oysters, mussels; mother-of-pearl}
868D CJK UNIFIED IDEOGRAPH-#868D, IRGKangXi=1077.220, RSKangXi=142.4, Def{mussels; various shellfish}
868E CJK UNIFIED IDEOGRAPH-#868E, IRGKangXi=1077.240, RSKangXi=142.4
868F CJK UNIFIED IDEOGRAPH-#868F, IRGKangXi=1077.250, RSKangXi=142.4
8690 CJK UNIFIED IDEOGRAPH-#8690, IRGKangXi=1077.270, RSKangXi=142.4
8691 CJK UNIFIED IDEOGRAPH-#8691, IRGKangXi=1077.280, RSKangXi=142.4, Def{tip-toe}
8692 CJK UNIFIED IDEOGRAPH-#8692, IRGKangXi=1077.330, Def{(Cant.) an edible snake, lizard}
8693 CJK UNIFIED IDEOGRAPH-#8693, IRGKangXi=1077.350, RSKangXi=142.4, Def{earthworm}
8694 CJK UNIFIED IDEOGRAPH-#8694, IRGKangXi=1077.360, RSKangXi=142.4, Def{ant eggs}
8695 CJK UNIFIED IDEOGRAPH-#8695, IRGKangXi=1077.380, RSKangXi=142.4, Def{silkworms}
8696 CJK UNIFIED IDEOGRAPH-#8696, IRGKangXi=1077.400, RSKangXi=142.4
8697 CJK UNIFIED IDEOGRAPH-#8697, IRGKangXi=1078.020, RSKangXi=142.4
8698 CJK UNIFIED IDEOGRAPH-#8698, IRGKangXi=1078.030, RSKangXi=142.4, Def{tapeworm}
8699 CJK UNIFIED IDEOGRAPH-#8699, IRGKangXi=1078.050, RSKangXi=142.4
869A CJK UNIFIED IDEOGRAPH-#869A, IRGKangXi=1078.070, RSKangXi=142.4
869B CJK UNIFIED IDEOGRAPH-#869B, IRGKangXi=1078.080, RSKangXi=142.4
869C CJK UNIFIED IDEOGRAPH-#869C, IRGKangXi=1078.090, RSKangXi=142.4, Def{plant louse, aphids}
869D CJK UNIFIED IDEOGRAPH-#869D, IRGKangXi=1078.100, RSKangXi=142.4, Def{hairy and poisonous caterpillars}
869E CJK UNIFIED IDEOGRAPH-#869E, IRGKangXi=1078.120, RSKangXi=142.4
869F CJK UNIFIED IDEOGRAPH-#869F, IRGKangXi=1078.130, RSKangXi=142.4
86A0 CJK UNIFIED IDEOGRAPH-#86A0, IRGKangXi=1078.160, RSKangXi=142.4, Def{person's name}
86A1 CJK UNIFIED IDEOGRAPH-#86A1, IRGKangXi=1078.170, RSKangXi=142.4, Def{mole}
86A2 CJK UNIFIED IDEOGRAPH-#86A2, IRGKangXi=1078.180, RSKangXi=142.4
86A3 CJK UNIFIED IDEOGRAPH-#86A3, IRGKangXi=1078.190, RSKangXi=142.4, Def{centipede}
86A4 CJK UNIFIED IDEOGRAPH-#86A4, IRGKangXi=1078.200, RSKangXi=142.4, Def{flea; louse}
86A5 CJK UNIFIED IDEOGRAPH-#86A5, IRGKangXi=1078.220, RSKangXi=142.4
86A6 CJK UNIFIED IDEOGRAPH-#86A6, IRGKangXi=1078.230, RSKangXi=142.4, Def{a boa constrictor}
86A7 CJK UNIFIED IDEOGRAPH-#86A7, IRGKangXi=1078.250, RSKangXi=142.4, Def{a red spotted lizard, used as medicine}
86A8 CJK UNIFIED IDEOGRAPH-#86A8, IRGKangXi=1078.260, RSKangXi=142.4, Def{a kind of water-beetle cash, then dollars and money generally}
86A9 CJK UNIFIED IDEOGRAPH-#86A9, IRGKangXi=1078.280, RSKangXi=142.4, Def{worm; ignorant, rustic; laugh}
86AA CJK UNIFIED IDEOGRAPH-#86AA, IRGKangXi=1079.010, RSKangXi=142.4, Def{tadpole}
86AB CJK UNIFIED IDEOGRAPH-#86AB, IRGKangXi=1079.090, RSKangXi=142.5, Def{abalone; dried fish; surname}
86AC CJK UNIFIED IDEOGRAPH-#86AC, IRGKangXi=1079.101, RSKangXi=142.4, Def{a variety of bivalves}
86AD CJK UNIFIED IDEOGRAPH-#86AD, IRGKangXi=1079.110, RSKangXi=142.5
86AE CJK UNIFIED IDEOGRAPH-#86AE, IRGKangXi=1079.120, RSKangXi=142.5
86AF CJK UNIFIED IDEOGRAPH-#86AF, IRGKangXi=1079.130, RSKangXi=142.5, Def{earthworm}
86B0 CJK UNIFIED IDEOGRAPH-#86B0, IRGKangXi=1079.150, RSKangXi=142.5, Def{millipede}
86B1 CJK UNIFIED IDEOGRAPH-#86B1, IRGKangXi=1079.160, RSKangXi=142.5, Def{grasshopper; (edible) locust; cicada}
86B2 CJK UNIFIED IDEOGRAPH-#86B2, IRGKangXi=1079.180, RSKangXi=142.5
86B3 CJK UNIFIED IDEOGRAPH-#86B3, IRGKangXi=1079.190, RSKangXi=142.5, Def{ant eggs}
86B4 CJK UNIFIED IDEOGRAPH-#86B4, IRGKangXi=1079.200, RSKangXi=142.5, Def{larva}
86B5 CJK UNIFIED IDEOGRAPH-#86B5, IRGKangXi=1079.210, RSKangXi=142.5, Def{oyster}
86B6 CJK UNIFIED IDEOGRAPH-#86B6, IRGKangXi=1079.220, RSKangXi=142.5, Def{kind of clam, arca inflata}
86B7 CJK UNIFIED IDEOGRAPH-#86B7, IRGKangXi=1079.240, RSKangXi=142.5
86B8 CJK UNIFIED IDEOGRAPH-#86B8, IRGKangXi=1079.250, RSKangXi=142.5
86B9 CJK UNIFIED IDEOGRAPH-#86B9, IRGKangXi=1079.260, RSKangXi=142.5
86BA CJK UNIFIED IDEOGRAPH-#86BA, IRGKangXi=1079.280, RSKangXi=142.5, Def{a boa constrictor}
86BB CJK UNIFIED IDEOGRAPH-#86BB, IRGKangXi=1079.290, RSKangXi=142.5, Def{small species of cicada}
86BC CJK UNIFIED IDEOGRAPH-#86BC, IRGKangXi=1079.300, RSKangXi=142.5
86BD CJK UNIFIED IDEOGRAPH-#86BD, IRGKangXi=1079.350, RSKangXi=142.5
86BE CJK UNIFIED IDEOGRAPH-#86BE, IRGKangXi=1079.360, RSKangXi=142.5
86BF CJK UNIFIED IDEOGRAPH-#86BF, IRGKangXi=1080.030, RSKangXi=142.5, Def{millipede}
86C0 CJK UNIFIED IDEOGRAPH-#86C0, IRGKangXi=1080.040, RSKangXi=142.5, Def{insects that eat books, clothes}
86C1 CJK UNIFIED IDEOGRAPH-#86C1, IRGKangXi=1080.050, RSKangXi=142.5
86C2 CJK UNIFIED IDEOGRAPH-#86C2, IRGKangXi=1080.120, RSKangXi=142.5
86C3 CJK UNIFIED IDEOGRAPH-#86C3, IRGKangXi=1080.140, RSKangXi=142.5
86C4 CJK UNIFIED IDEOGRAPH-#86C4, IRGKangXi=1080.160, RSKangXi=142.5, Def{mole cricket}
86C5 CJK UNIFIED IDEOGRAPH-#86C5, IRGKangXi=1080.170, RSKangXi=142.5, Def{a caterpillar}
86C6 CJK UNIFIED IDEOGRAPH-#86C6, IRGKangXi=1080.190, RSKangXi=142.5, Def{maggots}
86C7 CJK UNIFIED IDEOGRAPH-#86C7, IRGKangXi=1080.200, RSKangXi=142.5, Def{snake}
86C8 CJK UNIFIED IDEOGRAPH-#86C8, IRGKangXi=1080.240, RSKangXi=142.5
86C9 CJK UNIFIED IDEOGRAPH-#86C9, IRGKangXi=1080.250, RSKangXi=142.5, Def{dragonfly, libellulidae}
86CA CJK UNIFIED IDEOGRAPH-#86CA, IRGKangXi=1081.050, RSKangXi=142.5, Def{poison; venom; harm; bewitch}
86CB CJK UNIFIED IDEOGRAPH-#86CB, IRGKangXi=1081.110, RSKangXi=142.5, Def{eggs; term of abuse}
86CC CJK UNIFIED IDEOGRAPH-#86CC, IRGKangXi=1081.111, RSKangXi=142.5, Def{cricket}
86CD CJK UNIFIED IDEOGRAPH-#86CD, IRGKangXi=1081.111, RSKangXi=42.8, Def{glow-worm, luminous insect}
86CE CJK UNIFIED IDEOGRAPH-#86CE, IRGKangXi=1081.111, RSKangXi=142.5, Def{oyster}
86CF CJK UNIFIED IDEOGRAPH-#86CF, IRGKangXi=1081.111, RSKangXi=142.5, Def{razor clam}
86D0 CJK UNIFIED IDEOGRAPH-#86D0, IRGKangXi=1081.120, RSKangXi=142.6, Def{cricket; worm}
86D1 CJK UNIFIED IDEOGRAPH-#86D1, IRGKangXi=1081.130, RSKangXi=142.6, Def{a marine crab}
86D2 CJK UNIFIED IDEOGRAPH-#86D2, IRGKangXi=1081.140, RSKangXi=142.6
86D3 CJK UNIFIED IDEOGRAPH-#86D3, IRGKangXi=1081.150, RSKangXi=142.6, Def{caterpillar; (Cant.) a nit, louse; itching}
86D4 CJK UNIFIED IDEOGRAPH-#86D4, IRGKangXi=1081.170, RSKangXi=142.6, Def{tapeworm}
86D5 CJK UNIFIED IDEOGRAPH-#86D5, IRGKangXi=1081.180, RSKangXi=142.6, Def{the common intestinal worms, the tape-worm}
86D6 CJK UNIFIED IDEOGRAPH-#86D6, IRGKangXi=1085.261, RSKangXi=142.6
86D7 CJK UNIFIED IDEOGRAPH-#86D7, IRGKangXi=1081.220, RSKangXi=142.6, Def{a grasshopper, locust}
86D8 CJK UNIFIED IDEOGRAPH-#86D8, IRGKangXi=1081.240, RSKangXi=142.6, Def{a weevil found in rice, etc.}
86D9 CJK UNIFIED IDEOGRAPH-#86D9, IRGKangXi=1081.250, RSKangXi=142.6, Def{frog}
86DA CJK UNIFIED IDEOGRAPH-#86DA, IRGKangXi=1081.300, RSKangXi=142.6
86DB CJK UNIFIED IDEOGRAPH-#86DB, IRGKangXi=1081.310, RSKangXi=142.6, Def{spider}
86DC CJK UNIFIED IDEOGRAPH-#86DC, IRGKangXi=1081.320, RSKangXi=142.6
86DD CJK UNIFIED IDEOGRAPH-#86DD, IRGKangXi=1081.350, RSKangXi=142.6
86DE CJK UNIFIED IDEOGRAPH-#86DE, IRGKangXi=1081.360, RSKangXi=142.6, Def{snail; slug, mole cricket}
86DF CJK UNIFIED IDEOGRAPH-#86DF, IRGKangXi=1081.370, RSKangXi=142.6, Def{scaly dragon with four legs}
86E0 CJK UNIFIED IDEOGRAPH-#86E0, IRGKangXi=1082.030, RSKangXi=142.6
86E1 CJK UNIFIED IDEOGRAPH-#86E1, IRGKangXi=1082.050, RSKangXi=142.6
86E2 CJK UNIFIED IDEOGRAPH-#86E2, IRGKangXi=1082.080, RSKangXi=142.6
86E3 CJK UNIFIED IDEOGRAPH-#86E3, IRGKangXi=1082.090, RSKangXi=142.6, Def{(dung) beetle}
86E4 CJK UNIFIED IDEOGRAPH-#86E4, IRGKangXi=1082.120, RSKangXi=142.6, Def{clam}
86E5 CJK UNIFIED IDEOGRAPH-#86E5, IRGKangXi=1082.150, RSKangXi=142.6
86E6 CJK UNIFIED IDEOGRAPH-#86E6, IRGKangXi=1082.180, RSKangXi=142.6
86E7 CJK UNIFIED IDEOGRAPH-#86E7, IRGKangXi=1082.200, RSKangXi=142.6
86E8 CJK UNIFIED IDEOGRAPH-#86E8, IRGKangXi=1082.230, RSKangXi=142.6
86E9 CJK UNIFIED IDEOGRAPH-#86E9, IRGKangXi=1082.250, RSKangXi=142.6, Def{cricket, locust; anxious}
86EA CJK UNIFIED IDEOGRAPH-#86EA, IRGKangXi=1082.290, RSKangXi=142.6
86EB CJK UNIFIED IDEOGRAPH-#86EB, IRGKangXi=1082.300, RSKangXi=142.6
86EC CJK UNIFIED IDEOGRAPH-#86EC, IRGKangXi=1082.340, RSKangXi=142.6
86ED CJK UNIFIED IDEOGRAPH-#86ED, IRGKangXi=1083.010, RSKangXi=142.6, Def{leech}
86EE CJK UNIFIED IDEOGRAPH-#86EE, IRGKangXi=1083.100, RSKangXi=142.6, Def{barbarians; barbarous, savage}
86EF CJK UNIFIED IDEOGRAPH-#86EF, IRGKangXi=1083.151, RSKangXi=142.6, Def{shrimp}
86F0 CJK UNIFIED IDEOGRAPH-#86F0, IRGKangXi=1083.151, RSKangXi=142.6, Def{to hibernate}
86F1 CJK UNIFIED IDEOGRAPH-#86F1, IRGKangXi=1083.151, RSKangXi=142.6, Def{kind of butterfly}
86F2 CJK UNIFIED IDEOGRAPH-#86F2, IRGKangXi=1083.151, RSKangXi=142.6, Def{worms}
86F3 CJK UNIFIED IDEOGRAPH-#86F3, IRGKangXi=1083.151, RSKangXi=142.6, Def{kind of snail with spiral shell}
86F4 CJK UNIFIED IDEOGRAPH-#86F4, IRGKangXi=1083.151, RSKangXi=142.6, Def{maggots, grubs}
86F5 CJK UNIFIED IDEOGRAPH-#86F5, IRGKangXi=1083.160, RSKangXi=142.7
86F6 CJK UNIFIED IDEOGRAPH-#86F6, IRGKangXi=1083.170, RSKangXi=142.7
86F7 CJK UNIFIED IDEOGRAPH-#86F7, IRGKangXi=1083.200, RSKangXi=142.7
86F8 CJK UNIFIED IDEOGRAPH-#86F8, IRGKangXi=1083.210, RSKangXi=142.7, Def{long legged spider; octopus; chrysalis of mantis}
86F9 CJK UNIFIED IDEOGRAPH-#86F9, IRGKangXi=1083.250, RSKangXi=142.7, Def{chrysalis, larva}
86FA CJK UNIFIED IDEOGRAPH-#86FA, IRGKangXi=1083.260, RSKangXi=142.7, Def{kind of butterfly}
86FB CJK UNIFIED IDEOGRAPH-#86FB, IRGKangXi=1083.270, RSKangXi=142.7, Def{molt, exuviate, shed}
86FC CJK UNIFIED IDEOGRAPH-#86FC, IRGKangXi=1083.280, RSKangXi=142.7
86FD CJK UNIFIED IDEOGRAPH-#86FD, IRGKangXi=1083.300, RSKangXi=142.7
86FE CJK UNIFIED IDEOGRAPH-#86FE, IRGKangXi=1083.310, RSKangXi=142.7, Def{moth}
86FF CJK UNIFIED IDEOGRAPH-#86FF, IRGKangXi=1084.030, RSKangXi=142.7
8700 CJK UNIFIED IDEOGRAPH-#8700, IRGKangXi=1084.040, RSKangXi=142.7, Def{name of an ancient state}
8701 CJK UNIFIED IDEOGRAPH-#8701, IRGKangXi=1084.050, RSKangXi=142.7
8702 CJK UNIFIED IDEOGRAPH-#8702, IRGKangXi=1084.060, RSKangXi=142.7, Def{bee, wasp, hornet}
8703 CJK UNIFIED IDEOGRAPH-#8703, IRGKangXi=1084.070, RSKangXi=142.7, Def{marine monster which can change its shape; water spouts; clams}
8704 CJK UNIFIED IDEOGRAPH-#8704, IRGKangXi=1084.080, RSKangXi=142.7
8705 CJK UNIFIED IDEOGRAPH-#8705, IRGKangXi=1084.090, RSKangXi=142.7
8706 CJK UNIFIED IDEOGRAPH-#8706, IRGKangXi=1084.110, RSKangXi=142.7, Def{a variety of bivalves}
8707 CJK UNIFIED IDEOGRAPH-#8707, IRGKangXi=1084.130, RSKangXi=142.7, Def{jellyfish}
8708 CJK UNIFIED IDEOGRAPH-#8708, IRGKangXi=1084.160, RSKangXi=142.7, Def{centipede}
8709 CJK UNIFIED IDEOGRAPH-#8709, IRGKangXi=1084.220, RSKangXi=142.7, Def{mayfly; kind of large insect}
870A CJK UNIFIED IDEOGRAPH-#870A, IRGKangXi=1084.240, RSKangXi=142.7, Def{clam}
870B CJK UNIFIED IDEOGRAPH-#870B, IRGKangXi=1084.250, RSKangXi=142.7, Def{mantis, dung beetle; insect}
870C CJK UNIFIED IDEOGRAPH-#870C, IRGKangXi=1085.010, RSKangXi=142.7
870D CJK UNIFIED IDEOGRAPH-#870D, IRGKangXi=1085.020, RSKangXi=142.7, Def{toad}
870E CJK UNIFIED IDEOGRAPH-#870E, IRGKangXi=1085.070, RSKangXi=142.7, Def{mosquito larva}
870F CJK UNIFIED IDEOGRAPH-#870F, IRGKangXi=1085.080, RSKangXi=142.7
8710 CJK UNIFIED IDEOGRAPH-#8710, IRGKangXi=1085.100, RSKangXi=142.7
8711 CJK UNIFIED IDEOGRAPH-#8711, IRGKangXi=1085.110, RSKangXi=142.7, Def{egg}
8712 CJK UNIFIED IDEOGRAPH-#8712, IRGKangXi=1085.120, RSKangXi=142.7, Def{millipede}
8713 CJK UNIFIED IDEOGRAPH-#8713, IRGKangXi=1085.130, RSKangXi=142.7, Def{dragonfly}
8714 CJK UNIFIED IDEOGRAPH-#8714, IRGKangXi=1085.230, RSKangXi=142.7, Def{inlaid shell-work}
8715 CJK UNIFIED IDEOGRAPH-#8715, IRGKangXi=1085.261, RSKangXi=142.7, Def{molt}
8716 CJK UNIFIED IDEOGRAPH-#8716, IRGKangXi=1085.261, Def{tapeworm}
8717 CJK UNIFIED IDEOGRAPH-#8717, IRGKangXi=1085.261, RSKangXi=142.7, Def{a snail, Eulota callizoma}
8718 CJK UNIFIED IDEOGRAPH-#8718, IRGKangXi=1085.270, RSKangXi=142.8, Def{spider}
8719 CJK UNIFIED IDEOGRAPH-#8719, IRGKangXi=1085.300, RSKangXi=142.8
871A CJK UNIFIED IDEOGRAPH-#871A, IRGKangXi=1085.310, RSKangXi=142.8, Def{cockroach}
871B CJK UNIFIED IDEOGRAPH-#871B, IRGKangXi=1085.350, RSKangXi=142.8
871C CJK UNIFIED IDEOGRAPH-#871C, IRGKangXi=1085.360, RSKangXi=142.8, Def{honey; sweet; nectar}
871D CJK UNIFIED IDEOGRAPH-#871D, IRGKangXi=1086.010, RSKangXi=142.8, Def{a kind of crab; worm, leech}
871E CJK UNIFIED IDEOGRAPH-#871E, IRGKangXi=1086.020, RSKangXi=142.8, Def{a kind of crab; worm, leech}
871F CJK UNIFIED IDEOGRAPH-#871F, IRGKangXi=1086.040, RSKangXi=142.8
8720 CJK UNIFIED IDEOGRAPH-#8720, IRGKangXi=1086.060, RSKangXi=142.8
8721 CJK UNIFIED IDEOGRAPH-#8721, IRGKangXi=1086.070, RSKangXi=142.8, Def{wax; candle; waxy, glazed; maggot; as a non-simplified form sometimes used as an equivalent to U+410D 䄍, meaning imperial harvest}
8722 CJK UNIFIED IDEOGRAPH-#8722, IRGKangXi=1086.090, RSKangXi=142.8, Def{grasshopper}
8723 CJK UNIFIED IDEOGRAPH-#8723, IRGKangXi=1086.110, RSKangXi=142.8, Def{dung beetle}
8724 CJK UNIFIED IDEOGRAPH-#8724, IRGKangXi=1086.130, RSKangXi=142.8
8725 CJK UNIFIED IDEOGRAPH-#8725, IRGKangXi=1086.140, RSKangXi=142.8, Def{lizard}
8726 CJK UNIFIED IDEOGRAPH-#8726, IRGKangXi=1086.170, RSKangXi=142.8
8727 CJK UNIFIED IDEOGRAPH-#8727, IRGKangXi=1086.180, RSKangXi=142.8
8728 CJK UNIFIED IDEOGRAPH-#8728, IRGKangXi=1086.200, RSKangXi=142.8, Def{butterfly}
8729 CJK UNIFIED IDEOGRAPH-#8729, IRGKangXi=1086.230, RSKangXi=142.8, Def{cicada, broad locust}
872A CJK UNIFIED IDEOGRAPH-#872A, IRGKangXi=1087.010, RSKangXi=142.8
872B CJK UNIFIED IDEOGRAPH-#872B, IRGKangXi=1087.020, RSKangXi=142.7, Def{insects}
872C CJK UNIFIED IDEOGRAPH-#872C, IRGKangXi=1087.070, RSKangXi=142.8
872D CJK UNIFIED IDEOGRAPH-#872D, IRGKangXi=1087.080, RSKangXi=142.8
872E CJK UNIFIED IDEOGRAPH-#872E, IRGKangXi=1087.100, RSKangXi=142.8, Def{a fabulous creature like a turtle; a toad}
872F CJK UNIFIED IDEOGRAPH-#872F, IRGKangXi=1087.120, RSKangXi=142.8
8730 CJK UNIFIED IDEOGRAPH-#8730, IRGKangXi=1087.150, RSKangXi=142.8
8731 CJK UNIFIED IDEOGRAPH-#8731, IRGKangXi=1087.160, RSKangXi=142.8, Def{a tick, mite}
8732 CJK UNIFIED IDEOGRAPH-#8732, IRGKangXi=1087.190, RSKangXi=142.8
8733 CJK UNIFIED IDEOGRAPH-#8733, IRGKangXi=1087.200, RSKangXi=142.8
8734 CJK UNIFIED IDEOGRAPH-#8734, IRGKangXi=1087.230, RSKangXi=142.8, Def{lizard}
8735 CJK UNIFIED IDEOGRAPH-#8735, IRGKangXi=1087.240, RSKangXi=142.8
8736 CJK UNIFIED IDEOGRAPH-#8736, IRGKangXi=1087.290, RSKangXi=142.8, Def{a house cricket}
8737 CJK UNIFIED IDEOGRAPH-#8737, IRGKangXi=1087.320, RSKangXi=142.8, Def{creep like worm, curl one's body}
8738 CJK UNIFIED IDEOGRAPH-#8738, IRGKangXi=1087.330, RSKangXi=142.8
8739 CJK UNIFIED IDEOGRAPH-#8739, IRGKangXi=1087.340, RSKangXi=142.8, Def{gnat, mosquito}
873A CJK UNIFIED IDEOGRAPH-#873A, IRGKangXi=1087.350, RSKangXi=142.8, Def{reflection of rainbow}
873B CJK UNIFIED IDEOGRAPH-#873B, IRGKangXi=1088.010, RSKangXi=142.8, Def{dragonfly}
873C CJK UNIFIED IDEOGRAPH-#873C, IRGKangXi=1088.030, RSKangXi=142.8
873D CJK UNIFIED IDEOGRAPH-#873D, IRGKangXi=1088.050, RSKangXi=142.8
873E CJK UNIFIED IDEOGRAPH-#873E, IRGKangXi=1088.060, RSKangXi=142.8, Def{the solitary wasp}
873F CJK UNIFIED IDEOGRAPH-#873F, IRGKangXi=1088.080, RSKangXi=142.8, Def{creep, crawl}
8740 CJK UNIFIED IDEOGRAPH-#8740, IRGKangXi=1088.100, RSKangXi=142.8, Def{rainbow}
8741 CJK UNIFIED IDEOGRAPH-#8741, IRGKangXi=1088.110, RSKangXi=142.8
8742 CJK UNIFIED IDEOGRAPH-#8742, IRGKangXi=1088.120, RSKangXi=142.8
8743 CJK UNIFIED IDEOGRAPH-#8743, IRGKangXi=1088.130, RSKangXi=142.8, Def{rainbow}
8744 CJK UNIFIED IDEOGRAPH-#8744, IRGKangXi=1088.140, RSKangXi=142.8
8745 CJK UNIFIED IDEOGRAPH-#8745, IRGKangXi=1088.330, RSKangXi=142.8
8746 CJK UNIFIED IDEOGRAPH-#8746, IRGKangXi=1088.341, RSKangXi=142.7
8747 CJK UNIFIED IDEOGRAPH-#8747, IRGKangXi=1088.341, RSKangXi=142.8, Def{flies}
8748 CJK UNIFIED IDEOGRAPH-#8748, IRGKangXi=1088.341, RSKangXi=142.8, Def{small green frog; cicada}
8749 CJK UNIFIED IDEOGRAPH-#8749, IRGKangXi=1088.341, RSKangXi=142.8, Def{cicada; continuous}
874A CJK UNIFIED IDEOGRAPH-#874A, IRGKangXi=1088.341, RSKangXi=142.8
874B CJK UNIFIED IDEOGRAPH-#874B, IRGKangXi=1088.341, RSKangXi=142.8, Def{wax; candle; waxy, glazed}
874C CJK UNIFIED IDEOGRAPH-#874C, IRGKangXi=1088.350, RSKangXi=142.9, Def{tadpole}
874D CJK UNIFIED IDEOGRAPH-#874D, IRGKangXi=1088.390, RSKangXi=142.9, Def{a centipede}
874E CJK UNIFIED IDEOGRAPH-#874E, IRGKangXi=1088.400, RSKangXi=142.9, Def{scorpion}
874F CJK UNIFIED IDEOGRAPH-#874F, IRGKangXi=1089.010, RSKangXi=142.9
8750 CJK UNIFIED IDEOGRAPH-#8750, IRGKangXi=1089.030, RSKangXi=142.9
8751 CJK UNIFIED IDEOGRAPH-#8751, IRGKangXi=1089.040, RSKangXi=142.9
8752 CJK UNIFIED IDEOGRAPH-#8752, IRGKangXi=1089.050, RSKangXi=142.9
8753 CJK UNIFIED IDEOGRAPH-#8753, IRGKangXi=1089.070, RSKangXi=142.9, Def{snail}
8754 CJK UNIFIED IDEOGRAPH-#8754, IRGKangXi=1089.080, RSKangXi=142.9
8755 CJK UNIFIED IDEOGRAPH-#8755, IRGKangXi=1089.100, RSKangXi=142.9, Def{nibble away; erode; eclipse}
8756 CJK UNIFIED IDEOGRAPH-#8756, IRGKangXi=1089.120, RSKangXi=142.9
8757 CJK UNIFIED IDEOGRAPH-#8757, IRGKangXi=1089.130, RSKangXi=142.9, Def{kind of locust}
8758 CJK UNIFIED IDEOGRAPH-#8758, IRGKangXi=1089.140, RSKangXi=142.9, Def{gecko, kind of cicada}
8759 CJK UNIFIED IDEOGRAPH-#8759, IRGKangXi=1089.160, RSKangXi=142.9, Def{bat}
875A CJK UNIFIED IDEOGRAPH-#875A, IRGKangXi=1089.180, RSKangXi=142.9
875B CJK UNIFIED IDEOGRAPH-#875B, IRGKangXi=1089.200, RSKangXi=142.9, Def{the sow-bug, wood-louse}
875C CJK UNIFIED IDEOGRAPH-#875C, IRGKangXi=1089.220, RSKangXi=142.9
875D CJK UNIFIED IDEOGRAPH-#875D, IRGKangXi=1089.230, RSKangXi=142.9, Def{the larva of locust}
875E CJK UNIFIED IDEOGRAPH-#875E, IRGKangXi=1090.010, RSKangXi=142.9, Def{(Cant.) 塘蝞, dragonfly}
875F CJK UNIFIED IDEOGRAPH-#875F, IRGKangXi=1090.040, RSKangXi=142.9, Def{hedgehog}
8760 CJK UNIFIED IDEOGRAPH-#8760, IRGKangXi=1090.050, RSKangXi=142.9, Def{kind of bat}
8761 CJK UNIFIED IDEOGRAPH-#8761, IRGKangXi=1090.070, RSKangXi=142.9, Def{eumenes polifomis, kind of wasp}
8762 CJK UNIFIED IDEOGRAPH-#8762, IRGKangXi=1090.080, RSKangXi=142.9
8763 CJK UNIFIED IDEOGRAPH-#8763, IRGKangXi=1090.090, RSKangXi=142.9, Def{mayfly (Ephemera strigata)}
8764 CJK UNIFIED IDEOGRAPH-#8764, IRGKangXi=1090.100, RSKangXi=142.9
8765 CJK UNIFIED IDEOGRAPH-#8765, IRGKangXi=1090.110, RSKangXi=142.9, Def{a fly which is used similarly to cantharides}
8766 CJK UNIFIED IDEOGRAPH-#8766, IRGKangXi=1090.150, RSKangXi=142.9, Def{shrimp, prawn}
8767 CJK UNIFIED IDEOGRAPH-#8767, IRGKangXi=1090.180, RSKangXi=142.9
8768 CJK UNIFIED IDEOGRAPH-#8768, IRGKangXi=1090.190, RSKangXi=142.9, Def{louse; bed bug}
8769 CJK UNIFIED IDEOGRAPH-#8769, IRGKangXi=1090.210, RSKangXi=142.9
876A CJK UNIFIED IDEOGRAPH-#876A, IRGKangXi=1090.220, RSKangXi=142.9
876B CJK UNIFIED IDEOGRAPH-#876B, IRGKangXi=1090.230, RSKangXi=142.9
876C CJK UNIFIED IDEOGRAPH-#876C, IRGKangXi=1090.240, RSKangXi=142.9
876D CJK UNIFIED IDEOGRAPH-#876D, IRGKangXi=1090.250, RSKangXi=142.9
876E CJK UNIFIED IDEOGRAPH-#876E, IRGKangXi=1091.010, RSKangXi=142.9, Def{venomous snake, viper}
876F CJK UNIFIED IDEOGRAPH-#876F, IRGKangXi=1091.070, RSKangXi=142.9, Def{ape}
8770 CJK UNIFIED IDEOGRAPH-#8770, IRGKangXi=1091.080, RSKangXi=142.9, Def{vipera russelii siamensis}
8771 CJK UNIFIED IDEOGRAPH-#8771, IRGKangXi=1091.100, RSKangXi=142.9, Def{horsefly, gadfly}
8772 CJK UNIFIED IDEOGRAPH-#8772, IRGKangXi=1091.120, RSKangXi=142.9
8773 CJK UNIFIED IDEOGRAPH-#8773, IRGKangXi=1091.140, RSKangXi=142.9
8774 CJK UNIFIED IDEOGRAPH-#8774, IRGKangXi=1091.210, RSKangXi=142.9, Def{butterfly}
8775 CJK UNIFIED IDEOGRAPH-#8775, IRGKangXi=1091.220, RSKangXi=142.9
8776 CJK UNIFIED IDEOGRAPH-#8776, IRGKangXi=1091.250, RSKangXi=142.9, Def{butterfly}
8777 CJK UNIFIED IDEOGRAPH-#8777, IRGKangXi=1091.260, RSKangXi=142.9
8778 CJK UNIFIED IDEOGRAPH-#8778, IRGKangXi=1091.290, RSKangXi=142.9, Def{a snail, Eulota callizoma}
8779 CJK UNIFIED IDEOGRAPH-#8779, IRGKangXi=1092.030, RSKangXi=142.10
877A CJK UNIFIED IDEOGRAPH-#877A, IRGKangXi=1092.200, RSKangXi=142.9
877B CJK UNIFIED IDEOGRAPH-#877B, IRGKangXi=1092.211, RSKangXi=142.9, Def{immature locusts}
877C CJK UNIFIED IDEOGRAPH-#877C, IRGKangXi=1092.211, RSKangXi=142.9, Def{a mole cricket, Gryllotalpa africana}
877D CJK UNIFIED IDEOGRAPH-#877D, IRGKangXi=1092.211, RSKangXi=142.9, Def{bedbug}
877E CJK UNIFIED IDEOGRAPH-#877E, IRGKangXi=1092.211, RSKangXi=142.9, Def{lizard}
877F CJK UNIFIED IDEOGRAPH-#877F, IRGKangXi=1092.211, RSKangXi=142.9, Def{flies}
8780 CJK UNIFIED IDEOGRAPH-#8780, IRGKangXi=1092.211, RSKangXi=142.9, Def{kind of cicada}
8781 CJK UNIFIED IDEOGRAPH-#8781, IRGKangXi=1092.211, RSKangXi=142.10
8782 CJK UNIFIED IDEOGRAPH-#8782, IRGKangXi=1092.220, RSKangXi=142.10, Def{mantis, dung beetle}
8783 CJK UNIFIED IDEOGRAPH-#8783, IRGKangXi=1092.230, RSKangXi=142.10, Def{crab}
8784 CJK UNIFIED IDEOGRAPH-#8784, IRGKangXi=1092.240, RSKangXi=142.10, Def{kind of snail with spiral shell}
8785 CJK UNIFIED IDEOGRAPH-#8785, IRGKangXi=1092.260, RSKangXi=142.10, Def{intestinal worm}
8786 CJK UNIFIED IDEOGRAPH-#8786, IRGKangXi=1094.270, RSKangXi=142.10, Def{hairy and poisonous caterpillars; (Cant.) a louse}
8787 CJK UNIFIED IDEOGRAPH-#8787, IRGKangXi=1092.300, RSKangXi=142.10
8788 CJK UNIFIED IDEOGRAPH-#8788, IRGKangXi=1092.310, RSKangXi=142.10, Def{a silkworm}
8789 CJK UNIFIED IDEOGRAPH-#8789, IRGKangXi=1092.320, RSKangXi=142.10, Def{wasp}
878A CJK UNIFIED IDEOGRAPH-#878A, IRGKangXi=1092.370, RSKangXi=142.10
878B CJK UNIFIED IDEOGRAPH-#878B, IRGKangXi=1092.390, RSKangXi=142.10, Def{spider millipede}
878C CJK UNIFIED IDEOGRAPH-#878C, IRGKangXi=1092.410, RSKangXi=142.10, Def{a striped, poisonous fly}
878D CJK UNIFIED IDEOGRAPH-#878D, IRGKangXi=1092.420, RSKangXi=142.10, Def{melt, fuse; blend, harmonize}
878E CJK UNIFIED IDEOGRAPH-#878E, IRGKangXi=1092.430, RSKangXi=142.10
878F CJK UNIFIED IDEOGRAPH-#878F, IRGKangXi=1092.440, RSKangXi=142.10
8790 CJK UNIFIED IDEOGRAPH-#8790, IRGKangXi=1093.020, RSKangXi=142.10
8791 CJK UNIFIED IDEOGRAPH-#8791, IRGKangXi=1093.030, RSKangXi=142.10
8792 CJK UNIFIED IDEOGRAPH-#8792, IRGKangXi=1093.080, RSKangXi=142.10
8793 CJK UNIFIED IDEOGRAPH-#8793, IRGKangXi=1093.170, RSKangXi=142.10, Def{a small cicada with a square head}
8794 CJK UNIFIED IDEOGRAPH-#8794, IRGKangXi=1093.210, RSKangXi=142.10
8795 CJK UNIFIED IDEOGRAPH-#8795, IRGKangXi=1093.230, RSKangXi=142.10, Def{a tick, mite}
8796 CJK UNIFIED IDEOGRAPH-#8796, IRGKangXi=1093.240, RSKangXi=142.10
8797 CJK UNIFIED IDEOGRAPH-#8797, IRGKangXi=1093.260, RSKangXi=142.10, Def{a kind of cicada}
8798 CJK UNIFIED IDEOGRAPH-#8798, IRGKangXi=1093.270, RSKangXi=142.10, Def{ant}
8799 CJK UNIFIED IDEOGRAPH-#8799, IRGKangXi=1093.280, RSKangXi=142.10, Def{grubs in wood, worms in books, clothes, etc. used figuratively of corrupt officials}
879A CJK UNIFIED IDEOGRAPH-#879A, IRGKangXi=1093.300, RSKangXi=142.10
879B CJK UNIFIED IDEOGRAPH-#879B, IRGKangXi=1093.330, RSKangXi=142.10
879C CJK UNIFIED IDEOGRAPH-#879C, IRGKangXi=1093.350, RSKangXi=142.10
879D CJK UNIFIED IDEOGRAPH-#879D, IRGKangXi=1093.360, RSKangXi=142.10
879E CJK UNIFIED IDEOGRAPH-#879E, IRGKangXi=1093.400, RSKangXi=142.10, Def{ant; leech}
879F CJK UNIFIED IDEOGRAPH-#879F, IRGKangXi=1093.410, RSKangXi=142.10, Def{kind of caterpillar, larva}
87A0 CJK UNIFIED IDEOGRAPH-#87A0, IRGKangXi=1093.430, RSKangXi=142.10
87A1 CJK UNIFIED IDEOGRAPH-#87A1, IRGKangXi=1093.440, RSKangXi=142.10
87A2 CJK UNIFIED IDEOGRAPH-#87A2, IRGKangXi=1093.450, RSKangXi=142.10, Def{glow-worm, luminous insect}
87A3 CJK UNIFIED IDEOGRAPH-#87A3, IRGKangXi=1093.460, RSKangXi=142.10, Def{mythological wingless dragon of}
87A4 CJK UNIFIED IDEOGRAPH-#87A4, IRGKangXi=1094.090, RSKangXi=142.10
87A5 CJK UNIFIED IDEOGRAPH-#87A5, IRGKangXi=1094.271, Def{the house-fly}
87A6 CJK UNIFIED IDEOGRAPH-#87A6, IRGKangXi=1094.271, RSKangXi=142.10
87A7 CJK UNIFIED IDEOGRAPH-#87A7, IRGKangXi=1094.271, RSKangXi=142.10
87A8 CJK UNIFIED IDEOGRAPH-#87A8, IRGKangXi=1094.271, RSKangXi=142.10, Def{insect}
87A9 CJK UNIFIED IDEOGRAPH-#87A9, IRGKangXi=1094.271, RSKangXi=142.10
87AA CJK UNIFIED IDEOGRAPH-#87AA, IRGKangXi=1094.280, RSKangXi=142.11
87AB CJK UNIFIED IDEOGRAPH-#87AB, IRGKangXi=1094.480, RSKangXi=142.11, Def{poison; sting; poisonous insect}
87AC CJK UNIFIED IDEOGRAPH-#87AC, IRGKangXi=1094.490, RSKangXi=142.11, Def{grubs in fruit}
87AD CJK UNIFIED IDEOGRAPH-#87AD, IRGKangXi=1094.510, RSKangXi=142.11, Def{a dragon whose horns have not grown; cruel}
87AE CJK UNIFIED IDEOGRAPH-#87AE, IRGKangXi=1094.520, RSKangXi=142.11, Def{rainbow}
87AF CJK UNIFIED IDEOGRAPH-#87AF, IRGKangXi=1094.530, RSKangXi=142.11, Def{nippers}
87B0 CJK UNIFIED IDEOGRAPH-#87B0, IRGKangXi=1094.540, RSKangXi=142.11
87B1 CJK UNIFIED IDEOGRAPH-#87B1, IRGKangXi=1095.020, RSKangXi=142.11
87B2 CJK UNIFIED IDEOGRAPH-#87B2, IRGKangXi=1095.030, RSKangXi=142.11
87B3 CJK UNIFIED IDEOGRAPH-#87B3, IRGKangXi=1095.040, RSKangXi=142.11, Def{mantis}
87B4 CJK UNIFIED IDEOGRAPH-#87B4, IRGKangXi=1095.050, RSKangXi=142.11
87B5 CJK UNIFIED IDEOGRAPH-#87B5, IRGKangXi=1095.060, RSKangXi=142.11, Def{a chrysalis}
87B6 CJK UNIFIED IDEOGRAPH-#87B6, IRGKangXi=1095.070, RSKangXi=142.11
87B7 CJK UNIFIED IDEOGRAPH-#87B7, IRGKangXi=1095.090, RSKangXi=142.11
87B8 CJK UNIFIED IDEOGRAPH-#87B8, IRGKangXi=1095.100, RSKangXi=142.11
87B9 CJK UNIFIED IDEOGRAPH-#87B9, IRGKangXi=1095.110, RSKangXi=142.11
87BA CJK UNIFIED IDEOGRAPH-#87BA, IRGKangXi=1095.120, RSKangXi=142.11, Def{spiral shell; conch; spiral}
87BB CJK UNIFIED IDEOGRAPH-#87BB, IRGKangXi=1095.150, RSKangXi=142.11, Def{a mole cricket, Gryllotalpa orientalis}
87BC CJK UNIFIED IDEOGRAPH-#87BC, IRGKangXi=1095.160, RSKangXi=142.11
87BD CJK UNIFIED IDEOGRAPH-#87BD, IRGKangXi=1095.180, RSKangXi=142.11, Def{katydid}
87BE CJK UNIFIED IDEOGRAPH-#87BE, IRGKangXi=1095.290, RSKangXi=142.11, Def{the earthworm}
87BF CJK UNIFIED IDEOGRAPH-#87BF, IRGKangXi=1095.300, RSKangXi=142.11, Def{kind of cicada}
87C0 CJK UNIFIED IDEOGRAPH-#87C0, IRGKangXi=1095.310, RSKangXi=142.11, Def{cricket}
87C1 CJK UNIFIED IDEOGRAPH-#87C1, IRGKangXi=1095.330, RSKangXi=142.11, Def{a mosquito, a gnat}
87C2 CJK UNIFIED IDEOGRAPH-#87C2, IRGKangXi=1095.340, RSKangXi=142.11
87C3 CJK UNIFIED IDEOGRAPH-#87C3, IRGKangXi=1096.010, RSKangXi=142.11
87C4 CJK UNIFIED IDEOGRAPH-#87C4, IRGKangXi=1096.020, RSKangXi=142.11, Def{to hibernate}
87C5 CJK UNIFIED IDEOGRAPH-#87C5, IRGKangXi=1096.040, RSKangXi=142.11
87C6 CJK UNIFIED IDEOGRAPH-#87C6, IRGKangXi=1096.060, RSKangXi=142.11, Def{frog, toad}
87C7 CJK UNIFIED IDEOGRAPH-#87C7, IRGKangXi=1096.070, RSKangXi=142.11, Def{frog, toad}
87C8 CJK UNIFIED IDEOGRAPH-#87C8, IRGKangXi=1096.090, RSKangXi=142.11, Def{small green frog; cicada}
87C9 CJK UNIFIED IDEOGRAPH-#87C9, IRGKangXi=1096.100, RSKangXi=142.11
87CA CJK UNIFIED IDEOGRAPH-#87CA, IRGKangXi=1096.130, RSKangXi=142.11, Def{a fly which is used similarly to cantharides}
87CB CJK UNIFIED IDEOGRAPH-#87CB, IRGKangXi=1096.150, RSKangXi=142.11, Def{cricket}
87CC CJK UNIFIED IDEOGRAPH-#87CC, IRGKangXi=1096.220, RSKangXi=142.11
87CD CJK UNIFIED IDEOGRAPH-#87CD, IRGKangXi=1096.271, RSKangXi=142.11
87CE CJK UNIFIED IDEOGRAPH-#87CE, IRGKangXi=1096.271, RSKangXi=142.11, Def{insect}
87CF CJK UNIFIED IDEOGRAPH-#87CF, IRGKangXi=1098.441, RSKangXi=142.11, Def{a kind of spider with long legs}
87D0 CJK UNIFIED IDEOGRAPH-#87D0, IRGKangXi=1096.271, RSKangXi=142.11
87D1 CJK UNIFIED IDEOGRAPH-#87D1, IRGKangXi=1096.271, RSKangXi=142.11, Def{cockroach}
87D2 CJK UNIFIED IDEOGRAPH-#87D2, IRGKangXi=1096.290, RSKangXi=142.13, Def{python, boa constrictor}
87D3 CJK UNIFIED IDEOGRAPH-#87D3, IRGKangXi=1096.300, RSKangXi=142.12
87D4 CJK UNIFIED IDEOGRAPH-#87D4, IRGKangXi=1096.310, RSKangXi=142.12
87D5 CJK UNIFIED IDEOGRAPH-#87D5, IRGKangXi=1096.330, RSKangXi=142.12, Def{a species of tortoise found near the mouth of the Yellow River}
87D6 CJK UNIFIED IDEOGRAPH-#87D6, IRGKangXi=1096.340, RSKangXi=142.12, Def{the larva of a month; a grasshopper}
87D7 CJK UNIFIED IDEOGRAPH-#87D7, IRGKangXi=1096.350, RSKangXi=142.12
87D8 CJK UNIFIED IDEOGRAPH-#87D8, IRGKangXi=1096.360, RSKangXi=142.12
87D9 CJK UNIFIED IDEOGRAPH-#87D9, IRGKangXi=1096.370, RSKangXi=142.12
87DA CJK UNIFIED IDEOGRAPH-#87DA, IRGKangXi=1096.380, RSKangXi=142.12, Def{a small land crab}
87DB CJK UNIFIED IDEOGRAPH-#87DB, IRGKangXi=1096.390, RSKangXi=142.12, Def{a land-crab}
87DC CJK UNIFIED IDEOGRAPH-#87DC, IRGKangXi=1096.400, RSKangXi=142.12, Def{insect}
87DD CJK UNIFIED IDEOGRAPH-#87DD, IRGKangXi=1097.010, RSKangXi=142.12, Def{(Cant.) 蠄蟝, a dragonfly}
87DE CJK UNIFIED IDEOGRAPH-#87DE, IRGKangXi=1097.040, RSKangXi=142.12
87DF CJK UNIFIED IDEOGRAPH-#87DF, IRGKangXi=1097.060, RSKangXi=142.12
87E0 CJK UNIFIED IDEOGRAPH-#87E0, IRGKangXi=1097.070, RSKangXi=142.12, Def{coil; coiling, curling; occupy}
87E1 CJK UNIFIED IDEOGRAPH-#87E1, IRGKangXi=1097.090, RSKangXi=142.9
87E2 CJK UNIFIED IDEOGRAPH-#87E2, IRGKangXi=1097.100, RSKangXi=142.12, Def{caulk; a spider}
87E3 CJK UNIFIED IDEOGRAPH-#87E3, IRGKangXi=1097.110, RSKangXi=142.12, Def{louse eggs, nits}
87E4 CJK UNIFIED IDEOGRAPH-#87E4, IRGKangXi=1097.120, RSKangXi=142.12
87E5 CJK UNIFIED IDEOGRAPH-#87E5, IRGKangXi=1097.150, RSKangXi=142.12, Def{leech}
87E6 CJK UNIFIED IDEOGRAPH-#87E6, IRGKangXi=1097.160, RSKangXi=142.12
87E7 CJK UNIFIED IDEOGRAPH-#87E7, IRGKangXi=1097.170, RSKangXi=142.12, Def{(Cant.) 蠄蟧, a spider}
87E8 CJK UNIFIED IDEOGRAPH-#87E8, IRGKangXi=1097.180, RSKangXi=142.12, Def{the Siberian jerboa}
87E9 CJK UNIFIED IDEOGRAPH-#87E9, IRGKangXi=1097.190, RSKangXi=142.12
87EA CJK UNIFIED IDEOGRAPH-#87EA, IRGKangXi=1097.250, RSKangXi=142.12, Def{a kind of cicada}
87EB CJK UNIFIED IDEOGRAPH-#87EB, IRGKangXi=1097.300, RSKangXi=142.12, Def{silverfish}
87EC CJK UNIFIED IDEOGRAPH-#87EC, IRGKangXi=1097.310, RSKangXi=142.12, Def{cicada; continuous}
87ED CJK UNIFIED IDEOGRAPH-#87ED, IRGKangXi=1098.070, RSKangXi=142.12, Def{very small bug}
87EE CJK UNIFIED IDEOGRAPH-#87EE, IRGKangXi=1098.080, RSKangXi=142.12, Def{type of earthworm}
87EF CJK UNIFIED IDEOGRAPH-#87EF, IRGKangXi=1098.100, RSKangXi=142.12, Def{worms}
87F0 CJK UNIFIED IDEOGRAPH-#87F0, IRGKangXi=1098.441, RSKangXi=142.12, Def{small spider with long legs}
87F1 CJK UNIFIED IDEOGRAPH-#87F1, IRGKangXi=1098.150, RSKangXi=142.12
87F2 CJK UNIFIED IDEOGRAPH-#87F2, IRGKangXi=1098.160, RSKangXi=142.12, Def{worms; insects}
87F3 CJK UNIFIED IDEOGRAPH-#87F3, IRGKangXi=1098.170, RSKangXi=142.12, Def{a kind of crab}
87F4 CJK UNIFIED IDEOGRAPH-#87F4, IRGKangXi=1098.441, RSKangXi=142.12
87F5 CJK UNIFIED IDEOGRAPH-#87F5, IRGKangXi=1098.441, RSKangXi=142.12
87F6 CJK UNIFIED IDEOGRAPH-#87F6, IRGKangXi=1098.450, RSKangXi=142.13, Def{razor clam}
87F7 CJK UNIFIED IDEOGRAPH-#87F7, IRGKangXi=1098.460, RSKangXi=142.13, Def{mantis}
87F8 CJK UNIFIED IDEOGRAPH-#87F8, IRGKangXi=1098.470, RSKangXi=142.13
87F9 CJK UNIFIED IDEOGRAPH-#87F9, IRGKangXi=1098.490, RSKangXi=142.13, Def{crab, brachyura}
87FA CJK UNIFIED IDEOGRAPH-#87FA, IRGKangXi=1099.020, RSKangXi=142.13, Def{earthworm}
87FB CJK UNIFIED IDEOGRAPH-#87FB, IRGKangXi=1099.030, RSKangXi=142.13, Def{ants}
87FC CJK UNIFIED IDEOGRAPH-#87FC, IRGKangXi=1099.050, RSKangXi=142.13
87FD CJK UNIFIED IDEOGRAPH-#87FD, IRGKangXi=1099.060, RSKangXi=142.13
87FE CJK UNIFIED IDEOGRAPH-#87FE, IRGKangXi=1099.070, RSKangXi=142.13, Def{toad}
87FF CJK UNIFIED IDEOGRAPH-#87FF, IRGKangXi=1099.080, RSKangXi=142.13, Def{acrida chinensis}
8800 CJK UNIFIED IDEOGRAPH-#8800, IRGKangXi=1099.110, RSKangXi=142.13
8801 CJK UNIFIED IDEOGRAPH-#8801, IRGKangXi=1099.120, RSKangXi=142.13, Def{larvae, grubs}
8802 CJK UNIFIED IDEOGRAPH-#8802, IRGKangXi=1099.130, RSKangXi=142.13
8803 CJK UNIFIED IDEOGRAPH-#8803, IRGKangXi=1099.150, RSKangXi=142.13, Def{the solitary wasp}
8804 CJK UNIFIED IDEOGRAPH-#8804, IRGKangXi=1099.190, RSKangXi=142.13, Def{(Cant.) 蠄蟧, a spider; 蠄蟝, a toad}
8805 CJK UNIFIED IDEOGRAPH-#8805, IRGKangXi=1099.200, RSKangXi=142.13, Def{flies}
8806 CJK UNIFIED IDEOGRAPH-#8806, IRGKangXi=1099.240, RSKangXi=142.13, Def{a kind of scorpion; a sting in the tail}
8807 CJK UNIFIED IDEOGRAPH-#8807, IRGKangXi=1100.010, RSKangXi=142.13
8808 CJK UNIFIED IDEOGRAPH-#8808, IRGKangXi=1100.020, RSKangXi=142.13
8809 CJK UNIFIED IDEOGRAPH-#8809, IRGKangXi=1100.040, RSKangXi=142.13, Def{mosquito larvae, wrigglers}
880A CJK UNIFIED IDEOGRAPH-#880A, IRGKangXi=1100.060, RSKangXi=142.13
880B CJK UNIFIED IDEOGRAPH-#880B, IRGKangXi=1100.080, RSKangXi=142.13, Def{caterpillar}
880C CJK UNIFIED IDEOGRAPH-#880C, IRGKangXi=1100.090, RSKangXi=142.13
880D CJK UNIFIED IDEOGRAPH-#880D, IRGKangXi=1100.120, RSKangXi=142.13, Def{scorpion}
880E CJK UNIFIED IDEOGRAPH-#880E, IRGKangXi=1100.280, RSKangXi=142.12, Def{python, boa constrictor}
880F CJK UNIFIED IDEOGRAPH-#880F, IRGKangXi=1100.320, RSKangXi=142.13, Def{crab, brachyura}
8810 CJK UNIFIED IDEOGRAPH-#8810, IRGKangXi=1100.330, RSKangXi=142.14, Def{maggots, grubs}
8811 CJK UNIFIED IDEOGRAPH-#8811, IRGKangXi=1100.390, RSKangXi=142.14, Def{lizard}
8812 CJK UNIFIED IDEOGRAPH-#8812, IRGKangXi=1100.440, RSKangXi=142.14
8813 CJK UNIFIED IDEOGRAPH-#8813, IRGKangXi=1100.460, RSKangXi=142.14, Def{midges; sandflies}
8814 CJK UNIFIED IDEOGRAPH-#8814, IRGKangXi=1100.490, RSKangXi=142.14, Def{oyster}
8815 CJK UNIFIED IDEOGRAPH-#8815, IRGKangXi=1100.500, RSKangXi=142.14, Def{eumenes polifomis, kind of wasp}
8816 CJK UNIFIED IDEOGRAPH-#8816, IRGKangXi=1101.010, RSKangXi=142.14, Def{inch-worm; looper caterpiller}
8817 CJK UNIFIED IDEOGRAPH-#8817, IRGKangXi=1101.040, RSKangXi=142.14
8818 CJK UNIFIED IDEOGRAPH-#8818, IRGKangXi=1101.180, RSKangXi=142.14
8819 CJK UNIFIED IDEOGRAPH-#8819, IRGKangXi=1101.181, RSKangXi=142.14, Def{oyster}
881A CJK UNIFIED IDEOGRAPH-#881A, IRGKangXi=1101.190, RSKangXi=142.15
881B CJK UNIFIED IDEOGRAPH-#881B, IRGKangXi=1101.240, RSKangXi=142.15, Def{flies, small insects produced in damp places}
881C CJK UNIFIED IDEOGRAPH-#881C, IRGKangXi=1101.250, RSKangXi=142.15, Def{grasshopper}
881D CJK UNIFIED IDEOGRAPH-#881D, IRGKangXi=1101.290, RSKangXi=142.15
881E CJK UNIFIED IDEOGRAPH-#881E, IRGKangXi=1101.300, RSKangXi=142.15
881F CJK UNIFIED IDEOGRAPH-#881F, IRGKangXi=1101.310, RSKangXi=142.15, Def{wax; candle; waxy, glazed}
8820 CJK UNIFIED IDEOGRAPH-#8820, IRGKangXi=1101.400, RSKangXi=142.15
8821 CJK UNIFIED IDEOGRAPH-#8821, IRGKangXi=1101.410, RSKangXi=142.15, Def{wood-boring insect; bore into wood}
8822 CJK UNIFIED IDEOGRAPH-#8822, IRGKangXi=1101.440, RSKangXi=142.15, Def{wriggle; stupid; silly; fat}
8823 CJK UNIFIED IDEOGRAPH-#8823, IRGKangXi=1102.020, RSKangXi=142.15, Def{oyster}
8824 CJK UNIFIED IDEOGRAPH-#8824, IRGKangXi=1102.131, RSKangXi=142.15
8825 CJK UNIFIED IDEOGRAPH-#8825, IRGKangXi=1102.140, RSKangXi=142.16
8826 CJK UNIFIED IDEOGRAPH-#8826, IRGKangXi=1102.180, RSKangXi=142.16
8827 CJK UNIFIED IDEOGRAPH-#8827, IRGKangXi=1102.230, RSKangXi=142.16, Def{moth; insects which eat into cloth}
8828 CJK UNIFIED IDEOGRAPH-#8828, IRGKangXi=1102.270, RSKangXi=142.16, Def{a kind of spider with long legs}
8829 CJK UNIFIED IDEOGRAPH-#8829, IRGKangXi=1102.300, RSKangXi=142.16, Def{a toad}
882A CJK UNIFIED IDEOGRAPH-#882A, IRGKangXi=1102.310, RSKangXi=142.16
882B CJK UNIFIED IDEOGRAPH-#882B, IRGKangXi=1102.500, RSKangXi=142.16
882C CJK UNIFIED IDEOGRAPH-#882C, IRGKangXi=1102.521, RSKangXi=142.16
882D CJK UNIFIED IDEOGRAPH-#882D, IRGKangXi=1103.010, RSKangXi=142.17, Def{bees, hornets, wasps}
882E CJK UNIFIED IDEOGRAPH-#882E, IRGKangXi=1103.030, RSKangXi=142.17, Def{bee}
882F CJK UNIFIED IDEOGRAPH-#882F, IRGKangXi=1103.040, RSKangXi=142.17
8830 CJK UNIFIED IDEOGRAPH-#8830, IRGKangXi=1103.090, RSKangXi=142.17
8831 CJK UNIFIED IDEOGRAPH-#8831, IRGKangXi=1103.120, RSKangXi=142.17, Def{poison; venom; harm; bewitch}
8832 CJK UNIFIED IDEOGRAPH-#8832, IRGKangXi=1103.180, RSKangXi=142.17, Def{the millipede sometimes confounded with the grow-worm; bright, clear}
8833 CJK UNIFIED IDEOGRAPH-#8833, IRGKangXi=1103.280, RSKangXi=142.17
8834 CJK UNIFIED IDEOGRAPH-#8834, IRGKangXi=1104.181, RSKangXi=142.15
8835 CJK UNIFIED IDEOGRAPH-#8835, IRGKangXi=1103.300, RSKangXi=142.18, Def{large turtles}
8836 CJK UNIFIED IDEOGRAPH-#8836, IRGKangXi=1103.330, RSKangXi=142.18, Def{silkworms}
8837 CJK UNIFIED IDEOGRAPH-#8837, IRGKangXi=1104.020, RSKangXi=142.18
8838 CJK UNIFIED IDEOGRAPH-#8838, IRGKangXi=1104.030, RSKangXi=142.18
8839 CJK UNIFIED IDEOGRAPH-#8839, IRGKangXi=1104.050, RSKangXi=142.18, Def{moth; insects which eat into clot}
883A CJK UNIFIED IDEOGRAPH-#883A, IRGKangXi=1104.110, RSKangXi=142.18, Def{same as 蚕 U+8695 silkworms}
883B CJK UNIFIED IDEOGRAPH-#883B, IRGKangXi=1104.250, RSKangXi=142.19, Def{barbarians; barbarous, savage}
883C CJK UNIFIED IDEOGRAPH-#883C, IRGKangXi=1104.370, RSKangXi=142.20
883D CJK UNIFIED IDEOGRAPH-#883D, IRGKangXi=1104.410, RSKangXi=142.21
883E CJK UNIFIED IDEOGRAPH-#883E, IRGKangXi=1105.040, RSKangXi=142.21
883F CJK UNIFIED IDEOGRAPH-#883F, IRGKangXi=1105.140, RSKangXi=142.22
8840 CJK UNIFIED IDEOGRAPH-#8840, IRGKangXi=1107.010, RSKangXi=143.0, Def{blood; radical number 143}
8841 CJK UNIFIED IDEOGRAPH-#8841, IRGKangXi=1107.060, RSKangXi=143.3, Def{blood}
8842 CJK UNIFIED IDEOGRAPH-#8842, IRGKangXi=1107.071, RSKangXi=143.3, Def{to be defeated}
8843 CJK UNIFIED IDEOGRAPH-#8843, IRGKangXi=1107.080, RSKangXi=143.4
8844 CJK UNIFIED IDEOGRAPH-#8844, IRGKangXi=1107.090, RSKangXi=143.4, Def{epistaxis, nosebleed; to be defeated}
8845 CJK UNIFIED IDEOGRAPH-#8845, IRGKangXi=1107.150, RSKangXi=143.5, Def{consecrate sacrificial vessels by smearing blood; rift}
8846 CJK UNIFIED IDEOGRAPH-#8846, IRGKangXi=1107.160, RSKangXi=143.6, Def{multitude, crowd; masses, public}
8847 CJK UNIFIED IDEOGRAPH-#8847, IRGKangXi=1107.170, RSKangXi=143.6, Def{blood vessels, veins, arteries}
8848 CJK UNIFIED IDEOGRAPH-#8848, IRGKangXi=1107.180, RSKangXi=143.6, Def{the blood of a sacrificial fowl which was sprinkled on the doors and vessels}
8849 CJK UNIFIED IDEOGRAPH-#8849, IRGKangXi=1107.190, RSKangXi=143.6, Def{to vomit}
884A CJK UNIFIED IDEOGRAPH-#884A, IRGKangXi=1108.250, RSKangXi=143.15, Def{smear, slander; defile}
884B CJK UNIFIED IDEOGRAPH-#884B, IRGKangXi=1108.280, RSKangXi=143.18
884C CJK UNIFIED IDEOGRAPH-#884C, IRGKangXi=1108.310, RSKangXi=144.0, Def{go; walk; move, travel; circulate}
884D CJK UNIFIED IDEOGRAPH-#884D, IRGKangXi=1108.350, RSKangXi=144.3, Def{overflow, spill over, spread out}
884E CJK UNIFIED IDEOGRAPH-#884E, IRGKangXi=1109.010, RSKangXi=144.3, Def{to give pleasure; pleased, happy}
884F CJK UNIFIED IDEOGRAPH-#884F, IRGKangXi=1109.060, RSKangXi=144.4
8850 CJK UNIFIED IDEOGRAPH-#8850, IRGKangXi=1109.131, RSKangXi=144.5
8851 CJK UNIFIED IDEOGRAPH-#8851, IRGKangXi=1109.100, RSKangXi=144.5
8852 CJK UNIFIED IDEOGRAPH-#8852, IRGKangXi=1109.110, RSKangXi=144.5, Def{brag; show off, promote oneself}
8853 CJK UNIFIED IDEOGRAPH-#8853, IRGKangXi=1109.120, RSKangXi=144.5, Def{art, skill, special feat; method, technique}
8854 CJK UNIFIED IDEOGRAPH-#8854, IRGKangXi=1109.131, RSKangXi=60.8, Def{bit; hold in mouth, bite; gag}
8855 CJK UNIFIED IDEOGRAPH-#8855, IRGKangXi=1109.140, RSKangXi=144.6, Def{alley, lane}
8856 CJK UNIFIED IDEOGRAPH-#8856, IRGKangXi=1109.150, RSKangXi=144.6, Def{lane; alley}
8857 CJK UNIFIED IDEOGRAPH-#8857, IRGKangXi=1109.170, RSKangXi=144.6, Def{street, road, thoroughfare}
8858 CJK UNIFIED IDEOGRAPH-#8858, IRGKangXi=1109.180, RSKangXi=144.6
8859 CJK UNIFIED IDEOGRAPH-#8859, IRGKangXi=1109.240, RSKangXi=144.7, Def{public office; official residence}
885A CJK UNIFIED IDEOGRAPH-#885A, IRGKangXi=1109.280, RSKangXi=144.9, Def{lane, alley, side street}
885B CJK UNIFIED IDEOGRAPH-#885B, IRGKangXi=1109.290, RSKangXi=144.9, Def{guard, protect, defend}
885C CJK UNIFIED IDEOGRAPH-#885C, IRGKangXi=1110.010, RSKangXi=144.9, Def{way, path}
885D CJK UNIFIED IDEOGRAPH-#885D, IRGKangXi=1110.030, RSKangXi=144.9, Def{rush against, charge ahead}
885E CJK UNIFIED IDEOGRAPH-#885E, IRGKangXi=1110.070, RSKangXi=144.10, Def{guard, protect, defend}
885F CJK UNIFIED IDEOGRAPH-#885F, IRGKangXi=1110.080, RSKangXi=144.10
8860 CJK UNIFIED IDEOGRAPH-#8860, IRGKangXi=1110.090, RSKangXi=144.10
8861 CJK UNIFIED IDEOGRAPH-#8861, IRGKangXi=1110.110, RSKangXi=144.10, Def{measure, weigh, judge, consider}
8862 CJK UNIFIED IDEOGRAPH-#8862, IRGKangXi=1110.230, RSKangXi=144.18, Def{highway; thoroughfare, intersection}
8863 CJK UNIFIED IDEOGRAPH-#8863, IRGKangXi=1111.010, RSKangXi=145.0, Def{clothes, clothing; cover, skin}
8864 CJK UNIFIED IDEOGRAPH-#8864, IRGKangXi=1111.011, RSKangXi=145.0, Def{clothes; radical number 145}
8865 CJK UNIFIED IDEOGRAPH-#8865, IRGKangXi=1111.061, RSKangXi=145.2, Def{mend, patch, fix, repair, restore}
8866 CJK UNIFIED IDEOGRAPH-#8866, IRGKangXi=1111.090, Def{smooth out the clothes}
8867 CJK UNIFIED IDEOGRAPH-#8867, IRGKangXi=1111.100, RSKangXi=145.3
8868 CJK UNIFIED IDEOGRAPH-#8868, IRGKangXi=1111.130, RSKangXi=145.3, Def{show, express, manifest, display}
8869 CJK UNIFIED IDEOGRAPH-#8869, IRGKangXi=1111.170, RSKangXi=145.3, Def{the open seam of a garment which allows freedom of movement}
886A CJK UNIFIED IDEOGRAPH-#886A, IRGKangXi=1111.190, RSKangXi=145.3
886B CJK UNIFIED IDEOGRAPH-#886B, IRGKangXi=1112.020, RSKangXi=145.3, Def{shirt; robe; gown; jacket}
886C CJK UNIFIED IDEOGRAPH-#886C, IRGKangXi=1112.041, RSKangXi=145.3, Def{underwear; inner garments}
886D CJK UNIFIED IDEOGRAPH-#886D, IRGKangXi=1112.060, RSKangXi=145.4, Def{the lapel of a garment}
886E CJK UNIFIED IDEOGRAPH-#886E, IRGKangXi=1112.080, RSKangXi=145.4, Def{ceremonial dress worn by the emperor}
886F CJK UNIFIED IDEOGRAPH-#886F, IRGKangXi=1112.120, RSKangXi=145.4
8870 CJK UNIFIED IDEOGRAPH-#8870, IRGKangXi=1112.140, RSKangXi=145.4, Def{decline, falter, decrease; weaken}
8871 CJK UNIFIED IDEOGRAPH-#8871, IRGKangXi=1112.180, RSKangXi=145.4
8872 CJK UNIFIED IDEOGRAPH-#8872, IRGKangXi=1112.190, RSKangXi=145.4, Def{mend, sew, patch; line; quilt}
8873 CJK UNIFIED IDEOGRAPH-#8873, IRGKangXi=1112.200, RSKangXi=145.4
8874 CJK UNIFIED IDEOGRAPH-#8874, IRGKangXi=1112.220, RSKangXi=145.4
8875 CJK UNIFIED IDEOGRAPH-#8875, IRGKangXi=1112.240, RSKangXi=145.4, Def{chemise}
8876 CJK UNIFIED IDEOGRAPH-#8876, IRGKangXi=1112.270, RSKangXi=145.4
8877 CJK UNIFIED IDEOGRAPH-#8877, IRGKangXi=1112.280, RSKangXi=145.4, Def{heart, from bottom of one's heart}
8878 CJK UNIFIED IDEOGRAPH-#8878, IRGKangXi=1112.290, RSKangXi=145.4
8879 CJK UNIFIED IDEOGRAPH-#8879, IRGKangXi=1112.300, RSKangXi=145.4, Def{only, merely, but}
887A CJK UNIFIED IDEOGRAPH-#887A, IRGKangXi=1112.310, RSKangXi=145.4, Def{slit in garment to aid movement}
887B CJK UNIFIED IDEOGRAPH-#887B, IRGKangXi=1113.010, RSKangXi=145.4
887C CJK UNIFIED IDEOGRAPH-#887C, IRGKangXi=1113.020, RSKangXi=145.4
887D CJK UNIFIED IDEOGRAPH-#887D, IRGKangXi=1113.030, RSKangXi=145.4, Def{lapel; hidden lapel of coat}
887E CJK UNIFIED IDEOGRAPH-#887E, IRGKangXi=1113.040, RSKangXi=145.4, Def{coverlet, quilt}
887F CJK UNIFIED IDEOGRAPH-#887F, IRGKangXi=1113.050, RSKangXi=145.4, Def{collar or lapel of garment}
8880 CJK UNIFIED IDEOGRAPH-#8880, IRGKangXi=1113.060, RSKangXi=145.4
8881 CJK UNIFIED IDEOGRAPH-#8881, IRGKangXi=1113.080, RSKangXi=145.4, Def{robe; surname}
8882 CJK UNIFIED IDEOGRAPH-#8882, IRGKangXi=1113.100, RSKangXi=145.4, Def{sleeves}
8883 CJK UNIFIED IDEOGRAPH-#8883, IRGKangXi=1113.110, RSKangXi=145.4
8884 CJK UNIFIED IDEOGRAPH-#8884, IRGKangXi=1113.221, RSKangXi=145.4, Def{outer garments; coat, jacket}
8885 CJK UNIFIED IDEOGRAPH-#8885, IRGKangXi=1113.221, RSKangXi=145.4, Def{curling upwards; wavering gently}
8886 CJK UNIFIED IDEOGRAPH-#8886, IRGKangXi=1113.221, RSKangXi=145.4, Def{ceremonial gowns of a queen}
8887 CJK UNIFIED IDEOGRAPH-#8887, IRGKangXi=1113.221
8888 CJK UNIFIED IDEOGRAPH-#8888, IRGKangXi=1113.230, RSKangXi=145.5, Def{Buddhist cassock}
8889 CJK UNIFIED IDEOGRAPH-#8889, IRGKangXi=1113.240, RSKangXi=145.5
888A CJK UNIFIED IDEOGRAPH-#888A, IRGKangXi=1113.270, RSKangXi=145.5
888B CJK UNIFIED IDEOGRAPH-#888B, IRGKangXi=1113.280, RSKangXi=145.5, Def{pocket, bag, sack, pouch}
888C CJK UNIFIED IDEOGRAPH-#888C, IRGKangXi=1113.290, RSKangXi=145.5
888D CJK UNIFIED IDEOGRAPH-#888D, IRGKangXi=1113.300, RSKangXi=145.5, Def{long gown, robe, cloak}
888E CJK UNIFIED IDEOGRAPH-#888E, IRGKangXi=1114.010, RSKangXi=145.5
888F CJK UNIFIED IDEOGRAPH-#888F, IRGKangXi=1114.040, RSKangXi=145.5
8890 CJK UNIFIED IDEOGRAPH-#8890, IRGKangXi=1114.050, RSKangXi=145.5
8891 CJK UNIFIED IDEOGRAPH-#8891, IRGKangXi=1114.080, RSKangXi=145.5
8892 CJK UNIFIED IDEOGRAPH-#8892, IRGKangXi=1114.100, RSKangXi=145.5, Def{strip; lay bare; bared; naked}
8893 CJK UNIFIED IDEOGRAPH-#8893, IRGKangXi=1114.110, RSKangXi=145.5
8894 CJK UNIFIED IDEOGRAPH-#8894, IRGKangXi=1114.140, RSKangXi=145.5
8895 CJK UNIFIED IDEOGRAPH-#8895, IRGKangXi=1114.150, RSKangXi=145.5
8896 CJK UNIFIED IDEOGRAPH-#8896, IRGKangXi=1114.170, RSKangXi=145.5, Def{sleeve; put something in sleeve}
8897 CJK UNIFIED IDEOGRAPH-#8897, IRGKangXi=1114.190, RSKangXi=145.5, Def{unlined garments; hem of garment}
8898 CJK UNIFIED IDEOGRAPH-#8898, IRGKangXi=1114.200, RSKangXi=145.5
8899 CJK UNIFIED IDEOGRAPH-#8899, IRGKangXi=1114.210, RSKangXi=145.5
889A CJK UNIFIED IDEOGRAPH-#889A, IRGKangXi=1114.220, RSKangXi=145.5, Def{greave; knee-pads; buskins}
889B CJK UNIFIED IDEOGRAPH-#889B, IRGKangXi=1114.240, RSKangXi=145.5
889C CJK UNIFIED IDEOGRAPH-#889C, IRGKangXi=1114.250, RSKangXi=145.5, Def{socks, stockings}
889D CJK UNIFIED IDEOGRAPH-#889D, IRGKangXi=1114.270, RSKangXi=145.5
889E CJK UNIFIED IDEOGRAPH-#889E, IRGKangXi=1114.280, RSKangXi=145.5, Def{ceremonial dress worn by the emperor}
889F CJK UNIFIED IDEOGRAPH-#889F, IRGKangXi=1114.290, RSKangXi=145.5, Def{book cover; satchel or bag}
88A0 CJK UNIFIED IDEOGRAPH-#88A0, IRGKangXi=1114.300, RSKangXi=145.5, Def{book cover; satchel or bag}
88A1 CJK UNIFIED IDEOGRAPH-#88A1, IRGKangXi=1114.310, RSKangXi=145.5
88A2 CJK UNIFIED IDEOGRAPH-#88A2, IRGKangXi=1114.340, RSKangXi=145.5, Def{robe}
88A3 CJK UNIFIED IDEOGRAPH-#88A3, IRGKangXi=1115.010, RSKangXi=145.5
88A4 CJK UNIFIED IDEOGRAPH-#88A4, IRGKangXi=1115.020, RSKangXi=145.5, Def{longitude, lengthwise; length}
88A5 CJK UNIFIED IDEOGRAPH-#88A5, IRGKangXi=1115.030, RSKangXi=145.5
88A6 CJK UNIFIED IDEOGRAPH-#88A6, IRGKangXi=1115.040, RSKangXi=145.5
88A7 CJK UNIFIED IDEOGRAPH-#88A7, IRGKangXi=1115.050, RSKangXi=145.5
88A8 CJK UNIFIED IDEOGRAPH-#88A8, IRGKangXi=1115.060, RSKangXi=145.5
88A9 CJK UNIFIED IDEOGRAPH-#88A9, IRGKangXi=1115.070, RSKangXi=145.5
88AA CJK UNIFIED IDEOGRAPH-#88AA, IRGKangXi=1115.080, RSKangXi=145.5, Def{sleeves; cuff}
88AB CJK UNIFIED IDEOGRAPH-#88AB, IRGKangXi=1115.100, RSKangXi=145.5, Def{passive indicator 'by'; bedding}
88AC CJK UNIFIED IDEOGRAPH-#88AC, IRGKangXi=1115.160, RSKangXi=145.5
88AD CJK UNIFIED IDEOGRAPH-#88AD, IRGKangXi=1115.211, RSKangXi=212.6, Def{raid, attack; inherit}
88AE CJK UNIFIED IDEOGRAPH-#88AE, IRGKangXi=1115.211, RSKangXi=145.5, Def{used as a synonym for U+4F60 你 when referring to deity}
88AF CJK UNIFIED IDEOGRAPH-#88AF, IRGKangXi=1115.211, RSKangXi=145.6, Def{raincoat}
88B0 CJK UNIFIED IDEOGRAPH-#88B0, IRGKangXi=1115.211, RSKangXi=145.5
88B1 CJK UNIFIED IDEOGRAPH-#88B1, IRGKangXi=1115.220, RSKangXi=145.6, Def{a piece of cloth used wrap bundles}
88B2 CJK UNIFIED IDEOGRAPH-#88B2, IRGKangXi=1115.240, RSKangXi=145.6
88B3 CJK UNIFIED IDEOGRAPH-#88B3, IRGKangXi=1115.250, Def{spread one's clothes}
88B4 CJK UNIFIED IDEOGRAPH-#88B4, IRGKangXi=1115.260, RSKangXi=145.6, Def{pants; trousers; panties}
88B5 CJK UNIFIED IDEOGRAPH-#88B5, IRGKangXi=1115.280, RSKangXi=145.6, Def{lapel; hidden lapel of coat}
88B6 CJK UNIFIED IDEOGRAPH-#88B6, IRGKangXi=1115.290, RSKangXi=145.6
88B7 CJK UNIFIED IDEOGRAPH-#88B7, IRGKangXi=1115.300, RSKangXi=145.6, Def{lined garment}
88B8 CJK UNIFIED IDEOGRAPH-#88B8, IRGKangXi=1116.030, RSKangXi=145.6
88B9 CJK UNIFIED IDEOGRAPH-#88B9, IRGKangXi=1116.050, RSKangXi=145.6
88BA CJK UNIFIED IDEOGRAPH-#88BA, IRGKangXi=1116.060, RSKangXi=145.6, Def{hold up}
88BB CJK UNIFIED IDEOGRAPH-#88BB, IRGKangXi=1116.080, RSKangXi=145.6
88BC CJK UNIFIED IDEOGRAPH-#88BC, IRGKangXi=1116.090, RSKangXi=145.6
88BD CJK UNIFIED IDEOGRAPH-#88BD, IRGKangXi=1116.100, RSKangXi=145.6, Def{clothes}
88BE CJK UNIFIED IDEOGRAPH-#88BE, IRGKangXi=1116.120, RSKangXi=145.6
88BF CJK UNIFIED IDEOGRAPH-#88BF, IRGKangXi=1116.130, RSKangXi=145.6, Def{gown}
88C0 CJK UNIFIED IDEOGRAPH-#88C0, IRGKangXi=1116.150, RSKangXi=145.6, Def{mat, coverlet; underwear}
88C1 CJK UNIFIED IDEOGRAPH-#88C1, IRGKangXi=1116.160, RSKangXi=145.6, Def{cut out; decrease}
88C2 CJK UNIFIED IDEOGRAPH-#88C2, IRGKangXi=1116.180, RSKangXi=145.6, Def{split, crack, break open; rend}
88C3 CJK UNIFIED IDEOGRAPH-#88C3, IRGKangXi=1116.341, RSKangXi=145.6, Def{old ceremonial garb; samurai garb}
88C4 CJK UNIFIED IDEOGRAPH-#88C4, IRGKangXi=1116.341, RSKangXi=145.6, Def{sleeve length}
88C5 CJK UNIFIED IDEOGRAPH-#88C5, IRGKangXi=1116.341, RSKangXi=145.6, Def{dress, clothes, attire; fill}
88C6 CJK UNIFIED IDEOGRAPH-#88C6, IRGKangXi=1116.341, RSKangXi=145.6, Def{crotch or seat of pants; pants}
88C7 CJK UNIFIED IDEOGRAPH-#88C7, IRGKangXi=1116.341, RSKangXi=145.6, Def{(Cant.) a shirt (Engl. loanword)}
88C8 CJK UNIFIED IDEOGRAPH-#88C8, IRGKangXi=1116.341, RSKangXi=145.6, Def{trousers, pants, shorts, drawers}
88C9 CJK UNIFIED IDEOGRAPH-#88C9, IRGKangXi=1116.341, RSKangXi=145.6, Def{seam in a garment}
88CA CJK UNIFIED IDEOGRAPH-#88CA, IRGKangXi=1116.350, RSKangXi=145.7, Def{curling upwards; wavering gently}
88CB CJK UNIFIED IDEOGRAPH-#88CB, IRGKangXi=1116.360, RSKangXi=145.7, Def{cotton clothes of a boy servant}
88CC CJK UNIFIED IDEOGRAPH-#88CC, IRGKangXi=1116.380, RSKangXi=145.7, Def{lined garment}
88CD CJK UNIFIED IDEOGRAPH-#88CD, IRGKangXi=1116.400, RSKangXi=145.7, Def{a border or band on the edge of a dress}
88CE CJK UNIFIED IDEOGRAPH-#88CE, IRGKangXi=1117.020, RSKangXi=145.7, Def{to take off the clothes and expose the body. to carry in the girdle}
88CF CJK UNIFIED IDEOGRAPH-#88CF, IRGKangXi=1117.040, RSKangXi=145.7, Def{inside, interior, within}
88D0 CJK UNIFIED IDEOGRAPH-#88D0, IRGKangXi=1117.050, RSKangXi=145.7
88D1 CJK UNIFIED IDEOGRAPH-#88D1, IRGKangXi=1117.070, RSKangXi=145.7
88D2 CJK UNIFIED IDEOGRAPH-#88D2, IRGKangXi=1117.080, RSKangXi=145.7, Def{collect, gather, assemble; praise}
88D3 CJK UNIFIED IDEOGRAPH-#88D3, IRGKangXi=1117.100, RSKangXi=145.7
88D4 CJK UNIFIED IDEOGRAPH-#88D4, IRGKangXi=1117.120, RSKangXi=145.7, Def{progeny, descendants, posterity}
88D5 CJK UNIFIED IDEOGRAPH-#88D5, IRGKangXi=1117.160, RSKangXi=145.7, Def{abundant, rich, plentiful}
88D6 CJK UNIFIED IDEOGRAPH-#88D6, IRGKangXi=1117.170, RSKangXi=145.7
88D7 CJK UNIFIED IDEOGRAPH-#88D7, IRGKangXi=1117.200, RSKangXi=145.7
88D8 CJK UNIFIED IDEOGRAPH-#88D8, IRGKangXi=1117.220, RSKangXi=145.7, Def{fur garments; surname}
88D9 CJK UNIFIED IDEOGRAPH-#88D9, IRGKangXi=1117.240, RSKangXi=145.7, Def{skirt, apron, petticoat}
88DA CJK UNIFIED IDEOGRAPH-#88DA, IRGKangXi=1117.260, RSKangXi=145.7
88DB CJK UNIFIED IDEOGRAPH-#88DB, IRGKangXi=1117.270, RSKangXi=145.7, Def{to wrap and bind; damp; a book bag}
88DC CJK UNIFIED IDEOGRAPH-#88DC, IRGKangXi=1117.300, RSKangXi=145.7, Def{mend, patch, fix, repair, restore}
88DD CJK UNIFIED IDEOGRAPH-#88DD, IRGKangXi=1118.010, RSKangXi=145.7, Def{dress, clothes; decorate; fill}
88DE CJK UNIFIED IDEOGRAPH-#88DE, IRGKangXi=1118.040, RSKangXi=145.7
88DF CJK UNIFIED IDEOGRAPH-#88DF, IRGKangXi=1118.050, RSKangXi=145.7, Def{a cassock or robe of a monk}
88E0 CJK UNIFIED IDEOGRAPH-#88E0, IRGKangXi=1118.060, RSKangXi=145.7, Def{a short skirt}
88E1 CJK UNIFIED IDEOGRAPH-#88E1, IRGKangXi=1118.131, RSKangXi=145.7, Def{inside, interior, within}
88E2 CJK UNIFIED IDEOGRAPH-#88E2, IRGKangXi=1120.151, RSKangXi=145.7, Def{folding purse inserted in belt}
88E3 CJK UNIFIED IDEOGRAPH-#88E3, IRGKangXi=1118.131, RSKangXi=145.7, Def{draw one's hands into sleeve}
88E4 CJK UNIFIED IDEOGRAPH-#88E4, IRGKangXi=1118.131, RSKangXi=145.7, Def{trousers, pants}
88E5 CJK UNIFIED IDEOGRAPH-#88E5, IRGKangXi=1118.131, RSKangXi=145.7, Def{folds}
88E6 CJK UNIFIED IDEOGRAPH-#88E6, IRGKangXi=1118.140, RSKangXi=145.9
88E7 CJK UNIFIED IDEOGRAPH-#88E7, IRGKangXi=1118.160, RSKangXi=145.8
88E8 CJK UNIFIED IDEOGRAPH-#88E8, IRGKangXi=1118.180, RSKangXi=145.8, Def{aid, benefit, help; supplement}
88E9 CJK UNIFIED IDEOGRAPH-#88E9, IRGKangXi=1118.190, RSKangXi=145.8
88EA CJK UNIFIED IDEOGRAPH-#88EA, IRGKangXi=1118.210, Def{the sleeve}
88EB CJK UNIFIED IDEOGRAPH-#88EB, IRGKangXi=1118.230, RSKangXi=145.8
88EC CJK UNIFIED IDEOGRAPH-#88EC, IRGKangXi=1118.240, RSKangXi=145.8
88ED CJK UNIFIED IDEOGRAPH-#88ED, IRGKangXi=1118.260, RSKangXi=145.8
88EE CJK UNIFIED IDEOGRAPH-#88EE, IRGKangXi=1118.280, RSKangXi=145.8
88EF CJK UNIFIED IDEOGRAPH-#88EF, IRGKangXi=1118.290, RSKangXi=145.8, Def{coverlet; bedspread}
88F0 CJK UNIFIED IDEOGRAPH-#88F0, IRGKangXi=1118.300, RSKangXi=145.8, Def{to mend clothes}
88F1 CJK UNIFIED IDEOGRAPH-#88F1, IRGKangXi=1118.320, RSKangXi=145.8, Def{to mount maps or scrolls to paste}
88F2 CJK UNIFIED IDEOGRAPH-#88F2, IRGKangXi=1118.350, RSKangXi=145.8, Def{waistcoat}
88F3 CJK UNIFIED IDEOGRAPH-#88F3, IRGKangXi=1118.360, RSKangXi=145.8, Def{clothes; skirt; beautiful}
88F4 CJK UNIFIED IDEOGRAPH-#88F4, IRGKangXi=1119.010, RSKangXi=145.8, Def{surname; look of a flowing gown}
88F5 CJK UNIFIED IDEOGRAPH-#88F5, IRGKangXi=1119.020, RSKangXi=145.8, Def{surname; look of a flowing gown}
88F6 CJK UNIFIED IDEOGRAPH-#88F6, IRGKangXi=1119.030, RSKangXi=145.8
88F7 CJK UNIFIED IDEOGRAPH-#88F7, IRGKangXi=1119.050, RSKangXi=145.8
88F8 CJK UNIFIED IDEOGRAPH-#88F8, IRGKangXi=1119.100, RSKangXi=145.8, Def{bare, nude; undress, strip}
88F9 CJK UNIFIED IDEOGRAPH-#88F9, IRGKangXi=1119.120, RSKangXi=145.8, Def{wrap, bind; encircle, confine}
88FA CJK UNIFIED IDEOGRAPH-#88FA, IRGKangXi=1119.130, RSKangXi=145.8
88FB CJK UNIFIED IDEOGRAPH-#88FB, IRGKangXi=1119.140, RSKangXi=145.8
88FC CJK UNIFIED IDEOGRAPH-#88FC, IRGKangXi=1119.190, RSKangXi=145.8, Def{to take off one's top; divest}
88FD CJK UNIFIED IDEOGRAPH-#88FD, IRGKangXi=1119.200, RSKangXi=145.8, Def{make, manufacture; produce}
88FE CJK UNIFIED IDEOGRAPH-#88FE, IRGKangXi=1119.210, RSKangXi=145.8, Def{lapel, border of garment; skirt}
88FF CJK UNIFIED IDEOGRAPH-#88FF, IRGKangXi=1119.230, RSKangXi=145.8
8900 CJK UNIFIED IDEOGRAPH-#8900, IRGKangXi=1119.250, RSKangXi=145.8
8901 CJK UNIFIED IDEOGRAPH-#8901, IRGKangXi=1120.070, RSKangXi=145.8
8902 CJK UNIFIED IDEOGRAPH-#8902, IRGKangXi=1120.151, RSKangXi=145.8, Def{jacket, overcoat, coat; gown}
8903 CJK UNIFIED IDEOGRAPH-#8903, IRGKangXi=1120.151, RSKangXi=145.8, Def{a seam in a garment}
8904 CJK UNIFIED IDEOGRAPH-#8904, IRGKangXi=1120.151, RSKangXi=145.8, Def{a skirt}
8905 CJK UNIFIED IDEOGRAPH-#8905, IRGKangXi=1120.180, RSKangXi=145.9
8906 CJK UNIFIED IDEOGRAPH-#8906, IRGKangXi=1120.210, RSKangXi=145.9
8907 CJK UNIFIED IDEOGRAPH-#8907, IRGKangXi=1120.220, RSKangXi=145.9, Def{repeat, double, overlap}
8908 CJK UNIFIED IDEOGRAPH-#8908, IRGKangXi=1120.230
8909 CJK UNIFIED IDEOGRAPH-#8909, IRGKangXi=1120.240, RSKangXi=145.9, Def{short garments}
890A CJK UNIFIED IDEOGRAPH-#890A, IRGKangXi=1120.250, RSKangXi=145.9, Def{cramped, narrow, crowded; mean}
890B CJK UNIFIED IDEOGRAPH-#890B, IRGKangXi=1120.300, RSKangXi=145.9
890C CJK UNIFIED IDEOGRAPH-#890C, IRGKangXi=1120.340, RSKangXi=145.9, Def{trousers, pants, shorts, drawers}
890D CJK UNIFIED IDEOGRAPH-#890D, IRGKangXi=1120.350, RSKangXi=145.9
890E CJK UNIFIED IDEOGRAPH-#890E, IRGKangXi=1120.370, RSKangXi=145.9, Def{sleeve; ample flowing robes}
890F CJK UNIFIED IDEOGRAPH-#890F, IRGKangXi=1120.380, RSKangXi=145.9, Def{sleeve; ample flowing robes}
8910 CJK UNIFIED IDEOGRAPH-#8910, IRGKangXi=1120.420, RSKangXi=145.9, Def{coarse woolen cloth; dull, dark}
8911 CJK UNIFIED IDEOGRAPH-#8911, IRGKangXi=1121.010, RSKangXi=145.9
8912 CJK UNIFIED IDEOGRAPH-#8912, IRGKangXi=1121.020, RSKangXi=145.9, Def{praise, commend, honor, cite}
8913 CJK UNIFIED IDEOGRAPH-#8913, IRGKangXi=1121.030, RSKangXi=145.9, Def{swaddling cloth; infancy}
8914 CJK UNIFIED IDEOGRAPH-#8914, IRGKangXi=1121.040, RSKangXi=145.9, Def{complex; double}
8915 CJK UNIFIED IDEOGRAPH-#8915, IRGKangXi=1121.070, RSKangXi=145.9, Def{shirt}
8916 CJK UNIFIED IDEOGRAPH-#8916, IRGKangXi=1121.080, RSKangXi=145.9
8917 CJK UNIFIED IDEOGRAPH-#8917, IRGKangXi=1121.100, RSKangXi=145.9
8918 CJK UNIFIED IDEOGRAPH-#8918, IRGKangXi=1121.170, RSKangXi=145.9, Def{ceremonial gowns of a queen}
8919 CJK UNIFIED IDEOGRAPH-#8919, IRGKangXi=1121.190, RSKangXi=145.9, Def{paper or cloth pasted together}
891A CJK UNIFIED IDEOGRAPH-#891A, IRGKangXi=1121.210, RSKangXi=145.9, Def{bag, valise; stuff, pad; surname}
891B CJK UNIFIED IDEOGRAPH-#891B, IRGKangXi=1121.321, RSKangXi=145.9, Def{lapel, collar; tattered, threadbare}
891C CJK UNIFIED IDEOGRAPH-#891C, IRGKangXi=1121.321, RSKangXi=145.9
891D CJK UNIFIED IDEOGRAPH-#891D, IRGKangXi=1121.321, RSKangXi=145.9, Def{unlined garment}
891E CJK UNIFIED IDEOGRAPH-#891E, IRGKangXi=1121.350, RSKangXi=145.10, Def{a robe}
891F CJK UNIFIED IDEOGRAPH-#891F, IRGKangXi=1121.360, RSKangXi=145.10, Def{inner shirt or singlet}
8920 CJK UNIFIED IDEOGRAPH-#8920, IRGKangXi=1121.400, RSKangXi=145.10
8921 CJK UNIFIED IDEOGRAPH-#8921, IRGKangXi=1122.060, RSKangXi=145.10, Def{girdle; loincloth; pouch, bag}
8922 CJK UNIFIED IDEOGRAPH-#8922, IRGKangXi=1122.070, RSKangXi=145.10, Def{to carry in the bosom or the sleeve; to wrap, to conceal}
8923 CJK UNIFIED IDEOGRAPH-#8923, IRGKangXi=1122.080, RSKangXi=145.10
8924 CJK UNIFIED IDEOGRAPH-#8924, IRGKangXi=1122.120, RSKangXi=145.10
8925 CJK UNIFIED IDEOGRAPH-#8925, IRGKangXi=1122.150, RSKangXi=145.10, Def{mattress, cushion; bedding}
8926 CJK UNIFIED IDEOGRAPH-#8926, IRGKangXi=1122.170, RSKangXi=145.10, Def{stupid, dull, ignorant, doltish; (Cant.) to tie up, bind}
8927 CJK UNIFIED IDEOGRAPH-#8927, IRGKangXi=1122.180, RSKangXi=145.10, Def{unlined clothes; light overcoat}
8928 CJK UNIFIED IDEOGRAPH-#8928, IRGKangXi=1122.190, RSKangXi=145.10
8929 CJK UNIFIED IDEOGRAPH-#8929, IRGKangXi=1122.210, RSKangXi=145.10
892A CJK UNIFIED IDEOGRAPH-#892A, IRGKangXi=1122.220, RSKangXi=145.10, Def{strip, undress; fall off; fade}
892B CJK UNIFIED IDEOGRAPH-#892B, IRGKangXi=1122.230, RSKangXi=145.10, Def{strip, tear off, undress}
892C CJK UNIFIED IDEOGRAPH-#892C, IRGKangXi=1122.240, RSKangXi=145.10
892D CJK UNIFIED IDEOGRAPH-#892D, IRGKangXi=1122.280, RSKangXi=145.10
892E CJK UNIFIED IDEOGRAPH-#892E, IRGKangXi=1122.290, RSKangXi=145.10
892F CJK UNIFIED IDEOGRAPH-#892F, IRGKangXi=1122.310, RSKangXi=145.10, Def{children's garments. a mat for wrapping garments}
8930 CJK UNIFIED IDEOGRAPH-#8930, IRGKangXi=1122.320, RSKangXi=145.10, Def{underclothing; to pick up one's skirts}
8931 CJK UNIFIED IDEOGRAPH-#8931, IRGKangXi=1122.330, RSKangXi=145.10, Def{to carry in the bosom or the sleeve; to wrap, to conceal}
8932 CJK UNIFIED IDEOGRAPH-#8932, IRGKangXi=1122.391, RSKangXi=145.10, Def{trousers, pants}
8933 CJK UNIFIED IDEOGRAPH-#8933, IRGKangXi=1124.141, RSKangXi=145.11, Def{folding purse inserted in belt}
8934 CJK UNIFIED IDEOGRAPH-#8934, IRGKangXi=1122.391, RSKangXi=145.10, Def{ragged, tattered, threadbare}
8935 CJK UNIFIED IDEOGRAPH-#8935, IRGKangXi=1122.400, RSKangXi=145.11, Def{bridal veil}
8936 CJK UNIFIED IDEOGRAPH-#8936, IRGKangXi=1122.410, RSKangXi=145.11, Def{pleat, crease, wrinkles}
8937 CJK UNIFIED IDEOGRAPH-#8937, IRGKangXi=1123.020, RSKangXi=145.11
8938 CJK UNIFIED IDEOGRAPH-#8938, IRGKangXi=1123.050, RSKangXi=145.11, Def{lapel, collar; tattered, threadbare}
8939 CJK UNIFIED IDEOGRAPH-#8939, IRGKangXi=1123.090, RSKangXi=145.11
893A CJK UNIFIED IDEOGRAPH-#893A, IRGKangXi=1123.100, RSKangXi=145.11, Def{dirty, ragged; undress, to treat with irreverence}
893B CJK UNIFIED IDEOGRAPH-#893B, IRGKangXi=1123.110, RSKangXi=145.11, Def{dirty, ragged; slight, insult, treat with disrespect}
893C CJK UNIFIED IDEOGRAPH-#893C, IRGKangXi=1123.120, RSKangXi=145.11
893D CJK UNIFIED IDEOGRAPH-#893D, IRGKangXi=1123.130, RSKangXi=145.11, Def{cushion}
893E CJK UNIFIED IDEOGRAPH-#893E, IRGKangXi=1123.150, RSKangXi=145.11
893F CJK UNIFIED IDEOGRAPH-#893F, IRGKangXi=1123.180, RSKangXi=145.11
8940 CJK UNIFIED IDEOGRAPH-#8940, IRGKangXi=1123.190, RSKangXi=145.11, Def{a pleat, fold, tuck, crease}
8941 CJK UNIFIED IDEOGRAPH-#8941, IRGKangXi=1123.200, RSKangXi=145.11, Def{swaddling clothes}
8942 CJK UNIFIED IDEOGRAPH-#8942, IRGKangXi=1123.240, RSKangXi=145.11
8943 CJK UNIFIED IDEOGRAPH-#8943, IRGKangXi=1123.270, RSKangXi=145.11, Def{commend, honor, cite}
8944 CJK UNIFIED IDEOGRAPH-#8944, IRGKangXi=1123.310, RSKangXi=145.11, Def{aid, help, assist; undress}
8945 CJK UNIFIED IDEOGRAPH-#8945, IRGKangXi=1124.141, RSKangXi=145.11
8946 CJK UNIFIED IDEOGRAPH-#8946, IRGKangXi=1124.150, RSKangXi=145.12, Def{hood or cowl}
8947 CJK UNIFIED IDEOGRAPH-#8947, IRGKangXi=1125.151, RSKangXi=145.12, Def{folds}
8948 CJK UNIFIED IDEOGRAPH-#8948, IRGKangXi=1124.160, RSKangXi=145.12
8949 CJK UNIFIED IDEOGRAPH-#8949, IRGKangXi=1124.210, RSKangXi=145.12
894A CJK UNIFIED IDEOGRAPH-#894A, IRGKangXi=1124.230, RSKangXi=145.12
894B CJK UNIFIED IDEOGRAPH-#894B, IRGKangXi=1124.250, RSKangXi=145.12, Def{collar}
894C CJK UNIFIED IDEOGRAPH-#894C, IRGKangXi=1124.310, RSKangXi=145.12, Def{unlined garment}
894D CJK UNIFIED IDEOGRAPH-#894D, IRGKangXi=1124.330, RSKangXi=145.12, Def{mixed, blended; mix, mingle}
894E CJK UNIFIED IDEOGRAPH-#894E, IRGKangXi=1124.340, RSKangXi=145.12
894F CJK UNIFIED IDEOGRAPH-#894F, IRGKangXi=1124.360, RSKangXi=145.12, Def{raincoat}
8950 CJK UNIFIED IDEOGRAPH-#8950, IRGKangXi=1124.400, RSKangXi=145.12
8951 CJK UNIFIED IDEOGRAPH-#8951, IRGKangXi=1124.430, RSKangXi=145.12
8952 CJK UNIFIED IDEOGRAPH-#8952, IRGKangXi=1125.030, RSKangXi=145.12
8953 CJK UNIFIED IDEOGRAPH-#8953, IRGKangXi=1125.040, RSKangXi=145.12
8954 CJK UNIFIED IDEOGRAPH-#8954, IRGKangXi=1124.141, RSKangXi=145.11
8955 CJK UNIFIED IDEOGRAPH-#8955, IRGKangXi=1125.151, RSKangXi=145.12
8956 CJK UNIFIED IDEOGRAPH-#8956, IRGKangXi=1125.170, RSKangXi=145.13, Def{outer garments; coat, jacket}
8957 CJK UNIFIED IDEOGRAPH-#8957, IRGKangXi=1125.180, RSKangXi=145.13
8958 CJK UNIFIED IDEOGRAPH-#8958, IRGKangXi=1125.200, RSKangXi=145.13
8959 CJK UNIFIED IDEOGRAPH-#8959, IRGKangXi=1125.220, RSKangXi=145.13
895A CJK UNIFIED IDEOGRAPH-#895A, IRGKangXi=1125.240, RSKangXi=145.13, Def{grave clothes}
895B CJK UNIFIED IDEOGRAPH-#895B, IRGKangXi=1125.280, RSKangXi=145.13, Def{fine clothes}
895C CJK UNIFIED IDEOGRAPH-#895C, IRGKangXi=1125.290, RSKangXi=145.13, Def{flutter; shaking or vibrating}
895D CJK UNIFIED IDEOGRAPH-#895D, IRGKangXi=1125.300, RSKangXi=145.13, Def{draw one's hands into sleeve}
895E CJK UNIFIED IDEOGRAPH-#895E, IRGKangXi=1125.330, RSKangXi=145.13, Def{fold, pleat, crease}
895F CJK UNIFIED IDEOGRAPH-#895F, IRGKangXi=1125.350, RSKangXi=145.13, Def{lapel, collar}
8960 CJK UNIFIED IDEOGRAPH-#8960, IRGKangXi=1125.370, RSKangXi=145.13, Def{crotch or seat of pants; pants}
8961 CJK UNIFIED IDEOGRAPH-#8961, IRGKangXi=1125.380, RSKangXi=145.13, Def{short coat}
8962 CJK UNIFIED IDEOGRAPH-#8962, IRGKangXi=1126.010, RSKangXi=145.13, Def{strip; lay bare; bared; naked}
8963 CJK UNIFIED IDEOGRAPH-#8963, IRGKangXi=1126.180, RSKangXi=145.14
8964 CJK UNIFIED IDEOGRAPH-#8964, IRGKangXi=1126.190, RSKangXi=145.14, Def{ragged, tattered, threadbare}
8965 CJK UNIFIED IDEOGRAPH-#8965, IRGKangXi=1126.230
8966 CJK UNIFIED IDEOGRAPH-#8966, IRGKangXi=1126.240, RSKangXi=145.14, Def{short coat, jacket; fine silk fab}
8967 CJK UNIFIED IDEOGRAPH-#8967, IRGKangXi=1126.250, RSKangXi=145.14
8968 CJK UNIFIED IDEOGRAPH-#8968, IRGKangXi=1126.371, RSKangXi=145.14
8969 CJK UNIFIED IDEOGRAPH-#8969, IRGKangXi=1126.380, RSKangXi=145.15
896A CJK UNIFIED IDEOGRAPH-#896A, IRGKangXi=1126.400, RSKangXi=145.15, Def{socks, stockings}
896B CJK UNIFIED IDEOGRAPH-#896B, IRGKangXi=1126.440, RSKangXi=145.15, Def{raincoat}
896C CJK UNIFIED IDEOGRAPH-#896C, IRGKangXi=1126.450, RSKangXi=145.15, Def{lower part of a robe}
896D CJK UNIFIED IDEOGRAPH-#896D, IRGKangXi=1126.460, RSKangXi=145.15, Def{tuck up hem of garment and wrap}
896E CJK UNIFIED IDEOGRAPH-#896E, IRGKangXi=1126.490, RSKangXi=145.15, Def{collar; to expose}
896F CJK UNIFIED IDEOGRAPH-#896F, IRGKangXi=1127.010, RSKangXi=145.16, Def{underwear; inner garments}
8970 CJK UNIFIED IDEOGRAPH-#8970, IRGKangXi=1127.040, RSKangXi=145.16
8971 CJK UNIFIED IDEOGRAPH-#8971, IRGKangXi=1127.050, RSKangXi=145.16, Def{legs of trousers; overalls worn by workmen}
8972 CJK UNIFIED IDEOGRAPH-#8972, IRGKangXi=1127.060, RSKangXi=145.16, Def{raid, attack; inherit}
8973 CJK UNIFIED IDEOGRAPH-#8973, IRGKangXi=1127.130, RSKangXi=145.17
8974 CJK UNIFIED IDEOGRAPH-#8974, IRGKangXi=1127.170, RSKangXi=145.17, Def{a one piece garment}
8975 CJK UNIFIED IDEOGRAPH-#8975, IRGKangXi=1127.200, RSKangXi=145.18, Def{a pleat in a skirt}
8976 CJK UNIFIED IDEOGRAPH-#8976, IRGKangXi=1127.240, RSKangXi=145.18, Def{ignorant; naive; unsophisticated}
8977 CJK UNIFIED IDEOGRAPH-#8977, IRGKangXi=1127.261, RSKangXi=145.18, Def{a cord for holding up sleeves}
8978 CJK UNIFIED IDEOGRAPH-#8978, IRGKangXi=1127.270, RSKangXi=145.19
8979 CJK UNIFIED IDEOGRAPH-#8979, IRGKangXi=1127.280, RSKangXi=145.19
897A CJK UNIFIED IDEOGRAPH-#897A, IRGKangXi=1127.290, RSKangXi=145.19
897B CJK UNIFIED IDEOGRAPH-#897B, IRGKangXi=1127.300, RSKangXi=145.19, Def{a loop; a belt or band}
897C CJK UNIFIED IDEOGRAPH-#897C, IRGKangXi=1127.330, RSKangXi=145.19, Def{'kimono' sleeve}
897D CJK UNIFIED IDEOGRAPH-#897D, IRGKangXi=1128.021, RSKangXi=145.17
897E CJK UNIFIED IDEOGRAPH-#897E, IRGKangXi=1128.090, RSKangXi=146.0, Def{cover; KangXi radical 146}
897F CJK UNIFIED IDEOGRAPH-#897F, IRGKangXi=1128.100, RSKangXi=146.0, Def{west(ern); westward, occident}
8980 CJK UNIFIED IDEOGRAPH-#8980, IRGKangXi=1128.101, RSKangXi=146.0, Def{variant of radical 146}
8981 CJK UNIFIED IDEOGRAPH-#8981, IRGKangXi=1128.160, RSKangXi=146.3, Def{necessary, essential; necessity}
8982 CJK UNIFIED IDEOGRAPH-#8982, IRGKangXi=1128.270, RSKangXi=146.5, Def{to throw a rider}
8983 CJK UNIFIED IDEOGRAPH-#8983, IRGKangXi=1128.290, RSKangXi=146.6, Def{reach to, spread to; extensive}
8984 CJK UNIFIED IDEOGRAPH-#8984, IRGKangXi=1128.321, RSKangXi=146.6
8985 CJK UNIFIED IDEOGRAPH-#8985, IRGKangXi=1128.321, RSKangXi=146.7
8986 CJK UNIFIED IDEOGRAPH-#8986, IRGKangXi=1129.090, RSKangXi=146.12, Def{cover; tip over; return; reply}
8987 CJK UNIFIED IDEOGRAPH-#8987, IRGKangXi=1129.100, RSKangXi=146.13, Def{rule by might rather than right}
8988 CJK UNIFIED IDEOGRAPH-#8988, IRGKangXi=1129.110, RSKangXi=146.13, Def{investigate, consider, examine}
8989 CJK UNIFIED IDEOGRAPH-#8989, IRGKangXi=1129.140, RSKangXi=146.17, Def{variant of 羇 U+7F87, inn; to lodge; to travel}
898A CJK UNIFIED IDEOGRAPH-#898A, IRGKangXi=1129.150, RSKangXi=146.19, Def{halter; restrain, hold, control}
898B CJK UNIFIED IDEOGRAPH-#898B, IRGKangXi=1133.010, RSKangXi=147.0, Def{see, observe, behold; perceive}
898C CJK UNIFIED IDEOGRAPH-#898C, IRGKangXi=1133.031, Def{see, observe, view; appearance}
898D CJK UNIFIED IDEOGRAPH-#898D, IRGKangXi=1133.040, RSKangXi=147.3
898E CJK UNIFIED IDEOGRAPH-#898E, IRGKangXi=1133.050, Def{place name}
898F CJK UNIFIED IDEOGRAPH-#898F, IRGKangXi=1133.110, RSKangXi=147.4, Def{rules, regulations, customs, law}
8990 CJK UNIFIED IDEOGRAPH-#8990, IRGKangXi=1133.120, RSKangXi=147.4, Def{to sleep; to realize, feel}
8991 CJK UNIFIED IDEOGRAPH-#8991, IRGKangXi=1134.010, RSKangXi=147.4
8992 CJK UNIFIED IDEOGRAPH-#8992, IRGKangXi=1134.020, RSKangXi=147.4
8993 CJK UNIFIED IDEOGRAPH-#8993, IRGKangXi=1134.030, RSKangXi=147.4, Def{seek; search}
8994 CJK UNIFIED IDEOGRAPH-#8994, IRGKangXi=1134.040, RSKangXi=147.4, Def{to search for; to look after}
8995 CJK UNIFIED IDEOGRAPH-#8995, IRGKangXi=1134.130, RSKangXi=147.5
8996 CJK UNIFIED IDEOGRAPH-#8996, IRGKangXi=1134.210, RSKangXi=147.4, Def{look at, inspect, observe, see}
8997 CJK UNIFIED IDEOGRAPH-#8997, IRGKangXi=1134.320, RSKangXi=147.5, Def{peek}
8998 CJK UNIFIED IDEOGRAPH-#8998, IRGKangXi=1134.330, RSKangXi=147.5, Def{peek; spy on, watch; investigate}
8999 CJK UNIFIED IDEOGRAPH-#8999, IRGKangXi=1134.350, RSKangXi=147.2, Def{explain in detail}
899A CJK UNIFIED IDEOGRAPH-#899A, IRGKangXi=1134.361, RSKangXi=147.5, Def{to wake up from sleep; conscious}
899B CJK UNIFIED IDEOGRAPH-#899B, IRGKangXi=1135.010, RSKangXi=147.6
899C CJK UNIFIED IDEOGRAPH-#899C, IRGKangXi=1135.050, RSKangXi=147.6, Def{mission}
899D CJK UNIFIED IDEOGRAPH-#899D, IRGKangXi=1135.110, RSKangXi=147.7
899E CJK UNIFIED IDEOGRAPH-#899E, IRGKangXi=1135.130, RSKangXi=147.7
899F CJK UNIFIED IDEOGRAPH-#899F, IRGKangXi=1135.160, RSKangXi=147.7
89A0 CJK UNIFIED IDEOGRAPH-#89A0, IRGKangXi=1135.180, RSKangXi=147.7
89A1 CJK UNIFIED IDEOGRAPH-#89A1, IRGKangXi=1135.230, RSKangXi=147.7, Def{wizard}
89A2 CJK UNIFIED IDEOGRAPH-#89A2, IRGKangXi=1135.270, RSKangXi=147.8
89A3 CJK UNIFIED IDEOGRAPH-#89A3, IRGKangXi=1135.300, RSKangXi=147.8
89A4 CJK UNIFIED IDEOGRAPH-#89A4, IRGKangXi=1135.320, RSKangXi=147.8
89A5 CJK UNIFIED IDEOGRAPH-#89A5, IRGKangXi=1135.330, RSKangXi=147.8, Def{ashamed}
89A6 CJK UNIFIED IDEOGRAPH-#89A6, IRGKangXi=1135.390, RSKangXi=147.9, Def{desire strongly, covet, long for}
89A7 CJK UNIFIED IDEOGRAPH-#89A7, IRGKangXi=1135.400, RSKangXi=147.9, Def{look at, inspect; perceive}
89A8 CJK UNIFIED IDEOGRAPH-#89A8, IRGKangXi=1136.030, RSKangXi=147.9
89A9 CJK UNIFIED IDEOGRAPH-#89A9, IRGKangXi=1136.060, RSKangXi=147.9, Def{see, gaze at, witness}
89AA CJK UNIFIED IDEOGRAPH-#89AA, IRGKangXi=1136.120, RSKangXi=147.9, Def{relatives, parents; intimate}
89AB CJK UNIFIED IDEOGRAPH-#89AB, IRGKangXi=1136.230, RSKangXi=147.10
89AC CJK UNIFIED IDEOGRAPH-#89AC, IRGKangXi=1136.280, RSKangXi=147.10, Def{covet, long for, desire}
89AD CJK UNIFIED IDEOGRAPH-#89AD, IRGKangXi=1136.290, RSKangXi=147.10
89AE CJK UNIFIED IDEOGRAPH-#89AE, IRGKangXi=1136.310, RSKangXi=147.10
89AF CJK UNIFIED IDEOGRAPH-#89AF, IRGKangXi=1136.320, RSKangXi=147.10, Def{meet or see unexpectedly}
89B0 CJK UNIFIED IDEOGRAPH-#89B0, IRGKangXi=1137.010, RSKangXi=147.11, Def{to spy; to watch for}
89B1 CJK UNIFIED IDEOGRAPH-#89B1, IRGKangXi=1137.030, RSKangXi=147.11
89B2 CJK UNIFIED IDEOGRAPH-#89B2, IRGKangXi=1137.070, RSKangXi=147.11, Def{have imperial audience}
89B3 CJK UNIFIED IDEOGRAPH-#89B3, IRGKangXi=1137.091, RSKangXi=147.11, Def{see, observe, view; appearance}
89B4 CJK UNIFIED IDEOGRAPH-#89B4, IRGKangXi=1137.120, RSKangXi=147.12
89B5 CJK UNIFIED IDEOGRAPH-#89B5, IRGKangXi=1137.130, RSKangXi=147.12, Def{steal look; peep at; spy on}
89B6 CJK UNIFIED IDEOGRAPH-#89B6, IRGKangXi=1137.160, RSKangXi=147.12, Def{to look about; order, sequence; complicated thought which is not easy to express}
89B7 CJK UNIFIED IDEOGRAPH-#89B7, IRGKangXi=1137.201, RSKangXi=147.12, Def{peep at; watch, spy on}
89B8 CJK UNIFIED IDEOGRAPH-#89B8, IRGKangXi=1137.201, RSKangXi=147.12, Def{steal look; peep at; spy on}
89B9 CJK UNIFIED IDEOGRAPH-#89B9, IRGKangXi=1137.210, RSKangXi=147.13
89BA CJK UNIFIED IDEOGRAPH-#89BA, IRGKangXi=1137.230, RSKangXi=147.13, Def{to wake up from sleep; conscious}
89BB CJK UNIFIED IDEOGRAPH-#89BB, IRGKangXi=1137.270, RSKangXi=147.13
89BC CJK UNIFIED IDEOGRAPH-#89BC, IRGKangXi=1138.020, RSKangXi=147.14, Def{to explain in detail}
89BD CJK UNIFIED IDEOGRAPH-#89BD, IRGKangXi=1138.030, RSKangXi=147.14, Def{look at, inspect; perceive}
89BE CJK UNIFIED IDEOGRAPH-#89BE, IRGKangXi=1138.070, RSKangXi=147.15
89BF CJK UNIFIED IDEOGRAPH-#89BF, IRGKangXi=1138.080, RSKangXi=147.15, Def{see; interview; be admitted to audience}
89C0 CJK UNIFIED IDEOGRAPH-#89C0, IRGKangXi=1138.140, RSKangXi=147.18, Def{see, observe, view; appearance}
89C1 CJK UNIFIED IDEOGRAPH-#89C1, IRGKangXi=1139.051, RSKangXi=147.0, Def{see, observe, behold; perceive}
89C2 CJK UNIFIED IDEOGRAPH-#89C2, IRGKangXi=1139.051, RSKangXi=147.2, Def{see, observe, view; appearance}
89C3 CJK UNIFIED IDEOGRAPH-#89C3, IRGKangXi=1139.051, Def{place name}
89C4 CJK UNIFIED IDEOGRAPH-#89C4, IRGKangXi=1139.051, RSKangXi=147.4, Def{rules, regulations, customs, law}
89C5 CJK UNIFIED IDEOGRAPH-#89C5, IRGKangXi=1139.051, RSKangXi=87.4, Def{seek; search}
89C6 CJK UNIFIED IDEOGRAPH-#89C6, IRGKangXi=1139.051, RSKangXi=147.4, Def{look at, inspect, observe, see}
89C7 CJK UNIFIED IDEOGRAPH-#89C7, IRGKangXi=1139.051, RSKangXi=147.5, Def{peek; spy on, watch; investigate}
89C8 CJK UNIFIED IDEOGRAPH-#89C8, IRGKangXi=1139.051, RSKangXi=147.5, Def{look at, inspect; perceive}
89C9 CJK UNIFIED IDEOGRAPH-#89C9, IRGKangXi=1139.051, RSKangXi=147.5, Def{to wake up from sleep; conscious}
89CA CJK UNIFIED IDEOGRAPH-#89CA, IRGKangXi=1139.051, RSKangXi=147.6, Def{covet, long for, desire}
89CB CJK UNIFIED IDEOGRAPH-#89CB, IRGKangXi=1139.051, RSKangXi=147.7, Def{wizard}
89CC CJK UNIFIED IDEOGRAPH-#89CC, IRGKangXi=1139.051, RSKangXi=147.8, Def{see; interview; be admitted to audience}
89CD CJK UNIFIED IDEOGRAPH-#89CD, IRGKangXi=1139.051, RSKangXi=147.8, Def{ashamed}
89CE CJK UNIFIED IDEOGRAPH-#89CE, IRGKangXi=1139.051, RSKangXi=147.9, Def{desire strongly, covet, long for}
89CF CJK UNIFIED IDEOGRAPH-#89CF, IRGKangXi=1139.051, RSKangXi=147.10, Def{meet or see unexpectedly}
89D0 CJK UNIFIED IDEOGRAPH-#89D0, IRGKangXi=1139.051, RSKangXi=147.11, Def{have imperial audience}
89D1 CJK UNIFIED IDEOGRAPH-#89D1, IRGKangXi=1139.051, RSKangXi=147.11, Def{peep at; watch, spy on}
89D2 CJK UNIFIED IDEOGRAPH-#89D2, IRGKangXi=1139.060, RSKangXi=148.0, Def{horn; angle, corner; point}
89D3 CJK UNIFIED IDEOGRAPH-#89D3, IRGKangXi=1140.030, RSKangXi=148.2
89D4 CJK UNIFIED IDEOGRAPH-#89D4, IRGKangXi=1140.050, RSKangXi=148.2, Def{catty}
89D5 CJK UNIFIED IDEOGRAPH-#89D5, IRGKangXi=1140.100, RSKangXi=148.4, Def{coarse, rough, rude}
89D6 CJK UNIFIED IDEOGRAPH-#89D6, IRGKangXi=1140.120, RSKangXi=148.4, Def{to long for; dissatisfied to criticize}
89D7 CJK UNIFIED IDEOGRAPH-#89D7, IRGKangXi=1140.130, RSKangXi=148.4
89D8 CJK UNIFIED IDEOGRAPH-#89D8, IRGKangXi=1140.220, RSKangXi=148.4
89D9 CJK UNIFIED IDEOGRAPH-#89D9, IRGKangXi=1140.240, RSKangXi=148.4
89DA CJK UNIFIED IDEOGRAPH-#89DA, IRGKangXi=1140.310, RSKangXi=148.5, Def{jug, winecup, goblet; square}
89DB CJK UNIFIED IDEOGRAPH-#89DB, IRGKangXi=1141.050, RSKangXi=148.5
89DC CJK UNIFIED IDEOGRAPH-#89DC, IRGKangXi=1141.080, RSKangXi=148.6, Def{beak}
89DD CJK UNIFIED IDEOGRAPH-#89DD, IRGKangXi=1141.090, RSKangXi=148.5, Def{gore, butt; resist; push}
89DE CJK UNIFIED IDEOGRAPH-#89DE, IRGKangXi=1141.101, RSKangXi=148.5, Def{wine vessel; propose toast; feast}
89DF CJK UNIFIED IDEOGRAPH-#89DF, IRGKangXi=1141.130, RSKangXi=148.6
89E0 CJK UNIFIED IDEOGRAPH-#89E0, IRGKangXi=1141.150, RSKangXi=148.6
89E1 CJK UNIFIED IDEOGRAPH-#89E1, IRGKangXi=1141.160, RSKangXi=148.6, Def{antlers}
89E2 CJK UNIFIED IDEOGRAPH-#89E2, IRGKangXi=1141.190, RSKangXi=148.6
89E3 CJK UNIFIED IDEOGRAPH-#89E3, IRGKangXi=1142.010, RSKangXi=148.6, Def{loosen, unfasten, untie; explain}
89E4 CJK UNIFIED IDEOGRAPH-#89E4, IRGKangXi=1142.020, RSKangXi=148.6
89E5 CJK UNIFIED IDEOGRAPH-#89E5, IRGKangXi=1142.030, RSKangXi=148.6, Def{a cup made of horn obstinate}
89E6 CJK UNIFIED IDEOGRAPH-#89E6, IRGKangXi=1143.020, RSKangXi=148.6, Def{butt, ram, gore; touch}
89E7 CJK UNIFIED IDEOGRAPH-#89E7, IRGKangXi=1143.021, RSKangXi=148.6, Def{loosen, unfasten, untie; explain}
89E8 CJK UNIFIED IDEOGRAPH-#89E8, IRGKangXi=1143.040, RSKangXi=148.7
89E9 CJK UNIFIED IDEOGRAPH-#89E9, IRGKangXi=1143.070, RSKangXi=148.7, Def{strong}
89EA CJK UNIFIED IDEOGRAPH-#89EA, IRGKangXi=1143.090, RSKangXi=148.7
89EB CJK UNIFIED IDEOGRAPH-#89EB, IRGKangXi=1143.120, RSKangXi=148.7, Def{to start, tremble with fear}
89EC CJK UNIFIED IDEOGRAPH-#89EC, IRGKangXi=1143.170, RSKangXi=148.8
89ED CJK UNIFIED IDEOGRAPH-#89ED, IRGKangXi=1143.310, RSKangXi=148.8, Def{one turning up and one turning down}
89EE CJK UNIFIED IDEOGRAPH-#89EE, IRGKangXi=1143.320, RSKangXi=148.8
89EF CJK UNIFIED IDEOGRAPH-#89EF, IRGKangXi=1143.351, RSKangXi=148.8, Def{wine goblet made from horn}
89F0 CJK UNIFIED IDEOGRAPH-#89F0, IRGKangXi=1143.430, RSKangXi=148.9
89F1 CJK UNIFIED IDEOGRAPH-#89F1, IRGKangXi=1144.080, RSKangXi=148.9, Def{tartar horn; chilly wind}
89F2 CJK UNIFIED IDEOGRAPH-#89F2, IRGKangXi=1144.140, RSKangXi=148.10
89F3 CJK UNIFIED IDEOGRAPH-#89F3, IRGKangXi=1144.180, RSKangXi=148.10, Def{an ancient measure; a goblet; mean; frightened}
89F4 CJK UNIFIED IDEOGRAPH-#89F4, IRGKangXi=1144.250, RSKangXi=148.11, Def{wine vessel; propose toast; feast}
89F5 CJK UNIFIED IDEOGRAPH-#89F5, IRGKangXi=1144.320, RSKangXi=148.12, Def{a cup made of rhinoceros horn}
89F6 CJK UNIFIED IDEOGRAPH-#89F6, IRGKangXi=1145.030, RSKangXi=148.12, Def{wine goblet made from horn}
89F7 CJK UNIFIED IDEOGRAPH-#89F7, IRGKangXi=1145.090, RSKangXi=148.13, Def{to process or carve horns}
89F8 CJK UNIFIED IDEOGRAPH-#89F8, IRGKangXi=1145.110, RSKangXi=148.13, Def{touch; butt, ram, gore}
89F9 CJK UNIFIED IDEOGRAPH-#89F9, IRGKangXi=1145.150, RSKangXi=148.13
89FA CJK UNIFIED IDEOGRAPH-#89FA, IRGKangXi=1145.160, RSKangXi=148.14
89FB CJK UNIFIED IDEOGRAPH-#89FB, IRGKangXi=1145.220, RSKangXi=148.15
89FC CJK UNIFIED IDEOGRAPH-#89FC, IRGKangXi=1145.231, RSKangXi=148.15, Def{buckle}
89FD CJK UNIFIED IDEOGRAPH-#89FD, IRGKangXi=1145.250, RSKangXi=148.16
89FE CJK UNIFIED IDEOGRAPH-#89FE, IRGKangXi=1145.270, RSKangXi=148.16
89FF CJK UNIFIED IDEOGRAPH-#89FF, IRGKangXi=1145.280, RSKangXi=148.18, Def{a bodkin made of ivory, horn}
8A00 CJK UNIFIED IDEOGRAPH-#8A00, IRGKangXi=1146.010, RSKangXi=149.0, Def{words, speech; speak, say}
8A01 CJK UNIFIED IDEOGRAPH-#8A01, IRGKangXi=1146.011, RSKangXi=149.0, Def{KangXi radical 149}
8A02 CJK UNIFIED IDEOGRAPH-#8A02, IRGKangXi=1146.070, RSKangXi=149.2, Def{draw up agreement; arrange}
8A03 CJK UNIFIED IDEOGRAPH-#8A03, IRGKangXi=1146.100, RSKangXi=149.2, Def{obituary; give notice of death}
8A04 CJK UNIFIED IDEOGRAPH-#8A04, IRGKangXi=1146.110, RSKangXi=149.2
8A05 CJK UNIFIED IDEOGRAPH-#8A05, IRGKangXi=1146.120, RSKangXi=149.2
8A06 CJK UNIFIED IDEOGRAPH-#8A06, IRGKangXi=1146.130, RSKangXi=149.2
8A07 CJK UNIFIED IDEOGRAPH-#8A07, IRGKangXi=1146.150, RSKangXi=149.2, Def{the sound of a crash}
8A08 CJK UNIFIED IDEOGRAPH-#8A08, IRGKangXi=1147.010, RSKangXi=149.2, Def{plan, plot; strategem; scheme}
8A09 CJK UNIFIED IDEOGRAPH-#8A09, IRGKangXi=1147.020, RSKangXi=149.3
8A0A CJK UNIFIED IDEOGRAPH-#8A0A, IRGKangXi=1147.040, RSKangXi=149.3, Def{inquire; ask; examine; reproach}
8A0B CJK UNIFIED IDEOGRAPH-#8A0B, IRGKangXi=1147.110, RSKangXi=149.3
8A0C CJK UNIFIED IDEOGRAPH-#8A0C, IRGKangXi=1147.130, RSKangXi=149.3, Def{confusion; internal strife}
8A0D CJK UNIFIED IDEOGRAPH-#8A0D, IRGKangXi=1147.140, RSKangXi=149.3
8A0E CJK UNIFIED IDEOGRAPH-#8A0E, IRGKangXi=1147.160, RSKangXi=149.3, Def{to discuss; ask for, beg; demand; dun; marry}
8A0F CJK UNIFIED IDEOGRAPH-#8A0F, IRGKangXi=1147.180, RSKangXi=149.3, Def{boast, exaggerate; great, broad}
8A10 CJK UNIFIED IDEOGRAPH-#8A10, IRGKangXi=1148.010, RSKangXi=149.3, Def{expose other's secrets, pry}
8A11 CJK UNIFIED IDEOGRAPH-#8A11, IRGKangXi=1148.020, RSKangXi=149.3, Def{deceive, cheat; arrogant}
8A12 CJK UNIFIED IDEOGRAPH-#8A12, IRGKangXi=1148.040, RSKangXi=149.3, Def{hesitate to say, reluctant to speak}
8A13 CJK UNIFIED IDEOGRAPH-#8A13, IRGKangXi=1148.060, RSKangXi=149.3, Def{teach, instruct; exegesis}
8A14 CJK UNIFIED IDEOGRAPH-#8A14, IRGKangXi=1148.100, RSKangXi=149.3
8A15 CJK UNIFIED IDEOGRAPH-#8A15, IRGKangXi=1148.110, RSKangXi=149.3, Def{abuse, slander; vilify; ridicule}
8A16 CJK UNIFIED IDEOGRAPH-#8A16, IRGKangXi=1148.120, RSKangXi=149.3, Def{finish; conclude, stop; exhaust}
8A17 CJK UNIFIED IDEOGRAPH-#8A17, IRGKangXi=1149.010, RSKangXi=149.3, Def{entrust, rely on; commission}
8A18 CJK UNIFIED IDEOGRAPH-#8A18, IRGKangXi=1149.020, RSKangXi=149.3, Def{record; keep in mind, remember}
8A19 CJK UNIFIED IDEOGRAPH-#8A19, IRGKangXi=1149.030, RSKangXi=149.3
8A1A CJK UNIFIED IDEOGRAPH-#8A1A, IRGKangXi=1149.041, RSKangXi=149.3, Def{speak gently; respectful}
8A1B CJK UNIFIED IDEOGRAPH-#8A1B, IRGKangXi=1149.080, RSKangXi=149.4, Def{swindle, cheat; erroneous, wrong}
8A1C CJK UNIFIED IDEOGRAPH-#8A1C, IRGKangXi=1149.110, RSKangXi=149.4
8A1D CJK UNIFIED IDEOGRAPH-#8A1D, IRGKangXi=1149.120, RSKangXi=149.4, Def{express surprise, be surprised}
8A1E CJK UNIFIED IDEOGRAPH-#8A1E, IRGKangXi=1149.160, RSKangXi=149.4
8A1F CJK UNIFIED IDEOGRAPH-#8A1F, IRGKangXi=1149.180, RSKangXi=149.4, Def{accuse; argue, dispute; litigate}
8A20 CJK UNIFIED IDEOGRAPH-#8A20, IRGKangXi=1150.020, RSKangXi=149.4, Def{much more, still more; the gums}
8A21 CJK UNIFIED IDEOGRAPH-#8A21, IRGKangXi=1150.040, RSKangXi=149.4, Def{to chant, to moan, to sigh}
8A22 CJK UNIFIED IDEOGRAPH-#8A22, IRGKangXi=1150.060, RSKangXi=149.4, Def{pleased, delighted; happy}
8A23 CJK UNIFIED IDEOGRAPH-#8A23, IRGKangXi=1150.070, RSKangXi=149.4, Def{take leave of, bid farewell}
8A24 CJK UNIFIED IDEOGRAPH-#8A24, IRGKangXi=1150.080, RSKangXi=149.4
8A25 CJK UNIFIED IDEOGRAPH-#8A25, IRGKangXi=1150.090, RSKangXi=149.4, Def{slow of speech; mumble; stammer}
8A26 CJK UNIFIED IDEOGRAPH-#8A26, IRGKangXi=1150.110, RSKangXi=149.4, Def{sincere; faithful}
8A27 CJK UNIFIED IDEOGRAPH-#8A27, IRGKangXi=1150.130, RSKangXi=149.4, Def{fault}
8A28 CJK UNIFIED IDEOGRAPH-#8A28, IRGKangXi=1150.140, RSKangXi=149.4
8A29 CJK UNIFIED IDEOGRAPH-#8A29, IRGKangXi=1150.170, RSKangXi=149.4, Def{noisily; uproarious; troublesome}
8A2A CJK UNIFIED IDEOGRAPH-#8A2A, IRGKangXi=1150.180, RSKangXi=149.4, Def{visit; ask, inquire}
8A2B CJK UNIFIED IDEOGRAPH-#8A2B, IRGKangXi=1151.070, RSKangXi=149.4
8A2C CJK UNIFIED IDEOGRAPH-#8A2C, IRGKangXi=1151.080, RSKangXi=149.4, Def{clamour, uproar, annoyance, etc.}
8A2D CJK UNIFIED IDEOGRAPH-#8A2D, IRGKangXi=1151.090, RSKangXi=149.4, Def{build; establish; display; particle of hypothesis, supposing}
8A2E CJK UNIFIED IDEOGRAPH-#8A2E, IRGKangXi=1151.100, RSKangXi=149.4
8A2F CJK UNIFIED IDEOGRAPH-#8A2F, IRGKangXi=1151.110, RSKangXi=149.4
8A30 CJK UNIFIED IDEOGRAPH-#8A30, IRGKangXi=1151.130, RSKangXi=149.4
8A31 CJK UNIFIED IDEOGRAPH-#8A31, IRGKangXi=1151.140, RSKangXi=149.4, Def{allow, permit; promise; betroth}
8A32 CJK UNIFIED IDEOGRAPH-#8A32, IRGKangXi=1152.060, RSKangXi=149.4
8A33 CJK UNIFIED IDEOGRAPH-#8A33, IRGKangXi=1152.121, RSKangXi=149.4, Def{translate; decode; encode}
8A34 CJK UNIFIED IDEOGRAPH-#8A34, IRGKangXi=1152.130, RSKangXi=149.5, Def{accuse; sue; inform; narrate}
8A35 CJK UNIFIED IDEOGRAPH-#8A35, IRGKangXi=1152.140, RSKangXi=149.5
8A36 CJK UNIFIED IDEOGRAPH-#8A36, IRGKangXi=1152.150, RSKangXi=149.5, Def{scold loudly, curse, abuse}
8A37 CJK UNIFIED IDEOGRAPH-#8A37, IRGKangXi=1152.200, RSKangXi=149.5
8A38 CJK UNIFIED IDEOGRAPH-#8A38, IRGKangXi=1152.210, RSKangXi=149.5
8A39 CJK UNIFIED IDEOGRAPH-#8A39, IRGKangXi=1152.220, RSKangXi=149.5, Def{to beguile with false stories}
8A3A CJK UNIFIED IDEOGRAPH-#8A3A, IRGKangXi=1152.240, RSKangXi=149.5, Def{examine patient, diagnose}
8A3B CJK UNIFIED IDEOGRAPH-#8A3B, IRGKangXi=1152.260, RSKangXi=149.5, Def{explain; annotate; make entry}
8A3C CJK UNIFIED IDEOGRAPH-#8A3C, IRGKangXi=1152.270, RSKangXi=149.5, Def{prove, confirm, verify; proof}
8A3D CJK UNIFIED IDEOGRAPH-#8A3D, IRGKangXi=1152.290, RSKangXi=149.5, Def{blame}
8A3E CJK UNIFIED IDEOGRAPH-#8A3E, IRGKangXi=1153.010, RSKangXi=149.5, Def{bad-mouth; criticize; defects}
8A3F CJK UNIFIED IDEOGRAPH-#8A3F, IRGKangXi=1153.020, RSKangXi=149.5
8A40 CJK UNIFIED IDEOGRAPH-#8A40, IRGKangXi=1153.030, RSKangXi=149.5, Def{garrulous to whisper. to joke}
8A41 CJK UNIFIED IDEOGRAPH-#8A41, IRGKangXi=1153.040, RSKangXi=149.5, Def{exegesis, explanation; explain}
8A42 CJK UNIFIED IDEOGRAPH-#8A42, IRGKangXi=1153.070, RSKangXi=149.5
8A43 CJK UNIFIED IDEOGRAPH-#8A43, IRGKangXi=1153.080, RSKangXi=149.5
8A44 CJK UNIFIED IDEOGRAPH-#8A44, IRGKangXi=1153.090, RSKangXi=149.5
8A45 CJK UNIFIED IDEOGRAPH-#8A45, IRGKangXi=1153.110, RSKangXi=149.5, Def{to sell}
8A46 CJK UNIFIED IDEOGRAPH-#8A46, IRGKangXi=1154.010, RSKangXi=149.5, Def{slander, condemn, reproach}
8A47 CJK UNIFIED IDEOGRAPH-#8A47, IRGKangXi=1154.030, RSKangXi=149.5
8A48 CJK UNIFIED IDEOGRAPH-#8A48, IRGKangXi=1154.060, RSKangXi=149.5, Def{scold, abuse verbally, curse}
8A49 CJK UNIFIED IDEOGRAPH-#8A49, IRGKangXi=1154.070, RSKangXi=149.5, Def{gibberish; to wrangle}
8A4A CJK UNIFIED IDEOGRAPH-#8A4A, IRGKangXi=1154.080, RSKangXi=149.5
8A4B CJK UNIFIED IDEOGRAPH-#8A4B, IRGKangXi=1154.110, Def{to curse; to swear an oath incantations}
8A4C CJK UNIFIED IDEOGRAPH-#8A4C, IRGKangXi=1154.120, RSKangXi=149.5
8A4D CJK UNIFIED IDEOGRAPH-#8A4D, IRGKangXi=1154.130, RSKangXi=149.5
8A4E CJK UNIFIED IDEOGRAPH-#8A4E, IRGKangXi=1154.160, RSKangXi=149.5, Def{interjection used to express surprise}
8A4F CJK UNIFIED IDEOGRAPH-#8A4F, IRGKangXi=1154.180, RSKangXi=149.5, Def{(Cant.) to argue, debate}
8A50 CJK UNIFIED IDEOGRAPH-#8A50, IRGKangXi=1154.200, RSKangXi=149.5, Def{cheat, defraud, swindle; trick; to feign}
8A51 CJK UNIFIED IDEOGRAPH-#8A51, IRGKangXi=1154.210, RSKangXi=149.5, Def{cheat}
8A52 CJK UNIFIED IDEOGRAPH-#8A52, IRGKangXi=1154.230, RSKangXi=149.5, Def{bequeath, pass on to future generations}
8A53 CJK UNIFIED IDEOGRAPH-#8A53, IRGKangXi=1155.020, RSKangXi=149.5
8A54 CJK UNIFIED IDEOGRAPH-#8A54, IRGKangXi=1155.030, RSKangXi=149.5, Def{decree, proclaim; imperial decree}
8A55 CJK UNIFIED IDEOGRAPH-#8A55, IRGKangXi=1155.090, RSKangXi=149.5, Def{appraise, criticize, evaluate}
8A56 CJK UNIFIED IDEOGRAPH-#8A56, IRGKangXi=1155.100, RSKangXi=149.5, Def{argue; biased; one-sided}
8A57 CJK UNIFIED IDEOGRAPH-#8A57, IRGKangXi=1155.120, RSKangXi=149.5, Def{to spy; to give information; shrewd}
8A58 CJK UNIFIED IDEOGRAPH-#8A58, IRGKangXi=1155.130, RSKangXi=149.5, Def{bend, stoop, crouch; to yield}
8A59 CJK UNIFIED IDEOGRAPH-#8A59, IRGKangXi=1156.010, RSKangXi=149.5
8A5A CJK UNIFIED IDEOGRAPH-#8A5A, IRGKangXi=1156.020, RSKangXi=149.5
8A5B CJK UNIFIED IDEOGRAPH-#8A5B, IRGKangXi=1156.030, RSKangXi=149.5, Def{curse; swear, pledge}
8A5C CJK UNIFIED IDEOGRAPH-#8A5C, IRGKangXi=1156.060, RSKangXi=149.5
8A5D CJK UNIFIED IDEOGRAPH-#8A5D, IRGKangXi=1156.070, RSKangXi=149.5
8A5E CJK UNIFIED IDEOGRAPH-#8A5E, IRGKangXi=1156.090, RSKangXi=149.5, Def{words; phrase, expression}
8A5F CJK UNIFIED IDEOGRAPH-#8A5F, IRGKangXi=1156.171, RSKangXi=149.5, Def{fear; envy; loquacious}
8A60 CJK UNIFIED IDEOGRAPH-#8A60, IRGKangXi=1156.180, RSKangXi=149.5, Def{sing, hum, chant}
8A61 CJK UNIFIED IDEOGRAPH-#8A61, IRGKangXi=1156.190, RSKangXi=149.6, Def{boast, brag; popular, well known; to flatter}
8A62 CJK UNIFIED IDEOGRAPH-#8A62, IRGKangXi=1156.200, RSKangXi=149.6, Def{inquire into, ask about; consult}
8A63 CJK UNIFIED IDEOGRAPH-#8A63, IRGKangXi=1156.210, RSKangXi=149.6, Def{reach; achievement, accomplishment}
8A64 CJK UNIFIED IDEOGRAPH-#8A64, IRGKangXi=1157.010, RSKangXi=149.6, Def{to make wild statements to lie; to misstate; lies falsehood}
8A65 CJK UNIFIED IDEOGRAPH-#8A65, IRGKangXi=1157.020, RSKangXi=149.6
8A66 CJK UNIFIED IDEOGRAPH-#8A66, IRGKangXi=1157.030, RSKangXi=149.6, Def{test, try, experiment}
8A67 CJK UNIFIED IDEOGRAPH-#8A67, IRGKangXi=1157.130, RSKangXi=149.6, Def{to examine into judicially to find out}
8A68 CJK UNIFIED IDEOGRAPH-#8A68, IRGKangXi=1157.140, RSKangXi=149.6, Def{kind of cicada, cosmopsaltria}
8A69 CJK UNIFIED IDEOGRAPH-#8A69, IRGKangXi=1157.150, RSKangXi=149.6, Def{poetry; poem, verse, ode}
8A6A CJK UNIFIED IDEOGRAPH-#8A6A, IRGKangXi=1157.170, RSKangXi=149.6, Def{difficulty in speaking; wrangling}
8A6B CJK UNIFIED IDEOGRAPH-#8A6B, IRGKangXi=1157.210, RSKangXi=149.6, Def{to brag; exaggerated; to wonder at}
8A6C CJK UNIFIED IDEOGRAPH-#8A6C, IRGKangXi=1158.020, RSKangXi=149.6, Def{abuse, scold, berate, insult}
8A6D CJK UNIFIED IDEOGRAPH-#8A6D, IRGKangXi=1158.030, RSKangXi=149.6, Def{deceive, cheat, defraud; sly}
8A6E CJK UNIFIED IDEOGRAPH-#8A6E, IRGKangXi=1158.040, RSKangXi=149.6, Def{explain, expound, comment on}
8A6F CJK UNIFIED IDEOGRAPH-#8A6F, IRGKangXi=1158.060, RSKangXi=149.6
8A70 CJK UNIFIED IDEOGRAPH-#8A70, IRGKangXi=1158.090, RSKangXi=149.6, Def{question, interrogate}
8A71 CJK UNIFIED IDEOGRAPH-#8A71, IRGKangXi=1158.100, RSKangXi=149.6, Def{speech, talk, language; dialect}
8A72 CJK UNIFIED IDEOGRAPH-#8A72, IRGKangXi=1158.160, RSKangXi=149.6, Def{should, ought to, need to}
8A73 CJK UNIFIED IDEOGRAPH-#8A73, IRGKangXi=1158.170, RSKangXi=149.6, Def{detailed, complete, thorough}
8A74 CJK UNIFIED IDEOGRAPH-#8A74, IRGKangXi=1159.010, RSKangXi=149.6
8A75 CJK UNIFIED IDEOGRAPH-#8A75, IRGKangXi=1159.020, RSKangXi=149.6, Def{inquire, question; numerous}
8A76 CJK UNIFIED IDEOGRAPH-#8A76, IRGKangXi=1159.070, RSKangXi=149.6
8A77 CJK UNIFIED IDEOGRAPH-#8A77, IRGKangXi=1159.080, RSKangXi=149.6
8A78 CJK UNIFIED IDEOGRAPH-#8A78, IRGKangXi=1159.110, RSKangXi=149.6
8A79 CJK UNIFIED IDEOGRAPH-#8A79, IRGKangXi=1159.130, RSKangXi=149.6, Def{surname; talk too much, verbose}
8A7A CJK UNIFIED IDEOGRAPH-#8A7A, IRGKangXi=1159.150, RSKangXi=149.6
8A7B CJK UNIFIED IDEOGRAPH-#8A7B, IRGKangXi=1159.160, RSKangXi=149.6, Def{orders}
8A7C CJK UNIFIED IDEOGRAPH-#8A7C, IRGKangXi=1159.170, RSKangXi=149.6, Def{tease, joke with; ridicule, mock}
8A7D CJK UNIFIED IDEOGRAPH-#8A7D, IRGKangXi=1160.010, RSKangXi=149.6
8A7E CJK UNIFIED IDEOGRAPH-#8A7E, IRGKangXi=1160.020, RSKangXi=149.6, Def{noisily; uproarious; troublesome}
8A7F CJK UNIFIED IDEOGRAPH-#8A7F, IRGKangXi=1160.050, RSKangXi=149.6, Def{error, mistake; deceive, mislead}
8A80 CJK UNIFIED IDEOGRAPH-#8A80, IRGKangXi=1160.060, RSKangXi=149.6
8A81 CJK UNIFIED IDEOGRAPH-#8A81, IRGKangXi=1160.070, RSKangXi=149.6
8A82 CJK UNIFIED IDEOGRAPH-#8A82, IRGKangXi=1160.080, RSKangXi=149.6, Def{tempt}
8A83 CJK UNIFIED IDEOGRAPH-#8A83, IRGKangXi=1160.090, RSKangXi=149.6, Def{part}
8A84 CJK UNIFIED IDEOGRAPH-#8A84, IRGKangXi=1160.100, RSKangXi=149.6, Def{eulogize, praise the dead}
8A85 CJK UNIFIED IDEOGRAPH-#8A85, IRGKangXi=1160.110, RSKangXi=149.6, Def{execute, kill, put to death; punish}
8A86 CJK UNIFIED IDEOGRAPH-#8A86, IRGKangXi=1161.010, RSKangXi=149.6, Def{cheat, swindle, lie}
8A87 CJK UNIFIED IDEOGRAPH-#8A87, IRGKangXi=1161.020, RSKangXi=149.6, Def{exaggerate; brag, boast; flaunt}
8A88 CJK UNIFIED IDEOGRAPH-#8A88, IRGKangXi=1161.130, RSKangXi=149.6
8A89 CJK UNIFIED IDEOGRAPH-#8A89, IRGKangXi=1161.141, RSKangXi=149.6, Def{fame, reputation; praise}
8A8A CJK UNIFIED IDEOGRAPH-#8A8A, IRGKangXi=1161.141, RSKangXi=149.6, Def{copy, transcribe}
8A8B CJK UNIFIED IDEOGRAPH-#8A8B, IRGKangXi=1161.160, RSKangXi=149.7
8A8C CJK UNIFIED IDEOGRAPH-#8A8C, IRGKangXi=1161.170, RSKangXi=149.7, Def{write down; record; magazine}
8A8D CJK UNIFIED IDEOGRAPH-#8A8D, IRGKangXi=1161.180, RSKangXi=149.7, Def{recognize, know, understand}
8A8E CJK UNIFIED IDEOGRAPH-#8A8E, IRGKangXi=1161.230, RSKangXi=149.7
8A8F CJK UNIFIED IDEOGRAPH-#8A8F, IRGKangXi=1161.240, RSKangXi=149.7
8A90 CJK UNIFIED IDEOGRAPH-#8A90, IRGKangXi=1161.250, RSKangXi=149.7, Def{to intone, hum}
8A91 CJK UNIFIED IDEOGRAPH-#8A91, IRGKangXi=1161.260, RSKangXi=149.7, Def{deceive, lie, delude, cheat}
8A92 CJK UNIFIED IDEOGRAPH-#8A92, IRGKangXi=1161.290, RSKangXi=149.7, Def{an exclamation of confirmation}
8A93 CJK UNIFIED IDEOGRAPH-#8A93, IRGKangXi=1162.010, RSKangXi=149.7, Def{swear, pledge; oath}
8A94 CJK UNIFIED IDEOGRAPH-#8A94, IRGKangXi=1162.040, RSKangXi=149.7
8A95 CJK UNIFIED IDEOGRAPH-#8A95, IRGKangXi=1162.050, RSKangXi=149.7, Def{to bear children, give birth; birth}
8A96 CJK UNIFIED IDEOGRAPH-#8A96, IRGKangXi=1162.060, RSKangXi=149.7, Def{obstinate; disorderly; perverse}
8A97 CJK UNIFIED IDEOGRAPH-#8A97, IRGKangXi=1162.090, RSKangXi=149.7
8A98 CJK UNIFIED IDEOGRAPH-#8A98, IRGKangXi=1162.150, RSKangXi=149.7, Def{persuade, entice, induce; guide}
8A99 CJK UNIFIED IDEOGRAPH-#8A99, IRGKangXi=1162.170, RSKangXi=149.7
8A9A CJK UNIFIED IDEOGRAPH-#8A9A, IRGKangXi=1163.030, RSKangXi=149.7, Def{criticize, scold, blame, ridicule}
8A9B CJK UNIFIED IDEOGRAPH-#8A9B, IRGKangXi=1163.040, RSKangXi=149.7
8A9C CJK UNIFIED IDEOGRAPH-#8A9C, IRGKangXi=1163.050, RSKangXi=149.7
8A9D CJK UNIFIED IDEOGRAPH-#8A9D, IRGKangXi=1163.070, RSKangXi=149.7
8A9E CJK UNIFIED IDEOGRAPH-#8A9E, IRGKangXi=1163.080, RSKangXi=149.7, Def{language, words; saying, expression}
8A9F CJK UNIFIED IDEOGRAPH-#8A9F, IRGKangXi=1163.110, RSKangXi=149.7
8AA0 CJK UNIFIED IDEOGRAPH-#8AA0, IRGKangXi=1163.120, RSKangXi=149.7, Def{sincere, honest; true, real}
8AA1 CJK UNIFIED IDEOGRAPH-#8AA1, IRGKangXi=1163.130, RSKangXi=149.7, Def{warn, admonish; warning}
8AA2 CJK UNIFIED IDEOGRAPH-#8AA2, IRGKangXi=1163.150, RSKangXi=149.7
8AA3 CJK UNIFIED IDEOGRAPH-#8AA3, IRGKangXi=1163.170, RSKangXi=149.7, Def{make false accusation; defame}
8AA4 CJK UNIFIED IDEOGRAPH-#8AA4, IRGKangXi=1163.200, RSKangXi=149.7, Def{err, make mistake; interfere}
8AA5 CJK UNIFIED IDEOGRAPH-#8AA5, IRGKangXi=1163.230, RSKangXi=149.7, Def{inform, notify, admonish, order}
8AA6 CJK UNIFIED IDEOGRAPH-#8AA6, IRGKangXi=1164.020, RSKangXi=149.7, Def{recite, chant, repeat}
8AA7 CJK UNIFIED IDEOGRAPH-#8AA7, IRGKangXi=1164.030, RSKangXi=149.7, Def{huge; to admonish}
8AA8 CJK UNIFIED IDEOGRAPH-#8AA8, IRGKangXi=1164.040, RSKangXi=149.7, Def{teach, instruct; encourage, urge}
8AA9 CJK UNIFIED IDEOGRAPH-#8AA9, IRGKangXi=1164.060, RSKangXi=149.7, Def{to quarrel; to wrangle}
8AAA CJK UNIFIED IDEOGRAPH-#8AAA, IRGKangXi=1164.080, RSKangXi=149.7, Def{speak, say, talk; scold, upbraid}
8AAB CJK UNIFIED IDEOGRAPH-#8AAB, IRGKangXi=1165.040, RSKangXi=149.7
8AAC CJK UNIFIED IDEOGRAPH-#8AAC, IRGKangXi=1165.051, RSKangXi=149.7, Def{speak}
8AAD CJK UNIFIED IDEOGRAPH-#8AAD, IRGKangXi=1165.051, RSKangXi=149.7, Def{read, study; pronounce}
8AAE CJK UNIFIED IDEOGRAPH-#8AAE, IRGKangXi=1169.151, RSKangXi=149.7
8AAF CJK UNIFIED IDEOGRAPH-#8AAF, IRGKangXi=1165.100, RSKangXi=149.8
8AB0 CJK UNIFIED IDEOGRAPH-#8AB0, IRGKangXi=1165.110, RSKangXi=149.8, Def{who? whom? whose? anyone?}
8AB1 CJK UNIFIED IDEOGRAPH-#8AB1, IRGKangXi=1165.130, RSKangXi=149.8
8AB2 CJK UNIFIED IDEOGRAPH-#8AB2, IRGKangXi=1165.140, RSKangXi=149.8, Def{lesson; course; classwork}
8AB3 CJK UNIFIED IDEOGRAPH-#8AB3, IRGKangXi=1165.150, RSKangXi=149.8
8AB4 CJK UNIFIED IDEOGRAPH-#8AB4, IRGKangXi=1165.190, RSKangXi=149.8
8AB5 CJK UNIFIED IDEOGRAPH-#8AB5, IRGKangXi=1165.200, RSKangXi=149.8
8AB6 CJK UNIFIED IDEOGRAPH-#8AB6, IRGKangXi=1165.220, RSKangXi=149.8, Def{speak ill of, vilify; berate; interrogate}
8AB7 CJK UNIFIED IDEOGRAPH-#8AB7, IRGKangXi=1165.230, RSKangXi=149.8
8AB8 CJK UNIFIED IDEOGRAPH-#8AB8, IRGKangXi=1165.240, RSKangXi=149.8
8AB9 CJK UNIFIED IDEOGRAPH-#8AB9, IRGKangXi=1165.270, RSKangXi=149.8, Def{slander, vilify, condemn}
8ABA CJK UNIFIED IDEOGRAPH-#8ABA, IRGKangXi=1166.010, RSKangXi=149.8
8ABB CJK UNIFIED IDEOGRAPH-#8ABB, IRGKangXi=1166.030, RSKangXi=149.8
8ABC CJK UNIFIED IDEOGRAPH-#8ABC, IRGKangXi=1166.040, RSKangXi=149.8, Def{friendship; appropriate, suitable}
8ABD CJK UNIFIED IDEOGRAPH-#8ABD, IRGKangXi=1166.050, RSKangXi=149.8
8ABE CJK UNIFIED IDEOGRAPH-#8ABE, IRGKangXi=1166.070, RSKangXi=149.8, Def{speak gently; respectful}
8ABF CJK UNIFIED IDEOGRAPH-#8ABF, IRGKangXi=1166.080, RSKangXi=149.8, Def{transfer, move, change; tune}
8AC0 CJK UNIFIED IDEOGRAPH-#8AC0, IRGKangXi=1166.100, RSKangXi=149.8
8AC1 CJK UNIFIED IDEOGRAPH-#8AC1, IRGKangXi=1166.130, RSKangXi=149.8, Def{to suck, sip, sob, kiss; to chatter}
8AC2 CJK UNIFIED IDEOGRAPH-#8AC2, IRGKangXi=1166.150, RSKangXi=149.8, Def{flatter, truckle, toady}
8AC3 CJK UNIFIED IDEOGRAPH-#8AC3, IRGKangXi=1166.190, RSKangXi=149.8
8AC4 CJK UNIFIED IDEOGRAPH-#8AC4, IRGKangXi=1166.210, RSKangXi=149.8, Def{patient, earnest; earnestly}
8AC5 CJK UNIFIED IDEOGRAPH-#8AC5, IRGKangXi=1167.010, RSKangXi=149.8
8AC6 CJK UNIFIED IDEOGRAPH-#8AC6, IRGKangXi=1167.040, RSKangXi=149.8, Def{to cheat}
8AC7 CJK UNIFIED IDEOGRAPH-#8AC7, IRGKangXi=1167.110, RSKangXi=149.8, Def{talk; conversation; surname}
8AC8 CJK UNIFIED IDEOGRAPH-#8AC8, IRGKangXi=1167.130, RSKangXi=149.8
8AC9 CJK UNIFIED IDEOGRAPH-#8AC9, IRGKangXi=1167.140, RSKangXi=149.8, Def{pass buck, lay blame on others}
8ACA CJK UNIFIED IDEOGRAPH-#8ACA, IRGKangXi=1167.160, RSKangXi=149.8, Def{to make a judicial investigation}
8ACB CJK UNIFIED IDEOGRAPH-#8ACB, IRGKangXi=1167.180, RSKangXi=149.8, Def{ask, request; invite; please}
8ACC CJK UNIFIED IDEOGRAPH-#8ACC, IRGKangXi=1167.210, RSKangXi=149.8, Def{remonstrate, admonish}
8ACD CJK UNIFIED IDEOGRAPH-#8ACD, IRGKangXi=1167.220, RSKangXi=149.8, Def{to expostulate; to remonstrate}
8ACE CJK UNIFIED IDEOGRAPH-#8ACE, IRGKangXi=1168.010, RSKangXi=149.8
8ACF CJK UNIFIED IDEOGRAPH-#8ACF, IRGKangXi=1168.050, RSKangXi=149.8, Def{consult, confer; select, choose}
8AD0 CJK UNIFIED IDEOGRAPH-#8AD0, IRGKangXi=1168.060, RSKangXi=149.8, Def{fault}
8AD1 CJK UNIFIED IDEOGRAPH-#8AD1, IRGKangXi=1168.070, RSKangXi=149.8, Def{slander; gossip; rumors}
8AD2 CJK UNIFIED IDEOGRAPH-#8AD2, IRGKangXi=1168.090, RSKangXi=149.8, Def{excuse, forgive; guess, presume}
8AD3 CJK UNIFIED IDEOGRAPH-#8AD3, IRGKangXi=1168.100, RSKangXi=149.8, Def{flattering}
8AD4 CJK UNIFIED IDEOGRAPH-#8AD4, IRGKangXi=1168.110, RSKangXi=149.8
8AD5 CJK UNIFIED IDEOGRAPH-#8AD5, IRGKangXi=1168.120, RSKangXi=149.8, Def{to intimidate}
8AD6 CJK UNIFIED IDEOGRAPH-#8AD6, IRGKangXi=1168.130, RSKangXi=149.8, Def{debate; discuss; discourse}
8AD7 CJK UNIFIED IDEOGRAPH-#8AD7, IRGKangXi=1169.010, RSKangXi=149.8, Def{consult carefully with, counsel}
8AD8 CJK UNIFIED IDEOGRAPH-#8AD8, IRGKangXi=1169.050, RSKangXi=149.8
8AD9 CJK UNIFIED IDEOGRAPH-#8AD9, IRGKangXi=1169.130, RSKangXi=149.8
8ADA CJK UNIFIED IDEOGRAPH-#8ADA, IRGKangXi=1169.151, RSKangXi=149.8, Def{(kokuji) command}
8ADB CJK UNIFIED IDEOGRAPH-#8ADB, IRGKangXi=1169.190, RSKangXi=149.9, Def{flatter, truckle}
8ADC CJK UNIFIED IDEOGRAPH-#8ADC, IRGKangXi=1169.200, RSKangXi=149.9, Def{an intelligence report; to spy; spying}
8ADD CJK UNIFIED IDEOGRAPH-#8ADD, IRGKangXi=1169.250, RSKangXi=149.9, Def{knowledge; discrimination; treachery}
8ADE CJK UNIFIED IDEOGRAPH-#8ADE, IRGKangXi=1169.260, RSKangXi=149.9, Def{brag, boast; quibble}
8ADF CJK UNIFIED IDEOGRAPH-#8ADF, IRGKangXi=1169.270, RSKangXi=149.9, Def{to examine; to consider; honest}
8AE0 CJK UNIFIED IDEOGRAPH-#8AE0, IRGKangXi=1169.300, RSKangXi=149.9, Def{noisy, uproarious; forget}
8AE1 CJK UNIFIED IDEOGRAPH-#8AE1, IRGKangXi=1169.320, RSKangXi=149.9, Def{posthumous name, posthumous title}
8AE2 CJK UNIFIED IDEOGRAPH-#8AE2, IRGKangXi=1170.010, RSKangXi=149.9, Def{jokes, obscene jests; joke}
8AE3 CJK UNIFIED IDEOGRAPH-#8AE3, IRGKangXi=1170.040, RSKangXi=149.9
8AE4 CJK UNIFIED IDEOGRAPH-#8AE4, IRGKangXi=1170.050, RSKangXi=149.9, Def{honest speech, straightforward}
8AE5 CJK UNIFIED IDEOGRAPH-#8AE5, IRGKangXi=1170.070, RSKangXi=149.9
8AE6 CJK UNIFIED IDEOGRAPH-#8AE6, IRGKangXi=1170.080, RSKangXi=149.9, Def{careful, attentive}
8AE7 CJK UNIFIED IDEOGRAPH-#8AE7, IRGKangXi=1170.110, RSKangXi=149.9, Def{harmonize, agree; joke, jest}
8AE8 CJK UNIFIED IDEOGRAPH-#8AE8, IRGKangXi=1170.120, RSKangXi=149.9
8AE9 CJK UNIFIED IDEOGRAPH-#8AE9, IRGKangXi=1170.130, RSKangXi=149.8
8AEA CJK UNIFIED IDEOGRAPH-#8AEA, IRGKangXi=1170.160, RSKangXi=149.9
8AEB CJK UNIFIED IDEOGRAPH-#8AEB, IRGKangXi=1170.170, RSKangXi=149.9, Def{remonstrate, admonish}
8AEC CJK UNIFIED IDEOGRAPH-#8AEC, IRGKangXi=1171.020, RSKangXi=149.9, Def{to open to begin to explain to inform a letter}
8AED CJK UNIFIED IDEOGRAPH-#8AED, IRGKangXi=1171.030, RSKangXi=149.9, Def{proclaim, instruct; edict}
8AEE CJK UNIFIED IDEOGRAPH-#8AEE, IRGKangXi=1171.040, RSKangXi=149.9, Def{consult, confer; communicate in}
8AEF CJK UNIFIED IDEOGRAPH-#8AEF, IRGKangXi=1171.050, RSKangXi=149.9
8AF0 CJK UNIFIED IDEOGRAPH-#8AF0, IRGKangXi=1171.070, RSKangXi=149.9, Def{apprehensive}
8AF1 CJK UNIFIED IDEOGRAPH-#8AF1, IRGKangXi=1171.090, RSKangXi=149.9, Def{conceal; shun; regard as taboo}
8AF2 CJK UNIFIED IDEOGRAPH-#8AF2, IRGKangXi=1171.110, RSKangXi=149.9
8AF3 CJK UNIFIED IDEOGRAPH-#8AF3, IRGKangXi=1171.120, RSKangXi=149.9, Def{versed in, fully acquainted with}
8AF4 CJK UNIFIED IDEOGRAPH-#8AF4, IRGKangXi=1171.130, RSKangXi=149.9, Def{in harmony; in agreement; sincere}
8AF5 CJK UNIFIED IDEOGRAPH-#8AF5, IRGKangXi=1171.140, RSKangXi=149.9, Def{mutter}
8AF6 CJK UNIFIED IDEOGRAPH-#8AF6, IRGKangXi=1171.150, RSKangXi=149.9, Def{sincere, faithful; surname}
8AF7 CJK UNIFIED IDEOGRAPH-#8AF7, IRGKangXi=1172.020, RSKangXi=149.9, Def{recite, incant; satirize}
8AF8 CJK UNIFIED IDEOGRAPH-#8AF8, IRGKangXi=1172.040, RSKangXi=149.9, Def{several, various}
8AF9 CJK UNIFIED IDEOGRAPH-#8AF9, IRGKangXi=1172.080, RSKangXi=149.9
8AFA CJK UNIFIED IDEOGRAPH-#8AFA, IRGKangXi=1172.090, RSKangXi=149.9, Def{proverb, maxim}
8AFB CJK UNIFIED IDEOGRAPH-#8AFB, IRGKangXi=1172.120, RSKangXi=149.9
8AFC CJK UNIFIED IDEOGRAPH-#8AFC, IRGKangXi=1172.130, RSKangXi=149.9, Def{forget; lie, cheat, deceive}
8AFD CJK UNIFIED IDEOGRAPH-#8AFD, IRGKangXi=1173.010, RSKangXi=149.9
8AFE CJK UNIFIED IDEOGRAPH-#8AFE, IRGKangXi=1173.020, RSKangXi=149.9, Def{promise; assent, approve}
8AFF CJK UNIFIED IDEOGRAPH-#8AFF, IRGKangXi=1173.050, RSKangXi=149.9
8B00 CJK UNIFIED IDEOGRAPH-#8B00, IRGKangXi=1173.070, RSKangXi=149.9, Def{plan, scheme; strategem}
8B01 CJK UNIFIED IDEOGRAPH-#8B01, IRGKangXi=1173.100, RSKangXi=149.9, Def{visit, pay respects to}
8B02 CJK UNIFIED IDEOGRAPH-#8B02, IRGKangXi=1173.120, RSKangXi=149.9, Def{say, tell; call, name; be called}
8B03 CJK UNIFIED IDEOGRAPH-#8B03, IRGKangXi=1174.121, RSKangXi=149.9
8B04 CJK UNIFIED IDEOGRAPH-#8B04, IRGKangXi=1174.130, RSKangXi=149.10, Def{copy, transcribe}
8B05 CJK UNIFIED IDEOGRAPH-#8B05, IRGKangXi=1174.140, RSKangXi=149.10, Def{play with words, quip; talk nonse}
8B06 CJK UNIFIED IDEOGRAPH-#8B06, IRGKangXi=1174.160, RSKangXi=149.10, Def{beguile, cajole}
8B07 CJK UNIFIED IDEOGRAPH-#8B07, IRGKangXi=1174.230, RSKangXi=149.10, Def{stutter; speak out boldly}
8B08 CJK UNIFIED IDEOGRAPH-#8B08, IRGKangXi=1174.240, RSKangXi=149.10
8B09 CJK UNIFIED IDEOGRAPH-#8B09, IRGKangXi=1174.250, RSKangXi=149.10
8B0A CJK UNIFIED IDEOGRAPH-#8B0A, IRGKangXi=1174.260, RSKangXi=149.10, Def{lie}
8B0B CJK UNIFIED IDEOGRAPH-#8B0B, IRGKangXi=1174.270, RSKangXi=149.10
8B0C CJK UNIFIED IDEOGRAPH-#8B0C, IRGKangXi=1174.280, RSKangXi=149.10, Def{slander, defame}
8B0D CJK UNIFIED IDEOGRAPH-#8B0D, IRGKangXi=1174.300, RSKangXi=149.10
8B0E CJK UNIFIED IDEOGRAPH-#8B0E, IRGKangXi=1174.310, RSKangXi=149.10, Def{riddle, conundrum; puzzle}
8B0F CJK UNIFIED IDEOGRAPH-#8B0F, IRGKangXi=1174.320, RSKangXi=149.10, Def{scold, censure; lead people toward virtuous ways; small, little}
8B10 CJK UNIFIED IDEOGRAPH-#8B10, IRGKangXi=1175.020, RSKangXi=149.10, Def{calm, quiet, still; cautious}
8B11 CJK UNIFIED IDEOGRAPH-#8B11, IRGKangXi=1175.040, RSKangXi=149.10, Def{shame, disgrace}
8B12 CJK UNIFIED IDEOGRAPH-#8B12, IRGKangXi=1175.050, RSKangXi=149.10
8B13 CJK UNIFIED IDEOGRAPH-#8B13, IRGKangXi=1175.080, RSKangXi=149.10
8B14 CJK UNIFIED IDEOGRAPH-#8B14, IRGKangXi=1175.090, RSKangXi=149.10, Def{jeer}
8B15 CJK UNIFIED IDEOGRAPH-#8B15, IRGKangXi=1175.110, RSKangXi=149.10
8B16 CJK UNIFIED IDEOGRAPH-#8B16, IRGKangXi=1175.150, RSKangXi=149.10, Def{rise up; raise up}
8B17 CJK UNIFIED IDEOGRAPH-#8B17, IRGKangXi=1175.160, RSKangXi=149.10, Def{slander, libel}
8B18 CJK UNIFIED IDEOGRAPH-#8B18, IRGKangXi=1175.180, RSKangXi=149.10
8B19 CJK UNIFIED IDEOGRAPH-#8B19, IRGKangXi=1175.200, RSKangXi=149.10, Def{humble, modest}
8B1A CJK UNIFIED IDEOGRAPH-#8B1A, IRGKangXi=1175.230, RSKangXi=149.10, Def{to confer posthumous titles}
8B1B CJK UNIFIED IDEOGRAPH-#8B1B, IRGKangXi=1175.240, RSKangXi=149.10, Def{explain; discuss; talk}
8B1C CJK UNIFIED IDEOGRAPH-#8B1C, IRGKangXi=1176.010, RSKangXi=149.10
8B1D CJK UNIFIED IDEOGRAPH-#8B1D, IRGKangXi=1176.020, RSKangXi=149.10, Def{thank; decline}
8B1E CJK UNIFIED IDEOGRAPH-#8B1E, IRGKangXi=1176.030, RSKangXi=149.10
8B1F CJK UNIFIED IDEOGRAPH-#8B1F, IRGKangXi=1176.060, RSKangXi=149.10, Def{flatter; suspect, be uncertain}
8B20 CJK UNIFIED IDEOGRAPH-#8B20, IRGKangXi=1176.070, RSKangXi=149.10, Def{sing; folksong, ballad; rumor}
8B21 CJK UNIFIED IDEOGRAPH-#8B21, IRGKangXi=1177.021, RSKangXi=149.10, Def{sing; folksong, ballad; rumor}
8B22 CJK UNIFIED IDEOGRAPH-#8B22, IRGKangXi=1177.021, RSKangXi=149.10
8B23 CJK UNIFIED IDEOGRAPH-#8B23, IRGKangXi=1177.030, RSKangXi=149.11
8B24 CJK UNIFIED IDEOGRAPH-#8B24, IRGKangXi=1177.040, RSKangXi=149.11
8B25 CJK UNIFIED IDEOGRAPH-#8B25, IRGKangXi=1177.060, RSKangXi=149.11
8B26 CJK UNIFIED IDEOGRAPH-#8B26, IRGKangXi=1177.070, RSKangXi=149.11, Def{to speak softly}
8B27 CJK UNIFIED IDEOGRAPH-#8B27, IRGKangXi=1177.080, RSKangXi=149.11
8B28 CJK UNIFIED IDEOGRAPH-#8B28, IRGKangXi=1177.150, RSKangXi=149.11, Def{scheme, plan; plan; be without}
8B29 CJK UNIFIED IDEOGRAPH-#8B29, IRGKangXi=1177.190, RSKangXi=149.11
8B2A CJK UNIFIED IDEOGRAPH-#8B2A, IRGKangXi=1177.210, RSKangXi=149.11, Def{to consult; to deliberate; commerce}
8B2B CJK UNIFIED IDEOGRAPH-#8B2B, IRGKangXi=1177.220, RSKangXi=149.11, Def{charge, blame; disgrace; demote; punish}
8B2C CJK UNIFIED IDEOGRAPH-#8B2C, IRGKangXi=1177.270, RSKangXi=149.11, Def{error, exaggeration; erroneous}
8B2D CJK UNIFIED IDEOGRAPH-#8B2D, IRGKangXi=1177.280, RSKangXi=149.11, Def{shallow; stupid}
8B2E CJK UNIFIED IDEOGRAPH-#8B2E, IRGKangXi=1177.300, RSKangXi=149.11
8B2F CJK UNIFIED IDEOGRAPH-#8B2F, IRGKangXi=1177.310, RSKangXi=149.11
8B30 CJK UNIFIED IDEOGRAPH-#8B30, IRGKangXi=1178.050, RSKangXi=149.11
8B31 CJK UNIFIED IDEOGRAPH-#8B31, IRGKangXi=1178.060, RSKangXi=149.11
8B32 CJK UNIFIED IDEOGRAPH-#8B32, IRGKangXi=1178.070, RSKangXi=149.11
8B33 CJK UNIFIED IDEOGRAPH-#8B33, IRGKangXi=1178.090, RSKangXi=149.11, Def{to sing; songs}
8B34 CJK UNIFIED IDEOGRAPH-#8B34, IRGKangXi=1178.110, RSKangXi=149.11
8B35 CJK UNIFIED IDEOGRAPH-#8B35, IRGKangXi=1178.130, RSKangXi=149.11
8B36 CJK UNIFIED IDEOGRAPH-#8B36, IRGKangXi=1178.180, RSKangXi=149.11
8B37 CJK UNIFIED IDEOGRAPH-#8B37, IRGKangXi=1178.190, RSKangXi=149.11, Def{slander; to revile; huge; big}
8B38 CJK UNIFIED IDEOGRAPH-#8B38, IRGKangXi=1178.200, RSKangXi=149.11
8B39 CJK UNIFIED IDEOGRAPH-#8B39, IRGKangXi=1178.230, RSKangXi=149.11, Def{prudent, cautious; attentive}
8B3A CJK UNIFIED IDEOGRAPH-#8B3A, IRGKangXi=1178.240, RSKangXi=149.11
8B3B CJK UNIFIED IDEOGRAPH-#8B3B, IRGKangXi=1178.260, RSKangXi=149.11
8B3C CJK UNIFIED IDEOGRAPH-#8B3C, IRGKangXi=1179.020, RSKangXi=149.11, Def{to shout; to mourn to invoke}
8B3D CJK UNIFIED IDEOGRAPH-#8B3D, IRGKangXi=1179.040, RSKangXi=149.11
8B3E CJK UNIFIED IDEOGRAPH-#8B3E, IRGKangXi=1179.060, RSKangXi=149.11, Def{deceive, insult}
8B3F CJK UNIFIED IDEOGRAPH-#8B3F, IRGKangXi=1179.180, RSKangXi=149.12, Def{ridicule, deride, scorn, jeer at}
8B40 CJK UNIFIED IDEOGRAPH-#8B40, IRGKangXi=1179.190, RSKangXi=149.12
8B41 CJK UNIFIED IDEOGRAPH-#8B41, IRGKangXi=1179.210, RSKangXi=149.12, Def{noise, uproar; clamor, hubbub}
8B42 CJK UNIFIED IDEOGRAPH-#8B42, IRGKangXi=1179.230, RSKangXi=149.12
8B43 CJK UNIFIED IDEOGRAPH-#8B43, IRGKangXi=1180.010, RSKangXi=149.12
8B44 CJK UNIFIED IDEOGRAPH-#8B44, IRGKangXi=1180.020, RSKangXi=149.12
8B45 CJK UNIFIED IDEOGRAPH-#8B45, IRGKangXi=1180.030, RSKangXi=149.12, Def{wriggling}
8B46 CJK UNIFIED IDEOGRAPH-#8B46, IRGKangXi=1180.050, RSKangXi=149.12, Def{scream}
8B47 CJK UNIFIED IDEOGRAPH-#8B47, IRGKangXi=1180.080, RSKangXi=149.12
8B48 CJK UNIFIED IDEOGRAPH-#8B48, IRGKangXi=1180.130, RSKangXi=149.12, Def{dislike}
8B49 CJK UNIFIED IDEOGRAPH-#8B49, IRGKangXi=1180.140, RSKangXi=149.12, Def{proof, evidence; testify, verify}
8B4A CJK UNIFIED IDEOGRAPH-#8B4A, IRGKangXi=1180.160, RSKangXi=149.12, Def{wrangling; to quarrel}
8B4B CJK UNIFIED IDEOGRAPH-#8B4B, IRGKangXi=1180.170, RSKangXi=149.12
8B4C CJK UNIFIED IDEOGRAPH-#8B4C, IRGKangXi=1180.200, RSKangXi=149.12, Def{false, erronious}
8B4D CJK UNIFIED IDEOGRAPH-#8B4D, IRGKangXi=1180.220, RSKangXi=149.13, Def{answer}
8B4E CJK UNIFIED IDEOGRAPH-#8B4E, IRGKangXi=1180.250, RSKangXi=149.12, Def{cunning, crafty, sly, wily}
8B4F CJK UNIFIED IDEOGRAPH-#8B4F, IRGKangXi=1181.010, RSKangXi=149.12, Def{ridicule, jeer, mock; inspect}
8B50 CJK UNIFIED IDEOGRAPH-#8B50, IRGKangXi=1181.020, RSKangXi=149.12, Def{to talk, converse}
8B51 CJK UNIFIED IDEOGRAPH-#8B51, IRGKangXi=1181.040, RSKangXi=149.12
8B52 CJK UNIFIED IDEOGRAPH-#8B52, IRGKangXi=1181.050, RSKangXi=149.12
8B53 CJK UNIFIED IDEOGRAPH-#8B53, IRGKangXi=1181.070, RSKangXi=149.12
8B54 CJK UNIFIED IDEOGRAPH-#8B54, IRGKangXi=1181.110, RSKangXi=149.12, Def{eulogize; compose, write}
8B55 CJK UNIFIED IDEOGRAPH-#8B55, IRGKangXi=1181.140, RSKangXi=149.12
8B56 CJK UNIFIED IDEOGRAPH-#8B56, IRGKangXi=1181.150, RSKangXi=149.12, Def{to slander}
8B57 CJK UNIFIED IDEOGRAPH-#8B57, IRGKangXi=1181.160, RSKangXi=149.12
8B58 CJK UNIFIED IDEOGRAPH-#8B58, IRGKangXi=1181.170, RSKangXi=149.12, Def{recognize, understand, know}
8B59 CJK UNIFIED IDEOGRAPH-#8B59, IRGKangXi=1182.020, RSKangXi=149.12, Def{tower; surname}
8B5A CJK UNIFIED IDEOGRAPH-#8B5A, IRGKangXi=1182.050, RSKangXi=149.12, Def{surname; to talk}
8B5B CJK UNIFIED IDEOGRAPH-#8B5B, IRGKangXi=1182.111, RSKangXi=149.12, Def{to slander}
8B5C CJK UNIFIED IDEOGRAPH-#8B5C, IRGKangXi=1182.120, RSKangXi=149.12, Def{register, list, table; musical score}
8B5D CJK UNIFIED IDEOGRAPH-#8B5D, IRGKangXi=1182.130, RSKangXi=149.13
8B5E CJK UNIFIED IDEOGRAPH-#8B5E, IRGKangXi=1182.150, RSKangXi=149.13
8B5F CJK UNIFIED IDEOGRAPH-#8B5F, IRGKangXi=1182.190, RSKangXi=149.13, Def{clamor, noise, din; slander}
8B60 CJK UNIFIED IDEOGRAPH-#8B60, IRGKangXi=1182.210, RSKangXi=149.13
8B61 CJK UNIFIED IDEOGRAPH-#8B61, IRGKangXi=1182.220, RSKangXi=149.13
8B62 CJK UNIFIED IDEOGRAPH-#8B62, IRGKangXi=1182.240, RSKangXi=149.13
8B63 CJK UNIFIED IDEOGRAPH-#8B63, IRGKangXi=1183.020, RSKangXi=149.13
8B64 CJK UNIFIED IDEOGRAPH-#8B64, IRGKangXi=1183.030, RSKangXi=149.13
8B65 CJK UNIFIED IDEOGRAPH-#8B65, IRGKangXi=1183.040, RSKangXi=149.13
8B66 CJK UNIFIED IDEOGRAPH-#8B66, IRGKangXi=1183.050, RSKangXi=149.13, Def{guard, watch; alert, alarm}
8B67 CJK UNIFIED IDEOGRAPH-#8B67, IRGKangXi=1183.060, RSKangXi=149.13
8B68 CJK UNIFIED IDEOGRAPH-#8B68, IRGKangXi=1183.080, RSKangXi=149.13
8B69 CJK UNIFIED IDEOGRAPH-#8B69, IRGKangXi=1183.090, RSKangXi=149.13
8B6A CJK UNIFIED IDEOGRAPH-#8B6A, IRGKangXi=1183.110, RSKangXi=149.13
8B6B CJK UNIFIED IDEOGRAPH-#8B6B, IRGKangXi=1183.140, RSKangXi=149.13, Def{talkative; incoherent talk}
8B6C CJK UNIFIED IDEOGRAPH-#8B6C, IRGKangXi=1183.160, RSKangXi=149.13, Def{metaphor, simile, example}
8B6D CJK UNIFIED IDEOGRAPH-#8B6D, IRGKangXi=1183.170, RSKangXi=149.13, Def{to slander; to defame}
8B6E CJK UNIFIED IDEOGRAPH-#8B6E, IRGKangXi=1183.180, RSKangXi=149.13
8B6F CJK UNIFIED IDEOGRAPH-#8B6F, IRGKangXi=1183.190, RSKangXi=149.13, Def{translate; decode; encode}
8B70 CJK UNIFIED IDEOGRAPH-#8B70, IRGKangXi=1183.240, RSKangXi=149.13, Def{consult, talk over, discuss}
8B71 CJK UNIFIED IDEOGRAPH-#8B71, IRGKangXi=1184.010, RSKangXi=149.13
8B72 CJK UNIFIED IDEOGRAPH-#8B72, IRGKangXi=1184.081, RSKangXi=149.13, Def{allow, permit, yield, concede}
8B73 CJK UNIFIED IDEOGRAPH-#8B73, IRGKangXi=1184.100, RSKangXi=149.14
8B74 CJK UNIFIED IDEOGRAPH-#8B74, IRGKangXi=1184.130, RSKangXi=149.14, Def{reprimand, scold, abuse}
8B75 CJK UNIFIED IDEOGRAPH-#8B75, IRGKangXi=1184.140, RSKangXi=149.14
8B76 CJK UNIFIED IDEOGRAPH-#8B76, IRGKangXi=1184.150, RSKangXi=149.14
8B77 CJK UNIFIED IDEOGRAPH-#8B77, IRGKangXi=1184.170, RSKangXi=149.14, Def{protect, guard, defend, shelter}
8B78 CJK UNIFIED IDEOGRAPH-#8B78, IRGKangXi=1184.190, RSKangXi=149.14, Def{deceive, cheat; hurried, bustling}
8B79 CJK UNIFIED IDEOGRAPH-#8B79, IRGKangXi=1184.270, RSKangXi=149.14, Def{to shout, roar, terrify; swiftly}
8B7A CJK UNIFIED IDEOGRAPH-#8B7A, IRGKangXi=1184.320, RSKangXi=149.14
8B7B CJK UNIFIED IDEOGRAPH-#8B7B, IRGKangXi=1185.010, RSKangXi=149.14
8B7C CJK UNIFIED IDEOGRAPH-#8B7C, IRGKangXi=1185.050, RSKangXi=149.14, Def{to supervise to confine a government establishment}
8B7D CJK UNIFIED IDEOGRAPH-#8B7D, IRGKangXi=1185.070, RSKangXi=149.14, Def{fame, reputation; praise}
8B7E CJK UNIFIED IDEOGRAPH-#8B7E, IRGKangXi=1185.180, RSKangXi=149.15, Def{shallow; stupid}
8B7F CJK UNIFIED IDEOGRAPH-#8B7F, IRGKangXi=1185.250, RSKangXi=149.15
8B80 CJK UNIFIED IDEOGRAPH-#8B80, IRGKangXi=1185.270, RSKangXi=149.15, Def{read, study; pronounce}
8B81 CJK UNIFIED IDEOGRAPH-#8B81, IRGKangXi=1185.300, RSKangXi=149.15, Def{punish; fault, blame, reprove}
8B82 CJK UNIFIED IDEOGRAPH-#8B82, IRGKangXi=1186.071, RSKangXi=149.15
8B83 CJK UNIFIED IDEOGRAPH-#8B83, IRGKangXi=1185.350, RSKangXi=149.15, Def{praise, commend, eulogize}
8B84 CJK UNIFIED IDEOGRAPH-#8B84, IRGKangXi=1186.010, RSKangXi=149.15
8B85 CJK UNIFIED IDEOGRAPH-#8B85, IRGKangXi=1186.071, RSKangXi=149.15, Def{know in detail}
8B86 CJK UNIFIED IDEOGRAPH-#8B86, IRGKangXi=1186.071, RSKangXi=149.16, Def{to exaggerate; incredible}
8B87 CJK UNIFIED IDEOGRAPH-#8B87, IRGKangXi=1186.080, RSKangXi=149.16, Def{flatter; suspect, be uncertain}
8B88 CJK UNIFIED IDEOGRAPH-#8B88, IRGKangXi=1186.090, RSKangXi=149.16
8B89 CJK UNIFIED IDEOGRAPH-#8B89, IRGKangXi=1186.110, RSKangXi=149.16
8B8A CJK UNIFIED IDEOGRAPH-#8B8A, IRGKangXi=1186.120, RSKangXi=149.16, Def{change, transform, alter; rebel}
8B8B CJK UNIFIED IDEOGRAPH-#8B8B, IRGKangXi=1186.180, RSKangXi=149.16, Def{fear; envy; loquacious}
8B8C CJK UNIFIED IDEOGRAPH-#8B8C, IRGKangXi=1186.190, RSKangXi=149.16, Def{a feast, banquet; to entertain, feast}
8B8D CJK UNIFIED IDEOGRAPH-#8B8D, IRGKangXi=1186.200, RSKangXi=149.16, Def{honest speech}
8B8E CJK UNIFIED IDEOGRAPH-#8B8E, IRGKangXi=1186.210, RSKangXi=149.16, Def{enemy, rival, opponent}
8B8F CJK UNIFIED IDEOGRAPH-#8B8F, IRGKangXi=1186.250, RSKangXi=149.16
8B90 CJK UNIFIED IDEOGRAPH-#8B90, IRGKangXi=1187.030, RSKangXi=149.16, Def{enemy, rival, opponent}
8B91 CJK UNIFIED IDEOGRAPH-#8B91, IRGKangXi=1187.080
8B92 CJK UNIFIED IDEOGRAPH-#8B92, IRGKangXi=1187.090, RSKangXi=149.17, Def{slander, defame, misrepresent}
8B93 CJK UNIFIED IDEOGRAPH-#8B93, IRGKangXi=1187.120, RSKangXi=149.17, Def{allow, permit, yield, concede}
8B94 CJK UNIFIED IDEOGRAPH-#8B94, IRGKangXi=1187.150, RSKangXi=149.17
8B95 CJK UNIFIED IDEOGRAPH-#8B95, IRGKangXi=1187.160, RSKangXi=149.17, Def{accuse falsely; slander, libel}
8B96 CJK UNIFIED IDEOGRAPH-#8B96, IRGKangXi=1187.180, RSKangXi=149.17, Def{prophecy, hint, omen}
8B97 CJK UNIFIED IDEOGRAPH-#8B97, IRGKangXi=1187.210, RSKangXi=149.18
8B98 CJK UNIFIED IDEOGRAPH-#8B98, IRGKangXi=1187.240, RSKangXi=149.18
8B99 CJK UNIFIED IDEOGRAPH-#8B99, IRGKangXi=1187.250, RSKangXi=149.18, Def{cheer; noise, noisy}
8B9A CJK UNIFIED IDEOGRAPH-#8B9A, IRGKangXi=1188.040, RSKangXi=149.19, Def{praise, commend, eulogize}
8B9B CJK UNIFIED IDEOGRAPH-#8B9B, IRGKangXi=1188.050
8B9C CJK UNIFIED IDEOGRAPH-#8B9C, IRGKangXi=1188.080, RSKangXi=149.20, Def{counsel, advice; speak out}
8B9D CJK UNIFIED IDEOGRAPH-#8B9D, IRGKangXi=1188.090, RSKangXi=149.20
8B9E CJK UNIFIED IDEOGRAPH-#8B9E, IRGKangXi=1188.100, RSKangXi=149.20, Def{to decide, judge; a verdict, decision}
8B9F CJK UNIFIED IDEOGRAPH-#8B9F, IRGKangXi=1188.150, RSKangXi=149.22, Def{slander, utter evil words}
8BA0 CJK UNIFIED IDEOGRAPH-#8BA0, IRGKangXi=1188.181, RSKangXi=149.0, Def{simplified KangXi radical 149}
8BA1 CJK UNIFIED IDEOGRAPH-#8BA1, IRGKangXi=1188.181, RSKangXi=149.2, Def{plan, plot; strategem; scheme}
8BA2 CJK UNIFIED IDEOGRAPH-#8BA2, IRGKangXi=1188.181, RSKangXi=149.2, Def{draw up agreement; arrange}
8BA3 CJK UNIFIED IDEOGRAPH-#8BA3, IRGKangXi=1188.181, RSKangXi=149.2, Def{obituary; give notice of death}
8BA4 CJK UNIFIED IDEOGRAPH-#8BA4, IRGKangXi=1188.181, RSKangXi=149.2, Def{recognize, know, understand}
8BA5 CJK UNIFIED IDEOGRAPH-#8BA5, IRGKangXi=1188.181, RSKangXi=149.2, Def{ridicule, jeer, mock; inspect}
8BA6 CJK UNIFIED IDEOGRAPH-#8BA6, IRGKangXi=1188.181, RSKangXi=149.3, Def{expose other's secrets, pry}
8BA7 CJK UNIFIED IDEOGRAPH-#8BA7, IRGKangXi=1188.181, RSKangXi=149.3, Def{confusion; internal strife}
8BA8 CJK UNIFIED IDEOGRAPH-#8BA8, IRGKangXi=1188.181, RSKangXi=149.3, Def{to discuss; ask for, beg; demand; dun; marry}
8BA9 CJK UNIFIED IDEOGRAPH-#8BA9, IRGKangXi=1188.181, RSKangXi=149.3, Def{allow, permit, yield, concede}
8BAA CJK UNIFIED IDEOGRAPH-#8BAA, IRGKangXi=1188.181, RSKangXi=149.3, Def{abuse, slander; vilify; ridicule}
8BAB CJK UNIFIED IDEOGRAPH-#8BAB, IRGKangXi=1188.181, RSKangXi=149.3, Def{finish; conclude, stop; exhaust}
8BAC CJK UNIFIED IDEOGRAPH-#8BAC, IRGKangXi=1188.181, RSKangXi=149.3, Def{entrust, rely on; commission}
8BAD CJK UNIFIED IDEOGRAPH-#8BAD, IRGKangXi=1188.181, RSKangXi=149.3, Def{teach, instruct; exegesis}
8BAE CJK UNIFIED IDEOGRAPH-#8BAE, IRGKangXi=1188.181, RSKangXi=149.3, Def{consult, talk over, discuss}
8BAF CJK UNIFIED IDEOGRAPH-#8BAF, IRGKangXi=1188.181, RSKangXi=149.3, Def{inquire; ask; examine; reproach}
8BB0 CJK UNIFIED IDEOGRAPH-#8BB0, IRGKangXi=1188.181, RSKangXi=149.3, Def{record; keep in mind, remember}
8BB1 CJK UNIFIED IDEOGRAPH-#8BB1, IRGKangXi=1188.181, RSKangXi=149.3, Def{hesitate to say, reluctant to speak}
8BB2 CJK UNIFIED IDEOGRAPH-#8BB2, IRGKangXi=1188.181, RSKangXi=149.4, Def{explain; discuss; talk}
8BB3 CJK UNIFIED IDEOGRAPH-#8BB3, IRGKangXi=1188.181, RSKangXi=149.4, Def{conceal; shun; regard as taboo}
8BB4 CJK UNIFIED IDEOGRAPH-#8BB4, IRGKangXi=1188.181, RSKangXi=149.4, Def{sing; songs}
8BB5 CJK UNIFIED IDEOGRAPH-#8BB5, IRGKangXi=1188.181, RSKangXi=149.5, Def{an interjection used express surprise}
8BB6 CJK UNIFIED IDEOGRAPH-#8BB6, IRGKangXi=1188.181, RSKangXi=149.4, Def{express surprise, be surprised}
8BB7 CJK UNIFIED IDEOGRAPH-#8BB7, IRGKangXi=1188.181, RSKangXi=149.4, Def{slow of speech; mumble; stammer}
8BB8 CJK UNIFIED IDEOGRAPH-#8BB8, IRGKangXi=1188.181, RSKangXi=149.4, Def{allow, permit; promise; betroth}
8BB9 CJK UNIFIED IDEOGRAPH-#8BB9, IRGKangXi=1188.181, RSKangXi=149.4, Def{swindle, cheat; erroneous, wrong}
8BBA CJK UNIFIED IDEOGRAPH-#8BBA, IRGKangXi=1188.181, RSKangXi=149.4, Def{debate; discuss; discourse}
8BBB CJK UNIFIED IDEOGRAPH-#8BBB, IRGKangXi=1188.181, RSKangXi=149.4, Def{noisily; uproarious; troublesome}
8BBC CJK UNIFIED IDEOGRAPH-#8BBC, IRGKangXi=1188.181, RSKangXi=149.4, Def{accuse; argue, dispute; litigate}
8BBD CJK UNIFIED IDEOGRAPH-#8BBD, IRGKangXi=1188.181, RSKangXi=149.4, Def{recite, incant; satirize}
8BBE CJK UNIFIED IDEOGRAPH-#8BBE, IRGKangXi=1188.181, RSKangXi=149.4, Def{build; establish; display}
8BBF CJK UNIFIED IDEOGRAPH-#8BBF, IRGKangXi=1188.181, RSKangXi=149.4, Def{visit; ask, inquire}
8BC0 CJK UNIFIED IDEOGRAPH-#8BC0, IRGKangXi=1188.181, RSKangXi=149.4, Def{take leave of, bid farewell}
8BC1 CJK UNIFIED IDEOGRAPH-#8BC1, IRGKangXi=1188.181, RSKangXi=149.5, Def{prove, confirm, verify; proof}
8BC2 CJK UNIFIED IDEOGRAPH-#8BC2, IRGKangXi=1188.181, RSKangXi=149.5, Def{exegesis, explanation; explain}
8BC3 CJK UNIFIED IDEOGRAPH-#8BC3, IRGKangXi=1188.181, RSKangXi=149.5, Def{scold loudly, curse, abuse}
8BC4 CJK UNIFIED IDEOGRAPH-#8BC4, IRGKangXi=1188.181, RSKangXi=149.5, Def{appraise, criticize, evaluate}
8BC5 CJK UNIFIED IDEOGRAPH-#8BC5, IRGKangXi=1188.181, RSKangXi=149.5, Def{curse; swear, pledge}
8BC6 CJK UNIFIED IDEOGRAPH-#8BC6, IRGKangXi=1188.181, RSKangXi=149.5, Def{recognize, understand, know}
8BC7 CJK UNIFIED IDEOGRAPH-#8BC7, IRGKangXi=1188.181, RSKangXi=149.5, Def{to spy; to give information; shrewd}
8BC8 CJK UNIFIED IDEOGRAPH-#8BC8, IRGKangXi=1188.181, RSKangXi=149.5, Def{cheat, defraud, swindle; trick}
8BC9 CJK UNIFIED IDEOGRAPH-#8BC9, IRGKangXi=1188.181, RSKangXi=149.5, Def{accuse; sue; inform; narrate}
8BCA CJK UNIFIED IDEOGRAPH-#8BCA, IRGKangXi=1188.181, RSKangXi=149.5, Def{examine patient, diagnose}
8BCB CJK UNIFIED IDEOGRAPH-#8BCB, IRGKangXi=1188.181, RSKangXi=149.5, Def{slander, comdemn, reproach}
8BCC CJK UNIFIED IDEOGRAPH-#8BCC, IRGKangXi=1188.181, RSKangXi=149.5, Def{play with words, quip; talk nonse}
8BCD CJK UNIFIED IDEOGRAPH-#8BCD, IRGKangXi=1188.181, RSKangXi=149.5, Def{words; phrase, expression}
8BCE CJK UNIFIED IDEOGRAPH-#8BCE, IRGKangXi=1188.181, RSKangXi=149.5, Def{bend, stoop, crouch; to yield}
8BCF CJK UNIFIED IDEOGRAPH-#8BCF, IRGKangXi=1188.181, RSKangXi=149.5, Def{decree, proclaim; imperial decree}
8BD0 CJK UNIFIED IDEOGRAPH-#8BD0, IRGKangXi=1188.181, RSKangXi=149.5, Def{argue; biased; one-sided}
8BD1 CJK UNIFIED IDEOGRAPH-#8BD1, IRGKangXi=1188.181, RSKangXi=149.5, Def{translate; decode; encode}
8BD2 CJK UNIFIED IDEOGRAPH-#8BD2, IRGKangXi=1188.181, RSKangXi=149.5, Def{bequeath, pass on to future generations}
8BD3 CJK UNIFIED IDEOGRAPH-#8BD3, IRGKangXi=1188.181, RSKangXi=149.6, Def{cheat, swindle, lie}
8BD4 CJK UNIFIED IDEOGRAPH-#8BD4, IRGKangXi=1188.181, RSKangXi=149.6, Def{eulogize, praise the dead}
8BD5 CJK UNIFIED IDEOGRAPH-#8BD5, IRGKangXi=1188.181, RSKangXi=149.6, Def{test, try, experiment}
8BD6 CJK UNIFIED IDEOGRAPH-#8BD6, IRGKangXi=1188.181, RSKangXi=149.6, Def{error, mistake; deceive, mislead}
8BD7 CJK UNIFIED IDEOGRAPH-#8BD7, IRGKangXi=1188.181, RSKangXi=149.6, Def{poetry; poem, verse, ode}
8BD8 CJK UNIFIED IDEOGRAPH-#8BD8, IRGKangXi=1188.181, RSKangXi=149.6, Def{question, interrogate}
8BD9 CJK UNIFIED IDEOGRAPH-#8BD9, IRGKangXi=1188.181, RSKangXi=149.6, Def{tease, joke with; ridicule, mock}
8BDA CJK UNIFIED IDEOGRAPH-#8BDA, IRGKangXi=1188.181, RSKangXi=149.6, Def{sincere, honest; true, real}
8BDB CJK UNIFIED IDEOGRAPH-#8BDB, IRGKangXi=1188.181, RSKangXi=149.6, Def{execute, kill, put to death; punish}
8BDC CJK UNIFIED IDEOGRAPH-#8BDC, IRGKangXi=1188.181, RSKangXi=149.6, Def{inquire, question; numerous}
8BDD CJK UNIFIED IDEOGRAPH-#8BDD, IRGKangXi=1188.181, RSKangXi=149.6, Def{speech, talk, language; dialect}
8BDE CJK UNIFIED IDEOGRAPH-#8BDE, IRGKangXi=1188.181, RSKangXi=149.8, Def{bear children, give birth; birth}
8BDF CJK UNIFIED IDEOGRAPH-#8BDF, IRGKangXi=1188.181, RSKangXi=149.6, Def{abuse, scold, berate, insult}
8BE0 CJK UNIFIED IDEOGRAPH-#8BE0, IRGKangXi=1188.181, RSKangXi=149.6, Def{explain, expound, comment on}
8BE1 CJK UNIFIED IDEOGRAPH-#8BE1, IRGKangXi=1188.181, RSKangXi=149.6, Def{deceive, cheat, defraud; sly}
8BE2 CJK UNIFIED IDEOGRAPH-#8BE2, IRGKangXi=1188.181, RSKangXi=149.6, Def{inquire into, ask about; consult}
8BE3 CJK UNIFIED IDEOGRAPH-#8BE3, IRGKangXi=1188.181, RSKangXi=149.6, Def{reach; achievement, accomplishment}
8BE4 CJK UNIFIED IDEOGRAPH-#8BE4, IRGKangXi=1188.181, RSKangXi=149.6, Def{to expostulate; to remonstrate}
8BE5 CJK UNIFIED IDEOGRAPH-#8BE5, IRGKangXi=1188.181, RSKangXi=149.6, Def{should, ought to, need to}
8BE6 CJK UNIFIED IDEOGRAPH-#8BE6, IRGKangXi=1188.181, RSKangXi=149.6, Def{detailed, complete, thorough}
8BE7 CJK UNIFIED IDEOGRAPH-#8BE7, IRGKangXi=1188.181, RSKangXi=149.6, Def{be surprised, be shocked}
8BE8 CJK UNIFIED IDEOGRAPH-#8BE8, IRGKangXi=1188.181, RSKangXi=149.6, Def{jokes, obsene jests; joke}
8BE9 CJK UNIFIED IDEOGRAPH-#8BE9, IRGKangXi=1188.181, RSKangXi=149.6, Def{boast, brag; popular, well-known}
8BEA CJK UNIFIED IDEOGRAPH-#8BEA, IRGKangXi=1188.181, RSKangXi=149.14, Def{deceive, cheat; hurried, bustling}
8BEB CJK UNIFIED IDEOGRAPH-#8BEB, IRGKangXi=1188.181, RSKangXi=149.7, Def{warn, admonish; warning}
8BEC CJK UNIFIED IDEOGRAPH-#8BEC, IRGKangXi=1188.181, RSKangXi=149.7, Def{make false accusation; defame}
8BED CJK UNIFIED IDEOGRAPH-#8BED, IRGKangXi=1188.181, RSKangXi=149.7, Def{language, words; saying, expression}
8BEE CJK UNIFIED IDEOGRAPH-#8BEE, IRGKangXi=1188.181, RSKangXi=149.7, Def{criticize, scold, blame, ridicule}
8BEF CJK UNIFIED IDEOGRAPH-#8BEF, IRGKangXi=1188.181, RSKangXi=149.7, Def{err, make mistake; interfere}
8BF0 CJK UNIFIED IDEOGRAPH-#8BF0, IRGKangXi=1188.181, RSKangXi=149.7, Def{inform, notify, admonish, order}
8BF1 CJK UNIFIED IDEOGRAPH-#8BF1, IRGKangXi=1188.181, RSKangXi=149.7, Def{persuade, entice, induce; guide}
8BF2 CJK UNIFIED IDEOGRAPH-#8BF2, IRGKangXi=1188.181, RSKangXi=149.7, Def{teach, instruct; encourage, urge}
8BF3 CJK UNIFIED IDEOGRAPH-#8BF3, IRGKangXi=1188.181, RSKangXi=149.7, Def{deceive, lie, delude, cheat}
8BF4 CJK UNIFIED IDEOGRAPH-#8BF4, IRGKangXi=1188.181, RSKangXi=149.7, Def{speak, say, talk; scold, upbraid}
8BF5 CJK UNIFIED IDEOGRAPH-#8BF5, IRGKangXi=1188.181, RSKangXi=149.7, Def{recite, chant, repeat}
8BF6 CJK UNIFIED IDEOGRAPH-#8BF6, IRGKangXi=1188.181, RSKangXi=149.7, Def{an exclamation of confirmation}
8BF7 CJK UNIFIED IDEOGRAPH-#8BF7, IRGKangXi=1188.181, RSKangXi=149.8, Def{ask, request; invite; please}
8BF8 CJK UNIFIED IDEOGRAPH-#8BF8, IRGKangXi=1188.181, RSKangXi=149.8, Def{various, all, these; surname}
8BF9 CJK UNIFIED IDEOGRAPH-#8BF9, IRGKangXi=1188.181, RSKangXi=149.8, Def{consult, confer; select, choose}
8BFA CJK UNIFIED IDEOGRAPH-#8BFA, IRGKangXi=1188.181, RSKangXi=149.8, Def{promise; assent, approve}
8BFB CJK UNIFIED IDEOGRAPH-#8BFB, IRGKangXi=1188.181, RSKangXi=149.8, Def{read, study; pronounce}
8BFC CJK UNIFIED IDEOGRAPH-#8BFC, IRGKangXi=1188.181, RSKangXi=149.8, Def{slander; gossip; rumors}
8BFD CJK UNIFIED IDEOGRAPH-#8BFD, IRGKangXi=1188.181, RSKangXi=149.8, Def{slander, vilify, condemn}
8BFE CJK UNIFIED IDEOGRAPH-#8BFE, IRGKangXi=1188.181, RSKangXi=149.8, Def{lesson; course; classwork}
8BFF CJK UNIFIED IDEOGRAPH-#8BFF, IRGKangXi=1188.181, RSKangXi=149.8, Def{pass buck, lay blame on others}
8C00 CJK UNIFIED IDEOGRAPH-#8C00, IRGKangXi=1188.181, RSKangXi=149.8, Def{flatter, truckle}
8C01 CJK UNIFIED IDEOGRAPH-#8C01, IRGKangXi=1188.181, RSKangXi=149.8, Def{who? whom? whose? anyone?}
8C02 CJK UNIFIED IDEOGRAPH-#8C02, IRGKangXi=1188.181, RSKangXi=149.8, Def{consult carefully with, counsel}
8C03 CJK UNIFIED IDEOGRAPH-#8C03, IRGKangXi=1188.181, RSKangXi=149.8, Def{transfer, move, change; tune}
8C04 CJK UNIFIED IDEOGRAPH-#8C04, IRGKangXi=1188.181, RSKangXi=149.8, Def{flatter, truckle, toady}
8C05 CJK UNIFIED IDEOGRAPH-#8C05, IRGKangXi=1188.181, RSKangXi=149.8, Def{excuse, forgive; guess, presume}
8C06 CJK UNIFIED IDEOGRAPH-#8C06, IRGKangXi=1188.181, RSKangXi=149.8, Def{patient, earnest; earnestly}
8C07 CJK UNIFIED IDEOGRAPH-#8C07, IRGKangXi=1188.181, RSKangXi=149.8, Def{speak ill of, vilify; berate}
8C08 CJK UNIFIED IDEOGRAPH-#8C08, IRGKangXi=1188.181, RSKangXi=149.8, Def{talk; conversation; surname}
8C09 CJK UNIFIED IDEOGRAPH-#8C09, IRGKangXi=1188.181, RSKangXi=149.8
8C0A CJK UNIFIED IDEOGRAPH-#8C0A, IRGKangXi=1188.181, RSKangXi=149.8, Def{friendship; appropriate, suitable}
8C0B CJK UNIFIED IDEOGRAPH-#8C0B, IRGKangXi=1188.181, RSKangXi=149.9, Def{plan, scheme; strategem}
8C0C CJK UNIFIED IDEOGRAPH-#8C0C, IRGKangXi=1188.181, RSKangXi=149.9, Def{sincere, faithful; surname}
8C0D CJK UNIFIED IDEOGRAPH-#8C0D, IRGKangXi=1188.181, RSKangXi=149.9, Def{an intelligence report; to spy; spying}
8C0E CJK UNIFIED IDEOGRAPH-#8C0E, IRGKangXi=1188.181, RSKangXi=149.9, Def{lie}
8C0F CJK UNIFIED IDEOGRAPH-#8C0F, IRGKangXi=1188.181, RSKangXi=149.9, Def{remonstrate, admonish}
8C10 CJK UNIFIED IDEOGRAPH-#8C10, IRGKangXi=1188.181, RSKangXi=149.9, Def{harmonize, agree; joke, jest}
8C11 CJK UNIFIED IDEOGRAPH-#8C11, IRGKangXi=1188.181, RSKangXi=149.9, Def{jeer}
8C12 CJK UNIFIED IDEOGRAPH-#8C12, IRGKangXi=1188.181, RSKangXi=149.9, Def{visit, pay respects}
8C13 CJK UNIFIED IDEOGRAPH-#8C13, IRGKangXi=1188.181, RSKangXi=149.9, Def{say, tell; call, name; be called}
8C14 CJK UNIFIED IDEOGRAPH-#8C14, IRGKangXi=1188.181, RSKangXi=149.9, Def{honest speech, straightforward}
8C15 CJK UNIFIED IDEOGRAPH-#8C15, IRGKangXi=1188.181, RSKangXi=149.9, Def{proclaim, instruct; edict}
8C16 CJK UNIFIED IDEOGRAPH-#8C16, IRGKangXi=1188.181, RSKangXi=149.9, Def{forget; lie, cheat, deceive}
8C17 CJK UNIFIED IDEOGRAPH-#8C17, IRGKangXi=1188.181, RSKangXi=149.9, Def{slander, defame, misrepresent}
8C18 CJK UNIFIED IDEOGRAPH-#8C18, IRGKangXi=1188.181, RSKangXi=149.9, Def{consult, confer; communicate in}
8C19 CJK UNIFIED IDEOGRAPH-#8C19, IRGKangXi=1188.181, RSKangXi=149.9, Def{versed in, fully acquainted with}
8C1A CJK UNIFIED IDEOGRAPH-#8C1A, IRGKangXi=1188.181, RSKangXi=149.9, Def{proverb, maxim}
8C1B CJK UNIFIED IDEOGRAPH-#8C1B, IRGKangXi=1188.181, RSKangXi=149.9, Def{careful, attentive}
8C1C CJK UNIFIED IDEOGRAPH-#8C1C, IRGKangXi=1188.181, RSKangXi=149.9, Def{riddle, conundrum; puzzle}
8C1D CJK UNIFIED IDEOGRAPH-#8C1D, IRGKangXi=1188.181, RSKangXi=149.9, Def{brag, boast; quibble}
8C1E CJK UNIFIED IDEOGRAPH-#8C1E, IRGKangXi=1188.181, RSKangXi=149.9, Def{knowledge; discrimination; treachery}
8C1F CJK UNIFIED IDEOGRAPH-#8C1F, IRGKangXi=1188.181, RSKangXi=149.10, Def{scheme, plan; plan; be without}
8C20 CJK UNIFIED IDEOGRAPH-#8C20, IRGKangXi=1188.181, RSKangXi=149.10, Def{counsel, advice; speak out}
8C21 CJK UNIFIED IDEOGRAPH-#8C21, IRGKangXi=1188.181, RSKangXi=149.10, Def{rise up; raise up}
8C22 CJK UNIFIED IDEOGRAPH-#8C22, IRGKangXi=1188.181, RSKangXi=149.10, Def{thank; decline}
8C23 CJK UNIFIED IDEOGRAPH-#8C23, IRGKangXi=1188.181, RSKangXi=149.10, Def{sing; folksong, ballad; rumor}
8C24 CJK UNIFIED IDEOGRAPH-#8C24, IRGKangXi=1188.181, RSKangXi=149.10, Def{slander, libel}
8C25 CJK UNIFIED IDEOGRAPH-#8C25, IRGKangXi=1188.181, RSKangXi=149.10, Def{to confer posthumous titles}
8C26 CJK UNIFIED IDEOGRAPH-#8C26, IRGKangXi=1188.181, RSKangXi=149.10, Def{humble, modest}
8C27 CJK UNIFIED IDEOGRAPH-#8C27, IRGKangXi=1188.181, RSKangXi=149.10, Def{calm, quiet, still; cautious}
8C28 CJK UNIFIED IDEOGRAPH-#8C28, IRGKangXi=1188.181, RSKangXi=149.11, Def{prudent, cautious; attentive}
8C29 CJK UNIFIED IDEOGRAPH-#8C29, IRGKangXi=1188.181, RSKangXi=149.11, Def{deceive, insult}
8C2A CJK UNIFIED IDEOGRAPH-#8C2A, IRGKangXi=1188.181, RSKangXi=149.11, Def{charge, blame; disgrace; demote}
8C2B CJK UNIFIED IDEOGRAPH-#8C2B, IRGKangXi=1188.181, RSKangXi=149.11, Def{shallow; stupid}
8C2C CJK UNIFIED IDEOGRAPH-#8C2C, IRGKangXi=1188.181, RSKangXi=149.11, Def{error, exaggeration; erroneous}
8C2D CJK UNIFIED IDEOGRAPH-#8C2D, IRGKangXi=1188.181, RSKangXi=149.12, Def{surname}
8C2E CJK UNIFIED IDEOGRAPH-#8C2E, IRGKangXi=1188.181, RSKangXi=149.12, Def{to slander}
8C2F CJK UNIFIED IDEOGRAPH-#8C2F, IRGKangXi=1188.181, RSKangXi=149.12, Def{tower; surname}
8C30 CJK UNIFIED IDEOGRAPH-#8C30, IRGKangXi=1188.181, RSKangXi=149.12, Def{accuse falsely; slander, libel}
8C31 CJK UNIFIED IDEOGRAPH-#8C31, IRGKangXi=1188.181, RSKangXi=149.12, Def{list, table; musical score}
8C32 CJK UNIFIED IDEOGRAPH-#8C32, IRGKangXi=1188.181, RSKangXi=149.12, Def{cunning, crafty, sly, wily}
8C33 CJK UNIFIED IDEOGRAPH-#8C33, IRGKangXi=1188.181, RSKangXi=149.13, Def{to decide, judge; a verdict, decision}
8C34 CJK UNIFIED IDEOGRAPH-#8C34, IRGKangXi=1188.181, RSKangXi=149.13, Def{reprimand, scold, abuse}
8C35 CJK UNIFIED IDEOGRAPH-#8C35, IRGKangXi=1188.181, RSKangXi=149.13, Def{talkative; incoherent talk}
8C36 CJK UNIFIED IDEOGRAPH-#8C36, IRGKangXi=1188.181, RSKangXi=149.17, Def{prophecy, hint, omen}
8C37 CJK UNIFIED IDEOGRAPH-#8C37, IRGKangXi=1189.010, RSKangXi=150.0, Def{valley, gorge, ravine}
8C38 CJK UNIFIED IDEOGRAPH-#8C38, IRGKangXi=1189.050, RSKangXi=150.3
8C39 CJK UNIFIED IDEOGRAPH-#8C39, IRGKangXi=1189.100, RSKangXi=150.4
8C3A CJK UNIFIED IDEOGRAPH-#8C3A, IRGKangXi=1189.120, RSKangXi=150.4, Def{the mouth of a valley}
8C3B CJK UNIFIED IDEOGRAPH-#8C3B, IRGKangXi=1189.140, RSKangXi=150.4
8C3C CJK UNIFIED IDEOGRAPH-#8C3C, IRGKangXi=1190.060, RSKangXi=150.6
8C3D CJK UNIFIED IDEOGRAPH-#8C3D, IRGKangXi=1190.110, RSKangXi=150.7, Def{a mouth or opening}
8C3E CJK UNIFIED IDEOGRAPH-#8C3E, IRGKangXi=1190.170, RSKangXi=150.8
8C3F CJK UNIFIED IDEOGRAPH-#8C3F, IRGKangXi=1190.210, RSKangXi=150.10, Def{valley, gorge; mountain stream}
8C40 CJK UNIFIED IDEOGRAPH-#8C40, IRGKangXi=1190.220, RSKangXi=150.10, Def{to quarrel; mean and petty}
8C41 CJK UNIFIED IDEOGRAPH-#8C41, IRGKangXi=1190.230, RSKangXi=150.10, Def{open up, clear; exempt}
8C42 CJK UNIFIED IDEOGRAPH-#8C42, IRGKangXi=1190.250, RSKangXi=150.11
8C43 CJK UNIFIED IDEOGRAPH-#8C43, IRGKangXi=1191.020, RSKangXi=150.12
8C44 CJK UNIFIED IDEOGRAPH-#8C44, IRGKangXi=1191.080
8C45 CJK UNIFIED IDEOGRAPH-#8C45, IRGKangXi=1191.100, RSKangXi=150.16
8C46 CJK UNIFIED IDEOGRAPH-#8C46, IRGKangXi=1191.140, RSKangXi=151.0, Def{beans, peas; bean-shaped}
8C47 CJK UNIFIED IDEOGRAPH-#8C47, IRGKangXi=1191.180, RSKangXi=151.3, Def{a small kidney bean}
8C48 CJK UNIFIED IDEOGRAPH-#8C48, IRGKangXi=1191.200, RSKangXi=151.3, Def{how? what?}
8C49 CJK UNIFIED IDEOGRAPH-#8C49, IRGKangXi=1191.230, RSKangXi=151.4, Def{fermented beans}
8C4A CJK UNIFIED IDEOGRAPH-#8C4A, IRGKangXi=1192.070, RSKangXi=151.6, Def{abundant, lush, bountiful, plenty}
8C4B CJK UNIFIED IDEOGRAPH-#8C4B, IRGKangXi=1192.080, RSKangXi=151.6, Def{ceremonial vessel}
8C4C CJK UNIFIED IDEOGRAPH-#8C4C, IRGKangXi=1192.160, RSKangXi=151.8, Def{peas}
8C4D CJK UNIFIED IDEOGRAPH-#8C4D, IRGKangXi=1192.210, RSKangXi=151.8
8C4E CJK UNIFIED IDEOGRAPH-#8C4E, IRGKangXi=1192.220, RSKangXi=151.8, Def{vertical; perpendicular; upright}
8C4F CJK UNIFIED IDEOGRAPH-#8C4F, IRGKangXi=1193.010, RSKangXi=151.10, Def{half-grown beans}
8C50 CJK UNIFIED IDEOGRAPH-#8C50, IRGKangXi=1193.120, RSKangXi=151.11, Def{abundant, lush, bountiful, plenty}
8C51 CJK UNIFIED IDEOGRAPH-#8C51, IRGKangXi=1193.240, RSKangXi=151.13
8C52 CJK UNIFIED IDEOGRAPH-#8C52, IRGKangXi=1193.311
8C53 CJK UNIFIED IDEOGRAPH-#8C53, IRGKangXi=1193.330, RSKangXi=151.20, Def{beautiful, captivating, plump, voluptuous}
8C54 CJK UNIFIED IDEOGRAPH-#8C54, IRGKangXi=1194.020, RSKangXi=151.21, Def{plump, voluptuous, beautiful}
8C55 CJK UNIFIED IDEOGRAPH-#8C55, IRGKangXi=1194.040, RSKangXi=152.0, Def{a pig, boar; KangXi radical 152}
8C56 CJK UNIFIED IDEOGRAPH-#8C56, IRGKangXi=1194.080, RSKangXi=152.1, Def{a shackled pig}
8C57 CJK UNIFIED IDEOGRAPH-#8C57, IRGKangXi=1194.120, RSKangXi=152.3, Def{clamour}
8C58 CJK UNIFIED IDEOGRAPH-#8C58, IRGKangXi=1194.170, RSKangXi=152.4, Def{a small pig}
8C59 CJK UNIFIED IDEOGRAPH-#8C59, IRGKangXi=1194.200, RSKangXi=152.4
8C5A CJK UNIFIED IDEOGRAPH-#8C5A, IRGKangXi=1194.230, RSKangXi=152.4, Def{small pig, suckling pig; suffle}
8C5B CJK UNIFIED IDEOGRAPH-#8C5B, IRGKangXi=1195.010, RSKangXi=152.4
8C5C CJK UNIFIED IDEOGRAPH-#8C5C, IRGKangXi=1195.040, RSKangXi=152.4, Def{pig of 3 years}
8C5D CJK UNIFIED IDEOGRAPH-#8C5D, IRGKangXi=1195.050, RSKangXi=152.4, Def{sow (female pig)}
8C5E CJK UNIFIED IDEOGRAPH-#8C5E, IRGKangXi=1195.100, RSKangXi=152.5
8C5F CJK UNIFIED IDEOGRAPH-#8C5F, IRGKangXi=1195.110, RSKangXi=152.5
8C60 CJK UNIFIED IDEOGRAPH-#8C60, IRGKangXi=1195.150, RSKangXi=152.5
8C61 CJK UNIFIED IDEOGRAPH-#8C61, IRGKangXi=1195.210, RSKangXi=152.5, Def{elephant; ivory; figure, image}
8C62 CJK UNIFIED IDEOGRAPH-#8C62, IRGKangXi=1196.040, RSKangXi=152.6, Def{domestic animals; feed, raise}
8C63 CJK UNIFIED IDEOGRAPH-#8C63, IRGKangXi=1196.100, RSKangXi=152.6, Def{pig of 3 years}
8C64 CJK UNIFIED IDEOGRAPH-#8C64, IRGKangXi=1196.110, RSKangXi=152.6
8C65 CJK UNIFIED IDEOGRAPH-#8C65, IRGKangXi=1196.140, RSKangXi=152.6
8C66 CJK UNIFIED IDEOGRAPH-#8C66, IRGKangXi=1196.150, RSKangXi=152.6, Def{a wild boar; to fight}
8C67 CJK UNIFIED IDEOGRAPH-#8C67, IRGKangXi=1196.190, RSKangXi=152.7
8C68 CJK UNIFIED IDEOGRAPH-#8C68, IRGKangXi=1196.290, RSKangXi=152.7, Def{pig, hog}
8C69 CJK UNIFIED IDEOGRAPH-#8C69, IRGKangXi=1197.010, RSKangXi=152.7
8C6A CJK UNIFIED IDEOGRAPH-#8C6A, IRGKangXi=1197.020, RSKangXi=152.7, Def{brave, heroic, chivalrous}
8C6B CJK UNIFIED IDEOGRAPH-#8C6B, IRGKangXi=1197.200, RSKangXi=152.9, Def{relaxed, comfortable, at ease}
8C6C CJK UNIFIED IDEOGRAPH-#8C6C, IRGKangXi=1198.020, RSKangXi=152.9, Def{pig, hog}
8C6D CJK UNIFIED IDEOGRAPH-#8C6D, IRGKangXi=1198.050, RSKangXi=152.9, Def{boar, male pig}
8C6E CJK UNIFIED IDEOGRAPH-#8C6E, IRGKangXi=1198.081, RSKangXi=152.9, Def{castrate pig}
8C6F CJK UNIFIED IDEOGRAPH-#8C6F, IRGKangXi=1198.100, RSKangXi=152.10
8C70 CJK UNIFIED IDEOGRAPH-#8C70, IRGKangXi=1198.110, RSKangXi=152.10
8C71 CJK UNIFIED IDEOGRAPH-#8C71, IRGKangXi=1198.140, RSKangXi=152.10
8C72 CJK UNIFIED IDEOGRAPH-#8C72, IRGKangXi=1198.160, RSKangXi=152.10
8C73 CJK UNIFIED IDEOGRAPH-#8C73, IRGKangXi=1198.170, RSKangXi=152.10, Def{a Zhou-dynasty state}
8C74 CJK UNIFIED IDEOGRAPH-#8C74, IRGKangXi=1199.010, RSKangXi=152.11, Def{a pig's hoof; to go, to send}
8C75 CJK UNIFIED IDEOGRAPH-#8C75, IRGKangXi=1199.020, RSKangXi=152.11, Def{young pig}
8C76 CJK UNIFIED IDEOGRAPH-#8C76, IRGKangXi=1199.100, RSKangXi=152.13, Def{castrate pig}
8C77 CJK UNIFIED IDEOGRAPH-#8C77, IRGKangXi=1199.140, RSKangXi=152.12, Def{person's name}
8C78 CJK UNIFIED IDEOGRAPH-#8C78, IRGKangXi=1199.360, RSKangXi=153.0, Def{KangXi radical 153; legless insects; a legendary beast}
8C79 CJK UNIFIED IDEOGRAPH-#8C79, IRGKangXi=1199.390, RSKangXi=153.3, Def{leopard, panther; surname}
8C7A CJK UNIFIED IDEOGRAPH-#8C7A, IRGKangXi=1200.010, RSKangXi=153.3, Def{wolf; cruel, wicked, mean}
8C7B CJK UNIFIED IDEOGRAPH-#8C7B, IRGKangXi=1200.020, RSKangXi=153.3, Def{prison; a kind of wild dog}
8C7C CJK UNIFIED IDEOGRAPH-#8C7C, IRGKangXi=1200.050, RSKangXi=153.4, Def{fox, leopard, panther}
8C7D CJK UNIFIED IDEOGRAPH-#8C7D, IRGKangXi=1200.090, RSKangXi=153.4
8C7E CJK UNIFIED IDEOGRAPH-#8C7E, IRGKangXi=1200.140, RSKangXi=153.5
8C7F CJK UNIFIED IDEOGRAPH-#8C7F, IRGKangXi=1200.160, RSKangXi=153.5
8C80 CJK UNIFIED IDEOGRAPH-#8C80, IRGKangXi=1200.250, RSKangXi=153.5
8C81 CJK UNIFIED IDEOGRAPH-#8C81, IRGKangXi=1200.260, RSKangXi=153.5
8C82 CJK UNIFIED IDEOGRAPH-#8C82, IRGKangXi=1200.270, RSKangXi=153.5, Def{marten, sable, mink}
8C83 CJK UNIFIED IDEOGRAPH-#8C83, IRGKangXi=1200.290, RSKangXi=153.5
8C84 CJK UNIFIED IDEOGRAPH-#8C84, IRGKangXi=1201.040, RSKangXi=153.6
8C85 CJK UNIFIED IDEOGRAPH-#8C85, IRGKangXi=1201.060, RSKangXi=153.6, Def{brave, fierce, courageous}
8C86 CJK UNIFIED IDEOGRAPH-#8C86, IRGKangXi=1201.070, RSKangXi=153.6, Def{small badger; porcupine}
8C87 CJK UNIFIED IDEOGRAPH-#8C87, IRGKangXi=1201.110, RSKangXi=153.6, Def{to root, gnaw}
8C88 CJK UNIFIED IDEOGRAPH-#8C88, IRGKangXi=1201.120, RSKangXi=153.6
8C89 CJK UNIFIED IDEOGRAPH-#8C89, IRGKangXi=1201.130, RSKangXi=153.6, Def{badger; raccoon dog}
8C8A CJK UNIFIED IDEOGRAPH-#8C8A, IRGKangXi=1201.140, RSKangXi=153.6, Def{leopard; ancient tribe in northeastern China}
8C8B CJK UNIFIED IDEOGRAPH-#8C8B, IRGKangXi=1201.180, RSKangXi=153.7
8C8C CJK UNIFIED IDEOGRAPH-#8C8C, IRGKangXi=1201.190, RSKangXi=153.7, Def{countenance, appearance}
8C8D CJK UNIFIED IDEOGRAPH-#8C8D, IRGKangXi=1201.250, RSKangXi=153.7, Def{a fox-like animal}
8C8E CJK UNIFIED IDEOGRAPH-#8C8E, IRGKangXi=1202.100, RSKangXi=153.8, Def{lion; wild beast; wild horse}
8C8F CJK UNIFIED IDEOGRAPH-#8C8F, IRGKangXi=1202.160, RSKangXi=153.8
8C90 CJK UNIFIED IDEOGRAPH-#8C90, IRGKangXi=1202.220, RSKangXi=153.9
8C91 CJK UNIFIED IDEOGRAPH-#8C91, IRGKangXi=1202.230, RSKangXi=153.9
8C92 CJK UNIFIED IDEOGRAPH-#8C92, IRGKangXi=1202.260, RSKangXi=153.9
8C93 CJK UNIFIED IDEOGRAPH-#8C93, IRGKangXi=1202.300, RSKangXi=153.9, Def{cat}
8C94 CJK UNIFIED IDEOGRAPH-#8C94, IRGKangXi=1202.380, RSKangXi=153.10, Def{fox, leopard, panther}
8C95 CJK UNIFIED IDEOGRAPH-#8C95, IRGKangXi=1202.400, RSKangXi=153.10
8C96 CJK UNIFIED IDEOGRAPH-#8C96, IRGKangXi=1203.020, RSKangXi=153.10
8C97 CJK UNIFIED IDEOGRAPH-#8C97, IRGKangXi=1203.100, RSKangXi=153.11
8C98 CJK UNIFIED IDEOGRAPH-#8C98, IRGKangXi=1203.110, RSKangXi=153.11, Def{the panther; the tapir}
8C99 CJK UNIFIED IDEOGRAPH-#8C99, IRGKangXi=1203.140, RSKangXi=153.11, Def{a kind of animal like a tiger; fierce wild beasts}
8C9A CJK UNIFIED IDEOGRAPH-#8C9A, IRGKangXi=1203.240, RSKangXi=153.12
8C9B CJK UNIFIED IDEOGRAPH-#8C9B, IRGKangXi=1203.380, RSKangXi=153.18, Def{badger}
8C9C CJK UNIFIED IDEOGRAPH-#8C9C, IRGKangXi=1203.390, RSKangXi=153.20, Def{ape}
8C9D CJK UNIFIED IDEOGRAPH-#8C9D, IRGKangXi=1204.010, RSKangXi=154.0, Def{sea shell; money, currency}
8C9E CJK UNIFIED IDEOGRAPH-#8C9E, IRGKangXi=1204.030, RSKangXi=154.2, Def{virtuous, chaste, pure; loyal}
8C9F CJK UNIFIED IDEOGRAPH-#8C9F, IRGKangXi=1204.050, RSKangXi=154.2, Def{member; personnel, staff member}
8CA0 CJK UNIFIED IDEOGRAPH-#8CA0, IRGKangXi=1204.060, RSKangXi=154.2, Def{load, burden; carry, bear}
8CA1 CJK UNIFIED IDEOGRAPH-#8CA1, IRGKangXi=1204.110, RSKangXi=154.3, Def{wealth, valuables, riches}
8CA2 CJK UNIFIED IDEOGRAPH-#8CA2, IRGKangXi=1205.010, RSKangXi=154.3, Def{offer tribute; tribute, gifts}
8CA3 CJK UNIFIED IDEOGRAPH-#8CA3, IRGKangXi=1205.020, RSKangXi=154.3
8CA4 CJK UNIFIED IDEOGRAPH-#8CA4, IRGKangXi=1205.030, RSKangXi=154.3, Def{steps, grade, strata; series}
8CA5 CJK UNIFIED IDEOGRAPH-#8CA5, IRGKangXi=1205.060, RSKangXi=154.4
8CA6 CJK UNIFIED IDEOGRAPH-#8CA6, IRGKangXi=1205.080, RSKangXi=154.4
8CA7 CJK UNIFIED IDEOGRAPH-#8CA7, IRGKangXi=1205.100, RSKangXi=154.4, Def{poor, impoverished, needy}
8CA8 CJK UNIFIED IDEOGRAPH-#8CA8, IRGKangXi=1205.120, RSKangXi=154.4, Def{goods, commodities, products}
8CA9 CJK UNIFIED IDEOGRAPH-#8CA9, IRGKangXi=1205.150, RSKangXi=154.4, Def{peddler, hawker, street merchant}
8CAA CJK UNIFIED IDEOGRAPH-#8CAA, IRGKangXi=1205.160, RSKangXi=154.4, Def{greedy, covet; covetous}
8CAB CJK UNIFIED IDEOGRAPH-#8CAB, IRGKangXi=1205.170, RSKangXi=154.4, Def{a string of 1000 coins; to go through}
8CAC CJK UNIFIED IDEOGRAPH-#8CAC, IRGKangXi=1205.190, RSKangXi=154.4, Def{one's responsibility, duty}
8CAD CJK UNIFIED IDEOGRAPH-#8CAD, IRGKangXi=1206.061, RSKangXi=154.4, Def{matter, material, substance}
8CAE CJK UNIFIED IDEOGRAPH-#8CAE, IRGKangXi=1206.061, RSKangXi=154.4, AccountingNumeric=2, Def{number two}
8CAF CJK UNIFIED IDEOGRAPH-#8CAF, IRGKangXi=1206.090, RSKangXi=154.5, Def{store, stockpile, hoard}
8CB0 CJK UNIFIED IDEOGRAPH-#8CB0, IRGKangXi=1206.100, RSKangXi=154.5, Def{borrow; pardon; loan}
8CB1 CJK UNIFIED IDEOGRAPH-#8CB1, IRGKangXi=1206.120, RSKangXi=154.5
8CB2 CJK UNIFIED IDEOGRAPH-#8CB2, IRGKangXi=1206.130, RSKangXi=154.5, Def{property; wealth; to count}
8CB3 CJK UNIFIED IDEOGRAPH-#8CB3, IRGKangXi=1206.140, RSKangXi=154.5, AccountingNumeric=2, Def{number two}
8CB4 CJK UNIFIED IDEOGRAPH-#8CB4, IRGKangXi=1206.150, RSKangXi=154.5, Def{expensive, costly, valuable}
8CB5 CJK UNIFIED IDEOGRAPH-#8CB5, IRGKangXi=1206.180, RSKangXi=154.5
8CB6 CJK UNIFIED IDEOGRAPH-#8CB6, IRGKangXi=1206.200, RSKangXi=154.5, Def{decrease, lower; censure, criticize}
8CB7 CJK UNIFIED IDEOGRAPH-#8CB7, IRGKangXi=1206.210, RSKangXi=154.5, Def{buy, purchase; bribe, persuade}
8CB8 CJK UNIFIED IDEOGRAPH-#8CB8, IRGKangXi=1206.220, RSKangXi=154.5, Def{lend; borrow; pardon}
8CB9 CJK UNIFIED IDEOGRAPH-#8CB9, IRGKangXi=1206.240, RSKangXi=154.5
8CBA CJK UNIFIED IDEOGRAPH-#8CBA, IRGKangXi=1206.260, RSKangXi=154.5, Def{give, grant, bestow; surname}
8CBB CJK UNIFIED IDEOGRAPH-#8CBB, IRGKangXi=1207.040, RSKangXi=154.5, Def{expenses, expenditures, fee}
8CBC CJK UNIFIED IDEOGRAPH-#8CBC, IRGKangXi=1207.050, RSKangXi=154.5, Def{paste to, stick on; attached to}
8CBD CJK UNIFIED IDEOGRAPH-#8CBD, IRGKangXi=1207.060, RSKangXi=154.5, Def{give to, hand down, bequeath}
8CBE CJK UNIFIED IDEOGRAPH-#8CBE, IRGKangXi=1207.070, RSKangXi=154.5
8CBF CJK UNIFIED IDEOGRAPH-#8CBF, IRGKangXi=1207.080, RSKangXi=154.5, Def{trade, barter; mixed; rashly}
8CC0 CJK UNIFIED IDEOGRAPH-#8CC0, IRGKangXi=1207.120, RSKangXi=154.5, Def{congratulate; send present}
8CC1 CJK UNIFIED IDEOGRAPH-#8CC1, IRGKangXi=1207.140, RSKangXi=154.5, Def{forge ahead; energetic; surname}
8CC2 CJK UNIFIED IDEOGRAPH-#8CC2, IRGKangXi=1207.180, RSKangXi=154.6, Def{bribe; give present}
8CC3 CJK UNIFIED IDEOGRAPH-#8CC3, IRGKangXi=1207.220, RSKangXi=154.6, Def{rent, hire; hired person}
8CC4 CJK UNIFIED IDEOGRAPH-#8CC4, IRGKangXi=1208.020, RSKangXi=154.6, Def{bribe; bribes; riches, wealth}
8CC5 CJK UNIFIED IDEOGRAPH-#8CC5, IRGKangXi=1208.030, RSKangXi=154.6, Def{prepared for; inclusive}
8CC6 CJK UNIFIED IDEOGRAPH-#8CC6, IRGKangXi=1208.040, RSKangXi=154.6
8CC7 CJK UNIFIED IDEOGRAPH-#8CC7, IRGKangXi=1208.050, RSKangXi=154.6, Def{property; wealth; capital}
8CC8 CJK UNIFIED IDEOGRAPH-#8CC8, IRGKangXi=1208.100, RSKangXi=154.6, Def{surname; merchant; buy, trade}
8CC9 CJK UNIFIED IDEOGRAPH-#8CC9, IRGKangXi=1208.110, RSKangXi=154.6, Def{to give alms}
8CCA CJK UNIFIED IDEOGRAPH-#8CCA, IRGKangXi=1208.140, RSKangXi=154.6, Def{thief, traitor}
8CCB CJK UNIFIED IDEOGRAPH-#8CCB, IRGKangXi=1208.160, RSKangXi=154.6
8CCC CJK UNIFIED IDEOGRAPH-#8CCC, IRGKangXi=1208.220, RSKangXi=154.6
8CCD CJK UNIFIED IDEOGRAPH-#8CCD, IRGKangXi=1208.241, RSKangXi=154.6, Def{booty, loot, stolen goods; bribe}
8CCE CJK UNIFIED IDEOGRAPH-#8CCE, IRGKangXi=1208.241, RSKangXi=154.6, Def{mean, low; cheap, worthless}
8CCF CJK UNIFIED IDEOGRAPH-#8CCF, IRGKangXi=1208.280, RSKangXi=154.7, Def{pearls or shells strung together}
8CD0 CJK UNIFIED IDEOGRAPH-#8CD0, IRGKangXi=1208.290, RSKangXi=154.7
8CD1 CJK UNIFIED IDEOGRAPH-#8CD1, IRGKangXi=1208.340, RSKangXi=154.7, Def{relieve, aid distressed; rich}
8CD2 CJK UNIFIED IDEOGRAPH-#8CD2, IRGKangXi=1208.350, RSKangXi=154.7, Def{buy and sell on credit, distant}
8CD3 CJK UNIFIED IDEOGRAPH-#8CD3, IRGKangXi=1208.370, RSKangXi=154.7, Def{guest, visitor; surname; submit}
8CD4 CJK UNIFIED IDEOGRAPH-#8CD4, IRGKangXi=1209.020, Def{guest, visitor; surname; submit}
8CD5 CJK UNIFIED IDEOGRAPH-#8CD5, IRGKangXi=1209.030, RSKangXi=154.7, Def{bribe}
8CD6 CJK UNIFIED IDEOGRAPH-#8CD6, IRGKangXi=1209.081, RSKangXi=154.7
8CD7 CJK UNIFIED IDEOGRAPH-#8CD7, IRGKangXi=1209.081, RSKangXi=154.7
8CD8 CJK UNIFIED IDEOGRAPH-#8CD8, IRGKangXi=1209.081, RSKangXi=154.7
8CD9 CJK UNIFIED IDEOGRAPH-#8CD9, IRGKangXi=1209.090, RSKangXi=154.8, Def{give for charity}
8CDA CJK UNIFIED IDEOGRAPH-#8CDA, IRGKangXi=1209.100, RSKangXi=154.8, Def{give, present, confer; surname}
8CDB CJK UNIFIED IDEOGRAPH-#8CDB, IRGKangXi=1209.130, RSKangXi=154.8, Def{help, support, assist, aid}
8CDC CJK UNIFIED IDEOGRAPH-#8CDC, IRGKangXi=1209.150, RSKangXi=154.8, Def{give, bestow favors; appoint}
8CDD CJK UNIFIED IDEOGRAPH-#8CDD, IRGKangXi=1209.160, RSKangXi=154.8, Def{preious}
8CDE CJK UNIFIED IDEOGRAPH-#8CDE, IRGKangXi=1209.190, RSKangXi=154.8, Def{reward, grant, bestow; appreciate}
8CDF CJK UNIFIED IDEOGRAPH-#8CDF, IRGKangXi=1209.230, RSKangXi=154.8
8CE0 CJK UNIFIED IDEOGRAPH-#8CE0, IRGKangXi=1209.240, RSKangXi=154.8, Def{indemnify, suffer loss}
8CE1 CJK UNIFIED IDEOGRAPH-#8CE1, IRGKangXi=1209.250, RSKangXi=154.8, Def{continue}
8CE2 CJK UNIFIED IDEOGRAPH-#8CE2, IRGKangXi=1209.280, RSKangXi=154.8, Def{virtuous, worthy, good; able}
8CE3 CJK UNIFIED IDEOGRAPH-#8CE3, IRGKangXi=1209.330, RSKangXi=154.8, Def{sell; betray; show off}
8CE4 CJK UNIFIED IDEOGRAPH-#8CE4, IRGKangXi=1209.350, RSKangXi=154.8, Def{mean, low; cheap, worthless}
8CE5 CJK UNIFIED IDEOGRAPH-#8CE5, IRGKangXi=1210.010, RSKangXi=154.8
8CE6 CJK UNIFIED IDEOGRAPH-#8CE6, IRGKangXi=1210.030, RSKangXi=154.8, Def{tax; give; endow; army; diffuse}
8CE7 CJK UNIFIED IDEOGRAPH-#8CE7, IRGKangXi=1210.040, RSKangXi=154.8, Def{fine}
8CE8 CJK UNIFIED IDEOGRAPH-#8CE8, IRGKangXi=1210.050, RSKangXi=154.8, Def{tribute paid in cloth by the tribes in Szechwan and Yunnan under the Han dynasty}
8CE9 CJK UNIFIED IDEOGRAPH-#8CE9, IRGKangXi=1210.060, RSKangXi=154.8
8CEA CJK UNIFIED IDEOGRAPH-#8CEA, IRGKangXi=1210.070, RSKangXi=154.8, Def{matter, material, substance}
8CEB CJK UNIFIED IDEOGRAPH-#8CEB, IRGKangXi=1210.131, RSKangXi=154.8, Def{present}
8CEC CJK UNIFIED IDEOGRAPH-#8CEC, IRGKangXi=1210.131, RSKangXi=154.8, Def{accounts; bill, debt; credit}
8CED CJK UNIFIED IDEOGRAPH-#8CED, IRGKangXi=1210.170, RSKangXi=154.9, Def{bet, gamble, wager; compete}
8CEE CJK UNIFIED IDEOGRAPH-#8CEE, IRGKangXi=1210.200, RSKangXi=154.9, Def{farewell gift}
8CEF CJK UNIFIED IDEOGRAPH-#8CEF, IRGKangXi=1210.240, RSKangXi=154.9
8CF0 CJK UNIFIED IDEOGRAPH-#8CF0, IRGKangXi=1210.250, RSKangXi=154.9, Def{plentiful, wealthy or rich; handsome (pay, gifts, etc.)}
8CF1 CJK UNIFIED IDEOGRAPH-#8CF1, IRGKangXi=1210.270, RSKangXi=154.9
8CF2 CJK UNIFIED IDEOGRAPH-#8CF2, IRGKangXi=1210.290, RSKangXi=154.9
8CF3 CJK UNIFIED IDEOGRAPH-#8CF3, IRGKangXi=1210.300, RSKangXi=154.9
8CF4 CJK UNIFIED IDEOGRAPH-#8CF4, IRGKangXi=1210.310, RSKangXi=154.9, Def{rely, depend on; accuse falsely}
8CF5 CJK UNIFIED IDEOGRAPH-#8CF5, IRGKangXi=1211.040, RSKangXi=154.9, Def{gift}
8CF6 CJK UNIFIED IDEOGRAPH-#8CF6, IRGKangXi=1211.100, RSKangXi=154.10
8CF7 CJK UNIFIED IDEOGRAPH-#8CF7, IRGKangXi=1211.120, RSKangXi=154.10
8CF8 CJK UNIFIED IDEOGRAPH-#8CF8, IRGKangXi=1211.150, RSKangXi=154.10, Def{leftovers, residue, remains}
8CF9 CJK UNIFIED IDEOGRAPH-#8CF9, IRGKangXi=1211.160, RSKangXi=154.10
8CFA CJK UNIFIED IDEOGRAPH-#8CFA, IRGKangXi=1211.170, RSKangXi=154.10, Def{make money, earn; gain, profit}
8CFB CJK UNIFIED IDEOGRAPH-#8CFB, IRGKangXi=1211.180, RSKangXi=154.10, Def{gift of money help pay funeral}
8CFC CJK UNIFIED IDEOGRAPH-#8CFC, IRGKangXi=1211.210, RSKangXi=154.10, Def{buy, purchase; hire}
8CFD CJK UNIFIED IDEOGRAPH-#8CFD, IRGKangXi=1211.220, RSKangXi=154.10, Def{compete, contend; contest, race}
8CFE CJK UNIFIED IDEOGRAPH-#8CFE, IRGKangXi=1211.230, RSKangXi=154.11, Def{abstruse, deep, profound}
8CFF CJK UNIFIED IDEOGRAPH-#8CFF, IRGKangXi=1211.340, RSKangXi=154.11
8D00 CJK UNIFIED IDEOGRAPH-#8D00, IRGKangXi=1211.360, RSKangXi=154.11
8D01 CJK UNIFIED IDEOGRAPH-#8D01, IRGKangXi=1211.380, RSKangXi=154.11, Def{to defeat to spoil or be spoiled; to corrupt or be corrupted}
8D02 CJK UNIFIED IDEOGRAPH-#8D02, IRGKangXi=1211.390, RSKangXi=154.11
8D03 CJK UNIFIED IDEOGRAPH-#8D03, IRGKangXi=1211.440, RSKangXi=154.11, Def{to earn, to make a profit; (Cant.) to enjoy oneself}
8D04 CJK UNIFIED IDEOGRAPH-#8D04, IRGKangXi=1211.460, RSKangXi=154.11, Def{gift superior; gift given}
8D05 CJK UNIFIED IDEOGRAPH-#8D05, IRGKangXi=1211.470, RSKangXi=154.11, Def{unnecessary, superfluous}
8D06 CJK UNIFIED IDEOGRAPH-#8D06, IRGKangXi=1212.060, RSKangXi=154.12
8D07 CJK UNIFIED IDEOGRAPH-#8D07, IRGKangXi=1212.110, RSKangXi=154.12, Def{affable, agreeable, pleasant}
8D08 CJK UNIFIED IDEOGRAPH-#8D08, IRGKangXi=1212.150, RSKangXi=154.12, Def{give present; bestow, confer}
8D09 CJK UNIFIED IDEOGRAPH-#8D09, IRGKangXi=1212.170, RSKangXi=154.12, Def{earnest money; silk label on books}
8D0A CJK UNIFIED IDEOGRAPH-#8D0A, IRGKangXi=1212.210, RSKangXi=154.12, Def{help, support, assist, aid}
8D0B CJK UNIFIED IDEOGRAPH-#8D0B, IRGKangXi=1212.271, RSKangXi=154.12, Def{false; counterfeit; bogus; sham}
8D0C CJK UNIFIED IDEOGRAPH-#8D0C, IRGKangXi=1212.271, RSKangXi=154.12
8D0D CJK UNIFIED IDEOGRAPH-#8D0D, IRGKangXi=1212.280, RSKangXi=154.13, Def{support, aid; to be sufficient; rich, elegant}
8D0E CJK UNIFIED IDEOGRAPH-#8D0E, IRGKangXi=1212.300, RSKangXi=154.13
8D0F CJK UNIFIED IDEOGRAPH-#8D0F, IRGKangXi=1212.330, RSKangXi=154.13, Def{win; surplus, gain, profit}
8D10 CJK UNIFIED IDEOGRAPH-#8D10, IRGKangXi=1212.360, RSKangXi=154.14, Def{farewell present}
8D11 CJK UNIFIED IDEOGRAPH-#8D11, IRGKangXi=1212.400, RSKangXi=154.14, Def{Jiangxi province}
8D12 CJK UNIFIED IDEOGRAPH-#8D12, IRGKangXi=1213.010, RSKangXi=154.14, Def{virtuous, worthy, good; able}
8D13 CJK UNIFIED IDEOGRAPH-#8D13, IRGKangXi=1213.020, RSKangXi=154.14, Def{booty, loot, stolen goods; bribe}
8D14 CJK UNIFIED IDEOGRAPH-#8D14, IRGKangXi=1213.030, RSKangXi=154.14, Def{strong}
8D15 CJK UNIFIED IDEOGRAPH-#8D15, IRGKangXi=1213.070, RSKangXi=154.15
8D16 CJK UNIFIED IDEOGRAPH-#8D16, IRGKangXi=1213.080, RSKangXi=154.15, Def{buy, redeem; ransom; atone for}
8D17 CJK UNIFIED IDEOGRAPH-#8D17, IRGKangXi=1213.100, RSKangXi=154.15, Def{counterfeit, false}
8D18 CJK UNIFIED IDEOGRAPH-#8D18, IRGKangXi=1213.111, RSKangXi=154.15
8D19 CJK UNIFIED IDEOGRAPH-#8D19, IRGKangXi=1213.130, RSKangXi=154.16
8D1A CJK UNIFIED IDEOGRAPH-#8D1A, IRGKangXi=1213.150, RSKangXi=154.16
8D1B CJK UNIFIED IDEOGRAPH-#8D1B, IRGKangXi=1213.190, RSKangXi=154.17, Def{Jiangxi province; places therein}
8D1C CJK UNIFIED IDEOGRAPH-#8D1C, IRGKangXi=1213.201, RSKangXi=154.18, Def{booty, loot, stolen goods; bribe}
8D1D CJK UNIFIED IDEOGRAPH-#8D1D, IRGKangXi=1213.211, RSKangXi=154.0, Def{sea shell; money, currency}
8D1E CJK UNIFIED IDEOGRAPH-#8D1E, IRGKangXi=1213.211, RSKangXi=25.4, Def{virtuous, chaste, pure; loyal}
8D1F CJK UNIFIED IDEOGRAPH-#8D1F, IRGKangXi=1213.211, RSKangXi=154.2, Def{load, burden; carry, bear}
8D20 CJK UNIFIED IDEOGRAPH-#8D20, IRGKangXi=1213.211, RSKangXi=154.2, Def{member; personnel, staff member}
8D21 CJK UNIFIED IDEOGRAPH-#8D21, IRGKangXi=1213.211, RSKangXi=154.3, Def{offer tribute; tribute, gifts}
8D22 CJK UNIFIED IDEOGRAPH-#8D22, IRGKangXi=1213.211, RSKangXi=154.3, Def{wealth, valuables, riches}
8D23 CJK UNIFIED IDEOGRAPH-#8D23, IRGKangXi=1213.211, RSKangXi=154.4, Def{one's responsibility, duty}
8D24 CJK UNIFIED IDEOGRAPH-#8D24, IRGKangXi=1213.211, RSKangXi=154.4, Def{virtuous, worthy, good; able}
8D25 CJK UNIFIED IDEOGRAPH-#8D25, IRGKangXi=1213.211, RSKangXi=154.4, Def{be defeated, decline, fail}
8D26 CJK UNIFIED IDEOGRAPH-#8D26, IRGKangXi=1213.211, RSKangXi=154.4, Def{accounts; bill, debt; credit}
8D27 CJK UNIFIED IDEOGRAPH-#8D27, IRGKangXi=1213.211, RSKangXi=154.4, Def{goods, commodities, products}
8D28 CJK UNIFIED IDEOGRAPH-#8D28, IRGKangXi=1213.211, RSKangXi=27.4, Def{matter, material, substance}
8D29 CJK UNIFIED IDEOGRAPH-#8D29, IRGKangXi=1213.211, RSKangXi=154.4, Def{peddler, hawker, street merchant}
8D2A CJK UNIFIED IDEOGRAPH-#8D2A, IRGKangXi=1213.211, RSKangXi=154.4, Def{be greedy, covet; covetous}
8D2B CJK UNIFIED IDEOGRAPH-#8D2B, IRGKangXi=1213.211, RSKangXi=154.4, Def{poor, impoverished, needy}
8D2C CJK UNIFIED IDEOGRAPH-#8D2C, IRGKangXi=1213.211, RSKangXi=154.5, Def{decrease, lower; censure, criticize}
8D2D CJK UNIFIED IDEOGRAPH-#8D2D, IRGKangXi=1213.211, RSKangXi=154.4, Def{buy, purchase; hire}
8D2E CJK UNIFIED IDEOGRAPH-#8D2E, IRGKangXi=1213.211, RSKangXi=154.4, Def{store, stockpile, hoard}
8D2F CJK UNIFIED IDEOGRAPH-#8D2F, IRGKangXi=1213.211, RSKangXi=154.4, Def{a string of 1000 coins; to go through}
8D30 CJK UNIFIED IDEOGRAPH-#8D30, IRGKangXi=1213.211, RSKangXi=56.6, AccountingNumeric=2, Def{number two}
8D31 CJK UNIFIED IDEOGRAPH-#8D31, IRGKangXi=1213.211, RSKangXi=154.5, Def{mean, low; cheap, worthless}
8D32 CJK UNIFIED IDEOGRAPH-#8D32, IRGKangXi=1213.211, RSKangXi=154.5, Def{forge ahead; energetic; surname}
8D33 CJK UNIFIED IDEOGRAPH-#8D33, IRGKangXi=1213.211, RSKangXi=154.5, Def{borrow; pardon; loan}
8D34 CJK UNIFIED IDEOGRAPH-#8D34, IRGKangXi=1213.211, RSKangXi=154.5, Def{paste to, stick on; attached to}
8D35 CJK UNIFIED IDEOGRAPH-#8D35, IRGKangXi=1213.211, RSKangXi=154.5, Def{expensive, costly, valuable}
8D36 CJK UNIFIED IDEOGRAPH-#8D36, IRGKangXi=1213.211, RSKangXi=154.5, Def{give, grant, bestow; surname}
8D37 CJK UNIFIED IDEOGRAPH-#8D37, IRGKangXi=1213.211, RSKangXi=154.5, Def{lend; borrow; pardon}
8D38 CJK UNIFIED IDEOGRAPH-#8D38, IRGKangXi=1213.211, RSKangXi=154.5, Def{trade, barter; mixed; rashly}
8D39 CJK UNIFIED IDEOGRAPH-#8D39, IRGKangXi=1213.211, RSKangXi=154.5, Def{expenses, expenditures, fee}
8D3A CJK UNIFIED IDEOGRAPH-#8D3A, IRGKangXi=1213.211, RSKangXi=154.5, Def{congratulate; send present}
8D3B CJK UNIFIED IDEOGRAPH-#8D3B, IRGKangXi=1213.211, RSKangXi=154.5, Def{give to, hand down, bequeath}
8D3C CJK UNIFIED IDEOGRAPH-#8D3C, IRGKangXi=1213.211, RSKangXi=154.6, Def{thief, traitor; kill}
8D3D CJK UNIFIED IDEOGRAPH-#8D3D, IRGKangXi=1213.211, RSKangXi=154.6, Def{gift superior; gift given}
8D3E CJK UNIFIED IDEOGRAPH-#8D3E, IRGKangXi=1213.211, RSKangXi=154.6, Def{surname; merchant; buy, trade}
8D3F CJK UNIFIED IDEOGRAPH-#8D3F, IRGKangXi=1213.211, RSKangXi=154.6, Def{bribe; bribes; riches, wealth}
8D40 CJK UNIFIED IDEOGRAPH-#8D40, IRGKangXi=1213.211, RSKangXi=154.6, Def{property; wealth; to count}
8D41 CJK UNIFIED IDEOGRAPH-#8D41, IRGKangXi=1213.211, RSKangXi=154.6, Def{rent, hire; hired person}
8D42 CJK UNIFIED IDEOGRAPH-#8D42, IRGKangXi=1213.211, RSKangXi=154.6, Def{bribe; give present}
8D43 CJK UNIFIED IDEOGRAPH-#8D43, IRGKangXi=1213.211, RSKangXi=154.6, Def{booty, loot, stolen goods; bribe}
8D44 CJK UNIFIED IDEOGRAPH-#8D44, IRGKangXi=1213.211, RSKangXi=154.6, Def{property; wealth; capital}
8D45 CJK UNIFIED IDEOGRAPH-#8D45, IRGKangXi=1213.211, RSKangXi=154.6, Def{prepared for; inclusive}
8D46 CJK UNIFIED IDEOGRAPH-#8D46, IRGKangXi=1213.211, RSKangXi=154.6, Def{farewell present}
8D47 CJK UNIFIED IDEOGRAPH-#8D47, IRGKangXi=1213.211, RSKangXi=154.7, Def{bribe}
8D48 CJK UNIFIED IDEOGRAPH-#8D48, IRGKangXi=1213.211, RSKangXi=154.7, Def{relieve, aid distressed; rich}
8D49 CJK UNIFIED IDEOGRAPH-#8D49, IRGKangXi=1213.211, RSKangXi=154.7, Def{give, present, confer; surname}
8D4A CJK UNIFIED IDEOGRAPH-#8D4A, IRGKangXi=1213.211, RSKangXi=154.7, Def{buy and sell on credit, distant}
8D4B CJK UNIFIED IDEOGRAPH-#8D4B, IRGKangXi=1213.211, RSKangXi=154.8, Def{tax; give; endow; army; diffuse}
8D4C CJK UNIFIED IDEOGRAPH-#8D4C, IRGKangXi=1213.211, RSKangXi=154.8, Def{bet, gamble, wager; compete}
8D4D CJK UNIFIED IDEOGRAPH-#8D4D, IRGKangXi=1213.211, RSKangXi=154.8, Def{present}
8D4E CJK UNIFIED IDEOGRAPH-#8D4E, IRGKangXi=1213.211, RSKangXi=154.8, Def{buy, redeem; ransome; atone for}
8D4F CJK UNIFIED IDEOGRAPH-#8D4F, IRGKangXi=1213.211, RSKangXi=154.8, Def{reward, grant, bestow; appreciate}
8D50 CJK UNIFIED IDEOGRAPH-#8D50, IRGKangXi=1213.211, RSKangXi=154.8, Def{give, bestow favors; appoint}
8D51 CJK UNIFIED IDEOGRAPH-#8D51, IRGKangXi=1213.211, RSKangXi=154.14, Def{strong}
8D52 CJK UNIFIED IDEOGRAPH-#8D52, IRGKangXi=1213.211, RSKangXi=154.8, Def{give for charity}
8D53 CJK UNIFIED IDEOGRAPH-#8D53, IRGKangXi=1213.211, RSKangXi=53.9, Def{continue}
8D54 CJK UNIFIED IDEOGRAPH-#8D54, IRGKangXi=1213.211, RSKangXi=154.8, Def{indemnify, suffer loss}
8D55 CJK UNIFIED IDEOGRAPH-#8D55, IRGKangXi=1213.211, RSKangXi=154.8, Def{fine}
8D56 CJK UNIFIED IDEOGRAPH-#8D56, IRGKangXi=1213.211, RSKangXi=154.9, Def{rely, depend on; accuse falsely}
8D57 CJK UNIFIED IDEOGRAPH-#8D57, IRGKangXi=1213.211, RSKangXi=154.9, Def{gift}
8D58 CJK UNIFIED IDEOGRAPH-#8D58, IRGKangXi=1213.211, RSKangXi=154.10, Def{unnecessary, superfluous}
8D59 CJK UNIFIED IDEOGRAPH-#8D59, IRGKangXi=1213.211, RSKangXi=154.10, Def{gift of money help pay funeral}
8D5A CJK UNIFIED IDEOGRAPH-#8D5A, IRGKangXi=1213.211, RSKangXi=154.10, Def{make money, earn; gain, profit}
8D5B CJK UNIFIED IDEOGRAPH-#8D5B, IRGKangXi=1213.211, RSKangXi=40.11, Def{compete, contend; contest, race}
8D5C CJK UNIFIED IDEOGRAPH-#8D5C, IRGKangXi=1213.211, RSKangXi=22.13, Def{abstruse, deep, profound}
8D5D CJK UNIFIED IDEOGRAPH-#8D5D, IRGKangXi=1213.211, RSKangXi=27.14, Def{false; counterfeit; bogus; sham}
8D5E CJK UNIFIED IDEOGRAPH-#8D5E, IRGKangXi=1213.211, RSKangXi=154.12, Def{help, support, assist, aid}
8D5F CJK UNIFIED IDEOGRAPH-#8D5F, IRGKangXi=1213.211, RSKangXi=154.12, Def{affable, agreeable, pleasant}
8D60 CJK UNIFIED IDEOGRAPH-#8D60, IRGKangXi=1213.211, RSKangXi=154.12, Def{give present; bestow, confer}
8D61 CJK UNIFIED IDEOGRAPH-#8D61, IRGKangXi=1213.211, RSKangXi=154.13, Def{support, aid; rich, elegant}
8D62 CJK UNIFIED IDEOGRAPH-#8D62, IRGKangXi=1213.211, RSKangXi=8.15, Def{win; surplus, gain, profit}
8D63 CJK UNIFIED IDEOGRAPH-#8D63, IRGKangXi=1213.211, RSKangXi=154.17, Def{Jiangxi province; places therein}
8D64 CJK UNIFIED IDEOGRAPH-#8D64, IRGKangXi=1213.220, RSKangXi=155.0, Def{red; communist, 'red'; bare}
8D65 CJK UNIFIED IDEOGRAPH-#8D65, IRGKangXi=1213.280, RSKangXi=155.4
8D66 CJK UNIFIED IDEOGRAPH-#8D66, IRGKangXi=1213.290, RSKangXi=155.4, Def{forgive, remit, pardon}
8D67 CJK UNIFIED IDEOGRAPH-#8D67, IRGKangXi=1214.030, RSKangXi=155.5, Def{blush, turn red}
8D68 CJK UNIFIED IDEOGRAPH-#8D68, IRGKangXi=1214.050, RSKangXi=155.6
8D69 CJK UNIFIED IDEOGRAPH-#8D69, IRGKangXi=1214.060, RSKangXi=155.6
8D6A CJK UNIFIED IDEOGRAPH-#8D6A, IRGKangXi=1214.081, RSKangXi=155.6, Def{deep red}
8D6B CJK UNIFIED IDEOGRAPH-#8D6B, IRGKangXi=1214.120, RSKangXi=155.7, Def{bright, radiant, glowing}
8D6C CJK UNIFIED IDEOGRAPH-#8D6C, IRGKangXi=1214.150, RSKangXi=155.9, Def{deep red}
8D6D CJK UNIFIED IDEOGRAPH-#8D6D, IRGKangXi=1214.160, RSKangXi=155.9, Def{reddish brown; hematite; ochre}
8D6E CJK UNIFIED IDEOGRAPH-#8D6E, IRGKangXi=1214.170, RSKangXi=155.9
8D6F CJK UNIFIED IDEOGRAPH-#8D6F, IRGKangXi=1214.180, RSKangXi=155.10
8D70 CJK UNIFIED IDEOGRAPH-#8D70, IRGKangXi=1215.010, RSKangXi=156.0, Def{walk, go on foot; run; leave}
8D71 CJK UNIFIED IDEOGRAPH-#8D71, IRGKangXi=1215.021, RSKangXi=156.0, Def{walk, go on foot; run; leave}
8D72 CJK UNIFIED IDEOGRAPH-#8D72, IRGKangXi=1215.050, RSKangXi=156.2
8D73 CJK UNIFIED IDEOGRAPH-#8D73, IRGKangXi=1215.060, RSKangXi=156.2, Def{grand, valiant}
8D74 CJK UNIFIED IDEOGRAPH-#8D74, IRGKangXi=1215.080, RSKangXi=156.2, Def{go to; attend, be present}
8D75 CJK UNIFIED IDEOGRAPH-#8D75, IRGKangXi=1215.081, RSKangXi=156.2, Def{surname; ancient state}
8D76 CJK UNIFIED IDEOGRAPH-#8D76, IRGKangXi=1215.120, RSKangXi=156.3, Def{pursue, follow; expel, drive away}
8D77 CJK UNIFIED IDEOGRAPH-#8D77, IRGKangXi=1215.150, RSKangXi=156.3, Def{rise, stand up; go up; begin}
8D78 CJK UNIFIED IDEOGRAPH-#8D78, IRGKangXi=1215.220, RSKangXi=156.3
8D79 CJK UNIFIED IDEOGRAPH-#8D79, IRGKangXi=1215.230, RSKangXi=156.4
8D7A CJK UNIFIED IDEOGRAPH-#8D7A, IRGKangXi=1215.260, RSKangXi=156.4
8D7B CJK UNIFIED IDEOGRAPH-#8D7B, IRGKangXi=1215.270, RSKangXi=156.4
8D7C CJK UNIFIED IDEOGRAPH-#8D7C, IRGKangXi=1215.290, RSKangXi=156.4
8D7D CJK UNIFIED IDEOGRAPH-#8D7D, IRGKangXi=1215.380, RSKangXi=156.4
8D7E CJK UNIFIED IDEOGRAPH-#8D7E, IRGKangXi=1215.400, RSKangXi=156.4
8D7F CJK UNIFIED IDEOGRAPH-#8D7F, IRGKangXi=1215.410, RSKangXi=156.4, Def{late slow; dilatory; tardy to delay; dull; stupid}
8D80 CJK UNIFIED IDEOGRAPH-#8D80, IRGKangXi=1215.450, RSKangXi=156.5
8D81 CJK UNIFIED IDEOGRAPH-#8D81, IRGKangXi=1216.010, RSKangXi=156.5, Def{take advantage of, avail oneself}
8D82 CJK UNIFIED IDEOGRAPH-#8D82, IRGKangXi=1216.020, RSKangXi=156.5, Def{to take advantage of; to avail oneself of. to follow; to go}
8D83 CJK UNIFIED IDEOGRAPH-#8D83, IRGKangXi=1216.030, RSKangXi=156.5
8D84 CJK UNIFIED IDEOGRAPH-#8D84, IRGKangXi=1216.130, RSKangXi=156.5, Def{weak, lame}
8D85 CJK UNIFIED IDEOGRAPH-#8D85, IRGKangXi=1216.140, RSKangXi=156.5, Def{jump over, leap over; surpass}
8D86 CJK UNIFIED IDEOGRAPH-#8D86, IRGKangXi=1216.160, RSKangXi=156.5
8D87 CJK UNIFIED IDEOGRAPH-#8D87, IRGKangXi=1216.190, RSKangXi=156.5
8D88 CJK UNIFIED IDEOGRAPH-#8D88, IRGKangXi=1216.220, RSKangXi=156.5
8D89 CJK UNIFIED IDEOGRAPH-#8D89, IRGKangXi=1216.260, RSKangXi=156.5
8D8A CJK UNIFIED IDEOGRAPH-#8D8A, IRGKangXi=1216.280, RSKangXi=156.5, Def{exceed, go beyond; the more ...}
8D8B CJK UNIFIED IDEOGRAPH-#8D8B, IRGKangXi=1216.321, RSKangXi=156.5, Def{hasten, hurry; be attracted to}
8D8C CJK UNIFIED IDEOGRAPH-#8D8C, IRGKangXi=1216.340, RSKangXi=156.6, Def{(Cant.) to order someone to leave}
8D8D CJK UNIFIED IDEOGRAPH-#8D8D, IRGKangXi=1217.070, RSKangXi=156.6
8D8E CJK UNIFIED IDEOGRAPH-#8D8E, IRGKangXi=1217.080, RSKangXi=156.6
8D8F CJK UNIFIED IDEOGRAPH-#8D8F, IRGKangXi=1217.090, RSKangXi=156.6
8D90 CJK UNIFIED IDEOGRAPH-#8D90, IRGKangXi=1217.130, RSKangXi=156.6
8D91 CJK UNIFIED IDEOGRAPH-#8D91, IRGKangXi=1217.150, RSKangXi=156.6, Def{can't move; to falter}
8D92 CJK UNIFIED IDEOGRAPH-#8D92, IRGKangXi=1217.190, RSKangXi=156.6, Def{to jump, to climb over, to leap, to posture; a gangway}
8D93 CJK UNIFIED IDEOGRAPH-#8D93, IRGKangXi=1217.240, RSKangXi=156.6
8D94 CJK UNIFIED IDEOGRAPH-#8D94, IRGKangXi=1217.250, RSKangXi=156.6, Def{not progressing; to be checked}
8D95 CJK UNIFIED IDEOGRAPH-#8D95, IRGKangXi=1217.280, RSKangXi=156.7, Def{pursue, follow; expel, drive away}
8D96 CJK UNIFIED IDEOGRAPH-#8D96, IRGKangXi=1217.290, RSKangXi=156.7
8D97 CJK UNIFIED IDEOGRAPH-#8D97, IRGKangXi=1217.320, RSKangXi=156.7
8D98 CJK UNIFIED IDEOGRAPH-#8D98, IRGKangXi=1217.480, RSKangXi=156.7
8D99 CJK UNIFIED IDEOGRAPH-#8D99, IRGKangXi=1217.500, RSKangXi=156.7, Def{surname; ancient state}
8D9A CJK UNIFIED IDEOGRAPH-#8D9A, IRGKangXi=1218.020, RSKangXi=156.7
8D9B CJK UNIFIED IDEOGRAPH-#8D9B, IRGKangXi=1218.080, RSKangXi=156.8
8D9C CJK UNIFIED IDEOGRAPH-#8D9C, IRGKangXi=1218.090, RSKangXi=156.8, Def{(Cant.) to suffocate}
8D9D CJK UNIFIED IDEOGRAPH-#8D9D, IRGKangXi=1218.110, RSKangXi=156.8, Def{to pursue; to follow up}
8D9E CJK UNIFIED IDEOGRAPH-#8D9E, IRGKangXi=1218.150, RSKangXi=156.8
8D9F CJK UNIFIED IDEOGRAPH-#8D9F, IRGKangXi=1218.170, RSKangXi=156.8, Def{time, occasion; take journey}
8DA0 CJK UNIFIED IDEOGRAPH-#8DA0, IRGKangXi=1218.200, RSKangXi=156.8
8DA1 CJK UNIFIED IDEOGRAPH-#8DA1, IRGKangXi=1218.220, RSKangXi=156.8, Def{place}
8DA2 CJK UNIFIED IDEOGRAPH-#8DA2, IRGKangXi=1218.340, RSKangXi=156.8
8DA3 CJK UNIFIED IDEOGRAPH-#8DA3, IRGKangXi=1218.350, RSKangXi=156.8, Def{what attracts one's attention}
8DA4 CJK UNIFIED IDEOGRAPH-#8DA4, IRGKangXi=1218.390, RSKangXi=156.8
8DA5 CJK UNIFIED IDEOGRAPH-#8DA5, IRGKangXi=1219.050, RSKangXi=156.9
8DA6 CJK UNIFIED IDEOGRAPH-#8DA6, IRGKangXi=1219.080, RSKangXi=156.9, Def{unable to move; to falter}
8DA7 CJK UNIFIED IDEOGRAPH-#8DA7, IRGKangXi=1219.090, RSKangXi=156.9
8DA8 CJK UNIFIED IDEOGRAPH-#8DA8, IRGKangXi=1219.300, RSKangXi=156.10, Def{hasten, hurry; be attracted to}
8DA9 CJK UNIFIED IDEOGRAPH-#8DA9, IRGKangXi=1220.050, RSKangXi=156.12
8DAA CJK UNIFIED IDEOGRAPH-#8DAA, IRGKangXi=1220.130, RSKangXi=156.12
8DAB CJK UNIFIED IDEOGRAPH-#8DAB, IRGKangXi=1220.150, RSKangXi=156.12, Def{nimble}
8DAC CJK UNIFIED IDEOGRAPH-#8DAC, IRGKangXi=1220.190, RSKangXi=156.12
8DAD CJK UNIFIED IDEOGRAPH-#8DAD, IRGKangXi=1220.200, RSKangXi=156.12
8DAE CJK UNIFIED IDEOGRAPH-#8DAE, IRGKangXi=1220.350, RSKangXi=156.13, Def{easily provoked, hasty; fierce, cruel}
8DAF CJK UNIFIED IDEOGRAPH-#8DAF, IRGKangXi=1220.420, RSKangXi=156.14, Def{jump}
8DB0 CJK UNIFIED IDEOGRAPH-#8DB0, IRGKangXi=1220.421, RSKangXi=156.14
8DB1 CJK UNIFIED IDEOGRAPH-#8DB1, IRGKangXi=1221.071, RSKangXi=156.16, Def{go in hurry, hasten; urge}
8DB2 CJK UNIFIED IDEOGRAPH-#8DB2, IRGKangXi=1221.140, RSKangXi=156.19, Def{go in hurry, hasten; urge}
8DB3 CJK UNIFIED IDEOGRAPH-#8DB3, IRGKangXi=1221.170, RSKangXi=157.0, Def{foot; attain, satisfy, enough}
8DB4 CJK UNIFIED IDEOGRAPH-#8DB4, IRGKangXi=1221.251, RSKangXi=157.2, Def{lying prone, leaning over}
8DB5 CJK UNIFIED IDEOGRAPH-#8DB5, IRGKangXi=1221.260, RSKangXi=157.3, Def{noise of tramping feet}
8DB6 CJK UNIFIED IDEOGRAPH-#8DB6, IRGKangXi=1221.290, RSKangXi=157.3
8DB7 CJK UNIFIED IDEOGRAPH-#8DB7, IRGKangXi=1221.351, RSKangXi=157.3, Def{to jolt; (Cant.) to raise up; block}
8DB8 CJK UNIFIED IDEOGRAPH-#8DB8, IRGKangXi=1221.351, RSKangXi=157.3, Def{sell or buy wholesale; store}
8DB9 CJK UNIFIED IDEOGRAPH-#8DB9, IRGKangXi=1221.360, RSKangXi=157.4, Def{kick with hoof; horse's gallop}
8DBA CJK UNIFIED IDEOGRAPH-#8DBA, IRGKangXi=1222.010, RSKangXi=157.4, Def{sit cross-legged; back of the foo}
8DBB CJK UNIFIED IDEOGRAPH-#8DBB, IRGKangXi=1222.020, RSKangXi=157.4
8DBC CJK UNIFIED IDEOGRAPH-#8DBC, IRGKangXi=1222.070, RSKangXi=157.6, Def{callous skin on hands or feet. blisters}
8DBD CJK UNIFIED IDEOGRAPH-#8DBD, IRGKangXi=1222.110, RSKangXi=157.4
8DBE CJK UNIFIED IDEOGRAPH-#8DBE, IRGKangXi=1222.150, RSKangXi=157.4, Def{toe; tracks, footprints}
8DBF CJK UNIFIED IDEOGRAPH-#8DBF, IRGKangXi=1222.160, RSKangXi=157.4, Def{to tread on; slipshod}
8DC0 CJK UNIFIED IDEOGRAPH-#8DC0, IRGKangXi=1222.210, RSKangXi=157.4, Def{to cut off the feet, to stretch up}
8DC1 CJK UNIFIED IDEOGRAPH-#8DC1, IRGKangXi=1222.240, RSKangXi=157.4, Def{trample on, tread on; search for; (Cant.) to squat down}
8DC2 CJK UNIFIED IDEOGRAPH-#8DC2, IRGKangXi=1222.250, RSKangXi=157.4, Def{creeping, crawling}
8DC3 CJK UNIFIED IDEOGRAPH-#8DC3, IRGKangXi=1222.311, RSKangXi=157.4, Def{skip, jump, frolic}
8DC4 CJK UNIFIED IDEOGRAPH-#8DC4, IRGKangXi=1222.311, RSKangXi=157.4, Def{walk rapidly}
8DC5 CJK UNIFIED IDEOGRAPH-#8DC5, IRGKangXi=1222.320, RSKangXi=157.5, Def{careless, lax; dissolute}
8DC6 CJK UNIFIED IDEOGRAPH-#8DC6, IRGKangXi=1222.340, RSKangXi=157.5, Def{trample}
8DC7 CJK UNIFIED IDEOGRAPH-#8DC7, IRGKangXi=1222.360, RSKangXi=157.5
8DC8 CJK UNIFIED IDEOGRAPH-#8DC8, IRGKangXi=1222.390, RSKangXi=157.5
8DC9 CJK UNIFIED IDEOGRAPH-#8DC9, IRGKangXi=1223.050, RSKangXi=157.5
8DCA CJK UNIFIED IDEOGRAPH-#8DCA, IRGKangXi=1223.070, RSKangXi=157.5
8DCB CJK UNIFIED IDEOGRAPH-#8DCB, IRGKangXi=1223.090, RSKangXi=157.5, Def{go by foot; epilogue, colophon}
8DCC CJK UNIFIED IDEOGRAPH-#8DCC, IRGKangXi=1223.130, RSKangXi=157.5, Def{stumble, slip, fall down; stamp}
8DCD CJK UNIFIED IDEOGRAPH-#8DCD, IRGKangXi=1223.140, RSKangXi=157.5
8DCE CJK UNIFIED IDEOGRAPH-#8DCE, IRGKangXi=1223.150, RSKangXi=157.5, Def{slip, stumble, falter; vacillate}
8DCF CJK UNIFIED IDEOGRAPH-#8DCF, IRGKangXi=1223.200, RSKangXi=157.5, Def{sit cross-legged; squat}
8DD0 CJK UNIFIED IDEOGRAPH-#8DD0, IRGKangXi=1223.220, RSKangXi=157.5, Def{to trample, to step, to walk on the ball of the foot}
8DD1 CJK UNIFIED IDEOGRAPH-#8DD1, IRGKangXi=1223.230, RSKangXi=157.5, Def{run, flee, leave in hurry}
8DD2 CJK UNIFIED IDEOGRAPH-#8DD2, IRGKangXi=1223.250, RSKangXi=157.5
8DD3 CJK UNIFIED IDEOGRAPH-#8DD3, IRGKangXi=1223.270, RSKangXi=157.5
8DD4 CJK UNIFIED IDEOGRAPH-#8DD4, IRGKangXi=1223.280, RSKangXi=157.5, Def{numb feet; to limp}
8DD5 CJK UNIFIED IDEOGRAPH-#8DD5, IRGKangXi=1223.290, RSKangXi=157.5, Def{shuffle, limp}
8DD6 CJK UNIFIED IDEOGRAPH-#8DD6, IRGKangXi=1223.310, RSKangXi=157.5, Def{sole (of the foot)}
8DD7 CJK UNIFIED IDEOGRAPH-#8DD7, IRGKangXi=1223.350, RSKangXi=157.5, Def{the instep}
8DD8 CJK UNIFIED IDEOGRAPH-#8DD8, IRGKangXi=1224.010, RSKangXi=157.5
8DD9 CJK UNIFIED IDEOGRAPH-#8DD9, IRGKangXi=1224.020, RSKangXi=157.5, Def{weak, lame}
8DDA CJK UNIFIED IDEOGRAPH-#8DDA, IRGKangXi=1224.040, RSKangXi=157.5, Def{stagger, limp}
8DDB CJK UNIFIED IDEOGRAPH-#8DDB, IRGKangXi=1224.050, RSKangXi=157.5, Def{lame}
8DDC CJK UNIFIED IDEOGRAPH-#8DDC, IRGKangXi=1224.070, RSKangXi=157.5
8DDD CJK UNIFIED IDEOGRAPH-#8DDD, IRGKangXi=1224.080, RSKangXi=157.5, Def{distance; bird's spur}
8DDE CJK UNIFIED IDEOGRAPH-#8DDE, IRGKangXi=1224.131, RSKangXi=157.5, Def{walk, move}
8DDF CJK UNIFIED IDEOGRAPH-#8DDF, IRGKangXi=1224.140, RSKangXi=157.6, Def{heel; to follow, accompany; with}
8DE0 CJK UNIFIED IDEOGRAPH-#8DE0, IRGKangXi=1224.150, RSKangXi=157.6
8DE1 CJK UNIFIED IDEOGRAPH-#8DE1, IRGKangXi=1224.160, RSKangXi=157.6, Def{search, track, trace}
8DE2 CJK UNIFIED IDEOGRAPH-#8DE2, IRGKangXi=1224.180, RSKangXi=157.6
8DE3 CJK UNIFIED IDEOGRAPH-#8DE3, IRGKangXi=1224.190, RSKangXi=157.6, Def{bare footed}
8DE4 CJK UNIFIED IDEOGRAPH-#8DE4, IRGKangXi=1224.200, RSKangXi=157.6, Def{stumble, fall down; wrestle}
8DE5 CJK UNIFIED IDEOGRAPH-#8DE5, IRGKangXi=1224.210, RSKangXi=157.6, Def{stamp feet}
8DE6 CJK UNIFIED IDEOGRAPH-#8DE6, IRGKangXi=1224.230, RSKangXi=157.6, Def{hop}
8DE7 CJK UNIFIED IDEOGRAPH-#8DE7, IRGKangXi=1224.240, RSKangXi=157.6, Def{crouch}
8DE8 CJK UNIFIED IDEOGRAPH-#8DE8, IRGKangXi=1225.010, RSKangXi=157.6, Def{straddle, bestride, ride; carry}
8DE9 CJK UNIFIED IDEOGRAPH-#8DE9, IRGKangXi=1225.120, RSKangXi=157.6, Def{to waddle, to limp}
8DEA CJK UNIFIED IDEOGRAPH-#8DEA, IRGKangXi=1225.130, RSKangXi=157.6, Def{kneel}
8DEB CJK UNIFIED IDEOGRAPH-#8DEB, IRGKangXi=1225.160, RSKangXi=157.6, Def{sound of footsteps}
8DEC CJK UNIFIED IDEOGRAPH-#8DEC, IRGKangXi=1225.180, RSKangXi=157.6, Def{to step; a stride equal to half a pace}
8DED CJK UNIFIED IDEOGRAPH-#8DED, IRGKangXi=1225.190, RSKangXi=157.6
8DEE CJK UNIFIED IDEOGRAPH-#8DEE, IRGKangXi=1225.200, RSKangXi=157.6, Def{hasty walking}
8DEF CJK UNIFIED IDEOGRAPH-#8DEF, IRGKangXi=1225.220, RSKangXi=157.6, Def{road, path, street; journey}
8DF0 CJK UNIFIED IDEOGRAPH-#8DF0, IRGKangXi=1225.240, RSKangXi=157.6
8DF1 CJK UNIFIED IDEOGRAPH-#8DF1, IRGKangXi=1225.270, RSKangXi=157.6, Def{stop}
8DF2 CJK UNIFIED IDEOGRAPH-#8DF2, IRGKangXi=1225.300, RSKangXi=157.6, Def{hood, cowl, turban; stumble}
8DF3 CJK UNIFIED IDEOGRAPH-#8DF3, IRGKangXi=1226.010, RSKangXi=157.6, Def{jump, leap, vault, bounce; dance}
8DF4 CJK UNIFIED IDEOGRAPH-#8DF4, IRGKangXi=1226.091, RSKangXi=157.6, Def{step on, tread on; search for}
8DF5 CJK UNIFIED IDEOGRAPH-#8DF5, IRGKangXi=1224.131, RSKangXi=157.5, Def{trample, tread upon, walk on}
8DF6 CJK UNIFIED IDEOGRAPH-#8DF6, IRGKangXi=1227.091, RSKangXi=157.6, Def{stumble, slip}
8DF7 CJK UNIFIED IDEOGRAPH-#8DF7, IRGKangXi=1226.091, RSKangXi=157.6, Def{raise one's foot}
8DF8 CJK UNIFIED IDEOGRAPH-#8DF8, IRGKangXi=1226.091, RSKangXi=157.6, Def{clear way, make room for; emp}
8DF9 CJK UNIFIED IDEOGRAPH-#8DF9, IRGKangXi=1227.091, RSKangXi=157.6, Def{wander about, walk around; revolve}
8DFA CJK UNIFIED IDEOGRAPH-#8DFA, IRGKangXi=1226.091, RSKangXi=157.6, Def{stamp feet, step}
8DFB CJK UNIFIED IDEOGRAPH-#8DFB, IRGKangXi=1226.091, RSKangXi=157.6, Def{ascend, go up, rise}
8DFC CJK UNIFIED IDEOGRAPH-#8DFC, IRGKangXi=1226.100, RSKangXi=157.7, Def{bent, stooped, crouched; contract}
8DFD CJK UNIFIED IDEOGRAPH-#8DFD, IRGKangXi=1226.110, RSKangXi=157.7, Def{to kneel for a long time, to go down on hands and knees}
8DFE CJK UNIFIED IDEOGRAPH-#8DFE, IRGKangXi=1226.120, RSKangXi=157.7
8DFF CJK UNIFIED IDEOGRAPH-#8DFF, IRGKangXi=1226.140, RSKangXi=157.7
8E00 CJK UNIFIED IDEOGRAPH-#8E00, IRGKangXi=1226.160, RSKangXi=157.7
8E01 CJK UNIFIED IDEOGRAPH-#8E01, IRGKangXi=1226.200, RSKangXi=157.7, Def{tinkling, obstinate}
8E02 CJK UNIFIED IDEOGRAPH-#8E02, IRGKangXi=1226.250, RSKangXi=157.7
8E03 CJK UNIFIED IDEOGRAPH-#8E03, IRGKangXi=1226.260, RSKangXi=157.7
8E04 CJK UNIFIED IDEOGRAPH-#8E04, IRGKangXi=1226.300, RSKangXi=157.7
8E05 CJK UNIFIED IDEOGRAPH-#8E05, IRGKangXi=1226.320, RSKangXi=157.7, Def{to walk around; turn back midway}
8E06 CJK UNIFIED IDEOGRAPH-#8E06, IRGKangXi=1226.360, RSKangXi=157.7, Def{squat}
8E07 CJK UNIFIED IDEOGRAPH-#8E07, IRGKangXi=1226.400, RSKangXi=157.7
8E08 CJK UNIFIED IDEOGRAPH-#8E08, IRGKangXi=1226.410, RSKangXi=157.7, Def{neglect; careless, lax}
8E09 CJK UNIFIED IDEOGRAPH-#8E09, IRGKangXi=1227.010, RSKangXi=157.7, Def{hop, jump; hurriedly, urgently}
8E0A CJK UNIFIED IDEOGRAPH-#8E0A, IRGKangXi=1227.030, RSKangXi=157.7, Def{leap, jump}
8E0B CJK UNIFIED IDEOGRAPH-#8E0B, IRGKangXi=1227.091, RSKangXi=157.7, Def{the foot or feet cast of a play}
8E0C CJK UNIFIED IDEOGRAPH-#8E0C, IRGKangXi=1227.091, RSKangXi=157.7, Def{hesitate, falter; smug, self-satisfied}
8E0D CJK UNIFIED IDEOGRAPH-#8E0D, IRGKangXi=1227.091, RSKangXi=157.7
8E0E CJK UNIFIED IDEOGRAPH-#8E0E, IRGKangXi=1227.091, RSKangXi=157.7, Def{(Cant.) to squat}
8E0F CJK UNIFIED IDEOGRAPH-#8E0F, IRGKangXi=1227.110, RSKangXi=157.8, Def{step on, trample, tread on, walk}
8E10 CJK UNIFIED IDEOGRAPH-#8E10, IRGKangXi=1227.170, RSKangXi=157.8, Def{trample, tread upon, walk on}
8E11 CJK UNIFIED IDEOGRAPH-#8E11, IRGKangXi=1227.180, RSKangXi=157.8
8E12 CJK UNIFIED IDEOGRAPH-#8E12, IRGKangXi=1227.220, RSKangXi=157.8, Def{to slip and sprain a blimb}
8E13 CJK UNIFIED IDEOGRAPH-#8E13, IRGKangXi=1227.250, RSKangXi=157.8
8E14 CJK UNIFIED IDEOGRAPH-#8E14, IRGKangXi=1227.270, RSKangXi=157.8, Def{to get ahead; to stride; to excel}
8E15 CJK UNIFIED IDEOGRAPH-#8E15, IRGKangXi=1227.290, RSKangXi=157.8
8E16 CJK UNIFIED IDEOGRAPH-#8E16, IRGKangXi=1227.310, RSKangXi=157.8, Def{trample on, tread on}
8E17 CJK UNIFIED IDEOGRAPH-#8E17, IRGKangXi=1227.360, RSKangXi=157.8
8E18 CJK UNIFIED IDEOGRAPH-#8E18, IRGKangXi=1228.020, RSKangXi=157.8, Def{ball}
8E19 CJK UNIFIED IDEOGRAPH-#8E19, IRGKangXi=1228.060, RSKangXi=157.8
8E1A CJK UNIFIED IDEOGRAPH-#8E1A, IRGKangXi=1228.090, RSKangXi=157.8
8E1B CJK UNIFIED IDEOGRAPH-#8E1B, IRGKangXi=1228.110, RSKangXi=157.8
8E1C CJK UNIFIED IDEOGRAPH-#8E1C, IRGKangXi=1228.120, RSKangXi=157.8, Def{to stumble; to slip; to fall}
8E1D CJK UNIFIED IDEOGRAPH-#8E1D, IRGKangXi=1228.160, RSKangXi=157.8, Def{ankle}
8E1E CJK UNIFIED IDEOGRAPH-#8E1E, IRGKangXi=1228.170, RSKangXi=157.8, Def{crouch, squat; sit, occupy}
8E1F CJK UNIFIED IDEOGRAPH-#8E1F, IRGKangXi=1228.200, RSKangXi=157.8, Def{hesitate, undecided; embarrassed}
8E20 CJK UNIFIED IDEOGRAPH-#8E20, IRGKangXi=1228.210, RSKangXi=157.8, Def{to writhe, struggle, squirm, wriggle; to be impatient for}
8E21 CJK UNIFIED IDEOGRAPH-#8E21, IRGKangXi=1228.220, RSKangXi=157.8, Def{curled, coiled}
8E22 CJK UNIFIED IDEOGRAPH-#8E22, IRGKangXi=1228.230, RSKangXi=157.8, Def{kick}
8E23 CJK UNIFIED IDEOGRAPH-#8E23, IRGKangXi=1228.240, RSKangXi=157.8, Def{to stumble and fall prone stiff in death}
8E24 CJK UNIFIED IDEOGRAPH-#8E24, IRGKangXi=1228.250, RSKangXi=157.8
8E25 CJK UNIFIED IDEOGRAPH-#8E25, IRGKangXi=1228.290, RSKangXi=157.8
8E26 CJK UNIFIED IDEOGRAPH-#8E26, IRGKangXi=1228.300, RSKangXi=157.8, Def{the shin; to pierce; to touch}
8E27 CJK UNIFIED IDEOGRAPH-#8E27, IRGKangXi=1229.010, RSKangXi=157.8, Def{uneasiness, nervousness; level}
8E28 CJK UNIFIED IDEOGRAPH-#8E28, IRGKangXi=1229.020, RSKangXi=157.8
8E29 CJK UNIFIED IDEOGRAPH-#8E29, IRGKangXi=1229.060, RSKangXi=157.8, Def{step on}
8E2A CJK UNIFIED IDEOGRAPH-#8E2A, IRGKangXi=1229.071, RSKangXi=157.8, Def{footprints, traces, tracks}
8E2B CJK UNIFIED IDEOGRAPH-#8E2B, IRGKangXi=1229.091, RSKangXi=157.9, Def{collide, bump into}
8E2C CJK UNIFIED IDEOGRAPH-#8E2C, IRGKangXi=1229.071, RSKangXi=157.8, Def{stumble, totter; fail, be frustrated}
8E2D CJK UNIFIED IDEOGRAPH-#8E2D, IRGKangXi=1226.091, RSKangXi=157.8, Def{(Cant.) heel, elbow}
8E2E CJK UNIFIED IDEOGRAPH-#8E2E, IRGKangXi=1229.071, RSKangXi=157.8, Def{tip toe}
8E2F CJK UNIFIED IDEOGRAPH-#8E2F, IRGKangXi=1230.291, RSKangXi=157.8, Def{waver, hesitate, be irresolute}
8E30 CJK UNIFIED IDEOGRAPH-#8E30, IRGKangXi=1229.110, RSKangXi=157.9, Def{exceed, transgress; cross over}
8E31 CJK UNIFIED IDEOGRAPH-#8E31, IRGKangXi=1229.120, RSKangXi=157.9, Def{stroll, pace, walk slowly}
8E32 CJK UNIFIED IDEOGRAPH-#8E32, IRGKangXi=1229.170, RSKangXi=157.9
8E33 CJK UNIFIED IDEOGRAPH-#8E33, IRGKangXi=1229.190, RSKangXi=157.9
8E34 CJK UNIFIED IDEOGRAPH-#8E34, IRGKangXi=1229.200, RSKangXi=157.9, Def{leap, jump}
8E35 CJK UNIFIED IDEOGRAPH-#8E35, IRGKangXi=1229.220, RSKangXi=157.9, Def{heel; follow; visit, call on}
8E36 CJK UNIFIED IDEOGRAPH-#8E36, IRGKangXi=1229.250, RSKangXi=157.9, Def{paw}
8E37 CJK UNIFIED IDEOGRAPH-#8E37, IRGKangXi=1229.280, RSKangXi=157.9
8E38 CJK UNIFIED IDEOGRAPH-#8E38, IRGKangXi=1229.300, RSKangXi=157.9
8E39 CJK UNIFIED IDEOGRAPH-#8E39, IRGKangXi=1229.310, RSKangXi=157.9, Def{trample, tread on, kick; to crush}
8E3A CJK UNIFIED IDEOGRAPH-#8E3A, IRGKangXi=1229.340, RSKangXi=157.8
8E3B CJK UNIFIED IDEOGRAPH-#8E3B, IRGKangXi=1229.350, RSKangXi=157.9
8E3C CJK UNIFIED IDEOGRAPH-#8E3C, IRGKangXi=1229.370, RSKangXi=157.9, Def{to fall flat; to fall on the face}
8E3D CJK UNIFIED IDEOGRAPH-#8E3D, IRGKangXi=1230.120, RSKangXi=157.9, Def{to walk alone; self-reliant}
8E3E CJK UNIFIED IDEOGRAPH-#8E3E, IRGKangXi=1230.130, RSKangXi=157.9
8E3F CJK UNIFIED IDEOGRAPH-#8E3F, IRGKangXi=1230.140, RSKangXi=157.9
8E40 CJK UNIFIED IDEOGRAPH-#8E40, IRGKangXi=1230.150, RSKangXi=157.9, Def{to skip, to dance; to put the foot down}
8E41 CJK UNIFIED IDEOGRAPH-#8E41, IRGKangXi=1230.160, RSKangXi=157.9, Def{to walk with a limp}
8E42 CJK UNIFIED IDEOGRAPH-#8E42, IRGKangXi=1230.170, RSKangXi=157.9, Def{trample under foot, tread on}
8E43 CJK UNIFIED IDEOGRAPH-#8E43, IRGKangXi=1230.180, RSKangXi=157.9
8E44 CJK UNIFIED IDEOGRAPH-#8E44, IRGKangXi=1230.230, RSKangXi=157.9, Def{hoof; leg of pork; little witch}
8E45 CJK UNIFIED IDEOGRAPH-#8E45, IRGKangXi=1230.291, RSKangXi=157.9, Def{to tread on, walk through}
8E46 CJK UNIFIED IDEOGRAPH-#8E46, IRGKangXi=1230.360, RSKangXi=157.10, Def{(Cant.) to move in a straight line}
8E47 CJK UNIFIED IDEOGRAPH-#8E47, IRGKangXi=1230.400, RSKangXi=157.10, Def{lame, crippled; unlucky}
8E48 CJK UNIFIED IDEOGRAPH-#8E48, IRGKangXi=1231.030, RSKangXi=157.10, Def{stamp feet; dance}
8E49 CJK UNIFIED IDEOGRAPH-#8E49, IRGKangXi=1231.050, RSKangXi=157.10, Def{error, mistake, slip; failure}
8E4A CJK UNIFIED IDEOGRAPH-#8E4A, IRGKangXi=1231.070, RSKangXi=157.10, Def{footpath, trail; track}
8E4B CJK UNIFIED IDEOGRAPH-#8E4B, IRGKangXi=1231.110, RSKangXi=157.10, Def{step on, tread on; stumble, slip}
8E4C CJK UNIFIED IDEOGRAPH-#8E4C, IRGKangXi=1231.160, RSKangXi=157.10, Def{walk rapidly}
8E4D CJK UNIFIED IDEOGRAPH-#8E4D, IRGKangXi=1231.170, RSKangXi=157.10, Def{upper millstone; to grind, roll, triturate}
8E4E CJK UNIFIED IDEOGRAPH-#8E4E, IRGKangXi=1231.200, RSKangXi=157.10
8E4F CJK UNIFIED IDEOGRAPH-#8E4F, IRGKangXi=1231.230, RSKangXi=157.10, Def{hoof; leg of pork; little witch a horse}
8E50 CJK UNIFIED IDEOGRAPH-#8E50, IRGKangXi=1231.260, RSKangXi=157.10, Def{take short steps}
8E51 CJK UNIFIED IDEOGRAPH-#8E51, IRGKangXi=1231.301, RSKangXi=157.10, Def{tread, step on; follow, track}
8E52 CJK UNIFIED IDEOGRAPH-#8E52, IRGKangXi=1232.441, RSKangXi=157.10, Def{to jump over; to limp}
8E53 CJK UNIFIED IDEOGRAPH-#8E53, IRGKangXi=1231.301, RSKangXi=157.10, Def{stroll, take walk}
8E54 CJK UNIFIED IDEOGRAPH-#8E54, IRGKangXi=1231.330, RSKangXi=157.11, Def{temporary; fleeting; ephemeral}
8E55 CJK UNIFIED IDEOGRAPH-#8E55, IRGKangXi=1231.340, RSKangXi=157.11, Def{clear way, make room for; emp}
8E56 CJK UNIFIED IDEOGRAPH-#8E56, IRGKangXi=1231.350, RSKangXi=157.11
8E57 CJK UNIFIED IDEOGRAPH-#8E57, IRGKangXi=1232.030, RSKangXi=157.11
8E58 CJK UNIFIED IDEOGRAPH-#8E58, IRGKangXi=1232.050, RSKangXi=157.11, Def{(Cant.) to roost}
8E59 CJK UNIFIED IDEOGRAPH-#8E59, IRGKangXi=1232.060, RSKangXi=157.11, Def{urgent, suddenly; grieve, lament}
8E5A CJK UNIFIED IDEOGRAPH-#8E5A, IRGKangXi=1232.200, RSKangXi=157.11, Def{tread through mud and water}
8E5B CJK UNIFIED IDEOGRAPH-#8E5B, IRGKangXi=1232.220, RSKangXi=157.11
8E5C CJK UNIFIED IDEOGRAPH-#8E5C, IRGKangXi=1232.250, RSKangXi=157.11, Def{walk carefully}
8E5D CJK UNIFIED IDEOGRAPH-#8E5D, IRGKangXi=1232.260, RSKangXi=157.11, Def{sandal}
8E5E CJK UNIFIED IDEOGRAPH-#8E5E, IRGKangXi=1232.270, RSKangXi=157.11
8E5F CJK UNIFIED IDEOGRAPH-#8E5F, IRGKangXi=1232.280, RSKangXi=157.11, Def{trace, tracks; footprints}
8E60 CJK UNIFIED IDEOGRAPH-#8E60, IRGKangXi=1232.290, RSKangXi=157.11, Def{step on, tread on; sole}
8E61 CJK UNIFIED IDEOGRAPH-#8E61, IRGKangXi=1232.320, RSKangXi=157.11, Def{to limp; walking; in motion}
8E62 CJK UNIFIED IDEOGRAPH-#8E62, IRGKangXi=1232.350, RSKangXi=157.11, Def{hoof; a falter; to hesitate}
8E63 CJK UNIFIED IDEOGRAPH-#8E63, IRGKangXi=1232.370, RSKangXi=157.11, Def{to jump over; to limp}
8E64 CJK UNIFIED IDEOGRAPH-#8E64, IRGKangXi=1232.380, RSKangXi=157.11, Def{footprints, traces, tracks}
8E65 CJK UNIFIED IDEOGRAPH-#8E65, IRGKangXi=1232.390, RSKangXi=157.11
8E66 CJK UNIFIED IDEOGRAPH-#8E66, IRGKangXi=1232.441, RSKangXi=157.11, Def{hop, leap, jump; bright}
8E67 CJK UNIFIED IDEOGRAPH-#8E67, IRGKangXi=1232.441, RSKangXi=157.11, Def{to spoil; to ruin}
8E68 CJK UNIFIED IDEOGRAPH-#8E68, IRGKangXi=1232.450, RSKangXi=157.12, Def{(Cant.) to stand on tiptoe}
8E69 CJK UNIFIED IDEOGRAPH-#8E69, IRGKangXi=1233.040, RSKangXi=157.12, Def{to limp}
8E6A CJK UNIFIED IDEOGRAPH-#8E6A, IRGKangXi=1233.060, RSKangXi=157.12
8E6B CJK UNIFIED IDEOGRAPH-#8E6B, IRGKangXi=1233.100, RSKangXi=157.12
8E6C CJK UNIFIED IDEOGRAPH-#8E6C, IRGKangXi=1233.120, RSKangXi=157.12, Def{step on, tread on; lose energy}
8E6D CJK UNIFIED IDEOGRAPH-#8E6D, IRGKangXi=1233.210, RSKangXi=157.12, Def{to shuffle, procrastinate, dilly-dally}
8E6E CJK UNIFIED IDEOGRAPH-#8E6E, IRGKangXi=1233.220, RSKangXi=157.11, Def{to whirl, pirouette}
8E6F CJK UNIFIED IDEOGRAPH-#8E6F, IRGKangXi=1233.230, RSKangXi=157.12, Def{an animal's paws}
8E70 CJK UNIFIED IDEOGRAPH-#8E70, IRGKangXi=1233.260, RSKangXi=157.12, Def{hesitate, waver, falter}
8E71 CJK UNIFIED IDEOGRAPH-#8E71, IRGKangXi=1233.290, RSKangXi=157.12, Def{to stagger along; to fall}
8E72 CJK UNIFIED IDEOGRAPH-#8E72, IRGKangXi=1233.320, RSKangXi=157.12, Def{squat, crouch; idle about}
8E73 CJK UNIFIED IDEOGRAPH-#8E73, IRGKangXi=1233.340, RSKangXi=157.12
8E74 CJK UNIFIED IDEOGRAPH-#8E74, IRGKangXi=1233.360, RSKangXi=157.12, Def{kick; tread on; leap; solemn}
8E75 CJK UNIFIED IDEOGRAPH-#8E75, IRGKangXi=1233.370, RSKangXi=157.12, Def{to tread on; to kick}
8E76 CJK UNIFIED IDEOGRAPH-#8E76, IRGKangXi=1233.410, RSKangXi=157.12, Def{stumble, fall down; trample}
8E77 CJK UNIFIED IDEOGRAPH-#8E77, IRGKangXi=1234.010, Def{to kick back; to stumble, slip, fall}
8E78 CJK UNIFIED IDEOGRAPH-#8E78, IRGKangXi=1234.020, RSKangXi=157.12
8E79 CJK UNIFIED IDEOGRAPH-#8E79, IRGKangXi=1234.040, RSKangXi=157.12, Def{to tread on; to stamp; to walk}
8E7A CJK UNIFIED IDEOGRAPH-#8E7A, IRGKangXi=1234.060, RSKangXi=157.12, Def{raise one's foot}
8E7B CJK UNIFIED IDEOGRAPH-#8E7B, IRGKangXi=1234.070, RSKangXi=157.12, Def{to raise the feet; to cross the legs; brave; sandals}
8E7C CJK UNIFIED IDEOGRAPH-#8E7C, IRGKangXi=1234.090, RSKangXi=157.12, Def{webbed feet of waterfowl}
8E7D CJK UNIFIED IDEOGRAPH-#8E7D, IRGKangXi=1234.201, RSKangXi=157.12
8E7E CJK UNIFIED IDEOGRAPH-#8E7E, IRGKangXi=1234.201, RSKangXi=157.12, Def{to squat; to crouch}
8E7F CJK UNIFIED IDEOGRAPH-#8E7F, IRGKangXi=1234.201, RSKangXi=157.12, Def{leap; to jump; to spurt out}
8E80 CJK UNIFIED IDEOGRAPH-#8E80, IRGKangXi=1232.441, RSKangXi=157.11, Def{(Cant.) to stumble over, to fall}
8E81 CJK UNIFIED IDEOGRAPH-#8E81, IRGKangXi=1234.210, RSKangXi=157.13, Def{tense, excited, irritable}
8E82 CJK UNIFIED IDEOGRAPH-#8E82, IRGKangXi=1234.250, RSKangXi=157.13, Def{stumble, slip}
8E83 CJK UNIFIED IDEOGRAPH-#8E83, IRGKangXi=1234.270, RSKangXi=157.13
8E84 CJK UNIFIED IDEOGRAPH-#8E84, IRGKangXi=1234.280, RSKangXi=157.13, Def{cripple, lame}
8E85 CJK UNIFIED IDEOGRAPH-#8E85, IRGKangXi=1234.320, RSKangXi=157.13, Def{walk carefully; hesitate, falter}
8E86 CJK UNIFIED IDEOGRAPH-#8E86, IRGKangXi=1234.360, RSKangXi=157.13
8E87 CJK UNIFIED IDEOGRAPH-#8E87, IRGKangXi=1234.410, RSKangXi=157.13, Def{hesitate, falter, be undecided}
8E88 CJK UNIFIED IDEOGRAPH-#8E88, IRGKangXi=1235.030, RSKangXi=157.13
8E89 CJK UNIFIED IDEOGRAPH-#8E89, IRGKangXi=1235.060, RSKangXi=157.13, Def{sell or buy wholesale; store}
8E8A CJK UNIFIED IDEOGRAPH-#8E8A, IRGKangXi=1235.090, RSKangXi=157.14, Def{hesitate, falter; smug, self-satisfied}
8E8B CJK UNIFIED IDEOGRAPH-#8E8B, IRGKangXi=1235.170, RSKangXi=157.14, Def{ascend, go up, rise}
8E8C CJK UNIFIED IDEOGRAPH-#8E8C, IRGKangXi=1235.230, RSKangXi=157.14
8E8D CJK UNIFIED IDEOGRAPH-#8E8D, IRGKangXi=1235.260, RSKangXi=157.14, Def{skip, jump, frolic}
8E8E CJK UNIFIED IDEOGRAPH-#8E8E, IRGKangXi=1235.290, RSKangXi=157.14
8E8F CJK UNIFIED IDEOGRAPH-#8E8F, IRGKangXi=1235.461, RSKangXi=157.14, Def{trample down, oppress, overrun}
8E90 CJK UNIFIED IDEOGRAPH-#8E90, IRGKangXi=1235.330, RSKangXi=157.15, Def{to stride over; to step across}
8E91 CJK UNIFIED IDEOGRAPH-#8E91, IRGKangXi=1235.340, RSKangXi=157.15, Def{waver, hesitate, be irresolute}
8E92 CJK UNIFIED IDEOGRAPH-#8E92, IRGKangXi=1235.360, RSKangXi=157.15, Def{walk, move}
8E93 CJK UNIFIED IDEOGRAPH-#8E93, IRGKangXi=1235.380, RSKangXi=157.15, Def{stumble, totter; fail, be frustrated}
8E94 CJK UNIFIED IDEOGRAPH-#8E94, IRGKangXi=1235.410, RSKangXi=157.15, Def{follow in, imitate; rut, path}
8E95 CJK UNIFIED IDEOGRAPH-#8E95, IRGKangXi=1235.430, RSKangXi=157.15, Def{hesitate, waver, falter}
8E96 CJK UNIFIED IDEOGRAPH-#8E96, IRGKangXi=1235.440, RSKangXi=157.15
8E97 CJK UNIFIED IDEOGRAPH-#8E97, IRGKangXi=1235.461, RSKangXi=157.16, Def{exaggerate}
8E98 CJK UNIFIED IDEOGRAPH-#8E98, IRGKangXi=1236.010, RSKangXi=157.16, Def{to walk}
8E99 CJK UNIFIED IDEOGRAPH-#8E99, IRGKangXi=1236.020, RSKangXi=157.16, Def{trample down, oppress, overrun}
8E9A CJK UNIFIED IDEOGRAPH-#8E9A, IRGKangXi=1236.040, RSKangXi=157.16, Def{wander about, walk around; revolve}
8E9B CJK UNIFIED IDEOGRAPH-#8E9B, IRGKangXi=1236.060, RSKangXi=157.16, Def{exaggerate}
8E9C CJK UNIFIED IDEOGRAPH-#8E9C, IRGKangXi=1236.111, RSKangXi=157.16, Def{to jump}
8E9D CJK UNIFIED IDEOGRAPH-#8E9D, IRGKangXi=1236.120, RSKangXi=157.17, Def{to pass; to step over; to creep; to twine round}
8E9E CJK UNIFIED IDEOGRAPH-#8E9E, IRGKangXi=1236.160, RSKangXi=157.17, Def{to walk}
8E9F CJK UNIFIED IDEOGRAPH-#8E9F, IRGKangXi=1236.180, RSKangXi=157.17
8EA0 CJK UNIFIED IDEOGRAPH-#8EA0, IRGKangXi=1236.200, RSKangXi=157.17, Def{to limp}
8EA1 CJK UNIFIED IDEOGRAPH-#8EA1, IRGKangXi=1236.270, RSKangXi=157.18, Def{tread, step on; follow, track}
8EA2 CJK UNIFIED IDEOGRAPH-#8EA2, IRGKangXi=1236.300, RSKangXi=157.18
8EA3 CJK UNIFIED IDEOGRAPH-#8EA3, IRGKangXi=1236.320, RSKangXi=157.18
8EA4 CJK UNIFIED IDEOGRAPH-#8EA4, IRGKangXi=1236.330, RSKangXi=157.18
8EA5 CJK UNIFIED IDEOGRAPH-#8EA5, IRGKangXi=1236.351, RSKangXi=157.18, Def{leap; to jump; to spurt out}
8EA6 CJK UNIFIED IDEOGRAPH-#8EA6, IRGKangXi=1236.390, RSKangXi=157.19, Def{to jump}
8EA7 CJK UNIFIED IDEOGRAPH-#8EA7, IRGKangXi=1236.400, RSKangXi=157.19, Def{sandal}
8EA8 CJK UNIFIED IDEOGRAPH-#8EA8, IRGKangXi=1236.410, RSKangXi=157.22
8EA9 CJK UNIFIED IDEOGRAPH-#8EA9, IRGKangXi=1236.420, RSKangXi=157.20, Def{take quick, short steps}
8EAA CJK UNIFIED IDEOGRAPH-#8EAA, IRGKangXi=1236.430, RSKangXi=157.20, Def{trample down, oppress, overrun}
8EAB CJK UNIFIED IDEOGRAPH-#8EAB, IRGKangXi=1237.010, RSKangXi=158.0, Def{body; trunk, hull; rad. no. 158}
8EAC CJK UNIFIED IDEOGRAPH-#8EAC, IRGKangXi=1237.040, RSKangXi=158.3, Def{body; personally, in person}
8EAD CJK UNIFIED IDEOGRAPH-#8EAD, IRGKangXi=1237.130, RSKangXi=158.4, Def{to delay; to loiter; to hinder}
8EAE CJK UNIFIED IDEOGRAPH-#8EAE, IRGKangXi=1237.191, RSKangXi=158.4
8EAF CJK UNIFIED IDEOGRAPH-#8EAF, IRGKangXi=1237.191, RSKangXi=158.4, Def{body}
8EB0 CJK UNIFIED IDEOGRAPH-#8EB0, IRGKangXi=1237.230, RSKangXi=158.5, Def{body; group, class, body, unit}
8EB1 CJK UNIFIED IDEOGRAPH-#8EB1, IRGKangXi=1237.370, RSKangXi=158.6, Def{hide}
8EB2 CJK UNIFIED IDEOGRAPH-#8EB2, IRGKangXi=1237.380, RSKangXi=158.6, Def{hide, secrete; avoid, escape}
8EB3 CJK UNIFIED IDEOGRAPH-#8EB3, IRGKangXi=1237.430, RSKangXi=158.7, Def{body; self}
8EB4 CJK UNIFIED IDEOGRAPH-#8EB4, IRGKangXi=1237.440, RSKangXi=158.7, Def{tall}
8EB5 CJK UNIFIED IDEOGRAPH-#8EB5, IRGKangXi=1237.491, RSKangXi=158.7
8EB6 CJK UNIFIED IDEOGRAPH-#8EB6, IRGKangXi=1237.510, RSKangXi=158.8, Def{bare, nude; undress, strip}
8EB7 CJK UNIFIED IDEOGRAPH-#8EB7, IRGKangXi=1237.530, RSKangXi=158.8, Def{of short stature, low in height}
8EB8 CJK UNIFIED IDEOGRAPH-#8EB8, IRGKangXi=1237.540, RSKangXi=158.8
8EB9 CJK UNIFIED IDEOGRAPH-#8EB9, IRGKangXi=1237.550, RSKangXi=158.8
8EBA CJK UNIFIED IDEOGRAPH-#8EBA, IRGKangXi=1237.581, RSKangXi=158.8, Def{lie down, recline}
8EBB CJK UNIFIED IDEOGRAPH-#8EBB, IRGKangXi=1237.581, RSKangXi=158.8
8EBC CJK UNIFIED IDEOGRAPH-#8EBC, IRGKangXi=1237.581, RSKangXi=158.8
8EBD CJK UNIFIED IDEOGRAPH-#8EBD, IRGKangXi=1237.600, RSKangXi=158.9, Def{(Cant.) 躽胸凸肚, to push out one's chest and belly}
8EBE CJK UNIFIED IDEOGRAPH-#8EBE, IRGKangXi=1237.651, RSKangXi=158.9, Def{to discipline, train, bring up; discipline, training}
8EBF CJK UNIFIED IDEOGRAPH-#8EBF, IRGKangXi=1238.040, RSKangXi=158.10, Def{tall}
8EC0 CJK UNIFIED IDEOGRAPH-#8EC0, IRGKangXi=1238.050, RSKangXi=158.11, Def{body}
8EC1 CJK UNIFIED IDEOGRAPH-#8EC1, IRGKangXi=1238.060, RSKangXi=158.11
8EC2 CJK UNIFIED IDEOGRAPH-#8EC2, IRGKangXi=1238.090, RSKangXi=158.12
8EC3 CJK UNIFIED IDEOGRAPH-#8EC3, IRGKangXi=1238.110, RSKangXi=158.12
8EC4 CJK UNIFIED IDEOGRAPH-#8EC4, IRGKangXi=1238.120, RSKangXi=158.12, Def{to govern, to oversee, to manage, to direct official duty, office}
8EC5 CJK UNIFIED IDEOGRAPH-#8EC5, IRGKangXi=1238.141, RSKangXi=158.12
8EC6 CJK UNIFIED IDEOGRAPH-#8EC6, IRGKangXi=1238.150, RSKangXi=158.13, Def{body; group, class, body, unit}
8EC7 CJK UNIFIED IDEOGRAPH-#8EC7, IRGKangXi=1238.200, RSKangXi=158.14
8EC8 CJK UNIFIED IDEOGRAPH-#8EC8, IRGKangXi=1238.271, RSKangXi=158.17, Def{soon after, soon; almost; no more than; after all}
8EC9 CJK UNIFIED IDEOGRAPH-#8EC9, IRGKangXi=1238.290, RSKangXi=158.20
8ECA CJK UNIFIED IDEOGRAPH-#8ECA, IRGKangXi=1239.010, RSKangXi=159.0, Def{cart, vehicle; carry in cart}
8ECB CJK UNIFIED IDEOGRAPH-#8ECB, IRGKangXi=1239.030, RSKangXi=159.1, Def{crush by weight; grind}
8ECC CJK UNIFIED IDEOGRAPH-#8ECC, IRGKangXi=1239.060, RSKangXi=159.2, Def{track, rut, path}
8ECD CJK UNIFIED IDEOGRAPH-#8ECD, IRGKangXi=1239.110, RSKangXi=159.2, Def{army, military; soldiers, troops}
8ECE CJK UNIFIED IDEOGRAPH-#8ECE, IRGKangXi=1239.140, RSKangXi=159.3, Def{a brass parts for a cart in ancient China}
8ECF CJK UNIFIED IDEOGRAPH-#8ECF, IRGKangXi=1239.150, RSKangXi=159.3, Def{cross-bar at the end of the poles of a cart}
8ED0 CJK UNIFIED IDEOGRAPH-#8ED0, IRGKangXi=1239.160, RSKangXi=159.3
8ED1 CJK UNIFIED IDEOGRAPH-#8ED1, IRGKangXi=1240.020, RSKangXi=159.3
8ED2 CJK UNIFIED IDEOGRAPH-#8ED2, IRGKangXi=1240.030, RSKangXi=159.3, Def{carriage; high; wide; balcony; surname of the Yellow Emperor}
8ED3 CJK UNIFIED IDEOGRAPH-#8ED3, IRGKangXi=1240.050, RSKangXi=159.3
8ED4 CJK UNIFIED IDEOGRAPH-#8ED4, IRGKangXi=1240.060, RSKangXi=159.3, Def{a block that keeps a wheel from moving}
8ED5 CJK UNIFIED IDEOGRAPH-#8ED5, IRGKangXi=1240.061, RSKangXi=159.3
8ED6 CJK UNIFIED IDEOGRAPH-#8ED6, IRGKangXi=1240.080, RSKangXi=159.4
8ED7 CJK UNIFIED IDEOGRAPH-#8ED7, IRGKangXi=1240.100, RSKangXi=159.4
8ED8 CJK UNIFIED IDEOGRAPH-#8ED8, IRGKangXi=1240.110, RSKangXi=159.4, Def{war car}
8ED9 CJK UNIFIED IDEOGRAPH-#8ED9, IRGKangXi=1240.120, RSKangXi=159.4, Def{a Chinese family name to arrange; to display wheel}
8EDA CJK UNIFIED IDEOGRAPH-#8EDA, IRGKangXi=1240.140, RSKangXi=159.4, Def{(Cant.) a steering wheel}
8EDB CJK UNIFIED IDEOGRAPH-#8EDB, IRGKangXi=1240.200, RSKangXi=159.4, Def{yoke, collar; to restrain}
8EDC CJK UNIFIED IDEOGRAPH-#8EDC, IRGKangXi=1240.220, RSKangXi=159.4, Def{reins}
8EDD CJK UNIFIED IDEOGRAPH-#8EDD, IRGKangXi=1240.230, RSKangXi=159.4, Def{axle-tip}
8EDE CJK UNIFIED IDEOGRAPH-#8EDE, IRGKangXi=1240.250, RSKangXi=159.4
8EDF CJK UNIFIED IDEOGRAPH-#8EDF, IRGKangXi=1240.260, RSKangXi=159.4, Def{soft, flexible, pliable; weak}
8EE0 CJK UNIFIED IDEOGRAPH-#8EE0, IRGKangXi=1241.010, RSKangXi=159.4
8EE1 CJK UNIFIED IDEOGRAPH-#8EE1, IRGKangXi=1241.020, RSKangXi=159.4
8EE2 CJK UNIFIED IDEOGRAPH-#8EE2, IRGKangXi=1241.111, RSKangXi=159.4, Def{shift, move, turn}
8EE3 CJK UNIFIED IDEOGRAPH-#8EE3, IRGKangXi=1241.111, RSKangXi=159.4, Def{rumble, explosion, blast}
8EE4 CJK UNIFIED IDEOGRAPH-#8EE4, IRGKangXi=1241.120, RSKangXi=159.5, Def{surname}
8EE5 CJK UNIFIED IDEOGRAPH-#8EE5, IRGKangXi=1241.130, RSKangXi=159.5, Def{yoke}
8EE6 CJK UNIFIED IDEOGRAPH-#8EE6, IRGKangXi=1241.140, RSKangXi=159.5
8EE7 CJK UNIFIED IDEOGRAPH-#8EE7, IRGKangXi=1241.150, RSKangXi=159.5
8EE8 CJK UNIFIED IDEOGRAPH-#8EE8, IRGKangXi=1241.160, RSKangXi=159.5, Def{wooden cross-piece on front inside of carriage box}
8EE9 CJK UNIFIED IDEOGRAPH-#8EE9, IRGKangXi=1241.180, RSKangXi=159.5
8EEA CJK UNIFIED IDEOGRAPH-#8EEA, IRGKangXi=1241.190, RSKangXi=159.5
8EEB CJK UNIFIED IDEOGRAPH-#8EEB, IRGKangXi=1241.200, RSKangXi=159.5, Def{cross board at rear of carriage}
8EEC CJK UNIFIED IDEOGRAPH-#8EEC, IRGKangXi=1241.230, RSKangXi=159.5
8EED CJK UNIFIED IDEOGRAPH-#8EED, IRGKangXi=1241.240, RSKangXi=159.6, Def{(Cant.) to spoil, ruin}
8EEE CJK UNIFIED IDEOGRAPH-#8EEE, IRGKangXi=1241.260, RSKangXi=159.5
8EEF CJK UNIFIED IDEOGRAPH-#8EEF, IRGKangXi=1241.270, RSKangXi=159.5
8EF0 CJK UNIFIED IDEOGRAPH-#8EF0, IRGKangXi=1241.280, RSKangXi=159.5, Def{a row of carriages; a generation; a class, a series a kind; denotes the plural}
8EF1 CJK UNIFIED IDEOGRAPH-#8EF1, IRGKangXi=1241.310, RSKangXi=159.5
8EF2 CJK UNIFIED IDEOGRAPH-#8EF2, IRGKangXi=1241.320, RSKangXi=159.5, Def{a wheel; to revolve}
8EF3 CJK UNIFIED IDEOGRAPH-#8EF3, IRGKangXi=1241.330, RSKangXi=159.5
8EF4 CJK UNIFIED IDEOGRAPH-#8EF4, IRGKangXi=1241.350, RSKangXi=159.5
8EF5 CJK UNIFIED IDEOGRAPH-#8EF5, IRGKangXi=1242.050, RSKangXi=159.5
8EF6 CJK UNIFIED IDEOGRAPH-#8EF6, IRGKangXi=1242.080, RSKangXi=159.5
8EF7 CJK UNIFIED IDEOGRAPH-#8EF7, IRGKangXi=1242.100, RSKangXi=159.5, Def{sacrifice}
8EF8 CJK UNIFIED IDEOGRAPH-#8EF8, IRGKangXi=1242.130, RSKangXi=159.5, Def{axle, axletree; pivot; axis}
8EF9 CJK UNIFIED IDEOGRAPH-#8EF9, IRGKangXi=1242.150, RSKangXi=159.5, Def{end of axle; divergent}
8EFA CJK UNIFIED IDEOGRAPH-#8EFA, IRGKangXi=1242.160, RSKangXi=159.5, Def{small light carriage}
8EFB CJK UNIFIED IDEOGRAPH-#8EFB, IRGKangXi=1242.180, RSKangXi=159.5, Def{axle; personal name of mencius}
8EFC CJK UNIFIED IDEOGRAPH-#8EFC, IRGKangXi=1242.190, RSKangXi=159.5, Def{rush forth; surpass, excel}
8EFD CJK UNIFIED IDEOGRAPH-#8EFD, IRGKangXi=1242.191, RSKangXi=159.5, Def{light; easy, simple; gentle}
8EFE CJK UNIFIED IDEOGRAPH-#8EFE, IRGKangXi=1242.200, RSKangXi=159.6, Def{horizontal wooden bar in front of a sedan chair}
8EFF CJK UNIFIED IDEOGRAPH-#8EFF, IRGKangXi=1242.210, RSKangXi=159.6, Def{curtained carriage used by women}
8F00 CJK UNIFIED IDEOGRAPH-#8F00, IRGKangXi=1242.220, RSKangXi=159.6, Def{hearse}
8F01 CJK UNIFIED IDEOGRAPH-#8F01, IRGKangXi=1242.230, RSKangXi=159.6
8F02 CJK UNIFIED IDEOGRAPH-#8F02, IRGKangXi=1242.240, RSKangXi=159.6
8F03 CJK UNIFIED IDEOGRAPH-#8F03, IRGKangXi=1242.310, RSKangXi=159.6, Def{compare; comparatively, more}
8F04 CJK UNIFIED IDEOGRAPH-#8F04, IRGKangXi=1243.030, RSKangXi=159.6
8F05 CJK UNIFIED IDEOGRAPH-#8F05, IRGKangXi=1243.050, RSKangXi=159.6, Def{a chariot, carriage; a carriage pull-bar}
8F06 CJK UNIFIED IDEOGRAPH-#8F06, IRGKangXi=1243.060, RSKangXi=159.6
8F07 CJK UNIFIED IDEOGRAPH-#8F07, IRGKangXi=1243.070, RSKangXi=159.6, Def{cart wheel with no spokes}
8F08 CJK UNIFIED IDEOGRAPH-#8F08, IRGKangXi=1243.110, RSKangXi=159.6, Def{shaft}
8F09 CJK UNIFIED IDEOGRAPH-#8F09, IRGKangXi=1243.120, RSKangXi=159.6, Def{load; carry; transport, convey}
8F0A CJK UNIFIED IDEOGRAPH-#8F0A, IRGKangXi=1243.150, RSKangXi=159.6, Def{low rear portion of cart}
8F0B CJK UNIFIED IDEOGRAPH-#8F0B, IRGKangXi=1243.151, RSKangXi=159.6, Def{沙田禾輋, Hong Kong toponym}
8F0C CJK UNIFIED IDEOGRAPH-#8F0C, IRGKangXi=1243.151, RSKangXi=159.6, Def{numerary adjunct for vehicles}
8F0D CJK UNIFIED IDEOGRAPH-#8F0D, IRGKangXi=1243.200, RSKangXi=159.7
8F0E CJK UNIFIED IDEOGRAPH-#8F0E, IRGKangXi=1243.220, RSKangXi=159.7
8F0F CJK UNIFIED IDEOGRAPH-#8F0F, IRGKangXi=1243.240, RSKangXi=159.7, Def{light; light carriage}
8F10 CJK UNIFIED IDEOGRAPH-#8F10, IRGKangXi=1243.280, RSKangXi=159.7
8F11 CJK UNIFIED IDEOGRAPH-#8F11, IRGKangXi=1243.290, RSKangXi=159.7
8F12 CJK UNIFIED IDEOGRAPH-#8F12, IRGKangXi=1243.300, RSKangXi=159.7, Def{sides of chariot where weapons}
8F13 CJK UNIFIED IDEOGRAPH-#8F13, IRGKangXi=1243.310, RSKangXi=159.7, Def{mourn; pull; draw}
8F14 CJK UNIFIED IDEOGRAPH-#8F14, IRGKangXi=1244.050, RSKangXi=159.7, Def{cheek bone; protective; assist}
8F15 CJK UNIFIED IDEOGRAPH-#8F15, IRGKangXi=1244.090, RSKangXi=159.7, Def{light; easy, simple; gentle}
8F16 CJK UNIFIED IDEOGRAPH-#8F16, IRGKangXi=1244.130, RSKangXi=159.8
8F17 CJK UNIFIED IDEOGRAPH-#8F17, IRGKangXi=1244.140, RSKangXi=159.8, Def{the cross-bar at the end of a carriage pole; linchpin of a large carriage}
8F18 CJK UNIFIED IDEOGRAPH-#8F18, IRGKangXi=1244.150, RSKangXi=159.8, Def{a car-rut; rumbling of a cart}
8F19 CJK UNIFIED IDEOGRAPH-#8F19, IRGKangXi=1244.160, RSKangXi=159.8, Def{sides of chariot were weapons}
8F1A CJK UNIFIED IDEOGRAPH-#8F1A, IRGKangXi=1244.170, RSKangXi=159.8
8F1B CJK UNIFIED IDEOGRAPH-#8F1B, IRGKangXi=1244.190, RSKangXi=159.8, Def{numerary adjunct for vehicles}
8F1C CJK UNIFIED IDEOGRAPH-#8F1C, IRGKangXi=1244.260, RSKangXi=159.8, Def{a supply cart, covered wagon, dray}
8F1D CJK UNIFIED IDEOGRAPH-#8F1D, IRGKangXi=1244.300, RSKangXi=159.8, Def{brightness, luster, brilliance}
8F1E CJK UNIFIED IDEOGRAPH-#8F1E, IRGKangXi=1244.310, RSKangXi=159.8, Def{exterior rim of wheel, felly}
8F1F CJK UNIFIED IDEOGRAPH-#8F1F, IRGKangXi=1244.320, RSKangXi=159.8, Def{stop, suspend, halt}
8F20 CJK UNIFIED IDEOGRAPH-#8F20, IRGKangXi=1244.380, RSKangXi=159.8, Def{grease pot hung under axle of cart}
8F21 CJK UNIFIED IDEOGRAPH-#8F21, IRGKangXi=1245.010, RSKangXi=159.8, Def{same as 轗 U+8F57, to fail; a difficulty, misfortune}
8F22 CJK UNIFIED IDEOGRAPH-#8F22, IRGKangXi=1245.060, RSKangXi=159.8
8F23 CJK UNIFIED IDEOGRAPH-#8F23, IRGKangXi=1245.090, RSKangXi=159.8
8F24 CJK UNIFIED IDEOGRAPH-#8F24, IRGKangXi=1245.100, RSKangXi=159.8, Def{a pall to cover the hearse}
8F25 CJK UNIFIED IDEOGRAPH-#8F25, IRGKangXi=1245.110, RSKangXi=159.8, Def{turn round, revolve; roller}
8F26 CJK UNIFIED IDEOGRAPH-#8F26, IRGKangXi=1245.130, RSKangXi=159.8, Def{a hand-cart; to transport by carriage}
8F27 CJK UNIFIED IDEOGRAPH-#8F27, IRGKangXi=1245.170, RSKangXi=159.8, Def{curtained carriage used by women}
8F28 CJK UNIFIED IDEOGRAPH-#8F28, IRGKangXi=1245.180, RSKangXi=159.8
8F29 CJK UNIFIED IDEOGRAPH-#8F29, IRGKangXi=1245.190, RSKangXi=159.8, Def{generation, lifetime; class}
8F2A CJK UNIFIED IDEOGRAPH-#8F2A, IRGKangXi=1245.200, RSKangXi=159.8, Def{wheel; revolve, turn; recur}
8F2B CJK UNIFIED IDEOGRAPH-#8F2B, IRGKangXi=1245.210, RSKangXi=159.8
8F2C CJK UNIFIED IDEOGRAPH-#8F2C, IRGKangXi=1245.230, RSKangXi=159.8, Def{a hearse; a carriage}
8F2D CJK UNIFIED IDEOGRAPH-#8F2D, IRGKangXi=1245.280, RSKangXi=159.9, Def{flexible, pliable; weak, feeble}
8F2E CJK UNIFIED IDEOGRAPH-#8F2E, IRGKangXi=1245.310, RSKangXi=159.9, Def{exterior rim of wheel, felly}
8F2F CJK UNIFIED IDEOGRAPH-#8F2F, IRGKangXi=1246.050, RSKangXi=159.9, Def{gather up, collect; edit, compile}
8F30 CJK UNIFIED IDEOGRAPH-#8F30, IRGKangXi=1246.100, RSKangXi=159.9
8F31 CJK UNIFIED IDEOGRAPH-#8F31, IRGKangXi=1246.110
8F32 CJK UNIFIED IDEOGRAPH-#8F32, IRGKangXi=1246.120, RSKangXi=159.9
8F33 CJK UNIFIED IDEOGRAPH-#8F33, IRGKangXi=1246.140, RSKangXi=159.9, Def{hubs of wheel; converge around}
8F34 CJK UNIFIED IDEOGRAPH-#8F34, IRGKangXi=1246.170, RSKangXi=159.9, Def{sled}
8F35 CJK UNIFIED IDEOGRAPH-#8F35, IRGKangXi=1246.200, RSKangXi=159.9, Def{great array of spears and chariots}
8F36 CJK UNIFIED IDEOGRAPH-#8F36, IRGKangXi=1246.210, RSKangXi=159.9, Def{light carriage; trifling, light}
8F37 CJK UNIFIED IDEOGRAPH-#8F37, IRGKangXi=1246.220, RSKangXi=159.9
8F38 CJK UNIFIED IDEOGRAPH-#8F38, IRGKangXi=1246.230, RSKangXi=159.9, Def{transport, carry, haul}
8F39 CJK UNIFIED IDEOGRAPH-#8F39, IRGKangXi=1246.250, RSKangXi=159.9, Def{two pieces of wood underneath a cart}
8F3A CJK UNIFIED IDEOGRAPH-#8F3A, IRGKangXi=1246.260, RSKangXi=159.9
8F3B CJK UNIFIED IDEOGRAPH-#8F3B, IRGKangXi=1246.270, RSKangXi=159.9, Def{spokes of wheel}
8F3C CJK UNIFIED IDEOGRAPH-#8F3C, IRGKangXi=1247.031, RSKangXi=159.9
8F3D CJK UNIFIED IDEOGRAPH-#8F3D, IRGKangXi=1247.140, RSKangXi=159.10, Def{vehicle}
8F3E CJK UNIFIED IDEOGRAPH-#8F3E, IRGKangXi=1247.160, RSKangXi=159.10, Def{turn over, roll}
8F3F CJK UNIFIED IDEOGRAPH-#8F3F, IRGKangXi=1247.170, RSKangXi=159.10, Def{cart, palanquin; public opinion}
8F40 CJK UNIFIED IDEOGRAPH-#8F40, IRGKangXi=1247.220, RSKangXi=159.10, Def{hearse}
8F41 CJK UNIFIED IDEOGRAPH-#8F41, IRGKangXi=1247.260, RSKangXi=159.10
8F42 CJK UNIFIED IDEOGRAPH-#8F42, IRGKangXi=1247.280, RSKangXi=159.10, Def{hub of wheel}
8F43 CJK UNIFIED IDEOGRAPH-#8F43, IRGKangXi=1247.310, RSKangXi=159.10
8F44 CJK UNIFIED IDEOGRAPH-#8F44, IRGKangXi=1247.320, RSKangXi=159.10, Def{linchpin of wheel; control}
8F45 CJK UNIFIED IDEOGRAPH-#8F45, IRGKangXi=1247.330, RSKangXi=159.10, Def{axle; magistrate's office; surname}
8F46 CJK UNIFIED IDEOGRAPH-#8F46, IRGKangXi=1248.120, RSKangXi=159.11, Def{windlass, pulley, capstan; wheel}
8F47 CJK UNIFIED IDEOGRAPH-#8F47, IRGKangXi=1248.130, RSKangXi=159.11, Def{complicated, confused; dispute}
8F48 CJK UNIFIED IDEOGRAPH-#8F48, IRGKangXi=1248.150, RSKangXi=159.11, Def{turret on a chariot}
8F49 CJK UNIFIED IDEOGRAPH-#8F49, IRGKangXi=1248.170, RSKangXi=159.11, Def{shift, move, turn}
8F4A CJK UNIFIED IDEOGRAPH-#8F4A, IRGKangXi=1248.180, RSKangXi=159.11, Def{axle-tip}
8F4B CJK UNIFIED IDEOGRAPH-#8F4B, IRGKangXi=1248.191, RSKangXi=159.11
8F4C CJK UNIFIED IDEOGRAPH-#8F4C, IRGKangXi=1248.191, RSKangXi=159.11, Def{sled}
8F4D CJK UNIFIED IDEOGRAPH-#8F4D, IRGKangXi=1248.230, RSKangXi=159.12, Def{wagon ruts, wheel tracks}
8F4E CJK UNIFIED IDEOGRAPH-#8F4E, IRGKangXi=1248.310, RSKangXi=159.12, Def{sedan-chair, palanquin}
8F4F CJK UNIFIED IDEOGRAPH-#8F4F, IRGKangXi=1248.330, RSKangXi=159.12, Def{sleeping cart}
8F50 CJK UNIFIED IDEOGRAPH-#8F50, IRGKangXi=1248.370, RSKangXi=159.12
8F51 CJK UNIFIED IDEOGRAPH-#8F51, IRGKangXi=1248.380, RSKangXi=159.12, Def{rut}
8F52 CJK UNIFIED IDEOGRAPH-#8F52, IRGKangXi=1248.390, RSKangXi=159.12, Def{chariot}
8F53 CJK UNIFIED IDEOGRAPH-#8F53, IRGKangXi=1249.010, RSKangXi=159.12
8F54 CJK UNIFIED IDEOGRAPH-#8F54, IRGKangXi=1249.020, RSKangXi=159.12, Def{rumbling of vehicles; threshold}
8F55 CJK UNIFIED IDEOGRAPH-#8F55, IRGKangXi=1249.070, RSKangXi=159.13, Def{great array of spears and chariots}
8F56 CJK UNIFIED IDEOGRAPH-#8F56, IRGKangXi=1249.080, RSKangXi=159.13, Def{framework of lattice on cart}
8F57 CJK UNIFIED IDEOGRAPH-#8F57, IRGKangXi=1249.090, RSKangXi=159.13, Def{fail}
8F58 CJK UNIFIED IDEOGRAPH-#8F58, IRGKangXi=1249.100, RSKangXi=159.13, Def{tear asunder between chariots}
8F59 CJK UNIFIED IDEOGRAPH-#8F59, IRGKangXi=1249.140, RSKangXi=159.13, Def{rings on the yokes}
8F5A CJK UNIFIED IDEOGRAPH-#8F5A, IRGKangXi=1249.170, RSKangXi=159.13
8F5B CJK UNIFIED IDEOGRAPH-#8F5B, IRGKangXi=1249.190, RSKangXi=159.14
8F5C CJK UNIFIED IDEOGRAPH-#8F5C, IRGKangXi=1249.220, RSKangXi=159.14, Def{hearse}
8F5D CJK UNIFIED IDEOGRAPH-#8F5D, IRGKangXi=1249.230, RSKangXi=159.14, Def{envy; hate, dislike; resentment}
8F5E CJK UNIFIED IDEOGRAPH-#8F5E, IRGKangXi=1249.240, RSKangXi=159.14, Def{a vehicle for transporting prisoners}
8F5F CJK UNIFIED IDEOGRAPH-#8F5F, IRGKangXi=1249.280, RSKangXi=159.14, Def{rumble, explosion, blast}
8F60 CJK UNIFIED IDEOGRAPH-#8F60, IRGKangXi=1249.340, RSKangXi=159.15
8F61 CJK UNIFIED IDEOGRAPH-#8F61, IRGKangXi=1249.370, RSKangXi=159.15, Def{bridle of horse, reins}
8F62 CJK UNIFIED IDEOGRAPH-#8F62, IRGKangXi=1250.010, RSKangXi=159.15, Def{run over something with vehicle}
8F63 CJK UNIFIED IDEOGRAPH-#8F63, IRGKangXi=1250.020, RSKangXi=159.16, Def{to gallop; a mule}
8F64 CJK UNIFIED IDEOGRAPH-#8F64, IRGKangXi=1250.050, RSKangXi=159.16, Def{pulley, windlass, capstan}
8F65 CJK UNIFIED IDEOGRAPH-#8F65, IRGKangXi=1250.200, RSKangXi=159.20
8F66 CJK UNIFIED IDEOGRAPH-#8F66, IRGKangXi=1250.241, RSKangXi=159.0, Def{cart, vehicle; carry in cart}
8F67 CJK UNIFIED IDEOGRAPH-#8F67, IRGKangXi=1250.241, RSKangXi=159.1, Def{crush by weight; grind}
8F68 CJK UNIFIED IDEOGRAPH-#8F68, IRGKangXi=1250.241, RSKangXi=159.2, Def{track, rut, path}
8F69 CJK UNIFIED IDEOGRAPH-#8F69, IRGKangXi=1250.241, RSKangXi=159.3, Def{carriage; high; wide; balcony}
8F6A CJK UNIFIED IDEOGRAPH-#8F6A, IRGKangXi=1250.241, RSKangXi=159.3
8F6B CJK UNIFIED IDEOGRAPH-#8F6B, IRGKangXi=1250.241, RSKangXi=159.3, Def{a block that keeps a wheel from moving}
8F6C CJK UNIFIED IDEOGRAPH-#8F6C, IRGKangXi=1250.241, RSKangXi=159.4, Def{shift, move, turn}
8F6D CJK UNIFIED IDEOGRAPH-#8F6D, IRGKangXi=1250.241, RSKangXi=159.4, Def{yoke, collar}
8F6E CJK UNIFIED IDEOGRAPH-#8F6E, IRGKangXi=1250.241, RSKangXi=159.4, Def{wheel; revolve, turn; recur}
8F6F CJK UNIFIED IDEOGRAPH-#8F6F, IRGKangXi=1250.241, RSKangXi=159.4, Def{soft, flexible, pliable; weak}
8F70 CJK UNIFIED IDEOGRAPH-#8F70, IRGKangXi=1250.241, RSKangXi=159.4, Def{rumble, explosion, blast}
8F71 CJK UNIFIED IDEOGRAPH-#8F71, IRGKangXi=1250.241, RSKangXi=159.5, Def{wheel; to turn; to revolve}
8F72 CJK UNIFIED IDEOGRAPH-#8F72, IRGKangXi=1250.241, RSKangXi=159.5, Def{axle; personal name of mencius}
8F73 CJK UNIFIED IDEOGRAPH-#8F73, IRGKangXi=1250.241, RSKangXi=159.5, Def{pulley, windlass, capstan}
8F74 CJK UNIFIED IDEOGRAPH-#8F74, IRGKangXi=1250.241, RSKangXi=159.5, Def{axle, axletree; pivot; axis}
8F75 CJK UNIFIED IDEOGRAPH-#8F75, IRGKangXi=1250.241, RSKangXi=159.5, Def{end of axle; divergent}
8F76 CJK UNIFIED IDEOGRAPH-#8F76, IRGKangXi=1250.241, RSKangXi=159.5, Def{rush forth; surpass, excel}
8F77 CJK UNIFIED IDEOGRAPH-#8F77, IRGKangXi=1250.241, RSKangXi=159.5, Def{surname}
8F78 CJK UNIFIED IDEOGRAPH-#8F78, IRGKangXi=1250.241, RSKangXi=159.5, Def{cross board at rear of carriage}
8F79 CJK UNIFIED IDEOGRAPH-#8F79, IRGKangXi=1250.241, RSKangXi=159.5, Def{run over something with vehicle}
8F7A CJK UNIFIED IDEOGRAPH-#8F7A, IRGKangXi=1250.241, RSKangXi=159.5, Def{small light carriage}
8F7B CJK UNIFIED IDEOGRAPH-#8F7B, IRGKangXi=1250.241, RSKangXi=159.5, Def{light; easy, simple; gentle}
8F7C CJK UNIFIED IDEOGRAPH-#8F7C, IRGKangXi=1250.241, RSKangXi=159.6, Def{horizontal wooden bar in front}
8F7D CJK UNIFIED IDEOGRAPH-#8F7D, IRGKangXi=1250.241, RSKangXi=62.6, Def{load; carry; transport, convey}
8F7E CJK UNIFIED IDEOGRAPH-#8F7E, IRGKangXi=1250.241, RSKangXi=159.6, Def{low rear portion of cart}
8F7F CJK UNIFIED IDEOGRAPH-#8F7F, IRGKangXi=1250.241, RSKangXi=159.6, Def{sedan-chair, palanquin}
8F80 CJK UNIFIED IDEOGRAPH-#8F80, IRGKangXi=1250.241, RSKangXi=159.6, Def{shaft}
8F81 CJK UNIFIED IDEOGRAPH-#8F81, IRGKangXi=1250.241, RSKangXi=159.6, Def{cart wheel with no spokes}
8F82 CJK UNIFIED IDEOGRAPH-#8F82, IRGKangXi=1250.241, RSKangXi=159.6, Def{a chariot, carriage; a carriage pull-bar}
8F83 CJK UNIFIED IDEOGRAPH-#8F83, IRGKangXi=1250.241, RSKangXi=159.6, Def{compare; comparatively, more}
8F84 CJK UNIFIED IDEOGRAPH-#8F84, IRGKangXi=1250.241, RSKangXi=159.7, Def{sides of chariot where weapons}
8F85 CJK UNIFIED IDEOGRAPH-#8F85, IRGKangXi=1250.241, RSKangXi=159.7, Def{cheek bone; protective; assist}
8F86 CJK UNIFIED IDEOGRAPH-#8F86, IRGKangXi=1250.241, RSKangXi=159.7, Def{numerary adjunct for vehicles}
8F87 CJK UNIFIED IDEOGRAPH-#8F87, IRGKangXi=1250.241, RSKangXi=159.8, Def{hand-cart; transport by carriage}
8F88 CJK UNIFIED IDEOGRAPH-#8F88, IRGKangXi=1250.241, RSKangXi=175.4, Def{generation, lifetime; class}
8F89 CJK UNIFIED IDEOGRAPH-#8F89, IRGKangXi=1250.241, RSKangXi=42.9, Def{brightness, luster, brilliance}
8F8A CJK UNIFIED IDEOGRAPH-#8F8A, IRGKangXi=1250.241, RSKangXi=159.8, Def{turn round, revolve; roller}
8F8B CJK UNIFIED IDEOGRAPH-#8F8B, IRGKangXi=1250.241, RSKangXi=159.8, Def{exterior rim of wheel, felly}
8F8C CJK UNIFIED IDEOGRAPH-#8F8C, IRGKangXi=1250.241, RSKangXi=159.8, Def{a hearse; a carriage}
8F8D CJK UNIFIED IDEOGRAPH-#8F8D, IRGKangXi=1250.241, RSKangXi=159.8, Def{stop, suspend, halt}
8F8E CJK UNIFIED IDEOGRAPH-#8F8E, IRGKangXi=1250.241, RSKangXi=159.8, Def{a supply cart, covered wagon, dray}
8F8F CJK UNIFIED IDEOGRAPH-#8F8F, IRGKangXi=1250.241, RSKangXi=159.9, Def{hubs of wheel; converge around}
8F90 CJK UNIFIED IDEOGRAPH-#8F90, IRGKangXi=1250.241, RSKangXi=159.9, Def{spokes of wheel}
8F91 CJK UNIFIED IDEOGRAPH-#8F91, IRGKangXi=1250.241, RSKangXi=159.9, Def{gather up, collect; edit, compile}
8F92 CJK UNIFIED IDEOGRAPH-#8F92, IRGKangXi=1250.241, RSKangXi=159.9, Def{hearse}
8F93 CJK UNIFIED IDEOGRAPH-#8F93, IRGKangXi=1250.241, RSKangXi=159.9, Def{transport, carry, haul}
8F94 CJK UNIFIED IDEOGRAPH-#8F94, IRGKangXi=1250.241, RSKangXi=30.10, Def{bridle of horse, reins}
8F95 CJK UNIFIED IDEOGRAPH-#8F95, IRGKangXi=1250.241, RSKangXi=159.10, Def{axle; magistrate's office; surname}
8F96 CJK UNIFIED IDEOGRAPH-#8F96, IRGKangXi=1250.241, RSKangXi=159.10, Def{linchpin of wheel; control}
8F97 CJK UNIFIED IDEOGRAPH-#8F97, IRGKangXi=1250.241, RSKangXi=159.10, Def{turn over, roll}
8F98 CJK UNIFIED IDEOGRAPH-#8F98, IRGKangXi=1250.241, RSKangXi=159.11, Def{windlass, pulley, capstan; wheel}
8F99 CJK UNIFIED IDEOGRAPH-#8F99, IRGKangXi=1250.241, RSKangXi=159.12, Def{wagon ruts, wheel tracks}
8F9A CJK UNIFIED IDEOGRAPH-#8F9A, IRGKangXi=1250.241, RSKangXi=159.12, Def{rumbling of vehicles; threshold}
8F9B CJK UNIFIED IDEOGRAPH-#8F9B, IRGKangXi=1250.250, RSKangXi=160.0, Def{bitter; toilsome, laborious; 8th heavenly stem}
8F9C CJK UNIFIED IDEOGRAPH-#8F9C, IRGKangXi=1250.290, RSKangXi=160.5, Def{crime, criminal offense}
8F9D CJK UNIFIED IDEOGRAPH-#8F9D, IRGKangXi=1251.010, RSKangXi=160.5
8F9E CJK UNIFIED IDEOGRAPH-#8F9E, IRGKangXi=1251.020, RSKangXi=135.7, Def{words, speech, expression, phrase}
8F9F CJK UNIFIED IDEOGRAPH-#8F9F, IRGKangXi=1251.060, RSKangXi=160.6, Def{law, rule; open up, develop}
8FA0 CJK UNIFIED IDEOGRAPH-#8FA0, IRGKangXi=1251.090, RSKangXi=160.6, Def{crime, sin, vice; evil; hardship}
8FA1 CJK UNIFIED IDEOGRAPH-#8FA1, IRGKangXi=1251.100, RSKangXi=160.7, Def{recrimination; wrangling}
8FA2 CJK UNIFIED IDEOGRAPH-#8FA2, IRGKangXi=1251.110, RSKangXi=160.7, Def{bitter, pungent, acrid}
8FA3 CJK UNIFIED IDEOGRAPH-#8FA3, IRGKangXi=1251.120, RSKangXi=160.7, Def{peppery, pungent, hot; cruel}
8FA4 CJK UNIFIED IDEOGRAPH-#8FA4, IRGKangXi=1251.150, RSKangXi=160.8, Def{words, speech; a sentence, an expression or phrase; a message}
8FA5 CJK UNIFIED IDEOGRAPH-#8FA5, IRGKangXi=1251.170, RSKangXi=160.9, Def{variety of marsh grass}
8FA6 CJK UNIFIED IDEOGRAPH-#8FA6, IRGKangXi=1251.180, RSKangXi=160.9, Def{manage, do, handle; deal with}
8FA7 CJK UNIFIED IDEOGRAPH-#8FA7, IRGKangXi=1251.190, RSKangXi=160.9, Def{manage, do, handle; deal with}
8FA8 CJK UNIFIED IDEOGRAPH-#8FA8, IRGKangXi=1251.200, RSKangXi=160.9, Def{distinguish, discriminate}
8FA9 CJK UNIFIED IDEOGRAPH-#8FA9, IRGKangXi=1252.021, RSKangXi=160.9, Def{dispute, argue, debate, discuss}
8FAA CJK UNIFIED IDEOGRAPH-#8FAA, IRGKangXi=1252.041
8FAB CJK UNIFIED IDEOGRAPH-#8FAB, IRGKangXi=1252.041, RSKangXi=160.10, Def{braid; pigtail, plait, queue}
8FAC CJK UNIFIED IDEOGRAPH-#8FAC, IRGKangXi=1252.050, RSKangXi=160.11
8FAD CJK UNIFIED IDEOGRAPH-#8FAD, IRGKangXi=1252.080, RSKangXi=160.12, Def{words, speech, expression, phrase}
8FAE CJK UNIFIED IDEOGRAPH-#8FAE, IRGKangXi=1252.130, RSKangXi=120.14, Def{braid; pigtail, plait, queue}
8FAF CJK UNIFIED IDEOGRAPH-#8FAF, IRGKangXi=1252.140, RSKangXi=160.14, Def{dispute, argue, debate, discuss}
8FB0 CJK UNIFIED IDEOGRAPH-#8FB0, IRGKangXi=1252.150, RSKangXi=161.0, Def{early morning; 5th terrestrial branch}
8FB1 CJK UNIFIED IDEOGRAPH-#8FB1, IRGKangXi=1252.210, RSKangXi=161.3, Def{humiliate, insult, abuse}
8FB2 CJK UNIFIED IDEOGRAPH-#8FB2, IRGKangXi=1252.240, RSKangXi=161.6, Def{agriculture, farming; farmer}
8FB3 CJK UNIFIED IDEOGRAPH-#8FB3, IRGKangXi=1253.050, RSKangXi=161.8
8FB4 CJK UNIFIED IDEOGRAPH-#8FB4, IRGKangXi=1253.060, RSKangXi=161.12
8FB5 CJK UNIFIED IDEOGRAPH-#8FB5, IRGKangXi=1253.110, RSKangXi=162.0, Def{walk; walking; KangXi radical 162}
8FB6 CJK UNIFIED IDEOGRAPH-#8FB6, IRGKangXi=1253.111, RSKangXi=162.0, Def{walk; walking; KangXi radical 162}
8FB7 CJK UNIFIED IDEOGRAPH-#8FB7, IRGKangXi=1253.111, RSKangXi=162.1, Def{smooth, slippery}
8FB8 CJK UNIFIED IDEOGRAPH-#8FB8, IRGKangXi=1253.130, RSKangXi=162.2
8FB9 CJK UNIFIED IDEOGRAPH-#8FB9, IRGKangXi=1253.131, RSKangXi=162.2, Def{edge, margin, side, border}
8FBA CJK UNIFIED IDEOGRAPH-#8FBA, IRGKangXi=1253.131, RSKangXi=162.2, Def{edge, margin, side, border}
8FBB CJK UNIFIED IDEOGRAPH-#8FBB, IRGKangXi=1253.131, RSKangXi=162.2, Def{crossroads; street}
8FBC CJK UNIFIED IDEOGRAPH-#8FBC, IRGKangXi=1253.131, RSKangXi=162.2, Def{crowd into, go into}
8FBD CJK UNIFIED IDEOGRAPH-#8FBD, IRGKangXi=1253.131, RSKangXi=162.2, Def{distant, far}
8FBE CJK UNIFIED IDEOGRAPH-#8FBE, IRGKangXi=1253.170, RSKangXi=162.3, Def{arrive at, reach; intelligent; smooth, slippery}
8FBF CJK UNIFIED IDEOGRAPH-#8FBF, IRGKangXi=1253.180, RSKangXi=162.3, Def{follow, pursue}
8FC0 CJK UNIFIED IDEOGRAPH-#8FC0, IRGKangXi=1253.200, RSKangXi=162.3
8FC1 CJK UNIFIED IDEOGRAPH-#8FC1, IRGKangXi=1253.210, RSKangXi=162.3, Def{move, shift, change; transfer; relocate a capital city}
8FC2 CJK UNIFIED IDEOGRAPH-#8FC2, IRGKangXi=1253.220, RSKangXi=162.3, Def{doctrinaire, abstruse, unrealistic}
8FC3 CJK UNIFIED IDEOGRAPH-#8FC3, IRGKangXi=1253.230, RSKangXi=162.3
8FC4 CJK UNIFIED IDEOGRAPH-#8FC4, IRGKangXi=1253.240, RSKangXi=162.3, Def{extend, reach; until; till}
8FC5 CJK UNIFIED IDEOGRAPH-#8FC5, IRGKangXi=1253.260, RSKangXi=162.3, Def{quick, hasty, rapid, sudden}
8FC6 CJK UNIFIED IDEOGRAPH-#8FC6, IRGKangXi=1253.270, RSKangXi=162.3, Def{wind; walk out of straight path}
8FC7 CJK UNIFIED IDEOGRAPH-#8FC7, IRGKangXi=1253.281, RSKangXi=162.3, Def{pass, pass through, go across}
8FC8 CJK UNIFIED IDEOGRAPH-#8FC8, IRGKangXi=1253.281, RSKangXi=162.3, Def{take a big stride; pass by}
8FC9 CJK UNIFIED IDEOGRAPH-#8FC9, IRGKangXi=1253.281, RSKangXi=162.3
8FCA CJK UNIFIED IDEOGRAPH-#8FCA, IRGKangXi=1253.300, RSKangXi=162.4, Def{to go round, to make a circuit, to make a revolution, to turn round}
8FCB CJK UNIFIED IDEOGRAPH-#8FCB, IRGKangXi=1253.320, RSKangXi=162.4, Def{travel, go to; deceive; scare}
8FCC CJK UNIFIED IDEOGRAPH-#8FCC, IRGKangXi=1254.010, RSKangXi=162.4
8FCD CJK UNIFIED IDEOGRAPH-#8FCD, IRGKangXi=1254.020, RSKangXi=162.4, Def{falter, hesitate}
8FCE CJK UNIFIED IDEOGRAPH-#8FCE, IRGKangXi=1254.030, RSKangXi=162.4, Def{receive, welcome, greet}
8FCF CJK UNIFIED IDEOGRAPH-#8FCF, IRGKangXi=1254.040, RSKangXi=162.4
8FD0 CJK UNIFIED IDEOGRAPH-#8FD0, IRGKangXi=1254.050, RSKangXi=162.4, Def{run; simplified form of 運 luck, fortune; ship, transport}
8FD1 CJK UNIFIED IDEOGRAPH-#8FD1, IRGKangXi=1254.070, RSKangXi=162.4, Def{near, close; approach; intimate}
8FD2 CJK UNIFIED IDEOGRAPH-#8FD2, IRGKangXi=1254.110, RSKangXi=162.4
8FD3 CJK UNIFIED IDEOGRAPH-#8FD3, IRGKangXi=1254.120, RSKangXi=162.4, Def{to go to meet, to receive, as a guest}
8FD4 CJK UNIFIED IDEOGRAPH-#8FD4, IRGKangXi=1254.140, RSKangXi=162.4, Def{return, revert to, restore}
8FD5 CJK UNIFIED IDEOGRAPH-#8FD5, IRGKangXi=1254.150, RSKangXi=162.4, Def{obstinate, perverse}
8FD6 CJK UNIFIED IDEOGRAPH-#8FD6, IRGKangXi=1254.170, RSKangXi=162.4
8FD7 CJK UNIFIED IDEOGRAPH-#8FD7, IRGKangXi=1254.171, RSKangXi=162.4
8FD8 CJK UNIFIED IDEOGRAPH-#8FD8, IRGKangXi=1254.171, RSKangXi=162.4, Def{still, yet, also, besides}
8FD9 CJK UNIFIED IDEOGRAPH-#8FD9, IRGKangXi=1254.171, RSKangXi=162.4, Def{this, the, here}
8FDA CJK UNIFIED IDEOGRAPH-#8FDA, IRGKangXi=1254.171, RSKangXi=162.4, Def{very; somehow}
8FDB CJK UNIFIED IDEOGRAPH-#8FDB, IRGKangXi=1254.171, RSKangXi=162.4, Def{advance, make progress, enter}
8FDC CJK UNIFIED IDEOGRAPH-#8FDC, IRGKangXi=1254.171, RSKangXi=162.4, Def{distant, remote, far; profound}
8FDD CJK UNIFIED IDEOGRAPH-#8FDD, IRGKangXi=1254.171, RSKangXi=162.4, Def{disobey, violate, defy; be apart from}
8FDE CJK UNIFIED IDEOGRAPH-#8FDE, IRGKangXi=1254.171, RSKangXi=162.4, Def{join, connect; continuous; even}
8FDF CJK UNIFIED IDEOGRAPH-#8FDF, IRGKangXi=1254.171, RSKangXi=162.4, Def{late, tardy; slow; delay}
8FE0 CJK UNIFIED IDEOGRAPH-#8FE0, IRGKangXi=1254.210, RSKangXi=162.5, Def{made}
8FE1 CJK UNIFIED IDEOGRAPH-#8FE1, IRGKangXi=1254.220, RSKangXi=162.5
8FE2 CJK UNIFIED IDEOGRAPH-#8FE2, IRGKangXi=1254.250, RSKangXi=162.5, Def{far; distant}
8FE3 CJK UNIFIED IDEOGRAPH-#8FE3, IRGKangXi=1254.270, RSKangXi=162.5, Def{to leap over}
8FE4 CJK UNIFIED IDEOGRAPH-#8FE4, IRGKangXi=1254.290, RSKangXi=162.5, Def{wind; walk out of straight path}
8FE5 CJK UNIFIED IDEOGRAPH-#8FE5, IRGKangXi=1254.300, RSKangXi=162.5, Def{distant, far; separated; different}
8FE6 CJK UNIFIED IDEOGRAPH-#8FE6, IRGKangXi=1254.330, RSKangXi=162.5, Def{character for transliteration}
8FE7 CJK UNIFIED IDEOGRAPH-#8FE7, IRGKangXi=1254.340, RSKangXi=162.5, Def{a Chinese family name arrange; display a column of troops}
8FE8 CJK UNIFIED IDEOGRAPH-#8FE8, IRGKangXi=1254.350, RSKangXi=162.5, Def{until, when; seize, arrest}
8FE9 CJK UNIFIED IDEOGRAPH-#8FE9, IRGKangXi=1255.010, RSKangXi=162.5, Def{be near, be close; recently}
8FEA CJK UNIFIED IDEOGRAPH-#8FEA, IRGKangXi=1255.030, RSKangXi=162.5, Def{enlighten, advance; progress}
8FEB CJK UNIFIED IDEOGRAPH-#8FEB, IRGKangXi=1255.050, RSKangXi=162.5, Def{coerce, force, compel; urgent}
8FEC CJK UNIFIED IDEOGRAPH-#8FEC, IRGKangXi=1255.070, RSKangXi=162.4, Def{to walk along, to go}
8FED CJK UNIFIED IDEOGRAPH-#8FED, IRGKangXi=1255.080, RSKangXi=162.5, Def{repeatedly, frequently}
8FEE CJK UNIFIED IDEOGRAPH-#8FEE, IRGKangXi=1255.090, RSKangXi=162.5, Def{to rise; contracted; cramped}
8FEF CJK UNIFIED IDEOGRAPH-#8FEF, IRGKangXi=1255.100, RSKangXi=162.5, Def{escape, flee; abscond, dodge}
8FF0 CJK UNIFIED IDEOGRAPH-#8FF0, IRGKangXi=1255.110, RSKangXi=162.5, Def{narrate, state, express}
8FF1 CJK UNIFIED IDEOGRAPH-#8FF1, IRGKangXi=1255.120, RSKangXi=162.5
8FF2 CJK UNIFIED IDEOGRAPH-#8FF2, IRGKangXi=1255.141, RSKangXi=162.5
8FF3 CJK UNIFIED IDEOGRAPH-#8FF3, IRGKangXi=1255.141, RSKangXi=162.5, Def{pass by, approach; direct}
8FF4 CJK UNIFIED IDEOGRAPH-#8FF4, IRGKangXi=1255.160, RSKangXi=162.6, Def{revolve, rotate; curving, zigzag}
8FF5 CJK UNIFIED IDEOGRAPH-#8FF5, IRGKangXi=1255.190, RSKangXi=162.6
8FF6 CJK UNIFIED IDEOGRAPH-#8FF6, IRGKangXi=1255.200, RSKangXi=162.6
8FF7 CJK UNIFIED IDEOGRAPH-#8FF7, IRGKangXi=1255.230, RSKangXi=162.6, Def{bewitch, charm, infatuate}
8FF8 CJK UNIFIED IDEOGRAPH-#8FF8, IRGKangXi=1255.250, RSKangXi=162.8, Def{gush out; burst forth; split}
8FF9 CJK UNIFIED IDEOGRAPH-#8FF9, IRGKangXi=1255.260, RSKangXi=162.6, Def{traces, impressions, footprints}
8FFA CJK UNIFIED IDEOGRAPH-#8FFA, IRGKangXi=1256.040, RSKangXi=162.6, Def{then, thereupon, only then}
8FFB CJK UNIFIED IDEOGRAPH-#8FFB, IRGKangXi=1256.060, RSKangXi=162.6, Def{to shift; to transfer; to transform}
8FFC CJK UNIFIED IDEOGRAPH-#8FFC, IRGKangXi=1256.080, RSKangXi=162.6
8FFD CJK UNIFIED IDEOGRAPH-#8FFD, IRGKangXi=1256.100, RSKangXi=162.6, Def{pursue, chase after; expel}
8FFE CJK UNIFIED IDEOGRAPH-#8FFE, IRGKangXi=1256.110, RSKangXi=162.6, Def{(Cant.) row}
8FFF CJK UNIFIED IDEOGRAPH-#8FFF, IRGKangXi=1256.130, RSKangXi=162.6, Def{to be the first to begin a quarrel}
9000 CJK UNIFIED IDEOGRAPH-#9000, IRGKangXi=1256.140, RSKangXi=162.6, Def{step back, retreat, withdraw}
9001 CJK UNIFIED IDEOGRAPH-#9001, IRGKangXi=1256.210, RSKangXi=162.6, Def{see off, send off; dispatch, give}
9002 CJK UNIFIED IDEOGRAPH-#9002, IRGKangXi=1256.250, RSKangXi=162.6, Def{go, reach; appropriate, suitable}
9003 CJK UNIFIED IDEOGRAPH-#9003, IRGKangXi=1256.260, RSKangXi=162.6, Def{escape, flee; abscond, dodge}
9004 CJK UNIFIED IDEOGRAPH-#9004, IRGKangXi=1256.280, RSKangXi=162.6, Def{a surname}
9005 CJK UNIFIED IDEOGRAPH-#9005, IRGKangXi=1256.290, RSKangXi=162.6, Def{meet unexpectedly}
9006 CJK UNIFIED IDEOGRAPH-#9006, IRGKangXi=1256.300, RSKangXi=162.6, Def{disobey, rebel; rebel, traitor}
9007 CJK UNIFIED IDEOGRAPH-#9007, IRGKangXi=1257.041, RSKangXi=162.6
9008 CJK UNIFIED IDEOGRAPH-#9008, IRGKangXi=1257.041, RSKangXi=162.6, Def{distant, far; separated; different}
9009 CJK UNIFIED IDEOGRAPH-#9009, IRGKangXi=1257.041, RSKangXi=162.6, Def{choose, select; elect; election}
900A CJK UNIFIED IDEOGRAPH-#900A, IRGKangXi=1257.041, RSKangXi=162.6, Def{humble, modest; yield}
900B CJK UNIFIED IDEOGRAPH-#900B, IRGKangXi=1257.080, RSKangXi=162.7, Def{flee, run away, leave debt unsettled}
900C CJK UNIFIED IDEOGRAPH-#900C, IRGKangXi=1257.090, RSKangXi=162.7, Def{please; smiling; complacent}
900D CJK UNIFIED IDEOGRAPH-#900D, IRGKangXi=1257.100, RSKangXi=162.7, Def{ramble, stroll, jaunt, loiter}
900E CJK UNIFIED IDEOGRAPH-#900E, IRGKangXi=1257.110, RSKangXi=162.7, Def{strong, unyielding, forceful}
900F CJK UNIFIED IDEOGRAPH-#900F, IRGKangXi=1257.130, RSKangXi=162.7, Def{penetrate, pass through}
9010 CJK UNIFIED IDEOGRAPH-#9010, IRGKangXi=1257.140, RSKangXi=162.7, Def{chase, expel; one by one}
9011 CJK UNIFIED IDEOGRAPH-#9011, IRGKangXi=1257.160, RSKangXi=162.7, Def{collect, unite; match, pair}
9012 CJK UNIFIED IDEOGRAPH-#9012, IRGKangXi=1257.180, RSKangXi=162.7, Def{hand over, deliver; substitute}
9013 CJK UNIFIED IDEOGRAPH-#9013, IRGKangXi=1257.190, RSKangXi=162.7, Def{hand over, deliver; substitute}
9014 CJK UNIFIED IDEOGRAPH-#9014, IRGKangXi=1257.200, RSKangXi=162.7, Def{way, road, path, journey; course}
9015 CJK UNIFIED IDEOGRAPH-#9015, IRGKangXi=1257.210, RSKangXi=162.7, Def{pass by, approach; direct}
9016 CJK UNIFIED IDEOGRAPH-#9016, IRGKangXi=1257.240, RSKangXi=162.7, Def{far, distant; keep at distance}
9017 CJK UNIFIED IDEOGRAPH-#9017, IRGKangXi=1257.250, RSKangXi=162.7, Def{tempt, allure, arouse, stir}
9018 CJK UNIFIED IDEOGRAPH-#9018, IRGKangXi=1257.260, RSKangXi=162.7
9019 CJK UNIFIED IDEOGRAPH-#9019, IRGKangXi=1258.010, RSKangXi=162.7, Def{this, the, here}
901A CJK UNIFIED IDEOGRAPH-#901A, IRGKangXi=1258.040, RSKangXi=162.7, Def{pass through, common, communicate}
901B CJK UNIFIED IDEOGRAPH-#901B, IRGKangXi=1258.060, RSKangXi=162.7, Def{ramble, stroll, roam, wander}
901C CJK UNIFIED IDEOGRAPH-#901C, IRGKangXi=1258.070, RSKangXi=162.7
901D CJK UNIFIED IDEOGRAPH-#901D, IRGKangXi=1258.080, RSKangXi=162.7, Def{pass away; die}
901E CJK UNIFIED IDEOGRAPH-#901E, IRGKangXi=1258.090, RSKangXi=162.7, Def{indulge oneself; brag, show off}
901F CJK UNIFIED IDEOGRAPH-#901F, IRGKangXi=1258.100, RSKangXi=162.7, Def{quick, prompt, speedy}
9020 CJK UNIFIED IDEOGRAPH-#9020, IRGKangXi=1258.120, RSKangXi=162.7, Def{construct, build, make, begin; prepare}
9021 CJK UNIFIED IDEOGRAPH-#9021, IRGKangXi=1258.140, RSKangXi=162.7, Def{retreat, withdraw, fall back}
9022 CJK UNIFIED IDEOGRAPH-#9022, IRGKangXi=1258.160, RSKangXi=162.7, Def{come upon, happen meet; flatter}
9023 CJK UNIFIED IDEOGRAPH-#9023, IRGKangXi=1259.010, RSKangXi=162.7, Def{join, connect; continuous; even}
9024 CJK UNIFIED IDEOGRAPH-#9024, IRGKangXi=1259.030, RSKangXi=162.7
9025 CJK UNIFIED IDEOGRAPH-#9025, IRGKangXi=1259.061, Def{return, turn around; a time}
9026 CJK UNIFIED IDEOGRAPH-#9026, IRGKangXi=1259.061, RSKangXi=162.7, Def{meandering, winding}
9027 CJK UNIFIED IDEOGRAPH-#9027, IRGKangXi=1259.061, RSKangXi=162.7
9028 CJK UNIFIED IDEOGRAPH-#9028, IRGKangXi=1259.080, RSKangXi=162.8
9029 CJK UNIFIED IDEOGRAPH-#9029, IRGKangXi=1259.090, RSKangXi=162.8, Def{to run quickly}
902A CJK UNIFIED IDEOGRAPH-#902A, IRGKangXi=1259.110, RSKangXi=162.8
902B CJK UNIFIED IDEOGRAPH-#902B, IRGKangXi=1259.120, RSKangXi=162.8
902C CJK UNIFIED IDEOGRAPH-#902C, IRGKangXi=1259.150, RSKangXi=162.8, Def{to scatter; to expel; to crack, to split; to jump}
902D CJK UNIFIED IDEOGRAPH-#902D, IRGKangXi=1259.160, RSKangXi=162.8, Def{to escape from; to flee, to avoid}
902E CJK UNIFIED IDEOGRAPH-#902E, IRGKangXi=1259.180, RSKangXi=162.8, Def{seize, catch; reach, arrive}
902F CJK UNIFIED IDEOGRAPH-#902F, IRGKangXi=1259.100, RSKangXi=162.8, Def{leave without reason; surname}
9030 CJK UNIFIED IDEOGRAPH-#9030, IRGKangXi=1259.200, Def{wander, roam, travel}
9031 CJK UNIFIED IDEOGRAPH-#9031, IRGKangXi=1259.240, RSKangXi=162.8, Def{week; turn, cycle; anniversary}
9032 CJK UNIFIED IDEOGRAPH-#9032, IRGKangXi=1259.300, RSKangXi=162.8, Def{advance, make progress, enter}
9033 CJK UNIFIED IDEOGRAPH-#9033, IRGKangXi=1260.030, RSKangXi=162.8, Def{(Cant.) to move, touch, hit}
9034 CJK UNIFIED IDEOGRAPH-#9034, IRGKangXi=1260.040, RSKangXi=162.8, Def{argue, quarrel, squabble; far}
9035 CJK UNIFIED IDEOGRAPH-#9035, IRGKangXi=1260.050, RSKangXi=162.8, Def{thoroughfare, crossroads}
9036 CJK UNIFIED IDEOGRAPH-#9036, IRGKangXi=1260.060, RSKangXi=162.8, Def{winding, curving; swagger}
9037 CJK UNIFIED IDEOGRAPH-#9037, IRGKangXi=1260.070, RSKangXi=162.8, Def{distant, far away}
9038 CJK UNIFIED IDEOGRAPH-#9038, IRGKangXi=1260.080, RSKangXi=162.8, Def{flee, escape, break loose}
9039 CJK UNIFIED IDEOGRAPH-#9039, IRGKangXi=1260.151, RSKangXi=162.8, Def{arrive at, reach; intelligent}
903A CJK UNIFIED IDEOGRAPH-#903A, IRGKangXi=1260.151, Def{distant, remote, far; profound}
903B CJK UNIFIED IDEOGRAPH-#903B, IRGKangXi=1260.151, RSKangXi=162.8, Def{patrol; inspect; watch; patrol}
903C CJK UNIFIED IDEOGRAPH-#903C, IRGKangXi=1260.160, RSKangXi=162.9, Def{compel, pressure, force; bother}
903D CJK UNIFIED IDEOGRAPH-#903D, IRGKangXi=1260.190, RSKangXi=162.9
903E CJK UNIFIED IDEOGRAPH-#903E, IRGKangXi=1260.200, RSKangXi=162.9, Def{go over, pass over, exceed}
903F CJK UNIFIED IDEOGRAPH-#903F, IRGKangXi=1260.220, RSKangXi=162.9, Def{a time; a row; to fall, miss}
9040 CJK UNIFIED IDEOGRAPH-#9040, IRGKangXi=1260.240, RSKangXi=162.9
9041 CJK UNIFIED IDEOGRAPH-#9041, IRGKangXi=1260.260, RSKangXi=162.9, Def{hide, conceal oneself; escape}
9042 CJK UNIFIED IDEOGRAPH-#9042, IRGKangXi=1260.320, RSKangXi=162.9, Def{comply with, follow along; thereupon}
9043 CJK UNIFIED IDEOGRAPH-#9043, IRGKangXi=1261.010, RSKangXi=162.9
9044 CJK UNIFIED IDEOGRAPH-#9044, IRGKangXi=1261.030, RSKangXi=162.9, Def{to hurry; to go to and fro}
9045 CJK UNIFIED IDEOGRAPH-#9045, IRGKangXi=1261.050, RSKangXi=162.9, Def{late, tardy; slow; delay}
9046 CJK UNIFIED IDEOGRAPH-#9046, IRGKangXi=1261.060, RSKangXi=162.9
9047 CJK UNIFIED IDEOGRAPH-#9047, IRGKangXi=1261.070, RSKangXi=162.9, Def{meet, come across, encounter}
9048 CJK UNIFIED IDEOGRAPH-#9048, IRGKangXi=1261.090, RSKangXi=162.9
9049 CJK UNIFIED IDEOGRAPH-#9049, IRGKangXi=1261.100, RSKangXi=162.9, Def{spy, reconnoiter; detective}
904A CJK UNIFIED IDEOGRAPH-#904A, IRGKangXi=1261.110, RSKangXi=162.9, Def{wander, roam, travel}
904B CJK UNIFIED IDEOGRAPH-#904B, IRGKangXi=1261.180, RSKangXi=162.9, Def{luck, fortune; ship, transport}
904C CJK UNIFIED IDEOGRAPH-#904C, IRGKangXi=1261.200, RSKangXi=162.9
904D CJK UNIFIED IDEOGRAPH-#904D, IRGKangXi=1261.210, RSKangXi=162.9, Def{everywhere, all over, throughout}
904E CJK UNIFIED IDEOGRAPH-#904E, IRGKangXi=1261.220, RSKangXi=162.9, Def{pass, pass through, go across}
904F CJK UNIFIED IDEOGRAPH-#904F, IRGKangXi=1261.240, RSKangXi=162.9, Def{stop, suppress, curb, check; a bar}
9050 CJK UNIFIED IDEOGRAPH-#9050, IRGKangXi=1261.250, RSKangXi=162.9, Def{afar, distant; old, advanced in}
9051 CJK UNIFIED IDEOGRAPH-#9051, IRGKangXi=1262.010, RSKangXi=162.9, Def{leisure, leisurely; hurry about}
9052 CJK UNIFIED IDEOGRAPH-#9052, IRGKangXi=1262.030, RSKangXi=162.9, Def{strong, unyielding, forceful}
9053 CJK UNIFIED IDEOGRAPH-#9053, IRGKangXi=1262.060, RSKangXi=162.9, Def{path, road, street; method, way}
9054 CJK UNIFIED IDEOGRAPH-#9054, IRGKangXi=1262.100, RSKangXi=162.9, Def{arrive at, reach; intelligent}
9055 CJK UNIFIED IDEOGRAPH-#9055, IRGKangXi=1262.110, RSKangXi=162.9, Def{disobey, violate, defy; be apart from}
9056 CJK UNIFIED IDEOGRAPH-#9056, IRGKangXi=1262.201, RSKangXi=162.9
9057 CJK UNIFIED IDEOGRAPH-#9057, IRGKangXi=1262.201, RSKangXi=162.9, Def{lose; articles lost; omit}
9058 CJK UNIFIED IDEOGRAPH-#9058, IRGKangXi=1262.210, RSKangXi=162.10, Def{to meet; to come across}
9059 CJK UNIFIED IDEOGRAPH-#9059, IRGKangXi=1262.250, RSKangXi=162.10, Def{far away, distant, remote}
905A CJK UNIFIED IDEOGRAPH-#905A, IRGKangXi=1263.010, RSKangXi=162.10
905B CJK UNIFIED IDEOGRAPH-#905B, IRGKangXi=1263.020, RSKangXi=162.10, Def{take walk, stroll}
905C CJK UNIFIED IDEOGRAPH-#905C, IRGKangXi=1263.030, RSKangXi=162.10, Def{humble, modest; yield}
905D CJK UNIFIED IDEOGRAPH-#905D, IRGKangXi=1263.090, RSKangXi=162.10, Def{mixed, abundant, assorted}
905E CJK UNIFIED IDEOGRAPH-#905E, IRGKangXi=1263.100, RSKangXi=162.10, Def{hand over, deliver; substitute}
905F CJK UNIFIED IDEOGRAPH-#905F, IRGKangXi=1263.110, Def{late, tardy; slow; delay}
9060 CJK UNIFIED IDEOGRAPH-#9060, IRGKangXi=1263.120, RSKangXi=162.10, Def{distant, remote, far; profound}
9061 CJK UNIFIED IDEOGRAPH-#9061, IRGKangXi=1263.150, RSKangXi=162.10, Def{go upstream; trace source; formerly}
9062 CJK UNIFIED IDEOGRAPH-#9062, IRGKangXi=1263.170, RSKangXi=162.10, Def{careless, negligent, slipshod}
9063 CJK UNIFIED IDEOGRAPH-#9063, IRGKangXi=1263.190, RSKangXi=162.10, Def{send, dispatch; send off, exile}
9064 CJK UNIFIED IDEOGRAPH-#9064, IRGKangXi=1263.251, RSKangXi=162.10
9065 CJK UNIFIED IDEOGRAPH-#9065, IRGKangXi=1263.251, RSKangXi=162.9, Def{far away, distant, remote}
9066 CJK UNIFIED IDEOGRAPH-#9066, IRGKangXi=1263.260, RSKangXi=162.11
9067 CJK UNIFIED IDEOGRAPH-#9067, IRGKangXi=1263.300, RSKangXi=162.11
9068 CJK UNIFIED IDEOGRAPH-#9068, IRGKangXi=1263.310, RSKangXi=162.11, Def{ramble, roam; travel for pleasure}
9069 CJK UNIFIED IDEOGRAPH-#9069, IRGKangXi=1263.340, RSKangXi=162.11, Def{match, comfortable; just}
906A CJK UNIFIED IDEOGRAPH-#906A, IRGKangXi=1264.020, RSKangXi=162.11
906B CJK UNIFIED IDEOGRAPH-#906B, IRGKangXi=1264.030, RSKangXi=162.11, Def{speed}
906C CJK UNIFIED IDEOGRAPH-#906C, IRGKangXi=1264.040, RSKangXi=162.11
906D CJK UNIFIED IDEOGRAPH-#906D, IRGKangXi=1264.060, RSKangXi=162.11, Def{come across, meet with, encounter}
906E CJK UNIFIED IDEOGRAPH-#906E, IRGKangXi=1264.100, RSKangXi=162.11, Def{cover, shield, protect}
906F CJK UNIFIED IDEOGRAPH-#906F, IRGKangXi=1264.130, RSKangXi=162.11, Def{deceive, hide, conceal; flee}
9070 CJK UNIFIED IDEOGRAPH-#9070, IRGKangXi=1264.140, RSKangXi=162.11, Def{grunting sound of pigs; clash}
9071 CJK UNIFIED IDEOGRAPH-#9071, IRGKangXi=1264.150, RSKangXi=162.11
9072 CJK UNIFIED IDEOGRAPH-#9072, IRGKangXi=1264.170, RSKangXi=162.12, Def{late, tardy; slow; delay}
9073 CJK UNIFIED IDEOGRAPH-#9073, IRGKangXi=1264.200, RSKangXi=162.11
9074 CJK UNIFIED IDEOGRAPH-#9074, IRGKangXi=1264.250, RSKangXi=162.12, Def{select, choose; surname}
9075 CJK UNIFIED IDEOGRAPH-#9075, IRGKangXi=1264.260, RSKangXi=162.12, Def{obey, comply with, follow; honor}
9076 CJK UNIFIED IDEOGRAPH-#9076, IRGKangXi=1265.030, RSKangXi=162.12, Def{entwine; wind around; surround}
9077 CJK UNIFIED IDEOGRAPH-#9077, IRGKangXi=1265.040, RSKangXi=162.12, Def{move, shift, change; transfer}
9078 CJK UNIFIED IDEOGRAPH-#9078, IRGKangXi=1265.130, RSKangXi=162.12, Def{choose, select; elect; election}
9079 CJK UNIFIED IDEOGRAPH-#9079, IRGKangXi=1265.150, RSKangXi=162.12, Def{comply with, obey; shun, avoid}
907A CJK UNIFIED IDEOGRAPH-#907A, IRGKangXi=1265.180, RSKangXi=162.12, Def{lose; articles lost; omit}
907B CJK UNIFIED IDEOGRAPH-#907B, IRGKangXi=1265.230, RSKangXi=162.12, Def{meet}
907C CJK UNIFIED IDEOGRAPH-#907C, IRGKangXi=1265.240, RSKangXi=162.12, Def{distant, far}
907D CJK UNIFIED IDEOGRAPH-#907D, IRGKangXi=1266.070, RSKangXi=162.13, Def{suddenly, unexpectedly; at once}
907E CJK UNIFIED IDEOGRAPH-#907E, IRGKangXi=1266.080, RSKangXi=162.13
907F CJK UNIFIED IDEOGRAPH-#907F, IRGKangXi=1266.090, RSKangXi=162.13, Def{avoid; turn aside; escape; hide}
9080 CJK UNIFIED IDEOGRAPH-#9080, IRGKangXi=1266.160, RSKangXi=162.13, Def{invite, welcome; meet, intercept}
9081 CJK UNIFIED IDEOGRAPH-#9081, IRGKangXi=1266.170, RSKangXi=162.13, Def{take a big stride; pass by}
9082 CJK UNIFIED IDEOGRAPH-#9082, IRGKangXi=1266.210, RSKangXi=162.13, Def{unexpected meeting; encounter by}
9083 CJK UNIFIED IDEOGRAPH-#9083, IRGKangXi=1266.220, RSKangXi=162.13, Def{profound, detailed; deep}
9084 CJK UNIFIED IDEOGRAPH-#9084, IRGKangXi=1266.230, RSKangXi=162.13, Def{still, yet, also, besides}
9085 CJK UNIFIED IDEOGRAPH-#9085, IRGKangXi=1266.240, RSKangXi=162.13, Def{hesitant, faltering}
9086 CJK UNIFIED IDEOGRAPH-#9086, IRGKangXi=1266.260, RSKangXi=162.12
9087 CJK UNIFIED IDEOGRAPH-#9087, IRGKangXi=1267.040, RSKangXi=162.14, Def{be near, be close; recently}
9088 CJK UNIFIED IDEOGRAPH-#9088, IRGKangXi=1267.100, RSKangXi=162.14, Def{far, distant, remote; slight}
9089 CJK UNIFIED IDEOGRAPH-#9089, IRGKangXi=1267.111, RSKangXi=162.13, Def{edge, margin, side, border}
908A CJK UNIFIED IDEOGRAPH-#908A, IRGKangXi=1267.130, RSKangXi=162.15, Def{edge, margin, side, border}
908B CJK UNIFIED IDEOGRAPH-#908B, IRGKangXi=1267.150, RSKangXi=162.15, Def{rags}
908C CJK UNIFIED IDEOGRAPH-#908C, IRGKangXi=1267.160, RSKangXi=162.15, Def{to walk slowly; to parade}
908D CJK UNIFIED IDEOGRAPH-#908D, IRGKangXi=1267.200, RSKangXi=162.16
908E CJK UNIFIED IDEOGRAPH-#908E, IRGKangXi=1267.290, RSKangXi=162.17
908F CJK UNIFIED IDEOGRAPH-#908F, IRGKangXi=1267.360, RSKangXi=162.19, Def{patrol; inspect; watch}
9090 CJK UNIFIED IDEOGRAPH-#9090, IRGKangXi=1267.370, RSKangXi=162.19, Def{meandering, winding}
9091 CJK UNIFIED IDEOGRAPH-#9091, IRGKangXi=1267.420, RSKangXi=163.0, Def{area, district, city, state}
9092 CJK UNIFIED IDEOGRAPH-#9092, IRGKangXi=1268.020, RSKangXi=163.2
9093 CJK UNIFIED IDEOGRAPH-#9093, IRGKangXi=1268.031, RSKangXi=163.2, Def{surname}
9094 CJK UNIFIED IDEOGRAPH-#9094, IRGKangXi=1268.181, RSKangXi=163.3
9095 CJK UNIFIED IDEOGRAPH-#9095, IRGKangXi=1268.060, RSKangXi=163.3, Def{former or literary name for Nanning (in Guangxi)}
9096 CJK UNIFIED IDEOGRAPH-#9096, IRGKangXi=1268.070, RSKangXi=163.3
9097 CJK UNIFIED IDEOGRAPH-#9097, IRGKangXi=1268.080, RSKangXi=163.3, Def{an ancient place in the state of Wu}
9098 CJK UNIFIED IDEOGRAPH-#9098, IRGKangXi=1268.090, RSKangXi=163.3, Def{state in Henan province}
9099 CJK UNIFIED IDEOGRAPH-#9099, IRGKangXi=1268.100, RSKangXi=163.3, Def{mountain in Henan province}
909A CJK UNIFIED IDEOGRAPH-#909A, IRGKangXi=1268.120, RSKangXi=163.3
909B CJK UNIFIED IDEOGRAPH-#909B, IRGKangXi=1268.160, RSKangXi=163.3, Def{in distress; a mound}
909C CJK UNIFIED IDEOGRAPH-#909C, IRGKangXi=1268.181, RSKangXi=163.3
909D CJK UNIFIED IDEOGRAPH-#909D, IRGKangXi=1268.181, RSKangXi=163.3, Def{surname}
909E CJK UNIFIED IDEOGRAPH-#909E, IRGKangXi=1268.190, RSKangXi=163.4
909F CJK UNIFIED IDEOGRAPH-#909F, IRGKangXi=1268.200, RSKangXi=163.4
90A0 CJK UNIFIED IDEOGRAPH-#90A0, IRGKangXi=1268.220, RSKangXi=163.4, Def{county in Shaanxi province}
90A1 CJK UNIFIED IDEOGRAPH-#90A1, IRGKangXi=1268.260, RSKangXi=163.4, Def{name of a district in Sichuan}
90A2 CJK UNIFIED IDEOGRAPH-#90A2, IRGKangXi=1268.270, RSKangXi=163.4, Def{surname; state in today's Hebei}
90A3 CJK UNIFIED IDEOGRAPH-#90A3, IRGKangXi=1268.300, RSKangXi=163.4, Def{that, that one, those}
90A4 CJK UNIFIED IDEOGRAPH-#90A4, IRGKangXi=1269.020, RSKangXi=163.4
90A5 CJK UNIFIED IDEOGRAPH-#90A5, IRGKangXi=1269.040, RSKangXi=163.4
90A6 CJK UNIFIED IDEOGRAPH-#90A6, IRGKangXi=1269.050, RSKangXi=163.4, Def{nation, country, state}
90A7 CJK UNIFIED IDEOGRAPH-#90A7, IRGKangXi=1269.090, RSKangXi=163.4, Def{town in Shanxi province}
90A8 CJK UNIFIED IDEOGRAPH-#90A8, IRGKangXi=1269.100, RSKangXi=163.4, Def{village, hamlet; rustic}
90A9 CJK UNIFIED IDEOGRAPH-#90A9, IRGKangXi=1269.110, RSKangXi=163.4
90AA CJK UNIFIED IDEOGRAPH-#90AA, IRGKangXi=1269.140, RSKangXi=163.4, Def{wrong, evil, depraved, vicious, perverse, heterodox}
90AB CJK UNIFIED IDEOGRAPH-#90AB, IRGKangXi=1269.150, RSKangXi=163.4
90AC CJK UNIFIED IDEOGRAPH-#90AC, IRGKangXi=1269.161, RSKangXi=163.4, Def{various place names; surname}
90AD CJK UNIFIED IDEOGRAPH-#90AD, IRGKangXi=1269.180, RSKangXi=163.5
90AE CJK UNIFIED IDEOGRAPH-#90AE, IRGKangXi=1269.200, RSKangXi=163.5, Def{postal, mail; post office}
90AF CJK UNIFIED IDEOGRAPH-#90AF, IRGKangXi=1269.220, RSKangXi=163.5, Def{city in Hebei province; various}
90B0 CJK UNIFIED IDEOGRAPH-#90B0, IRGKangXi=1269.230, RSKangXi=163.5, Def{surname; state in modern Shanxi}
90B1 CJK UNIFIED IDEOGRAPH-#90B1, IRGKangXi=1269.260, RSKangXi=163.5, Def{surname; hill; mound; grave}
90B2 CJK UNIFIED IDEOGRAPH-#90B2, IRGKangXi=1269.290, RSKangXi=163.5, Def{good-looking; name of a place}
90B3 CJK UNIFIED IDEOGRAPH-#90B3, IRGKangXi=1269.300, RSKangXi=163.5, Def{a department in the State of Lu; in what is now Shantung or N. China}
90B4 CJK UNIFIED IDEOGRAPH-#90B4, IRGKangXi=1269.310, RSKangXi=163.5, Def{name of a city in the ancient state of Song, in what is now Shandong; pleased}
90B5 CJK UNIFIED IDEOGRAPH-#90B5, IRGKangXi=1270.020, RSKangXi=163.5, Def{surname; various place names}
90B6 CJK UNIFIED IDEOGRAPH-#90B6, IRGKangXi=1270.030, RSKangXi=163.5, Def{place in today's Henan province}
90B7 CJK UNIFIED IDEOGRAPH-#90B7, IRGKangXi=1270.050, RSKangXi=163.5
90B8 CJK UNIFIED IDEOGRAPH-#90B8, IRGKangXi=1270.060, RSKangXi=163.5, Def{official residence, residence of}
90B9 CJK UNIFIED IDEOGRAPH-#90B9, IRGKangXi=1270.071, RSKangXi=163.5, Def{name of an ancient state; surname}
90BA CJK UNIFIED IDEOGRAPH-#90BA, IRGKangXi=1270.071, RSKangXi=163.5, Def{place in today's Henan province}
90BB CJK UNIFIED IDEOGRAPH-#90BB, IRGKangXi=1270.071, RSKangXi=163.5, Def{neighbor; neighborhood}
90BC CJK UNIFIED IDEOGRAPH-#90BC, IRGKangXi=1270.090, RSKangXi=163.6
90BD CJK UNIFIED IDEOGRAPH-#90BD, IRGKangXi=1270.100, RSKangXi=163.6, Def{name of a county in Han dynasty}
90BE CJK UNIFIED IDEOGRAPH-#90BE, IRGKangXi=1270.140, RSKangXi=163.6, Def{a feudal state which existed B.C.700-469; now in Shandong}
90BF CJK UNIFIED IDEOGRAPH-#90BF, IRGKangXi=1270.150, RSKangXi=163.6, Def{a state in Shandong province}
90C0 CJK UNIFIED IDEOGRAPH-#90C0, IRGKangXi=1270.170, RSKangXi=163.6
90C1 CJK UNIFIED IDEOGRAPH-#90C1, IRGKangXi=1270.190, RSKangXi=163.6, Def{sweet smelling, rich in aroma; (Cant.) to move, hit}
90C2 CJK UNIFIED IDEOGRAPH-#90C2, IRGKangXi=1270.200, RSKangXi=163.6
90C3 CJK UNIFIED IDEOGRAPH-#90C3, IRGKangXi=1270.240, RSKangXi=163.6, Def{county in Shanxi province}
90C4 CJK UNIFIED IDEOGRAPH-#90C4, IRGKangXi=1270.260, RSKangXi=163.6, Def{surname}
90C5 CJK UNIFIED IDEOGRAPH-#90C5, IRGKangXi=1270.270, RSKangXi=163.6, Def{to go up to. flourishing a superlative}
90C6 CJK UNIFIED IDEOGRAPH-#90C6, IRGKangXi=1271.010, RSKangXi=163.6
90C7 CJK UNIFIED IDEOGRAPH-#90C7, IRGKangXi=1271.050, RSKangXi=163.6, Def{an ancient feudal State in Shaanxi}
90C8 CJK UNIFIED IDEOGRAPH-#90C8, IRGKangXi=1271.080, RSKangXi=163.6, Def{place in Shandong province}
90C9 CJK UNIFIED IDEOGRAPH-#90C9, IRGKangXi=1271.090, RSKangXi=163.6, Def{surname; place name}
90CA CJK UNIFIED IDEOGRAPH-#90CA, IRGKangXi=1271.110, RSKangXi=163.6, Def{suburbs; waste land, open spaces}
90CB CJK UNIFIED IDEOGRAPH-#90CB, IRGKangXi=1271.120, RSKangXi=163.6
90CC CJK UNIFIED IDEOGRAPH-#90CC, IRGKangXi=1271.121, RSKangXi=163.6, Def{name of an ancient county in modern Gansu/Shaanxi area.}
90CD CJK UNIFIED IDEOGRAPH-#90CD, IRGKangXi=1271.121, RSKangXi=163.6
90CE CJK UNIFIED IDEOGRAPH-#90CE, IRGKangXi=1271.121, RSKangXi=163.6, Def{gentleman, young man; husband}
90CF CJK UNIFIED IDEOGRAPH-#90CF, IRGKangXi=1271.121, RSKangXi=163.6, Def{county in Henan province; surname}
90D0 CJK UNIFIED IDEOGRAPH-#90D0, IRGKangXi=1271.121, RSKangXi=163.6, Def{state in today's Henan province}
90D1 CJK UNIFIED IDEOGRAPH-#90D1, IRGKangXi=1271.121, RSKangXi=163.6, Def{state in today's Henan; surname}
90D2 CJK UNIFIED IDEOGRAPH-#90D2, IRGKangXi=1271.121, RSKangXi=163.7
90D3 CJK UNIFIED IDEOGRAPH-#90D3, IRGKangXi=1271.121, RSKangXi=163.6, Def{surname; an ancient town's name}
90D4 CJK UNIFIED IDEOGRAPH-#90D4, IRGKangXi=1271.140, RSKangXi=163.7, Def{place name in Shandong province}
90D5 CJK UNIFIED IDEOGRAPH-#90D5, IRGKangXi=1271.150, RSKangXi=163.7, Def{state in Shandong province}
90D6 CJK UNIFIED IDEOGRAPH-#90D6, IRGKangXi=1271.180, RSKangXi=163.7
90D7 CJK UNIFIED IDEOGRAPH-#90D7, IRGKangXi=1271.190, RSKangXi=163.7, Def{city under the Chou Dyn. a surname}
90D8 CJK UNIFIED IDEOGRAPH-#90D8, IRGKangXi=1271.220, RSKangXi=163.7
90D9 CJK UNIFIED IDEOGRAPH-#90D9, IRGKangXi=1271.250, RSKangXi=163.7, Def{to be exiled; delay payment for}
90DA CJK UNIFIED IDEOGRAPH-#90DA, IRGKangXi=1271.260, RSKangXi=163.7, Def{towns in Shandong province}
90DB CJK UNIFIED IDEOGRAPH-#90DB, IRGKangXi=1271.340, RSKangXi=163.7, Def{outer walls of city; suburbs}
90DC CJK UNIFIED IDEOGRAPH-#90DC, IRGKangXi=1271.360, RSKangXi=163.7, Def{name of fief in Shantong bestowed on the eldest son of Wen Wang}
90DD CJK UNIFIED IDEOGRAPH-#90DD, IRGKangXi=1272.010, RSKangXi=163.7, Def{surname; place in modern Shanxi}
90DE CJK UNIFIED IDEOGRAPH-#90DE, IRGKangXi=1272.020, RSKangXi=163.7, Def{gentleman}
90DF CJK UNIFIED IDEOGRAPH-#90DF, IRGKangXi=1272.040, RSKangXi=163.7, Def{county in Henan province; surname}
90E0 CJK UNIFIED IDEOGRAPH-#90E0, IRGKangXi=1272.050, RSKangXi=163.7, Def{place in Shandong province}
90E1 CJK UNIFIED IDEOGRAPH-#90E1, IRGKangXi=1272.070, RSKangXi=163.7, Def{administrative division}
90E2 CJK UNIFIED IDEOGRAPH-#90E2, IRGKangXi=1272.080, RSKangXi=163.7, Def{state in today's Hubei province}
90E3 CJK UNIFIED IDEOGRAPH-#90E3, IRGKangXi=1272.090, RSKangXi=163.7
90E4 CJK UNIFIED IDEOGRAPH-#90E4, IRGKangXi=1272.100, RSKangXi=163.7, Def{crack, opening; surname}
90E5 CJK UNIFIED IDEOGRAPH-#90E5, IRGKangXi=1272.101, RSKangXi=163.7
90E6 CJK UNIFIED IDEOGRAPH-#90E6, IRGKangXi=1272.101, RSKangXi=163.7, Def{place in today's Henan province}
90E7 CJK UNIFIED IDEOGRAPH-#90E7, IRGKangXi=1272.101, RSKangXi=163.7, Def{county in Hubei province}
90E8 CJK UNIFIED IDEOGRAPH-#90E8, IRGKangXi=1272.170, RSKangXi=163.8, Def{part, division, section}
90E9 CJK UNIFIED IDEOGRAPH-#90E9, IRGKangXi=1273.020, RSKangXi=163.8
90EA CJK UNIFIED IDEOGRAPH-#90EA, IRGKangXi=1273.040, RSKangXi=163.8, Def{name of a stream in Sichuan province}
90EB CJK UNIFIED IDEOGRAPH-#90EB, IRGKangXi=1273.090, RSKangXi=163.8
90EC CJK UNIFIED IDEOGRAPH-#90EC, IRGKangXi=1273.110, RSKangXi=163.8
90ED CJK UNIFIED IDEOGRAPH-#90ED, IRGKangXi=1273.130, RSKangXi=163.8, Def{outer part (of a city); surname}
90EE CJK UNIFIED IDEOGRAPH-#90EE, IRGKangXi=1273.150, RSKangXi=163.8
90EF CJK UNIFIED IDEOGRAPH-#90EF, IRGKangXi=1273.160, RSKangXi=163.8, Def{name of a small ancient principality which was situated in what is now part of Shantung and Kiangsu}
90F0 CJK UNIFIED IDEOGRAPH-#90F0, IRGKangXi=1273.170, RSKangXi=163.8, Def{birthplace of Confucius, a place in Shandong}
90F1 CJK UNIFIED IDEOGRAPH-#90F1, IRGKangXi=1273.190, RSKangXi=163.8
90F2 CJK UNIFIED IDEOGRAPH-#90F2, IRGKangXi=1273.200, RSKangXi=163.8
90F3 CJK UNIFIED IDEOGRAPH-#90F3, IRGKangXi=1273.210, RSKangXi=163.8, Def{state in Shandong province}
90F4 CJK UNIFIED IDEOGRAPH-#90F4, IRGKangXi=1273.230, RSKangXi=163.8, Def{county in Hunan province; surname}
90F5 CJK UNIFIED IDEOGRAPH-#90F5, IRGKangXi=1273.240, RSKangXi=163.8, Def{postal, mail; post office}
90F6 CJK UNIFIED IDEOGRAPH-#90F6, IRGKangXi=1273.271, RSKangXi=163.8
90F7 CJK UNIFIED IDEOGRAPH-#90F7, IRGKangXi=1273.271, RSKangXi=163.8, Def{country; rural; village}
90F8 CJK UNIFIED IDEOGRAPH-#90F8, IRGKangXi=1273.271, RSKangXi=163.8, Def{county in Hebei province}
90F9 CJK UNIFIED IDEOGRAPH-#90F9, IRGKangXi=1274.020, RSKangXi=163.9
90FA CJK UNIFIED IDEOGRAPH-#90FA, IRGKangXi=1274.060, RSKangXi=163.9
90FB CJK UNIFIED IDEOGRAPH-#90FB, IRGKangXi=1274.070, RSKangXi=163.9
90FC CJK UNIFIED IDEOGRAPH-#90FC, IRGKangXi=1274.080, RSKangXi=163.9
90FD CJK UNIFIED IDEOGRAPH-#90FD, IRGKangXi=1274.090, RSKangXi=163.9, Def{metropolis, capital; all, the whole; elegant, refined}
90FE CJK UNIFIED IDEOGRAPH-#90FE, IRGKangXi=1274.140, RSKangXi=163.9, Def{county in Henan province}
90FF CJK UNIFIED IDEOGRAPH-#90FF, IRGKangXi=1274.150, RSKangXi=163.9, Def{county in Shaanxi province}
9100 CJK UNIFIED IDEOGRAPH-#9100, IRGKangXi=1274.180, RSKangXi=163.9, Def{state in Henan province}
9101 CJK UNIFIED IDEOGRAPH-#9101, IRGKangXi=1274.200, RSKangXi=163.9
9102 CJK UNIFIED IDEOGRAPH-#9102, IRGKangXi=1274.220, RSKangXi=163.9, Def{Hubei province; startled}
9103 CJK UNIFIED IDEOGRAPH-#9103, IRGKangXi=1274.240, RSKangXi=163.9
9104 CJK UNIFIED IDEOGRAPH-#9104, IRGKangXi=1274.250, RSKangXi=163.9
9105 CJK UNIFIED IDEOGRAPH-#9105, IRGKangXi=1274.270, RSKangXi=163.9
9106 CJK UNIFIED IDEOGRAPH-#9106, IRGKangXi=1274.300, RSKangXi=163.9, Def{surname; an ancient town's name}
9107 CJK UNIFIED IDEOGRAPH-#9107, IRGKangXi=1275.010, RSKangXi=163.9, Def{a name of a town in Henan province}
9108 CJK UNIFIED IDEOGRAPH-#9108, IRGKangXi=1275.020, RSKangXi=163.9, Def{slippers, sandals; dance shoes}
9109 CJK UNIFIED IDEOGRAPH-#9109, IRGKangXi=1275.021, RSKangXi=163.9, Def{country; rural; village}
910A CJK UNIFIED IDEOGRAPH-#910A, IRGKangXi=1275.021, RSKangXi=163.9
910B CJK UNIFIED IDEOGRAPH-#910B, IRGKangXi=1275.100, RSKangXi=163.10, Def{county}
910C CJK UNIFIED IDEOGRAPH-#910C, IRGKangXi=1275.110
910D CJK UNIFIED IDEOGRAPH-#910D, IRGKangXi=1275.130, RSKangXi=163.10, Def{a town in Shandong province}
910E CJK UNIFIED IDEOGRAPH-#910E, IRGKangXi=1275.140, RSKangXi=163.10, Def{a place in Henan province}
910F CJK UNIFIED IDEOGRAPH-#910F, IRGKangXi=1275.170, RSKangXi=163.10, Def{place in Henan province}
9110 CJK UNIFIED IDEOGRAPH-#9110, IRGKangXi=1275.180, RSKangXi=163.10, Def{town in Henan province}
9111 CJK UNIFIED IDEOGRAPH-#9111, IRGKangXi=1275.200, RSKangXi=163.10, Def{kick; place in Shandong province}
9112 CJK UNIFIED IDEOGRAPH-#9112, IRGKangXi=1275.210, RSKangXi=163.10, Def{name of an ancient state; surname}
9113 CJK UNIFIED IDEOGRAPH-#9113, IRGKangXi=1275.260
9114 CJK UNIFIED IDEOGRAPH-#9114, IRGKangXi=1275.280, RSKangXi=163.10, Def{various place names; surname; transliteration of Sanskrit 'u'}
9115 CJK UNIFIED IDEOGRAPH-#9115, IRGKangXi=1275.290, RSKangXi=163.10, Def{country; rural; village}
9116 CJK UNIFIED IDEOGRAPH-#9116, IRGKangXi=1276.010, RSKangXi=163.10, Def{county in Hubei province}
9117 CJK UNIFIED IDEOGRAPH-#9117, IRGKangXi=1276.050, RSKangXi=163.10, Def{county in Hebei province}
9118 CJK UNIFIED IDEOGRAPH-#9118, IRGKangXi=1276.170, RSKangXi=163.11, Def{state in Henan province}
9119 CJK UNIFIED IDEOGRAPH-#9119, IRGKangXi=1276.180, RSKangXi=163.11, Def{mean; low}
911A CJK UNIFIED IDEOGRAPH-#911A, IRGKangXi=1276.210, RSKangXi=163.11, Def{place in today's Hebei province}
911B CJK UNIFIED IDEOGRAPH-#911B, IRGKangXi=1276.230, RSKangXi=163.11
911C CJK UNIFIED IDEOGRAPH-#911C, IRGKangXi=1276.250, RSKangXi=163.11, Def{county in Shanxi province}
911D CJK UNIFIED IDEOGRAPH-#911D, IRGKangXi=1276.260, RSKangXi=163.11
911E CJK UNIFIED IDEOGRAPH-#911E, IRGKangXi=1276.270, RSKangXi=163.11, Def{county in Zhejiang province}
911F CJK UNIFIED IDEOGRAPH-#911F, IRGKangXi=1276.280, RSKangXi=163.11
9120 CJK UNIFIED IDEOGRAPH-#9120, IRGKangXi=1277.020, RSKangXi=163.11, Def{county in Shanxi province}
9121 CJK UNIFIED IDEOGRAPH-#9121, IRGKangXi=1277.030, RSKangXi=163.11
9122 CJK UNIFIED IDEOGRAPH-#9122, IRGKangXi=1277.040, RSKangXi=163.11, Def{name of a district in Honan}
9123 CJK UNIFIED IDEOGRAPH-#9123, IRGKangXi=1277.070, RSKangXi=163.11, Def{name of an ancient city in N. Jiangsu, near Shandong}
9124 CJK UNIFIED IDEOGRAPH-#9124, IRGKangXi=1277.090, RSKangXi=163.11, Def{place in Henan province}
9125 CJK UNIFIED IDEOGRAPH-#9125, IRGKangXi=1277.091, RSKangXi=163.11
9126 CJK UNIFIED IDEOGRAPH-#9126, IRGKangXi=1277.120, RSKangXi=163.12
9127 CJK UNIFIED IDEOGRAPH-#9127, IRGKangXi=1277.130, RSKangXi=163.12, Def{surname}
9128 CJK UNIFIED IDEOGRAPH-#9128, IRGKangXi=1277.150, RSKangXi=163.12
9129 CJK UNIFIED IDEOGRAPH-#9129, IRGKangXi=1277.160, RSKangXi=163.12, Def{county in Shandong province}
912A CJK UNIFIED IDEOGRAPH-#912A, IRGKangXi=1277.180, RSKangXi=163.12
912B CJK UNIFIED IDEOGRAPH-#912B, IRGKangXi=1277.260, RSKangXi=163.12, Def{state in today's Shandong province}
912C CJK UNIFIED IDEOGRAPH-#912C, IRGKangXi=1277.270, RSKangXi=163.12, Def{place in Henan province}
912D CJK UNIFIED IDEOGRAPH-#912D, IRGKangXi=1277.300, RSKangXi=163.12, Def{state in today's Henan; surname}
912E CJK UNIFIED IDEOGRAPH-#912E, IRGKangXi=1278.030, RSKangXi=163.12
912F CJK UNIFIED IDEOGRAPH-#912F, IRGKangXi=1278.070, RSKangXi=163.12, Def{district in Gansu during the Tang dynasty}
9130 CJK UNIFIED IDEOGRAPH-#9130, IRGKangXi=1278.080, RSKangXi=163.12, Def{neighbor; neighborhood}
9131 CJK UNIFIED IDEOGRAPH-#9131, IRGKangXi=1278.100, RSKangXi=163.12, Def{county and lake in Jiangxi}
9132 CJK UNIFIED IDEOGRAPH-#9132, IRGKangXi=1278.110, RSKangXi=163.12, Def{county in Hebei province}
9133 CJK UNIFIED IDEOGRAPH-#9133, IRGKangXi=1278.180, RSKangXi=163.13
9134 CJK UNIFIED IDEOGRAPH-#9134, IRGKangXi=1278.250, RSKangXi=163.13, Def{place in today's honan province}
9135 CJK UNIFIED IDEOGRAPH-#9135, IRGKangXi=1278.260, RSKangXi=163.13
9136 CJK UNIFIED IDEOGRAPH-#9136, IRGKangXi=1278.270, RSKangXi=163.13, Def{state in today's Henan province}
9137 CJK UNIFIED IDEOGRAPH-#9137, IRGKangXi=1278.280, RSKangXi=163.13
9138 CJK UNIFIED IDEOGRAPH-#9138, IRGKangXi=1278.360, RSKangXi=163.14
9139 CJK UNIFIED IDEOGRAPH-#9139, IRGKangXi=1278.370, RSKangXi=163.14, Def{name of a state; surname}
913A CJK UNIFIED IDEOGRAPH-#913A, IRGKangXi=1279.030, RSKangXi=163.15, Def{surname}
913B CJK UNIFIED IDEOGRAPH-#913B, IRGKangXi=1279.050, RSKangXi=163.15, Def{spoil, ruin}
913C CJK UNIFIED IDEOGRAPH-#913C, IRGKangXi=1279.070, RSKangXi=163.15
913D CJK UNIFIED IDEOGRAPH-#913D, IRGKangXi=1279.110, RSKangXi=163.15
913E CJK UNIFIED IDEOGRAPH-#913E, IRGKangXi=1279.150, RSKangXi=163.15, Def{place in Hubei province}
913F CJK UNIFIED IDEOGRAPH-#913F, IRGKangXi=1279.220, RSKangXi=163.16, Def{county in Xinjiang province}
9140 CJK UNIFIED IDEOGRAPH-#9140, IRGKangXi=1279.230, RSKangXi=163.16
9141 CJK UNIFIED IDEOGRAPH-#9141, IRGKangXi=1279.240, RSKangXi=163.17
9142 CJK UNIFIED IDEOGRAPH-#9142, IRGKangXi=1279.251, RSKangXi=163.16, Def{collect; small administration}
9143 CJK UNIFIED IDEOGRAPH-#9143, IRGKangXi=1279.280, RSKangXi=163.17, Def{the spirit of a being, which acts upon others spirit; divine; efficacious}
9144 CJK UNIFIED IDEOGRAPH-#9144, IRGKangXi=1279.290, RSKangXi=163.18
9145 CJK UNIFIED IDEOGRAPH-#9145, IRGKangXi=1279.300, RSKangXi=163.18, Def{raise feet; town in Shandong province}
9146 CJK UNIFIED IDEOGRAPH-#9146, IRGKangXi=1279.310, RSKangXi=163.18, Def{name of Zhou period state}
9147 CJK UNIFIED IDEOGRAPH-#9147, IRGKangXi=1279.330, RSKangXi=163.19, Def{collect; small administration}
9148 CJK UNIFIED IDEOGRAPH-#9148, IRGKangXi=1279.340, RSKangXi=163.19, Def{place in today's Henan province}
9149 CJK UNIFIED IDEOGRAPH-#9149, IRGKangXi=1280.020, RSKangXi=164.0, Def{10th terrestrial branch; a wine vessel}
914A CJK UNIFIED IDEOGRAPH-#914A, IRGKangXi=1280.040, RSKangXi=164.2, Def{drunk, intoxicated}
914B CJK UNIFIED IDEOGRAPH-#914B, IRGKangXi=1280.050, RSKangXi=164.2, Def{chief of tribe, chieftain}
914C CJK UNIFIED IDEOGRAPH-#914C, IRGKangXi=1280.070, RSKangXi=164.3, Def{serve wine; feast; deliberate}
914D CJK UNIFIED IDEOGRAPH-#914D, IRGKangXi=1280.090, RSKangXi=164.3, Def{match, pair; equal; blend}
914E CJK UNIFIED IDEOGRAPH-#914E, IRGKangXi=1280.100, RSKangXi=164.3, Def{double-fermented wine, vintage wine}
914F CJK UNIFIED IDEOGRAPH-#914F, IRGKangXi=1280.110, RSKangXi=164.3, Def{millet wine}
9150 CJK UNIFIED IDEOGRAPH-#9150, IRGKangXi=1281.010, RSKangXi=164.3, Def{anhydride}
9151 CJK UNIFIED IDEOGRAPH-#9151, IRGKangXi=1281.020, RSKangXi=164.3
9152 CJK UNIFIED IDEOGRAPH-#9152, IRGKangXi=1281.030, RSKangXi=164.3, Def{wine, spirits, liquor, alcoholic beverage}
9153 CJK UNIFIED IDEOGRAPH-#9153, IRGKangXi=1281.110, RSKangXi=164.4
9154 CJK UNIFIED IDEOGRAPH-#9154, IRGKangXi=1281.130, RSKangXi=164.4, Def{intoxicated, drunk; addicted to}
9155 CJK UNIFIED IDEOGRAPH-#9155, IRGKangXi=1281.160, RSKangXi=164.4
9156 CJK UNIFIED IDEOGRAPH-#9156, IRGKangXi=1281.180, RSKangXi=164.4, Def{wine with bird poison added}
9157 CJK UNIFIED IDEOGRAPH-#9157, IRGKangXi=1281.190, RSKangXi=164.4, Def{drunk, to become violent under the influence of alcohol}
9158 CJK UNIFIED IDEOGRAPH-#9158, IRGKangXi=1281.220, RSKangXi=164.4
9159 CJK UNIFIED IDEOGRAPH-#9159, IRGKangXi=1281.281, RSKangXi=164.4
915A CJK UNIFIED IDEOGRAPH-#915A, IRGKangXi=1281.281, RSKangXi=164.4, Def{carbolic acid; phenol}
915B CJK UNIFIED IDEOGRAPH-#915B, IRGKangXi=1281.281, RSKangXi=164.4
915C CJK UNIFIED IDEOGRAPH-#915C, IRGKangXi=1281.281, RSKangXi=164.4
915D CJK UNIFIED IDEOGRAPH-#915D, IRGKangXi=1281.281, RSKangXi=164.4, Def{liquor, spirits, wine; ferment}
915E CJK UNIFIED IDEOGRAPH-#915E, IRGKangXi=1281.281, RSKangXi=164.4, Def{phthalein}
915F CJK UNIFIED IDEOGRAPH-#915F, IRGKangXi=1281.340, RSKangXi=164.5
9160 CJK UNIFIED IDEOGRAPH-#9160, IRGKangXi=1281.360, RSKangXi=164.5
9161 CJK UNIFIED IDEOGRAPH-#9161, IRGKangXi=1281.410, RSKangXi=164.5, Def{flushed; rubicund}
9162 CJK UNIFIED IDEOGRAPH-#9162, IRGKangXi=1282.010, RSKangXi=164.5, Def{toast one's host with wine; to express juice by pressing}
9163 CJK UNIFIED IDEOGRAPH-#9163, IRGKangXi=1282.020, RSKangXi=164.5, Def{enjoy intoxicants}
9164 CJK UNIFIED IDEOGRAPH-#9164, IRGKangXi=1282.050, RSKangXi=164.5, Def{to deal in spirits}
9165 CJK UNIFIED IDEOGRAPH-#9165, IRGKangXi=1282.110, RSKangXi=164.5, Def{butter; flaky, crispy, light, fluffy}
9166 CJK UNIFIED IDEOGRAPH-#9166, IRGKangXi=1282.131, RSKangXi=164.6, Def{fermentation, brewing}
9167 CJK UNIFIED IDEOGRAPH-#9167, IRGKangXi=1282.160, RSKangXi=164.6, Def{to pledge with wine}
9168 CJK UNIFIED IDEOGRAPH-#9168, IRGKangXi=1282.170, RSKangXi=164.6
9169 CJK UNIFIED IDEOGRAPH-#9169, IRGKangXi=1282.210, RSKangXi=164.6, Def{drunk; intoxicated; tipsy}
916A CJK UNIFIED IDEOGRAPH-#916A, IRGKangXi=1282.220, RSKangXi=164.6, Def{cream, cheese; koumiss}
916B CJK UNIFIED IDEOGRAPH-#916B, IRGKangXi=1282.240
916C CJK UNIFIED IDEOGRAPH-#916C, IRGKangXi=1282.250, RSKangXi=164.6, Def{toast; reward, recompense}
916D CJK UNIFIED IDEOGRAPH-#916D, IRGKangXi=1282.260, RSKangXi=164.6
916E CJK UNIFIED IDEOGRAPH-#916E, IRGKangXi=1283.010, RSKangXi=164.6, Def{ketones}
916F CJK UNIFIED IDEOGRAPH-#916F, IRGKangXi=1283.051, RSKangXi=164.6, Def{ester}
9170 CJK UNIFIED IDEOGRAPH-#9170, IRGKangXi=1283.051, RSKangXi=164.6, Def{acyl}
9171 CJK UNIFIED IDEOGRAPH-#9171, IRGKangXi=1283.051, RSKangXi=164.6, Def{any jam-like or paste-like food}
9172 CJK UNIFIED IDEOGRAPH-#9172, IRGKangXi=1283.090, RSKangXi=164.7, Def{hangover; uncomfortable}
9173 CJK UNIFIED IDEOGRAPH-#9173, IRGKangXi=1283.100, RSKangXi=164.7
9174 CJK UNIFIED IDEOGRAPH-#9174, IRGKangXi=1283.110, RSKangXi=164.7, Def{leaven, yeast; wine}
9175 CJK UNIFIED IDEOGRAPH-#9175, IRGKangXi=1283.120, RSKangXi=164.7, Def{yeast, leaven}
9176 CJK UNIFIED IDEOGRAPH-#9176, IRGKangXi=1283.130, RSKangXi=164.7, Def{enzymes; (Cant.) soft}
9177 CJK UNIFIED IDEOGRAPH-#9177, IRGKangXi=1283.140, RSKangXi=164.7, Def{strong, stimulating; very}
9178 CJK UNIFIED IDEOGRAPH-#9178, IRGKangXi=1283.150, RSKangXi=164.7, Def{tart, sour; acid; stiff; spoiled}
9179 CJK UNIFIED IDEOGRAPH-#9179, IRGKangXi=1283.170, RSKangXi=164.7, Def{to pour out a libation; to sprinkle}
917A CJK UNIFIED IDEOGRAPH-#917A, IRGKangXi=1283.190, RSKangXi=164.7, Def{drink with others; drink heavily}
917B CJK UNIFIED IDEOGRAPH-#917B, IRGKangXi=1284.010, RSKangXi=164.7
917C CJK UNIFIED IDEOGRAPH-#917C, IRGKangXi=1284.021, RSKangXi=164.7
917D CJK UNIFIED IDEOGRAPH-#917D, IRGKangXi=1284.021, RSKangXi=164.7, Def{thick, strong (beverage)}
917E CJK UNIFIED IDEOGRAPH-#917E, IRGKangXi=1284.021, RSKangXi=164.7, Def{strain}
917F CJK UNIFIED IDEOGRAPH-#917F, IRGKangXi=1284.021, RSKangXi=164.7, Def{brew, ferment}
9180 CJK UNIFIED IDEOGRAPH-#9180, IRGKangXi=1284.040, RSKangXi=164.8
9181 CJK UNIFIED IDEOGRAPH-#9181, IRGKangXi=1284.050, RSKangXi=164.8, Def{a kind of green-colored wine}
9182 CJK UNIFIED IDEOGRAPH-#9182, IRGKangXi=1284.090, RSKangXi=164.8, Def{to remove astringency; to bleach in water}
9183 CJK UNIFIED IDEOGRAPH-#9183, IRGKangXi=1284.130, RSKangXi=164.8, Def{marinate, pickle; salt}
9184 CJK UNIFIED IDEOGRAPH-#9184, IRGKangXi=1285.031, RSKangXi=164.8
9185 CJK UNIFIED IDEOGRAPH-#9185, IRGKangXi=1284.160, RSKangXi=164.8, Def{unstrained spirits}
9186 CJK UNIFIED IDEOGRAPH-#9186, IRGKangXi=1284.170, RSKangXi=164.8, Def{wine cup; muddy wine}
9187 CJK UNIFIED IDEOGRAPH-#9187, IRGKangXi=1284.180, RSKangXi=164.8, Def{rich, good as wine; pure, unmixed}
9188 CJK UNIFIED IDEOGRAPH-#9188, IRGKangXi=1284.210, RSKangXi=164.8
9189 CJK UNIFIED IDEOGRAPH-#9189, IRGKangXi=1284.240, RSKangXi=164.8, Def{intoxicated, drunk; addicted to}
918A CJK UNIFIED IDEOGRAPH-#918A, IRGKangXi=1284.250, RSKangXi=164.8, Def{to pour wine in a libation}
918B CJK UNIFIED IDEOGRAPH-#918B, IRGKangXi=1284.280, RSKangXi=164.8, Def{vinegar; jealousy, envy}
918C CJK UNIFIED IDEOGRAPH-#918C, IRGKangXi=1285.031, RSKangXi=164.8
918D CJK UNIFIED IDEOGRAPH-#918D, IRGKangXi=1285.090, RSKangXi=164.9, Def{essential oil of butter}
918E CJK UNIFIED IDEOGRAPH-#918E, IRGKangXi=1285.110, RSKangXi=164.9
918F CJK UNIFIED IDEOGRAPH-#918F, IRGKangXi=1285.120, RSKangXi=164.9
9190 CJK UNIFIED IDEOGRAPH-#9190, IRGKangXi=1285.150, RSKangXi=164.9, Def{purest cream}
9191 CJK UNIFIED IDEOGRAPH-#9191, IRGKangXi=1285.190, RSKangXi=164.9, Def{to strain spirits}
9192 CJK UNIFIED IDEOGRAPH-#9192, IRGKangXi=1285.200, RSKangXi=164.9, Def{wake up; sober up; startle}
9193 CJK UNIFIED IDEOGRAPH-#9193, IRGKangXi=1285.250, RSKangXi=164.9, Def{salted meat; brine from pickled mince}
9194 CJK UNIFIED IDEOGRAPH-#9194, IRGKangXi=1285.260, RSKangXi=164.9
9195 CJK UNIFIED IDEOGRAPH-#9195, IRGKangXi=1285.320, RSKangXi=164.9
9196 CJK UNIFIED IDEOGRAPH-#9196, IRGKangXi=1285.371, RSKangXi=164.9, Def{liquor}
9197 CJK UNIFIED IDEOGRAPH-#9197, IRGKangXi=1285.371, RSKangXi=164.9, Def{to brew for the second time}
9198 CJK UNIFIED IDEOGRAPH-#9198, IRGKangXi=1285.390, RSKangXi=164.10
9199 CJK UNIFIED IDEOGRAPH-#9199, IRGKangXi=1285.420, RSKangXi=164.10
919A CJK UNIFIED IDEOGRAPH-#919A, IRGKangXi=1285.430, RSKangXi=164.10, Def{ether}
919B CJK UNIFIED IDEOGRAPH-#919B, IRGKangXi=1286.050, RSKangXi=164.10, Def{aldehyde}
919C CJK UNIFIED IDEOGRAPH-#919C, IRGKangXi=1286.090, RSKangXi=164.10, Def{ugly looking, homely; disgraceful}
919D CJK UNIFIED IDEOGRAPH-#919D, IRGKangXi=1286.130, RSKangXi=164.10, Def{white wine}
919E CJK UNIFIED IDEOGRAPH-#919E, IRGKangXi=1286.150, RSKangXi=164.10, Def{liquor, spirits, wine; ferment}
919F CJK UNIFIED IDEOGRAPH-#919F, IRGKangXi=1286.170, RSKangXi=164.10
91A0 CJK UNIFIED IDEOGRAPH-#91A0, IRGKangXi=1286.190, RSKangXi=164.10
91A1 CJK UNIFIED IDEOGRAPH-#91A1, IRGKangXi=1286.200, RSKangXi=164.10, Def{wine press}
91A2 CJK UNIFIED IDEOGRAPH-#91A2, IRGKangXi=1286.210, RSKangXi=164.10, Def{minced pickled meat; mince}
91A3 CJK UNIFIED IDEOGRAPH-#91A3, IRGKangXi=1286.241, RSKangXi=164.10, Def{carbohydrates}
91A4 CJK UNIFIED IDEOGRAPH-#91A4, IRGKangXi=1286.241, RSKangXi=164.10, Def{any jam-like or paste-like food}
91A5 CJK UNIFIED IDEOGRAPH-#91A5, IRGKangXi=1287.030, RSKangXi=164.11
91A6 CJK UNIFIED IDEOGRAPH-#91A6, IRGKangXi=1287.050, RSKangXi=164.11
91A7 CJK UNIFIED IDEOGRAPH-#91A7, IRGKangXi=1287.060, RSKangXi=164.11
91A8 CJK UNIFIED IDEOGRAPH-#91A8, IRGKangXi=1287.080, RSKangXi=164.11, Def{dregs of wine}
91A9 CJK UNIFIED IDEOGRAPH-#91A9, IRGKangXi=1287.100, Def{sediment, dregs; grains from a distillery; disordered, spoilt}
91AA CJK UNIFIED IDEOGRAPH-#91AA, IRGKangXi=1287.110, RSKangXi=164.11, Def{unclear wine, wine with dregs}
91AB CJK UNIFIED IDEOGRAPH-#91AB, IRGKangXi=1287.130, RSKangXi=164.11, Def{cure, heal; doctor, medical}
91AC CJK UNIFIED IDEOGRAPH-#91AC, IRGKangXi=1287.170, RSKangXi=164.11, Def{any jam-like or paste-like food}
91AD CJK UNIFIED IDEOGRAPH-#91AD, IRGKangXi=1287.250, RSKangXi=164.12, Def{molds on liquids; scum}
91AE CJK UNIFIED IDEOGRAPH-#91AE, IRGKangXi=1287.330, RSKangXi=164.12, Def{religious service; Daoist or Buddhist ceremony}
91AF CJK UNIFIED IDEOGRAPH-#91AF, IRGKangXi=1287.370, RSKangXi=164.12, Def{vinegar; pickle; acid}
91B0 CJK UNIFIED IDEOGRAPH-#91B0, IRGKangXi=1288.020, RSKangXi=164.12, Def{bitter taste in wine; rich; full flavoured}
91B1 CJK UNIFIED IDEOGRAPH-#91B1, IRGKangXi=1288.030, RSKangXi=164.12, Def{to brew for the second time}
91B2 CJK UNIFIED IDEOGRAPH-#91B2, IRGKangXi=1288.080, RSKangXi=164.13, Def{strong wine; dense, thick}
91B3 CJK UNIFIED IDEOGRAPH-#91B3, IRGKangXi=1288.090, RSKangXi=164.13
91B4 CJK UNIFIED IDEOGRAPH-#91B4, IRGKangXi=1288.100, RSKangXi=164.13, Def{sweet wine; sweet spring}
91B5 CJK UNIFIED IDEOGRAPH-#91B5, IRGKangXi=1288.120, RSKangXi=164.13, Def{contribute for drinks; pool money}
91B6 CJK UNIFIED IDEOGRAPH-#91B6, IRGKangXi=1288.140, RSKangXi=164.13
91B7 CJK UNIFIED IDEOGRAPH-#91B7, IRGKangXi=1288.150, RSKangXi=164.13
91B8 CJK UNIFIED IDEOGRAPH-#91B8, IRGKangXi=1288.181, RSKangXi=164.13, Def{brew, ferment}
91B9 CJK UNIFIED IDEOGRAPH-#91B9, IRGKangXi=1288.230, RSKangXi=164.14, Def{strong wine}
91BA CJK UNIFIED IDEOGRAPH-#91BA, IRGKangXi=1288.240, RSKangXi=164.14, Def{get drunk, be intoxicated}
91BB CJK UNIFIED IDEOGRAPH-#91BB, IRGKangXi=1288.260, RSKangXi=164.14, Def{to pledge, thank}
91BC CJK UNIFIED IDEOGRAPH-#91BC, IRGKangXi=1289.120, RSKangXi=164.16, Def{offer food and wine one's guests}
91BD CJK UNIFIED IDEOGRAPH-#91BD, IRGKangXi=1289.190, RSKangXi=164.17, Def{kind of wine}
91BE CJK UNIFIED IDEOGRAPH-#91BE, IRGKangXi=1289.210, RSKangXi=164.17
91BF CJK UNIFIED IDEOGRAPH-#91BF, IRGKangXi=1289.220, RSKangXi=164.17
91C0 CJK UNIFIED IDEOGRAPH-#91C0, IRGKangXi=1289.230, RSKangXi=164.17, Def{brew, ferment}
91C1 CJK UNIFIED IDEOGRAPH-#91C1, IRGKangXi=1289.270, RSKangXi=164.18, Def{smear with blood in sacrifice; rift, quarrel}
91C2 CJK UNIFIED IDEOGRAPH-#91C2, IRGKangXi=1289.280, RSKangXi=164.18, Def{drain}
91C3 CJK UNIFIED IDEOGRAPH-#91C3, IRGKangXi=1289.290, RSKangXi=164.19, Def{strain}
91C4 CJK UNIFIED IDEOGRAPH-#91C4, IRGKangXi=1289.300, RSKangXi=164.19, Def{wine brew for the second time}
91C5 CJK UNIFIED IDEOGRAPH-#91C5, IRGKangXi=1289.320, RSKangXi=164.20, Def{thick, strong (beverage)}
91C6 CJK UNIFIED IDEOGRAPH-#91C6, IRGKangXi=1290.040, RSKangXi=165.0, Def{distinguish; KangXi radical 165}
91C7 CJK UNIFIED IDEOGRAPH-#91C7, IRGKangXi=1290.060, RSKangXi=165.1, Def{collect, gather; pick, pluck}
91C8 CJK UNIFIED IDEOGRAPH-#91C8, IRGKangXi=1290.091, RSKangXi=165.4, Def{interprete, elucidate; release}
91C9 CJK UNIFIED IDEOGRAPH-#91C9, IRGKangXi=1290.100, RSKangXi=165.5, Def{glaze}
91CA CJK UNIFIED IDEOGRAPH-#91CA, IRGKangXi=1290.101, RSKangXi=165.5, Def{interprete, elucidate; release}
91CB CJK UNIFIED IDEOGRAPH-#91CB, IRGKangXi=1290.170, RSKangXi=165.13, Def{interprete, elucidate; release}
91CC CJK UNIFIED IDEOGRAPH-#91CC, IRGKangXi=1291.020, RSKangXi=166.0, Def{unit of distance; village; lane}
91CD CJK UNIFIED IDEOGRAPH-#91CD, IRGKangXi=1291.030, RSKangXi=166.2, Def{heavy, weighty; double}
91CE CJK UNIFIED IDEOGRAPH-#91CE, IRGKangXi=1291.050, RSKangXi=166.4, Def{open country, field; wilderness}
91CF CJK UNIFIED IDEOGRAPH-#91CF, IRGKangXi=1292.050, RSKangXi=166.5, Def{measure, quantity, capacity}
91D0 CJK UNIFIED IDEOGRAPH-#91D0, IRGKangXi=1292.100, RSKangXi=166.11, Def{manage, control; 1/1000 of a foot}
91D1 CJK UNIFIED IDEOGRAPH-#91D1, IRGKangXi=1295.010, RSKangXi=167.0, Def{gold; metals in general; money}
91D2 CJK UNIFIED IDEOGRAPH-#91D2, IRGKangXi=1295.011, RSKangXi=167.0, Def{KangXi radical 167}
91D3 CJK UNIFIED IDEOGRAPH-#91D3, IRGKangXi=1295.040, RSKangXi=167.1, Def{gadolinium}
91D4 CJK UNIFIED IDEOGRAPH-#91D4, IRGKangXi=1295.041, RSKangXi=167.1, Def{yttrium}
91D5 CJK UNIFIED IDEOGRAPH-#91D5, IRGKangXi=1295.060, RSKangXi=167.2, Def{ruthenium}
91D6 CJK UNIFIED IDEOGRAPH-#91D6, IRGKangXi=1296.010, RSKangXi=167.2, Def{knife, sword}
91D7 CJK UNIFIED IDEOGRAPH-#91D7, IRGKangXi=1296.020, RSKangXi=167.2, Def{endeavor, strive; encourage; cut}
91D8 CJK UNIFIED IDEOGRAPH-#91D8, IRGKangXi=1296.030, RSKangXi=167.2, Def{nail, spike; pursue closely}
91D9 CJK UNIFIED IDEOGRAPH-#91D9, IRGKangXi=1296.040, RSKangXi=167.2, Def{polonium}
91DA CJK UNIFIED IDEOGRAPH-#91DA, IRGKangXi=1296.050, RSKangXi=167.2
91DB CJK UNIFIED IDEOGRAPH-#91DB, IRGKangXi=1296.070, RSKangXi=167.2
91DC CJK UNIFIED IDEOGRAPH-#91DC, IRGKangXi=1296.080, RSKangXi=167.2, Def{cauldron, pot, kettle}
91DD CJK UNIFIED IDEOGRAPH-#91DD, IRGKangXi=1296.090, RSKangXi=167.2, Def{needle; pin; tack; acupuncture}
91DE CJK UNIFIED IDEOGRAPH-#91DE, IRGKangXi=1296.100, RSKangXi=167.2
91DF CJK UNIFIED IDEOGRAPH-#91DF, IRGKangXi=1296.110, RSKangXi=167.2
91E0 CJK UNIFIED IDEOGRAPH-#91E0, IRGKangXi=1296.121, RSKangXi=167.2
91E1 CJK UNIFIED IDEOGRAPH-#91E1, IRGKangXi=1296.121, RSKangXi=167.2, Def{cauldron, pot, kettle}
91E2 CJK UNIFIED IDEOGRAPH-#91E2, IRGKangXi=1296.121, RSKangXi=167.2
91E3 CJK UNIFIED IDEOGRAPH-#91E3, IRGKangXi=1296.130, RSKangXi=167.3, Def{fish; fishhook; tempt, lure}
91E4 CJK UNIFIED IDEOGRAPH-#91E4, IRGKangXi=1296.140, RSKangXi=167.3, Def{samarium}
91E5 CJK UNIFIED IDEOGRAPH-#91E5, IRGKangXi=1296.150, RSKangXi=167.3
91E6 CJK UNIFIED IDEOGRAPH-#91E6, IRGKangXi=1296.160, RSKangXi=167.3, Def{button; buckle, clasp; engrave}
91E7 CJK UNIFIED IDEOGRAPH-#91E7, IRGKangXi=1296.170, RSKangXi=167.3, Def{bracelet, armlet}
91E8 CJK UNIFIED IDEOGRAPH-#91E8, IRGKangXi=1296.190, RSKangXi=167.3
91E9 CJK UNIFIED IDEOGRAPH-#91E9, IRGKangXi=1296.200, RSKangXi=167.3, Def{vanadium}
91EA CJK UNIFIED IDEOGRAPH-#91EA, IRGKangXi=1296.210, RSKangXi=167.3, Def{an alms bowl; a small bell}
91EB CJK UNIFIED IDEOGRAPH-#91EB, IRGKangXi=1297.010, RSKangXi=167.3
91EC CJK UNIFIED IDEOGRAPH-#91EC, IRGKangXi=1297.020, RSKangXi=167.3, Def{solder}
91ED CJK UNIFIED IDEOGRAPH-#91ED, IRGKangXi=1297.030, RSKangXi=167.3, Def{tire of wheel; band}
91EE CJK UNIFIED IDEOGRAPH-#91EE, IRGKangXi=1297.040, RSKangXi=167.3
91EF CJK UNIFIED IDEOGRAPH-#91EF, IRGKangXi=1297.050, RSKangXi=167.3, Def{point of sword; sharp point}
91F0 CJK UNIFIED IDEOGRAPH-#91F0, IRGKangXi=1297.060, RSKangXi=167.3
91F1 CJK UNIFIED IDEOGRAPH-#91F1, IRGKangXi=1297.070, RSKangXi=167.3, Def{fetters; to fetter}
91F2 CJK UNIFIED IDEOGRAPH-#91F2, IRGKangXi=1297.080, RSKangXi=167.3
91F3 CJK UNIFIED IDEOGRAPH-#91F3, IRGKangXi=1297.090, RSKangXi=167.3
91F4 CJK UNIFIED IDEOGRAPH-#91F4, IRGKangXi=1297.100, RSKangXi=167.3
91F5 CJK UNIFIED IDEOGRAPH-#91F5, IRGKangXi=1297.110, RSKangXi=167.3, Def{ornamental hairpin}
91F6 CJK UNIFIED IDEOGRAPH-#91F6, IRGKangXi=1297.120, RSKangXi=167.3
91F7 CJK UNIFIED IDEOGRAPH-#91F7, IRGKangXi=1297.141, RSKangXi=167.3, Def{thorium}
91F8 CJK UNIFIED IDEOGRAPH-#91F8, IRGKangXi=1297.141, RSKangXi=167.3
91F9 CJK UNIFIED IDEOGRAPH-#91F9, IRGKangXi=1297.141, RSKangXi=167.3, Def{neodymium}
91FA CJK UNIFIED IDEOGRAPH-#91FA, IRGKangXi=1297.141, RSKangXi=167.3, Def{tool for boring holes}
91FB CJK UNIFIED IDEOGRAPH-#91FB, IRGKangXi=1297.141, RSKangXi=167.3
91FC CJK UNIFIED IDEOGRAPH-#91FC, IRGKangXi=1297.141, RSKangXi=167.3, Def{sword, dagger, saber}
91FD CJK UNIFIED IDEOGRAPH-#91FD, IRGKangXi=1297.150, RSKangXi=167.4, Def{a farmer's hoeing fork}
91FE CJK UNIFIED IDEOGRAPH-#91FE, IRGKangXi=1297.160, RSKangXi=167.4
91FF CJK UNIFIED IDEOGRAPH-#91FF, IRGKangXi=1297.180, RSKangXi=167.4
9200 CJK UNIFIED IDEOGRAPH-#9200, IRGKangXi=1297.190, RSKangXi=167.4, Def{palladium}
9201 CJK UNIFIED IDEOGRAPH-#9201, IRGKangXi=1297.200, RSKangXi=167.4, Def{francium}
9202 CJK UNIFIED IDEOGRAPH-#9202, IRGKangXi=1297.210, RSKangXi=167.4
9203 CJK UNIFIED IDEOGRAPH-#9203, IRGKangXi=1298.010, RSKangXi=167.4, Def{ancient wine vessel}
9204 CJK UNIFIED IDEOGRAPH-#9204, IRGKangXi=1298.020, RSKangXi=167.4, Def{a wine flagon}
9205 CJK UNIFIED IDEOGRAPH-#9205, IRGKangXi=1298.040, RSKangXi=167.4
9206 CJK UNIFIED IDEOGRAPH-#9206, IRGKangXi=1298.050, RSKangXi=167.4, Def{lead}
9207 CJK UNIFIED IDEOGRAPH-#9207, IRGKangXi=1298.070, RSKangXi=167.4, Def{an ax; a hatchet}
9208 CJK UNIFIED IDEOGRAPH-#9208, IRGKangXi=1298.080, RSKangXi=167.4, Def{plutonium}
9209 CJK UNIFIED IDEOGRAPH-#9209, IRGKangXi=1298.090, RSKangXi=167.4, Def{sodium, natrium; sharpen wood}
920A CJK UNIFIED IDEOGRAPH-#920A, IRGKangXi=1298.100, RSKangXi=167.4, Def{cadolinium}
920B CJK UNIFIED IDEOGRAPH-#920B, IRGKangXi=1298.110, RSKangXi=167.4
920C CJK UNIFIED IDEOGRAPH-#920C, IRGKangXi=1298.120, RSKangXi=167.4, Def{to pierce, to stab; to take}
920D CJK UNIFIED IDEOGRAPH-#920D, IRGKangXi=1298.130, RSKangXi=167.4, Def{blunt, obtuse; dull; flat; dull-witted}
920E CJK UNIFIED IDEOGRAPH-#920E, IRGKangXi=1298.140, RSKangXi=167.4, Def{hook, barb; sickle; stroke with}
920F CJK UNIFIED IDEOGRAPH-#920F, IRGKangXi=1298.160, RSKangXi=167.4
9210 CJK UNIFIED IDEOGRAPH-#9210, IRGKangXi=1298.170, RSKangXi=167.4, Def{lock, latch; stamp, seal}
9211 CJK UNIFIED IDEOGRAPH-#9211, IRGKangXi=1298.190, RSKangXi=167.4, Def{plate}
9212 CJK UNIFIED IDEOGRAPH-#9212, IRGKangXi=1298.200, RSKangXi=167.4, Def{spear; (Cant.) to cut, slice; grass-shears}
9213 CJK UNIFIED IDEOGRAPH-#9213, IRGKangXi=1298.210, RSKangXi=167.4
9214 CJK UNIFIED IDEOGRAPH-#9214, IRGKangXi=1298.220, RSKangXi=167.4, Def{paper money, bank notes; copy}
9215 CJK UNIFIED IDEOGRAPH-#9215, IRGKangXi=1298.230, RSKangXi=167.4, Def{button, knob; surname}
9216 CJK UNIFIED IDEOGRAPH-#9216, IRGKangXi=1299.010, RSKangXi=167.4
9217 CJK UNIFIED IDEOGRAPH-#9217, IRGKangXi=1299.020, RSKangXi=167.4
9218 CJK UNIFIED IDEOGRAPH-#9218, IRGKangXi=1299.040, RSKangXi=167.4
9219 CJK UNIFIED IDEOGRAPH-#9219, IRGKangXi=1299.050, RSKangXi=167.4
921A CJK UNIFIED IDEOGRAPH-#921A, IRGKangXi=1299.060, RSKangXi=167.4
921B CJK UNIFIED IDEOGRAPH-#921B, IRGKangXi=1299.070, RSKangXi=167.4
921C CJK UNIFIED IDEOGRAPH-#921C, IRGKangXi=1299.080, RSKangXi=167.4
921D CJK UNIFIED IDEOGRAPH-#921D, IRGKangXi=1299.090, RSKangXi=167.4
921E CJK UNIFIED IDEOGRAPH-#921E, IRGKangXi=1299.100, RSKangXi=167.4, Def{unit of measure equivalent to thirty catties}
921F CJK UNIFIED IDEOGRAPH-#921F, IRGKangXi=1299.120, RSKangXi=167.4
9220 CJK UNIFIED IDEOGRAPH-#9220, IRGKangXi=1299.180, RSKangXi=167.4
9221 CJK UNIFIED IDEOGRAPH-#9221, IRGKangXi=1299.191, RSKangXi=167.4
9222 CJK UNIFIED IDEOGRAPH-#9222, IRGKangXi=1299.191, RSKangXi=167.4
9223 CJK UNIFIED IDEOGRAPH-#9223, IRGKangXi=1299.191, RSKangXi=167.4, Def{calcium}
9224 CJK UNIFIED IDEOGRAPH-#9224, IRGKangXi=1299.191, RSKangXi=167.4
9225 CJK UNIFIED IDEOGRAPH-#9225, IRGKangXi=1299.191, RSKangXi=167.4, Def{holmium}
9226 CJK UNIFIED IDEOGRAPH-#9226, IRGKangXi=1299.191, RSKangXi=167.4, Def{titanium}
9227 CJK UNIFIED IDEOGRAPH-#9227, IRGKangXi=1299.191, RSKangXi=167.4, Def{scandium}
9228 CJK UNIFIED IDEOGRAPH-#9228, IRGKangXi=1299.191, RSKangXi=167.4
9229 CJK UNIFIED IDEOGRAPH-#9229, IRGKangXi=1299.191, RSKangXi=167.4, Def{fireplace, stove, oven, furnace}
922A CJK UNIFIED IDEOGRAPH-#922A, IRGKangXi=1299.191, RSKangXi=167.4, Def{(Cant.) bracelet; bangle}
922B CJK UNIFIED IDEOGRAPH-#922B, IRGKangXi=1299.191, RSKangXi=167.4
922C CJK UNIFIED IDEOGRAPH-#922C, IRGKangXi=1299.191, RSKangXi=167.4, Def{bell; surname}
922D CJK UNIFIED IDEOGRAPH-#922D, IRGKangXi=1299.200, RSKangXi=167.5
922E CJK UNIFIED IDEOGRAPH-#922E, IRGKangXi=1299.210, RSKangXi=167.5, Def{niobium}
922F CJK UNIFIED IDEOGRAPH-#922F, IRGKangXi=1299.220, RSKangXi=167.5
9230 CJK UNIFIED IDEOGRAPH-#9230, IRGKangXi=1299.230, RSKangXi=167.5, Def{cerium}
9231 CJK UNIFIED IDEOGRAPH-#9231, IRGKangXi=1299.240, RSKangXi=167.5
9232 CJK UNIFIED IDEOGRAPH-#9232, IRGKangXi=1299.250, RSKangXi=167.5
9233 CJK UNIFIED IDEOGRAPH-#9233, IRGKangXi=1299.270, RSKangXi=167.5, Def{a small cauldron; columbium (an older name for niobium)}
9234 CJK UNIFIED IDEOGRAPH-#9234, IRGKangXi=1299.280, RSKangXi=167.5, Def{bell}
9235 CJK UNIFIED IDEOGRAPH-#9235, IRGKangXi=1299.290, RSKangXi=167.5
9236 CJK UNIFIED IDEOGRAPH-#9236, IRGKangXi=1299.300, RSKangXi=167.5
9237 CJK UNIFIED IDEOGRAPH-#9237, IRGKangXi=1299.310, RSKangXi=167.5, Def{cobalt; household iron cobaltum}
9238 CJK UNIFIED IDEOGRAPH-#9238, IRGKangXi=1299.320, RSKangXi=167.5, Def{cymbals}
9239 CJK UNIFIED IDEOGRAPH-#9239, IRGKangXi=1300.010, RSKangXi=167.5, Def{a needle used in Chinese medicine; a sword, large knife; beryllium}
923A CJK UNIFIED IDEOGRAPH-#923A, IRGKangXi=1300.020, RSKangXi=167.5, Def{rare treasure}
923B CJK UNIFIED IDEOGRAPH-#923B, IRGKangXi=1300.040, RSKangXi=167.5
923C CJK UNIFIED IDEOGRAPH-#923C, IRGKangXi=1300.050, RSKangXi=167.5
923D CJK UNIFIED IDEOGRAPH-#923D, IRGKangXi=1300.060, RSKangXi=167.5, Def{plutonium}
923E CJK UNIFIED IDEOGRAPH-#923E, IRGKangXi=1300.070, RSKangXi=167.5, Def{uranium}
923F CJK UNIFIED IDEOGRAPH-#923F, IRGKangXi=1300.080, RSKangXi=167.5, Def{hairpin; gold inlaid work, filigree}
9240 CJK UNIFIED IDEOGRAPH-#9240, IRGKangXi=1300.090, RSKangXi=167.5, Def{potassium kalium}
9241 CJK UNIFIED IDEOGRAPH-#9241, IRGKangXi=1300.110, RSKangXi=167.5
9242 CJK UNIFIED IDEOGRAPH-#9242, IRGKangXi=1300.120, RSKangXi=167.5
9243 CJK UNIFIED IDEOGRAPH-#9243, IRGKangXi=1300.130, RSKangXi=167.5
9244 CJK UNIFIED IDEOGRAPH-#9244, IRGKangXi=1300.140, RSKangXi=167.5, Def{iron; strong, solid, firm}
9245 CJK UNIFIED IDEOGRAPH-#9245, IRGKangXi=1300.150, RSKangXi=167.5, Def{steel, iron; great}
9246 CJK UNIFIED IDEOGRAPH-#9246, IRGKangXi=1300.160, RSKangXi=167.5, Def{tweezers}
9247 CJK UNIFIED IDEOGRAPH-#9247, IRGKangXi=1300.170, RSKangXi=167.5
9248 CJK UNIFIED IDEOGRAPH-#9248, IRGKangXi=1300.180, RSKangXi=167.5, Def{a short spear; thallium}
9249 CJK UNIFIED IDEOGRAPH-#9249, IRGKangXi=1300.190, RSKangXi=167.5, Def{device for carrying a tripod}
924A CJK UNIFIED IDEOGRAPH-#924A, IRGKangXi=1300.200, RSKangXi=167.5
924B CJK UNIFIED IDEOGRAPH-#924B, IRGKangXi=1300.210, RSKangXi=167.5, Def{carpenter's plane}
924C CJK UNIFIED IDEOGRAPH-#924C, IRGKangXi=1301.020, RSKangXi=167.5, Def{the bells on the cart in ancient China}
924D CJK UNIFIED IDEOGRAPH-#924D, IRGKangXi=1301.030, RSKangXi=167.5, Def{bismuth}
924E CJK UNIFIED IDEOGRAPH-#924E, IRGKangXi=1301.040, RSKangXi=167.5, Def{(Cant.) to rust}
924F CJK UNIFIED IDEOGRAPH-#924F, IRGKangXi=1301.050, RSKangXi=167.5, Def{hoe; eradicate, eliminate}
9250 CJK UNIFIED IDEOGRAPH-#9250, IRGKangXi=1301.060, RSKangXi=167.5
9251 CJK UNIFIED IDEOGRAPH-#9251, IRGKangXi=1301.070, RSKangXi=167.5, Def{platinum; thin sheet of metal}
9252 CJK UNIFIED IDEOGRAPH-#9252, IRGKangXi=1301.080, RSKangXi=167.5
9253 CJK UNIFIED IDEOGRAPH-#9253, IRGKangXi=1301.090, RSKangXi=167.5
9254 CJK UNIFIED IDEOGRAPH-#9254, IRGKangXi=1301.100, RSKangXi=167.5
9255 CJK UNIFIED IDEOGRAPH-#9255, IRGKangXi=1301.110, RSKangXi=167.5, Def{promethium bronze}
9256 CJK UNIFIED IDEOGRAPH-#9256, IRGKangXi=1301.120, RSKangXi=167.5
9257 CJK UNIFIED IDEOGRAPH-#9257, IRGKangXi=1301.140, RSKangXi=167.5, Def{pincers, pliers, tongs}
9258 CJK UNIFIED IDEOGRAPH-#9258, IRGKangXi=1301.150, RSKangXi=167.5
9259 CJK UNIFIED IDEOGRAPH-#9259, IRGKangXi=1301.160, RSKangXi=167.5
925A CJK UNIFIED IDEOGRAPH-#925A, IRGKangXi=1301.170, RSKangXi=167.5, Def{rivet}
925B CJK UNIFIED IDEOGRAPH-#925B, IRGKangXi=1301.180, RSKangXi=167.5, Def{lead plumbum}
925C CJK UNIFIED IDEOGRAPH-#925C, IRGKangXi=1301.190, RSKangXi=167.5
925D CJK UNIFIED IDEOGRAPH-#925D, IRGKangXi=1302.010, RSKangXi=167.5
925E CJK UNIFIED IDEOGRAPH-#925E, IRGKangXi=1302.020, RSKangXi=167.5, Def{broad-axe, a battle axe, halberd}
925F CJK UNIFIED IDEOGRAPH-#925F, IRGKangXi=1302.030, RSKangXi=167.5
9260 CJK UNIFIED IDEOGRAPH-#9260, IRGKangXi=1302.040, RSKangXi=167.5
9261 CJK UNIFIED IDEOGRAPH-#9261, IRGKangXi=1302.050, RSKangXi=167.5
9262 CJK UNIFIED IDEOGRAPH-#9262, IRGKangXi=1302.060, RSKangXi=167.5, Def{earthenware basin; alms bowl (Sanskrit paatra)}
9263 CJK UNIFIED IDEOGRAPH-#9263, IRGKangXi=1302.070, RSKangXi=167.5
9264 CJK UNIFIED IDEOGRAPH-#9264, IRGKangXi=1302.080, RSKangXi=167.5, Def{hook, barb; sickle; stroke with}
9265 CJK UNIFIED IDEOGRAPH-#9265, IRGKangXi=1303.010, RSKangXi=167.5, Def{needle}
9266 CJK UNIFIED IDEOGRAPH-#9266, IRGKangXi=1303.030, RSKangXi=167.5, Def{kind of gong used in ancient times by troops on the march}
9267 CJK UNIFIED IDEOGRAPH-#9267, IRGKangXi=1303.040, RSKangXi=167.5
9268 CJK UNIFIED IDEOGRAPH-#9268, IRGKangXi=1303.050, RSKangXi=167.5
9269 CJK UNIFIED IDEOGRAPH-#9269, IRGKangXi=1303.090, RSKangXi=167.5
926A CJK UNIFIED IDEOGRAPH-#926A, IRGKangXi=1303.100, RSKangXi=167.5
926B CJK UNIFIED IDEOGRAPH-#926B, IRGKangXi=1303.101, RSKangXi=167.5
926C CJK UNIFIED IDEOGRAPH-#926C, IRGKangXi=1303.101, RSKangXi=167.5, Def{molybdenum}
926D CJK UNIFIED IDEOGRAPH-#926D, IRGKangXi=1303.101, RSKangXi=167.5, Def{tantalum}
926E CJK UNIFIED IDEOGRAPH-#926E, IRGKangXi=1303.101, RSKangXi=167.5
926F CJK UNIFIED IDEOGRAPH-#926F, IRGKangXi=1303.101, RSKangXi=167.5
9270 CJK UNIFIED IDEOGRAPH-#9270, IRGKangXi=1303.101, RSKangXi=167.5
9271 CJK UNIFIED IDEOGRAPH-#9271, IRGKangXi=1303.101, RSKangXi=167.5, Def{mine; mineral, ore}
9272 CJK UNIFIED IDEOGRAPH-#9272, IRGKangXi=1303.101, RSKangXi=167.5, Def{cadmium}
9273 CJK UNIFIED IDEOGRAPH-#9273, IRGKangXi=1303.101
9274 CJK UNIFIED IDEOGRAPH-#9274, IRGKangXi=1303.101, RSKangXi=167.5, Def{mirror, looking glass; reflect}
9275 CJK UNIFIED IDEOGRAPH-#9275, IRGKangXi=1303.120, RSKangXi=167.6
9276 CJK UNIFIED IDEOGRAPH-#9276, IRGKangXi=1303.130, RSKangXi=167.6, Def{sacrificial cauldron}
9277 CJK UNIFIED IDEOGRAPH-#9277, IRGKangXi=1303.150, RSKangXi=167.6, Def{trigger}
9278 CJK UNIFIED IDEOGRAPH-#9278, IRGKangXi=1303.160, RSKangXi=167.6, Def{hinge; shears, scissors}
9279 CJK UNIFIED IDEOGRAPH-#9279, IRGKangXi=1303.180, RSKangXi=167.6
927A CJK UNIFIED IDEOGRAPH-#927A, IRGKangXi=1303.190, RSKangXi=167.6, Def{erbium}
927B CJK UNIFIED IDEOGRAPH-#927B, IRGKangXi=1303.200, RSKangXi=167.6, Def{chromium}
927C CJK UNIFIED IDEOGRAPH-#927C, IRGKangXi=1303.210, RSKangXi=167.8, Def{plate; (Cant.) a penny}
927D CJK UNIFIED IDEOGRAPH-#927D, IRGKangXi=1303.220, RSKangXi=167.6
927E CJK UNIFIED IDEOGRAPH-#927E, IRGKangXi=1303.230, RSKangXi=167.6, Def{spear}
927F CJK UNIFIED IDEOGRAPH-#927F, IRGKangXi=1303.240, RSKangXi=167.6, Def{hafnium}
9280 CJK UNIFIED IDEOGRAPH-#9280, IRGKangXi=1303.250, RSKangXi=167.6, Def{silver; cash, money, wealth}
9281 CJK UNIFIED IDEOGRAPH-#9281, IRGKangXi=1304.010, RSKangXi=167.6, Def{a weight of thirty catties}
9282 CJK UNIFIED IDEOGRAPH-#9282, IRGKangXi=1304.020, RSKangXi=167.6
9283 CJK UNIFIED IDEOGRAPH-#9283, IRGKangXi=1304.030, RSKangXi=167.6, Def{ancient weapon, blunderbuss}
9284 CJK UNIFIED IDEOGRAPH-#9284, IRGKangXi=1304.040, RSKangXi=167.6
9285 CJK UNIFIED IDEOGRAPH-#9285, IRGKangXi=1304.050, RSKangXi=167.6, Def{copper, brass, bronze cuprum}
9286 CJK UNIFIED IDEOGRAPH-#9286, IRGKangXi=1304.060, RSKangXi=167.6
9287 CJK UNIFIED IDEOGRAPH-#9287, IRGKangXi=1304.080, RSKangXi=167.6
9288 CJK UNIFIED IDEOGRAPH-#9288, IRGKangXi=1304.090, RSKangXi=167.6
9289 CJK UNIFIED IDEOGRAPH-#9289, IRGKangXi=1304.100, RSKangXi=167.6
928A CJK UNIFIED IDEOGRAPH-#928A, IRGKangXi=1304.110, RSKangXi=167.6
928B CJK UNIFIED IDEOGRAPH-#928B, IRGKangXi=1304.120, RSKangXi=167.6
928C CJK UNIFIED IDEOGRAPH-#928C, IRGKangXi=1304.130, RSKangXi=167.6
928D CJK UNIFIED IDEOGRAPH-#928D, IRGKangXi=1304.150, RSKangXi=167.6, Def{a sickle}
928E CJK UNIFIED IDEOGRAPH-#928E, IRGKangXi=1304.160, RSKangXi=167.6, Def{eyehole to hang an axe by}
928F CJK UNIFIED IDEOGRAPH-#928F, IRGKangXi=1304.170, RSKangXi=167.5
9290 CJK UNIFIED IDEOGRAPH-#9290, IRGKangXi=1304.180, RSKangXi=167.6
9291 CJK UNIFIED IDEOGRAPH-#9291, IRGKangXi=1304.190, RSKangXi=167.6, Def{mill}
9292 CJK UNIFIED IDEOGRAPH-#9292, IRGKangXi=1304.200, RSKangXi=167.6
9293 CJK UNIFIED IDEOGRAPH-#9293, IRGKangXi=1304.210, RSKangXi=167.6, Def{weigh, measure; select officials}
9294 CJK UNIFIED IDEOGRAPH-#9294, IRGKangXi=1305.030, RSKangXi=167.6
9295 CJK UNIFIED IDEOGRAPH-#9295, IRGKangXi=1305.040, RSKangXi=167.6, Def{iron; strong, solid, firm}
9296 CJK UNIFIED IDEOGRAPH-#9296, IRGKangXi=1305.050, RSKangXi=167.6, Def{unit of weight, one twenty-fourth of a Chinese ounce (liang)}
9297 CJK UNIFIED IDEOGRAPH-#9297, IRGKangXi=1305.060, RSKangXi=167.6
9298 CJK UNIFIED IDEOGRAPH-#9298, IRGKangXi=1305.070, RSKangXi=167.6, Def{inscribe, engrave; unforgettably}
9299 CJK UNIFIED IDEOGRAPH-#9299, IRGKangXi=1305.080, RSKangXi=167.6
929A CJK UNIFIED IDEOGRAPH-#929A, IRGKangXi=1305.090, RSKangXi=167.6, Def{large hoe; surname; a spear brevium}
929B CJK UNIFIED IDEOGRAPH-#929B, IRGKangXi=1305.110, RSKangXi=167.6, Def{sharp, keen-edged; a kind of hoe}
929C CJK UNIFIED IDEOGRAPH-#929C, IRGKangXi=1305.120, RSKangXi=167.6, Def{bit; hold in mouth, bite; gag}
929D CJK UNIFIED IDEOGRAPH-#929D, IRGKangXi=1305.130, RSKangXi=167.6
929E CJK UNIFIED IDEOGRAPH-#929E, IRGKangXi=1305.140, RSKangXi=167.6
929F CJK UNIFIED IDEOGRAPH-#929F, IRGKangXi=1305.150, RSKangXi=167.6
92A0 CJK UNIFIED IDEOGRAPH-#92A0, IRGKangXi=1305.170, RSKangXi=167.6, Def{rhodium ruthenium}
92A1 CJK UNIFIED IDEOGRAPH-#92A1, IRGKangXi=1305.210, RSKangXi=167.6
92A2 CJK UNIFIED IDEOGRAPH-#92A2, IRGKangXi=1305.211, RSKangXi=167.6
92A3 CJK UNIFIED IDEOGRAPH-#92A3, IRGKangXi=1305.211, RSKangXi=167.6, Def{rubidium}
92A4 CJK UNIFIED IDEOGRAPH-#92A4, IRGKangXi=1305.211, RSKangXi=167.6
92A5 CJK UNIFIED IDEOGRAPH-#92A5, IRGKangXi=1305.211, RSKangXi=167.6, Def{iridium}
92A6 CJK UNIFIED IDEOGRAPH-#92A6, IRGKangXi=1305.211, RSKangXi=167.6, Def{indium}
92A7 CJK UNIFIED IDEOGRAPH-#92A7, IRGKangXi=1305.211, RSKangXi=167.6, Def{point of a sword}
92A8 CJK UNIFIED IDEOGRAPH-#92A8, IRGKangXi=1305.211, RSKangXi=167.6, Def{ammonium}
92A9 CJK UNIFIED IDEOGRAPH-#92A9, IRGKangXi=1305.211, RSKangXi=167.6, Def{thulium}
92AA CJK UNIFIED IDEOGRAPH-#92AA, IRGKangXi=1305.211, RSKangXi=167.6, Def{europium}
92AB CJK UNIFIED IDEOGRAPH-#92AB, IRGKangXi=1305.211, RSKangXi=167.6, Def{cesium}
92AC CJK UNIFIED IDEOGRAPH-#92AC, IRGKangXi=1305.211, RSKangXi=167.6, Def{shackles, manacle}
92AD CJK UNIFIED IDEOGRAPH-#92AD, IRGKangXi=1305.211, RSKangXi=167.6, Def{money, currency, coins}
92AE CJK UNIFIED IDEOGRAPH-#92AE, IRGKangXi=1305.211, RSKangXi=167.6, Def{bells hung on horse; bells hung}
92AF CJK UNIFIED IDEOGRAPH-#92AF, IRGKangXi=1305.211, RSKangXi=167.6
92B0 CJK UNIFIED IDEOGRAPH-#92B0, IRGKangXi=1305.211, RSKangXi=167.6
92B1 CJK UNIFIED IDEOGRAPH-#92B1, IRGKangXi=1305.211, RSKangXi=167.6
92B2 CJK UNIFIED IDEOGRAPH-#92B2, IRGKangXi=1306.020, RSKangXi=167.7, Def{solder, weld; leg armor, greaves}
92B3 CJK UNIFIED IDEOGRAPH-#92B3, IRGKangXi=1306.030, RSKangXi=167.7, Def{sharp, keen, acute, pointed}
92B4 CJK UNIFIED IDEOGRAPH-#92B4, IRGKangXi=1306.040, RSKangXi=167.7
92B5 CJK UNIFIED IDEOGRAPH-#92B5, IRGKangXi=1306.060, RSKangXi=167.7
92B6 CJK UNIFIED IDEOGRAPH-#92B6, IRGKangXi=1306.080, RSKangXi=167.7, Def{chisel}
92B7 CJK UNIFIED IDEOGRAPH-#92B7, IRGKangXi=1306.090, RSKangXi=167.7, Def{melt, fuse; market, sell; to pass time, finish, cancel}
92B8 CJK UNIFIED IDEOGRAPH-#92B8, IRGKangXi=1306.100, RSKangXi=167.7
92B9 CJK UNIFIED IDEOGRAPH-#92B9, IRGKangXi=1306.110, RSKangXi=167.7, Def{rust, corrode}
92BA CJK UNIFIED IDEOGRAPH-#92BA, IRGKangXi=1306.120, RSKangXi=167.7
92BB CJK UNIFIED IDEOGRAPH-#92BB, IRGKangXi=1306.130, RSKangXi=167.7, Def{antimony (stibium)}
92BC CJK UNIFIED IDEOGRAPH-#92BC, IRGKangXi=1306.150, RSKangXi=167.7, Def{carpenter's file, file smooth}
92BD CJK UNIFIED IDEOGRAPH-#92BD, IRGKangXi=1306.160, RSKangXi=167.7
92BE CJK UNIFIED IDEOGRAPH-#92BE, IRGKangXi=1306.170, RSKangXi=167.7, Def{element mercury}
92BF CJK UNIFIED IDEOGRAPH-#92BF, IRGKangXi=1306.180, RSKangXi=167.7
92C0 CJK UNIFIED IDEOGRAPH-#92C0, IRGKangXi=1306.190, RSKangXi=167.7
92C1 CJK UNIFIED IDEOGRAPH-#92C1, IRGKangXi=1306.200, RSKangXi=167.7, Def{aluminum}
92C2 CJK UNIFIED IDEOGRAPH-#92C2, IRGKangXi=1306.210, RSKangXi=167.7, Def{bit cup}
92C3 CJK UNIFIED IDEOGRAPH-#92C3, IRGKangXi=1306.220, RSKangXi=167.7, Def{lock lanthanum}
92C4 CJK UNIFIED IDEOGRAPH-#92C4, IRGKangXi=1306.230, RSKangXi=167.7
92C5 CJK UNIFIED IDEOGRAPH-#92C5, IRGKangXi=1306.250, RSKangXi=167.7, Def{zincum}
92C6 CJK UNIFIED IDEOGRAPH-#92C6, IRGKangXi=1306.270, RSKangXi=167.7, Def{gold; character used in personal name}
92C7 CJK UNIFIED IDEOGRAPH-#92C7, IRGKangXi=1306.280, RSKangXi=167.7, Def{barium}
92C8 CJK UNIFIED IDEOGRAPH-#92C8, IRGKangXi=1306.290, RSKangXi=167.7, Def{silver plating}
92C9 CJK UNIFIED IDEOGRAPH-#92C9, IRGKangXi=1307.010, RSKangXi=167.7
92CA CJK UNIFIED IDEOGRAPH-#92CA, IRGKangXi=1307.020, RSKangXi=167.7, Def{a poker; brass filings; to file}
92CB CJK UNIFIED IDEOGRAPH-#92CB, IRGKangXi=1307.030, RSKangXi=167.7
92CC CJK UNIFIED IDEOGRAPH-#92CC, IRGKangXi=1307.040, RSKangXi=167.7, Def{ingots, bars of metal; hurry}
92CD CJK UNIFIED IDEOGRAPH-#92CD, IRGKangXi=1307.050, RSKangXi=167.7
92CE CJK UNIFIED IDEOGRAPH-#92CE, IRGKangXi=1307.060, RSKangXi=167.7
92CF CJK UNIFIED IDEOGRAPH-#92CF, IRGKangXi=1307.070, RSKangXi=167.7, Def{tongs, pincers; dagger; sword}
92D0 CJK UNIFIED IDEOGRAPH-#92D0, IRGKangXi=1307.080, RSKangXi=167.7, Def{state in today's Hubei province}
92D1 CJK UNIFIED IDEOGRAPH-#92D1, IRGKangXi=1307.110, RSKangXi=167.7, Def{to engrave or carve, as a block for printing}
92D2 CJK UNIFIED IDEOGRAPH-#92D2, IRGKangXi=1307.120, RSKangXi=167.7, Def{point of spear, sharp point}
92D3 CJK UNIFIED IDEOGRAPH-#92D3, IRGKangXi=1307.130, RSKangXi=167.7
92D4 CJK UNIFIED IDEOGRAPH-#92D4, IRGKangXi=1307.150, RSKangXi=167.7
92D5 CJK UNIFIED IDEOGRAPH-#92D5, IRGKangXi=1307.170, RSKangXi=167.7, Def{engrave}
92D6 CJK UNIFIED IDEOGRAPH-#92D6, IRGKangXi=1307.180, RSKangXi=167.7
92D7 CJK UNIFIED IDEOGRAPH-#92D7, IRGKangXi=1307.190, RSKangXi=167.7, Def{a small basin; rings on a cart of carriage}
92D8 CJK UNIFIED IDEOGRAPH-#92D8, IRGKangXi=1307.200, RSKangXi=167.7, Def{sword}
92D9 CJK UNIFIED IDEOGRAPH-#92D9, IRGKangXi=1307.210, RSKangXi=167.7, Def{misfit; disordant; music instrument; hoe}
92DA CJK UNIFIED IDEOGRAPH-#92DA, IRGKangXi=1307.220, RSKangXi=167.7, Def{iron; bronze decoration on bridle}
92DB CJK UNIFIED IDEOGRAPH-#92DB, IRGKangXi=1307.230, RSKangXi=167.7
92DC CJK UNIFIED IDEOGRAPH-#92DC, IRGKangXi=1307.240, RSKangXi=167.7, Def{fetters, shackles}
92DD CJK UNIFIED IDEOGRAPH-#92DD, IRGKangXi=1307.250, RSKangXi=167.7, Def{6 oz; ancient measurement}
92DE CJK UNIFIED IDEOGRAPH-#92DE, IRGKangXi=1308.020, RSKangXi=167.7
92DF CJK UNIFIED IDEOGRAPH-#92DF, IRGKangXi=1308.040, RSKangXi=167.7, Def{carve}
92E0 CJK UNIFIED IDEOGRAPH-#92E0, IRGKangXi=1308.050, RSKangXi=167.7
92E1 CJK UNIFIED IDEOGRAPH-#92E1, IRGKangXi=1308.070, RSKangXi=167.7
92E2 CJK UNIFIED IDEOGRAPH-#92E2, IRGKangXi=1308.080, RSKangXi=167.7
92E3 CJK UNIFIED IDEOGRAPH-#92E3, IRGKangXi=1308.090, RSKangXi=167.7, Def{sword}
92E4 CJK UNIFIED IDEOGRAPH-#92E4, IRGKangXi=1308.100, RSKangXi=167.7, Def{hoe; eradicate}
92E5 CJK UNIFIED IDEOGRAPH-#92E5, IRGKangXi=1308.130, RSKangXi=167.7, Def{polish}
92E6 CJK UNIFIED IDEOGRAPH-#92E6, IRGKangXi=1308.140, RSKangXi=167.7, Def{curium}
92E7 CJK UNIFIED IDEOGRAPH-#92E7, IRGKangXi=1308.160, RSKangXi=167.7
92E8 CJK UNIFIED IDEOGRAPH-#92E8, IRGKangXi=1308.180, RSKangXi=167.7, Def{an ancient name for iron; osmium}
92E9 CJK UNIFIED IDEOGRAPH-#92E9, IRGKangXi=1308.261, RSKangXi=167.7, Def{point of sword; sharp point}
92EA CJK UNIFIED IDEOGRAPH-#92EA, IRGKangXi=1308.210, RSKangXi=167.7, Def{spread out, arrange; shop, store; place to sleep, bed}
92EB CJK UNIFIED IDEOGRAPH-#92EB, IRGKangXi=1308.230, RSKangXi=167.7
92EC CJK UNIFIED IDEOGRAPH-#92EC, IRGKangXi=1308.250, RSKangXi=167.7
92ED CJK UNIFIED IDEOGRAPH-#92ED, IRGKangXi=1308.261, RSKangXi=167.7, Def{sharp}
92EE CJK UNIFIED IDEOGRAPH-#92EE, IRGKangXi=1308.261, RSKangXi=167.7, Def{person's name}
92EF CJK UNIFIED IDEOGRAPH-#92EF, IRGKangXi=1308.261, RSKangXi=167.7, Def{zirconium}
92F0 CJK UNIFIED IDEOGRAPH-#92F0, IRGKangXi=1308.261, RSKangXi=167.7, Def{lithium}
92F1 CJK UNIFIED IDEOGRAPH-#92F1, IRGKangXi=1308.261, RSKangXi=167.7, Def{terbium}
92F2 CJK UNIFIED IDEOGRAPH-#92F2, IRGKangXi=1308.261, RSKangXi=167.7, Def{rivet}
92F3 CJK UNIFIED IDEOGRAPH-#92F3, IRGKangXi=1308.261, RSKangXi=167.7, Def{melt, cast; coin, mint}
92F4 CJK UNIFIED IDEOGRAPH-#92F4, IRGKangXi=1308.261, RSKangXi=167.7
92F5 CJK UNIFIED IDEOGRAPH-#92F5, IRGKangXi=1308.261, RSKangXi=167.7
92F6 CJK UNIFIED IDEOGRAPH-#92F6, IRGKangXi=1308.261, RSKangXi=167.7
92F7 CJK UNIFIED IDEOGRAPH-#92F7, IRGKangXi=1308.270, RSKangXi=167.8
92F8 CJK UNIFIED IDEOGRAPH-#92F8, IRGKangXi=1308.280, RSKangXi=167.8, Def{a saw; to saw; amputate}
92F9 CJK UNIFIED IDEOGRAPH-#92F9, IRGKangXi=1308.290, RSKangXi=167.8, Def{sharp; a keen edge; sharp point}
92FA CJK UNIFIED IDEOGRAPH-#92FA, IRGKangXi=1308.300, RSKangXi=167.8, Def{a metal bowl}
92FB CJK UNIFIED IDEOGRAPH-#92FB, IRGKangXi=1308.310, RSKangXi=167.8
92FC CJK UNIFIED IDEOGRAPH-#92FC, IRGKangXi=1309.010, RSKangXi=167.8, Def{steel; hard, strong, tough}
92FD CJK UNIFIED IDEOGRAPH-#92FD, IRGKangXi=1309.020, RSKangXi=167.8
92FE CJK UNIFIED IDEOGRAPH-#92FE, IRGKangXi=1309.030, RSKangXi=167.8
92FF CJK UNIFIED IDEOGRAPH-#92FF, IRGKangXi=1309.040, RSKangXi=167.8
9300 CJK UNIFIED IDEOGRAPH-#9300, IRGKangXi=1309.050, RSKangXi=167.8
9301 CJK UNIFIED IDEOGRAPH-#9301, IRGKangXi=1309.060, RSKangXi=167.8, Def{ingot; acrobatic move}
9302 CJK UNIFIED IDEOGRAPH-#9302, IRGKangXi=1309.070, RSKangXi=167.8
9303 CJK UNIFIED IDEOGRAPH-#9303, IRGKangXi=1309.100, RSKangXi=167.8
9304 CJK UNIFIED IDEOGRAPH-#9304, IRGKangXi=1309.110, RSKangXi=167.8, Def{copy, write down, record}
9305 CJK UNIFIED IDEOGRAPH-#9305, IRGKangXi=1309.120, RSKangXi=167.8
9306 CJK UNIFIED IDEOGRAPH-#9306, IRGKangXi=1309.150, RSKangXi=167.8, Def{the color of a mineral}
9307 CJK UNIFIED IDEOGRAPH-#9307, IRGKangXi=1309.160, RSKangXi=167.8, Def{berkelium}
9308 CJK UNIFIED IDEOGRAPH-#9308, IRGKangXi=1309.170, RSKangXi=167.8, Def{to bend iron}
9309 CJK UNIFIED IDEOGRAPH-#9309, IRGKangXi=1309.180, RSKangXi=167.8
930A CJK UNIFIED IDEOGRAPH-#930A, IRGKangXi=1309.200, RSKangXi=167.8
930B CJK UNIFIED IDEOGRAPH-#930B, IRGKangXi=1309.210, RSKangXi=167.8
930C CJK UNIFIED IDEOGRAPH-#930C, IRGKangXi=1309.220, RSKangXi=167.8
930D CJK UNIFIED IDEOGRAPH-#930D, IRGKangXi=1309.230, RSKangXi=167.8
930E CJK UNIFIED IDEOGRAPH-#930E, IRGKangXi=1309.250, RSKangXi=167.8
930F CJK UNIFIED IDEOGRAPH-#930F, IRGKangXi=1309.260, RSKangXi=167.8, Def{soft steel; ammonium}
9310 CJK UNIFIED IDEOGRAPH-#9310, IRGKangXi=1309.280, RSKangXi=167.8, Def{gimlet, awl, drill, auger; bore}
9311 CJK UNIFIED IDEOGRAPH-#9311, IRGKangXi=1310.010, RSKangXi=167.8
9312 CJK UNIFIED IDEOGRAPH-#9312, IRGKangXi=1310.020, RSKangXi=167.8, Def{actinium}
9313 CJK UNIFIED IDEOGRAPH-#9313, IRGKangXi=1310.040, RSKangXi=167.8
9314 CJK UNIFIED IDEOGRAPH-#9314, IRGKangXi=1310.050, RSKangXi=167.8, Def{cap}
9315 CJK UNIFIED IDEOGRAPH-#9315, IRGKangXi=1310.060, RSKangXi=167.8, Def{ancient treasured sword}
9316 CJK UNIFIED IDEOGRAPH-#9316, IRGKangXi=1310.080, RSKangXi=167.8
9317 CJK UNIFIED IDEOGRAPH-#9317, IRGKangXi=1310.100, RSKangXi=167.8
9318 CJK UNIFIED IDEOGRAPH-#9318, IRGKangXi=1310.110, RSKangXi=167.8, Def{balance weight on scale; hammer}
9319 CJK UNIFIED IDEOGRAPH-#9319, IRGKangXi=1310.120, RSKangXi=167.8, Def{8 oz; an ancient unit of weight}
931A CJK UNIFIED IDEOGRAPH-#931A, IRGKangXi=1310.160, RSKangXi=167.8, Def{clanging sound; small gong}
931B CJK UNIFIED IDEOGRAPH-#931B, IRGKangXi=1310.170, RSKangXi=167.8, Def{adz; adze}
931C CJK UNIFIED IDEOGRAPH-#931C, IRGKangXi=1310.180, RSKangXi=167.8
931D CJK UNIFIED IDEOGRAPH-#931D, IRGKangXi=1310.190, RSKangXi=167.8
931E CJK UNIFIED IDEOGRAPH-#931E, IRGKangXi=1310.200, RSKangXi=167.8, Def{instrument}
931F CJK UNIFIED IDEOGRAPH-#931F, IRGKangXi=1310.210, RSKangXi=167.8, Def{long spear}
9320 CJK UNIFIED IDEOGRAPH-#9320, IRGKangXi=1311.010, RSKangXi=167.8, Def{spindle, slab, cake, tablet}
9321 CJK UNIFIED IDEOGRAPH-#9321, IRGKangXi=1311.020, RSKangXi=167.8, Def{a kind of pen; a kind of chisel}
9322 CJK UNIFIED IDEOGRAPH-#9322, IRGKangXi=1311.050, RSKangXi=167.8, Def{money, currency, coins}
9323 CJK UNIFIED IDEOGRAPH-#9323, IRGKangXi=1311.080, RSKangXi=167.8, Def{armor neckplates}
9324 CJK UNIFIED IDEOGRAPH-#9324, IRGKangXi=1311.090, RSKangXi=167.8, Def{hoe}
9325 CJK UNIFIED IDEOGRAPH-#9325, IRGKangXi=1311.100, RSKangXi=167.8
9326 CJK UNIFIED IDEOGRAPH-#9326, IRGKangXi=1311.110, RSKangXi=167.8, Def{brocade, tapestry; embroidered}
9327 CJK UNIFIED IDEOGRAPH-#9327, IRGKangXi=1312.010, RSKangXi=167.8
9328 CJK UNIFIED IDEOGRAPH-#9328, IRGKangXi=1312.020, RSKangXi=167.9, Def{anchor}
9329 CJK UNIFIED IDEOGRAPH-#9329, IRGKangXi=1312.030, RSKangXi=167.8, Def{vessel}
932A CJK UNIFIED IDEOGRAPH-#932A, IRGKangXi=1312.040, RSKangXi=167.8
932B CJK UNIFIED IDEOGRAPH-#932B, IRGKangXi=1312.050, RSKangXi=167.8, Def{tin, stannum; bestow, confer}
932C CJK UNIFIED IDEOGRAPH-#932C, IRGKangXi=1312.090, RSKangXi=167.8, Def{smelt metals}
932D CJK UNIFIED IDEOGRAPH-#932D, IRGKangXi=1312.100, RSKangXi=167.8
932E CJK UNIFIED IDEOGRAPH-#932E, IRGKangXi=1312.110, RSKangXi=167.8, Def{run metal into cracks; confine}
932F CJK UNIFIED IDEOGRAPH-#932F, IRGKangXi=1312.120, RSKangXi=167.8, Def{error, blunder, mistake, wrong}
9330 CJK UNIFIED IDEOGRAPH-#9330, IRGKangXi=1313.010, RSKangXi=167.8
9331 CJK UNIFIED IDEOGRAPH-#9331, IRGKangXi=1313.040, RSKangXi=167.8
9332 CJK UNIFIED IDEOGRAPH-#9332, IRGKangXi=1313.051, RSKangXi=167.8, Def{copy}
9333 CJK UNIFIED IDEOGRAPH-#9333, IRGKangXi=1313.051, RSKangXi=167.8, Def{manganese}
9334 CJK UNIFIED IDEOGRAPH-#9334, IRGKangXi=1313.051, RSKangXi=167.8
9335 CJK UNIFIED IDEOGRAPH-#9335, IRGKangXi=1313.051, RSKangXi=167.8
9336 CJK UNIFIED IDEOGRAPH-#9336, IRGKangXi=1313.051, RSKangXi=167.8, Def{a watch, clock}
9337 CJK UNIFIED IDEOGRAPH-#9337, IRGKangXi=1313.051, RSKangXi=167.8
9338 CJK UNIFIED IDEOGRAPH-#9338, IRGKangXi=1313.051, RSKangXi=167.8, Def{rhenium}
9339 CJK UNIFIED IDEOGRAPH-#9339, IRGKangXi=1313.051, RSKangXi=167.8
933A CJK UNIFIED IDEOGRAPH-#933A, IRGKangXi=1313.051, RSKangXi=167.8, Def{metal jewelry}
933B CJK UNIFIED IDEOGRAPH-#933B, IRGKangXi=1313.051, RSKangXi=167.8, Def{a tin plate}
933C CJK UNIFIED IDEOGRAPH-#933C, IRGKangXi=1313.051, RSKangXi=167.8, Def{neptunium (Np)}
933D CJK UNIFIED IDEOGRAPH-#933D, IRGKangXi=1313.051, RSKangXi=167.8
933E CJK UNIFIED IDEOGRAPH-#933E, IRGKangXi=1313.051, RSKangXi=167.8, Def{engraving tool, chisel}
933F CJK UNIFIED IDEOGRAPH-#933F, IRGKangXi=1313.051, RSKangXi=167.8
9340 CJK UNIFIED IDEOGRAPH-#9340, IRGKangXi=1313.051, RSKangXi=167.8, Def{technetium}
9341 CJK UNIFIED IDEOGRAPH-#9341, IRGKangXi=1313.051, RSKangXi=167.8, Def{shovel}
9342 CJK UNIFIED IDEOGRAPH-#9342, IRGKangXi=1313.051, RSKangXi=167.8
9343 CJK UNIFIED IDEOGRAPH-#9343, IRGKangXi=1313.051, RSKangXi=167.8, Def{a kind of tool}
9344 CJK UNIFIED IDEOGRAPH-#9344, IRGKangXi=1313.051, RSKangXi=167.8
9345 CJK UNIFIED IDEOGRAPH-#9345, IRGKangXi=1313.051
9346 CJK UNIFIED IDEOGRAPH-#9346, IRGKangXi=1313.051, RSKangXi=167.8, Def{mendelevium (Md)}
9347 CJK UNIFIED IDEOGRAPH-#9347, IRGKangXi=1313.060, RSKangXi=167.9, Def{high quality iron}
9348 CJK UNIFIED IDEOGRAPH-#9348, IRGKangXi=1313.070, RSKangXi=167.8
9349 CJK UNIFIED IDEOGRAPH-#9349, IRGKangXi=1313.080, RSKangXi=167.9, Def{spoon, key}
934A CJK UNIFIED IDEOGRAPH-#934A, IRGKangXi=1313.090, RSKangXi=167.9, Def{smelt metals, forge; refine}
934B CJK UNIFIED IDEOGRAPH-#934B, IRGKangXi=1313.100, RSKangXi=167.9, Def{cooking-pot, saucepan}
934C CJK UNIFIED IDEOGRAPH-#934C, IRGKangXi=1313.120, RSKangXi=167.9
934D CJK UNIFIED IDEOGRAPH-#934D, IRGKangXi=1313.140, RSKangXi=167.9, Def{plate, coat, gild}
934E CJK UNIFIED IDEOGRAPH-#934E, IRGKangXi=1313.150, RSKangXi=167.9
934F CJK UNIFIED IDEOGRAPH-#934F, IRGKangXi=1313.170, RSKangXi=167.9
9350 CJK UNIFIED IDEOGRAPH-#9350, IRGKangXi=1313.190, RSKangXi=167.9, Def{a headstall, ornament on a bride}
9351 CJK UNIFIED IDEOGRAPH-#9351, IRGKangXi=1313.200, RSKangXi=167.9
9352 CJK UNIFIED IDEOGRAPH-#9352, IRGKangXi=1313.210, RSKangXi=167.9
9353 CJK UNIFIED IDEOGRAPH-#9353, IRGKangXi=1313.230, RSKangXi=167.9
9354 CJK UNIFIED IDEOGRAPH-#9354, IRGKangXi=1314.010, RSKangXi=167.9, Def{high, lofty; edge of knife}
9355 CJK UNIFIED IDEOGRAPH-#9355, IRGKangXi=1314.030, RSKangXi=167.9
9356 CJK UNIFIED IDEOGRAPH-#9356, IRGKangXi=1314.040, RSKangXi=167.9
9357 CJK UNIFIED IDEOGRAPH-#9357, IRGKangXi=1314.050, RSKangXi=167.9
9358 CJK UNIFIED IDEOGRAPH-#9358, IRGKangXi=1314.060, RSKangXi=167.9, Def{sickle for cutting grass or hay}
9359 CJK UNIFIED IDEOGRAPH-#9359, IRGKangXi=1314.070, RSKangXi=167.9
935A CJK UNIFIED IDEOGRAPH-#935A, IRGKangXi=1314.080, RSKangXi=167.9, Def{frontlet}
935B CJK UNIFIED IDEOGRAPH-#935B, IRGKangXi=1314.090, RSKangXi=167.9, Def{forge metal; temper, refine}
935C CJK UNIFIED IDEOGRAPH-#935C, IRGKangXi=1314.100, RSKangXi=167.9, Def{to forge, work}
935D CJK UNIFIED IDEOGRAPH-#935D, IRGKangXi=1314.110, RSKangXi=167.9
935E CJK UNIFIED IDEOGRAPH-#935E, IRGKangXi=1314.120, RSKangXi=167.9
935F CJK UNIFIED IDEOGRAPH-#935F, IRGKangXi=1314.130, RSKangXi=167.9, Def{(Cant.) rust}
9360 CJK UNIFIED IDEOGRAPH-#9360, IRGKangXi=1314.140, RSKangXi=167.9, Def{weapon}
9361 CJK UNIFIED IDEOGRAPH-#9361, IRGKangXi=1314.150, RSKangXi=167.9
9362 CJK UNIFIED IDEOGRAPH-#9362, IRGKangXi=1314.160, RSKangXi=167.9
9363 CJK UNIFIED IDEOGRAPH-#9363, IRGKangXi=1314.170, RSKangXi=167.9
9364 CJK UNIFIED IDEOGRAPH-#9364, IRGKangXi=1314.180, RSKangXi=167.9, Def{spade, shovel; marking pin}
9365 CJK UNIFIED IDEOGRAPH-#9365, IRGKangXi=1314.190, RSKangXi=167.9, Def{sickle; cut, carve, engrave}
9366 CJK UNIFIED IDEOGRAPH-#9366, IRGKangXi=1314.200, RSKangXi=167.9
9367 CJK UNIFIED IDEOGRAPH-#9367, IRGKangXi=1314.210, RSKangXi=167.9
9368 CJK UNIFIED IDEOGRAPH-#9368, IRGKangXi=1314.220, RSKangXi=167.9
9369 CJK UNIFIED IDEOGRAPH-#9369, IRGKangXi=1314.230, RSKangXi=167.9, Def{nobelium}
936A CJK UNIFIED IDEOGRAPH-#936A, IRGKangXi=1314.240, RSKangXi=167.9, Def{an iron pan; a metal cap}
936B CJK UNIFIED IDEOGRAPH-#936B, IRGKangXi=1315.020, RSKangXi=167.9, Def{shovel}
936C CJK UNIFIED IDEOGRAPH-#936C, IRGKangXi=1315.030, RSKangXi=167.9, Def{shovel}
936D CJK UNIFIED IDEOGRAPH-#936D, IRGKangXi=1315.040, RSKangXi=167.9, Def{arrow}
936E CJK UNIFIED IDEOGRAPH-#936E, IRGKangXi=1315.050, RSKangXi=167.9, Def{brass}
936F CJK UNIFIED IDEOGRAPH-#936F, IRGKangXi=1315.060, RSKangXi=167.9
9370 CJK UNIFIED IDEOGRAPH-#9370, IRGKangXi=1315.080, RSKangXi=167.9, Def{measure; money, coins}
9371 CJK UNIFIED IDEOGRAPH-#9371, IRGKangXi=1315.090, RSKangXi=167.9, Def{thin plates of metal}
9372 CJK UNIFIED IDEOGRAPH-#9372, IRGKangXi=1315.100, RSKangXi=167.9
9373 CJK UNIFIED IDEOGRAPH-#9373, IRGKangXi=1315.110, RSKangXi=167.9
9374 CJK UNIFIED IDEOGRAPH-#9374, IRGKangXi=1315.130, RSKangXi=167.9
9375 CJK UNIFIED IDEOGRAPH-#9375, IRGKangXi=1315.140, RSKangXi=167.9, Def{door bolt, lock bolt; key}
9376 CJK UNIFIED IDEOGRAPH-#9376, IRGKangXi=1315.160, RSKangXi=167.9, Def{strontium; an iron utensil}
9377 CJK UNIFIED IDEOGRAPH-#9377, IRGKangXi=1315.170, RSKangXi=167.9
9378 CJK UNIFIED IDEOGRAPH-#9378, IRGKangXi=1315.180, RSKangXi=167.9, Def{food, gruel}
9379 CJK UNIFIED IDEOGRAPH-#9379, IRGKangXi=1315.190, RSKangXi=167.9
937A CJK UNIFIED IDEOGRAPH-#937A, IRGKangXi=1315.210, RSKangXi=167.9, Def{germanium; metal flashing on the axle of a cart}
937B CJK UNIFIED IDEOGRAPH-#937B, IRGKangXi=1315.250, RSKangXi=167.9
937C CJK UNIFIED IDEOGRAPH-#937C, IRGKangXi=1315.270, RSKangXi=167.9, Def{needle, pin, tack; prick; inject}
937D CJK UNIFIED IDEOGRAPH-#937D, IRGKangXi=1316.040, RSKangXi=167.9
937E CJK UNIFIED IDEOGRAPH-#937E, IRGKangXi=1316.050, RSKangXi=167.9, Def{cup, glass, goblet; surname}
937F CJK UNIFIED IDEOGRAPH-#937F, IRGKangXi=1316.060, RSKangXi=167.9
9380 CJK UNIFIED IDEOGRAPH-#9380, IRGKangXi=1316.070, RSKangXi=167.9
9381 CJK UNIFIED IDEOGRAPH-#9381, IRGKangXi=1316.090, RSKangXi=167.9
9382 CJK UNIFIED IDEOGRAPH-#9382, IRGKangXi=1316.111, RSKangXi=167.9, Def{magnesium}
9383 CJK UNIFIED IDEOGRAPH-#9383, IRGKangXi=1316.111, RSKangXi=167.9
9384 CJK UNIFIED IDEOGRAPH-#9384, IRGKangXi=1316.111, RSKangXi=167.9, Def{iridium einsteinium}
9385 CJK UNIFIED IDEOGRAPH-#9385, IRGKangXi=1316.111, RSKangXi=167.9, Def{(Cant.) to saw; to cut}
9386 CJK UNIFIED IDEOGRAPH-#9386, IRGKangXi=1316.111, RSKangXi=167.9
9387 CJK UNIFIED IDEOGRAPH-#9387, IRGKangXi=1316.111, RSKangXi=167.9, Def{americium}
9388 CJK UNIFIED IDEOGRAPH-#9388, IRGKangXi=1316.120, RSKangXi=167.10
9389 CJK UNIFIED IDEOGRAPH-#9389, IRGKangXi=1316.130, RSKangXi=167.10, Def{thallium}
938A CJK UNIFIED IDEOGRAPH-#938A, IRGKangXi=1316.140, RSKangXi=167.10, Def{pound sterling; to scrape}
938B CJK UNIFIED IDEOGRAPH-#938B, IRGKangXi=1316.150, RSKangXi=167.10, Def{the linch-pin of a wheel to govern or control the noise of a barrow}
938C CJK UNIFIED IDEOGRAPH-#938C, IRGKangXi=1316.160, RSKangXi=167.10, Def{sickle}
938D CJK UNIFIED IDEOGRAPH-#938D, IRGKangXi=1316.170, RSKangXi=167.10, Def{chain; wire}
938E CJK UNIFIED IDEOGRAPH-#938E, IRGKangXi=1316.180, RSKangXi=167.10
938F CJK UNIFIED IDEOGRAPH-#938F, IRGKangXi=1316.190, RSKangXi=167.10, Def{pure gold}
9390 CJK UNIFIED IDEOGRAPH-#9390, IRGKangXi=1316.210, RSKangXi=167.10, Def{family name; wine cup}
9391 CJK UNIFIED IDEOGRAPH-#9391, IRGKangXi=1316.220, RSKangXi=167.10
9392 CJK UNIFIED IDEOGRAPH-#9392, IRGKangXi=1316.230, RSKangXi=167.10, Def{to hoe; to weed}
9393 CJK UNIFIED IDEOGRAPH-#9393, IRGKangXi=1316.240, RSKangXi=167.10
9394 CJK UNIFIED IDEOGRAPH-#9394, IRGKangXi=1317.010, RSKangXi=167.10, Def{fuse, melt, smelt; mold}
9395 CJK UNIFIED IDEOGRAPH-#9395, IRGKangXi=1317.030, RSKangXi=167.10
9396 CJK UNIFIED IDEOGRAPH-#9396, IRGKangXi=1317.050, RSKangXi=167.10, Def{lock, padlock; shackles, chains}
9397 CJK UNIFIED IDEOGRAPH-#9397, IRGKangXi=1317.060, RSKangXi=167.10, Def{rifle, small arms, hand gun}
9398 CJK UNIFIED IDEOGRAPH-#9398, IRGKangXi=1317.070, RSKangXi=167.10, Def{cadmium}
9399 CJK UNIFIED IDEOGRAPH-#9399, IRGKangXi=1317.100, RSKangXi=167.10, Def{large spear; chess board}
939A CJK UNIFIED IDEOGRAPH-#939A, IRGKangXi=1317.120, RSKangXi=167.10, Def{hammer, mallet; club}
939B CJK UNIFIED IDEOGRAPH-#939B, IRGKangXi=1317.150, RSKangXi=167.10, Def{large bell; hoe, spade}
939C CJK UNIFIED IDEOGRAPH-#939C, IRGKangXi=1317.170, RSKangXi=167.10
939D CJK UNIFIED IDEOGRAPH-#939D, IRGKangXi=1317.180, RSKangXi=167.10, Def{technetium (Tc, same as 鍀); engrave (same as 鏤); tilling implement}
939E CJK UNIFIED IDEOGRAPH-#939E, IRGKangXi=1317.190, RSKangXi=167.10, Def{plowshare; barb, lancet}
939F CJK UNIFIED IDEOGRAPH-#939F, IRGKangXi=1317.210, RSKangXi=167.10
93A0 CJK UNIFIED IDEOGRAPH-#93A0, IRGKangXi=1317.240, RSKangXi=167.10
93A1 CJK UNIFIED IDEOGRAPH-#93A1, IRGKangXi=1317.250, RSKangXi=167.10, Def{hoe; mattock}
93A2 CJK UNIFIED IDEOGRAPH-#93A2, IRGKangXi=1317.260, RSKangXi=167.10, Def{tungsten (wolfram)}
93A3 CJK UNIFIED IDEOGRAPH-#93A3, IRGKangXi=1317.270, RSKangXi=167.10, Def{polish}
93A4 CJK UNIFIED IDEOGRAPH-#93A4, IRGKangXi=1318.010, RSKangXi=167.10, Def{sound of a bell; small bell}
93A5 CJK UNIFIED IDEOGRAPH-#93A5, IRGKangXi=1318.030, RSKangXi=167.10
93A6 CJK UNIFIED IDEOGRAPH-#93A6, IRGKangXi=1318.040, RSKangXi=167.10, Def{distil; lutetium; surname}
93A7 CJK UNIFIED IDEOGRAPH-#93A7, IRGKangXi=1318.050, RSKangXi=167.10, Def{armor, chain mail}
93A8 CJK UNIFIED IDEOGRAPH-#93A8, IRGKangXi=1318.060, RSKangXi=167.10
93A9 CJK UNIFIED IDEOGRAPH-#93A9, IRGKangXi=1318.080, RSKangXi=167.11, Def{moult samarium}
93AA CJK UNIFIED IDEOGRAPH-#93AA, IRGKangXi=1318.100, RSKangXi=167.10, Def{to engrave (metal of wood)}
93AB CJK UNIFIED IDEOGRAPH-#93AB, IRGKangXi=1318.110, RSKangXi=167.10, Def{ornament over the horse's head}
93AC CJK UNIFIED IDEOGRAPH-#93AC, IRGKangXi=1318.120, RSKangXi=167.10, Def{stove; bright}
93AD CJK UNIFIED IDEOGRAPH-#93AD, IRGKangXi=1318.150, RSKangXi=167.10, Def{town, market place; suppress}
93AE CJK UNIFIED IDEOGRAPH-#93AE, IRGKangXi=1318.170, RSKangXi=167.10, Def{town, market place; suppress}
93AF CJK UNIFIED IDEOGRAPH-#93AF, IRGKangXi=1318.180, RSKangXi=167.10, Def{large hammer}
93B0 CJK UNIFIED IDEOGRAPH-#93B0, IRGKangXi=1318.190, RSKangXi=167.10, Def{measure of weight for gold}
93B1 CJK UNIFIED IDEOGRAPH-#93B1, IRGKangXi=1318.250, RSKangXi=167.10
93B2 CJK UNIFIED IDEOGRAPH-#93B2, IRGKangXi=1318.281, RSKangXi=167.10
93B3 CJK UNIFIED IDEOGRAPH-#93B3, IRGKangXi=1318.281, RSKangXi=167.10, Def{nickel}
93B4 CJK UNIFIED IDEOGRAPH-#93B4, IRGKangXi=1318.281, RSKangXi=167.10
93B5 CJK UNIFIED IDEOGRAPH-#93B5, IRGKangXi=1318.281, RSKangXi=167.10, Def{gallium}
93B6 CJK UNIFIED IDEOGRAPH-#93B6, IRGKangXi=1318.281, RSKangXi=167.10, Def{Copernicium}
93B7 CJK UNIFIED IDEOGRAPH-#93B7, IRGKangXi=1318.281, RSKangXi=167.10
93B8 CJK UNIFIED IDEOGRAPH-#93B8, IRGKangXi=1318.281, RSKangXi=167.10, Def{engraving tool; carve, engrave}
93B9 CJK UNIFIED IDEOGRAPH-#93B9, IRGKangXi=1318.281, RSKangXi=167.10, Def{a clamp}
93BA CJK UNIFIED IDEOGRAPH-#93BA, IRGKangXi=1318.281, RSKangXi=167.10
93BB CJK UNIFIED IDEOGRAPH-#93BB, IRGKangXi=1318.281, RSKangXi=167.10, Def{lock, padlock; shackles, chains}
93BC CJK UNIFIED IDEOGRAPH-#93BC, IRGKangXi=1318.281, RSKangXi=167.10
93BD CJK UNIFIED IDEOGRAPH-#93BD, IRGKangXi=1318.281, RSKangXi=167.10
93BE CJK UNIFIED IDEOGRAPH-#93BE, IRGKangXi=1318.281, RSKangXi=167.10
93BF CJK UNIFIED IDEOGRAPH-#93BF, IRGKangXi=1318.281, RSKangXi=167.10, Def{neptunium (Np)}
93C0 CJK UNIFIED IDEOGRAPH-#93C0, IRGKangXi=1318.290, RSKangXi=167.11
93C1 CJK UNIFIED IDEOGRAPH-#93C1, IRGKangXi=1319.010, RSKangXi=167.11, Def{variant of 鎖 U+9396, a lock, padlock; shackles, chains}
93C2 CJK UNIFIED IDEOGRAPH-#93C2, IRGKangXi=1319.020, RSKangXi=167.11
93C3 CJK UNIFIED IDEOGRAPH-#93C3, IRGKangXi=1319.030, RSKangXi=167.11, Def{arrowhead, barb; swift, quick}
93C4 CJK UNIFIED IDEOGRAPH-#93C4, IRGKangXi=1319.060, RSKangXi=167.11
93C5 CJK UNIFIED IDEOGRAPH-#93C5, IRGKangXi=1319.070, RSKangXi=167.11
93C6 CJK UNIFIED IDEOGRAPH-#93C6, IRGKangXi=1319.080, RSKangXi=167.11
93C7 CJK UNIFIED IDEOGRAPH-#93C7, IRGKangXi=1319.090, RSKangXi=167.11, Def{lathe}
93C8 CJK UNIFIED IDEOGRAPH-#93C8, IRGKangXi=1319.100, RSKangXi=167.11, Def{chain, wire, cable; chain, shack}
93C9 CJK UNIFIED IDEOGRAPH-#93C9, IRGKangXi=1319.120, RSKangXi=167.11
93CA CJK UNIFIED IDEOGRAPH-#93CA, IRGKangXi=1319.130, RSKangXi=167.11, Def{a flat, iron cooking-plate for cakes}
93CB CJK UNIFIED IDEOGRAPH-#93CB, IRGKangXi=1319.140, RSKangXi=167.11
93CC CJK UNIFIED IDEOGRAPH-#93CC, IRGKangXi=1319.150, RSKangXi=167.11, Def{sword}
93CD CJK UNIFIED IDEOGRAPH-#93CD, IRGKangXi=1319.160, RSKangXi=167.11
93CE CJK UNIFIED IDEOGRAPH-#93CE, IRGKangXi=1319.170, RSKangXi=167.11
93CF CJK UNIFIED IDEOGRAPH-#93CF, IRGKangXi=1319.180, RSKangXi=167.11
93D0 CJK UNIFIED IDEOGRAPH-#93D0, IRGKangXi=1319.200, RSKangXi=167.11, Def{pure gold}
93D1 CJK UNIFIED IDEOGRAPH-#93D1, IRGKangXi=1319.210, RSKangXi=167.11, Def{dysprosium; the barb of an arrow; the head of a javelin}
93D2 CJK UNIFIED IDEOGRAPH-#93D2, IRGKangXi=1319.230, RSKangXi=167.11
93D3 CJK UNIFIED IDEOGRAPH-#93D3, IRGKangXi=1319.260, RSKangXi=167.11
93D4 CJK UNIFIED IDEOGRAPH-#93D4, IRGKangXi=1319.280, RSKangXi=167.11
93D5 CJK UNIFIED IDEOGRAPH-#93D5, IRGKangXi=1319.290, RSKangXi=167.11
93D6 CJK UNIFIED IDEOGRAPH-#93D6, IRGKangXi=1319.300, RSKangXi=167.11, Def{to fight to the end, engage in a fierce battle}
93D7 CJK UNIFIED IDEOGRAPH-#93D7, IRGKangXi=1319.320, RSKangXi=167.11, Def{strike, beat, stroke; jingling}
93D8 CJK UNIFIED IDEOGRAPH-#93D8, IRGKangXi=1319.330, RSKangXi=167.11, Def{tinkle, clang, jingle}
93D9 CJK UNIFIED IDEOGRAPH-#93D9, IRGKangXi=1320.010, RSKangXi=167.11
93DA CJK UNIFIED IDEOGRAPH-#93DA, IRGKangXi=1320.020, RSKangXi=167.11, Def{axe}
93DB CJK UNIFIED IDEOGRAPH-#93DB, IRGKangXi=1320.030, RSKangXi=167.11, Def{to polish; iron rim on a wagon wheel}
93DC CJK UNIFIED IDEOGRAPH-#93DC, IRGKangXi=1320.040, RSKangXi=167.11, Def{boring tool}
93DD CJK UNIFIED IDEOGRAPH-#93DD, IRGKangXi=1320.050, RSKangXi=167.11, Def{trowel}
93DE CJK UNIFIED IDEOGRAPH-#93DE, IRGKangXi=1320.060, RSKangXi=167.11, Def{a large bell used as a musical instrument}
93DF CJK UNIFIED IDEOGRAPH-#93DF, IRGKangXi=1320.080, RSKangXi=167.11, Def{spade, shovel, trowel, scoop}
93E0 CJK UNIFIED IDEOGRAPH-#93E0, IRGKangXi=1320.090, RSKangXi=167.11
93E1 CJK UNIFIED IDEOGRAPH-#93E1, IRGKangXi=1320.100, RSKangXi=167.11, Def{mirror; lens; glass; glasses}
93E2 CJK UNIFIED IDEOGRAPH-#93E2, IRGKangXi=1320.110, RSKangXi=167.11, Def{dart, spear, harpoon; escort}
93E3 CJK UNIFIED IDEOGRAPH-#93E3, IRGKangXi=1320.150, RSKangXi=167.11
93E4 CJK UNIFIED IDEOGRAPH-#93E4, IRGKangXi=1320.180, RSKangXi=167.11, Def{carve, inlay, engrave, tattoo}
93E5 CJK UNIFIED IDEOGRAPH-#93E5, IRGKangXi=1320.190, RSKangXi=167.11, Def{rust, corrosion}
93E6 CJK UNIFIED IDEOGRAPH-#93E6, IRGKangXi=1320.200, RSKangXi=167.11, Def{a short spear}
93E7 CJK UNIFIED IDEOGRAPH-#93E7, IRGKangXi=1320.210, RSKangXi=167.11
93E8 CJK UNIFIED IDEOGRAPH-#93E8, IRGKangXi=1320.220, RSKangXi=167.11, Def{engraving tool, chisel}
93E9 CJK UNIFIED IDEOGRAPH-#93E9, IRGKangXi=1320.230, RSKangXi=167.11
93EA CJK UNIFIED IDEOGRAPH-#93EA, IRGKangXi=1320.240, RSKangXi=167.11
93EB CJK UNIFIED IDEOGRAPH-#93EB, IRGKangXi=1321.020, RSKangXi=167.11
93EC CJK UNIFIED IDEOGRAPH-#93EC, IRGKangXi=1321.070, RSKangXi=167.11
93ED CJK UNIFIED IDEOGRAPH-#93ED, IRGKangXi=1321.071, RSKangXi=167.11
93EE CJK UNIFIED IDEOGRAPH-#93EE, IRGKangXi=1321.071, RSKangXi=167.11
93EF CJK UNIFIED IDEOGRAPH-#93EF, IRGKangXi=1321.071, RSKangXi=167.11
93F0 CJK UNIFIED IDEOGRAPH-#93F0, IRGKangXi=1321.071, RSKangXi=167.11, Def{coin, money}
93F1 CJK UNIFIED IDEOGRAPH-#93F1, IRGKangXi=1321.071, RSKangXi=167.11
93F2 CJK UNIFIED IDEOGRAPH-#93F2, IRGKangXi=1321.071, RSKangXi=167.11
93F3 CJK UNIFIED IDEOGRAPH-#93F3, IRGKangXi=1321.080, RSKangXi=167.12
93F4 CJK UNIFIED IDEOGRAPH-#93F4, IRGKangXi=1321.090, RSKangXi=167.13, Def{to plug a hole}
93F5 CJK UNIFIED IDEOGRAPH-#93F5, IRGKangXi=1321.100, RSKangXi=167.12, Def{spade, shovel, plowshare}
93F6 CJK UNIFIED IDEOGRAPH-#93F6, IRGKangXi=1321.120, RSKangXi=167.12
93F7 CJK UNIFIED IDEOGRAPH-#93F7, IRGKangXi=1321.130, RSKangXi=167.12, Def{protactinium}
93F8 CJK UNIFIED IDEOGRAPH-#93F8, IRGKangXi=1321.140, RSKangXi=167.12
93F9 CJK UNIFIED IDEOGRAPH-#93F9, IRGKangXi=1321.160, RSKangXi=167.11, Def{coins, money, wealth; (Cant.) 鏹水, sulfuric acid}
93FA CJK UNIFIED IDEOGRAPH-#93FA, IRGKangXi=1321.170, RSKangXi=167.12
93FB CJK UNIFIED IDEOGRAPH-#93FB, IRGKangXi=1321.180, RSKangXi=167.12, Def{phosphonium}
93FC CJK UNIFIED IDEOGRAPH-#93FC, IRGKangXi=1321.190, RSKangXi=167.12
93FD CJK UNIFIED IDEOGRAPH-#93FD, IRGKangXi=1321.210, RSKangXi=167.12, Def{rust, corrode}
93FE CJK UNIFIED IDEOGRAPH-#93FE, IRGKangXi=1321.220, RSKangXi=167.12, Def{the trigger of a crossbow; crossbow}
93FF CJK UNIFIED IDEOGRAPH-#93FF, IRGKangXi=1321.230, RSKangXi=167.12
9400 CJK UNIFIED IDEOGRAPH-#9400, IRGKangXi=1321.260, RSKangXi=167.12, Def{a cupboard; a press; a wardrobe shop-counter}
9401 CJK UNIFIED IDEOGRAPH-#9401, IRGKangXi=1321.280, RSKangXi=167.12
9402 CJK UNIFIED IDEOGRAPH-#9402, IRGKangXi=1321.290, RSKangXi=167.12
9403 CJK UNIFIED IDEOGRAPH-#9403, IRGKangXi=1321.300, RSKangXi=167.12, Def{cymbals; hand bell; disturb}
9404 CJK UNIFIED IDEOGRAPH-#9404, IRGKangXi=1321.310, RSKangXi=167.12, Def{bell}
9405 CJK UNIFIED IDEOGRAPH-#9405, IRGKangXi=1321.320, RSKangXi=167.12
9406 CJK UNIFIED IDEOGRAPH-#9406, IRGKangXi=1321.350, RSKangXi=167.12
9407 CJK UNIFIED IDEOGRAPH-#9407, IRGKangXi=1321.360, RSKangXi=167.12, Def{vanadium}
9408 CJK UNIFIED IDEOGRAPH-#9408, IRGKangXi=1321.370, RSKangXi=167.12
9409 CJK UNIFIED IDEOGRAPH-#9409, IRGKangXi=1321.380, RSKangXi=167.12
940A CJK UNIFIED IDEOGRAPH-#940A, IRGKangXi=1321.400, RSKangXi=167.12
940B CJK UNIFIED IDEOGRAPH-#940B, IRGKangXi=1321.410, RSKangXi=167.12, Def{gong}
940C CJK UNIFIED IDEOGRAPH-#940C, IRGKangXi=1322.010, RSKangXi=167.12
940D CJK UNIFIED IDEOGRAPH-#940D, IRGKangXi=1322.030, RSKangXi=167.12, Def{hasp of a lock}
940E CJK UNIFIED IDEOGRAPH-#940E, IRGKangXi=1322.050, RSKangXi=167.12
940F CJK UNIFIED IDEOGRAPH-#940F, IRGKangXi=1322.060, RSKangXi=167.12, Def{cap}
9410 CJK UNIFIED IDEOGRAPH-#9410, IRGKangXi=1322.070, RSKangXi=167.12, Def{fetters}
9411 CJK UNIFIED IDEOGRAPH-#9411, IRGKangXi=1322.090, RSKangXi=167.12
9412 CJK UNIFIED IDEOGRAPH-#9412, IRGKangXi=1322.100, RSKangXi=167.12, Def{lawrencium}
9413 CJK UNIFIED IDEOGRAPH-#9413, IRGKangXi=1322.120, RSKangXi=167.12, Def{ferrule; castrate}
9414 CJK UNIFIED IDEOGRAPH-#9414, IRGKangXi=1322.130, RSKangXi=167.12, Def{dagger; small sword}
9415 CJK UNIFIED IDEOGRAPH-#9415, IRGKangXi=1322.160, RSKangXi=167.12
9416 CJK UNIFIED IDEOGRAPH-#9416, IRGKangXi=1322.170, RSKangXi=167.12
9417 CJK UNIFIED IDEOGRAPH-#9417, IRGKangXi=1322.190, RSKangXi=167.12
9418 CJK UNIFIED IDEOGRAPH-#9418, IRGKangXi=1323.020, RSKangXi=167.12, Def{clock; bell}
9419 CJK UNIFIED IDEOGRAPH-#9419, IRGKangXi=1323.040, RSKangXi=167.12, Def{lamp; a kind of cooking vessel}
941A CJK UNIFIED IDEOGRAPH-#941A, IRGKangXi=1323.060, RSKangXi=167.12, Def{soft steel; ammonium}
941B CJK UNIFIED IDEOGRAPH-#941B, IRGKangXi=1323.100, RSKangXi=167.12
941C CJK UNIFIED IDEOGRAPH-#941C, IRGKangXi=1323.120, RSKangXi=167.12
941D CJK UNIFIED IDEOGRAPH-#941D, IRGKangXi=1323.121, RSKangXi=167.12, Def{a pick, a hoe}
941E CJK UNIFIED IDEOGRAPH-#941E, IRGKangXi=1323.121, RSKangXi=167.12
941F CJK UNIFIED IDEOGRAPH-#941F, IRGKangXi=1323.121, RSKangXi=167.12
9420 CJK UNIFIED IDEOGRAPH-#9420, IRGKangXi=1323.121, RSKangXi=167.12, Def{praseodymium}
9421 CJK UNIFIED IDEOGRAPH-#9421, IRGKangXi=1323.121, RSKangXi=167.12, Def{iron; strong, solid, firm}
9422 CJK UNIFIED IDEOGRAPH-#9422, IRGKangXi=1323.121, RSKangXi=167.12
9423 CJK UNIFIED IDEOGRAPH-#9423, IRGKangXi=1323.121, RSKangXi=167.12
9424 CJK UNIFIED IDEOGRAPH-#9424, IRGKangXi=1324.161, RSKangXi=167.13, Def{huge tripod of bronze with two ears; sacrificial vessel}
9425 CJK UNIFIED IDEOGRAPH-#9425, IRGKangXi=1323.121, RSKangXi=167.12
9426 CJK UNIFIED IDEOGRAPH-#9426, IRGKangXi=1323.121, RSKangXi=167.12, Def{californium}
9427 CJK UNIFIED IDEOGRAPH-#9427, IRGKangXi=1323.121, RSKangXi=167.12, Def{kind of rapier}
9428 CJK UNIFIED IDEOGRAPH-#9428, IRGKangXi=1323.121, RSKangXi=167.12, Def{fermium}
9429 CJK UNIFIED IDEOGRAPH-#9429, IRGKangXi=1323.130, RSKangXi=167.13, Def{lens}
942A CJK UNIFIED IDEOGRAPH-#942A, IRGKangXi=1323.150, RSKangXi=167.13
942B CJK UNIFIED IDEOGRAPH-#942B, IRGKangXi=1323.160, RSKangXi=167.13, Def{engraving tool; carve, engrave}
942C CJK UNIFIED IDEOGRAPH-#942C, IRGKangXi=1323.170, RSKangXi=167.13
942D CJK UNIFIED IDEOGRAPH-#942D, IRGKangXi=1323.180, RSKangXi=167.13
942E CJK UNIFIED IDEOGRAPH-#942E, IRGKangXi=1323.190, RSKangXi=167.13, Def{sickle}
942F CJK UNIFIED IDEOGRAPH-#942F, IRGKangXi=1323.200, RSKangXi=167.13
9430 CJK UNIFIED IDEOGRAPH-#9430, IRGKangXi=1323.210, RSKangXi=167.13
9431 CJK UNIFIED IDEOGRAPH-#9431, IRGKangXi=1323.260, RSKangXi=167.13
9432 CJK UNIFIED IDEOGRAPH-#9432, IRGKangXi=1323.290, RSKangXi=167.13, Def{bracelet, armband; small bell}
9433 CJK UNIFIED IDEOGRAPH-#9433, IRGKangXi=1323.320, RSKangXi=167.13, Def{radium}
9434 CJK UNIFIED IDEOGRAPH-#9434, IRGKangXi=1323.350, RSKangXi=167.13
9435 CJK UNIFIED IDEOGRAPH-#9435, IRGKangXi=1323.370, RSKangXi=167.13, Def{iron; strong, solid, firm}
9436 CJK UNIFIED IDEOGRAPH-#9436, IRGKangXi=1324.010, RSKangXi=167.13, Def{metal ring; measure of currency}
9437 CJK UNIFIED IDEOGRAPH-#9437, IRGKangXi=1324.030, RSKangXi=167.13
9438 CJK UNIFIED IDEOGRAPH-#9438, IRGKangXi=1324.060, RSKangXi=167.13, Def{bell; surname}
9439 CJK UNIFIED IDEOGRAPH-#9439, IRGKangXi=1324.070, RSKangXi=167.13
943A CJK UNIFIED IDEOGRAPH-#943A, IRGKangXi=1324.090, RSKangXi=167.13, Def{frying pan; warming vessel}
943B CJK UNIFIED IDEOGRAPH-#943B, IRGKangXi=1324.120, RSKangXi=167.13, Def{drumstick}
943C CJK UNIFIED IDEOGRAPH-#943C, IRGKangXi=1324.130, RSKangXi=167.13
943D CJK UNIFIED IDEOGRAPH-#943D, IRGKangXi=1324.140, RSKangXi=167.13
943E CJK UNIFIED IDEOGRAPH-#943E, IRGKangXi=1324.150, RSKangXi=167.13
943F CJK UNIFIED IDEOGRAPH-#943F, IRGKangXi=1324.161, RSKangXi=167.13, Def{ytterbium}
9440 CJK UNIFIED IDEOGRAPH-#9440, IRGKangXi=1324.161, RSKangXi=167.13, Def{ionium}
9441 CJK UNIFIED IDEOGRAPH-#9441, IRGKangXi=1324.161, RSKangXi=167.13
9442 CJK UNIFIED IDEOGRAPH-#9442, IRGKangXi=1324.180, RSKangXi=167.14
9443 CJK UNIFIED IDEOGRAPH-#9443, IRGKangXi=1324.210, RSKangXi=167.14
9444 CJK UNIFIED IDEOGRAPH-#9444, IRGKangXi=1324.230, RSKangXi=167.14, Def{melt, cast; coin, mint}
9445 CJK UNIFIED IDEOGRAPH-#9445, IRGKangXi=1324.250, RSKangXi=167.14
9446 CJK UNIFIED IDEOGRAPH-#9446, IRGKangXi=1324.270, RSKangXi=167.14
9447 CJK UNIFIED IDEOGRAPH-#9447, IRGKangXi=1324.280, RSKangXi=167.14
9448 CJK UNIFIED IDEOGRAPH-#9448, IRGKangXi=1324.290, RSKangXi=167.14
9449 CJK UNIFIED IDEOGRAPH-#9449, IRGKangXi=1325.020, RSKangXi=167.14
944A CJK UNIFIED IDEOGRAPH-#944A, IRGKangXi=1325.030, RSKangXi=167.14, Def{cauldron, large iron pot; a wok}
944B CJK UNIFIED IDEOGRAPH-#944B, IRGKangXi=1325.040, RSKangXi=167.14
944C CJK UNIFIED IDEOGRAPH-#944C, IRGKangXi=1325.050, RSKangXi=167.14, Def{high quality iron}
944D CJK UNIFIED IDEOGRAPH-#944D, IRGKangXi=1325.060, RSKangXi=167.14
944E CJK UNIFIED IDEOGRAPH-#944E, IRGKangXi=1325.070, RSKangXi=167.14
944F CJK UNIFIED IDEOGRAPH-#944F, IRGKangXi=1325.080, RSKangXi=167.14
9450 CJK UNIFIED IDEOGRAPH-#9450, IRGKangXi=1325.090, RSKangXi=167.14, Def{bolt of a Chinese lock}
9451 CJK UNIFIED IDEOGRAPH-#9451, IRGKangXi=1325.100, RSKangXi=167.14, Def{mirror, looking glass; reflect}
9452 CJK UNIFIED IDEOGRAPH-#9452, IRGKangXi=1325.110, RSKangXi=167.14, Def{mirror, looking glass; reflect}
9453 CJK UNIFIED IDEOGRAPH-#9453, IRGKangXi=1325.181, RSKangXi=167.14, Def{spear, lance, javelin}
9454 CJK UNIFIED IDEOGRAPH-#9454, IRGKangXi=1325.181, RSKangXi=167.14, Def{cymbals}
9455 CJK UNIFIED IDEOGRAPH-#9455, IRGKangXi=1325.190, RSKangXi=167.15, Def{tungsten, wolfram}
9456 CJK UNIFIED IDEOGRAPH-#9456, IRGKangXi=1325.210, RSKangXi=167.15
9457 CJK UNIFIED IDEOGRAPH-#9457, IRGKangXi=1325.230, RSKangXi=167.15
9458 CJK UNIFIED IDEOGRAPH-#9458, IRGKangXi=1325.240, RSKangXi=167.15
9459 CJK UNIFIED IDEOGRAPH-#9459, IRGKangXi=1326.121, RSKangXi=167.15
945A CJK UNIFIED IDEOGRAPH-#945A, IRGKangXi=1325.270, RSKangXi=167.15, Def{drill, bore; pierce; diamond}
945B CJK UNIFIED IDEOGRAPH-#945B, IRGKangXi=1325.280, RSKangXi=167.15, Def{mine; mineral, ore}
945C CJK UNIFIED IDEOGRAPH-#945C, IRGKangXi=1325.310, RSKangXi=167.15
945D CJK UNIFIED IDEOGRAPH-#945D, IRGKangXi=1325.320, RSKangXi=167.15
945E CJK UNIFIED IDEOGRAPH-#945E, IRGKangXi=1326.010, RSKangXi=167.15, Def{solder; tin}
945F CJK UNIFIED IDEOGRAPH-#945F, IRGKangXi=1326.030, RSKangXi=167.15
9460 CJK UNIFIED IDEOGRAPH-#9460, IRGKangXi=1326.060, RSKangXi=167.15, Def{melt, smelt; shine}
9461 CJK UNIFIED IDEOGRAPH-#9461, IRGKangXi=1326.070, RSKangXi=167.15
9462 CJK UNIFIED IDEOGRAPH-#9462, IRGKangXi=1326.080, RSKangXi=167.15, Def{file, rasp; file; polish; (Cant.) to cut}
9463 CJK UNIFIED IDEOGRAPH-#9463, IRGKangXi=1326.090, RSKangXi=167.15, Def{bit, bridle; ride}
9464 CJK UNIFIED IDEOGRAPH-#9464, IRGKangXi=1326.121, RSKangXi=167.15, Def{carpenter's plane}
9465 CJK UNIFIED IDEOGRAPH-#9465, IRGKangXi=1326.121, RSKangXi=167.15, Def{lutetium}
9466 CJK UNIFIED IDEOGRAPH-#9466, IRGKangXi=1326.121, RSKangXi=167.15
9467 CJK UNIFIED IDEOGRAPH-#9467, IRGKangXi=1326.121, RSKangXi=167.14
9468 CJK UNIFIED IDEOGRAPH-#9468, IRGKangXi=1326.160, RSKangXi=167.16
9469 CJK UNIFIED IDEOGRAPH-#9469, IRGKangXi=1326.190, RSKangXi=167.16
946A CJK UNIFIED IDEOGRAPH-#946A, IRGKangXi=1326.200, RSKangXi=167.16, Def{fireplace, stove, oven, furnace}
946B CJK UNIFIED IDEOGRAPH-#946B, IRGKangXi=1326.220, RSKangXi=167.16, Def{used in names}
946C CJK UNIFIED IDEOGRAPH-#946C, IRGKangXi=1326.261, RSKangXi=167.16
946D CJK UNIFIED IDEOGRAPH-#946D, IRGKangXi=1326.270, RSKangXi=167.17, Def{lanthanum}
946E CJK UNIFIED IDEOGRAPH-#946E, IRGKangXi=1326.290, RSKangXi=167.17
946F CJK UNIFIED IDEOGRAPH-#946F, IRGKangXi=1326.300, RSKangXi=167.17
9470 CJK UNIFIED IDEOGRAPH-#9470, IRGKangXi=1326.310, RSKangXi=167.17, Def{key; lock}
9471 CJK UNIFIED IDEOGRAPH-#9471, IRGKangXi=1326.320, RSKangXi=167.17, Def{spade, trowel}
9472 CJK UNIFIED IDEOGRAPH-#9472, IRGKangXi=1327.010, RSKangXi=167.17, Def{insert, inlay, set, mount; fill}
9473 CJK UNIFIED IDEOGRAPH-#9473, IRGKangXi=1327.030, RSKangXi=167.17
9474 CJK UNIFIED IDEOGRAPH-#9474, IRGKangXi=1327.070, RSKangXi=167.18, Def{to engrave or carve, as a block for printing}
9475 CJK UNIFIED IDEOGRAPH-#9475, IRGKangXi=1327.100, RSKangXi=167.18, Def{jar; can}
9476 CJK UNIFIED IDEOGRAPH-#9476, IRGKangXi=1327.130, RSKangXi=167.18
9477 CJK UNIFIED IDEOGRAPH-#9477, IRGKangXi=1327.150, RSKangXi=167.18, Def{tweezers, forceps, pincers}
9478 CJK UNIFIED IDEOGRAPH-#9478, IRGKangXi=1327.160, RSKangXi=167.18
9479 CJK UNIFIED IDEOGRAPH-#9479, IRGKangXi=1327.180, RSKangXi=167.18, Def{pick, poker}
947A CJK UNIFIED IDEOGRAPH-#947A, IRGKangXi=1327.190, RSKangXi=167.18
947B CJK UNIFIED IDEOGRAPH-#947B, IRGKangXi=1327.250, RSKangXi=167.19
947C CJK UNIFIED IDEOGRAPH-#947C, IRGKangXi=1327.260, RSKangXi=167.19, Def{gong}
947D CJK UNIFIED IDEOGRAPH-#947D, IRGKangXi=1327.270, RSKangXi=167.19, Def{drill, bore; pierce; diamond}
947E CJK UNIFIED IDEOGRAPH-#947E, IRGKangXi=1327.280, RSKangXi=167.19, Def{bells hung on horse; bells hung}
947F CJK UNIFIED IDEOGRAPH-#947F, IRGKangXi=1327.290, RSKangXi=167.19, Def{chisel; bore, pierce}
9480 CJK UNIFIED IDEOGRAPH-#9480, IRGKangXi=1328.040, RSKangXi=167.20
9481 CJK UNIFIED IDEOGRAPH-#9481, IRGKangXi=1328.050, RSKangXi=167.20, Def{a mattock; a billhook}
9482 CJK UNIFIED IDEOGRAPH-#9482, IRGKangXi=1328.051, RSKangXi=167.20
9483 CJK UNIFIED IDEOGRAPH-#9483, IRGKangXi=1328.060, RSKangXi=167.21
9484 CJK UNIFIED IDEOGRAPH-#9484, IRGKangXi=1328.061, RSKangXi=167.21
9485 CJK UNIFIED IDEOGRAPH-#9485, IRGKangXi=1328.061, RSKangXi=167.0, Def{gold; money; KangXi radical 167}
9486 CJK UNIFIED IDEOGRAPH-#9486, IRGKangXi=1328.061, RSKangXi=167.1, Def{gadolinium}
9487 CJK UNIFIED IDEOGRAPH-#9487, IRGKangXi=1328.061, RSKangXi=167.1, Def{yttrium}
9488 CJK UNIFIED IDEOGRAPH-#9488, IRGKangXi=1328.061, RSKangXi=167.2, Def{needle; pin; tack; acupuncture}
9489 CJK UNIFIED IDEOGRAPH-#9489, IRGKangXi=1328.061, RSKangXi=167.2, Def{nail, spike; pursue closely}
948A CJK UNIFIED IDEOGRAPH-#948A, IRGKangXi=1328.061, RSKangXi=167.2, Def{endeavor, strive; encourage; cut}
948B CJK UNIFIED IDEOGRAPH-#948B, IRGKangXi=1328.061, RSKangXi=167.2, Def{polonium}
948C CJK UNIFIED IDEOGRAPH-#948C, IRGKangXi=1328.061, RSKangXi=167.2, Def{ruthenium}
948D CJK UNIFIED IDEOGRAPH-#948D, IRGKangXi=1328.061, RSKangXi=167.3, Def{thorium}
948E CJK UNIFIED IDEOGRAPH-#948E, IRGKangXi=1328.061, RSKangXi=167.3, Def{tool for boring holes}
948F CJK UNIFIED IDEOGRAPH-#948F, IRGKangXi=1328.061, RSKangXi=167.3, Def{bracelet, armlet}
9490 CJK UNIFIED IDEOGRAPH-#9490, IRGKangXi=1328.061, RSKangXi=167.3, Def{samarium}
9491 CJK UNIFIED IDEOGRAPH-#9491, IRGKangXi=1328.061, RSKangXi=167.3, Def{spear}
9492 CJK UNIFIED IDEOGRAPH-#9492, IRGKangXi=1328.061, RSKangXi=167.3, Def{vanadium}
9493 CJK UNIFIED IDEOGRAPH-#9493, IRGKangXi=1328.061, RSKangXi=167.3, Def{fish; fishhook; tempt, lure}
9494 CJK UNIFIED IDEOGRAPH-#9494, IRGKangXi=1328.061, RSKangXi=167.3, Def{mendelevium (Md)}
9495 CJK UNIFIED IDEOGRAPH-#9495, IRGKangXi=1328.061, RSKangXi=167.3, Def{neodymium}
9496 CJK UNIFIED IDEOGRAPH-#9496, IRGKangXi=1328.061, RSKangXi=167.3, Def{frontlet}
9497 CJK UNIFIED IDEOGRAPH-#9497, IRGKangXi=1328.061, RSKangXi=167.3, Def{ornamental hairpin}
9498 CJK UNIFIED IDEOGRAPH-#9498, IRGKangXi=1328.061, RSKangXi=167.4, Def{ancient wine vessel}
9499 CJK UNIFIED IDEOGRAPH-#9499, IRGKangXi=1328.061, RSKangXi=167.4, Def{calcium}
949A CJK UNIFIED IDEOGRAPH-#949A, IRGKangXi=1328.061, RSKangXi=167.4, Def{plutonium}
949B CJK UNIFIED IDEOGRAPH-#949B, IRGKangXi=1328.061, RSKangXi=167.4, Def{titanium}
949C CJK UNIFIED IDEOGRAPH-#949C, IRGKangXi=1328.061, RSKangXi=167.4, Def{steel, iron; great}
949D CJK UNIFIED IDEOGRAPH-#949D, IRGKangXi=1328.061, RSKangXi=167.4, Def{blunt, obtuse; dull; flat; dull-witted}
949E CJK UNIFIED IDEOGRAPH-#949E, IRGKangXi=1328.061, RSKangXi=167.4, Def{paper money, bank notes; copy}
949F CJK UNIFIED IDEOGRAPH-#949F, IRGKangXi=1328.061, RSKangXi=167.4, Def{clock; bell}
94A0 CJK UNIFIED IDEOGRAPH-#94A0, IRGKangXi=1328.061, RSKangXi=167.4, Def{sodium, natrium; sharpen wood}
94A1 CJK UNIFIED IDEOGRAPH-#94A1, IRGKangXi=1328.061, RSKangXi=167.4, Def{barium}
94A2 CJK UNIFIED IDEOGRAPH-#94A2, IRGKangXi=1328.061, RSKangXi=167.4, Def{steel; hard, strong, tough}
94A3 CJK UNIFIED IDEOGRAPH-#94A3, IRGKangXi=1328.061, RSKangXi=167.4, Def{plate}
94A4 CJK UNIFIED IDEOGRAPH-#94A4, IRGKangXi=1328.061, RSKangXi=167.4, Def{lock, latch; stamp, seal}
94A5 CJK UNIFIED IDEOGRAPH-#94A5, IRGKangXi=1328.061, RSKangXi=167.4, Def{key; lock}
94A6 CJK UNIFIED IDEOGRAPH-#94A6, IRGKangXi=1328.061, RSKangXi=167.4, Def{respect, admire; respectful}
94A7 CJK UNIFIED IDEOGRAPH-#94A7, IRGKangXi=1328.061, RSKangXi=167.4, Def{unit of measure equivalent to thirty catties}
94A8 CJK UNIFIED IDEOGRAPH-#94A8, IRGKangXi=1328.061, RSKangXi=167.5, Def{tungsten, wolfram}
94A9 CJK UNIFIED IDEOGRAPH-#94A9, IRGKangXi=1328.061, RSKangXi=167.5, Def{hook, barb; sickle; stroke with}
94AA CJK UNIFIED IDEOGRAPH-#94AA, IRGKangXi=1328.061, RSKangXi=167.4, Def{scandium}
94AB CJK UNIFIED IDEOGRAPH-#94AB, IRGKangXi=1328.061, RSKangXi=167.4, Def{francium}
94AC CJK UNIFIED IDEOGRAPH-#94AC, IRGKangXi=1328.061, RSKangXi=167.4, Def{holmium}
94AD CJK UNIFIED IDEOGRAPH-#94AD, IRGKangXi=1328.061, RSKangXi=167.4, Def{a wine flagon}
94AE CJK UNIFIED IDEOGRAPH-#94AE, IRGKangXi=1328.061, RSKangXi=167.4, Def{button, knob; surname}
94AF CJK UNIFIED IDEOGRAPH-#94AF, IRGKangXi=1328.061, RSKangXi=167.4, Def{palladium}
94B0 CJK UNIFIED IDEOGRAPH-#94B0, IRGKangXi=1328.061, RSKangXi=167.5, Def{rare treasure}
94B1 CJK UNIFIED IDEOGRAPH-#94B1, IRGKangXi=1328.061, RSKangXi=167.5, Def{money, currency, coins}
94B2 CJK UNIFIED IDEOGRAPH-#94B2, IRGKangXi=1328.061, RSKangXi=167.5, Def{kind of gong used in ancient times by troops on the march}
94B3 CJK UNIFIED IDEOGRAPH-#94B3, IRGKangXi=1328.061, RSKangXi=167.5, Def{pincers, pliers, tongs; to compress}
94B4 CJK UNIFIED IDEOGRAPH-#94B4, IRGKangXi=1328.061, RSKangXi=167.5, Def{cobalt; household iron}
94B5 CJK UNIFIED IDEOGRAPH-#94B5, IRGKangXi=1328.061, RSKangXi=167.5, Def{earthenware basin; alms bowl}
94B6 CJK UNIFIED IDEOGRAPH-#94B6, IRGKangXi=1328.061, RSKangXi=167.5, Def{columbium}
94B7 CJK UNIFIED IDEOGRAPH-#94B7, IRGKangXi=1328.061, RSKangXi=167.5, Def{promethium}
94B8 CJK UNIFIED IDEOGRAPH-#94B8, IRGKangXi=1328.061, RSKangXi=167.5, Def{plutonium}
94B9 CJK UNIFIED IDEOGRAPH-#94B9, IRGKangXi=1328.061, RSKangXi=167.5, Def{cymbals}
94BA CJK UNIFIED IDEOGRAPH-#94BA, IRGKangXi=1328.061, RSKangXi=167.5, Def{broad-axe, a battle axe, halberd}
94BB CJK UNIFIED IDEOGRAPH-#94BB, IRGKangXi=1328.061, RSKangXi=167.5, Def{drill, bore; pierce; diamond}
94BC CJK UNIFIED IDEOGRAPH-#94BC, IRGKangXi=1328.061, RSKangXi=167.5, Def{molybdenum}
94BD CJK UNIFIED IDEOGRAPH-#94BD, IRGKangXi=1328.061, RSKangXi=167.5, Def{tantalum}
94BE CJK UNIFIED IDEOGRAPH-#94BE, IRGKangXi=1328.061, RSKangXi=167.5, Def{potassium}
94BF CJK UNIFIED IDEOGRAPH-#94BF, IRGKangXi=1328.061, RSKangXi=167.5, Def{hairpin; gold inlaid work, filigree}
94C0 CJK UNIFIED IDEOGRAPH-#94C0, IRGKangXi=1328.061, RSKangXi=167.5, Def{uranium}
94C1 CJK UNIFIED IDEOGRAPH-#94C1, IRGKangXi=1328.061, RSKangXi=167.5, Def{iron; strong, solid, firm}
94C2 CJK UNIFIED IDEOGRAPH-#94C2, IRGKangXi=1328.061, RSKangXi=167.5, Def{platinum; thin sheet of metal}
94C3 CJK UNIFIED IDEOGRAPH-#94C3, IRGKangXi=1328.061, RSKangXi=167.5, Def{bell}
94C4 CJK UNIFIED IDEOGRAPH-#94C4, IRGKangXi=1328.061, RSKangXi=167.5, Def{melt, smelt; shine}
94C5 CJK UNIFIED IDEOGRAPH-#94C5, IRGKangXi=1328.061, RSKangXi=167.5, Def{lead}
94C6 CJK UNIFIED IDEOGRAPH-#94C6, IRGKangXi=1328.061, RSKangXi=167.5, Def{rivet}
94C7 CJK UNIFIED IDEOGRAPH-#94C7, IRGKangXi=1328.061, RSKangXi=167.5, Def{carpenter's plane}
94C8 CJK UNIFIED IDEOGRAPH-#94C8, IRGKangXi=1328.061, RSKangXi=167.5, Def{cerium}
94C9 CJK UNIFIED IDEOGRAPH-#94C9, IRGKangXi=1328.061, RSKangXi=167.5, Def{device for carrying a tripod}
94CA CJK UNIFIED IDEOGRAPH-#94CA, IRGKangXi=1328.061, RSKangXi=167.5, Def{thallium}
94CB CJK UNIFIED IDEOGRAPH-#94CB, IRGKangXi=1328.061, RSKangXi=167.5, Def{bismuth}
94CC CJK UNIFIED IDEOGRAPH-#94CC, IRGKangXi=1328.061, RSKangXi=167.5, Def{niobium}
94CD CJK UNIFIED IDEOGRAPH-#94CD, IRGKangXi=1328.061, RSKangXi=167.5, Def{beryllium}
94CE CJK UNIFIED IDEOGRAPH-#94CE, IRGKangXi=1328.061, RSKangXi=167.5, Def{bell; surname}
94CF CJK UNIFIED IDEOGRAPH-#94CF, IRGKangXi=1328.061, RSKangXi=167.6, Def{sacrificial cauldron}
94D0 CJK UNIFIED IDEOGRAPH-#94D0, IRGKangXi=1328.061, RSKangXi=167.6, Def{shackles, manacles}
94D1 CJK UNIFIED IDEOGRAPH-#94D1, IRGKangXi=1328.061, RSKangXi=167.6, Def{rhodium}
94D2 CJK UNIFIED IDEOGRAPH-#94D2, IRGKangXi=1328.061, RSKangXi=167.6, Def{erbium}
94D3 CJK UNIFIED IDEOGRAPH-#94D3, IRGKangXi=1328.061, RSKangXi=167.7, Def{point of sword; sharp point}
94D4 CJK UNIFIED IDEOGRAPH-#94D4, IRGKangXi=1328.061, RSKangXi=167.8, Def{soft steel; ammonium}
94D5 CJK UNIFIED IDEOGRAPH-#94D5, IRGKangXi=1328.061, RSKangXi=167.6, Def{europium}
94D6 CJK UNIFIED IDEOGRAPH-#94D6, IRGKangXi=1328.061, RSKangXi=167.6, Def{person's name}
94D7 CJK UNIFIED IDEOGRAPH-#94D7, IRGKangXi=1328.061, RSKangXi=167.6, Def{tongs, pincers; dagger; sword}
94D8 CJK UNIFIED IDEOGRAPH-#94D8, IRGKangXi=1328.061, RSKangXi=167.7, Def{sword}
94D9 CJK UNIFIED IDEOGRAPH-#94D9, IRGKangXi=1328.061, RSKangXi=167.6, Def{cymbals; hand bell; disturb}
94DA CJK UNIFIED IDEOGRAPH-#94DA, IRGKangXi=1328.061, RSKangXi=167.6, Def{a sickle}
94DB CJK UNIFIED IDEOGRAPH-#94DB, IRGKangXi=1328.061, RSKangXi=167.6, Def{frying pan; warming vessel}
94DC CJK UNIFIED IDEOGRAPH-#94DC, IRGKangXi=1328.061, RSKangXi=167.6, Def{copper, brass, bronze}
94DD CJK UNIFIED IDEOGRAPH-#94DD, IRGKangXi=1328.061, RSKangXi=167.6, Def{aluminum}
94DE CJK UNIFIED IDEOGRAPH-#94DE, IRGKangXi=1328.061, RSKangXi=167.6
94DF CJK UNIFIED IDEOGRAPH-#94DF, IRGKangXi=1328.061, RSKangXi=167.6, Def{indium}
94E0 CJK UNIFIED IDEOGRAPH-#94E0, IRGKangXi=1328.061, RSKangXi=167.6, Def{armor, chain mail}
94E1 CJK UNIFIED IDEOGRAPH-#94E1, IRGKangXi=1328.061, RSKangXi=167.6, Def{sickle for cutting grass or hay}
94E2 CJK UNIFIED IDEOGRAPH-#94E2, IRGKangXi=1328.061, RSKangXi=167.6, Def{unit of weight, one twenty-fourth of a Chinese ounce (liang)}
94E3 CJK UNIFIED IDEOGRAPH-#94E3, IRGKangXi=1328.061, RSKangXi=167.6, Def{mill}
94E4 CJK UNIFIED IDEOGRAPH-#94E4, IRGKangXi=1328.061, RSKangXi=167.7, Def{ingots, bars of metal; hurry}
94E5 CJK UNIFIED IDEOGRAPH-#94E5, IRGKangXi=1328.061, RSKangXi=167.6, Def{thulium}
94E6 CJK UNIFIED IDEOGRAPH-#94E6, IRGKangXi=1328.061, RSKangXi=167.6, Def{sharp, keen-edged; a kind of hoe}
94E7 CJK UNIFIED IDEOGRAPH-#94E7, IRGKangXi=1328.061, RSKangXi=167.6, Def{spade, shovel, plowshare}
94E8 CJK UNIFIED IDEOGRAPH-#94E8, IRGKangXi=1328.061, RSKangXi=167.6, Def{weigh, measure; select officials}
94E9 CJK UNIFIED IDEOGRAPH-#94E9, IRGKangXi=1328.061, RSKangXi=167.6, Def{moult}
94EA CJK UNIFIED IDEOGRAPH-#94EA, IRGKangXi=1328.061, RSKangXi=167.6, Def{hafnium}
94EB CJK UNIFIED IDEOGRAPH-#94EB, IRGKangXi=1328.061, RSKangXi=167.6, Def{large hoe; surname; a spear}
94EC CJK UNIFIED IDEOGRAPH-#94EC, IRGKangXi=1328.061, RSKangXi=167.6, Def{chromium}
94ED CJK UNIFIED IDEOGRAPH-#94ED, IRGKangXi=1328.061, RSKangXi=167.6, Def{inscribe, engrave}
94EE CJK UNIFIED IDEOGRAPH-#94EE, IRGKangXi=1328.061, RSKangXi=167.8, Def{clanging sound; small gong}
94EF CJK UNIFIED IDEOGRAPH-#94EF, IRGKangXi=1328.061, RSKangXi=167.6, Def{cesium}
94F0 CJK UNIFIED IDEOGRAPH-#94F0, IRGKangXi=1328.061, RSKangXi=167.6, Def{hinge; shears, scissors}
94F1 CJK UNIFIED IDEOGRAPH-#94F1, IRGKangXi=1328.061, RSKangXi=167.6, Def{iridium}
94F2 CJK UNIFIED IDEOGRAPH-#94F2, IRGKangXi=1328.061, RSKangXi=167.6, Def{spade, shovel, trowel, scoop}
94F3 CJK UNIFIED IDEOGRAPH-#94F3, IRGKangXi=1328.061, RSKangXi=167.5, Def{ancient weapon, blunderbuss}
94F4 CJK UNIFIED IDEOGRAPH-#94F4, IRGKangXi=1328.061, RSKangXi=167.7, Def{gong}
94F5 CJK UNIFIED IDEOGRAPH-#94F5, IRGKangXi=1328.061, RSKangXi=167.6, Def{ammonium}
94F6 CJK UNIFIED IDEOGRAPH-#94F6, IRGKangXi=1328.061, RSKangXi=167.6, Def{silver; cash, money, wealth}
94F7 CJK UNIFIED IDEOGRAPH-#94F7, IRGKangXi=1328.061, RSKangXi=167.6, Def{rubidium}
94F8 CJK UNIFIED IDEOGRAPH-#94F8, IRGKangXi=1328.061, RSKangXi=167.7, Def{melt, cast; coin, mint}
94F9 CJK UNIFIED IDEOGRAPH-#94F9, IRGKangXi=1328.061, RSKangXi=167.7, Def{lawrencium (Lr)}
94FA CJK UNIFIED IDEOGRAPH-#94FA, IRGKangXi=1328.061, RSKangXi=167.7, Def{shop, store; place sleep, bed}
94FB CJK UNIFIED IDEOGRAPH-#94FB, IRGKangXi=1328.061, RSKangXi=167.7, Def{misfit; disordant; music instrument; hoe}
94FC CJK UNIFIED IDEOGRAPH-#94FC, IRGKangXi=1328.061, RSKangXi=167.7, Def{rhenium}
94FD CJK UNIFIED IDEOGRAPH-#94FD, IRGKangXi=1328.061, RSKangXi=167.7, Def{terbium}
94FE CJK UNIFIED IDEOGRAPH-#94FE, IRGKangXi=1328.061, RSKangXi=167.7, Def{chain, wire, cable; chain, shack}
94FF CJK UNIFIED IDEOGRAPH-#94FF, IRGKangXi=1328.061, RSKangXi=167.7, Def{strike, beat, stroke; jingling}
9500 CJK UNIFIED IDEOGRAPH-#9500, IRGKangXi=1328.061, RSKangXi=167.7, Def{melt, fuse; market, sell}
9501 CJK UNIFIED IDEOGRAPH-#9501, IRGKangXi=1328.061, RSKangXi=167.7, Def{lock, padlock; shackles, chains}
9502 CJK UNIFIED IDEOGRAPH-#9502, IRGKangXi=1328.061, RSKangXi=167.7, Def{lithium}
9503 CJK UNIFIED IDEOGRAPH-#9503, IRGKangXi=1328.061, RSKangXi=167.7, Def{polish}
9504 CJK UNIFIED IDEOGRAPH-#9504, IRGKangXi=1328.061, RSKangXi=167.7, Def{hoe; eradicate}
9505 CJK UNIFIED IDEOGRAPH-#9505, IRGKangXi=1328.061, RSKangXi=167.7, Def{cooking-pot, saucepan}
9506 CJK UNIFIED IDEOGRAPH-#9506, IRGKangXi=1328.061, RSKangXi=167.7, Def{zirconium}
9507 CJK UNIFIED IDEOGRAPH-#9507, IRGKangXi=1328.061, RSKangXi=167.7, Def{osmium}
9508 CJK UNIFIED IDEOGRAPH-#9508, IRGKangXi=1328.061, RSKangXi=167.7, Def{rust, corrode}
9509 CJK UNIFIED IDEOGRAPH-#9509, IRGKangXi=1328.061, RSKangXi=167.7, Def{carpenter's file, file smooth}
950A CJK UNIFIED IDEOGRAPH-#950A, IRGKangXi=1328.061, RSKangXi=167.7, Def{6 oz; ancient measurement}
950B CJK UNIFIED IDEOGRAPH-#950B, IRGKangXi=1328.061, RSKangXi=167.7, Def{point of spear, sharp point}
950C CJK UNIFIED IDEOGRAPH-#950C, IRGKangXi=1328.061, RSKangXi=167.7, Def{zinc}
950D CJK UNIFIED IDEOGRAPH-#950D, IRGKangXi=1328.061, RSKangXi=167.7
950E CJK UNIFIED IDEOGRAPH-#950E, IRGKangXi=1328.061, RSKangXi=167.7, Def{caesium}
950F CJK UNIFIED IDEOGRAPH-#950F, IRGKangXi=1328.061, RSKangXi=167.7, Def{kind of rapier}
9510 CJK UNIFIED IDEOGRAPH-#9510, IRGKangXi=1328.061, RSKangXi=167.7, Def{sharp, keen, acute, pointed}
9511 CJK UNIFIED IDEOGRAPH-#9511, IRGKangXi=1328.061, RSKangXi=167.7, Def{antimony}
9512 CJK UNIFIED IDEOGRAPH-#9512, IRGKangXi=1328.061, RSKangXi=167.7, Def{lock}
9513 CJK UNIFIED IDEOGRAPH-#9513, IRGKangXi=1328.061, RSKangXi=167.7, Def{carve}
9514 CJK UNIFIED IDEOGRAPH-#9514, IRGKangXi=1328.061, RSKangXi=167.7, Def{curium}
9515 CJK UNIFIED IDEOGRAPH-#9515, IRGKangXi=1328.061, RSKangXi=167.8, Def{actinium (Ac)}
9516 CJK UNIFIED IDEOGRAPH-#9516, IRGKangXi=1328.061, RSKangXi=167.8, Def{the color of the a mineral}
9517 CJK UNIFIED IDEOGRAPH-#9517, IRGKangXi=1328.061, RSKangXi=167.8, Def{germanium}
9518 CJK UNIFIED IDEOGRAPH-#9518, IRGKangXi=1328.061, RSKangXi=167.8, Def{nobelium (No)}
9519 CJK UNIFIED IDEOGRAPH-#9519, IRGKangXi=1328.061, RSKangXi=167.8, Def{error, blunder, mistake; wrong}
951A CJK UNIFIED IDEOGRAPH-#951A, IRGKangXi=1328.061, RSKangXi=167.8, Def{anchor}
951B CJK UNIFIED IDEOGRAPH-#951B, IRGKangXi=1328.061, RSKangXi=167.8, Def{adze}
951C CJK UNIFIED IDEOGRAPH-#951C, IRGKangXi=1328.061, RSKangXi=167.8, Def{a kind of pen; a kind of chisel}
951D CJK UNIFIED IDEOGRAPH-#951D, IRGKangXi=1328.061, RSKangXi=167.8, Def{technetium}
951E CJK UNIFIED IDEOGRAPH-#951E, IRGKangXi=1328.061, RSKangXi=167.8, Def{ingot; acrobatic move}
951F CJK UNIFIED IDEOGRAPH-#951F, IRGKangXi=1328.061, RSKangXi=167.8, Def{ancient treasured sword}
9520 CJK UNIFIED IDEOGRAPH-#9520, IRGKangXi=1328.061, RSKangXi=167.8, Def{vessel}
9521 CJK UNIFIED IDEOGRAPH-#9521, IRGKangXi=1328.061, RSKangXi=167.8, Def{tin, stannum; bestow, confer}
9522 CJK UNIFIED IDEOGRAPH-#9522, IRGKangXi=1328.061, RSKangXi=167.8, Def{run metal into cracks; confine}
9523 CJK UNIFIED IDEOGRAPH-#9523, IRGKangXi=1328.061, RSKangXi=167.8, Def{gong}
9524 CJK UNIFIED IDEOGRAPH-#9524, IRGKangXi=1328.061, RSKangXi=167.8, Def{balance weight on scale; hammer}
9525 CJK UNIFIED IDEOGRAPH-#9525, IRGKangXi=1328.061, RSKangXi=167.8, Def{gimlet, awl, drill, auger; bore}
9526 CJK UNIFIED IDEOGRAPH-#9526, IRGKangXi=1328.061, RSKangXi=167.8, Def{brocade, tapestry; embroidered}
9527 CJK UNIFIED IDEOGRAPH-#9527, IRGKangXi=1328.061, RSKangXi=167.15, Def{tungsten, wolfram}
9528 CJK UNIFIED IDEOGRAPH-#9528, IRGKangXi=1328.061, RSKangXi=167.8, Def{shovel}
9529 CJK UNIFIED IDEOGRAPH-#9529, IRGKangXi=1328.061, RSKangXi=167.8, Def{to bend iron}
952A CJK UNIFIED IDEOGRAPH-#952A, IRGKangXi=1328.061, RSKangXi=167.8, Def{a kind of tool}
952B CJK UNIFIED IDEOGRAPH-#952B, IRGKangXi=1328.061, RSKangXi=167.8, Def{berkelium}
952C CJK UNIFIED IDEOGRAPH-#952C, IRGKangXi=1328.061, RSKangXi=167.8, Def{long spear}
952D CJK UNIFIED IDEOGRAPH-#952D, IRGKangXi=1328.061, RSKangXi=167.8, Def{spindle, slab, cake, tablet}
952E CJK UNIFIED IDEOGRAPH-#952E, IRGKangXi=1328.061, RSKangXi=167.8, Def{door bolt, lock bolt; key}
952F CJK UNIFIED IDEOGRAPH-#952F, IRGKangXi=1328.061, RSKangXi=167.8, Def{a saw; to saw; amputate}
9530 CJK UNIFIED IDEOGRAPH-#9530, IRGKangXi=1328.061, RSKangXi=167.8, Def{manganese}
9531 CJK UNIFIED IDEOGRAPH-#9531, IRGKangXi=1328.061, RSKangXi=167.8, Def{8 oz; an ancient unit of weight}
9532 CJK UNIFIED IDEOGRAPH-#9532, IRGKangXi=1328.061, RSKangXi=167.9, Def{sickle; cut, carve, engrave}
9533 CJK UNIFIED IDEOGRAPH-#9533, IRGKangXi=1328.061, RSKangXi=167.8
9534 CJK UNIFIED IDEOGRAPH-#9534, IRGKangXi=1328.061, RSKangXi=167.9, Def{high quality iron}
9535 CJK UNIFIED IDEOGRAPH-#9535, IRGKangXi=1328.061, RSKangXi=167.9, Def{tinkle, clang, jingle}
9536 CJK UNIFIED IDEOGRAPH-#9536, IRGKangXi=1328.061, RSKangXi=167.9, Def{strontium}
9537 CJK UNIFIED IDEOGRAPH-#9537, IRGKangXi=1328.061, RSKangXi=167.9, Def{high, lofty; edge of knife}
9538 CJK UNIFIED IDEOGRAPH-#9538, IRGKangXi=1328.061, RSKangXi=167.9, Def{spade, shovel; marking pin}
9539 CJK UNIFIED IDEOGRAPH-#9539, IRGKangXi=1328.061, RSKangXi=167.9, Def{shovel}
953A CJK UNIFIED IDEOGRAPH-#953A, IRGKangXi=1328.061, RSKangXi=167.9, Def{cup, glass, goblet; surname}
953B CJK UNIFIED IDEOGRAPH-#953B, IRGKangXi=1328.061, RSKangXi=167.9, Def{forge metal; temper, refine}
953C CJK UNIFIED IDEOGRAPH-#953C, IRGKangXi=1328.061, RSKangXi=167.9, Def{carve}
953D CJK UNIFIED IDEOGRAPH-#953D, IRGKangXi=1328.061, RSKangXi=167.9, Def{weapon}
953E CJK UNIFIED IDEOGRAPH-#953E, IRGKangXi=1328.061, RSKangXi=167.9, Def{measure; money, coins}
953F CJK UNIFIED IDEOGRAPH-#953F, IRGKangXi=1328.061, RSKangXi=167.9, Def{einsteinium (Es)}
9540 CJK UNIFIED IDEOGRAPH-#9540, IRGKangXi=1328.061, RSKangXi=167.9, Def{plate, coat, gild}
9541 CJK UNIFIED IDEOGRAPH-#9541, IRGKangXi=1328.061, RSKangXi=167.9, Def{magnesium}
9542 CJK UNIFIED IDEOGRAPH-#9542, IRGKangXi=1328.061, RSKangXi=167.9, Def{carve, inlay, engrave, tattoo}
9543 CJK UNIFIED IDEOGRAPH-#9543, IRGKangXi=1328.061, RSKangXi=167.9, Def{hoe; mattock}
9544 CJK UNIFIED IDEOGRAPH-#9544, IRGKangXi=1328.061, RSKangXi=167.9, Def{fermium}
9545 CJK UNIFIED IDEOGRAPH-#9545, IRGKangXi=1328.061, RSKangXi=167.9, Def{americium}
9546 CJK UNIFIED IDEOGRAPH-#9546, IRGKangXi=1328.061, RSKangXi=167.10, Def{sword}
9547 CJK UNIFIED IDEOGRAPH-#9547, IRGKangXi=1328.061, RSKangXi=167.10, Def{town, market place; suppress}
9548 CJK UNIFIED IDEOGRAPH-#9548, IRGKangXi=1328.061, RSKangXi=167.10, Def{large bell; hoe, spade}
9549 CJK UNIFIED IDEOGRAPH-#9549, IRGKangXi=1328.061, RSKangXi=167.10, Def{cadmium}
954A CJK UNIFIED IDEOGRAPH-#954A, IRGKangXi=1328.061, RSKangXi=167.10, Def{tweezers, forceps, pincers}
954B CJK UNIFIED IDEOGRAPH-#954B, IRGKangXi=1328.061, RSKangXi=167.20
954C CJK UNIFIED IDEOGRAPH-#954C, IRGKangXi=1328.061, RSKangXi=167.10, Def{engraving tool; carve, engrave}
954D CJK UNIFIED IDEOGRAPH-#954D, IRGKangXi=1328.061, RSKangXi=167.10, Def{nickel}
954E CJK UNIFIED IDEOGRAPH-#954E, IRGKangXi=1328.061, RSKangXi=167.10, Def{neptunium (Np)}
954F CJK UNIFIED IDEOGRAPH-#954F, IRGKangXi=1328.061, RSKangXi=167.10, Def{distil; lutetium; surname}
9550 CJK UNIFIED IDEOGRAPH-#9550, IRGKangXi=1328.061, RSKangXi=167.10, Def{stove; bright}
9551 CJK UNIFIED IDEOGRAPH-#9551, IRGKangXi=1328.061, RSKangXi=167.10, Def{pound sterling}
9552 CJK UNIFIED IDEOGRAPH-#9552, IRGKangXi=1328.061, RSKangXi=167.10, Def{measure of weight for gold}
9553 CJK UNIFIED IDEOGRAPH-#9553, IRGKangXi=1328.061, RSKangXi=167.10, Def{gallium}
9554 CJK UNIFIED IDEOGRAPH-#9554, IRGKangXi=1328.061, RSKangXi=167.10, Def{high quality iron}
9555 CJK UNIFIED IDEOGRAPH-#9555, IRGKangXi=1328.061, RSKangXi=167.10, Def{fuse, melt, smelt; mold}
9556 CJK UNIFIED IDEOGRAPH-#9556, IRGKangXi=1328.061, RSKangXi=167.11, Def{dart, spear, harpoon; escort}
9557 CJK UNIFIED IDEOGRAPH-#9557, IRGKangXi=1328.061, RSKangXi=167.11, Def{boring tool}
9558 CJK UNIFIED IDEOGRAPH-#9558, IRGKangXi=1328.061, RSKangXi=167.11, Def{trowel}
9559 CJK UNIFIED IDEOGRAPH-#9559, IRGKangXi=1328.061, RSKangXi=167.11
955A CJK UNIFIED IDEOGRAPH-#955A, IRGKangXi=1328.061, RSKangXi=167.11, Def{small coin}
955B CJK UNIFIED IDEOGRAPH-#955B, IRGKangXi=1328.061, RSKangXi=167.11, Def{large bell used as musical instrument}
955C CJK UNIFIED IDEOGRAPH-#955C, IRGKangXi=1328.061, RSKangXi=167.11, Def{mirror; lens; glass; glasses}
955D CJK UNIFIED IDEOGRAPH-#955D, IRGKangXi=1328.061, RSKangXi=167.11, Def{dysprosium}
955E CJK UNIFIED IDEOGRAPH-#955E, IRGKangXi=1328.061, RSKangXi=167.11, Def{arrowhead, barb; swift, quick}
955F CJK UNIFIED IDEOGRAPH-#955F, IRGKangXi=1328.061, RSKangXi=167.11, Def{lathe}
9560 CJK UNIFIED IDEOGRAPH-#9560, IRGKangXi=1328.061, RSKangXi=167.11, Def{pure gold}
9561 CJK UNIFIED IDEOGRAPH-#9561, IRGKangXi=1328.061, RSKangXi=167.12, Def{dagger; small sword}
9562 CJK UNIFIED IDEOGRAPH-#9562, IRGKangXi=1328.061, RSKangXi=167.12, Def{hoe}
9563 CJK UNIFIED IDEOGRAPH-#9563, IRGKangXi=1328.061, RSKangXi=167.12, Def{fetters}
9564 CJK UNIFIED IDEOGRAPH-#9564, IRGKangXi=1328.061, RSKangXi=167.12, Def{protactinium (Pa)}
9565 CJK UNIFIED IDEOGRAPH-#9565, IRGKangXi=1328.061, RSKangXi=167.12, Def{lutetium}
9566 CJK UNIFIED IDEOGRAPH-#9566, IRGKangXi=1328.061, RSKangXi=167.12, Def{ferrule; castrate}
9567 CJK UNIFIED IDEOGRAPH-#9567, IRGKangXi=1328.061, RSKangXi=167.12, Def{lanthanum}
9568 CJK UNIFIED IDEOGRAPH-#9568, IRGKangXi=1328.061, RSKangXi=167.12, Def{praseodymium}
9569 CJK UNIFIED IDEOGRAPH-#9569, IRGKangXi=1328.061, RSKangXi=167.12, Def{pick, poker}
956A CJK UNIFIED IDEOGRAPH-#956A, IRGKangXi=1328.061, RSKangXi=167.12, Def{coins, money, wealth}
956B CJK UNIFIED IDEOGRAPH-#956B, IRGKangXi=1328.061, RSKangXi=167.12, Def{lamp; a kind of cooking vessel}
956C CJK UNIFIED IDEOGRAPH-#956C, IRGKangXi=1328.061, RSKangXi=167.13, Def{cauldron, large iron pot}
956D CJK UNIFIED IDEOGRAPH-#956D, IRGKangXi=1328.061, RSKangXi=167.13, Def{radium}
956E CJK UNIFIED IDEOGRAPH-#956E, IRGKangXi=1328.061, RSKangXi=167.13, Def{metal ring; measure of currency}
956F CJK UNIFIED IDEOGRAPH-#956F, IRGKangXi=1328.061, RSKangXi=167.13, Def{bracelet, armband; small bell}
9570 CJK UNIFIED IDEOGRAPH-#9570, IRGKangXi=1328.061, RSKangXi=167.13, Def{sickle}
9571 CJK UNIFIED IDEOGRAPH-#9571, IRGKangXi=1328.061, RSKangXi=167.13, Def{ytterbium}
9572 CJK UNIFIED IDEOGRAPH-#9572, IRGKangXi=1328.061, RSKangXi=167.13, Def{cymbals}
9573 CJK UNIFIED IDEOGRAPH-#9573, IRGKangXi=1328.061, RSKangXi=167.15, Def{bit, bridle; ride}
9574 CJK UNIFIED IDEOGRAPH-#9574, IRGKangXi=1328.061, RSKangXi=167.15, Def{solder; tin}
9575 CJK UNIFIED IDEOGRAPH-#9575, IRGKangXi=1328.061, RSKangXi=167.17, Def{spade, trowel}
9576 CJK UNIFIED IDEOGRAPH-#9576, IRGKangXi=1328.061, RSKangXi=167.17, Def{insert, inlay, set, mount; fill}
9577 CJK UNIFIED IDEOGRAPH-#9577, IRGKangXi=1328.070, RSKangXi=168.0, Def{long; length; excel in; leader}
9578 CJK UNIFIED IDEOGRAPH-#9578, IRGKangXi=1328.160, RSKangXi=168.0, Def{long}
9579 CJK UNIFIED IDEOGRAPH-#9579, IRGKangXi=1329.010, RSKangXi=168.3
957A CJK UNIFIED IDEOGRAPH-#957A, IRGKangXi=1329.060, RSKangXi=168.4
957B CJK UNIFIED IDEOGRAPH-#957B, IRGKangXi=1329.110, RSKangXi=168.5
957C CJK UNIFIED IDEOGRAPH-#957C, IRGKangXi=1329.290, RSKangXi=168.8
957D CJK UNIFIED IDEOGRAPH-#957D, IRGKangXi=1329.420, RSKangXi=168.12
957E CJK UNIFIED IDEOGRAPH-#957E, IRGKangXi=1329.480, RSKangXi=168.14
957F CJK UNIFIED IDEOGRAPH-#957F, IRGKangXi=1329.521, RSKangXi=168.0, Def{long; length; excel in; leader}
9580 CJK UNIFIED IDEOGRAPH-#9580, IRGKangXi=1329.530, RSKangXi=169.0, Def{gate, door, entrance, opening}
9581 CJK UNIFIED IDEOGRAPH-#9581, IRGKangXi=1330.010, RSKangXi=169.1
9582 CJK UNIFIED IDEOGRAPH-#9582, IRGKangXi=1330.030, RSKangXi=169.1, Def{bolt, latch, crossbar}
9583 CJK UNIFIED IDEOGRAPH-#9583, IRGKangXi=1330.060, RSKangXi=169.2, Def{flash; avoid, dodge, evade}
9584 CJK UNIFIED IDEOGRAPH-#9584, IRGKangXi=1330.080, RSKangXi=169.2
9585 CJK UNIFIED IDEOGRAPH-#9585, IRGKangXi=1330.090, RSKangXi=169.2
9586 CJK UNIFIED IDEOGRAPH-#9586, IRGKangXi=1330.110, RSKangXi=169.3, Def{village gate}
9587 CJK UNIFIED IDEOGRAPH-#9587, IRGKangXi=1330.120, RSKangXi=169.3, Def{shut, close; obstruct, block up}
9588 CJK UNIFIED IDEOGRAPH-#9588, IRGKangXi=1330.130, RSKangXi=169.3, Def{village}
9589 CJK UNIFIED IDEOGRAPH-#9589, IRGKangXi=1330.140, RSKangXi=169.3, Def{shut, close; obstruct, block up}
958A CJK UNIFIED IDEOGRAPH-#958A, IRGKangXi=1331.011, RSKangXi=169.3, Def{to be obstructed, blocked; to break down}
958B CJK UNIFIED IDEOGRAPH-#958B, IRGKangXi=1331.050, RSKangXi=169.4, Def{open; initiate, begin, start}
958C CJK UNIFIED IDEOGRAPH-#958C, IRGKangXi=1331.130, RSKangXi=169.4, Def{door}
958D CJK UNIFIED IDEOGRAPH-#958D, IRGKangXi=1331.140, RSKangXi=169.4
958E CJK UNIFIED IDEOGRAPH-#958E, IRGKangXi=1331.150, RSKangXi=169.4, Def{gate, barrier; wide, vast, expand}
958F CJK UNIFIED IDEOGRAPH-#958F, IRGKangXi=1331.180, RSKangXi=169.4, Def{intercalary; extra, surplus}
9590 CJK UNIFIED IDEOGRAPH-#9590, IRGKangXi=1332.010, RSKangXi=169.4
9591 CJK UNIFIED IDEOGRAPH-#9591, IRGKangXi=1332.020, RSKangXi=169.4, Def{fence, barrier; defend; idle time}
9592 CJK UNIFIED IDEOGRAPH-#9592, IRGKangXi=1332.030, RSKangXi=169.4, Def{liesure; idle; peaceful, tranquil, calm}
9593 CJK UNIFIED IDEOGRAPH-#9593, IRGKangXi=1333.010, RSKangXi=169.4, Def{interval, space; place, between}
9594 CJK UNIFIED IDEOGRAPH-#9594, IRGKangXi=1333.030, RSKangXi=169.4, Def{mourn, grieve; urge on, incite}
9595 CJK UNIFIED IDEOGRAPH-#9595, IRGKangXi=1333.040, RSKangXi=169.4
9596 CJK UNIFIED IDEOGRAPH-#9596, IRGKangXi=1333.091, RSKangXi=169.4, Def{(J) flower name; a water-gate, sluice; toponym}
9597 CJK UNIFIED IDEOGRAPH-#9597, IRGKangXi=1333.091, RSKangXi=169.4
9598 CJK UNIFIED IDEOGRAPH-#9598, IRGKangXi=1333.120, RSKangXi=169.5, Def{sluice; flood gate, canal lock}
9599 CJK UNIFIED IDEOGRAPH-#9599, IRGKangXi=1333.130, RSKangXi=169.5, Def{quarrel; dispute hotly}
959A CJK UNIFIED IDEOGRAPH-#959A, IRGKangXi=1333.140, RSKangXi=169.5
959B CJK UNIFIED IDEOGRAPH-#959B, IRGKangXi=1333.160, RSKangXi=169.5
959C CJK UNIFIED IDEOGRAPH-#959C, IRGKangXi=1333.280, RSKangXi=169.5
959D CJK UNIFIED IDEOGRAPH-#959D, IRGKangXi=1333.300, RSKangXi=169.5
959E CJK UNIFIED IDEOGRAPH-#959E, IRGKangXi=1333.310, RSKangXi=169.5
959F CJK UNIFIED IDEOGRAPH-#959F, IRGKangXi=1333.320, RSKangXi=169.5, Def{hide, keep secret; hideaway}
95A0 CJK UNIFIED IDEOGRAPH-#95A0, IRGKangXi=1333.361, RSKangXi=169.5, Def{intercalary; extra, surplus}
95A1 CJK UNIFIED IDEOGRAPH-#95A1, IRGKangXi=1333.370, RSKangXi=169.6, Def{blocked or separated; to prevent}
95A2 CJK UNIFIED IDEOGRAPH-#95A2, IRGKangXi=1334.080, RSKangXi=169.6, Def{frontier pass; close; relation}
95A3 CJK UNIFIED IDEOGRAPH-#95A3, IRGKangXi=1334.110, RSKangXi=169.6, Def{chamber, pavilion; cabinet}
95A4 CJK UNIFIED IDEOGRAPH-#95A4, IRGKangXi=1334.120, RSKangXi=169.6, Def{small side door; chamber}
95A5 CJK UNIFIED IDEOGRAPH-#95A5, IRGKangXi=1334.190, RSKangXi=169.6, Def{powerful and influential group}
95A6 CJK UNIFIED IDEOGRAPH-#95A6, IRGKangXi=1335.010, RSKangXi=169.6, Def{crowd; transliteration of Sanskrit 'kso', e.g. 'aksobhya'}
95A7 CJK UNIFIED IDEOGRAPH-#95A7, IRGKangXi=1335.030, RSKangXi=169.6, Def{boisterous; clamor, noise}
95A8 CJK UNIFIED IDEOGRAPH-#95A8, IRGKangXi=1335.040, RSKangXi=169.6, Def{small entrance; women's quarters}
95A9 CJK UNIFIED IDEOGRAPH-#95A9, IRGKangXi=1335.070, RSKangXi=169.6, Def{Fujian province; a river; a tribe}
95AA CJK UNIFIED IDEOGRAPH-#95AA, IRGKangXi=1335.091, RSKangXi=169.6, Def{to lose lost item; (Cant.) vagina (vulg.)}
95AB CJK UNIFIED IDEOGRAPH-#95AB, IRGKangXi=1335.120, RSKangXi=169.7, Def{threshold; women's quarters}
95AC CJK UNIFIED IDEOGRAPH-#95AC, IRGKangXi=1335.130, RSKangXi=169.7, Def{high door; high gate; high, lofty}
95AD CJK UNIFIED IDEOGRAPH-#95AD, IRGKangXi=1335.170, RSKangXi=169.7, Def{village of twenty-five families}
95AE CJK UNIFIED IDEOGRAPH-#95AE, IRGKangXi=1336.040, RSKangXi=169.7
95AF CJK UNIFIED IDEOGRAPH-#95AF, IRGKangXi=1336.050, RSKangXi=169.7
95B0 CJK UNIFIED IDEOGRAPH-#95B0, IRGKangXi=1336.060, RSKangXi=169.7
95B1 CJK UNIFIED IDEOGRAPH-#95B1, IRGKangXi=1336.070, RSKangXi=169.7, Def{examine, inspect, review, read}
95B2 CJK UNIFIED IDEOGRAPH-#95B2, IRGKangXi=1336.111, RSKangXi=169.7, Def{examine}
95B3 CJK UNIFIED IDEOGRAPH-#95B3, IRGKangXi=1336.111, RSKangXi=169.7
95B4 CJK UNIFIED IDEOGRAPH-#95B4, IRGKangXi=1336.111, RSKangXi=169.7, Def{quiet}
95B5 CJK UNIFIED IDEOGRAPH-#95B5, IRGKangXi=1336.120, RSKangXi=169.8
95B6 CJK UNIFIED IDEOGRAPH-#95B6, IRGKangXi=1336.170, RSKangXi=169.8, Def{gate of heaven; main gate of palace}
95B7 CJK UNIFIED IDEOGRAPH-#95B7, IRGKangXi=1336.180, RSKangXi=169.9
95B8 CJK UNIFIED IDEOGRAPH-#95B8, IRGKangXi=1337.030, RSKangXi=169.8
95B9 CJK UNIFIED IDEOGRAPH-#95B9, IRGKangXi=1337.050, RSKangXi=169.8, Def{castrate; eunuch}
95BA CJK UNIFIED IDEOGRAPH-#95BA, IRGKangXi=1337.080, RSKangXi=169.8
95BB CJK UNIFIED IDEOGRAPH-#95BB, IRGKangXi=1337.120, RSKangXi=169.8, Def{village gate; surname}
95BC CJK UNIFIED IDEOGRAPH-#95BC, IRGKangXi=1337.130, RSKangXi=169.8, Def{block, obstruct, stop up, conceal}
95BD CJK UNIFIED IDEOGRAPH-#95BD, IRGKangXi=1337.160, RSKangXi=169.8, Def{gatekeeper; gate, door}
95BE CJK UNIFIED IDEOGRAPH-#95BE, IRGKangXi=1337.170, RSKangXi=169.8, Def{threshold; separated, confined}
95BF CJK UNIFIED IDEOGRAPH-#95BF, IRGKangXi=1337.190, RSKangXi=169.8, Def{name of a district in Henan province}
95C0 CJK UNIFIED IDEOGRAPH-#95C0, IRGKangXi=1338.010, RSKangXi=169.8
95C1 CJK UNIFIED IDEOGRAPH-#95C1, IRGKangXi=1338.020, RSKangXi=169.8
95C2 CJK UNIFIED IDEOGRAPH-#95C2, IRGKangXi=1338.030, RSKangXi=169.8
95C3 CJK UNIFIED IDEOGRAPH-#95C3, IRGKangXi=1338.120, RSKangXi=169.9, Def{alone; quiet, still}
95C4 CJK UNIFIED IDEOGRAPH-#95C4, IRGKangXi=1338.140, RSKangXi=169.9
95C5 CJK UNIFIED IDEOGRAPH-#95C5, IRGKangXi=1338.160, RSKangXi=169.9
95C6 CJK UNIFIED IDEOGRAPH-#95C6, IRGKangXi=1338.210, RSKangXi=169.9, Def{boss, the owner, person in charge}
95C7 CJK UNIFIED IDEOGRAPH-#95C7, IRGKangXi=1338.220, RSKangXi=169.9, Def{close, shut; dark, dismal}
95C8 CJK UNIFIED IDEOGRAPH-#95C8, IRGKangXi=1338.260, RSKangXi=169.9, Def{gate, door; living quarters}
95C9 CJK UNIFIED IDEOGRAPH-#95C9, IRGKangXi=1338.290, RSKangXi=169.9, Def{curved, bent; a curved wall}
95CA CJK UNIFIED IDEOGRAPH-#95CA, IRGKangXi=1338.300, RSKangXi=169.9, Def{broad, ample, wide; be apart}
95CB CJK UNIFIED IDEOGRAPH-#95CB, IRGKangXi=1339.010, RSKangXi=169.9, Def{close, shut; watch tower}
95CC CJK UNIFIED IDEOGRAPH-#95CC, IRGKangXi=1339.040, RSKangXi=169.9, Def{door screen; railing fence}
95CD CJK UNIFIED IDEOGRAPH-#95CD, IRGKangXi=1339.050, RSKangXi=169.9, Def{tower over city gate}
95CE CJK UNIFIED IDEOGRAPH-#95CE, IRGKangXi=1339.071, RSKangXi=169.9
95CF CJK UNIFIED IDEOGRAPH-#95CF, IRGKangXi=1339.071, RSKangXi=169.9
95D0 CJK UNIFIED IDEOGRAPH-#95D0, IRGKangXi=1339.110, RSKangXi=169.10, Def{a place in Xinjiang province}
95D1 CJK UNIFIED IDEOGRAPH-#95D1, IRGKangXi=1339.140, RSKangXi=169.10, Def{the doorsill}
95D2 CJK UNIFIED IDEOGRAPH-#95D2, IRGKangXi=1339.150, RSKangXi=169.10, Def{upper-story door or window}
95D3 CJK UNIFIED IDEOGRAPH-#95D3, IRGKangXi=1340.010, RSKangXi=169.10, Def{open; peaceful}
95D4 CJK UNIFIED IDEOGRAPH-#95D4, IRGKangXi=1340.020, RSKangXi=169.10, Def{close; whole, entire; all; leaf}
95D5 CJK UNIFIED IDEOGRAPH-#95D5, IRGKangXi=1340.060, RSKangXi=169.10, Def{watch tower; palace}
95D6 CJK UNIFIED IDEOGRAPH-#95D6, IRGKangXi=1340.080, RSKangXi=169.10, Def{rush in, burst in, charge in}
95D7 CJK UNIFIED IDEOGRAPH-#95D7, IRGKangXi=1341.031, Def{a frontier pass or gate to shut or close; a custom-house; suburbs of a city}
95D8 CJK UNIFIED IDEOGRAPH-#95D8, IRGKangXi=1341.031, RSKangXi=169.10, Def{struggle, fight, compete, contend}
95D9 CJK UNIFIED IDEOGRAPH-#95D9, IRGKangXi=1341.040, RSKangXi=169.11
95DA CJK UNIFIED IDEOGRAPH-#95DA, IRGKangXi=1341.060, RSKangXi=169.11, Def{flash; flashing; steal look}
95DB CJK UNIFIED IDEOGRAPH-#95DB, IRGKangXi=1341.070, RSKangXi=169.11
95DC CJK UNIFIED IDEOGRAPH-#95DC, IRGKangXi=1341.090, RSKangXi=169.11, Def{frontier pass; close; relation}
95DD CJK UNIFIED IDEOGRAPH-#95DD, IRGKangXi=1341.141, RSKangXi=169.11
95DE CJK UNIFIED IDEOGRAPH-#95DE, IRGKangXi=1341.210, RSKangXi=169.12, Def{glance, peep; roar, growl}
95DF CJK UNIFIED IDEOGRAPH-#95DF, IRGKangXi=1342.030, RSKangXi=169.12, Def{peacefully; quietly}
95E0 CJK UNIFIED IDEOGRAPH-#95E0, IRGKangXi=1342.040, RSKangXi=169.12, Def{gate of a market}
95E1 CJK UNIFIED IDEOGRAPH-#95E1, IRGKangXi=1342.050, RSKangXi=169.12, Def{explain, clarify, elucidate}
95E2 CJK UNIFIED IDEOGRAPH-#95E2, IRGKangXi=1342.100, RSKangXi=169.13, Def{open; settle, develop, open up}
95E3 CJK UNIFIED IDEOGRAPH-#95E3, IRGKangXi=1342.150, RSKangXi=169.13
95E4 CJK UNIFIED IDEOGRAPH-#95E4, IRGKangXi=1342.180, RSKangXi=169.13, Def{wall around market place}
95E5 CJK UNIFIED IDEOGRAPH-#95E5, IRGKangXi=1342.200, RSKangXi=169.13, Def{door; gate}
95E6 CJK UNIFIED IDEOGRAPH-#95E6, IRGKangXi=1343.011, RSKangXi=169.13
95E7 CJK UNIFIED IDEOGRAPH-#95E7, IRGKangXi=1343.051, RSKangXi=169.14
95E8 CJK UNIFIED IDEOGRAPH-#95E8, IRGKangXi=1343.121, RSKangXi=169.0, Def{gate, door, entrance, opening}
95E9 CJK UNIFIED IDEOGRAPH-#95E9, IRGKangXi=1343.121, RSKangXi=169.1, Def{bolt, latch, crossbar}
95EA CJK UNIFIED IDEOGRAPH-#95EA, IRGKangXi=1343.121, RSKangXi=169.2, Def{flash; avoid, dodge, evade}
95EB CJK UNIFIED IDEOGRAPH-#95EB, IRGKangXi=1343.121, RSKangXi=169.3, Def{village gate}
95EC CJK UNIFIED IDEOGRAPH-#95EC, IRGKangXi=1343.121, RSKangXi=169.3, Def{village}
95ED CJK UNIFIED IDEOGRAPH-#95ED, IRGKangXi=1343.121, RSKangXi=169.3, Def{shut, close; obstruct, block up}
95EE CJK UNIFIED IDEOGRAPH-#95EE, IRGKangXi=1343.121, RSKangXi=169.3, Def{ask about, inquire after}
95EF CJK UNIFIED IDEOGRAPH-#95EF, IRGKangXi=1343.121, RSKangXi=169.3, Def{rush in, burst in, charge in}
95F0 CJK UNIFIED IDEOGRAPH-#95F0, IRGKangXi=1343.121, RSKangXi=169.4, Def{intercalary; extra, surplus}
95F1 CJK UNIFIED IDEOGRAPH-#95F1, IRGKangXi=1343.121, RSKangXi=169.4, Def{gate, door; living quarters}
95F2 CJK UNIFIED IDEOGRAPH-#95F2, IRGKangXi=1343.121, RSKangXi=169.4, Def{fence, guard; defend; idle time}
95F3 CJK UNIFIED IDEOGRAPH-#95F3, IRGKangXi=1343.121, RSKangXi=169.4, Def{gate, barrier; wide, vast, expand}
95F4 CJK UNIFIED IDEOGRAPH-#95F4, IRGKangXi=1343.121, RSKangXi=169.4, Def{midpoint, space; place, locality}
95F5 CJK UNIFIED IDEOGRAPH-#95F5, IRGKangXi=1343.121, RSKangXi=169.4, Def{mourn, grieve; urge on, incite}
95F6 CJK UNIFIED IDEOGRAPH-#95F6, IRGKangXi=1343.121, RSKangXi=169.4, Def{door}
95F7 CJK UNIFIED IDEOGRAPH-#95F7, IRGKangXi=1343.121, RSKangXi=169.4, Def{gloomy, depressed, melancholy}
95F8 CJK UNIFIED IDEOGRAPH-#95F8, IRGKangXi=1343.121, RSKangXi=169.5, Def{sluice; flood gate, canal lock}
95F9 CJK UNIFIED IDEOGRAPH-#95F9, IRGKangXi=1343.121, RSKangXi=169.5, Def{quarrel; dispute hotly}
95FA CJK UNIFIED IDEOGRAPH-#95FA, IRGKangXi=1343.121, RSKangXi=169.6, Def{small entrance; women's quarters}
95FB CJK UNIFIED IDEOGRAPH-#95FB, IRGKangXi=1343.121, RSKangXi=169.6, Def{hear; smell; make known; news}
95FC CJK UNIFIED IDEOGRAPH-#95FC, IRGKangXi=1343.121, RSKangXi=169.6, Def{door; gate}
95FD CJK UNIFIED IDEOGRAPH-#95FD, IRGKangXi=1343.121, RSKangXi=169.6, Def{fujian province; a river; a tribe}
95FE CJK UNIFIED IDEOGRAPH-#95FE, IRGKangXi=1343.121, RSKangXi=169.6, Def{village of twenty-five families}
95FF CJK UNIFIED IDEOGRAPH-#95FF, IRGKangXi=1343.121, RSKangXi=169.10, Def{open; peaceful}
9600 CJK UNIFIED IDEOGRAPH-#9600, IRGKangXi=1343.121, RSKangXi=169.6, Def{powerful and influential group}
9601 CJK UNIFIED IDEOGRAPH-#9601, IRGKangXi=1343.121, RSKangXi=169.6, Def{chamber, pavilion; cabinet}
9602 CJK UNIFIED IDEOGRAPH-#9602, IRGKangXi=1343.121, RSKangXi=169.6, Def{blocked or separated; to prevent}
9603 CJK UNIFIED IDEOGRAPH-#9603, IRGKangXi=1343.121, RSKangXi=169.7, Def{threshold; women's quarters}
9604 CJK UNIFIED IDEOGRAPH-#9604, IRGKangXi=1343.121, RSKangXi=169.7, Def{lots (to be drawn); draw lots}
9605 CJK UNIFIED IDEOGRAPH-#9605, IRGKangXi=1343.121, RSKangXi=169.7, Def{examine, inspect, review, read}
9606 CJK UNIFIED IDEOGRAPH-#9606, IRGKangXi=1343.121, RSKangXi=169.7, Def{high door; high gate; high, lofty}
9607 CJK UNIFIED IDEOGRAPH-#9607, IRGKangXi=1343.121, RSKangXi=169.9, Def{a Buddhist high priest}
9608 CJK UNIFIED IDEOGRAPH-#9608, IRGKangXi=1343.121, RSKangXi=169.8, Def{threshold; separated, confined}
9609 CJK UNIFIED IDEOGRAPH-#9609, IRGKangXi=1343.121, RSKangXi=169.8, Def{castrate; eunuch}
960A CJK UNIFIED IDEOGRAPH-#960A, IRGKangXi=1343.121, RSKangXi=169.8, Def{gate of heaven; main gate of a palace}
960B CJK UNIFIED IDEOGRAPH-#960B, IRGKangXi=1343.121, RSKangXi=169.8, Def{feud, fight, quarrel}
960C CJK UNIFIED IDEOGRAPH-#960C, IRGKangXi=1343.121, RSKangXi=169.8, Def{wen xiang, Henan province}
960D CJK UNIFIED IDEOGRAPH-#960D, IRGKangXi=1343.121, RSKangXi=169.8, Def{gatekeeper; gate, door}
960E CJK UNIFIED IDEOGRAPH-#960E, IRGKangXi=1343.121, RSKangXi=169.8, Def{village gate; surname}
960F CJK UNIFIED IDEOGRAPH-#960F, IRGKangXi=1343.121, RSKangXi=169.8, Def{block, obstruct, stop up}
9610 CJK UNIFIED IDEOGRAPH-#9610, IRGKangXi=1343.121, RSKangXi=169.8, Def{explain, clarify, elucidate}
9611 CJK UNIFIED IDEOGRAPH-#9611, IRGKangXi=1343.121, RSKangXi=169.9, Def{door screen; railing fence}
9612 CJK UNIFIED IDEOGRAPH-#9612, IRGKangXi=1343.121, RSKangXi=169.9, Def{alone; quiet, still}
9613 CJK UNIFIED IDEOGRAPH-#9613, IRGKangXi=1343.121, RSKangXi=169.9, Def{gate of a market}
9614 CJK UNIFIED IDEOGRAPH-#9614, IRGKangXi=1343.121, RSKangXi=169.9, Def{broad, ample, wide; be apart}
9615 CJK UNIFIED IDEOGRAPH-#9615, IRGKangXi=1343.121, RSKangXi=169.9, Def{close, shut; watch tower}
9616 CJK UNIFIED IDEOGRAPH-#9616, IRGKangXi=1343.121, RSKangXi=169.10, Def{close; whole, entire; all; leaf}
9617 CJK UNIFIED IDEOGRAPH-#9617, IRGKangXi=1343.121, RSKangXi=169.10, Def{a place in Xinjiang province}
9618 CJK UNIFIED IDEOGRAPH-#9618, IRGKangXi=1343.121, RSKangXi=169.10, Def{upper-story door or window}
9619 CJK UNIFIED IDEOGRAPH-#9619, IRGKangXi=1343.121, RSKangXi=169.10, Def{watch tower; palace}
961A CJK UNIFIED IDEOGRAPH-#961A, IRGKangXi=1343.121, RSKangXi=169.11, Def{glance, peep; roar, growl}
961B CJK UNIFIED IDEOGRAPH-#961B, IRGKangXi=1343.121, RSKangXi=169.13, Def{wall around market place}
961C CJK UNIFIED IDEOGRAPH-#961C, IRGKangXi=1345.010, RSKangXi=170.0, Def{mound; abundant, ample, numerous}
961D CJK UNIFIED IDEOGRAPH-#961D, IRGKangXi=1345.040, RSKangXi=170.0, Def{place; KangXi radical 170}
961E CJK UNIFIED IDEOGRAPH-#961E, IRGKangXi=1345.110, RSKangXi=170.2, Def{vein}
961F CJK UNIFIED IDEOGRAPH-#961F, IRGKangXi=1345.121, RSKangXi=170.2, Def{team, group; army unit}
9620 CJK UNIFIED IDEOGRAPH-#9620, IRGKangXi=1345.150, RSKangXi=170.3
9621 CJK UNIFIED IDEOGRAPH-#9621, IRGKangXi=1345.160, RSKangXi=170.3, AccountingNumeric=1000, Def{footpaths between fields; paths}
9622 CJK UNIFIED IDEOGRAPH-#9622, IRGKangXi=1345.180, RSKangXi=170.3
9623 CJK UNIFIED IDEOGRAPH-#9623, IRGKangXi=1346.010, RSKangXi=170.3
9624 CJK UNIFIED IDEOGRAPH-#9624, IRGKangXi=1346.020, RSKangXi=170.3, Def{hill}
9625 CJK UNIFIED IDEOGRAPH-#9625, IRGKangXi=1346.050, RSKangXi=170.4
9626 CJK UNIFIED IDEOGRAPH-#9626, IRGKangXi=1346.060, RSKangXi=170.4
9627 CJK UNIFIED IDEOGRAPH-#9627, IRGKangXi=1346.070, RSKangXi=170.4, Def{sloping, steep; suddenly, abruptly}
9628 CJK UNIFIED IDEOGRAPH-#9628, IRGKangXi=1346.080, RSKangXi=170.4, Def{in distress; adverse; strategic; (Cant.) to swindle}
9629 CJK UNIFIED IDEOGRAPH-#9629, IRGKangXi=1346.100, RSKangXi=170.4
962A CJK UNIFIED IDEOGRAPH-#962A, IRGKangXi=1346.110, RSKangXi=170.4, Def{hillside farmland; slope}
962B CJK UNIFIED IDEOGRAPH-#962B, IRGKangXi=1346.130, RSKangXi=170.4
962C CJK UNIFIED IDEOGRAPH-#962C, IRGKangXi=1346.140, RSKangXi=170.4, Def{pit, hole, shaft}
962D CJK UNIFIED IDEOGRAPH-#962D, IRGKangXi=1346.150, RSKangXi=170.4
962E CJK UNIFIED IDEOGRAPH-#962E, IRGKangXi=1346.180, RSKangXi=170.4, Def{ancient musical instrument: surname}
962F CJK UNIFIED IDEOGRAPH-#962F, IRGKangXi=1346.190, RSKangXi=170.4, Def{foundation; site; address}
9630 CJK UNIFIED IDEOGRAPH-#9630, IRGKangXi=1346.200, RSKangXi=170.4
9631 CJK UNIFIED IDEOGRAPH-#9631, IRGKangXi=1347.030, RSKangXi=170.4, Def{pitfall, trap, snare}
9632 CJK UNIFIED IDEOGRAPH-#9632, IRGKangXi=1347.050, RSKangXi=170.4, Def{defend; prevent; embankment}
9633 CJK UNIFIED IDEOGRAPH-#9633, IRGKangXi=1347.070, RSKangXi=170.4, Def{'male' principle; light; sun}
9634 CJK UNIFIED IDEOGRAPH-#9634, IRGKangXi=1347.080, RSKangXi=170.4, Def{'female' principle; dark; secret}
9635 CJK UNIFIED IDEOGRAPH-#9635, IRGKangXi=1347.081, RSKangXi=170.4, Def{column, row or file of troops}
9636 CJK UNIFIED IDEOGRAPH-#9636, IRGKangXi=1347.081, RSKangXi=170.4, Def{stairs, steps; rank, degree}
9637 CJK UNIFIED IDEOGRAPH-#9637, IRGKangXi=1347.120, RSKangXi=170.5
9638 CJK UNIFIED IDEOGRAPH-#9638, IRGKangXi=1347.170, RSKangXi=170.5, Def{distress; difficulty}
9639 CJK UNIFIED IDEOGRAPH-#9639, IRGKangXi=1347.180, RSKangXi=170.5, Def{a pen; to surround}
963A CJK UNIFIED IDEOGRAPH-#963A, IRGKangXi=1347.190, RSKangXi=170.5
963B CJK UNIFIED IDEOGRAPH-#963B, IRGKangXi=1347.200, RSKangXi=170.5, Def{impede, hinder, obstruct; oppose}
963C CJK UNIFIED IDEOGRAPH-#963C, IRGKangXi=1348.010, RSKangXi=170.5, Def{the steps leading to the eastern door}
963D CJK UNIFIED IDEOGRAPH-#963D, IRGKangXi=1348.020, RSKangXi=170.5
963E CJK UNIFIED IDEOGRAPH-#963E, IRGKangXi=1348.040, RSKangXi=170.5
963F CJK UNIFIED IDEOGRAPH-#963F, IRGKangXi=1348.060, RSKangXi=170.5, Def{prefix for people's names; used in transliteration}
9640 CJK UNIFIED IDEOGRAPH-#9640, IRGKangXi=1348.070, RSKangXi=170.5, Def{steep bank, rough terrain}
9641 CJK UNIFIED IDEOGRAPH-#9641, IRGKangXi=1348.080, RSKangXi=170.5, Def{a steep bank, a declivity}
9642 CJK UNIFIED IDEOGRAPH-#9642, IRGKangXi=1348.100, RSKangXi=170.5, Def{dam, embankment; reservoir}
9643 CJK UNIFIED IDEOGRAPH-#9643, IRGKangXi=1349.010, RSKangXi=170.5
9644 CJK UNIFIED IDEOGRAPH-#9644, IRGKangXi=1349.030, RSKangXi=170.5, Def{adhere to, append; rely on near to}
9645 CJK UNIFIED IDEOGRAPH-#9645, IRGKangXi=1349.051, RSKangXi=170.5, Def{border, boundary, juncture}
9646 CJK UNIFIED IDEOGRAPH-#9646, IRGKangXi=1349.051, RSKangXi=170.5, AccountingNumeric=6, Def{land, continental; army}
9647 CJK UNIFIED IDEOGRAPH-#9647, IRGKangXi=1349.051, RSKangXi=170.5, Def{mountain located between Shanxi}
9648 CJK UNIFIED IDEOGRAPH-#9648, IRGKangXi=1349.051, RSKangXi=170.5, Def{exhibit, display; plead; a surname}
9649 CJK UNIFIED IDEOGRAPH-#9649, IRGKangXi=1349.051, RSKangXi=170.5, Def{defile, mountain pass, gorge}
964A CJK UNIFIED IDEOGRAPH-#964A, IRGKangXi=1349.060, RSKangXi=170.6
964B CJK UNIFIED IDEOGRAPH-#964B, IRGKangXi=1349.080, RSKangXi=170.6, Def{narrow; crude, coarse; ugly}
964C CJK UNIFIED IDEOGRAPH-#964C, IRGKangXi=1349.090, RSKangXi=170.6, AccountingNumeric=100, Def{foot path between rice fields}
964D CJK UNIFIED IDEOGRAPH-#964D, IRGKangXi=1349.120, RSKangXi=170.6, Def{descend, fall, drop; lower, down}
964E CJK UNIFIED IDEOGRAPH-#964E, IRGKangXi=1350.020, RSKangXi=170.6
964F CJK UNIFIED IDEOGRAPH-#964F, IRGKangXi=1350.030, RSKangXi=170.6
9650 CJK UNIFIED IDEOGRAPH-#9650, IRGKangXi=1350.070, RSKangXi=170.6, Def{boundary, limit, line}
9651 CJK UNIFIED IDEOGRAPH-#9651, IRGKangXi=1350.090, RSKangXi=170.6
9652 CJK UNIFIED IDEOGRAPH-#9652, IRGKangXi=1350.100, RSKangXi=170.6
9653 CJK UNIFIED IDEOGRAPH-#9653, IRGKangXi=1350.110, RSKangXi=170.6
9654 CJK UNIFIED IDEOGRAPH-#9654, IRGKangXi=1350.130, RSKangXi=170.6, Def{a step, a terrace, a grade a ledge}
9655 CJK UNIFIED IDEOGRAPH-#9655, IRGKangXi=1350.201, RSKangXi=170.6, Def{mountain pass; Shanxi province}
9656 CJK UNIFIED IDEOGRAPH-#9656, IRGKangXi=1351.010, RSKangXi=170.7
9657 CJK UNIFIED IDEOGRAPH-#9657, IRGKangXi=1351.020, RSKangXi=170.7, Def{a steep hill; precipitous}
9658 CJK UNIFIED IDEOGRAPH-#9658, IRGKangXi=1351.060, RSKangXi=170.7, Def{defile, mountain pass, gorge}
9659 CJK UNIFIED IDEOGRAPH-#9659, IRGKangXi=1351.070, RSKangXi=170.7
965A CJK UNIFIED IDEOGRAPH-#965A, IRGKangXi=1351.090, RSKangXi=170.8
965B CJK UNIFIED IDEOGRAPH-#965B, IRGKangXi=1351.100, RSKangXi=170.7, Def{steps leading throne; throne}
965C CJK UNIFIED IDEOGRAPH-#965C, IRGKangXi=1351.120, RSKangXi=170.7, Def{narrow; mountain pass}
965D CJK UNIFIED IDEOGRAPH-#965D, IRGKangXi=1351.140, RSKangXi=170.7, Def{mountain pass; Shaanxi province}
965E CJK UNIFIED IDEOGRAPH-#965E, IRGKangXi=1351.150, RSKangXi=170.7, Def{promote, rise, ascend}
965F CJK UNIFIED IDEOGRAPH-#965F, IRGKangXi=1351.160, RSKangXi=170.7, Def{climb, scale, ascend; proceed}
9660 CJK UNIFIED IDEOGRAPH-#9660, IRGKangXi=1351.190, RSKangXi=170.7
9661 CJK UNIFIED IDEOGRAPH-#9661, IRGKangXi=1352.020, RSKangXi=170.7, Def{steep, sloping; abruptly, sudden}
9662 CJK UNIFIED IDEOGRAPH-#9662, IRGKangXi=1352.040, RSKangXi=170.7, Def{courtyard, yard, court; school}
9663 CJK UNIFIED IDEOGRAPH-#9663, IRGKangXi=1352.060, RSKangXi=170.7, Def{column, row or file of troops}
9664 CJK UNIFIED IDEOGRAPH-#9664, IRGKangXi=1352.080, RSKangXi=170.7, Def{eliminate, remove, except}
9665 CJK UNIFIED IDEOGRAPH-#9665, IRGKangXi=1352.141, RSKangXi=170.7, Def{submerge, sink, plunge; trap}
9666 CJK UNIFIED IDEOGRAPH-#9666, IRGKangXi=1352.141, RSKangXi=170.7
9667 CJK UNIFIED IDEOGRAPH-#9667, IRGKangXi=1352.141, RSKangXi=170.7, Def{in disorder; a dangerous condition of the State}
9668 CJK UNIFIED IDEOGRAPH-#9668, IRGKangXi=1352.141, RSKangXi=170.7, Def{fall, slip; let fall; die}
9669 CJK UNIFIED IDEOGRAPH-#9669, IRGKangXi=1352.141, RSKangXi=170.7, Def{narrow pass, strategic point}
966A CJK UNIFIED IDEOGRAPH-#966A, IRGKangXi=1352.180, RSKangXi=170.8, Def{accompany, be with, keep company}
966B CJK UNIFIED IDEOGRAPH-#966B, IRGKangXi=1352.190, RSKangXi=170.8
966C CJK UNIFIED IDEOGRAPH-#966C, IRGKangXi=1352.230, RSKangXi=170.8, Def{corner, cranny, nook, niche}
966D CJK UNIFIED IDEOGRAPH-#966D, IRGKangXi=1353.010, RSKangXi=170.8
966E CJK UNIFIED IDEOGRAPH-#966E, IRGKangXi=1353.020, RSKangXi=170.8
966F CJK UNIFIED IDEOGRAPH-#966F, IRGKangXi=1353.050, RSKangXi=170.8
9670 CJK UNIFIED IDEOGRAPH-#9670, IRGKangXi=1353.060, RSKangXi=170.8, Def{'female' principle; dark; secret}
9671 CJK UNIFIED IDEOGRAPH-#9671, IRGKangXi=1353.140, RSKangXi=170.8
9672 CJK UNIFIED IDEOGRAPH-#9672, IRGKangXi=1353.150, RSKangXi=170.8, Def{frontier, border}
9673 CJK UNIFIED IDEOGRAPH-#9673, IRGKangXi=1353.190, RSKangXi=170.8, Def{exhibit, display; plead; surname}
9674 CJK UNIFIED IDEOGRAPH-#9674, IRGKangXi=1354.040, RSKangXi=170.8, Def{a parapet on a city wall}
9675 CJK UNIFIED IDEOGRAPH-#9675, IRGKangXi=1354.060, RSKangXi=170.8, Def{hill, mound; mausoleum}
9676 CJK UNIFIED IDEOGRAPH-#9676, IRGKangXi=1354.100, RSKangXi=170.8, Def{pottery, ceramics}
9677 CJK UNIFIED IDEOGRAPH-#9677, IRGKangXi=1354.120, RSKangXi=170.8, Def{submerge, sink, plunge; trap}
9678 CJK UNIFIED IDEOGRAPH-#9678, IRGKangXi=1355.010, RSKangXi=170.8, AccountingNumeric=6, Def{land, continental; army; an accounting form of U+516D 六 (six)}
9679 CJK UNIFIED IDEOGRAPH-#9679, IRGKangXi=1355.100, RSKangXi=170.8
967A CJK UNIFIED IDEOGRAPH-#967A, IRGKangXi=1355.111, RSKangXi=170.8, Def{narrow pass, strategic point}
967B CJK UNIFIED IDEOGRAPH-#967B, IRGKangXi=1355.130, RSKangXi=170.9, Def{small hill, mound; bury; dam}
967C CJK UNIFIED IDEOGRAPH-#967C, IRGKangXi=1355.140, RSKangXi=170.9, Def{islet}
967D CJK UNIFIED IDEOGRAPH-#967D, IRGKangXi=1355.150, RSKangXi=170.9, Def{'male' principle; light; sun}
967E CJK UNIFIED IDEOGRAPH-#967E, IRGKangXi=1356.010, RSKangXi=170.9, Def{in file}
967F CJK UNIFIED IDEOGRAPH-#967F, IRGKangXi=1356.020, RSKangXi=170.9
9680 CJK UNIFIED IDEOGRAPH-#9680, IRGKangXi=1356.030, RSKangXi=170.9
9681 CJK UNIFIED IDEOGRAPH-#9681, IRGKangXi=1356.060, RSKangXi=170.9
9682 CJK UNIFIED IDEOGRAPH-#9682, IRGKangXi=1356.100, RSKangXi=170.9, Def{shady, secret, dark; mysterious; cold; the negative of female principle in nature}
9683 CJK UNIFIED IDEOGRAPH-#9683, IRGKangXi=1356.130, RSKangXi=170.9, Def{to exceed; a state in Shanxi province}
9684 CJK UNIFIED IDEOGRAPH-#9684, IRGKangXi=1356.150, RSKangXi=170.9, Def{dike, embankment}
9685 CJK UNIFIED IDEOGRAPH-#9685, IRGKangXi=1356.190, RSKangXi=170.9, Def{corner, nook, remote place}
9686 CJK UNIFIED IDEOGRAPH-#9686, IRGKangXi=1356.220, RSKangXi=170.9, Def{prosperous, plentiful, abundant}
9687 CJK UNIFIED IDEOGRAPH-#9687, IRGKangXi=1357.010, RSKangXi=170.9
9688 CJK UNIFIED IDEOGRAPH-#9688, IRGKangXi=1357.020, RSKangXi=170.9, Def{cove, bay, inlet}
9689 CJK UNIFIED IDEOGRAPH-#9689, IRGKangXi=1357.030, RSKangXi=170.9, Def{in disorder; a dangerous condition of the State}
968A CJK UNIFIED IDEOGRAPH-#968A, IRGKangXi=1357.040, RSKangXi=170.9, Def{team, group; army unit}
968B CJK UNIFIED IDEOGRAPH-#968B, IRGKangXi=1357.050, RSKangXi=170.9, Def{Sui dynasty; surname}
968C CJK UNIFIED IDEOGRAPH-#968C, IRGKangXi=1357.060, RSKangXi=170.9
968D CJK UNIFIED IDEOGRAPH-#968D, IRGKangXi=1357.080, RSKangXi=170.9, Def{dry ditch, dry moat}
968E CJK UNIFIED IDEOGRAPH-#968E, IRGKangXi=1357.090, RSKangXi=170.9, Def{stairs, steps; rank, degree}
968F CJK UNIFIED IDEOGRAPH-#968F, IRGKangXi=1359.161, RSKangXi=170.10, Def{follow, listen to, submit to}
9690 CJK UNIFIED IDEOGRAPH-#9690, IRGKangXi=1357.151, RSKangXi=170.9, Def{hide, conceal; hidden, secret}
9691 CJK UNIFIED IDEOGRAPH-#9691, IRGKangXi=1358.010, RSKangXi=170.10
9692 CJK UNIFIED IDEOGRAPH-#9692, IRGKangXi=1358.050, RSKangXi=170.10, Def{the appearance of a mountain, as if two pots were standing one upon the other; the steep bank of a stream a rough mountain path}
9693 CJK UNIFIED IDEOGRAPH-#9693, IRGKangXi=1358.110, RSKangXi=170.10
9694 CJK UNIFIED IDEOGRAPH-#9694, IRGKangXi=1358.170, RSKangXi=170.10, Def{separate, partition}
9695 CJK UNIFIED IDEOGRAPH-#9695, IRGKangXi=1358.190, RSKangXi=170.10, Def{fall, slip; let fall; die}
9696 CJK UNIFIED IDEOGRAPH-#9696, IRGKangXi=1358.200, RSKangXi=170.10, Def{entrenchment, bank, low wall}
9697 CJK UNIFIED IDEOGRAPH-#9697, IRGKangXi=1358.220, RSKangXi=170.10, Def{high; lofty; surname}
9698 CJK UNIFIED IDEOGRAPH-#9698, IRGKangXi=1358.240, RSKangXi=170.10, Def{narrow, confined; a strategic pass}
9699 CJK UNIFIED IDEOGRAPH-#9699, IRGKangXi=1359.010, RSKangXi=170.10, Def{crack, split, fissure; grudge}
969A CJK UNIFIED IDEOGRAPH-#969A, IRGKangXi=1359.270, RSKangXi=170.11
969B CJK UNIFIED IDEOGRAPH-#969B, IRGKangXi=1359.280, RSKangXi=170.11, Def{border, boundary, juncture}
969C CJK UNIFIED IDEOGRAPH-#969C, IRGKangXi=1359.290, RSKangXi=170.11, Def{separate; shield; barricade}
969D CJK UNIFIED IDEOGRAPH-#969D, IRGKangXi=1360.020, RSKangXi=170.11, Def{dock, entrenchment, low wall}
969E CJK UNIFIED IDEOGRAPH-#969E, IRGKangXi=1360.060, RSKangXi=170.11
969F CJK UNIFIED IDEOGRAPH-#969F, IRGKangXi=1360.070, RSKangXi=170.11
96A0 CJK UNIFIED IDEOGRAPH-#96A0, IRGKangXi=1360.111, RSKangXi=170.11, Def{to hide, conceal, cover; to disappear, lurk; an open secret}
96A1 CJK UNIFIED IDEOGRAPH-#96A1, IRGKangXi=1360.111, RSKangXi=170.11
96A2 CJK UNIFIED IDEOGRAPH-#96A2, IRGKangXi=1360.190, RSKangXi=170.12
96A3 CJK UNIFIED IDEOGRAPH-#96A3, IRGKangXi=1360.220, RSKangXi=170.12, Def{neighbor; neighboring; adjacent}
96A4 CJK UNIFIED IDEOGRAPH-#96A4, IRGKangXi=1360.240, RSKangXi=170.12, Def{to fall in ruins; to collapse}
96A5 CJK UNIFIED IDEOGRAPH-#96A5, IRGKangXi=1360.250, RSKangXi=170.12
96A6 CJK UNIFIED IDEOGRAPH-#96A6, IRGKangXi=1360.400, RSKangXi=170.13
96A7 CJK UNIFIED IDEOGRAPH-#96A7, IRGKangXi=1361.020, RSKangXi=170.13, Def{tunnel, underground passageway, path to a tomb}
96A8 CJK UNIFIED IDEOGRAPH-#96A8, IRGKangXi=1361.040, RSKangXi=170.13, Def{follow, listen to, submit; to accompany; subsequently, then}
96A9 CJK UNIFIED IDEOGRAPH-#96A9, IRGKangXi=1361.080, RSKangXi=170.13, Def{profound, subtle; warm}
96AA CJK UNIFIED IDEOGRAPH-#96AA, IRGKangXi=1361.100, RSKangXi=170.13, Def{narrow pass, strategic point, dangerous}
96AB CJK UNIFIED IDEOGRAPH-#96AB, IRGKangXi=1361.110, RSKangXi=170.13
96AC CJK UNIFIED IDEOGRAPH-#96AC, IRGKangXi=1362.050, RSKangXi=170.14
96AD CJK UNIFIED IDEOGRAPH-#96AD, IRGKangXi=1362.060, RSKangXi=170.14
96AE CJK UNIFIED IDEOGRAPH-#96AE, IRGKangXi=1362.080, RSKangXi=170.14, Def{to rise up; a rainbow; to fall}
96AF CJK UNIFIED IDEOGRAPH-#96AF, IRGKangXi=1362.100, RSKangXi=170.14
96B0 CJK UNIFIED IDEOGRAPH-#96B0, IRGKangXi=1362.120, RSKangXi=170.14, Def{low, damp land, marsh, swamp}
96B1 CJK UNIFIED IDEOGRAPH-#96B1, IRGKangXi=1362.150, RSKangXi=170.14, Def{hide, conceal; hidden, secret}
96B2 CJK UNIFIED IDEOGRAPH-#96B2, IRGKangXi=1362.191, RSKangXi=170.14, Def{stallion; promote}
96B3 CJK UNIFIED IDEOGRAPH-#96B3, IRGKangXi=1362.220, RSKangXi=170.15, Def{to destroy; to overthrow}
96B4 CJK UNIFIED IDEOGRAPH-#96B4, IRGKangXi=1363.080, RSKangXi=170.16, Def{mountain located between Shanxi}
96B5 CJK UNIFIED IDEOGRAPH-#96B5, IRGKangXi=1363.110
96B6 CJK UNIFIED IDEOGRAPH-#96B6, IRGKangXi=1363.220, RSKangXi=171.0, Def{subservient; servant; KangXi radical 171}
96B7 CJK UNIFIED IDEOGRAPH-#96B7, IRGKangXi=1363.260, RSKangXi=171.8, Def{be subservient to; servant}
96B8 CJK UNIFIED IDEOGRAPH-#96B8, IRGKangXi=1363.300, RSKangXi=171.9, Def{be subservient to; servant}
96B9 CJK UNIFIED IDEOGRAPH-#96B9, IRGKangXi=1364.050, RSKangXi=172.0, Def{bird; KangXi radical 172}
96BA CJK UNIFIED IDEOGRAPH-#96BA, IRGKangXi=1364.080, RSKangXi=172.2, Def{a bird flying high ambition}
96BB CJK UNIFIED IDEOGRAPH-#96BB, IRGKangXi=1364.090, RSKangXi=172.2, Def{single, one of pair, lone}
96BC CJK UNIFIED IDEOGRAPH-#96BC, IRGKangXi=1364.110, RSKangXi=172.2, Def{aquiline (nose); a falcon}
96BD CJK UNIFIED IDEOGRAPH-#96BD, IRGKangXi=1364.130, RSKangXi=172.2, Def{superior, outstanding, talented}
96BE CJK UNIFIED IDEOGRAPH-#96BE, IRGKangXi=1364.131, RSKangXi=29.8, Def{difficult, arduous, hard; unable}
96BF CJK UNIFIED IDEOGRAPH-#96BF, IRGKangXi=1364.170, RSKangXi=172.3
96C0 CJK UNIFIED IDEOGRAPH-#96C0, IRGKangXi=1364.200, RSKangXi=172.3, Def{sparrow}
96C1 CJK UNIFIED IDEOGRAPH-#96C1, IRGKangXi=1364.240, RSKangXi=172.4, Def{wild goose}
96C2 CJK UNIFIED IDEOGRAPH-#96C2, IRGKangXi=1365.030, RSKangXi=172.4
96C3 CJK UNIFIED IDEOGRAPH-#96C3, IRGKangXi=1365.110, RSKangXi=172.4
96C4 CJK UNIFIED IDEOGRAPH-#96C4, IRGKangXi=1365.120, RSKangXi=172.4, Def{male of species; hero; manly}
96C5 CJK UNIFIED IDEOGRAPH-#96C5, IRGKangXi=1365.140, RSKangXi=172.4, Def{elegant, graceful, refined}
96C6 CJK UNIFIED IDEOGRAPH-#96C6, IRGKangXi=1365.150, RSKangXi=172.4, Def{assemble, collect together}
96C7 CJK UNIFIED IDEOGRAPH-#96C7, IRGKangXi=1365.180, RSKangXi=172.4, Def{employ, to hire}
96C8 CJK UNIFIED IDEOGRAPH-#96C8, IRGKangXi=1365.181, RSKangXi=172.4
96C9 CJK UNIFIED IDEOGRAPH-#96C9, IRGKangXi=1365.240, RSKangXi=172.5, Def{pheasant; crenellated wall}
96CA CJK UNIFIED IDEOGRAPH-#96CA, IRGKangXi=1366.050, RSKangXi=172.5, Def{the crow of a male pheasant}
96CB CJK UNIFIED IDEOGRAPH-#96CB, IRGKangXi=1366.090, RSKangXi=172.5, Def{superior, outstanding, talented}
96CC CJK UNIFIED IDEOGRAPH-#96CC, IRGKangXi=1366.110, RSKangXi=172.5, Def{female; feminine; gentle, soft}
96CD CJK UNIFIED IDEOGRAPH-#96CD, IRGKangXi=1366.140, RSKangXi=172.5, Def{harmony, union; harmonious}
96CE CJK UNIFIED IDEOGRAPH-#96CE, IRGKangXi=1366.160, RSKangXi=172.5, Def{osprey, fishhawk; hold back}
96CF CJK UNIFIED IDEOGRAPH-#96CF, IRGKangXi=1366.181, RSKangXi=172.5, Def{chick, fledging; infant, toddler}
96D0 CJK UNIFIED IDEOGRAPH-#96D0, IRGKangXi=1367.010, RSKangXi=141.8
96D1 CJK UNIFIED IDEOGRAPH-#96D1, IRGKangXi=1367.070, RSKangXi=172.6, Def{mixed, blended; mix, mingle}
96D2 CJK UNIFIED IDEOGRAPH-#96D2, IRGKangXi=1367.110, RSKangXi=172.6, Def{black horse with white mane}
96D3 CJK UNIFIED IDEOGRAPH-#96D3, IRGKangXi=1367.280, RSKangXi=172.7
96D4 CJK UNIFIED IDEOGRAPH-#96D4, IRGKangXi=1367.530, RSKangXi=172.8
96D5 CJK UNIFIED IDEOGRAPH-#96D5, IRGKangXi=1367.580, RSKangXi=172.8, Def{engrave, inlay, carve; exhaust; used for U+9D70 鵰 an eagle, vulture}
96D6 CJK UNIFIED IDEOGRAPH-#96D6, IRGKangXi=1368.220, RSKangXi=172.9, Def{although, even if}
96D7 CJK UNIFIED IDEOGRAPH-#96D7, IRGKangXi=1368.290, RSKangXi=172.10, Def{a white pheasant}
96D8 CJK UNIFIED IDEOGRAPH-#96D8, IRGKangXi=1368.300, RSKangXi=172.10, Def{dye made from red soil; ochre}
96D9 CJK UNIFIED IDEOGRAPH-#96D9, IRGKangXi=1368.340, RSKangXi=172.10, Def{set of two, pair, couple; both}
96DA CJK UNIFIED IDEOGRAPH-#96DA, IRGKangXi=1368.380, RSKangXi=172.10, Def{a heron; small cup}
96DB CJK UNIFIED IDEOGRAPH-#96DB, IRGKangXi=1368.390, RSKangXi=172.10, Def{chick, fledging; infant, toddler}
96DC CJK UNIFIED IDEOGRAPH-#96DC, IRGKangXi=1368.400, RSKangXi=172.10, Def{mixed, blended; mix, mingle}
96DD CJK UNIFIED IDEOGRAPH-#96DD, IRGKangXi=1369.010, RSKangXi=172.10, Def{marsh; pool; harmonious}
96DE CJK UNIFIED IDEOGRAPH-#96DE, IRGKangXi=1369.020, RSKangXi=172.10, Def{chickens; domestic fowl}
96DF CJK UNIFIED IDEOGRAPH-#96DF, IRGKangXi=1369.030, RSKangXi=172.10, Def{sparrow; revolve; place name}
96E0 CJK UNIFIED IDEOGRAPH-#96E0, IRGKangXi=1369.041, RSKangXi=172.10, Def{enemy, rival, opponent}
96E1 CJK UNIFIED IDEOGRAPH-#96E1, IRGKangXi=1369.100, RSKangXi=172.11
96E2 CJK UNIFIED IDEOGRAPH-#96E2, IRGKangXi=1369.160, RSKangXi=172.11, Def{leave, depart; go away; separate}
96E3 CJK UNIFIED IDEOGRAPH-#96E3, IRGKangXi=1370.050, RSKangXi=172.11, Def{difficult, arduous, hard; unable}
96E4 CJK UNIFIED IDEOGRAPH-#96E4, IRGKangXi=1370.350, RSKangXi=172.13
96E5 CJK UNIFIED IDEOGRAPH-#96E5, IRGKangXi=1371.090, RSKangXi=172.16
96E6 CJK UNIFIED IDEOGRAPH-#96E6, IRGKangXi=1371.110, RSKangXi=172.16
96E7 CJK UNIFIED IDEOGRAPH-#96E7, IRGKangXi=1371.150, RSKangXi=172.20
96E8 CJK UNIFIED IDEOGRAPH-#96E8, IRGKangXi=1371.180, RSKangXi=173.0, Def{rain; rainy; KangXi radical 173}
96E9 CJK UNIFIED IDEOGRAPH-#96E9, IRGKangXi=1371.250, RSKangXi=173.3, Def{offer sacrifice for rain}
96EA CJK UNIFIED IDEOGRAPH-#96EA, IRGKangXi=1371.290, RSKangXi=173.3, Def{snow; wipe away shame, avenge}
96EB CJK UNIFIED IDEOGRAPH-#96EB, IRGKangXi=1371.301, RSKangXi=173.3, Def{a drop, trickle, dripping}
96EC CJK UNIFIED IDEOGRAPH-#96EC, IRGKangXi=1371.310, RSKangXi=173.4
96ED CJK UNIFIED IDEOGRAPH-#96ED, IRGKangXi=1371.350, RSKangXi=173.4
96EE CJK UNIFIED IDEOGRAPH-#96EE, IRGKangXi=1371.380, RSKangXi=173.4
96EF CJK UNIFIED IDEOGRAPH-#96EF, IRGKangXi=1371.410, RSKangXi=173.4, Def{cloud patterns, coloring of cloud}
96F0 CJK UNIFIED IDEOGRAPH-#96F0, IRGKangXi=1372.010, RSKangXi=173.4, Def{atmosphere; mist, fog}
96F1 CJK UNIFIED IDEOGRAPH-#96F1, IRGKangXi=1372.030, RSKangXi=173.4, Def{snowing heavily}
96F2 CJK UNIFIED IDEOGRAPH-#96F2, IRGKangXi=1372.050, RSKangXi=173.4, Def{clouds; Yunnan province}
96F3 CJK UNIFIED IDEOGRAPH-#96F3, IRGKangXi=1372.061, RSKangXi=173.4, Def{thunderclap, crashing thunder}
96F4 CJK UNIFIED IDEOGRAPH-#96F4, IRGKangXi=1372.080, RSKangXi=173.5
96F5 CJK UNIFIED IDEOGRAPH-#96F5, IRGKangXi=1372.090, RSKangXi=173.5
96F6 CJK UNIFIED IDEOGRAPH-#96F6, IRGKangXi=1372.100, RSKangXi=173.5, Def{zero; fragment, fraction}
96F7 CJK UNIFIED IDEOGRAPH-#96F7, IRGKangXi=1372.140, RSKangXi=173.5, Def{thunder}
96F8 CJK UNIFIED IDEOGRAPH-#96F8, IRGKangXi=1372.240, RSKangXi=173.5
96F9 CJK UNIFIED IDEOGRAPH-#96F9, IRGKangXi=1372.260, RSKangXi=173.5, Def{hail}
96FA CJK UNIFIED IDEOGRAPH-#96FA, IRGKangXi=1373.020, RSKangXi=173.5
96FB CJK UNIFIED IDEOGRAPH-#96FB, IRGKangXi=1373.050, RSKangXi=173.5, Def{electricity, electric; lightning}
96FC CJK UNIFIED IDEOGRAPH-#96FC, IRGKangXi=1373.090, RSKangXi=173.5
96FD CJK UNIFIED IDEOGRAPH-#96FD, IRGKangXi=1373.091, RSKangXi=173.5
96FE CJK UNIFIED IDEOGRAPH-#96FE, IRGKangXi=1373.091, RSKangXi=173.5, Def{fog, mist, vapor, fine spray}
96FF CJK UNIFIED IDEOGRAPH-#96FF, IRGKangXi=1373.230, RSKangXi=173.6
9700 CJK UNIFIED IDEOGRAPH-#9700, IRGKangXi=1373.240, RSKangXi=173.6, Def{need, require, must}
9701 CJK UNIFIED IDEOGRAPH-#9701, IRGKangXi=1374.021, RSKangXi=173.6, Def{to clear up after rain; to cease be angry}
9702 CJK UNIFIED IDEOGRAPH-#9702, IRGKangXi=1374.030, RSKangXi=173.7, Def{fine rain, drizzle}
9703 CJK UNIFIED IDEOGRAPH-#9703, IRGKangXi=1374.050, RSKangXi=173.7, Def{long continued rains}
9704 CJK UNIFIED IDEOGRAPH-#9704, IRGKangXi=1374.110, RSKangXi=173.7, Def{sky; clouds, mist; night}
9705 CJK UNIFIED IDEOGRAPH-#9705, IRGKangXi=1374.170, RSKangXi=173.7, Def{thunder}
9706 CJK UNIFIED IDEOGRAPH-#9706, IRGKangXi=1374.200, RSKangXi=173.7, Def{a sudden peal of thunder}
9707 CJK UNIFIED IDEOGRAPH-#9707, IRGKangXi=1374.210, RSKangXi=173.7, Def{shake, quake, tremor; excite}
9708 CJK UNIFIED IDEOGRAPH-#9708, IRGKangXi=1375.010, RSKangXi=173.7, Def{torrential rains, flow of water}
9709 CJK UNIFIED IDEOGRAPH-#9709, IRGKangXi=1375.020, RSKangXi=173.7, Def{mildew, mold; moldy, mildewed}
970A CJK UNIFIED IDEOGRAPH-#970A, IRGKangXi=1375.051, RSKangXi=173.7, Def{spirit, soul; spiritual world}
970B CJK UNIFIED IDEOGRAPH-#970B, IRGKangXi=1375.090, RSKangXi=173.8, Def{slight, passing}
970C CJK UNIFIED IDEOGRAPH-#970C, IRGKangXi=1375.150, RSKangXi=173.8
970D CJK UNIFIED IDEOGRAPH-#970D, IRGKangXi=1375.170, RSKangXi=173.8, Def{quickly, suddenly; surname}
970E CJK UNIFIED IDEOGRAPH-#970E, IRGKangXi=1375.180, RSKangXi=173.8, Def{light rain, drizzle; an instant; passing}
970F CJK UNIFIED IDEOGRAPH-#970F, IRGKangXi=1375.190, RSKangXi=173.8, Def{falling of snow and rain}
9710 CJK UNIFIED IDEOGRAPH-#9710, IRGKangXi=1375.250, RSKangXi=173.8
9711 CJK UNIFIED IDEOGRAPH-#9711, IRGKangXi=1375.260, RSKangXi=173.8, Def{be moistened, soaked; moisten}
9712 CJK UNIFIED IDEOGRAPH-#9712, IRGKangXi=1375.270, RSKangXi=173.8
9713 CJK UNIFIED IDEOGRAPH-#9713, IRGKangXi=1375.290, RSKangXi=173.8, Def{rainbow; variegated, colored}
9714 CJK UNIFIED IDEOGRAPH-#9714, IRGKangXi=1376.010, RSKangXi=173.8
9715 CJK UNIFIED IDEOGRAPH-#9715, IRGKangXi=1376.020, RSKangXi=173.8
9716 CJK UNIFIED IDEOGRAPH-#9716, IRGKangXi=1376.030, RSKangXi=173.8, Def{long spell of rain, copious rain}
9717 CJK UNIFIED IDEOGRAPH-#9717, IRGKangXi=1376.091, RSKangXi=173.8
9718 CJK UNIFIED IDEOGRAPH-#9718, IRGKangXi=1376.150, RSKangXi=173.9
9719 CJK UNIFIED IDEOGRAPH-#9719, IRGKangXi=1376.160, RSKangXi=173.9, Def{sleet}
971A CJK UNIFIED IDEOGRAPH-#971A, IRGKangXi=1376.170, RSKangXi=173.9
971B CJK UNIFIED IDEOGRAPH-#971B, IRGKangXi=1376.180, RSKangXi=173.9
971C CJK UNIFIED IDEOGRAPH-#971C, IRGKangXi=1376.290, RSKangXi=173.9, Def{frost; crystallized; candied}
971D CJK UNIFIED IDEOGRAPH-#971D, IRGKangXi=1376.300, RSKangXi=173.9, Def{drops of rain; to fall in drops}
971E CJK UNIFIED IDEOGRAPH-#971E, IRGKangXi=1376.310, RSKangXi=173.9, Def{rosy clouds}
971F CJK UNIFIED IDEOGRAPH-#971F, IRGKangXi=1376.320, RSKangXi=173.9
9720 CJK UNIFIED IDEOGRAPH-#9720, IRGKangXi=1376.340, RSKangXi=173.9
9721 CJK UNIFIED IDEOGRAPH-#9721, IRGKangXi=1377.080, RSKangXi=173.10, Def{drizzling rain; to soak-- used fig. of favours}
9722 CJK UNIFIED IDEOGRAPH-#9722, IRGKangXi=1377.090, RSKangXi=173.10, Def{dust}
9723 CJK UNIFIED IDEOGRAPH-#9723, IRGKangXi=1377.170, RSKangXi=173.10, Def{fall}
9724 CJK UNIFIED IDEOGRAPH-#9724, IRGKangXi=1377.220, RSKangXi=173.10, Def{drip; rain-water catcher}
9725 CJK UNIFIED IDEOGRAPH-#9725, IRGKangXi=1377.250, RSKangXi=173.10
9726 CJK UNIFIED IDEOGRAPH-#9726, IRGKangXi=1377.330, RSKangXi=173.11
9727 CJK UNIFIED IDEOGRAPH-#9727, IRGKangXi=1377.360, RSKangXi=173.11, Def{fog, mist, vapor, fine spray}
9728 CJK UNIFIED IDEOGRAPH-#9728, IRGKangXi=1377.370, RSKangXi=173.11, Def{clouding}
9729 CJK UNIFIED IDEOGRAPH-#9729, IRGKangXi=1377.380, RSKangXi=173.11
972A CJK UNIFIED IDEOGRAPH-#972A, IRGKangXi=1377.480, RSKangXi=173.11, Def{long and heavy rain}
972B CJK UNIFIED IDEOGRAPH-#972B, IRGKangXi=1377.520, RSKangXi=173.11, Def{heavy rain}
972C CJK UNIFIED IDEOGRAPH-#972C, IRGKangXi=1378.041, RSKangXi=173.11
972D CJK UNIFIED IDEOGRAPH-#972D, IRGKangXi=1378.041, RSKangXi=173.11, Def{cloudy sky, haze; calm, peaceful}
972E CJK UNIFIED IDEOGRAPH-#972E, IRGKangXi=1378.090, RSKangXi=173.12
972F CJK UNIFIED IDEOGRAPH-#972F, IRGKangXi=1378.100, RSKangXi=173.12
9730 CJK UNIFIED IDEOGRAPH-#9730, IRGKangXi=1378.160, RSKangXi=173.12, Def{hail, sleet}
9731 CJK UNIFIED IDEOGRAPH-#9731, IRGKangXi=1378.210, RSKangXi=173.12, Def{cloud}
9732 CJK UNIFIED IDEOGRAPH-#9732, IRGKangXi=1378.220, RSKangXi=173.12, Def{dew; bare, open, exposed}
9733 CJK UNIFIED IDEOGRAPH-#9733, IRGKangXi=1378.230, RSKangXi=173.12
9734 CJK UNIFIED IDEOGRAPH-#9734, IRGKangXi=1378.250, RSKangXi=173.12
9735 CJK UNIFIED IDEOGRAPH-#9735, IRGKangXi=1378.290, RSKangXi=173.13
9736 CJK UNIFIED IDEOGRAPH-#9736, IRGKangXi=1379.100, RSKangXi=173.13, Def{downpouring of rain}
9737 CJK UNIFIED IDEOGRAPH-#9737, IRGKangXi=1379.120, RSKangXi=173.13
9738 CJK UNIFIED IDEOGRAPH-#9738, IRGKangXi=1379.130, RSKangXi=173.13, Def{rule by might rather than right}
9739 CJK UNIFIED IDEOGRAPH-#9739, IRGKangXi=1379.150, RSKangXi=173.13, Def{thunder, crashing thunder}
973A CJK UNIFIED IDEOGRAPH-#973A, IRGKangXi=1379.160, RSKangXi=173.13
973B CJK UNIFIED IDEOGRAPH-#973B, IRGKangXi=1379.201, RSKangXi=173.13
973C CJK UNIFIED IDEOGRAPH-#973C, IRGKangXi=1379.210, RSKangXi=173.14
973D CJK UNIFIED IDEOGRAPH-#973D, IRGKangXi=1379.220, RSKangXi=173.14, Def{to clear up after rain; to cease be angry}
973E CJK UNIFIED IDEOGRAPH-#973E, IRGKangXi=1379.300, RSKangXi=173.14, Def{misty, foggy; dust storm}
973F CJK UNIFIED IDEOGRAPH-#973F, IRGKangXi=1380.010, RSKangXi=173.14
9740 CJK UNIFIED IDEOGRAPH-#9740, IRGKangXi=1380.020, RSKangXi=173.14, Def{drizzling, fine rain; mist}
9741 CJK UNIFIED IDEOGRAPH-#9741, IRGKangXi=1380.110, RSKangXi=173.15, Def{thick, strong}
9742 CJK UNIFIED IDEOGRAPH-#9742, IRGKangXi=1380.150, RSKangXi=173.16, Def{thunderclap, crashing thunder}
9743 CJK UNIFIED IDEOGRAPH-#9743, IRGKangXi=1380.170, RSKangXi=173.16
9744 CJK UNIFIED IDEOGRAPH-#9744, IRGKangXi=1380.180, RSKangXi=173.16, Def{cloudy sky, haze; calm, peaceful}
9745 CJK UNIFIED IDEOGRAPH-#9745, IRGKangXi=1380.190, RSKangXi=173.16
9746 CJK UNIFIED IDEOGRAPH-#9746, IRGKangXi=1380.220, RSKangXi=173.16, Def{cloudy sky; not clear; dark}
9747 CJK UNIFIED IDEOGRAPH-#9747, IRGKangXi=1380.230, RSKangXi=173.16
9748 CJK UNIFIED IDEOGRAPH-#9748, IRGKangXi=1380.240, RSKangXi=173.16, Def{spirit, soul; spiritual world}
9749 CJK UNIFIED IDEOGRAPH-#9749, IRGKangXi=1381.020, RSKangXi=173.17, Def{cloudy sky; dark, obscure}
974A CJK UNIFIED IDEOGRAPH-#974A, IRGKangXi=1381.070, RSKangXi=173.18
974B CJK UNIFIED IDEOGRAPH-#974B, IRGKangXi=1381.110, RSKangXi=173.19
974C CJK UNIFIED IDEOGRAPH-#974C, IRGKangXi=1381.111, RSKangXi=173.19
974D CJK UNIFIED IDEOGRAPH-#974D, IRGKangXi=1381.111, RSKangXi=173.19
974E CJK UNIFIED IDEOGRAPH-#974E, IRGKangXi=1381.111, RSKangXi=173.19
974F CJK UNIFIED IDEOGRAPH-#974F, IRGKangXi=1381.141, RSKangXi=173.21
9750 CJK UNIFIED IDEOGRAPH-#9750, IRGKangXi=1381.160, RSKangXi=173.31
9751 CJK UNIFIED IDEOGRAPH-#9751, IRGKangXi=1381.190, RSKangXi=174.0, Def{blue}
9752 CJK UNIFIED IDEOGRAPH-#9752, IRGKangXi=1381.191, RSKangXi=174.0, Def{blue, green, black; young}
9753 CJK UNIFIED IDEOGRAPH-#9753, IRGKangXi=1381.261, RSKangXi=174.4, Def{make up face; ornament; quiet}
9754 CJK UNIFIED IDEOGRAPH-#9754, IRGKangXi=1381.261, RSKangXi=174.4
9755 CJK UNIFIED IDEOGRAPH-#9755, IRGKangXi=1381.270, RSKangXi=174.5
9756 CJK UNIFIED IDEOGRAPH-#9756, IRGKangXi=1381.280, RSKangXi=174.5, Def{pacify; appease; calm, peaceful}
9757 CJK UNIFIED IDEOGRAPH-#9757, IRGKangXi=1381.300, RSKangXi=174.6
9758 CJK UNIFIED IDEOGRAPH-#9758, IRGKangXi=1381.310, RSKangXi=174.6
9759 CJK UNIFIED IDEOGRAPH-#9759, IRGKangXi=1381.311, RSKangXi=174.6, Def{quiet, still, motionless; gentle}
975A CJK UNIFIED IDEOGRAPH-#975A, IRGKangXi=1381.320, RSKangXi=174.7, Def{make up face; ornament; quiet; (Cant.) pretty}
975B CJK UNIFIED IDEOGRAPH-#975B, IRGKangXi=1382.020, RSKangXi=174.8, Def{indigo; any blue dye}
975C CJK UNIFIED IDEOGRAPH-#975C, IRGKangXi=1382.030, RSKangXi=174.8, Def{quiet, still, motionless; gentle}
975D CJK UNIFIED IDEOGRAPH-#975D, IRGKangXi=1382.070, RSKangXi=174.10, Def{(in taoism) the heaven}
975E CJK UNIFIED IDEOGRAPH-#975E, IRGKangXi=1382.110, RSKangXi=175.0, Def{not, negative, non-; oppose}
975F CJK UNIFIED IDEOGRAPH-#975F, IRGKangXi=1382.220, RSKangXi=175.4
9760 CJK UNIFIED IDEOGRAPH-#9760, IRGKangXi=1382.290, RSKangXi=175.7, Def{lean on, trust, depend on; near}
9761 CJK UNIFIED IDEOGRAPH-#9761, IRGKangXi=1383.020, RSKangXi=175.11, Def{divide, disperse, scatter}
9762 CJK UNIFIED IDEOGRAPH-#9762, IRGKangXi=1383.070, RSKangXi=176.0, Def{face; surface; plane; side, dimension}
9763 CJK UNIFIED IDEOGRAPH-#9763, IRGKangXi=1383.071, RSKangXi=176.0
9764 CJK UNIFIED IDEOGRAPH-#9764, IRGKangXi=1383.230, RSKangXi=176.5
9765 CJK UNIFIED IDEOGRAPH-#9765, IRGKangXi=1384.071, RSKangXi=27.13, Def{dimples}
9766 CJK UNIFIED IDEOGRAPH-#9766, IRGKangXi=1384.150, RSKangXi=176.7, Def{timid, shy, bashful}
9767 CJK UNIFIED IDEOGRAPH-#9767, IRGKangXi=1384.390, RSKangXi=176.12, Def{wash face}
9768 CJK UNIFIED IDEOGRAPH-#9768, IRGKangXi=1384.440, RSKangXi=176.14, Def{dimples}
9769 CJK UNIFIED IDEOGRAPH-#9769, IRGKangXi=1385.010, RSKangXi=177.0, Def{leather, animal hides; rad. 177}
976A CJK UNIFIED IDEOGRAPH-#976A, IRGKangXi=1385.030, RSKangXi=177.2, Def{to cobble, to patch}
976B CJK UNIFIED IDEOGRAPH-#976B, IRGKangXi=1385.040, RSKangXi=177.3, Def{strong and pliable, resilient}
976C CJK UNIFIED IDEOGRAPH-#976C, IRGKangXi=1385.050, RSKangXi=177.3
976D CJK UNIFIED IDEOGRAPH-#976D, IRGKangXi=1385.060, RSKangXi=177.3, Def{strong and pliable, resilient}
976E CJK UNIFIED IDEOGRAPH-#976E, IRGKangXi=1385.090, RSKangXi=177.3, Def{bridle}
976F CJK UNIFIED IDEOGRAPH-#976F, IRGKangXi=1385.100, RSKangXi=177.3
9770 CJK UNIFIED IDEOGRAPH-#9770, IRGKangXi=1385.131, RSKangXi=177.3, Def{leg warmer}
9771 CJK UNIFIED IDEOGRAPH-#9771, IRGKangXi=1385.131, RSKangXi=177.3, Def{strong and pliable, resilient}
9772 CJK UNIFIED IDEOGRAPH-#9772, IRGKangXi=1385.140, RSKangXi=177.4
9773 CJK UNIFIED IDEOGRAPH-#9773, IRGKangXi=1385.180, RSKangXi=177.4, Def{strap on a horse's breast}
9774 CJK UNIFIED IDEOGRAPH-#9774, IRGKangXi=1385.190, RSKangXi=177.4, Def{boots}
9775 CJK UNIFIED IDEOGRAPH-#9775, IRGKangXi=1385.220, RSKangXi=177.4
9776 CJK UNIFIED IDEOGRAPH-#9776, IRGKangXi=1385.240, RSKangXi=177.4, Def{target; splashboard on chariot}
9777 CJK UNIFIED IDEOGRAPH-#9777, IRGKangXi=1385.250, RSKangXi=177.4, Def{the leather belt that connects a horse with a cart}
9778 CJK UNIFIED IDEOGRAPH-#9778, IRGKangXi=1386.070, RSKangXi=177.4, Def{a child's shoes; slippers}
9779 CJK UNIFIED IDEOGRAPH-#9779, IRGKangXi=1386.101, RSKangXi=177.4
977A CJK UNIFIED IDEOGRAPH-#977A, IRGKangXi=1386.170, RSKangXi=177.5, Def{stocking; the Tungusic tribe}
977B CJK UNIFIED IDEOGRAPH-#977B, IRGKangXi=1386.180, RSKangXi=177.5
977C CJK UNIFIED IDEOGRAPH-#977C, IRGKangXi=1386.200, RSKangXi=177.5, Def{tartars}
977D CJK UNIFIED IDEOGRAPH-#977D, IRGKangXi=1386.230, RSKangXi=177.5
977E CJK UNIFIED IDEOGRAPH-#977E, IRGKangXi=1386.260, RSKangXi=177.5
977F CJK UNIFIED IDEOGRAPH-#977F, IRGKangXi=1386.270, RSKangXi=177.5, Def{the leg of a boot}
9780 CJK UNIFIED IDEOGRAPH-#9780, IRGKangXi=1386.280, RSKangXi=177.5, Def{drum}
9781 CJK UNIFIED IDEOGRAPH-#9781, IRGKangXi=1386.330, RSKangXi=177.5
9782 CJK UNIFIED IDEOGRAPH-#9782, IRGKangXi=1386.360, RSKangXi=177.5
9783 CJK UNIFIED IDEOGRAPH-#9783, IRGKangXi=1386.370, RSKangXi=177.5, Def{board}
9784 CJK UNIFIED IDEOGRAPH-#9784, IRGKangXi=1386.380, RSKangXi=177.5, Def{to work hides; leather bag}
9785 CJK UNIFIED IDEOGRAPH-#9785, IRGKangXi=1386.410, RSKangXi=177.5, Def{leather strap over horse's neck}
9786 CJK UNIFIED IDEOGRAPH-#9786, IRGKangXi=1387.031, RSKangXi=177.5, Def{an archer's arm-protector}
9787 CJK UNIFIED IDEOGRAPH-#9787, IRGKangXi=1387.110, RSKangXi=177.6
9788 CJK UNIFIED IDEOGRAPH-#9788, IRGKangXi=1387.140, RSKangXi=177.6
9789 CJK UNIFIED IDEOGRAPH-#9789, IRGKangXi=1387.160, RSKangXi=177.6, Def{drum}
978A CJK UNIFIED IDEOGRAPH-#978A, IRGKangXi=1387.190, RSKangXi=177.6
978B CJK UNIFIED IDEOGRAPH-#978B, IRGKangXi=1387.220, RSKangXi=177.6, Def{shoes, footwear in general}
978C CJK UNIFIED IDEOGRAPH-#978C, IRGKangXi=1387.230, RSKangXi=177.6
978D CJK UNIFIED IDEOGRAPH-#978D, IRGKangXi=1387.240, RSKangXi=177.6, Def{saddle; any saddle-shaped object}
978E CJK UNIFIED IDEOGRAPH-#978E, IRGKangXi=1387.260, RSKangXi=177.6
978F CJK UNIFIED IDEOGRAPH-#978F, IRGKangXi=1387.280, RSKangXi=177.6, Def{bind; firm, secure, strong}
9790 CJK UNIFIED IDEOGRAPH-#9790, IRGKangXi=1387.291, RSKangXi=177.6
9791 CJK UNIFIED IDEOGRAPH-#9791, IRGKangXi=1388.151, RSKangXi=177.6, Def{tatars}
9792 CJK UNIFIED IDEOGRAPH-#9792, IRGKangXi=1387.291, RSKangXi=177.6, Def{mud shoe, sledge for the feet}
9793 CJK UNIFIED IDEOGRAPH-#9793, IRGKangXi=1387.310, RSKangXi=177.7
9794 CJK UNIFIED IDEOGRAPH-#9794, IRGKangXi=1387.350, RSKangXi=177.7, Def{sides or uppers of shoes to stretch a skin on a frame for a drum; (Cant.) to cover}
9795 CJK UNIFIED IDEOGRAPH-#9795, IRGKangXi=1388.010, RSKangXi=177.7
9796 CJK UNIFIED IDEOGRAPH-#9796, IRGKangXi=1388.080, RSKangXi=177.7
9797 CJK UNIFIED IDEOGRAPH-#9797, IRGKangXi=1388.110, RSKangXi=177.7, Def{reins}
9798 CJK UNIFIED IDEOGRAPH-#9798, IRGKangXi=1388.120, RSKangXi=177.7, Def{scabbard, sheath}
9799 CJK UNIFIED IDEOGRAPH-#9799, IRGKangXi=1388.130, RSKangXi=177.7, Def{scabbard; traces, reins}
979A CJK UNIFIED IDEOGRAPH-#979A, IRGKangXi=1388.180, RSKangXi=177.8, Def{bridle}
979B CJK UNIFIED IDEOGRAPH-#979B, IRGKangXi=1388.360, RSKangXi=177.8
979C CJK UNIFIED IDEOGRAPH-#979C, IRGKangXi=1388.380, RSKangXi=177.8, Def{shoes, boots}
979D CJK UNIFIED IDEOGRAPH-#979D, IRGKangXi=1388.400, RSKangXi=177.8, Def{the piece of leather used for soles on Chinese shoes. a patch}
979E CJK UNIFIED IDEOGRAPH-#979E, IRGKangXi=1388.440, RSKangXi=177.8, Def{sheath}
979F CJK UNIFIED IDEOGRAPH-#979F, IRGKangXi=1389.040, RSKangXi=177.8, Def{skin; leather}
97A0 CJK UNIFIED IDEOGRAPH-#97A0, IRGKangXi=1389.050, RSKangXi=177.8, Def{bow, bend; rear, raise, nourish}
97A1 CJK UNIFIED IDEOGRAPH-#97A1, IRGKangXi=1389.071, RSKangXi=177.8, Def{leg warmer}
97A2 CJK UNIFIED IDEOGRAPH-#97A2, IRGKangXi=1389.080, RSKangXi=177.9
97A3 CJK UNIFIED IDEOGRAPH-#97A3, IRGKangXi=1389.130, RSKangXi=177.9, Def{tan, soften}
97A4 CJK UNIFIED IDEOGRAPH-#97A4, IRGKangXi=1389.150, RSKangXi=177.9
97A5 CJK UNIFIED IDEOGRAPH-#97A5, IRGKangXi=1389.240, RSKangXi=177.9
97A6 CJK UNIFIED IDEOGRAPH-#97A6, IRGKangXi=1389.250, RSKangXi=177.9, Def{leather stap; swing}
97A7 CJK UNIFIED IDEOGRAPH-#97A7, IRGKangXi=1389.260, RSKangXi=177.9, Def{a leather strap}
97A8 CJK UNIFIED IDEOGRAPH-#97A8, IRGKangXi=1389.270, RSKangXi=177.9, Def{tribe}
97A9 CJK UNIFIED IDEOGRAPH-#97A9, IRGKangXi=1389.310, RSKangXi=177.9
97AA CJK UNIFIED IDEOGRAPH-#97AA, IRGKangXi=1389.330, RSKangXi=177.9
97AB CJK UNIFIED IDEOGRAPH-#97AB, IRGKangXi=1390.020, RSKangXi=177.9, Def{interrogate, question}
97AC CJK UNIFIED IDEOGRAPH-#97AC, IRGKangXi=1390.060, RSKangXi=177.9, Def{a quiver on a horse; a store}
97AD CJK UNIFIED IDEOGRAPH-#97AD, IRGKangXi=1390.090, RSKangXi=177.9, Def{whip; whip; string of firecrackers}
97AE CJK UNIFIED IDEOGRAPH-#97AE, IRGKangXi=1390.130, RSKangXi=177.9, Def{leather shoes}
97AF CJK UNIFIED IDEOGRAPH-#97AF, IRGKangXi=1390.151, RSKangXi=177.9, Def{saddle blanket}
97B0 CJK UNIFIED IDEOGRAPH-#97B0, IRGKangXi=1391.071, RSKangXi=177.9
97B1 CJK UNIFIED IDEOGRAPH-#97B1, IRGKangXi=1390.180, RSKangXi=177.10
97B2 CJK UNIFIED IDEOGRAPH-#97B2, IRGKangXi=1390.240, RSKangXi=177.10, Def{leather arm guard}
97B3 CJK UNIFIED IDEOGRAPH-#97B3, IRGKangXi=1390.280, RSKangXi=177.10
97B4 CJK UNIFIED IDEOGRAPH-#97B4, IRGKangXi=1390.340, RSKangXi=177.10, Def{saddle up horse; drive horse}
97B5 CJK UNIFIED IDEOGRAPH-#97B5, IRGKangXi=1390.360, RSKangXi=177.10, Def{shoes; boots}
97B6 CJK UNIFIED IDEOGRAPH-#97B6, IRGKangXi=1391.030, RSKangXi=177.10, Def{big leather belt}
97B7 CJK UNIFIED IDEOGRAPH-#97B7, IRGKangXi=1391.071, RSKangXi=177.10
97B8 CJK UNIFIED IDEOGRAPH-#97B8, IRGKangXi=1391.090, RSKangXi=177.11, Def{leather arm guard}
97B9 CJK UNIFIED IDEOGRAPH-#97B9, IRGKangXi=1391.100, RSKangXi=177.11, Def{skin}
97BA CJK UNIFIED IDEOGRAPH-#97BA, IRGKangXi=1391.150, RSKangXi=177.11, Def{the sound of drums}
97BB CJK UNIFIED IDEOGRAPH-#97BB, IRGKangXi=1391.260, RSKangXi=177.11
97BC CJK UNIFIED IDEOGRAPH-#97BC, IRGKangXi=1391.310, RSKangXi=177.12
97BD CJK UNIFIED IDEOGRAPH-#97BD, IRGKangXi=1391.380, RSKangXi=177.12, Def{mud shoe, sledge for the feet}
97BE CJK UNIFIED IDEOGRAPH-#97BE, IRGKangXi=1391.400, RSKangXi=177.12, Def{boots}
97BF CJK UNIFIED IDEOGRAPH-#97BF, IRGKangXi=1391.430, RSKangXi=177.12
97C0 CJK UNIFIED IDEOGRAPH-#97C0, IRGKangXi=1392.060, RSKangXi=177.13, Def{a saddle fastener}
97C1 CJK UNIFIED IDEOGRAPH-#97C1, IRGKangXi=1392.070, RSKangXi=177.13, Def{reins, halter; bridle}
97C2 CJK UNIFIED IDEOGRAPH-#97C2, IRGKangXi=1392.090, RSKangXi=177.13, Def{a saddle-flap. trappings}
97C3 CJK UNIFIED IDEOGRAPH-#97C3, IRGKangXi=1392.130, RSKangXi=177.13, Def{tatars}
97C4 CJK UNIFIED IDEOGRAPH-#97C4, IRGKangXi=1392.250, RSKangXi=177.14
97C5 CJK UNIFIED IDEOGRAPH-#97C5, IRGKangXi=1392.260, RSKangXi=177.14, Def{harness}
97C6 CJK UNIFIED IDEOGRAPH-#97C6, IRGKangXi=1392.290, RSKangXi=177.15, Def{swing}
97C7 CJK UNIFIED IDEOGRAPH-#97C7, IRGKangXi=1392.310, RSKangXi=177.15
97C8 CJK UNIFIED IDEOGRAPH-#97C8, IRGKangXi=1392.330, RSKangXi=177.15, Def{socks, stockings}
97C9 CJK UNIFIED IDEOGRAPH-#97C9, IRGKangXi=1392.400, RSKangXi=177.17, Def{saddle blanket}
97CA CJK UNIFIED IDEOGRAPH-#97CA, IRGKangXi=1393.010, RSKangXi=177.21, Def{a case for a bow}
97CB CJK UNIFIED IDEOGRAPH-#97CB, IRGKangXi=1393.060, RSKangXi=178.0, Def{tanned leather; surname; KangXi radical number 178}
97CC CJK UNIFIED IDEOGRAPH-#97CC, IRGKangXi=1393.100, RSKangXi=178.3, Def{strong and pliable, resilient; (Cant.) tough, elastic}
97CD CJK UNIFIED IDEOGRAPH-#97CD, IRGKangXi=1393.210, RSKangXi=178.5, Def{a leather knee-pad worn during sacrifices}
97CE CJK UNIFIED IDEOGRAPH-#97CE, IRGKangXi=1393.250, RSKangXi=178.5, Def{red}
97CF CJK UNIFIED IDEOGRAPH-#97CF, IRGKangXi=1394.050, RSKangXi=178.6
97D0 CJK UNIFIED IDEOGRAPH-#97D0, IRGKangXi=1394.080, RSKangXi=178.6, Def{knee-pad made of red-dyed leather}
97D1 CJK UNIFIED IDEOGRAPH-#97D1, IRGKangXi=1394.081, RSKangXi=178.6
97D2 CJK UNIFIED IDEOGRAPH-#97D2, IRGKangXi=1394.120, Def{a sheath, scabbard}
97D3 CJK UNIFIED IDEOGRAPH-#97D3, IRGKangXi=1394.200, RSKangXi=178.8, Def{fence; surname; Korea}
97D4 CJK UNIFIED IDEOGRAPH-#97D4, IRGKangXi=1394.210, RSKangXi=178.8, Def{a wrapper or case for bow}
97D5 CJK UNIFIED IDEOGRAPH-#97D5, IRGKangXi=1394.240, RSKangXi=178.8
97D6 CJK UNIFIED IDEOGRAPH-#97D6, IRGKangXi=1394.280, RSKangXi=178.9, Def{tan, soften}
97D7 CJK UNIFIED IDEOGRAPH-#97D7, IRGKangXi=1394.320, RSKangXi=178.9
97D8 CJK UNIFIED IDEOGRAPH-#97D8, IRGKangXi=1394.330, RSKangXi=178.9, Def{archer's thumb ring}
97D9 CJK UNIFIED IDEOGRAPH-#97D9, IRGKangXi=1394.340, RSKangXi=178.9, Def{right; proper; perpriety}
97DA CJK UNIFIED IDEOGRAPH-#97DA, IRGKangXi=1394.381, RSKangXi=178.9
97DB CJK UNIFIED IDEOGRAPH-#97DB, IRGKangXi=1394.440, RSKangXi=178.11
97DC CJK UNIFIED IDEOGRAPH-#97DC, IRGKangXi=1395.030, RSKangXi=178.10, Def{sheath, scabbard, bow case}
97DD CJK UNIFIED IDEOGRAPH-#97DD, IRGKangXi=1395.040, RSKangXi=178.10, Def{leather arm band}
97DE CJK UNIFIED IDEOGRAPH-#97DE, IRGKangXi=1395.050, RSKangXi=178.10, Def{an orange color; hide, conceal}
97DF CJK UNIFIED IDEOGRAPH-#97DF, IRGKangXi=1395.071, RSKangXi=178.10
97E0 CJK UNIFIED IDEOGRAPH-#97E0, IRGKangXi=1395.100, RSKangXi=178.11, Def{knee-pad}
97E1 CJK UNIFIED IDEOGRAPH-#97E1, IRGKangXi=1395.180, RSKangXi=178.12, Def{gorgeous}
97E2 CJK UNIFIED IDEOGRAPH-#97E2, IRGKangXi=1395.190, RSKangXi=178.12
97E3 CJK UNIFIED IDEOGRAPH-#97E3, IRGKangXi=1395.230, RSKangXi=178.13, Def{bow-bag}
97E4 CJK UNIFIED IDEOGRAPH-#97E4, IRGKangXi=1395.320, RSKangXi=178.15, Def{socks, stockings}
97E5 CJK UNIFIED IDEOGRAPH-#97E5, IRGKangXi=1395.330, RSKangXi=178.15
97E6 CJK UNIFIED IDEOGRAPH-#97E6, IRGKangXi=1396.031, RSKangXi=178.0, Def{tanned leather; surname; simplified form of KangXi radical number 178}
97E7 CJK UNIFIED IDEOGRAPH-#97E7, IRGKangXi=1396.031, RSKangXi=178.3, Def{strong and pliable, resilient}
97E8 CJK UNIFIED IDEOGRAPH-#97E8, IRGKangXi=1396.031, RSKangXi=178.5, Def{a leather knee-pad worn during sacrifices}
97E9 CJK UNIFIED IDEOGRAPH-#97E9, IRGKangXi=1396.031, RSKangXi=178.8, Def{fence; surname; Korea}
97EA CJK UNIFIED IDEOGRAPH-#97EA, IRGKangXi=1396.031, RSKangXi=178.9, Def{right; proper; perpriety}
97EB CJK UNIFIED IDEOGRAPH-#97EB, IRGKangXi=1396.031, RSKangXi=178.9, Def{secrete, hide, conceal}
97EC CJK UNIFIED IDEOGRAPH-#97EC, IRGKangXi=1396.031, RSKangXi=178.10, Def{sheath, scabbard, bow case}
97ED CJK UNIFIED IDEOGRAPH-#97ED, IRGKangXi=1396.040, RSKangXi=179.0, Def{scallion, leek; radical 179}
97EE CJK UNIFIED IDEOGRAPH-#97EE, IRGKangXi=1396.050, RSKangXi=179.4, Def{scallion, leek}
97EF CJK UNIFIED IDEOGRAPH-#97EF, IRGKangXi=1396.080, RSKangXi=179.6, Def{wild onions or leeks}
97F0 CJK UNIFIED IDEOGRAPH-#97F0, IRGKangXi=1396.090, RSKangXi=179.7
97F1 CJK UNIFIED IDEOGRAPH-#97F1, IRGKangXi=1396.120, RSKangXi=179.8, Def{wild onions or leeks}
97F2 CJK UNIFIED IDEOGRAPH-#97F2, IRGKangXi=1396.130, RSKangXi=179.10, Def{break or smash into pieces, pulverize}
97F3 CJK UNIFIED IDEOGRAPH-#97F3, IRGKangXi=1396.250, RSKangXi=180.0, Def{sound, tone, pitch, pronunciation}
97F4 CJK UNIFIED IDEOGRAPH-#97F4, IRGKangXi=1397.030, RSKangXi=180.4
97F5 CJK UNIFIED IDEOGRAPH-#97F5, IRGKangXi=1397.050, RSKangXi=180.4, Def{rhyme; vowel}
97F6 CJK UNIFIED IDEOGRAPH-#97F6, IRGKangXi=1397.090, RSKangXi=180.5, Def{music of the emperor Shun; beautiful}
97F7 CJK UNIFIED IDEOGRAPH-#97F7, IRGKangXi=1397.110, RSKangXi=180.5
97F8 CJK UNIFIED IDEOGRAPH-#97F8, IRGKangXi=1397.180, RSKangXi=180.7
97F9 CJK UNIFIED IDEOGRAPH-#97F9, IRGKangXi=1397.230, RSKangXi=180.9, Def{music of bell and drum}
97FA CJK UNIFIED IDEOGRAPH-#97FA, IRGKangXi=1397.240, RSKangXi=180.9, Def{music}
97FB CJK UNIFIED IDEOGRAPH-#97FB, IRGKangXi=1397.290, RSKangXi=180.10, Def{rhyme; vowel}
97FC CJK UNIFIED IDEOGRAPH-#97FC, IRGKangXi=1397.320, RSKangXi=180.10
97FD CJK UNIFIED IDEOGRAPH-#97FD, IRGKangXi=1397.330, RSKangXi=180.11
97FE CJK UNIFIED IDEOGRAPH-#97FE, IRGKangXi=1397.340, RSKangXi=180.11
97FF CJK UNIFIED IDEOGRAPH-#97FF, IRGKangXi=1398.020, RSKangXi=180.11, Def{make sound, make noise; sound}
9800 CJK UNIFIED IDEOGRAPH-#9800, IRGKangXi=1398.070, RSKangXi=180.14, Def{music}
9801 CJK UNIFIED IDEOGRAPH-#9801, IRGKangXi=1399.010, RSKangXi=181.0, Def{page, sheet, leaf; rad. no. 181}
9802 CJK UNIFIED IDEOGRAPH-#9802, IRGKangXi=1399.020, RSKangXi=181.2, Def{top, peak; carry on head; very}
9803 CJK UNIFIED IDEOGRAPH-#9803, IRGKangXi=1399.050, RSKangXi=181.2, Def{a moment; a measure of area equal to 100 mu or 6.7 hectares; to lean}
9804 CJK UNIFIED IDEOGRAPH-#9804, IRGKangXi=1399.070, RSKangXi=181.2, Def{cheekbone}
9805 CJK UNIFIED IDEOGRAPH-#9805, IRGKangXi=1399.110, RSKangXi=181.3, Def{neck, nape of neck; sum; funds}
9806 CJK UNIFIED IDEOGRAPH-#9806, IRGKangXi=1399.170, RSKangXi=181.3, Def{obey, submit to, go along with}
9807 CJK UNIFIED IDEOGRAPH-#9807, IRGKangXi=1399.220, RSKangXi=181.3, Def{large face, flat face; stupid}
9808 CJK UNIFIED IDEOGRAPH-#9808, IRGKangXi=1399.230, RSKangXi=181.3, Def{must, have to, necessary; moment; whiskers}
9809 CJK UNIFIED IDEOGRAPH-#9809, IRGKangXi=1400.020, RSKangXi=181.3, Def{cheeks; jaw; chin; rear; nourish}
980A CJK UNIFIED IDEOGRAPH-#980A, IRGKangXi=1400.040, RSKangXi=181.4, Def{grieved; anxious}
980B CJK UNIFIED IDEOGRAPH-#980B, IRGKangXi=1402.140, RSKangXi=181.4, Def{to care for, to look after to regard; to turn the head round to look}
980C CJK UNIFIED IDEOGRAPH-#980C, IRGKangXi=1400.120, RSKangXi=181.4, Def{laud, acclaim; hymn; ode}
980D CJK UNIFIED IDEOGRAPH-#980D, IRGKangXi=1400.160, RSKangXi=181.4, Def{to raise one's head}
980E CJK UNIFIED IDEOGRAPH-#980E, IRGKangXi=1400.170, RSKangXi=181.4, Def{tall and slim}
980F CJK UNIFIED IDEOGRAPH-#980F, IRGKangXi=1401.010, RSKangXi=181.4, Def{fly down or downward}
9810 CJK UNIFIED IDEOGRAPH-#9810, IRGKangXi=1401.030, RSKangXi=181.4, Def{prepare, arrange; in advance}
9811 CJK UNIFIED IDEOGRAPH-#9811, IRGKangXi=1401.040, RSKangXi=181.4, Def{obstinate, stubborn; recalcitrant}
9812 CJK UNIFIED IDEOGRAPH-#9812, IRGKangXi=1401.080, RSKangXi=181.4, Def{confer, bestow; publish, promulgate}
9813 CJK UNIFIED IDEOGRAPH-#9813, IRGKangXi=1401.110, RSKangXi=181.4, Def{pause, stop; bow, kowtow; arrange}
9814 CJK UNIFIED IDEOGRAPH-#9814, IRGKangXi=1401.160, RSKangXi=181.5, Def{good and beautiful}
9815 CJK UNIFIED IDEOGRAPH-#9815, IRGKangXi=1402.010, RSKangXi=181.5, Def{(Cant.) to raise the head}
9816 CJK UNIFIED IDEOGRAPH-#9816, IRGKangXi=1402.030, RSKangXi=181.5, Def{Zhou dynasty school; disperse; fall apart}
9817 CJK UNIFIED IDEOGRAPH-#9817, IRGKangXi=1402.180, RSKangXi=181.5, Def{lean one side; very, rather}
9818 CJK UNIFIED IDEOGRAPH-#9818, IRGKangXi=1402.230, RSKangXi=181.5, Def{neck; collar; lead, guide}
9819 CJK UNIFIED IDEOGRAPH-#9819, IRGKangXi=1402.250, RSKangXi=181.5, Def{correct}
981A CJK UNIFIED IDEOGRAPH-#981A, IRGKangXi=1402.301, RSKangXi=181.5, Def{neck, throat}
981B CJK UNIFIED IDEOGRAPH-#981B, IRGKangXi=1402.320, RSKangXi=181.6
981C CJK UNIFIED IDEOGRAPH-#981C, IRGKangXi=1402.360, RSKangXi=181.6, Def{mouth; jaw}
981D CJK UNIFIED IDEOGRAPH-#981D, IRGKangXi=1402.380, RSKangXi=181.6
981E CJK UNIFIED IDEOGRAPH-#981E, IRGKangXi=1403.050, RSKangXi=181.6, Def{(nose) bridge}
981F CJK UNIFIED IDEOGRAPH-#981F, IRGKangXi=1403.060, RSKangXi=181.6, Def{the forehead; a fixed number}
9820 CJK UNIFIED IDEOGRAPH-#9820, IRGKangXi=1403.090, RSKangXi=181.6, Def{quiet}
9821 CJK UNIFIED IDEOGRAPH-#9821, IRGKangXi=1403.100, RSKangXi=181.6, Def{fly upward, soar; contest; to rob}
9822 CJK UNIFIED IDEOGRAPH-#9822, IRGKangXi=1403.110, RSKangXi=181.6
9823 CJK UNIFIED IDEOGRAPH-#9823, IRGKangXi=1403.120, RSKangXi=181.6, Def{to view others with raised eyes}
9824 CJK UNIFIED IDEOGRAPH-#9824, IRGKangXi=1403.130, RSKangXi=181.7, Def{cheeks; jaw; chin; rear; to nourish}
9825 CJK UNIFIED IDEOGRAPH-#9825, IRGKangXi=1403.140, RSKangXi=181.7
9826 CJK UNIFIED IDEOGRAPH-#9826, IRGKangXi=1403.150, RSKangXi=181.6, Def{chin}
9827 CJK UNIFIED IDEOGRAPH-#9827, IRGKangXi=1403.170, RSKangXi=181.6
9828 CJK UNIFIED IDEOGRAPH-#9828, IRGKangXi=1403.180, RSKangXi=181.6
9829 CJK UNIFIED IDEOGRAPH-#9829, IRGKangXi=1403.200, RSKangXi=181.6
982A CJK UNIFIED IDEOGRAPH-#982A, IRGKangXi=1403.210, RSKangXi=181.6
982B CJK UNIFIED IDEOGRAPH-#982B, IRGKangXi=1403.220, RSKangXi=181.6, Def{bow; nod; condescend}
982C CJK UNIFIED IDEOGRAPH-#982C, IRGKangXi=1404.071, RSKangXi=181.6, Def{cheeks, jaw}
982D CJK UNIFIED IDEOGRAPH-#982D, IRGKangXi=1404.200, RSKangXi=181.7, Def{head; top; chief, first; boss}
982E CJK UNIFIED IDEOGRAPH-#982E, IRGKangXi=1404.220, RSKangXi=181.7, Def{wash}
982F CJK UNIFIED IDEOGRAPH-#982F, IRGKangXi=1404.230, RSKangXi=181.7, Def{cheekbone}
9830 CJK UNIFIED IDEOGRAPH-#9830, IRGKangXi=1404.270, RSKangXi=181.7, Def{cheeks, jaw}
9831 CJK UNIFIED IDEOGRAPH-#9831, IRGKangXi=1404.280, RSKangXi=181.7
9832 CJK UNIFIED IDEOGRAPH-#9832, IRGKangXi=1405.020, RSKangXi=181.7, Def{straight}
9833 CJK UNIFIED IDEOGRAPH-#9833, IRGKangXi=1405.040, RSKangXi=181.7, Def{red}
9834 CJK UNIFIED IDEOGRAPH-#9834, IRGKangXi=1405.050, RSKangXi=181.7, Def{rice tassel; sharp point; clever}
9835 CJK UNIFIED IDEOGRAPH-#9835, IRGKangXi=1405.080, RSKangXi=181.7, Def{(Cant.) 大頭頵, a big head}
9836 CJK UNIFIED IDEOGRAPH-#9836, IRGKangXi=1405.090, RSKangXi=181.7
9837 CJK UNIFIED IDEOGRAPH-#9837, IRGKangXi=1405.100, RSKangXi=181.7, Def{chin, jowl; give nod}
9838 CJK UNIFIED IDEOGRAPH-#9838, IRGKangXi=1405.140, RSKangXi=181.7, Def{neck, throat}
9839 CJK UNIFIED IDEOGRAPH-#9839, IRGKangXi=1405.160, RSKangXi=181.7, Def{ruined, decayed; disintegrate}
983A CJK UNIFIED IDEOGRAPH-#983A, IRGKangXi=1405.170, RSKangXi=181.7
983B CJK UNIFIED IDEOGRAPH-#983B, IRGKangXi=1405.180, RSKangXi=181.7, Def{frequently, again and again}
983C CJK UNIFIED IDEOGRAPH-#983C, IRGKangXi=1405.241, RSKangXi=181.7, Def{rely, depend on; accuse falsely}
983D CJK UNIFIED IDEOGRAPH-#983D, IRGKangXi=1405.241, RSKangXi=181.7, Def{ruined}
983E CJK UNIFIED IDEOGRAPH-#983E, IRGKangXi=1405.250, RSKangXi=181.9, Def{beard}
983F CJK UNIFIED IDEOGRAPH-#983F, IRGKangXi=1405.260
9840 CJK UNIFIED IDEOGRAPH-#9840, IRGKangXi=1405.270, RSKangXi=181.8
9841 CJK UNIFIED IDEOGRAPH-#9841, IRGKangXi=1405.280, RSKangXi=181.8
9842 CJK UNIFIED IDEOGRAPH-#9842, IRGKangXi=1405.330, RSKangXi=181.8
9843 CJK UNIFIED IDEOGRAPH-#9843, IRGKangXi=1405.350, RSKangXi=181.8
9844 CJK UNIFIED IDEOGRAPH-#9844, IRGKangXi=1405.360, RSKangXi=181.8
9845 CJK UNIFIED IDEOGRAPH-#9845, IRGKangXi=1406.020, RSKangXi=181.8
9846 CJK UNIFIED IDEOGRAPH-#9846, IRGKangXi=1406.060, RSKangXi=181.8, Def{grain, kernel}
9847 CJK UNIFIED IDEOGRAPH-#9847, IRGKangXi=1406.120, RSKangXi=181.8, Def{be worn out, be haggard}
9848 CJK UNIFIED IDEOGRAPH-#9848, IRGKangXi=1406.160, RSKangXi=120.11
9849 CJK UNIFIED IDEOGRAPH-#9849, IRGKangXi=1406.190, RSKangXi=181.8
984A CJK UNIFIED IDEOGRAPH-#984A, IRGKangXi=1406.250, RSKangXi=181.8
984B CJK UNIFIED IDEOGRAPH-#984B, IRGKangXi=1406.300, RSKangXi=181.9, Def{lower part of face; jaw; gills of a fish}
984C CJK UNIFIED IDEOGRAPH-#984C, IRGKangXi=1406.380, RSKangXi=181.9, Def{forehead; title, headline; theme}
984D CJK UNIFIED IDEOGRAPH-#984D, IRGKangXi=1406.400, RSKangXi=181.9, Def{forehead; tablet, plaque; fixed}
984E CJK UNIFIED IDEOGRAPH-#984E, IRGKangXi=1407.040, RSKangXi=181.9, Def{jaw}
984F CJK UNIFIED IDEOGRAPH-#984F, IRGKangXi=1407.050, RSKangXi=181.9, Def{face, facial appearance}
9850 CJK UNIFIED IDEOGRAPH-#9850, IRGKangXi=1407.100, RSKangXi=181.9
9851 CJK UNIFIED IDEOGRAPH-#9851, IRGKangXi=1407.120, RSKangXi=181.9, Def{yellow}
9852 CJK UNIFIED IDEOGRAPH-#9852, IRGKangXi=1407.130, RSKangXi=181.9, Def{solemn, large, grand, majestic}
9853 CJK UNIFIED IDEOGRAPH-#9853, IRGKangXi=1407.140, RSKangXi=181.9, Def{good, honest; simple; respectful}
9854 CJK UNIFIED IDEOGRAPH-#9854, IRGKangXi=1407.171, RSKangXi=181.9, Def{face, facial appearance}
9855 CJK UNIFIED IDEOGRAPH-#9855, IRGKangXi=1407.171, RSKangXi=181.9, Def{manifest, display; evident, clear}
9856 CJK UNIFIED IDEOGRAPH-#9856, IRGKangXi=1407.180, RSKangXi=181.10, Def{top of the head; skull}
9857 CJK UNIFIED IDEOGRAPH-#9857, IRGKangXi=1407.220, RSKangXi=181.10, Def{quiet}
9858 CJK UNIFIED IDEOGRAPH-#9858, IRGKangXi=1407.310, RSKangXi=181.10, Def{desire, want; wish; ambition}
9859 CJK UNIFIED IDEOGRAPH-#9859, IRGKangXi=1408.010, RSKangXi=181.10, Def{the forehead; to kowtow}
985A CJK UNIFIED IDEOGRAPH-#985A, IRGKangXi=1408.050, RSKangXi=181.10, Def{top, peak, summit; upset}
985B CJK UNIFIED IDEOGRAPH-#985B, IRGKangXi=1408.060, RSKangXi=181.10, Def{top, peak, summit; upset}
985C CJK UNIFIED IDEOGRAPH-#985C, IRGKangXi=1408.090, RSKangXi=181.10
985D CJK UNIFIED IDEOGRAPH-#985D, IRGKangXi=1408.100, RSKangXi=181.10
985E CJK UNIFIED IDEOGRAPH-#985E, IRGKangXi=1408.130, RSKangXi=181.10, Def{class, group, kind, category}
985F CJK UNIFIED IDEOGRAPH-#985F, IRGKangXi=1409.050, RSKangXi=181.11
9860 CJK UNIFIED IDEOGRAPH-#9860, IRGKangXi=1409.070, RSKangXi=181.11
9861 CJK UNIFIED IDEOGRAPH-#9861, IRGKangXi=1409.080, RSKangXi=181.11
9862 CJK UNIFIED IDEOGRAPH-#9862, IRGKangXi=1409.090, RSKangXi=181.11, Def{dawdling; thoughtless, careless}
9863 CJK UNIFIED IDEOGRAPH-#9863, IRGKangXi=1409.130, RSKangXi=181.11, Def{frown}
9864 CJK UNIFIED IDEOGRAPH-#9864, IRGKangXi=1409.230, RSKangXi=181.12
9865 CJK UNIFIED IDEOGRAPH-#9865, IRGKangXi=1409.300, RSKangXi=181.12, Def{luminous; white, hoary}
9866 CJK UNIFIED IDEOGRAPH-#9866, IRGKangXi=1409.370, RSKangXi=181.12, Def{be worn-out, emaciated, haggard}
9867 CJK UNIFIED IDEOGRAPH-#9867, IRGKangXi=1409.380, RSKangXi=181.12, Def{look back; look at; look after}
9868 CJK UNIFIED IDEOGRAPH-#9868, IRGKangXi=1409.400, RSKangXi=181.12
9869 CJK UNIFIED IDEOGRAPH-#9869, IRGKangXi=1409.440, RSKangXi=181.13
986A CJK UNIFIED IDEOGRAPH-#986A, IRGKangXi=1410.040, RSKangXi=181.13
986B CJK UNIFIED IDEOGRAPH-#986B, IRGKangXi=1410.050, RSKangXi=181.13, Def{shiver, tremble; trembling}
986C CJK UNIFIED IDEOGRAPH-#986C, IRGKangXi=1410.110, RSKangXi=181.14, Def{the temporal bone}
986D CJK UNIFIED IDEOGRAPH-#986D, IRGKangXi=1410.150, RSKangXi=181.14
986E CJK UNIFIED IDEOGRAPH-#986E, IRGKangXi=1410.200, RSKangXi=181.14
986F CJK UNIFIED IDEOGRAPH-#986F, IRGKangXi=1410.210, RSKangXi=181.14, Def{manifest, display; evident, clear}
9870 CJK UNIFIED IDEOGRAPH-#9870, IRGKangXi=1410.290, RSKangXi=181.15, Def{frown, knit brows; with knitted}
9871 CJK UNIFIED IDEOGRAPH-#9871, IRGKangXi=1410.340, RSKangXi=181.16, Def{skull}
9872 CJK UNIFIED IDEOGRAPH-#9872, IRGKangXi=1410.350, RSKangXi=181.16
9873 CJK UNIFIED IDEOGRAPH-#9873, IRGKangXi=1410.420, RSKangXi=181.18, Def{the temporal bone}
9874 CJK UNIFIED IDEOGRAPH-#9874, IRGKangXi=1410.430, RSKangXi=181.18, Def{cheek bones}
9875 CJK UNIFIED IDEOGRAPH-#9875, IRGKangXi=1410.451, RSKangXi=181.0, Def{page, sheet, leaf; rad. no. 181}
9876 CJK UNIFIED IDEOGRAPH-#9876, IRGKangXi=1410.451, RSKangXi=181.2, Def{top, summit, peak; to carry on the head}
9877 CJK UNIFIED IDEOGRAPH-#9877, IRGKangXi=1410.451, RSKangXi=181.2, Def{a moment; a measure of area equal to 100 mu or 6.7 hectares; to lean}
9878 CJK UNIFIED IDEOGRAPH-#9878, IRGKangXi=1410.451, RSKangXi=51.6, Def{large face, flat face; stupid}
9879 CJK UNIFIED IDEOGRAPH-#9879, IRGKangXi=1410.451, RSKangXi=181.3, Def{neck, nape of neck; sum; funds}
987A CJK UNIFIED IDEOGRAPH-#987A, IRGKangXi=1410.451, RSKangXi=181.3, Def{obey, submit to, go along with}
987B CJK UNIFIED IDEOGRAPH-#987B, IRGKangXi=1410.451, RSKangXi=59.6, Def{must, have to, necessary}
987C CJK UNIFIED IDEOGRAPH-#987C, IRGKangXi=1410.451, RSKangXi=96.6, Def{grieved}
987D CJK UNIFIED IDEOGRAPH-#987D, IRGKangXi=1410.451, RSKangXi=181.4, Def{obstinate, stubborn; recalcitrant}
987E CJK UNIFIED IDEOGRAPH-#987E, IRGKangXi=1410.451, RSKangXi=181.4, Def{look back; look at; look after}
987F CJK UNIFIED IDEOGRAPH-#987F, IRGKangXi=1410.451, RSKangXi=181.4, Def{pause, stop; bow, kowtow; arrange}
9880 CJK UNIFIED IDEOGRAPH-#9880, IRGKangXi=1410.451, RSKangXi=69.6, Def{tall and slim}
9881 CJK UNIFIED IDEOGRAPH-#9881, IRGKangXi=1410.451, RSKangXi=181.4, Def{confer, bestow; publish, promulgate}
9882 CJK UNIFIED IDEOGRAPH-#9882, IRGKangXi=1410.451, RSKangXi=181.4, Def{laud, acclaim; hymn; ode}
9883 CJK UNIFIED IDEOGRAPH-#9883, IRGKangXi=1410.451, RSKangXi=181.4, Def{fly down or downward}
9884 CJK UNIFIED IDEOGRAPH-#9884, IRGKangXi=1410.451, RSKangXi=181.4, Def{prepare, arrange; in advance}
9885 CJK UNIFIED IDEOGRAPH-#9885, IRGKangXi=1410.451, RSKangXi=181.5, Def{skull}
9886 CJK UNIFIED IDEOGRAPH-#9886, IRGKangXi=1410.451, RSKangXi=181.5, Def{neck; collar; lead, guide}
9887 CJK UNIFIED IDEOGRAPH-#9887, IRGKangXi=1410.451, RSKangXi=181.5, Def{lean one side; very, rather}
9888 CJK UNIFIED IDEOGRAPH-#9888, IRGKangXi=1410.451, RSKangXi=181.5, Def{neck, throat}
9889 CJK UNIFIED IDEOGRAPH-#9889, IRGKangXi=1410.451, RSKangXi=181.6, Def{fly upward, soar; contest}
988A CJK UNIFIED IDEOGRAPH-#988A, IRGKangXi=1410.451, RSKangXi=181.6, Def{cheeks, jaw}
988B CJK UNIFIED IDEOGRAPH-#988B, IRGKangXi=1410.451, RSKangXi=181.6, Def{straight}
988C CJK UNIFIED IDEOGRAPH-#988C, IRGKangXi=1410.451, RSKangXi=181.6, Def{mouth; jaw}
988D CJK UNIFIED IDEOGRAPH-#988D, IRGKangXi=1410.451, RSKangXi=85.8, Def{river in Anhui}
988E CJK UNIFIED IDEOGRAPH-#988E, IRGKangXi=1410.451, RSKangXi=86.8, Def{bright}
988F CJK UNIFIED IDEOGRAPH-#988F, IRGKangXi=1410.451, RSKangXi=181.6, Def{chin}
9890 CJK UNIFIED IDEOGRAPH-#9890, IRGKangXi=1410.451, RSKangXi=181.7, Def{cheeks; jaw; chin; rear; to nourish}
9891 CJK UNIFIED IDEOGRAPH-#9891, IRGKangXi=1410.451, RSKangXi=181.7, Def{frequently, again and again}
9892 CJK UNIFIED IDEOGRAPH-#9892, IRGKangXi=1410.451, RSKangXi=181.7, Def{wash}
9893 CJK UNIFIED IDEOGRAPH-#9893, IRGKangXi=1410.451, RSKangXi=181.7, Def{ruined, decayed; disintegrate}
9894 CJK UNIFIED IDEOGRAPH-#9894, IRGKangXi=1410.451, RSKangXi=181.7, Def{chin, jowl; give nod}
9895 CJK UNIFIED IDEOGRAPH-#9895, IRGKangXi=1410.451, RSKangXi=181.7, Def{rice tassel; sharp point; clever}
9896 CJK UNIFIED IDEOGRAPH-#9896, IRGKangXi=1410.451, RSKangXi=181.7, Def{rice tassel; sharp point; clever}
9897 CJK UNIFIED IDEOGRAPH-#9897, IRGKangXi=1410.451, RSKangXi=181.8, Def{grain, kernel}
9898 CJK UNIFIED IDEOGRAPH-#9898, IRGKangXi=1410.451, RSKangXi=181.9, Def{forehead; title, headline; theme}
9899 CJK UNIFIED IDEOGRAPH-#9899, IRGKangXi=1410.451, RSKangXi=181.9, Def{solemn, large, grand, majestic}
989A CJK UNIFIED IDEOGRAPH-#989A, IRGKangXi=1410.451, RSKangXi=181.9, Def{jaw}
989B CJK UNIFIED IDEOGRAPH-#989B, IRGKangXi=1410.451, RSKangXi=181.9, Def{good, honest; simple; respectful}
989C CJK UNIFIED IDEOGRAPH-#989C, IRGKangXi=1410.451, RSKangXi=181.9, Def{face, facial appearance}
989D CJK UNIFIED IDEOGRAPH-#989D, IRGKangXi=1410.451, RSKangXi=181.9, Def{forehead; tablet, plaque; fixed}
989E CJK UNIFIED IDEOGRAPH-#989E, IRGKangXi=1410.451, RSKangXi=181.9, Def{the temporal bone}
989F CJK UNIFIED IDEOGRAPH-#989F, IRGKangXi=1410.451, RSKangXi=181.10, Def{dawdling; thoughtless, careless}
98A0 CJK UNIFIED IDEOGRAPH-#98A0, IRGKangXi=1410.451, RSKangXi=181.10, Def{top, peak, summit; upset}
98A1 CJK UNIFIED IDEOGRAPH-#98A1, IRGKangXi=1410.451, RSKangXi=181.10, Def{the forehead; to kowtow}
98A2 CJK UNIFIED IDEOGRAPH-#98A2, IRGKangXi=1410.451, RSKangXi=181.12, Def{luminous; white, hoary}
98A3 CJK UNIFIED IDEOGRAPH-#98A3, IRGKangXi=1410.451, RSKangXi=120.12
98A4 CJK UNIFIED IDEOGRAPH-#98A4, IRGKangXi=1410.451, RSKangXi=181.13, Def{shiver, tremble; trembling}
98A5 CJK UNIFIED IDEOGRAPH-#98A5, IRGKangXi=1410.451, RSKangXi=181.14, Def{the temporal bone}
98A6 CJK UNIFIED IDEOGRAPH-#98A6, IRGKangXi=1410.451, RSKangXi=24.19, Def{frown, knit brows; with knitted}
98A7 CJK UNIFIED IDEOGRAPH-#98A7, IRGKangXi=1410.451, RSKangXi=181.17, Def{cheek bones}
98A8 CJK UNIFIED IDEOGRAPH-#98A8, IRGKangXi=1411.010, RSKangXi=182.0, Def{wind; air; manners, atmosphere}
98A9 CJK UNIFIED IDEOGRAPH-#98A9, IRGKangXi=1411.140, RSKangXi=182.3
98AA CJK UNIFIED IDEOGRAPH-#98AA, IRGKangXi=1411.141, RSKangXi=182.3, Def{(Japanese) wind blowing down from the mountains}
98AB CJK UNIFIED IDEOGRAPH-#98AB, IRGKangXi=1411.180, RSKangXi=182.4, Def{a storm}
98AC CJK UNIFIED IDEOGRAPH-#98AC, IRGKangXi=1411.240, RSKangXi=182.4
98AD CJK UNIFIED IDEOGRAPH-#98AD, IRGKangXi=1412.060, RSKangXi=182.5, Def{sway in wind}
98AE CJK UNIFIED IDEOGRAPH-#98AE, IRGKangXi=1412.140, RSKangXi=182.5, Def{storm whirlwind}
98AF CJK UNIFIED IDEOGRAPH-#98AF, IRGKangXi=1412.170, RSKangXi=182.5, Def{the sound of the wind; bleak; melancholy}
98B0 CJK UNIFIED IDEOGRAPH-#98B0, IRGKangXi=1412.190, RSKangXi=182.5
98B1 CJK UNIFIED IDEOGRAPH-#98B1, IRGKangXi=1412.231, RSKangXi=182.5, Def{taiphoon}
98B2 CJK UNIFIED IDEOGRAPH-#98B2, IRGKangXi=1412.250, RSKangXi=182.6
98B3 CJK UNIFIED IDEOGRAPH-#98B3, IRGKangXi=1412.320, RSKangXi=182.6, Def{to blow}
98B4 CJK UNIFIED IDEOGRAPH-#98B4, IRGKangXi=1412.470, RSKangXi=182.7, Def{whirlwind}
98B5 CJK UNIFIED IDEOGRAPH-#98B5, IRGKangXi=1412.510, RSKangXi=182.7
98B6 CJK UNIFIED IDEOGRAPH-#98B6, IRGKangXi=1413.200, RSKangXi=182.8, Def{cyclone, typhoon, gale}
98B7 CJK UNIFIED IDEOGRAPH-#98B7, IRGKangXi=1413.240, RSKangXi=182.8, Def{whirlwind}
98B8 CJK UNIFIED IDEOGRAPH-#98B8, IRGKangXi=1413.270, RSKangXi=182.9, Def{cool breeze of autumn}
98B9 CJK UNIFIED IDEOGRAPH-#98B9, IRGKangXi=1413.330, RSKangXi=182.9
98BA CJK UNIFIED IDEOGRAPH-#98BA, IRGKangXi=1413.460, RSKangXi=182.9, Def{soar, fly, float; scatter}
98BB CJK UNIFIED IDEOGRAPH-#98BB, IRGKangXi=1413.500, RSKangXi=182.10, Def{floating in air, drifting with wind}
98BC CJK UNIFIED IDEOGRAPH-#98BC, IRGKangXi=1414.020, RSKangXi=182.10, Def{sound of wind; blow chilly}
98BD CJK UNIFIED IDEOGRAPH-#98BD, IRGKangXi=1414.030, RSKangXi=182.10
98BE CJK UNIFIED IDEOGRAPH-#98BE, IRGKangXi=1414.080, RSKangXi=182.10, Def{blowing of the wind}
98BF CJK UNIFIED IDEOGRAPH-#98BF, IRGKangXi=1414.090, RSKangXi=182.10, Def{sail}
98C0 CJK UNIFIED IDEOGRAPH-#98C0, IRGKangXi=1414.111, RSKangXi=182.10, Def{soughing of wind; noise}
98C1 CJK UNIFIED IDEOGRAPH-#98C1, IRGKangXi=1414.160, RSKangXi=182.11
98C2 CJK UNIFIED IDEOGRAPH-#98C2, IRGKangXi=1414.200, RSKangXi=182.11, Def{wind in high places}
98C3 CJK UNIFIED IDEOGRAPH-#98C3, IRGKangXi=1414.210, RSKangXi=182.11, Def{whirlwind, cyclone; floating}
98C4 CJK UNIFIED IDEOGRAPH-#98C4, IRGKangXi=1414.220, RSKangXi=182.11, Def{whirlwind, cyclone; floating}
98C5 CJK UNIFIED IDEOGRAPH-#98C5, IRGKangXi=1414.290, RSKangXi=182.12
98C6 CJK UNIFIED IDEOGRAPH-#98C6, IRGKangXi=1414.340, RSKangXi=182.12, Def{whirlwind, stormy gale}
98C7 CJK UNIFIED IDEOGRAPH-#98C7, IRGKangXi=1414.350, RSKangXi=182.12, Def{whirlwind, stormy gale}
98C8 CJK UNIFIED IDEOGRAPH-#98C8, IRGKangXi=1414.360, RSKangXi=182.12, Def{whirlwind}
98C9 CJK UNIFIED IDEOGRAPH-#98C9, IRGKangXi=1414.370, RSKangXi=182.12
98CA CJK UNIFIED IDEOGRAPH-#98CA, IRGKangXi=1414.381, RSKangXi=182.12
98CB CJK UNIFIED IDEOGRAPH-#98CB, IRGKangXi=1414.400, RSKangXi=182.13
98CC CJK UNIFIED IDEOGRAPH-#98CC, IRGKangXi=1415.080, RSKangXi=182.18, Def{wind}
98CD CJK UNIFIED IDEOGRAPH-#98CD, IRGKangXi=1415.100, RSKangXi=182.18
98CE CJK UNIFIED IDEOGRAPH-#98CE, IRGKangXi=1415.131, RSKangXi=182.0, Def{wind; air; manners, atmosphere}
98CF CJK UNIFIED IDEOGRAPH-#98CF, IRGKangXi=1415.131, RSKangXi=182.9, Def{soar, fly, float; scatter}
98D0 CJK UNIFIED IDEOGRAPH-#98D0, IRGKangXi=1415.131, RSKangXi=182.5, Def{sway in wind}
98D1 CJK UNIFIED IDEOGRAPH-#98D1, IRGKangXi=1415.131, RSKangXi=182.5, Def{storm}
98D2 CJK UNIFIED IDEOGRAPH-#98D2, IRGKangXi=1415.131, RSKangXi=182.5, Def{the sound of the wind; bleak; melancholy}
98D3 CJK UNIFIED IDEOGRAPH-#98D3, IRGKangXi=1415.131, RSKangXi=182.8, Def{cyclone, typhoon, gale}
98D4 CJK UNIFIED IDEOGRAPH-#98D4, IRGKangXi=1415.131, RSKangXi=182.9, Def{cool breeze of autumn}
98D5 CJK UNIFIED IDEOGRAPH-#98D5, IRGKangXi=1415.131, RSKangXi=182.10, Def{sound of wind; blow chilly}
98D6 CJK UNIFIED IDEOGRAPH-#98D6, IRGKangXi=1415.131, RSKangXi=182.10, Def{floating in air, drifting with wind}
98D7 CJK UNIFIED IDEOGRAPH-#98D7, IRGKangXi=1415.131, RSKangXi=182.10, Def{soughing of wind; noise}
98D8 CJK UNIFIED IDEOGRAPH-#98D8, IRGKangXi=1415.131, RSKangXi=182.11, Def{whirlwind, cyclone; floating}
98D9 CJK UNIFIED IDEOGRAPH-#98D9, IRGKangXi=1415.131, RSKangXi=182.12, Def{whirlwind, stormy gale}
98DA CJK UNIFIED IDEOGRAPH-#98DA, IRGKangXi=1415.131, RSKangXi=182.12, Def{whirlwind}
98DB CJK UNIFIED IDEOGRAPH-#98DB, IRGKangXi=1415.140, RSKangXi=183.0, Def{fly; go quickly; dart; high}
98DC CJK UNIFIED IDEOGRAPH-#98DC, IRGKangXi=1415.250, RSKangXi=183.12, Def{flip over, upset, capsize}
98DD CJK UNIFIED IDEOGRAPH-#98DD, IRGKangXi=1415.280, RSKangXi=183.18
98DE CJK UNIFIED IDEOGRAPH-#98DE, IRGKangXi=1415.281, RSKangXi=5.2, Def{fly; go quickly; dart; high}
98DF CJK UNIFIED IDEOGRAPH-#98DF, IRGKangXi=1415.290, RSKangXi=184.0, Def{eat; meal; food; KangXi radical number 184}
98E0 CJK UNIFIED IDEOGRAPH-#98E0, IRGKangXi=1415.291, RSKangXi=184.0, Def{eat, food; radical number 184}
98E1 CJK UNIFIED IDEOGRAPH-#98E1, IRGKangXi=1416.070, RSKangXi=184.2, Def{meal; eat}
98E2 CJK UNIFIED IDEOGRAPH-#98E2, IRGKangXi=1416.080, RSKangXi=184.2, Def{hunger, starving; hungry; a famine}
98E3 CJK UNIFIED IDEOGRAPH-#98E3, IRGKangXi=1416.090, RSKangXi=184.2, Def{display food for show only; sacrifice}
98E4 CJK UNIFIED IDEOGRAPH-#98E4, IRGKangXi=1416.100, RSKangXi=184.2, Def{to feed; provisions}
98E5 CJK UNIFIED IDEOGRAPH-#98E5, IRGKangXi=1416.120, RSKangXi=184.3, Def{rice cake}
98E6 CJK UNIFIED IDEOGRAPH-#98E6, IRGKangXi=1416.180, RSKangXi=184.3, Def{well-boiled congee or gruel; thick, rich}
98E7 CJK UNIFIED IDEOGRAPH-#98E7, IRGKangXi=1416.190, RSKangXi=184.3, Def{evening meal, supper; cooked food}
98E8 CJK UNIFIED IDEOGRAPH-#98E8, IRGKangXi=1417.011, RSKangXi=184.3, Def{host banquet; banquet}
98E9 CJK UNIFIED IDEOGRAPH-#98E9, IRGKangXi=1417.020, RSKangXi=184.4, Def{stuffed dumplings}
98EA CJK UNIFIED IDEOGRAPH-#98EA, IRGKangXi=1417.050, RSKangXi=184.4, Def{cooked food; cook until well done}
98EB CJK UNIFIED IDEOGRAPH-#98EB, IRGKangXi=1417.070, RSKangXi=184.4, Def{surfeited, satiated; confer}
98EC CJK UNIFIED IDEOGRAPH-#98EC, IRGKangXi=1417.140, RSKangXi=184.4
98ED CJK UNIFIED IDEOGRAPH-#98ED, IRGKangXi=1417.150, RSKangXi=184.4, Def{order; command; give command}
98EE CJK UNIFIED IDEOGRAPH-#98EE, IRGKangXi=1417.190, RSKangXi=184.4, Def{drink; swallow; kind of drink}
98EF CJK UNIFIED IDEOGRAPH-#98EF, IRGKangXi=1417.270, RSKangXi=184.4, Def{cooked rice; food; meal}
98F0 CJK UNIFIED IDEOGRAPH-#98F0, IRGKangXi=1417.280, RSKangXi=184.4
98F1 CJK UNIFIED IDEOGRAPH-#98F1, IRGKangXi=1417.290, RSKangXi=78.9, Def{evening meal}
98F2 CJK UNIFIED IDEOGRAPH-#98F2, IRGKangXi=1417.331, RSKangXi=184.4, Def{drink; swallow; kind of drink}
98F3 CJK UNIFIED IDEOGRAPH-#98F3, IRGKangXi=1418.030, RSKangXi=184.5
98F4 CJK UNIFIED IDEOGRAPH-#98F4, IRGKangXi=1418.070, RSKangXi=184.5, Def{sweet-meats; sweet-cakes; syrup}
98F5 CJK UNIFIED IDEOGRAPH-#98F5, IRGKangXi=1418.120, RSKangXi=184.5, Def{(Cant.) food; profit}
98F6 CJK UNIFIED IDEOGRAPH-#98F6, IRGKangXi=1418.210, RSKangXi=184.5, Def{odour}
98F7 CJK UNIFIED IDEOGRAPH-#98F7, IRGKangXi=1418.220, RSKangXi=184.5
98F8 CJK UNIFIED IDEOGRAPH-#98F8, IRGKangXi=1418.270, RSKangXi=184.5
98F9 CJK UNIFIED IDEOGRAPH-#98F9, IRGKangXi=1418.290, RSKangXi=184.5
98FA CJK UNIFIED IDEOGRAPH-#98FA, IRGKangXi=1418.330, RSKangXi=184.6
98FB CJK UNIFIED IDEOGRAPH-#98FB, IRGKangXi=1418.340, RSKangXi=184.5
98FC CJK UNIFIED IDEOGRAPH-#98FC, IRGKangXi=1418.360, RSKangXi=184.5, Def{raise animals; feed; nourish}
98FD CJK UNIFIED IDEOGRAPH-#98FD, IRGKangXi=1418.380, RSKangXi=184.5, Def{eat heartily; eat one's fill}
98FE CJK UNIFIED IDEOGRAPH-#98FE, IRGKangXi=1418.420, RSKangXi=184.5, Def{decorate, ornament, adorn; to deceive}
98FF CJK UNIFIED IDEOGRAPH-#98FF, IRGKangXi=1419.021, RSKangXi=184.5
9900 CJK UNIFIED IDEOGRAPH-#9900, IRGKangXi=1419.030, RSKangXi=184.6, Def{tainted food}
9901 CJK UNIFIED IDEOGRAPH-#9901, IRGKangXi=1419.070, Def{cooked food; cook until well done}
9902 CJK UNIFIED IDEOGRAPH-#9902, IRGKangXi=1419.090, RSKangXi=184.6, Def{to obtain by hook}
9903 CJK UNIFIED IDEOGRAPH-#9903, IRGKangXi=1419.120, RSKangXi=184.6, Def{stuffed dumplings}
9904 CJK UNIFIED IDEOGRAPH-#9904, IRGKangXi=1419.130
9905 CJK UNIFIED IDEOGRAPH-#9905, IRGKangXi=1419.140, RSKangXi=184.8, Def{rice-cakes, biscuits}
9906 CJK UNIFIED IDEOGRAPH-#9906, IRGKangXi=1419.150, RSKangXi=184.6
9907 CJK UNIFIED IDEOGRAPH-#9907, IRGKangXi=1419.160, RSKangXi=184.6, Def{food}
9908 CJK UNIFIED IDEOGRAPH-#9908, IRGKangXi=1419.180, RSKangXi=184.6, Def{rice cake}
9909 CJK UNIFIED IDEOGRAPH-#9909, IRGKangXi=1419.210, RSKangXi=184.6, Def{rations and pay for soldiers}
990A CJK UNIFIED IDEOGRAPH-#990A, IRGKangXi=1419.260, RSKangXi=184.6, Def{raise, rear, bring up; support}
990B CJK UNIFIED IDEOGRAPH-#990B, IRGKangXi=1419.290, RSKangXi=184.6
990C CJK UNIFIED IDEOGRAPH-#990C, IRGKangXi=1419.300, RSKangXi=184.6, Def{bait; bait, entice; dumplings}
990D CJK UNIFIED IDEOGRAPH-#990D, IRGKangXi=1419.351, RSKangXi=184.6, Def{be satiated, eat one's full}
990E CJK UNIFIED IDEOGRAPH-#990E, IRGKangXi=1419.351, RSKangXi=184.6
990F CJK UNIFIED IDEOGRAPH-#990F, IRGKangXi=1419.351, RSKangXi=184.6
9910 CJK UNIFIED IDEOGRAPH-#9910, IRGKangXi=1419.390, RSKangXi=184.7, Def{eat, dine; meal; food}
9911 CJK UNIFIED IDEOGRAPH-#9911, IRGKangXi=1420.020, RSKangXi=184.7, Def{ferrule; cakes, biscuits}
9912 CJK UNIFIED IDEOGRAPH-#9912, IRGKangXi=1420.030, RSKangXi=184.7, Def{hungry, starving, famished}
9913 CJK UNIFIED IDEOGRAPH-#9913, IRGKangXi=1420.080, RSKangXi=184.7, Def{hungry; greedy for; hunger}
9914 CJK UNIFIED IDEOGRAPH-#9914, IRGKangXi=1420.130, RSKangXi=184.7, Def{eat; dinner time; sunset}
9915 CJK UNIFIED IDEOGRAPH-#9915, IRGKangXi=1420.140, RSKangXi=184.7, Def{leftovers}
9916 CJK UNIFIED IDEOGRAPH-#9916, IRGKangXi=1420.190, RSKangXi=184.7, Def{food item set out for show only}
9917 CJK UNIFIED IDEOGRAPH-#9917, IRGKangXi=1420.200, RSKangXi=184.7, Def{a pot of cooked rice}
9918 CJK UNIFIED IDEOGRAPH-#9918, IRGKangXi=1420.250, RSKangXi=184.7, Def{surplus, excess, remainder}
9919 CJK UNIFIED IDEOGRAPH-#9919, IRGKangXi=1421.061, RSKangXi=184.7, Def{to adorn; ornaments; to deceive}
991A CJK UNIFIED IDEOGRAPH-#991A, IRGKangXi=1421.090, RSKangXi=184.8, Def{prepared meat; food}
991B CJK UNIFIED IDEOGRAPH-#991B, IRGKangXi=1421.120, RSKangXi=184.8, Def{dumpling soup, wonton}
991C CJK UNIFIED IDEOGRAPH-#991C, IRGKangXi=1421.160, RSKangXi=184.8, Def{cakes, biscuits, pastry}
991D CJK UNIFIED IDEOGRAPH-#991D, IRGKangXi=1421.220, RSKangXi=184.7
991E CJK UNIFIED IDEOGRAPH-#991E, IRGKangXi=1421.240, RSKangXi=184.8, Def{farewell party; see off, send off}
991F CJK UNIFIED IDEOGRAPH-#991F, IRGKangXi=1421.250, RSKangXi=184.8, Def{libation}
9920 CJK UNIFIED IDEOGRAPH-#9920, IRGKangXi=1421.300, RSKangXi=184.8, Def{rice-cakes, biscuits}
9921 CJK UNIFIED IDEOGRAPH-#9921, IRGKangXi=1421.340, RSKangXi=184.8, Def{pastry filling, stuffing}
9922 CJK UNIFIED IDEOGRAPH-#9922, IRGKangXi=1422.030, RSKangXi=184.8
9923 CJK UNIFIED IDEOGRAPH-#9923, IRGKangXi=1422.040, RSKangXi=184.8
9924 CJK UNIFIED IDEOGRAPH-#9924, IRGKangXi=1422.050, RSKangXi=184.8, Def{incite}
9925 CJK UNIFIED IDEOGRAPH-#9925, IRGKangXi=1422.070, RSKangXi=184.8
9926 CJK UNIFIED IDEOGRAPH-#9926, IRGKangXi=1422.080, RSKangXi=184.8, Def{candy, pastry}
9927 CJK UNIFIED IDEOGRAPH-#9927, IRGKangXi=1422.130, RSKangXi=184.8, Def{steamed bread; to feed}
9928 CJK UNIFIED IDEOGRAPH-#9928, IRGKangXi=1422.140, RSKangXi=184.8, Def{public building}
9929 CJK UNIFIED IDEOGRAPH-#9929, IRGKangXi=1422.160, RSKangXi=184.8, Def{hiccough}
992A CJK UNIFIED IDEOGRAPH-#992A, IRGKangXi=1422.250, RSKangXi=184.9, Def{feast}
992B CJK UNIFIED IDEOGRAPH-#992B, IRGKangXi=1422.260, RSKangXi=184.9, Def{dumpling; supply}
992C CJK UNIFIED IDEOGRAPH-#992C, IRGKangXi=1422.270, RSKangXi=184.9, Def{porridge, gruel, congee; paste}
992D CJK UNIFIED IDEOGRAPH-#992D, IRGKangXi=1422.290, RSKangXi=184.9, Def{dried sweetmeat}
992E CJK UNIFIED IDEOGRAPH-#992E, IRGKangXi=1422.390, RSKangXi=184.9, Def{a legendary animal; a greedy person}
992F CJK UNIFIED IDEOGRAPH-#992F, IRGKangXi=1423.020, RSKangXi=184.9
9930 CJK UNIFIED IDEOGRAPH-#9930, IRGKangXi=1423.050, RSKangXi=184.9
9931 CJK UNIFIED IDEOGRAPH-#9931, IRGKangXi=1423.080, RSKangXi=184.9, Def{dry goods, dry provisions}
9932 CJK UNIFIED IDEOGRAPH-#9932, IRGKangXi=1423.090, RSKangXi=184.9, Def{spoiled, sour, moldy}
9933 CJK UNIFIED IDEOGRAPH-#9933, IRGKangXi=1423.130, RSKangXi=184.9, Def{sugar, syrup; malt sugar; sticky}
9934 CJK UNIFIED IDEOGRAPH-#9934, IRGKangXi=1423.150, RSKangXi=184.9
9935 CJK UNIFIED IDEOGRAPH-#9935, IRGKangXi=1423.241, RSKangXi=184.9, Def{to feed, to raise}
9936 CJK UNIFIED IDEOGRAPH-#9936, IRGKangXi=1424.171, RSKangXi=184.10
9937 CJK UNIFIED IDEOGRAPH-#9937, IRGKangXi=1423.241, RSKangXi=184.9, Def{stir and cook}
9938 CJK UNIFIED IDEOGRAPH-#9938, IRGKangXi=1424.171, RSKangXi=184.10, Def{(Cant.) a side dish of food prepared to accompany rice}
9939 CJK UNIFIED IDEOGRAPH-#9939, IRGKangXi=1423.250, RSKangXi=184.10, Def{sugar; sugared; candy; crystallized sweetmeats}
993A CJK UNIFIED IDEOGRAPH-#993A, IRGKangXi=1423.300, RSKangXi=184.10, Def{rice cake}
993B CJK UNIFIED IDEOGRAPH-#993B, IRGKangXi=1423.330, RSKangXi=184.10, Def{cakes, pastry}
993C CJK UNIFIED IDEOGRAPH-#993C, IRGKangXi=1423.410, RSKangXi=184.10, Def{sacrificial victim; gift; grain}
993D CJK UNIFIED IDEOGRAPH-#993D, IRGKangXi=1424.040, RSKangXi=184.10, Def{make present of food; gift}
993E CJK UNIFIED IDEOGRAPH-#993E, IRGKangXi=1424.050, RSKangXi=184.10, Def{distill, distillation}
993F CJK UNIFIED IDEOGRAPH-#993F, IRGKangXi=1424.070, RSKangXi=184.10, Def{spoiled, rotten, stale, rancid}
9940 CJK UNIFIED IDEOGRAPH-#9940, IRGKangXi=1424.090, RSKangXi=184.10
9941 CJK UNIFIED IDEOGRAPH-#9941, IRGKangXi=1424.120, RSKangXi=184.10, Def{carry meal to workers in field}
9942 CJK UNIFIED IDEOGRAPH-#9942, IRGKangXi=1424.171, RSKangXi=184.10, Def{Japanese noodles}
9943 CJK UNIFIED IDEOGRAPH-#9943, IRGKangXi=1425.111, RSKangXi=184.11, Def{bread}
9944 CJK UNIFIED IDEOGRAPH-#9944, IRGKangXi=1424.190, RSKangXi=184.11
9945 CJK UNIFIED IDEOGRAPH-#9945, IRGKangXi=1424.240, RSKangXi=184.11, Def{steamed bread; steamed dumplings}
9946 CJK UNIFIED IDEOGRAPH-#9946, IRGKangXi=1424.270, RSKangXi=184.11
9947 CJK UNIFIED IDEOGRAPH-#9947, IRGKangXi=1424.310, RSKangXi=184.11, Def{to eat too much, surfeited; to confer}
9948 CJK UNIFIED IDEOGRAPH-#9948, IRGKangXi=1425.010, RSKangXi=184.11, Def{food, meal; eat; offer}
9949 CJK UNIFIED IDEOGRAPH-#9949, IRGKangXi=1425.040, RSKangXi=184.11, Def{time of famine or crop failure}
994A CJK UNIFIED IDEOGRAPH-#994A, IRGKangXi=1425.140, RSKangXi=184.12, Def{fried round cakes of wheat flour}
994B CJK UNIFIED IDEOGRAPH-#994B, IRGKangXi=1425.190, RSKangXi=184.12, Def{offer food superior; send gift}
994C CJK UNIFIED IDEOGRAPH-#994C, IRGKangXi=1425.240, RSKangXi=184.12, Def{feed, support, provide for; food; fine meats, delicacies}
994D CJK UNIFIED IDEOGRAPH-#994D, IRGKangXi=1425.280, RSKangXi=184.12, Def{meals, provisions, board}
994E CJK UNIFIED IDEOGRAPH-#994E, IRGKangXi=1425.290, RSKangXi=184.12, Def{wine and food eaten with wine}
994F CJK UNIFIED IDEOGRAPH-#994F, IRGKangXi=1425.300, RSKangXi=184.12
9950 CJK UNIFIED IDEOGRAPH-#9950, IRGKangXi=1425.330, RSKangXi=184.12, Def{spoiled, rotten, sour}
9951 CJK UNIFIED IDEOGRAPH-#9951, IRGKangXi=1425.350, RSKangXi=184.12, Def{starve, be hungry; famine}
9952 CJK UNIFIED IDEOGRAPH-#9952, IRGKangXi=1425.400, RSKangXi=184.12, Def{bountiful, abundant, plentiful}
9953 CJK UNIFIED IDEOGRAPH-#9953, IRGKangXi=1425.430, RSKangXi=184.12
9954 CJK UNIFIED IDEOGRAPH-#9954, IRGKangXi=1425.480, RSKangXi=184.13, Def{breakfast; eat prepared food}
9955 CJK UNIFIED IDEOGRAPH-#9955, IRGKangXi=1426.100, RSKangXi=184.13, Def{gluttonous, greedy, covetous}
9956 CJK UNIFIED IDEOGRAPH-#9956, IRGKangXi=1426.140, RSKangXi=184.13
9957 CJK UNIFIED IDEOGRAPH-#9957, IRGKangXi=1426.150, RSKangXi=184.13, Def{host banquet; banquet}
9958 CJK UNIFIED IDEOGRAPH-#9958, IRGKangXi=1426.170, RSKangXi=184.13, Def{gruel}
9959 CJK UNIFIED IDEOGRAPH-#9959, IRGKangXi=1426.190, RSKangXi=184.13
995A CJK UNIFIED IDEOGRAPH-#995A, IRGKangXi=1426.240, RSKangXi=184.14
995B CJK UNIFIED IDEOGRAPH-#995B, IRGKangXi=1426.320, RSKangXi=184.14
995C CJK UNIFIED IDEOGRAPH-#995C, IRGKangXi=1426.340, RSKangXi=184.14, Def{be satiated, eat one's full}
995D CJK UNIFIED IDEOGRAPH-#995D, IRGKangXi=1427.180, RSKangXi=184.16, Def{to feed an infant by hand steamed bread}
995E CJK UNIFIED IDEOGRAPH-#995E, IRGKangXi=1427.220, RSKangXi=184.17, Def{gluttonous, greedy; lewd, lecherous}
995F CJK UNIFIED IDEOGRAPH-#995F, IRGKangXi=1427.230, RSKangXi=184.17, Def{rations and pay for soldiers; dried rice}
9960 CJK UNIFIED IDEOGRAPH-#9960, IRGKangXi=1427.270, RSKangXi=184.19, Def{rice cake}
9961 CJK UNIFIED IDEOGRAPH-#9961, IRGKangXi=1427.280, RSKangXi=184.19
9962 CJK UNIFIED IDEOGRAPH-#9962, IRGKangXi=1427.311, RSKangXi=184.21, Def{bread (Persian 'naan')}
9963 CJK UNIFIED IDEOGRAPH-#9963, IRGKangXi=1427.311, RSKangXi=184.0, Def{eat, food; radical number 184}
9964 CJK UNIFIED IDEOGRAPH-#9964, IRGKangXi=1427.311, RSKangXi=184.2, Def{display food for show only; sacrifice}
9965 CJK UNIFIED IDEOGRAPH-#9965, IRGKangXi=1427.311, RSKangXi=184.2, Def{hunger, starving; hungry; a famine}
9966 CJK UNIFIED IDEOGRAPH-#9966, IRGKangXi=1427.311, RSKangXi=184.3, Def{rice cake}
9967 CJK UNIFIED IDEOGRAPH-#9967, IRGKangXi=1427.311, RSKangXi=184.3, Def{sugar, syrup; malt sugar; sticky}
9968 CJK UNIFIED IDEOGRAPH-#9968, IRGKangXi=1427.311, RSKangXi=184.4, Def{stuffed dumplings}
9969 CJK UNIFIED IDEOGRAPH-#9969, IRGKangXi=1427.311, RSKangXi=184.4, Def{sacrficial victim; gift; grain}
996A CJK UNIFIED IDEOGRAPH-#996A, IRGKangXi=1427.311, RSKangXi=184.4, Def{cooked food; cook until well done}
996B CJK UNIFIED IDEOGRAPH-#996B, IRGKangXi=1427.311, RSKangXi=184.4, Def{surfeited, satiated; confer}
996C CJK UNIFIED IDEOGRAPH-#996C, IRGKangXi=1427.311, RSKangXi=184.4, Def{order; command; give command}
996D CJK UNIFIED IDEOGRAPH-#996D, IRGKangXi=1427.311, RSKangXi=184.4, Def{cooked rice; food, meal}
996E CJK UNIFIED IDEOGRAPH-#996E, IRGKangXi=1427.311, RSKangXi=184.4, Def{drink; swallow; kind of drink}
996F CJK UNIFIED IDEOGRAPH-#996F, IRGKangXi=1427.311, RSKangXi=184.5, Def{farewell party; see off, send off}
9970 CJK UNIFIED IDEOGRAPH-#9970, IRGKangXi=1427.311, RSKangXi=184.5, Def{decorate, ornament, adorn}
9971 CJK UNIFIED IDEOGRAPH-#9971, IRGKangXi=1427.311, RSKangXi=184.5, Def{eat heartily; eat one's fill}
9972 CJK UNIFIED IDEOGRAPH-#9972, IRGKangXi=1427.311, RSKangXi=184.5, Def{raise animals; feed; nourish}
9973 CJK UNIFIED IDEOGRAPH-#9973, IRGKangXi=1427.311, RSKangXi=184.5
9974 CJK UNIFIED IDEOGRAPH-#9974, IRGKangXi=1427.311, RSKangXi=184.5, Def{sweet-meats; sweet-cakes; syrup}
9975 CJK UNIFIED IDEOGRAPH-#9975, IRGKangXi=1427.311, RSKangXi=184.6, Def{bait; bait, entice; dumplings}
9976 CJK UNIFIED IDEOGRAPH-#9976, IRGKangXi=1427.311, RSKangXi=184.6, Def{bountiful, abundant, plentiful}
9977 CJK UNIFIED IDEOGRAPH-#9977, IRGKangXi=1427.311, RSKangXi=184.6, Def{rations and pay for soldiers}
9978 CJK UNIFIED IDEOGRAPH-#9978, IRGKangXi=1427.311, RSKangXi=184.6
9979 CJK UNIFIED IDEOGRAPH-#9979, IRGKangXi=1427.311, RSKangXi=184.6
997A CJK UNIFIED IDEOGRAPH-#997A, IRGKangXi=1427.311, RSKangXi=184.6, Def{stuffed dumplings}
997B CJK UNIFIED IDEOGRAPH-#997B, IRGKangXi=1427.311, RSKangXi=184.6
997C CJK UNIFIED IDEOGRAPH-#997C, IRGKangXi=1427.311, RSKangXi=184.6, Def{rice-cakes, biscuits}
997D CJK UNIFIED IDEOGRAPH-#997D, IRGKangXi=1427.311, RSKangXi=184.7, Def{ferrule}
997E CJK UNIFIED IDEOGRAPH-#997E, IRGKangXi=1427.311, RSKangXi=184.7, Def{food item set out for show only}
997F CJK UNIFIED IDEOGRAPH-#997F, IRGKangXi=1427.311, RSKangXi=184.7, Def{hungry; greedy for; hunger}
9980 CJK UNIFIED IDEOGRAPH-#9980, IRGKangXi=1427.311, RSKangXi=184.7, Def{surplus, excess, remainder}
9981 CJK UNIFIED IDEOGRAPH-#9981, IRGKangXi=1427.311, RSKangXi=184.7, Def{hungry, starving, famished}
9982 CJK UNIFIED IDEOGRAPH-#9982, IRGKangXi=1427.311, RSKangXi=184.7, Def{leftovers}
9983 CJK UNIFIED IDEOGRAPH-#9983, IRGKangXi=1427.311, RSKangXi=184.8, Def{cakes, biscuits, pastry}
9984 CJK UNIFIED IDEOGRAPH-#9984, IRGKangXi=1427.311, RSKangXi=184.8, Def{dumpling soup, wonton}
9985 CJK UNIFIED IDEOGRAPH-#9985, IRGKangXi=1427.311, RSKangXi=184.8, Def{filling, stuffing; secret}
9986 CJK UNIFIED IDEOGRAPH-#9986, IRGKangXi=1427.311, RSKangXi=184.8, Def{public building}
9987 CJK UNIFIED IDEOGRAPH-#9987, IRGKangXi=1427.311, RSKangXi=184.9, Def{stir and cook}
9988 CJK UNIFIED IDEOGRAPH-#9988, IRGKangXi=1427.311, RSKangXi=184.9, Def{offer food superior; send gift}
9989 CJK UNIFIED IDEOGRAPH-#9989, IRGKangXi=1427.311, RSKangXi=184.10
998A CJK UNIFIED IDEOGRAPH-#998A, IRGKangXi=1427.311, RSKangXi=184.9, Def{spoiled, rotten, stale, rancid}
998B CJK UNIFIED IDEOGRAPH-#998B, IRGKangXi=1427.311, RSKangXi=184.9, Def{gluttonous, greedy; lewd, lecherous}
998C CJK UNIFIED IDEOGRAPH-#998C, IRGKangXi=1427.311, RSKangXi=184.10, Def{carry meal to workers in field}
998D CJK UNIFIED IDEOGRAPH-#998D, IRGKangXi=1427.311, RSKangXi=184.10, Def{bread}
998E CJK UNIFIED IDEOGRAPH-#998E, IRGKangXi=1427.311, RSKangXi=184.10, Def{rice cake}
998F CJK UNIFIED IDEOGRAPH-#998F, IRGKangXi=1427.311, RSKangXi=184.10, Def{distill, distillation}
9990 CJK UNIFIED IDEOGRAPH-#9990, IRGKangXi=1427.311, RSKangXi=184.11, Def{food, meal; eat; offer}
9991 CJK UNIFIED IDEOGRAPH-#9991, IRGKangXi=1427.311, RSKangXi=184.11, Def{time of famine or crop failure}
9992 CJK UNIFIED IDEOGRAPH-#9992, IRGKangXi=1427.311, RSKangXi=184.11, Def{steamed bread; steamed dumplings}
9993 CJK UNIFIED IDEOGRAPH-#9993, IRGKangXi=1427.311, RSKangXi=184.12, Def{fried round cakes of wheat flour}
9994 CJK UNIFIED IDEOGRAPH-#9994, IRGKangXi=1427.311, RSKangXi=184.12, Def{to feed, support, provide for; food}
9995 CJK UNIFIED IDEOGRAPH-#9995, IRGKangXi=1427.311, RSKangXi=184.22, Def{bread (persian naan)}
9996 CJK UNIFIED IDEOGRAPH-#9996, IRGKangXi=1427.320, RSKangXi=185.0, Def{head; first; leader, chief; a poem}
9997 CJK UNIFIED IDEOGRAPH-#9997, IRGKangXi=1428.030, RSKangXi=185.2, Def{cheekbone; path, road; intersection}
9998 CJK UNIFIED IDEOGRAPH-#9998, IRGKangXi=1428.130, RSKangXi=185.8, Def{cut off left ear; tally dead enemy}
9999 CJK UNIFIED IDEOGRAPH-#9999, IRGKangXi=1428.210, RSKangXi=186.0, Def{fragrant, sweet smelling, incense}
999A CJK UNIFIED IDEOGRAPH-#999A, IRGKangXi=1429.020, RSKangXi=186.4, Def{aromatic, perfumed}
999B CJK UNIFIED IDEOGRAPH-#999B, IRGKangXi=1429.060, RSKangXi=186.5, Def{fragrance, fragrant}
999C CJK UNIFIED IDEOGRAPH-#999C, IRGKangXi=1429.080, RSKangXi=186.5
999D CJK UNIFIED IDEOGRAPH-#999D, IRGKangXi=1429.090, RSKangXi=186.5, Def{fragrance}
999E CJK UNIFIED IDEOGRAPH-#999E, IRGKangXi=1429.110, RSKangXi=186.7
999F CJK UNIFIED IDEOGRAPH-#999F, IRGKangXi=1429.120, RSKangXi=186.7, Def{fragrant}
99A0 CJK UNIFIED IDEOGRAPH-#99A0, IRGKangXi=1429.130, RSKangXi=186.7
99A1 CJK UNIFIED IDEOGRAPH-#99A1, IRGKangXi=1429.160, RSKangXi=186.8, Def{scent}
99A2 CJK UNIFIED IDEOGRAPH-#99A2, IRGKangXi=1429.170, RSKangXi=186.8
99A3 CJK UNIFIED IDEOGRAPH-#99A3, IRGKangXi=1429.190, RSKangXi=186.8
99A4 CJK UNIFIED IDEOGRAPH-#99A4, IRGKangXi=1429.200, RSKangXi=186.9
99A5 CJK UNIFIED IDEOGRAPH-#99A5, IRGKangXi=1429.210, RSKangXi=186.9, Def{fragrance, scent, aroma}
99A6 CJK UNIFIED IDEOGRAPH-#99A6, IRGKangXi=1429.260, RSKangXi=186.10
99A7 CJK UNIFIED IDEOGRAPH-#99A7, IRGKangXi=1429.280, RSKangXi=186.10
99A8 CJK UNIFIED IDEOGRAPH-#99A8, IRGKangXi=1429.300, RSKangXi=186.11, Def{fragrant, aromatic; distant fragrance}
99A9 CJK UNIFIED IDEOGRAPH-#99A9, IRGKangXi=1429.310, RSKangXi=186.12, Def{aromatic, perfumed}
99AA CJK UNIFIED IDEOGRAPH-#99AA, IRGKangXi=1429.340, RSKangXi=186.14
99AB CJK UNIFIED IDEOGRAPH-#99AB, IRGKangXi=1430.010, RSKangXi=186.18
99AC CJK UNIFIED IDEOGRAPH-#99AC, IRGKangXi=1433.010, RSKangXi=187.0, Def{horse; surname; KangXi radical 187}
99AD CJK UNIFIED IDEOGRAPH-#99AD, IRGKangXi=1433.080, RSKangXi=187.2, Def{drive, ride; manage, control}
99AE CJK UNIFIED IDEOGRAPH-#99AE, IRGKangXi=1433.110, RSKangXi=187.2, Def{surname; gallop; by dint of}
99AF CJK UNIFIED IDEOGRAPH-#99AF, IRGKangXi=1434.030, RSKangXi=187.3
99B0 CJK UNIFIED IDEOGRAPH-#99B0, IRGKangXi=1434.060, RSKangXi=187.3
99B1 CJK UNIFIED IDEOGRAPH-#99B1, IRGKangXi=1434.070, RSKangXi=187.3, Def{carry on back}
99B2 CJK UNIFIED IDEOGRAPH-#99B2, IRGKangXi=1434.100, RSKangXi=187.3, Def{camel}
99B3 CJK UNIFIED IDEOGRAPH-#99B3, IRGKangXi=1434.110, RSKangXi=187.3, Def{go quickly or swiftly; hurry}
99B4 CJK UNIFIED IDEOGRAPH-#99B4, IRGKangXi=1434.140, RSKangXi=187.3, Def{tame, docile, obedient}
99B5 CJK UNIFIED IDEOGRAPH-#99B5, IRGKangXi=1434.160, RSKangXi=187.3, Def{horse with white back legs}
99B6 CJK UNIFIED IDEOGRAPH-#99B6, IRGKangXi=1434.170, RSKangXi=187.4
99B7 CJK UNIFIED IDEOGRAPH-#99B7, IRGKangXi=1434.190, RSKangXi=187.4
99B8 CJK UNIFIED IDEOGRAPH-#99B8, IRGKangXi=1434.210, RSKangXi=187.4
99B9 CJK UNIFIED IDEOGRAPH-#99B9, IRGKangXi=1434.230, RSKangXi=187.4, Def{post horse, relay horse}
99BA CJK UNIFIED IDEOGRAPH-#99BA, IRGKangXi=1434.240, RSKangXi=187.4
99BB CJK UNIFIED IDEOGRAPH-#99BB, IRGKangXi=1435.020, RSKangXi=187.4
99BC CJK UNIFIED IDEOGRAPH-#99BC, IRGKangXi=1435.050, RSKangXi=187.4
99BD CJK UNIFIED IDEOGRAPH-#99BD, IRGKangXi=1435.060, RSKangXi=187.4
99BE CJK UNIFIED IDEOGRAPH-#99BE, IRGKangXi=1435.070, RSKangXi=187.4
99BF CJK UNIFIED IDEOGRAPH-#99BF, IRGKangXi=1435.100, RSKangXi=187.4, Def{an ass; a donkey}
99C0 CJK UNIFIED IDEOGRAPH-#99C0, IRGKangXi=1435.110, RSKangXi=187.4
99C1 CJK UNIFIED IDEOGRAPH-#99C1, IRGKangXi=1435.120, RSKangXi=187.4, Def{varicolored, variegated; mixed; contradict, argue; suddenly}
99C2 CJK UNIFIED IDEOGRAPH-#99C2, IRGKangXi=1435.160, RSKangXi=187.4
99C3 CJK UNIFIED IDEOGRAPH-#99C3, IRGKangXi=1435.180, RSKangXi=187.4, Def{gallop}
99C4 CJK UNIFIED IDEOGRAPH-#99C4, IRGKangXi=1435.211, RSKangXi=187.4, Def{a horse load; a pack-horse}
99C5 CJK UNIFIED IDEOGRAPH-#99C5, IRGKangXi=1435.211, RSKangXi=187.4, Def{relay station}
99C6 CJK UNIFIED IDEOGRAPH-#99C6, IRGKangXi=1435.211, RSKangXi=187.4, Def{spur a horse on; expel, drive away}
99C7 CJK UNIFIED IDEOGRAPH-#99C7, IRGKangXi=1435.211, RSKangXi=187.4
99C8 CJK UNIFIED IDEOGRAPH-#99C8, IRGKangXi=1435.230, RSKangXi=187.5, Def{spur a horse on; expel, drive away}
99C9 CJK UNIFIED IDEOGRAPH-#99C9, IRGKangXi=1435.240, RSKangXi=187.5, Def{big}
99CA CJK UNIFIED IDEOGRAPH-#99CA, IRGKangXi=1435.250, RSKangXi=187.5
99CB CJK UNIFIED IDEOGRAPH-#99CB, IRGKangXi=1435.290, RSKangXi=187.5
99CC CJK UNIFIED IDEOGRAPH-#99CC, IRGKangXi=1435.330, RSKangXi=187.5
99CD CJK UNIFIED IDEOGRAPH-#99CD, IRGKangXi=1435.370, RSKangXi=187.5
99CE CJK UNIFIED IDEOGRAPH-#99CE, IRGKangXi=1435.380, RSKangXi=187.5
99CF CJK UNIFIED IDEOGRAPH-#99CF, IRGKangXi=1435.440, RSKangXi=187.5, Def{offspring of a stallion and a she-mule}
99D0 CJK UNIFIED IDEOGRAPH-#99D0, IRGKangXi=1436.020, RSKangXi=187.5, Def{to be stationed at, reside at; to stop}
99D1 CJK UNIFIED IDEOGRAPH-#99D1, IRGKangXi=1436.030, RSKangXi=187.5, Def{tired, old horse; old, weak}
99D2 CJK UNIFIED IDEOGRAPH-#99D2, IRGKangXi=1436.050, RSKangXi=187.5, Def{colt; fleet, swift; sun; surname}
99D3 CJK UNIFIED IDEOGRAPH-#99D3, IRGKangXi=1436.060, RSKangXi=187.5, Def{gallop}
99D4 CJK UNIFIED IDEOGRAPH-#99D4, IRGKangXi=1436.070, RSKangXi=187.5, Def{excellent horse, noble steed}
99D5 CJK UNIFIED IDEOGRAPH-#99D5, IRGKangXi=1436.090, RSKangXi=187.5, Def{to drive, sail, fly; a cart, carriage}
99D6 CJK UNIFIED IDEOGRAPH-#99D6, IRGKangXi=1436.130, RSKangXi=187.5
99D7 CJK UNIFIED IDEOGRAPH-#99D7, IRGKangXi=1436.140, RSKangXi=187.5
99D8 CJK UNIFIED IDEOGRAPH-#99D8, IRGKangXi=1436.160, RSKangXi=187.5, Def{an old, tired horse, a jade; tired, exhausted}
99D9 CJK UNIFIED IDEOGRAPH-#99D9, IRGKangXi=1436.170, RSKangXi=187.5, Def{extra horse; imperial son-in-law}
99DA CJK UNIFIED IDEOGRAPH-#99DA, IRGKangXi=1437.010, RSKangXi=187.5
99DB CJK UNIFIED IDEOGRAPH-#99DB, IRGKangXi=1437.020, RSKangXi=187.5, Def{sail, drive, pilot; fast, quick}
99DC CJK UNIFIED IDEOGRAPH-#99DC, IRGKangXi=1437.030, RSKangXi=187.5, Def{strong horse}
99DD CJK UNIFIED IDEOGRAPH-#99DD, IRGKangXi=1437.040, RSKangXi=187.5, Def{a camel; humpbacked; to carry on the back}
99DE CJK UNIFIED IDEOGRAPH-#99DE, IRGKangXi=1437.050, RSKangXi=187.5, Def{camel}
99DF CJK UNIFIED IDEOGRAPH-#99DF, IRGKangXi=1437.060, RSKangXi=187.5, Def{team of four horses}
99E0 CJK UNIFIED IDEOGRAPH-#99E0, IRGKangXi=1437.110, RSKangXi=187.5
99E1 CJK UNIFIED IDEOGRAPH-#99E1, IRGKangXi=1437.130, RSKangXi=30.13, Def{accuse, blame, curse, scold}
99E2 CJK UNIFIED IDEOGRAPH-#99E2, IRGKangXi=1437.150, RSKangXi=187.6, Def{team of horses; associate, join}
99E3 CJK UNIFIED IDEOGRAPH-#99E3, IRGKangXi=1437.170, RSKangXi=187.6
99E4 CJK UNIFIED IDEOGRAPH-#99E4, IRGKangXi=1437.180, RSKangXi=187.6
99E5 CJK UNIFIED IDEOGRAPH-#99E5, IRGKangXi=1437.250, RSKangXi=187.6
99E6 CJK UNIFIED IDEOGRAPH-#99E6, IRGKangXi=1437.270, RSKangXi=187.6, Def{to mount, to ascend; to move, to turn out}
99E7 CJK UNIFIED IDEOGRAPH-#99E7, IRGKangXi=1437.280, RSKangXi=187.6
99E8 CJK UNIFIED IDEOGRAPH-#99E8, IRGKangXi=1437.290, RSKangXi=187.6
99E9 CJK UNIFIED IDEOGRAPH-#99E9, IRGKangXi=1437.310, RSKangXi=187.6
99EA CJK UNIFIED IDEOGRAPH-#99EA, IRGKangXi=1438.030, RSKangXi=187.6, Def{crowd}
99EB CJK UNIFIED IDEOGRAPH-#99EB, IRGKangXi=1438.040, RSKangXi=187.6
99EC CJK UNIFIED IDEOGRAPH-#99EC, IRGKangXi=1438.070, RSKangXi=187.6, Def{name of a legendary swift horse}
99ED CJK UNIFIED IDEOGRAPH-#99ED, IRGKangXi=1438.080, RSKangXi=187.6, Def{terrify, frighten, scare; shock}
99EE CJK UNIFIED IDEOGRAPH-#99EE, IRGKangXi=1438.090, RSKangXi=187.6, Def{a kind of fierce animal; join; argue; transfer; piebald horse, variegated}
99EF CJK UNIFIED IDEOGRAPH-#99EF, IRGKangXi=1438.100, RSKangXi=187.6
99F0 CJK UNIFIED IDEOGRAPH-#99F0, IRGKangXi=1438.150, RSKangXi=187.6, Def{grey horse}
99F1 CJK UNIFIED IDEOGRAPH-#99F1, IRGKangXi=1438.170, RSKangXi=187.6, Def{a white horse with black mane; a camel}
99F2 CJK UNIFIED IDEOGRAPH-#99F2, IRGKangXi=1438.261, RSKangXi=187.6
99F3 CJK UNIFIED IDEOGRAPH-#99F3, IRGKangXi=1438.280, RSKangXi=187.8
99F4 CJK UNIFIED IDEOGRAPH-#99F4, IRGKangXi=1438.300, RSKangXi=187.7, Def{drum}
99F5 CJK UNIFIED IDEOGRAPH-#99F5, IRGKangXi=1439.010, RSKangXi=187.7
99F6 CJK UNIFIED IDEOGRAPH-#99F6, IRGKangXi=1439.020, RSKangXi=187.7
99F7 CJK UNIFIED IDEOGRAPH-#99F7, IRGKangXi=1439.090, RSKangXi=187.7
99F8 CJK UNIFIED IDEOGRAPH-#99F8, IRGKangXi=1439.100, RSKangXi=187.7, Def{galloping; speeding}
99F9 CJK UNIFIED IDEOGRAPH-#99F9, IRGKangXi=1439.120, RSKangXi=187.7, Def{black horse with a white face}
99FA CJK UNIFIED IDEOGRAPH-#99FA, IRGKangXi=1439.150, RSKangXi=187.7
99FB CJK UNIFIED IDEOGRAPH-#99FB, IRGKangXi=1439.180, RSKangXi=187.7, Def{a fierce horse; to rage, run wild}
99FC CJK UNIFIED IDEOGRAPH-#99FC, IRGKangXi=1439.230, RSKangXi=187.7
99FD CJK UNIFIED IDEOGRAPH-#99FD, IRGKangXi=1439.240, RSKangXi=187.7, Def{grey}
99FE CJK UNIFIED IDEOGRAPH-#99FE, IRGKangXi=1439.250, RSKangXi=187.7, Def{run away}
99FF CJK UNIFIED IDEOGRAPH-#99FF, IRGKangXi=1439.260, RSKangXi=187.7, Def{excellent horse, noble steed}
9A00 CJK UNIFIED IDEOGRAPH-#9A00, IRGKangXi=1439.270, RSKangXi=187.7
9A01 CJK UNIFIED IDEOGRAPH-#9A01, IRGKangXi=1439.280, RSKangXi=187.7, Def{gallop horse; hasten, hurry}
9A02 CJK UNIFIED IDEOGRAPH-#9A02, IRGKangXi=1439.300, RSKangXi=187.7, Def{red, brown, bay; neat, harmonious}
9A03 CJK UNIFIED IDEOGRAPH-#9A03, IRGKangXi=1440.010, RSKangXi=187.7, Def{stupid; foolish}
9A04 CJK UNIFIED IDEOGRAPH-#9A04, IRGKangXi=1440.070, RSKangXi=187.8, Def{name of a legendary swift horse}
9A05 CJK UNIFIED IDEOGRAPH-#9A05, IRGKangXi=1440.080, RSKangXi=187.8, Def{piebald horse}
9A06 CJK UNIFIED IDEOGRAPH-#9A06, IRGKangXi=1440.090, RSKangXi=187.8
9A07 CJK UNIFIED IDEOGRAPH-#9A07, IRGKangXi=1440.110, RSKangXi=187.8
9A08 CJK UNIFIED IDEOGRAPH-#9A08, IRGKangXi=1440.150, RSKangXi=187.8, Def{team of horses; associate}
9A09 CJK UNIFIED IDEOGRAPH-#9A09, IRGKangXi=1440.210, RSKangXi=187.8, Def{fine horse}
9A0A CJK UNIFIED IDEOGRAPH-#9A0A, IRGKangXi=1440.270, RSKangXi=187.8
9A0B CJK UNIFIED IDEOGRAPH-#9A0B, IRGKangXi=1440.280, RSKangXi=187.8, Def{tall (7 chi) horse}
9A0C CJK UNIFIED IDEOGRAPH-#9A0C, IRGKangXi=1440.340, RSKangXi=187.8, Def{a horse's mane; bristles}
9A0D CJK UNIFIED IDEOGRAPH-#9A0D, IRGKangXi=1440.350, RSKangXi=187.8, Def{mother horse}
9A0E CJK UNIFIED IDEOGRAPH-#9A0E, IRGKangXi=1440.360, RSKangXi=187.8, Def{ride horseback; mount; cavalry}
9A0F CJK UNIFIED IDEOGRAPH-#9A0F, IRGKangXi=1440.370, RSKangXi=187.8, Def{piebald horse; excellent horse}
9A10 CJK UNIFIED IDEOGRAPH-#9A10, IRGKangXi=1440.420, RSKangXi=187.8, Def{to verity, to fulfil; to examine, to hold an inquest}
9A11 CJK UNIFIED IDEOGRAPH-#9A11, IRGKangXi=1441.020, RSKangXi=187.8, Def{horse; run}
9A12 CJK UNIFIED IDEOGRAPH-#9A12, IRGKangXi=1441.071, RSKangXi=187.8, Def{harass, bother, annoy, disturb}
9A13 CJK UNIFIED IDEOGRAPH-#9A13, IRGKangXi=1441.071, RSKangXi=187.8, Def{test, examine, inspect; verify}
9A14 CJK UNIFIED IDEOGRAPH-#9A14, IRGKangXi=1441.100, RSKangXi=187.9
9A15 CJK UNIFIED IDEOGRAPH-#9A15, IRGKangXi=1441.130, RSKangXi=187.9, Def{name of a fabulous horse}
9A16 CJK UNIFIED IDEOGRAPH-#9A16, IRGKangXi=1441.170, RSKangXi=187.9, Def{gallop; rush about; pursue, run}
9A17 CJK UNIFIED IDEOGRAPH-#9A17, IRGKangXi=1441.190, RSKangXi=187.9, Def{to swindle; to cheat}
9A18 CJK UNIFIED IDEOGRAPH-#9A18, IRGKangXi=1441.200, RSKangXi=187.9, Def{a piebald horse}
9A19 CJK UNIFIED IDEOGRAPH-#9A19, IRGKangXi=1441.210, RSKangXi=187.9, Def{swindle, cheat out of, defraud}
9A1A CJK UNIFIED IDEOGRAPH-#9A1A, IRGKangXi=1441.250, RSKangXi=187.9
9A1B CJK UNIFIED IDEOGRAPH-#9A1B, IRGKangXi=1441.270, RSKangXi=187.9
9A1C CJK UNIFIED IDEOGRAPH-#9A1C, IRGKangXi=1441.290, RSKangXi=187.9
9A1D CJK UNIFIED IDEOGRAPH-#9A1D, IRGKangXi=1441.300, RSKangXi=187.9
9A1E CJK UNIFIED IDEOGRAPH-#9A1E, IRGKangXi=1441.320, RSKangXi=187.9
9A1F CJK UNIFIED IDEOGRAPH-#9A1F, IRGKangXi=1441.340, RSKangXi=187.9
9A20 CJK UNIFIED IDEOGRAPH-#9A20, IRGKangXi=1441.350, RSKangXi=187.9, Def{a horse, mule}
9A21 CJK UNIFIED IDEOGRAPH-#9A21, IRGKangXi=1441.370, RSKangXi=187.9
9A22 CJK UNIFIED IDEOGRAPH-#9A22, IRGKangXi=1441.390, RSKangXi=187.9, Def{bay}
9A23 CJK UNIFIED IDEOGRAPH-#9A23, IRGKangXi=1441.400, RSKangXi=187.9, Def{mane}
9A24 CJK UNIFIED IDEOGRAPH-#9A24, IRGKangXi=1441.420, RSKangXi=187.9, Def{(of a horse) lively; vigorous}
9A25 CJK UNIFIED IDEOGRAPH-#9A25, IRGKangXi=1441.440, RSKangXi=187.9
9A26 CJK UNIFIED IDEOGRAPH-#9A26, IRGKangXi=1442.040, RSKangXi=187.9
9A27 CJK UNIFIED IDEOGRAPH-#9A27, IRGKangXi=1442.060, RSKangXi=187.9, Def{tan or piebald horse}
9A28 CJK UNIFIED IDEOGRAPH-#9A28, IRGKangXi=1442.121, RSKangXi=187.9, Def{dappled}
9A29 CJK UNIFIED IDEOGRAPH-#9A29, IRGKangXi=1442.130, RSKangXi=187.10
9A2A CJK UNIFIED IDEOGRAPH-#9A2A, IRGKangXi=1442.140, RSKangXi=187.10
9A2B CJK UNIFIED IDEOGRAPH-#9A2B, IRGKangXi=1442.170, RSKangXi=187.10, Def{raise, hold high; fly, soar}
9A2C CJK UNIFIED IDEOGRAPH-#9A2C, IRGKangXi=1442.200, RSKangXi=187.10
9A2D CJK UNIFIED IDEOGRAPH-#9A2D, IRGKangXi=1442.280, RSKangXi=187.10, Def{stallion; promote}
9A2E CJK UNIFIED IDEOGRAPH-#9A2E, IRGKangXi=1442.330, RSKangXi=187.10, Def{famous horse}
9A2F CJK UNIFIED IDEOGRAPH-#9A2F, IRGKangXi=1442.340, RSKangXi=187.10, Def{loud, noisy, boisterous; fight}
9A30 CJK UNIFIED IDEOGRAPH-#9A30, IRGKangXi=1442.350, RSKangXi=187.10, Def{fly; gallop; run; prance; rise}
9A31 CJK UNIFIED IDEOGRAPH-#9A31, IRGKangXi=1442.360, RSKangXi=187.10
9A32 CJK UNIFIED IDEOGRAPH-#9A32, IRGKangXi=1443.010, RSKangXi=187.10, Def{the female of certain animals such as horses, a mare}
9A33 CJK UNIFIED IDEOGRAPH-#9A33, IRGKangXi=1443.050, RSKangXi=187.10, Def{run, race}
9A34 CJK UNIFIED IDEOGRAPH-#9A34, IRGKangXi=1443.080, RSKangXi=187.10
9A35 CJK UNIFIED IDEOGRAPH-#9A35, IRGKangXi=1443.090, RSKangXi=187.10, Def{bay}
9A36 CJK UNIFIED IDEOGRAPH-#9A36, IRGKangXi=1443.120, RSKangXi=187.10, Def{mounted escort; groom}
9A37 CJK UNIFIED IDEOGRAPH-#9A37, IRGKangXi=1443.190, RSKangXi=187.10, Def{harass, bother, annoy, disturb, agitate; sad, grieved}
9A38 CJK UNIFIED IDEOGRAPH-#9A38, IRGKangXi=1443.210, RSKangXi=187.10, Def{geld, castrate}
9A39 CJK UNIFIED IDEOGRAPH-#9A39, IRGKangXi=1444.301, RSKangXi=187.11
9A3A CJK UNIFIED IDEOGRAPH-#9A3A, IRGKangXi=1444.010, RSKangXi=187.11, Def{heavy horse; horse unable to move because of twisted leg; plodding}
9A3B CJK UNIFIED IDEOGRAPH-#9A3B, IRGKangXi=1444.040, RSKangXi=187.11, Def{horse}
9A3C CJK UNIFIED IDEOGRAPH-#9A3C, IRGKangXi=1444.080, RSKangXi=187.11
9A3D CJK UNIFIED IDEOGRAPH-#9A3D, IRGKangXi=1444.090, RSKangXi=187.11
9A3E CJK UNIFIED IDEOGRAPH-#9A3E, IRGKangXi=1444.110, RSKangXi=187.11, Def{mule}
9A3F CJK UNIFIED IDEOGRAPH-#9A3F, IRGKangXi=1444.120, RSKangXi=187.11
9A40 CJK UNIFIED IDEOGRAPH-#9A40, IRGKangXi=1444.150, RSKangXi=187.11, Def{suddenly, quickly, abruptly}
9A41 CJK UNIFIED IDEOGRAPH-#9A41, IRGKangXi=1444.180, RSKangXi=187.11, Def{wild horse, mustang; wild}
9A42 CJK UNIFIED IDEOGRAPH-#9A42, IRGKangXi=1444.210, RSKangXi=187.11, Def{two outside ones in three horse}
9A43 CJK UNIFIED IDEOGRAPH-#9A43, IRGKangXi=1444.220, RSKangXi=187.11, Def{charger, steed; swift, valiant}
9A44 CJK UNIFIED IDEOGRAPH-#9A44, IRGKangXi=1444.230, RSKangXi=187.11, Def{horse with a bluish white color}
9A45 CJK UNIFIED IDEOGRAPH-#9A45, IRGKangXi=1444.240, RSKangXi=187.11, Def{spur a horse on; expel, drive away}
9A46 CJK UNIFIED IDEOGRAPH-#9A46, IRGKangXi=1444.280, RSKangXi=187.11, Def{used in transliterating Buddhist books}
9A47 CJK UNIFIED IDEOGRAPH-#9A47, IRGKangXi=1444.301, RSKangXi=187.11, Def{heavy horse; horse unable to move because of twisted leg; plodding}
9A48 CJK UNIFIED IDEOGRAPH-#9A48, IRGKangXi=1444.310, RSKangXi=187.12, Def{black horses}
9A49 CJK UNIFIED IDEOGRAPH-#9A49, IRGKangXi=1444.340, RSKangXi=187.12
9A4A CJK UNIFIED IDEOGRAPH-#9A4A, IRGKangXi=1444.350, RSKangXi=187.12, Def{an excellent horse}
9A4B CJK UNIFIED IDEOGRAPH-#9A4B, IRGKangXi=1445.010, RSKangXi=187.12
9A4C CJK UNIFIED IDEOGRAPH-#9A4C, IRGKangXi=1445.030, RSKangXi=187.12, Def{name of a famous horse}
9A4D CJK UNIFIED IDEOGRAPH-#9A4D, IRGKangXi=1445.040, RSKangXi=187.12, Def{excellent horse; brave, valiant}
9A4E CJK UNIFIED IDEOGRAPH-#9A4E, IRGKangXi=1445.080, RSKangXi=187.12
9A4F CJK UNIFIED IDEOGRAPH-#9A4F, IRGKangXi=1445.090, RSKangXi=187.12, Def{horse without saddle}
9A50 CJK UNIFIED IDEOGRAPH-#9A50, IRGKangXi=1445.100, RSKangXi=187.12
9A51 CJK UNIFIED IDEOGRAPH-#9A51, IRGKangXi=1445.120, RSKangXi=187.12
9A52 CJK UNIFIED IDEOGRAPH-#9A52, IRGKangXi=1445.190, RSKangXi=187.12, Def{dappled}
9A53 CJK UNIFIED IDEOGRAPH-#9A53, IRGKangXi=1445.200, RSKangXi=187.12
9A54 CJK UNIFIED IDEOGRAPH-#9A54, IRGKangXi=1445.210, RSKangXi=187.12, Def{black horse}
9A55 CJK UNIFIED IDEOGRAPH-#9A55, IRGKangXi=1445.250, RSKangXi=187.12, Def{spirited horse; haughty}
9A56 CJK UNIFIED IDEOGRAPH-#9A56, IRGKangXi=1445.380, RSKangXi=187.13, Def{black (horse)}
9A57 CJK UNIFIED IDEOGRAPH-#9A57, IRGKangXi=1445.400, RSKangXi=187.13, Def{test, examine, inspect; verify}
9A58 CJK UNIFIED IDEOGRAPH-#9A58, IRGKangXi=1445.410, RSKangXi=187.13, Def{mule}
9A59 CJK UNIFIED IDEOGRAPH-#9A59, IRGKangXi=1446.010, RSKangXi=187.13
9A5A CJK UNIFIED IDEOGRAPH-#9A5A, IRGKangXi=1446.040, RSKangXi=187.13, Def{frighten, surprise, startle}
9A5B CJK UNIFIED IDEOGRAPH-#9A5B, IRGKangXi=1446.050, RSKangXi=187.13, Def{relay station}
9A5C CJK UNIFIED IDEOGRAPH-#9A5C, IRGKangXi=1446.060, RSKangXi=187.13
9A5D CJK UNIFIED IDEOGRAPH-#9A5D, IRGKangXi=1446.120, RSKangXi=187.14, Def{a camel; the name of an office}
9A5E CJK UNIFIED IDEOGRAPH-#9A5E, IRGKangXi=1446.190, RSKangXi=187.14
9A5F CJK UNIFIED IDEOGRAPH-#9A5F, IRGKangXi=1446.210, RSKangXi=187.14, Def{procedure; gallop; sudden(ly)}
9A60 CJK UNIFIED IDEOGRAPH-#9A60, IRGKangXi=1446.370, RSKangXi=187.16
9A61 CJK UNIFIED IDEOGRAPH-#9A61, IRGKangXi=1446.390, RSKangXi=187.16
9A62 CJK UNIFIED IDEOGRAPH-#9A62, IRGKangXi=1446.400, RSKangXi=187.16, Def{donkey, ass}
9A63 CJK UNIFIED IDEOGRAPH-#9A63, IRGKangXi=1447.010, RSKangXi=187.16
9A64 CJK UNIFIED IDEOGRAPH-#9A64, IRGKangXi=1447.030, RSKangXi=187.17, Def{gallop about with head uplifted}
9A65 CJK UNIFIED IDEOGRAPH-#9A65, IRGKangXi=1447.040, RSKangXi=187.17, Def{thoroughbred horse; refined}
9A66 CJK UNIFIED IDEOGRAPH-#9A66, IRGKangXi=1447.060, RSKangXi=187.17, Def{horse}
9A67 CJK UNIFIED IDEOGRAPH-#9A67, IRGKangXi=1447.070, RSKangXi=187.17
9A68 CJK UNIFIED IDEOGRAPH-#9A68, IRGKangXi=1447.120, RSKangXi=187.18
9A69 CJK UNIFIED IDEOGRAPH-#9A69, IRGKangXi=1447.150, RSKangXi=187.18, Def{happy, pleased, glad; joy; to enjoy}
9A6A CJK UNIFIED IDEOGRAPH-#9A6A, IRGKangXi=1447.180, RSKangXi=187.19, Def{a pure black horse; a pair of horses}
9A6B CJK UNIFIED IDEOGRAPH-#9A6B, IRGKangXi=1447.220, RSKangXi=187.20, Def{horses}
9A6C CJK UNIFIED IDEOGRAPH-#9A6C, IRGKangXi=1447.241, RSKangXi=187.0, Def{horse; surname; KangXi radical 187}
9A6D CJK UNIFIED IDEOGRAPH-#9A6D, IRGKangXi=1447.241, RSKangXi=187.2, Def{drive, ride; manage, control}
9A6E CJK UNIFIED IDEOGRAPH-#9A6E, IRGKangXi=1447.241, RSKangXi=187.3, Def{carry on back}
9A6F CJK UNIFIED IDEOGRAPH-#9A6F, IRGKangXi=1447.241, RSKangXi=187.3, Def{tame, docile, obedient}
9A70 CJK UNIFIED IDEOGRAPH-#9A70, IRGKangXi=1447.241, RSKangXi=187.3, Def{go quickly or swiftly; hurry}
9A71 CJK UNIFIED IDEOGRAPH-#9A71, IRGKangXi=1447.241, RSKangXi=187.4, Def{spur a horse on; expel, drive away}
9A72 CJK UNIFIED IDEOGRAPH-#9A72, IRGKangXi=1447.241, RSKangXi=187.4, Def{post horse, relay horse}
9A73 CJK UNIFIED IDEOGRAPH-#9A73, IRGKangXi=1447.241, RSKangXi=187.4, Def{varicolored, variegated; mixed}
9A74 CJK UNIFIED IDEOGRAPH-#9A74, IRGKangXi=1447.241, RSKangXi=187.4, Def{donkey, ass}
9A75 CJK UNIFIED IDEOGRAPH-#9A75, IRGKangXi=1447.241, RSKangXi=187.5, Def{excellent horse, noble steed}
9A76 CJK UNIFIED IDEOGRAPH-#9A76, IRGKangXi=1447.241, RSKangXi=187.5, Def{sail, drive, pilot; fast, quick}
9A77 CJK UNIFIED IDEOGRAPH-#9A77, IRGKangXi=1447.241, RSKangXi=187.5, Def{team of four horses; horses}
9A78 CJK UNIFIED IDEOGRAPH-#9A78, IRGKangXi=1447.241, RSKangXi=187.5, Def{extra horse; imperial son-in-law}
9A79 CJK UNIFIED IDEOGRAPH-#9A79, IRGKangXi=1447.241, RSKangXi=187.5, Def{colt; fleet, swift; sun; surname}
9A7A CJK UNIFIED IDEOGRAPH-#9A7A, IRGKangXi=1447.241, RSKangXi=187.5, Def{mounted escort; groom}
9A7B CJK UNIFIED IDEOGRAPH-#9A7B, IRGKangXi=1447.241, RSKangXi=187.5, Def{to be stationed at, reside at; to stop}
9A7C CJK UNIFIED IDEOGRAPH-#9A7C, IRGKangXi=1447.241, RSKangXi=187.5, Def{a camel; humpbacked; to carry on the back}
9A7D CJK UNIFIED IDEOGRAPH-#9A7D, IRGKangXi=1447.241, RSKangXi=187.5, Def{tired, old horse; old, weak}
9A7E CJK UNIFIED IDEOGRAPH-#9A7E, IRGKangXi=1447.241, RSKangXi=187.5, Def{to drive, sail, fly; a cart, carriage}
9A7F CJK UNIFIED IDEOGRAPH-#9A7F, IRGKangXi=1447.241, RSKangXi=187.5, Def{relay station}
9A80 CJK UNIFIED IDEOGRAPH-#9A80, IRGKangXi=1447.241, RSKangXi=187.5, Def{an old, tired horse, a jade; tired, exhausted}
9A81 CJK UNIFIED IDEOGRAPH-#9A81, IRGKangXi=1447.241, RSKangXi=187.6, Def{excellent horse; brave, valiant}
9A82 CJK UNIFIED IDEOGRAPH-#9A82, IRGKangXi=1447.241, RSKangXi=30.6, Def{accuse, blame, curse, scold}
9A83 CJK UNIFIED IDEOGRAPH-#9A83, IRGKangXi=1447.241, RSKangXi=187.6, Def{grey horse}
9A84 CJK UNIFIED IDEOGRAPH-#9A84, IRGKangXi=1447.241, RSKangXi=187.6, Def{spirited horse; haughty}
9A85 CJK UNIFIED IDEOGRAPH-#9A85, IRGKangXi=1447.241, RSKangXi=187.6, Def{an excellent horse}
9A86 CJK UNIFIED IDEOGRAPH-#9A86, IRGKangXi=1447.241, RSKangXi=187.6, Def{a white horse with black mane; a camel}
9A87 CJK UNIFIED IDEOGRAPH-#9A87, IRGKangXi=1447.241, RSKangXi=187.6, Def{terrify, frighten, scare; shock}
9A88 CJK UNIFIED IDEOGRAPH-#9A88, IRGKangXi=1447.241, RSKangXi=187.6, Def{team of horses; associate, join}
9A89 CJK UNIFIED IDEOGRAPH-#9A89, IRGKangXi=1447.241, RSKangXi=187.6, Def{running; herd of horses}
9A8A CJK UNIFIED IDEOGRAPH-#9A8A, IRGKangXi=1447.241, RSKangXi=187.7, Def{a pure black horse; a pair of horses}
9A8B CJK UNIFIED IDEOGRAPH-#9A8B, IRGKangXi=1447.241, RSKangXi=187.7, Def{gallop horse; hasten, hurry}
9A8C CJK UNIFIED IDEOGRAPH-#9A8C, IRGKangXi=1447.241, RSKangXi=187.7, Def{test, examine, inspect; verify}
9A8D CJK UNIFIED IDEOGRAPH-#9A8D, IRGKangXi=1447.241, RSKangXi=187.7, Def{red, brown, bay; neat, harmonious}
9A8E CJK UNIFIED IDEOGRAPH-#9A8E, IRGKangXi=1447.241, RSKangXi=187.7, Def{galloping; speeding}
9A8F CJK UNIFIED IDEOGRAPH-#9A8F, IRGKangXi=1447.241, RSKangXi=187.7, Def{excellent horse, noble steed}
9A90 CJK UNIFIED IDEOGRAPH-#9A90, IRGKangXi=1447.241, RSKangXi=187.8, Def{piebald horse; excellent horse}
9A91 CJK UNIFIED IDEOGRAPH-#9A91, IRGKangXi=1447.241, RSKangXi=187.8, Def{ride horseback; mount; cavalry}
9A92 CJK UNIFIED IDEOGRAPH-#9A92, IRGKangXi=1447.241, RSKangXi=187.8, Def{mother horse}
9A93 CJK UNIFIED IDEOGRAPH-#9A93, IRGKangXi=1447.241, RSKangXi=187.8, Def{piebald horse}
9A94 CJK UNIFIED IDEOGRAPH-#9A94, IRGKangXi=1447.241, RSKangXi=187.8, Def{a horse's mane; bristles}
9A95 CJK UNIFIED IDEOGRAPH-#9A95, IRGKangXi=1447.241, RSKangXi=187.12, Def{name of a famous horse}
9A96 CJK UNIFIED IDEOGRAPH-#9A96, IRGKangXi=1447.241, RSKangXi=187.8, Def{two outside ones in three horse}
9A97 CJK UNIFIED IDEOGRAPH-#9A97, IRGKangXi=1447.241, RSKangXi=187.9, Def{swindle, cheat out of, defraud}
9A98 CJK UNIFIED IDEOGRAPH-#9A98, IRGKangXi=1447.241, RSKangXi=187.9, Def{stallion; promote}
9A99 CJK UNIFIED IDEOGRAPH-#9A99, IRGKangXi=1447.241, RSKangXi=187.9, Def{(of a horse) lively; vigorous}
9A9A CJK UNIFIED IDEOGRAPH-#9A9A, IRGKangXi=1447.241, RSKangXi=187.9, Def{harass, bother, annoy, disturb}
9A9B CJK UNIFIED IDEOGRAPH-#9A9B, IRGKangXi=1447.241, RSKangXi=187.9, Def{gallop; rush about; pursue, run}
9A9C CJK UNIFIED IDEOGRAPH-#9A9C, IRGKangXi=1447.241, RSKangXi=187.10, Def{wild horse, mustang; wild}
9A9D CJK UNIFIED IDEOGRAPH-#9A9D, IRGKangXi=1447.241, RSKangXi=187.10, Def{famous horse}
9A9E CJK UNIFIED IDEOGRAPH-#9A9E, IRGKangXi=1447.241, RSKangXi=187.10, Def{raise, hold high; fly, soar}
9A9F CJK UNIFIED IDEOGRAPH-#9A9F, IRGKangXi=1447.241, RSKangXi=187.10, Def{geld, castrate}
9AA0 CJK UNIFIED IDEOGRAPH-#9AA0, IRGKangXi=1447.241, RSKangXi=187.11, Def{charger, steed; swift, valiant}
9AA1 CJK UNIFIED IDEOGRAPH-#9AA1, IRGKangXi=1447.241, RSKangXi=187.11, Def{mule}
9AA2 CJK UNIFIED IDEOGRAPH-#9AA2, IRGKangXi=1447.241, RSKangXi=187.11, Def{horse with a bluish white color}
9AA3 CJK UNIFIED IDEOGRAPH-#9AA3, IRGKangXi=1447.241, RSKangXi=187.12, Def{horse without saddle}
9AA4 CJK UNIFIED IDEOGRAPH-#9AA4, IRGKangXi=1447.241, RSKangXi=187.14, Def{procedure; gallop; sudden(ly)}
9AA5 CJK UNIFIED IDEOGRAPH-#9AA5, IRGKangXi=1447.241, RSKangXi=187.16, Def{thoroughbred horse; refined and}
9AA6 CJK UNIFIED IDEOGRAPH-#9AA6, IRGKangXi=1447.241, RSKangXi=187.17, Def{horse}
9AA7 CJK UNIFIED IDEOGRAPH-#9AA7, IRGKangXi=1447.241, RSKangXi=187.17, Def{gallop about with head uplifted}
9AA8 CJK UNIFIED IDEOGRAPH-#9AA8, IRGKangXi=1447.250, RSKangXi=188.0, Def{bone; skeleton; frame, framework}
9AA9 CJK UNIFIED IDEOGRAPH-#9AA9, IRGKangXi=1448.010
9AAA CJK UNIFIED IDEOGRAPH-#9AAA, IRGKangXi=1448.020, RSKangXi=188.3, Def{crooked bones}
9AAB CJK UNIFIED IDEOGRAPH-#9AAB, IRGKangXi=1448.030, RSKangXi=188.3
9AAC CJK UNIFIED IDEOGRAPH-#9AAC, IRGKangXi=1448.050, RSKangXi=188.3
9AAD CJK UNIFIED IDEOGRAPH-#9AAD, IRGKangXi=1448.060, RSKangXi=188.3, Def{shin bone}
9AAE CJK UNIFIED IDEOGRAPH-#9AAE, IRGKangXi=1448.080, RSKangXi=188.3
9AAF CJK UNIFIED IDEOGRAPH-#9AAF, IRGKangXi=1448.170, RSKangXi=188.4, Def{dirty}
9AB0 CJK UNIFIED IDEOGRAPH-#9AB0, IRGKangXi=1448.200, RSKangXi=188.4, Def{die, dice}
9AB1 CJK UNIFIED IDEOGRAPH-#9AB1, IRGKangXi=1448.210, RSKangXi=188.4
9AB2 CJK UNIFIED IDEOGRAPH-#9AB2, IRGKangXi=1448.300, RSKangXi=188.5, Def{(Cant.) to push with the body}
9AB3 CJK UNIFIED IDEOGRAPH-#9AB3, IRGKangXi=1448.340, RSKangXi=188.5
9AB4 CJK UNIFIED IDEOGRAPH-#9AB4, IRGKangXi=1448.350, RSKangXi=188.5, Def{a putrid carcase}
9AB5 CJK UNIFIED IDEOGRAPH-#9AB5, IRGKangXi=1448.390, RSKangXi=188.5
9AB6 CJK UNIFIED IDEOGRAPH-#9AB6, IRGKangXi=1448.420, RSKangXi=188.5, Def{coccyx}
9AB7 CJK UNIFIED IDEOGRAPH-#9AB7, IRGKangXi=1448.430, RSKangXi=188.5, Def{skeleton}
9AB8 CJK UNIFIED IDEOGRAPH-#9AB8, IRGKangXi=1448.500, RSKangXi=188.6, Def{skeleton, body; leg bone}
9AB9 CJK UNIFIED IDEOGRAPH-#9AB9, IRGKangXi=1449.060, RSKangXi=188.6, Def{(Cant.) a joint}
9ABA CJK UNIFIED IDEOGRAPH-#9ABA, IRGKangXi=1449.080, RSKangXi=188.6, Def{tip of a long bone}
9ABB CJK UNIFIED IDEOGRAPH-#9ABB, IRGKangXi=1449.100, RSKangXi=188.6
9ABC CJK UNIFIED IDEOGRAPH-#9ABC, IRGKangXi=1449.110, RSKangXi=188.6, Def{bone; skeleton; corpse}
9ABD CJK UNIFIED IDEOGRAPH-#9ABD, IRGKangXi=1449.220, RSKangXi=188.7, Def{leg, thigh}
9ABE CJK UNIFIED IDEOGRAPH-#9ABE, IRGKangXi=1449.290, RSKangXi=188.7, Def{any object that sticks in throat; bony}
9ABF CJK UNIFIED IDEOGRAPH-#9ABF, IRGKangXi=1449.340, RSKangXi=188.8
9AC0 CJK UNIFIED IDEOGRAPH-#9AC0, IRGKangXi=1449.350, RSKangXi=188.8, Def{buttocks; thigh, thigh bone}
9AC1 CJK UNIFIED IDEOGRAPH-#9AC1, IRGKangXi=1449.460, RSKangXi=188.8, Def{thigh bone, hipbone; kneecap}
9AC2 CJK UNIFIED IDEOGRAPH-#9AC2, IRGKangXi=1450.090, RSKangXi=188.9, Def{the pelvis}
9AC3 CJK UNIFIED IDEOGRAPH-#9AC3, IRGKangXi=1450.170, RSKangXi=188.9, Def{shoulder bone}
9AC4 CJK UNIFIED IDEOGRAPH-#9AC4, IRGKangXi=1450.321, RSKangXi=188.9, Def{bone marrow; essences, substances}
9AC5 CJK UNIFIED IDEOGRAPH-#9AC5, IRGKangXi=1450.181, RSKangXi=188.9, Def{skull; skeleton}
9AC6 CJK UNIFIED IDEOGRAPH-#9AC6, IRGKangXi=1450.190, RSKangXi=188.10, Def{shoulder blade}
9AC7 CJK UNIFIED IDEOGRAPH-#9AC7, IRGKangXi=1450.210, RSKangXi=188.10
9AC8 CJK UNIFIED IDEOGRAPH-#9AC8, IRGKangXi=1450.240, RSKangXi=188.10, Def{the pelvis, the hip-bone; the humerus; a wing}
9AC9 CJK UNIFIED IDEOGRAPH-#9AC9, IRGKangXi=1450.300, RSKangXi=188.10
9ACA CJK UNIFIED IDEOGRAPH-#9ACA, IRGKangXi=1450.310, RSKangXi=188.10
9ACB CJK UNIFIED IDEOGRAPH-#9ACB, IRGKangXi=1450.461, RSKangXi=188.10, Def{hipbone; hip}
9ACC CJK UNIFIED IDEOGRAPH-#9ACC, IRGKangXi=1450.321, RSKangXi=188.10, Def{kneecap}
9ACD CJK UNIFIED IDEOGRAPH-#9ACD, IRGKangXi=1450.330, RSKangXi=188.11
9ACE CJK UNIFIED IDEOGRAPH-#9ACE, IRGKangXi=1450.400, RSKangXi=188.11, Def{hip bone}
9ACF CJK UNIFIED IDEOGRAPH-#9ACF, IRGKangXi=1450.440, RSKangXi=188.11, Def{skull; skeleton}
9AD0 CJK UNIFIED IDEOGRAPH-#9AD0, IRGKangXi=1450.510, RSKangXi=188.12
9AD1 CJK UNIFIED IDEOGRAPH-#9AD1, IRGKangXi=1450.570, RSKangXi=188.13, Def{skull}
9AD2 CJK UNIFIED IDEOGRAPH-#9AD2, IRGKangXi=1450.600, RSKangXi=188.13, Def{dirty; firm; fat}
9AD3 CJK UNIFIED IDEOGRAPH-#9AD3, IRGKangXi=1451.040, RSKangXi=188.13, Def{bone marrow; essences, substances}
9AD4 CJK UNIFIED IDEOGRAPH-#9AD4, IRGKangXi=1451.060, RSKangXi=188.13, Def{body; group, class, body, unit}
9AD5 CJK UNIFIED IDEOGRAPH-#9AD5, IRGKangXi=1451.140, RSKangXi=188.14, Def{kneecap}
9AD6 CJK UNIFIED IDEOGRAPH-#9AD6, IRGKangXi=1451.150, RSKangXi=188.15, Def{hipbone; hip}
9AD7 CJK UNIFIED IDEOGRAPH-#9AD7, IRGKangXi=1451.190, RSKangXi=188.16, Def{the skull; the forehead}
9AD8 CJK UNIFIED IDEOGRAPH-#9AD8, IRGKangXi=1451.260, RSKangXi=189.0, Def{high, tall; lofty, elevated}
9AD9 CJK UNIFIED IDEOGRAPH-#9AD9, IRGKangXi=1451.261, RSKangXi=189.0, Def{variant of 高 U+9AD8, high, tall; lofty, elevated}
9ADA CJK UNIFIED IDEOGRAPH-#9ADA, IRGKangXi=1451.320, RSKangXi=189.4
9ADB CJK UNIFIED IDEOGRAPH-#9ADB, IRGKangXi=1451.350, RSKangXi=189.5
9ADC CJK UNIFIED IDEOGRAPH-#9ADC, IRGKangXi=1452.060, RSKangXi=189.8
9ADD CJK UNIFIED IDEOGRAPH-#9ADD, IRGKangXi=1452.130, RSKangXi=189.12
9ADE CJK UNIFIED IDEOGRAPH-#9ADE, IRGKangXi=1452.170, RSKangXi=189.13, Def{high, imposing, eminent}
9ADF CJK UNIFIED IDEOGRAPH-#9ADF, IRGKangXi=1452.260, RSKangXi=190.0, Def{hair; KangXi radical 190}
9AE0 CJK UNIFIED IDEOGRAPH-#9AE0, IRGKangXi=1452.300, RSKangXi=190.2, Def{shave head as punishment; prune}
9AE1 CJK UNIFIED IDEOGRAPH-#9AE1, IRGKangXi=1452.310, RSKangXi=190.3, Def{to shear tree; ancient punishment}
9AE2 CJK UNIFIED IDEOGRAPH-#9AE2, IRGKangXi=1452.330, RSKangXi=190.3, Def{wig}
9AE3 CJK UNIFIED IDEOGRAPH-#9AE3, IRGKangXi=1452.390, RSKangXi=190.4, Def{similar to, like}
9AE4 CJK UNIFIED IDEOGRAPH-#9AE4, IRGKangXi=1452.400, RSKangXi=190.4
9AE5 CJK UNIFIED IDEOGRAPH-#9AE5, IRGKangXi=1452.430, RSKangXi=190.4, Def{beard; mustache}
9AE6 CJK UNIFIED IDEOGRAPH-#9AE6, IRGKangXi=1453.020, RSKangXi=190.4, Def{flowing hair of young child}
9AE7 CJK UNIFIED IDEOGRAPH-#9AE7, IRGKangXi=1453.030, RSKangXi=190.4, Def{long hair; (Cant.) to hang down, droop}
9AE8 CJK UNIFIED IDEOGRAPH-#9AE8, IRGKangXi=1453.070
9AE9 CJK UNIFIED IDEOGRAPH-#9AE9, IRGKangXi=1453.081, RSKangXi=190.4
9AEA CJK UNIFIED IDEOGRAPH-#9AEA, IRGKangXi=1453.081, RSKangXi=190.4, Def{hair}
9AEB CJK UNIFIED IDEOGRAPH-#9AEB, IRGKangXi=1453.130, RSKangXi=190.5, Def{children's hair style; a youngster}
9AEC CJK UNIFIED IDEOGRAPH-#9AEC, IRGKangXi=1453.180, RSKangXi=190.5
9AED CJK UNIFIED IDEOGRAPH-#9AED, IRGKangXi=1453.200, RSKangXi=190.5, Def{mustache}
9AEE CJK UNIFIED IDEOGRAPH-#9AEE, IRGKangXi=1453.210, RSKangXi=190.5, Def{hair}
9AEF CJK UNIFIED IDEOGRAPH-#9AEF, IRGKangXi=1453.290, RSKangXi=190.5, Def{beard; mustache}
9AF0 CJK UNIFIED IDEOGRAPH-#9AF0, IRGKangXi=1453.340, RSKangXi=190.5
9AF1 CJK UNIFIED IDEOGRAPH-#9AF1, IRGKangXi=1453.350, RSKangXi=190.5, Def{a topknot, bun, coiled hair-knot}
9AF2 CJK UNIFIED IDEOGRAPH-#9AF2, IRGKangXi=1453.360, RSKangXi=190.5, Def{a wig}
9AF3 CJK UNIFIED IDEOGRAPH-#9AF3, IRGKangXi=1453.370, RSKangXi=190.5, Def{state}
9AF4 CJK UNIFIED IDEOGRAPH-#9AF4, IRGKangXi=1453.390, RSKangXi=190.5, Def{disheveled hair; similar to}
9AF5 CJK UNIFIED IDEOGRAPH-#9AF5, IRGKangXi=1453.420, RSKangXi=190.6, Def{whiskers, bristles on the jaws of an animal}
9AF6 CJK UNIFIED IDEOGRAPH-#9AF6, IRGKangXi=1453.430, RSKangXi=190.6
9AF7 CJK UNIFIED IDEOGRAPH-#9AF7, IRGKangXi=1454.020, RSKangXi=190.6, Def{a topknot}
9AF8 CJK UNIFIED IDEOGRAPH-#9AF8, IRGKangXi=1454.050, RSKangXi=190.6
9AF9 CJK UNIFIED IDEOGRAPH-#9AF9, IRGKangXi=1454.060, RSKangXi=190.6, Def{red lacquer; to lacquer}
9AFA CJK UNIFIED IDEOGRAPH-#9AFA, IRGKangXi=1454.150, RSKangXi=190.6, Def{the hair dishevelled, as in mourning}
9AFB CJK UNIFIED IDEOGRAPH-#9AFB, IRGKangXi=1454.180, RSKangXi=190.6, Def{hair rolled up in a bun, topknot}
9AFC CJK UNIFIED IDEOGRAPH-#9AFC, IRGKangXi=1454.210, RSKangXi=190.7
9AFD CJK UNIFIED IDEOGRAPH-#9AFD, IRGKangXi=1454.300, RSKangXi=190.7, Def{to dress the hair}
9AFE CJK UNIFIED IDEOGRAPH-#9AFE, IRGKangXi=1454.350, RSKangXi=190.7, Def{tail of a comet; long hair}
9AFF CJK UNIFIED IDEOGRAPH-#9AFF, IRGKangXi=1454.360, RSKangXi=190.7
9B00 CJK UNIFIED IDEOGRAPH-#9B00, IRGKangXi=1454.370, RSKangXi=190.7, Def{to shave}
9B01 CJK UNIFIED IDEOGRAPH-#9B01, IRGKangXi=1454.391, RSKangXi=190.7, Def{favus}
9B02 CJK UNIFIED IDEOGRAPH-#9B02, IRGKangXi=1454.391, RSKangXi=190.7, Def{the hair on the temples}
9B03 CJK UNIFIED IDEOGRAPH-#9B03, IRGKangXi=1454.400, RSKangXi=190.8, Def{mane; neck bristles}
9B04 CJK UNIFIED IDEOGRAPH-#9B04, IRGKangXi=1454.410, RSKangXi=190.8
9B05 CJK UNIFIED IDEOGRAPH-#9B05, IRGKangXi=1454.440, RSKangXi=190.8, Def{unkempt hair; loose; flowing hair; (Cant.) 鬅鬠, to be slovenly dressed}
9B06 CJK UNIFIED IDEOGRAPH-#9B06, IRGKangXi=1455.050, RSKangXi=190.8, Def{lax, loose; loosen, relax}
9B07 CJK UNIFIED IDEOGRAPH-#9B07, IRGKangXi=1455.100, RSKangXi=190.6
9B08 CJK UNIFIED IDEOGRAPH-#9B08, IRGKangXi=1455.110, RSKangXi=190.8, Def{fine growth of hair curly hair}
9B09 CJK UNIFIED IDEOGRAPH-#9B09, IRGKangXi=1455.170, RSKangXi=190.9
9B0A CJK UNIFIED IDEOGRAPH-#9B0A, IRGKangXi=1455.330, RSKangXi=190.9
9B0B CJK UNIFIED IDEOGRAPH-#9B0B, IRGKangXi=1455.360, RSKangXi=190.9, Def{forelock, bangs}
9B0C CJK UNIFIED IDEOGRAPH-#9B0C, IRGKangXi=1455.390, RSKangXi=190.9, Def{tufts of hair left on the heads of children after shaving}
9B0D CJK UNIFIED IDEOGRAPH-#9B0D, IRGKangXi=1455.421, RSKangXi=190.9, Def{beard, mustache, whiskers}
9B0E CJK UNIFIED IDEOGRAPH-#9B0E, IRGKangXi=1455.421, RSKangXi=190.9, Def{favus, scabies}
9B0F CJK UNIFIED IDEOGRAPH-#9B0F, IRGKangXi=1455.421, RSKangXi=190.9, Def{a coiffure on top of the head}
9B10 CJK UNIFIED IDEOGRAPH-#9B10, IRGKangXi=1455.510, RSKangXi=190.10, Def{horse's mane; fins}
9B11 CJK UNIFIED IDEOGRAPH-#9B11, IRGKangXi=1456.010, RSKangXi=190.10, Def{long, flowing hair}
9B12 CJK UNIFIED IDEOGRAPH-#9B12, IRGKangXi=1456.050, RSKangXi=190.10, Def{black, glossy hair}
9B13 CJK UNIFIED IDEOGRAPH-#9B13, IRGKangXi=1456.091, RSKangXi=190.10, Def{hair on temples}
9B14 CJK UNIFIED IDEOGRAPH-#9B14, IRGKangXi=1456.110
9B15 CJK UNIFIED IDEOGRAPH-#9B15, IRGKangXi=1456.150, RSKangXi=190.11
9B16 CJK UNIFIED IDEOGRAPH-#9B16, IRGKangXi=1456.210, RSKangXi=190.11, Def{wild hair}
9B17 CJK UNIFIED IDEOGRAPH-#9B17, IRGKangXi=1456.260, RSKangXi=190.11
9B18 CJK UNIFIED IDEOGRAPH-#9B18, IRGKangXi=1456.270, RSKangXi=190.11, Def{beautiful hair}
9B19 CJK UNIFIED IDEOGRAPH-#9B19, IRGKangXi=1456.360, RSKangXi=190.12, Def{matted hair}
9B1A CJK UNIFIED IDEOGRAPH-#9B1A, IRGKangXi=1456.380, RSKangXi=190.12, Def{beard, whiskers; whisker-like}
9B1B CJK UNIFIED IDEOGRAPH-#9B1B, IRGKangXi=1456.420, RSKangXi=190.12, Def{variant of 鬣 U+9B23, a mane}
9B1C CJK UNIFIED IDEOGRAPH-#9B1C, IRGKangXi=1456.450, RSKangXi=190.12, Def{to go bald}
9B1D CJK UNIFIED IDEOGRAPH-#9B1D, IRGKangXi=1456.481, RSKangXi=190.11
9B1E CJK UNIFIED IDEOGRAPH-#9B1E, IRGKangXi=1456.520, RSKangXi=190.13
9B1F CJK UNIFIED IDEOGRAPH-#9B1F, IRGKangXi=1456.540, RSKangXi=190.13, Def{dress hair in coiled knot; maid}
9B20 CJK UNIFIED IDEOGRAPH-#9B20, IRGKangXi=1456.550, RSKangXi=190.13, Def{to make a top knot; (Cant.) 鬅鬠, to be slovenly dressed}
9B21 CJK UNIFIED IDEOGRAPH-#9B21, IRGKangXi=1457.080, RSKangXi=190.14
9B22 CJK UNIFIED IDEOGRAPH-#9B22, IRGKangXi=1457.100, RSKangXi=190.14, Def{hair on temples}
9B23 CJK UNIFIED IDEOGRAPH-#9B23, IRGKangXi=1457.150, RSKangXi=190.15, Def{horse's mane; fin; human whiskers}
9B24 CJK UNIFIED IDEOGRAPH-#9B24, IRGKangXi=1457.230, RSKangXi=190.17
9B25 CJK UNIFIED IDEOGRAPH-#9B25, IRGKangXi=1457.290, RSKangXi=191.0, Def{struggle, fight, compete, contend}
9B26 CJK UNIFIED IDEOGRAPH-#9B26, IRGKangXi=1457.310, RSKangXi=191.4, Def{struggle, fight, compete, contend}
9B27 CJK UNIFIED IDEOGRAPH-#9B27, IRGKangXi=1457.340, RSKangXi=191.5, Def{quarrel; dispute hotly}
9B28 CJK UNIFIED IDEOGRAPH-#9B28, IRGKangXi=1457.360, RSKangXi=191.6, Def{boisterous; clamor, noise}
9B29 CJK UNIFIED IDEOGRAPH-#9B29, IRGKangXi=1457.370, RSKangXi=191.8, Def{feud, fight, quarrel}
9B2A CJK UNIFIED IDEOGRAPH-#9B2A, IRGKangXi=1457.410, RSKangXi=191.10, Def{struggle, fight, compete, contend}
9B2B CJK UNIFIED IDEOGRAPH-#9B2B, IRGKangXi=1458.020, RSKangXi=191.12
9B2C CJK UNIFIED IDEOGRAPH-#9B2C, IRGKangXi=1458.071, RSKangXi=191.14, Def{struggle}
9B2D CJK UNIFIED IDEOGRAPH-#9B2D, IRGKangXi=1458.060, RSKangXi=191.14, Def{struggle, fight, compete, contend; (Cant.) woodwork, carpentry}
9B2E CJK UNIFIED IDEOGRAPH-#9B2E, IRGKangXi=1458.080, RSKangXi=191.17, Def{lots (to be drawn); draw lots}
9B2F CJK UNIFIED IDEOGRAPH-#9B2F, IRGKangXi=1458.100, RSKangXi=192.0, Def{sacrificial wine; unhindered}
9B30 CJK UNIFIED IDEOGRAPH-#9B30, IRGKangXi=1458.161, Def{luxuriant; dense, thick; moody}
9B31 CJK UNIFIED IDEOGRAPH-#9B31, IRGKangXi=1458.180, RSKangXi=192.19, Def{luxuriant; dense, thick; moody}
9B32 CJK UNIFIED IDEOGRAPH-#9B32, IRGKangXi=1458.200, RSKangXi=193.0, Def{type of caldron with three hollow legs; name of a state; KangXi radical number 193}
9B33 CJK UNIFIED IDEOGRAPH-#9B33, IRGKangXi=1459.090, RSKangXi=193.6
9B34 CJK UNIFIED IDEOGRAPH-#9B34, IRGKangXi=1459.180, RSKangXi=193.7, Def{pot}
9B35 CJK UNIFIED IDEOGRAPH-#9B35, IRGKangXi=1459.210, RSKangXi=193.8, Def{big iron pot, caldron}
9B36 CJK UNIFIED IDEOGRAPH-#9B36, IRGKangXi=1459.241, RSKangXi=193.8
9B37 CJK UNIFIED IDEOGRAPH-#9B37, IRGKangXi=1459.270, RSKangXi=193.9, Def{pot}
9B38 CJK UNIFIED IDEOGRAPH-#9B38, IRGKangXi=1459.340, RSKangXi=193.10
9B39 CJK UNIFIED IDEOGRAPH-#9B39, IRGKangXi=1459.380, RSKangXi=193.11
9B3A CJK UNIFIED IDEOGRAPH-#9B3A, IRGKangXi=1459.400, RSKangXi=193.11
9B3B CJK UNIFIED IDEOGRAPH-#9B3B, IRGKangXi=1459.450, RSKangXi=193.12, Def{sell; child, childish; nourish}
9B3C CJK UNIFIED IDEOGRAPH-#9B3C, IRGKangXi=1460.300, RSKangXi=194.0, Def{ghost; spirit of dead; devil}
9B3D CJK UNIFIED IDEOGRAPH-#9B3D, IRGKangXi=1460.400, RSKangXi=194.3
9B3E CJK UNIFIED IDEOGRAPH-#9B3E, IRGKangXi=1460.450, RSKangXi=194.4
9B3F CJK UNIFIED IDEOGRAPH-#9B3F, IRGKangXi=1461.040, RSKangXi=194.4
9B40 CJK UNIFIED IDEOGRAPH-#9B40, IRGKangXi=1461.070
9B41 CJK UNIFIED IDEOGRAPH-#9B41, IRGKangXi=1461.090, RSKangXi=194.4, Def{chief; leader; best; monstrous}
9B42 CJK UNIFIED IDEOGRAPH-#9B42, IRGKangXi=1461.120, RSKangXi=194.4, Def{soul, spirit}
9B43 CJK UNIFIED IDEOGRAPH-#9B43, IRGKangXi=1461.240, RSKangXi=194.5, Def{drought demon}
9B44 CJK UNIFIED IDEOGRAPH-#9B44, IRGKangXi=1461.280, RSKangXi=194.5, Def{vigor; body; dark part of moon}
9B45 CJK UNIFIED IDEOGRAPH-#9B45, IRGKangXi=1461.300, RSKangXi=194.5, Def{kind of forest demon, elf}
9B46 CJK UNIFIED IDEOGRAPH-#9B46, IRGKangXi=1461.340, RSKangXi=194.5, Def{black}
9B47 CJK UNIFIED IDEOGRAPH-#9B47, IRGKangXi=1462.121, RSKangXi=194.6, Def{nightmare, bad dreams}
9B48 CJK UNIFIED IDEOGRAPH-#9B48, IRGKangXi=1462.150, RSKangXi=194.7, Def{mischevious, one footed spirit that dwells in the mountains}
9B49 CJK UNIFIED IDEOGRAPH-#9B49, IRGKangXi=1462.241, RSKangXi=194.7, Def{a kind of monster}
9B4A CJK UNIFIED IDEOGRAPH-#9B4A, IRGKangXi=1462.300, RSKangXi=194.8, Def{a mythical creature said hurl san}
9B4B CJK UNIFIED IDEOGRAPH-#9B4B, IRGKangXi=1462.310, RSKangXi=194.8, Def{bear}
9B4C CJK UNIFIED IDEOGRAPH-#9B4C, IRGKangXi=1462.330, RSKangXi=194.8
9B4D CJK UNIFIED IDEOGRAPH-#9B4D, IRGKangXi=1462.380, RSKangXi=194.8, Def{demons, mountain spirits}
9B4E CJK UNIFIED IDEOGRAPH-#9B4E, IRGKangXi=1462.390, RSKangXi=194.8, Def{a kind of monster}
9B4F CJK UNIFIED IDEOGRAPH-#9B4F, IRGKangXi=1462.400, RSKangXi=194.8, Def{kingdom of Wei; surname}
9B50 CJK UNIFIED IDEOGRAPH-#9B50, IRGKangXi=1462.570
9B51 CJK UNIFIED IDEOGRAPH-#9B51, IRGKangXi=1462.610, RSKangXi=194.11, Def{a mountain demon resembling a tiger}
9B52 CJK UNIFIED IDEOGRAPH-#9B52, IRGKangXi=1462.650, RSKangXi=194.11
9B53 CJK UNIFIED IDEOGRAPH-#9B53, IRGKangXi=1462.660, RSKangXi=194.11
9B54 CJK UNIFIED IDEOGRAPH-#9B54, IRGKangXi=1462.670, RSKangXi=194.11, Def{demon, evil spirits; magic power}
9B55 CJK UNIFIED IDEOGRAPH-#9B55, IRGKangXi=1463.130, RSKangXi=194.12
9B56 CJK UNIFIED IDEOGRAPH-#9B56, IRGKangXi=1463.140, RSKangXi=194.12
9B57 CJK UNIFIED IDEOGRAPH-#9B57, IRGKangXi=1463.200, RSKangXi=194.14
9B58 CJK UNIFIED IDEOGRAPH-#9B58, IRGKangXi=1463.230, RSKangXi=194.14, Def{nightmare, bad dreams}
9B59 CJK UNIFIED IDEOGRAPH-#9B59, IRGKangXi=1463.240, RSKangXi=194.14
9B5A CJK UNIFIED IDEOGRAPH-#9B5A, IRGKangXi=1465.010, RSKangXi=195.0, Def{fish; surname; KangXi radical 195}
9B5B CJK UNIFIED IDEOGRAPH-#9B5B, IRGKangXi=1465.040, RSKangXi=195.2, Def{the mullet}
9B5C CJK UNIFIED IDEOGRAPH-#9B5C, IRGKangXi=1465.070, RSKangXi=195.2, Def{mermaid; manatee}
9B5D CJK UNIFIED IDEOGRAPH-#9B5D, IRGKangXi=1465.080, RSKangXi=195.2
9B5E CJK UNIFIED IDEOGRAPH-#9B5E, IRGKangXi=1465.121, RSKangXi=195.2, Def{fish trap}
9B5F CJK UNIFIED IDEOGRAPH-#9B5F, IRGKangXi=1465.130, RSKangXi=195.3, Def{a ray, skate}
9B60 CJK UNIFIED IDEOGRAPH-#9B60, IRGKangXi=1465.140, RSKangXi=195.3
9B61 CJK UNIFIED IDEOGRAPH-#9B61, IRGKangXi=1465.160, RSKangXi=195.3
9B62 CJK UNIFIED IDEOGRAPH-#9B62, IRGKangXi=1465.211, RSKangXi=195.3, Def{name of fish}
9B63 CJK UNIFIED IDEOGRAPH-#9B63, IRGKangXi=1465.230, RSKangXi=195.4
9B64 CJK UNIFIED IDEOGRAPH-#9B64, IRGKangXi=1465.240, RSKangXi=195.4
9B65 CJK UNIFIED IDEOGRAPH-#9B65, IRGKangXi=1465.260, RSKangXi=195.4
9B66 CJK UNIFIED IDEOGRAPH-#9B66, IRGKangXi=1466.010, RSKangXi=195.4, Def{shark family, including some rays and skates}
9B67 CJK UNIFIED IDEOGRAPH-#9B67, IRGKangXi=1466.060, RSKangXi=195.4
9B68 CJK UNIFIED IDEOGRAPH-#9B68, IRGKangXi=1466.070, RSKangXi=195.4, Def{blowfish, globefish, Spheroides vermicular}
9B69 CJK UNIFIED IDEOGRAPH-#9B69, IRGKangXi=1466.100
9B6A CJK UNIFIED IDEOGRAPH-#9B6A, IRGKangXi=1466.140, RSKangXi=195.4
9B6B CJK UNIFIED IDEOGRAPH-#9B6B, IRGKangXi=1466.170, RSKangXi=195.4, Def{the young of fish}
9B6C CJK UNIFIED IDEOGRAPH-#9B6C, IRGKangXi=1466.190, RSKangXi=195.4, Def{sole or flounder}
9B6D CJK UNIFIED IDEOGRAPH-#9B6D, IRGKangXi=1466.210, RSKangXi=195.4
9B6E CJK UNIFIED IDEOGRAPH-#9B6E, IRGKangXi=1466.220, RSKangXi=195.4
9B6F CJK UNIFIED IDEOGRAPH-#9B6F, IRGKangXi=1466.260, RSKangXi=195.4, Def{foolish, stupid, rash; vulgar}
9B70 CJK UNIFIED IDEOGRAPH-#9B70, IRGKangXi=1466.280, RSKangXi=195.4, Def{the flying-fish}
9B71 CJK UNIFIED IDEOGRAPH-#9B71, IRGKangXi=1466.310, RSKangXi=195.4
9B72 CJK UNIFIED IDEOGRAPH-#9B72, IRGKangXi=1466.320, RSKangXi=195.4, Def{fish name}
9B73 CJK UNIFIED IDEOGRAPH-#9B73, IRGKangXi=1466.330, RSKangXi=195.4, Def{a barracuda}
9B74 CJK UNIFIED IDEOGRAPH-#9B74, IRGKangXi=1466.350, RSKangXi=195.4, Def{bream}
9B75 CJK UNIFIED IDEOGRAPH-#9B75, IRGKangXi=1466.360, RSKangXi=195.4, Def{shrimp}
9B76 CJK UNIFIED IDEOGRAPH-#9B76, IRGKangXi=1466.370, RSKangXi=195.4
9B77 CJK UNIFIED IDEOGRAPH-#9B77, IRGKangXi=1467.041, RSKangXi=195.4, Def{cuttlefish}
9B78 CJK UNIFIED IDEOGRAPH-#9B78, IRGKangXi=1467.041, RSKangXi=195.4
9B79 CJK UNIFIED IDEOGRAPH-#9B79, IRGKangXi=1467.041, RSKangXi=195.4
9B7A CJK UNIFIED IDEOGRAPH-#9B7A, IRGKangXi=1467.050, RSKangXi=195.5
9B7B CJK UNIFIED IDEOGRAPH-#9B7B, IRGKangXi=1467.070, RSKangXi=195.5
9B7C CJK UNIFIED IDEOGRAPH-#9B7C, IRGKangXi=1467.080, RSKangXi=195.5
9B7D CJK UNIFIED IDEOGRAPH-#9B7D, IRGKangXi=1467.090, RSKangXi=195.5
9B7E CJK UNIFIED IDEOGRAPH-#9B7E, IRGKangXi=1467.100, RSKangXi=195.5
9B7F CJK UNIFIED IDEOGRAPH-#9B7F, IRGKangXi=1467.110, RSKangXi=195.5
9B80 CJK UNIFIED IDEOGRAPH-#9B80, IRGKangXi=1467.120, RSKangXi=195.5, Def{snakefish}
9B81 CJK UNIFIED IDEOGRAPH-#9B81, IRGKangXi=1467.150, RSKangXi=195.5, Def{the bonito}
9B82 CJK UNIFIED IDEOGRAPH-#9B82, IRGKangXi=1467.160, RSKangXi=195.5
9B83 CJK UNIFIED IDEOGRAPH-#9B83, IRGKangXi=1467.170, RSKangXi=195.5, Def{a flatfish, flounder}
9B84 CJK UNIFIED IDEOGRAPH-#9B84, IRGKangXi=1467.190, RSKangXi=195.5, Def{gurnard}
9B85 CJK UNIFIED IDEOGRAPH-#9B85, IRGKangXi=1467.200, RSKangXi=195.5
9B86 CJK UNIFIED IDEOGRAPH-#9B86, IRGKangXi=1467.260, RSKangXi=195.5, Def{fish}
9B87 CJK UNIFIED IDEOGRAPH-#9B87, IRGKangXi=1467.320, RSKangXi=195.5
9B88 CJK UNIFIED IDEOGRAPH-#9B88, IRGKangXi=1468.010, RSKangXi=195.5
9B89 CJK UNIFIED IDEOGRAPH-#9B89, IRGKangXi=1468.030, RSKangXi=195.5, Def{bream}
9B8A CJK UNIFIED IDEOGRAPH-#9B8A, IRGKangXi=1468.040, RSKangXi=195.5
9B8B CJK UNIFIED IDEOGRAPH-#9B8B, IRGKangXi=1468.060, RSKangXi=195.5
9B8C CJK UNIFIED IDEOGRAPH-#9B8C, IRGKangXi=1468.070, RSKangXi=195.5
9B8D CJK UNIFIED IDEOGRAPH-#9B8D, IRGKangXi=1468.090, RSKangXi=195.5
9B8E CJK UNIFIED IDEOGRAPH-#9B8E, IRGKangXi=1468.100, RSKangXi=195.5, Def{sheatfish, parasilurus asotus}
9B8F CJK UNIFIED IDEOGRAPH-#9B8F, IRGKangXi=1468.110, RSKangXi=195.5
9B90 CJK UNIFIED IDEOGRAPH-#9B90, IRGKangXi=1468.130, RSKangXi=195.5, Def{blowfish, globefish, tetraodon}
9B91 CJK UNIFIED IDEOGRAPH-#9B91, IRGKangXi=1468.140, RSKangXi=195.5, Def{abalone; dried fish; surname}
9B92 CJK UNIFIED IDEOGRAPH-#9B92, IRGKangXi=1468.150, RSKangXi=195.5, Def{carp, carassicus auratus}
9B93 CJK UNIFIED IDEOGRAPH-#9B93, IRGKangXi=1468.160, RSKangXi=195.5, Def{minced and salted fish; to preserve}
9B94 CJK UNIFIED IDEOGRAPH-#9B94, IRGKangXi=1468.221, RSKangXi=195.5
9B95 CJK UNIFIED IDEOGRAPH-#9B95, IRGKangXi=1468.221, RSKangXi=195.5
9B96 CJK UNIFIED IDEOGRAPH-#9B96, IRGKangXi=1468.221, RSKangXi=195.5
9B97 CJK UNIFIED IDEOGRAPH-#9B97, IRGKangXi=1468.221, RSKangXi=195.5
9B98 CJK UNIFIED IDEOGRAPH-#9B98, IRGKangXi=1468.221, RSKangXi=195.5
9B99 CJK UNIFIED IDEOGRAPH-#9B99, IRGKangXi=1468.230, RSKangXi=195.6
9B9A CJK UNIFIED IDEOGRAPH-#9B9A, IRGKangXi=1468.240, RSKangXi=195.6, Def{clam; oyster}
9B9B CJK UNIFIED IDEOGRAPH-#9B9B, IRGKangXi=1468.270, RSKangXi=195.6
9B9C CJK UNIFIED IDEOGRAPH-#9B9C, IRGKangXi=1468.300
9B9D CJK UNIFIED IDEOGRAPH-#9B9D, IRGKangXi=1468.310, RSKangXi=195.6, Def{dried fish}
9B9E CJK UNIFIED IDEOGRAPH-#9B9E, IRGKangXi=1468.350, RSKangXi=195.6, Def{roe}
9B9F CJK UNIFIED IDEOGRAPH-#9B9F, IRGKangXi=1469.030, RSKangXi=195.6, Def{anglerfish}
9BA0 CJK UNIFIED IDEOGRAPH-#9BA0, IRGKangXi=1469.070, RSKangXi=195.6, Def{a kind of shad with a head like a sturgeon}
9BA1 CJK UNIFIED IDEOGRAPH-#9BA1, IRGKangXi=1469.080, RSKangXi=195.6
9BA2 CJK UNIFIED IDEOGRAPH-#9BA2, IRGKangXi=1469.100, RSKangXi=195.6
9BA3 CJK UNIFIED IDEOGRAPH-#9BA3, IRGKangXi=1469.110, RSKangXi=195.5
9BA4 CJK UNIFIED IDEOGRAPH-#9BA4, IRGKangXi=1469.120, RSKangXi=195.6
9BA5 CJK UNIFIED IDEOGRAPH-#9BA5, IRGKangXi=1469.140, RSKangXi=195.6
9BA6 CJK UNIFIED IDEOGRAPH-#9BA6, IRGKangXi=1469.150, RSKangXi=195.6, Def{snakefish}
9BA7 CJK UNIFIED IDEOGRAPH-#9BA7, IRGKangXi=1469.160, RSKangXi=195.6, Def{the sheat fish}
9BA8 CJK UNIFIED IDEOGRAPH-#9BA8, IRGKangXi=1469.170, RSKangXi=195.6, Def{seasoned rice mixed with fish or vegetables}
9BA9 CJK UNIFIED IDEOGRAPH-#9BA9, IRGKangXi=1469.190, RSKangXi=195.6
9BAA CJK UNIFIED IDEOGRAPH-#9BAA, IRGKangXi=1469.210, RSKangXi=195.6, Def{kind of sturgeon, tuna}
9BAB CJK UNIFIED IDEOGRAPH-#9BAB, IRGKangXi=1469.220, RSKangXi=195.6, Def{shark}
9BAC CJK UNIFIED IDEOGRAPH-#9BAC, IRGKangXi=1470.030, RSKangXi=195.6
9BAD CJK UNIFIED IDEOGRAPH-#9BAD, IRGKangXi=1470.050, RSKangXi=195.6, Def{salmon; spheroides vermicularis}
9BAE CJK UNIFIED IDEOGRAPH-#9BAE, IRGKangXi=1470.060, RSKangXi=195.6, Def{fresh, new, delicious; rare, few}
9BAF CJK UNIFIED IDEOGRAPH-#9BAF, IRGKangXi=1470.070, RSKangXi=195.6
9BB0 CJK UNIFIED IDEOGRAPH-#9BB0, IRGKangXi=1470.101, RSKangXi=195.6, Def{a small sturgeon found in the Yangzi; catfish}
9BB1 CJK UNIFIED IDEOGRAPH-#9BB1, IRGKangXi=1470.101, RSKangXi=195.6
9BB2 CJK UNIFIED IDEOGRAPH-#9BB2, IRGKangXi=1470.101, RSKangXi=195.6
9BB3 CJK UNIFIED IDEOGRAPH-#9BB3, IRGKangXi=1470.101, RSKangXi=195.6
9BB4 CJK UNIFIED IDEOGRAPH-#9BB4, IRGKangXi=1470.101, RSKangXi=195.6
9BB5 CJK UNIFIED IDEOGRAPH-#9BB5, IRGKangXi=1470.110, RSKangXi=195.7
9BB6 CJK UNIFIED IDEOGRAPH-#9BB6, IRGKangXi=1470.120, RSKangXi=195.7
9BB7 CJK UNIFIED IDEOGRAPH-#9BB7, IRGKangXi=1470.170, RSKangXi=195.7
9BB8 CJK UNIFIED IDEOGRAPH-#9BB8, IRGKangXi=1470.180, RSKangXi=195.7, Def{Sciaena albiflora; otolithoidesmiiuy}
9BB9 CJK UNIFIED IDEOGRAPH-#9BB9, IRGKangXi=1470.190, RSKangXi=195.7, Def{an octopus, devilfish}
9BBA CJK UNIFIED IDEOGRAPH-#9BBA, IRGKangXi=1470.210, RSKangXi=195.6
9BBB CJK UNIFIED IDEOGRAPH-#9BBB, IRGKangXi=1470.220, RSKangXi=195.7, Def{dace; Canton dace}
9BBC CJK UNIFIED IDEOGRAPH-#9BBC, IRGKangXi=1470.230, RSKangXi=195.7
9BBD CJK UNIFIED IDEOGRAPH-#9BBD, IRGKangXi=1470.270, RSKangXi=195.7
9BBE CJK UNIFIED IDEOGRAPH-#9BBE, IRGKangXi=1470.280, RSKangXi=195.7
9BBF CJK UNIFIED IDEOGRAPH-#9BBF, IRGKangXi=1471.010, RSKangXi=195.7, Def{dried fish}
9BC0 CJK UNIFIED IDEOGRAPH-#9BC0, IRGKangXi=1471.030, RSKangXi=195.7, Def{giant fish; father of the emperor Yu}
9BC1 CJK UNIFIED IDEOGRAPH-#9BC1, IRGKangXi=1471.060, RSKangXi=195.7, Def{fish bones; honest, upright}
9BC2 CJK UNIFIED IDEOGRAPH-#9BC2, IRGKangXi=1471.080, RSKangXi=195.7
9BC3 CJK UNIFIED IDEOGRAPH-#9BC3, IRGKangXi=1471.090, RSKangXi=195.7
9BC4 CJK UNIFIED IDEOGRAPH-#9BC4, IRGKangXi=1471.100, RSKangXi=195.7
9BC5 CJK UNIFIED IDEOGRAPH-#9BC5, IRGKangXi=1471.110, RSKangXi=195.7
9BC6 CJK UNIFIED IDEOGRAPH-#9BC6, IRGKangXi=1471.120, RSKangXi=195.7, Def{the skate or ray}
9BC7 CJK UNIFIED IDEOGRAPH-#9BC7, IRGKangXi=1471.130, RSKangXi=195.7, Def{carp}
9BC8 CJK UNIFIED IDEOGRAPH-#9BC8, IRGKangXi=1471.140, RSKangXi=195.7, Def{fish}
9BC9 CJK UNIFIED IDEOGRAPH-#9BC9, IRGKangXi=1471.170, RSKangXi=195.7, Def{carp}
9BCA CJK UNIFIED IDEOGRAPH-#9BCA, IRGKangXi=1471.210, RSKangXi=195.7, Def{shark}
9BCB CJK UNIFIED IDEOGRAPH-#9BCB, IRGKangXi=1471.220, Def{shark}
9BCC CJK UNIFIED IDEOGRAPH-#9BCC, IRGKangXi=1471.280, RSKangXi=195.7
9BCD CJK UNIFIED IDEOGRAPH-#9BCD, IRGKangXi=1471.281, RSKangXi=195.7
9BCE CJK UNIFIED IDEOGRAPH-#9BCE, IRGKangXi=1471.281, RSKangXi=195.7
9BCF CJK UNIFIED IDEOGRAPH-#9BCF, IRGKangXi=1471.281, RSKangXi=195.7, Def{dialect name for a (bad tasting) blood clam}
9BD0 CJK UNIFIED IDEOGRAPH-#9BD0, IRGKangXi=1471.281, RSKangXi=195.7
9BD1 CJK UNIFIED IDEOGRAPH-#9BD1, IRGKangXi=1471.281, RSKangXi=195.7
9BD2 CJK UNIFIED IDEOGRAPH-#9BD2, IRGKangXi=1471.281, RSKangXi=195.7, Def{a flathead (fish)}
9BD3 CJK UNIFIED IDEOGRAPH-#9BD3, IRGKangXi=1471.281, RSKangXi=195.7
9BD4 CJK UNIFIED IDEOGRAPH-#9BD4, IRGKangXi=1472.010, RSKangXi=195.8, Def{mullet}
9BD5 CJK UNIFIED IDEOGRAPH-#9BD5, IRGKangXi=1472.020, RSKangXi=195.8, Def{coryphaena hippurus}
9BD6 CJK UNIFIED IDEOGRAPH-#9BD6, IRGKangXi=1472.030, RSKangXi=195.8, Def{mackerel}
9BD7 CJK UNIFIED IDEOGRAPH-#9BD7, IRGKangXi=1472.040, RSKangXi=195.8, Def{dried fish}
9BD8 CJK UNIFIED IDEOGRAPH-#9BD8, IRGKangXi=1472.060, RSKangXi=195.8
9BD9 CJK UNIFIED IDEOGRAPH-#9BD9, IRGKangXi=1472.140, RSKangXi=195.8, Def{Scomberomorus sinensis}
9BDA CJK UNIFIED IDEOGRAPH-#9BDA, IRGKangXi=1472.160, RSKangXi=195.8
9BDB CJK UNIFIED IDEOGRAPH-#9BDB, IRGKangXi=1472.180, RSKangXi=195.8, Def{pagrosomus major, porgy}
9BDC CJK UNIFIED IDEOGRAPH-#9BDC, IRGKangXi=1472.190, RSKangXi=195.8
9BDD CJK UNIFIED IDEOGRAPH-#9BDD, IRGKangXi=1472.260, RSKangXi=195.8, Def{fish guts}
9BDE CJK UNIFIED IDEOGRAPH-#9BDE, IRGKangXi=1472.280, RSKangXi=195.8
9BDF CJK UNIFIED IDEOGRAPH-#9BDF, IRGKangXi=1472.290, RSKangXi=195.8
9BE0 CJK UNIFIED IDEOGRAPH-#9BE0, IRGKangXi=1472.330, RSKangXi=195.8, Def{to confer; to bestow on an inferior; to reward}
9BE1 CJK UNIFIED IDEOGRAPH-#9BE1, IRGKangXi=1472.350, RSKangXi=195.8, Def{herring}
9BE2 CJK UNIFIED IDEOGRAPH-#9BE2, IRGKangXi=1472.370, RSKangXi=195.8, Def{Cryptobranchus japonicus; a salamander}
9BE3 CJK UNIFIED IDEOGRAPH-#9BE3, IRGKangXi=1472.380, RSKangXi=195.8, Def{a cuttlefish}
9BE4 CJK UNIFIED IDEOGRAPH-#9BE4, IRGKangXi=1473.020, RSKangXi=195.8, Def{spawn; roe; fy}
9BE5 CJK UNIFIED IDEOGRAPH-#9BE5, IRGKangXi=1473.040, RSKangXi=195.8
9BE6 CJK UNIFIED IDEOGRAPH-#9BE6, IRGKangXi=1473.090, RSKangXi=195.8
9BE7 CJK UNIFIED IDEOGRAPH-#9BE7, IRGKangXi=1473.100, RSKangXi=195.8, Def{the silvery pomfret, Stromateoides argenteus}
9BE8 CJK UNIFIED IDEOGRAPH-#9BE8, IRGKangXi=1473.120, RSKangXi=195.8, Def{whale}
9BE9 CJK UNIFIED IDEOGRAPH-#9BE9, IRGKangXi=1473.130, RSKangXi=195.8
9BEA CJK UNIFIED IDEOGRAPH-#9BEA, IRGKangXi=1473.140, RSKangXi=195.8, Def{carp}
9BEB CJK UNIFIED IDEOGRAPH-#9BEB, IRGKangXi=1473.150, RSKangXi=195.8, Def{small fish; small; minnow}
9BEC CJK UNIFIED IDEOGRAPH-#9BEC, IRGKangXi=1473.170, RSKangXi=195.8
9BED CJK UNIFIED IDEOGRAPH-#9BED, IRGKangXi=1473.180, RSKangXi=195.8, Def{(Cant.) 泥鯭, a kind of fish that lives in turbid water}
9BEE CJK UNIFIED IDEOGRAPH-#9BEE, IRGKangXi=1473.210, RSKangXi=195.8
9BEF CJK UNIFIED IDEOGRAPH-#9BEF, IRGKangXi=1473.271, RSKangXi=195.8
9BF0 CJK UNIFIED IDEOGRAPH-#9BF0, IRGKangXi=1473.271, RSKangXi=195.8, Def{sheat}
9BF1 CJK UNIFIED IDEOGRAPH-#9BF1, IRGKangXi=1473.271, RSKangXi=195.8, Def{mythical dolphin-like fish}
9BF2 CJK UNIFIED IDEOGRAPH-#9BF2, IRGKangXi=1473.271, RSKangXi=195.8
9BF3 CJK UNIFIED IDEOGRAPH-#9BF3, IRGKangXi=1473.271, RSKangXi=195.8
9BF4 CJK UNIFIED IDEOGRAPH-#9BF4, IRGKangXi=1473.271, RSKangXi=195.8, Def{cat fish}
9BF5 CJK UNIFIED IDEOGRAPH-#9BF5, IRGKangXi=1473.271, RSKangXi=195.8
9BF6 CJK UNIFIED IDEOGRAPH-#9BF6, IRGKangXi=1473.280, RSKangXi=195.9
9BF7 CJK UNIFIED IDEOGRAPH-#9BF7, IRGKangXi=1473.290, RSKangXi=195.9, Def{anchovy}
9BF8 CJK UNIFIED IDEOGRAPH-#9BF8, IRGKangXi=1473.300, RSKangXi=195.9, Def{blowfish}
9BF9 CJK UNIFIED IDEOGRAPH-#9BF9, IRGKangXi=1473.320, RSKangXi=195.9
9BFA CJK UNIFIED IDEOGRAPH-#9BFA, IRGKangXi=1473.350, RSKangXi=195.9, Def{blowfish}
9BFB CJK UNIFIED IDEOGRAPH-#9BFB, IRGKangXi=1474.010, RSKangXi=195.8
9BFC CJK UNIFIED IDEOGRAPH-#9BFC, IRGKangXi=1474.050, RSKangXi=195.9
9BFD CJK UNIFIED IDEOGRAPH-#9BFD, IRGKangXi=1474.060, RSKangXi=195.9, Def{Carassius auratus, crucian carp}
9BFE CJK UNIFIED IDEOGRAPH-#9BFE, IRGKangXi=1474.070, RSKangXi=195.9
9BFF CJK UNIFIED IDEOGRAPH-#9BFF, IRGKangXi=1474.080, RSKangXi=195.9, Def{bream}
9C00 CJK UNIFIED IDEOGRAPH-#9C00, IRGKangXi=1474.090, RSKangXi=195.9
9C01 CJK UNIFIED IDEOGRAPH-#9C01, IRGKangXi=1474.100, RSKangXi=195.9, Def{name of fish}
9C02 CJK UNIFIED IDEOGRAPH-#9C02, IRGKangXi=1474.110, RSKangXi=195.9, Def{cuttlefish}
9C03 CJK UNIFIED IDEOGRAPH-#9C03, IRGKangXi=1474.150, RSKangXi=195.9, Def{name of fish}
9C04 CJK UNIFIED IDEOGRAPH-#9C04, IRGKangXi=1474.160, RSKangXi=195.9
9C05 CJK UNIFIED IDEOGRAPH-#9C05, IRGKangXi=1474.170, RSKangXi=195.9
9C06 CJK UNIFIED IDEOGRAPH-#9C06, IRGKangXi=1474.190, RSKangXi=195.9, Def{Scomberomorus sinensis}
9C07 CJK UNIFIED IDEOGRAPH-#9C07, IRGKangXi=1474.210, RSKangXi=195.9
9C08 CJK UNIFIED IDEOGRAPH-#9C08, IRGKangXi=1474.240, RSKangXi=195.9, Def{flatfish; flounder; sole}
9C09 CJK UNIFIED IDEOGRAPH-#9C09, IRGKangXi=1474.250, RSKangXi=195.9, Def{sturgeon}
9C0A CJK UNIFIED IDEOGRAPH-#9C0A, IRGKangXi=1474.270, RSKangXi=195.9, Def{a herring}
9C0B CJK UNIFIED IDEOGRAPH-#9C0B, IRGKangXi=1474.280, RSKangXi=195.9, Def{sheat}
9C0C CJK UNIFIED IDEOGRAPH-#9C0C, IRGKangXi=1474.320, RSKangXi=195.9, Def{loach; squid; lizard; eel}
9C0D CJK UNIFIED IDEOGRAPH-#9C0D, IRGKangXi=1474.330, RSKangXi=195.9, Def{loach}
9C0E CJK UNIFIED IDEOGRAPH-#9C0E, IRGKangXi=1474.340, RSKangXi=195.9
9C0F CJK UNIFIED IDEOGRAPH-#9C0F, IRGKangXi=1474.380, RSKangXi=195.9
9C10 CJK UNIFIED IDEOGRAPH-#9C10, IRGKangXi=1475.010, RSKangXi=195.9, Def{alligator}
9C11 CJK UNIFIED IDEOGRAPH-#9C11, IRGKangXi=1475.030, RSKangXi=195.9
9C12 CJK UNIFIED IDEOGRAPH-#9C12, IRGKangXi=1475.040, RSKangXi=195.9, Def{abalone}
9C13 CJK UNIFIED IDEOGRAPH-#9C13, IRGKangXi=1475.080, RSKangXi=195.9, Def{fish gills}
9C14 CJK UNIFIED IDEOGRAPH-#9C14, IRGKangXi=1475.090, RSKangXi=195.9
9C15 CJK UNIFIED IDEOGRAPH-#9C15, IRGKangXi=1475.100, RSKangXi=195.9, Def{shrimp, prawn}
9C16 CJK UNIFIED IDEOGRAPH-#9C16, IRGKangXi=1475.110, RSKangXi=195.9
9C17 CJK UNIFIED IDEOGRAPH-#9C17, IRGKangXi=1475.140, RSKangXi=195.9
9C18 CJK UNIFIED IDEOGRAPH-#9C18, IRGKangXi=1475.161, RSKangXi=195.9
9C19 CJK UNIFIED IDEOGRAPH-#9C19, IRGKangXi=1475.161, RSKangXi=195.9
9C1A CJK UNIFIED IDEOGRAPH-#9C1A, IRGKangXi=1475.161, RSKangXi=195.9
9C1B CJK UNIFIED IDEOGRAPH-#9C1B, IRGKangXi=1475.161, RSKangXi=195.9, Def{sardine}
9C1C CJK UNIFIED IDEOGRAPH-#9C1C, IRGKangXi=1475.170, RSKangXi=195.10, Def{big-mouthed flounder}
9C1D CJK UNIFIED IDEOGRAPH-#9C1D, IRGKangXi=1475.200, RSKangXi=195.10
9C1E CJK UNIFIED IDEOGRAPH-#9C1E, IRGKangXi=1475.220, RSKangXi=195.10, Def{squid}
9C1F CJK UNIFIED IDEOGRAPH-#9C1F, IRGKangXi=1475.300, RSKangXi=195.10
9C20 CJK UNIFIED IDEOGRAPH-#9C20, IRGKangXi=1475.310, RSKangXi=195.9, Def{carp}
9C21 CJK UNIFIED IDEOGRAPH-#9C21, IRGKangXi=1475.330, RSKangXi=195.10
9C22 CJK UNIFIED IDEOGRAPH-#9C22, IRGKangXi=1475.350, RSKangXi=195.10
9C23 CJK UNIFIED IDEOGRAPH-#9C23, IRGKangXi=1475.360, RSKangXi=195.10, Def{reeves' shad; hilsa herring}
9C24 CJK UNIFIED IDEOGRAPH-#9C24, IRGKangXi=1475.390, RSKangXi=195.10, Def{a yellowtail (fish)}
9C25 CJK UNIFIED IDEOGRAPH-#9C25, IRGKangXi=1475.400, RSKangXi=195.10, Def{huge fish; widower; bachelor}
9C26 CJK UNIFIED IDEOGRAPH-#9C26, IRGKangXi=1476.010, RSKangXi=195.10
9C27 CJK UNIFIED IDEOGRAPH-#9C27, IRGKangXi=1476.050, RSKangXi=195.10
9C28 CJK UNIFIED IDEOGRAPH-#9C28, IRGKangXi=1476.060, RSKangXi=195.10, Def{sole}
9C29 CJK UNIFIED IDEOGRAPH-#9C29, IRGKangXi=1476.080, RSKangXi=195.10, Def{the nautilus; the ray}
9C2A CJK UNIFIED IDEOGRAPH-#9C2A, IRGKangXi=1476.130, RSKangXi=195.10
9C2B CJK UNIFIED IDEOGRAPH-#9C2B, IRGKangXi=1476.140, RSKangXi=195.10
9C2C CJK UNIFIED IDEOGRAPH-#9C2C, IRGKangXi=1476.160, RSKangXi=195.10
9C2D CJK UNIFIED IDEOGRAPH-#9C2D, IRGKangXi=1476.170, RSKangXi=195.10, Def{fin}
9C2E CJK UNIFIED IDEOGRAPH-#9C2E, IRGKangXi=1476.200, RSKangXi=195.10, Def{sardine}
9C2F CJK UNIFIED IDEOGRAPH-#9C2F, IRGKangXi=1476.251, RSKangXi=195.10, Def{a sardine}
9C30 CJK UNIFIED IDEOGRAPH-#9C30, IRGKangXi=1476.251, RSKangXi=195.10
9C31 CJK UNIFIED IDEOGRAPH-#9C31, IRGKangXi=1476.260, RSKangXi=195.11, Def{silver carp, hypophthalmiathys}
9C32 CJK UNIFIED IDEOGRAPH-#9C32, IRGKangXi=1476.270, RSKangXi=195.11, Def{huge sea turtle}
9C33 CJK UNIFIED IDEOGRAPH-#9C33, IRGKangXi=1476.310, RSKangXi=195.11, Def{Chinese herring; shad}
9C34 CJK UNIFIED IDEOGRAPH-#9C34, IRGKangXi=1476.330, RSKangXi=195.11
9C35 CJK UNIFIED IDEOGRAPH-#9C35, IRGKangXi=1476.360, RSKangXi=195.11, Def{codfish}
9C36 CJK UNIFIED IDEOGRAPH-#9C36, IRGKangXi=1476.400, RSKangXi=195.11
9C37 CJK UNIFIED IDEOGRAPH-#9C37, IRGKangXi=1476.410, RSKangXi=195.11, Def{minnow}
9C38 CJK UNIFIED IDEOGRAPH-#9C38, IRGKangXi=1477.010, RSKangXi=195.11
9C39 CJK UNIFIED IDEOGRAPH-#9C39, IRGKangXi=1477.020, RSKangXi=195.11, Def{skipjack, bonito}
9C3A CJK UNIFIED IDEOGRAPH-#9C3A, IRGKangXi=1477.060, RSKangXi=195.11, Def{a horse mackerel}
9C3B CJK UNIFIED IDEOGRAPH-#9C3B, IRGKangXi=1477.070, RSKangXi=195.11, Def{eel}
9C3C CJK UNIFIED IDEOGRAPH-#9C3C, IRGKangXi=1477.080, RSKangXi=195.11, Def{the weather or dojo loach, Misgurnus anguillicaudatus}
9C3D CJK UNIFIED IDEOGRAPH-#9C3D, IRGKangXi=1477.090, RSKangXi=195.11, Def{herring}
9C3E CJK UNIFIED IDEOGRAPH-#9C3E, IRGKangXi=1477.110, RSKangXi=195.11, Def{swimming bladder of fish}
9C3F CJK UNIFIED IDEOGRAPH-#9C3F, IRGKangXi=1477.140, RSKangXi=195.11
9C40 CJK UNIFIED IDEOGRAPH-#9C40, IRGKangXi=1477.160, RSKangXi=195.11
9C41 CJK UNIFIED IDEOGRAPH-#9C41, IRGKangXi=1477.180, RSKangXi=195.11
9C42 CJK UNIFIED IDEOGRAPH-#9C42, IRGKangXi=1477.200, RSKangXi=195.11, Def{name of fish}
9C43 CJK UNIFIED IDEOGRAPH-#9C43, IRGKangXi=1477.210, RSKangXi=195.11
9C44 CJK UNIFIED IDEOGRAPH-#9C44, IRGKangXi=1477.230, RSKangXi=195.11, Def{anchovy}
9C45 CJK UNIFIED IDEOGRAPH-#9C45, IRGKangXi=1477.240, RSKangXi=195.11, Def{a kind of tench}
9C46 CJK UNIFIED IDEOGRAPH-#9C46, IRGKangXi=1477.290, RSKangXi=195.11, Def{an octopus, devilfish}
9C47 CJK UNIFIED IDEOGRAPH-#9C47, IRGKangXi=1477.301, RSKangXi=195.11, Def{anglerfish}
9C48 CJK UNIFIED IDEOGRAPH-#9C48, IRGKangXi=1477.301, RSKangXi=195.11, Def{codfish}
9C49 CJK UNIFIED IDEOGRAPH-#9C49, IRGKangXi=1477.310, RSKangXi=195.12, Def{turtle}
9C4A CJK UNIFIED IDEOGRAPH-#9C4A, IRGKangXi=1477.320, RSKangXi=195.12
9C4B CJK UNIFIED IDEOGRAPH-#9C4B, IRGKangXi=1477.330, RSKangXi=195.12
9C4C CJK UNIFIED IDEOGRAPH-#9C4C, IRGKangXi=1478.040, RSKangXi=195.12
9C4D CJK UNIFIED IDEOGRAPH-#9C4D, IRGKangXi=1478.050, RSKangXi=195.12
9C4E CJK UNIFIED IDEOGRAPH-#9C4E, IRGKangXi=1478.070, RSKangXi=195.12
9C4F CJK UNIFIED IDEOGRAPH-#9C4F, IRGKangXi=1478.080, RSKangXi=195.12, Def{a ray, skate}
9C50 CJK UNIFIED IDEOGRAPH-#9C50, IRGKangXi=1478.090, RSKangXi=195.12, Def{dried fish}
9C51 CJK UNIFIED IDEOGRAPH-#9C51, IRGKangXi=1478.100, RSKangXi=195.12, Def{the sturgeon}
9C52 CJK UNIFIED IDEOGRAPH-#9C52, IRGKangXi=1478.120, RSKangXi=195.12, Def{barbel}
9C53 CJK UNIFIED IDEOGRAPH-#9C53, IRGKangXi=1478.160, RSKangXi=195.12, Def{eel}
9C54 CJK UNIFIED IDEOGRAPH-#9C54, IRGKangXi=1478.190, RSKangXi=195.12, Def{eel}
9C55 CJK UNIFIED IDEOGRAPH-#9C55, IRGKangXi=1478.200, RSKangXi=195.12
9C56 CJK UNIFIED IDEOGRAPH-#9C56, IRGKangXi=1478.210, RSKangXi=195.12, Def{mandarin fish}
9C57 CJK UNIFIED IDEOGRAPH-#9C57, IRGKangXi=1478.220, RSKangXi=195.12, Def{fish scales}
9C58 CJK UNIFIED IDEOGRAPH-#9C58, IRGKangXi=1478.240, RSKangXi=195.12, Def{sturgeon}
9C59 CJK UNIFIED IDEOGRAPH-#9C59, IRGKangXi=1478.290, RSKangXi=195.12
9C5A CJK UNIFIED IDEOGRAPH-#9C5A, IRGKangXi=1478.311, RSKangXi=195.12
9C5B CJK UNIFIED IDEOGRAPH-#9C5B, IRGKangXi=1478.311, RSKangXi=195.12, Def{fish name}
9C5C CJK UNIFIED IDEOGRAPH-#9C5C, IRGKangXi=1479.261, RSKangXi=195.13
9C5D CJK UNIFIED IDEOGRAPH-#9C5D, IRGKangXi=1478.320, RSKangXi=195.13, Def{fish}
9C5E CJK UNIFIED IDEOGRAPH-#9C5E, IRGKangXi=1478.330, RSKangXi=195.13
9C5F CJK UNIFIED IDEOGRAPH-#9C5F, IRGKangXi=1478.400, RSKangXi=195.13, Def{king crab}
9C60 CJK UNIFIED IDEOGRAPH-#9C60, IRGKangXi=1479.020, RSKangXi=195.13, Def{minced fish; hash}
9C61 CJK UNIFIED IDEOGRAPH-#9C61, IRGKangXi=1479.030, RSKangXi=195.13, Def{the cuttle-fish}
9C62 CJK UNIFIED IDEOGRAPH-#9C62, IRGKangXi=1479.040, RSKangXi=195.13
9C63 CJK UNIFIED IDEOGRAPH-#9C63, IRGKangXi=1479.050, RSKangXi=195.13, Def{sturgeon}
9C64 CJK UNIFIED IDEOGRAPH-#9C64, IRGKangXi=1479.060, RSKangXi=195.13
9C65 CJK UNIFIED IDEOGRAPH-#9C65, IRGKangXi=1479.080, RSKangXi=195.13
9C66 CJK UNIFIED IDEOGRAPH-#9C66, IRGKangXi=1479.130, RSKangXi=195.13
9C67 CJK UNIFIED IDEOGRAPH-#9C67, IRGKangXi=1479.140, RSKangXi=195.13, Def{snakehead}
9C68 CJK UNIFIED IDEOGRAPH-#9C68, IRGKangXi=1479.180, RSKangXi=195.14, Def{codfish}
9C69 CJK UNIFIED IDEOGRAPH-#9C69, IRGKangXi=1479.261, RSKangXi=195.13
9C6A CJK UNIFIED IDEOGRAPH-#9C6A, IRGKangXi=1479.261, RSKangXi=195.13
9C6B CJK UNIFIED IDEOGRAPH-#9C6B, IRGKangXi=1479.261, RSKangXi=195.13
9C6C CJK UNIFIED IDEOGRAPH-#9C6C, IRGKangXi=1479.290, RSKangXi=195.14
9C6D CJK UNIFIED IDEOGRAPH-#9C6D, IRGKangXi=1479.330, RSKangXi=195.14, Def{anchovy}
9C6E CJK UNIFIED IDEOGRAPH-#9C6E, IRGKangXi=1479.340, RSKangXi=195.14, Def{silver carp (Hypophthalmichthys molitrix); bream; (Cant.) 大嶼山 daai6ju4saan1 Lantau Island}
9C6F CJK UNIFIED IDEOGRAPH-#9C6F, IRGKangXi=1479.350, RSKangXi=195.14
9C70 CJK UNIFIED IDEOGRAPH-#9C70, IRGKangXi=1480.071, RSKangXi=195.14
9C71 CJK UNIFIED IDEOGRAPH-#9C71, IRGKangXi=1480.110, RSKangXi=195.15
9C72 CJK UNIFIED IDEOGRAPH-#9C72, IRGKangXi=1480.130, RSKangXi=195.15, Def{(Cant.) 赤鱲角, Hong Kong place name}
9C73 CJK UNIFIED IDEOGRAPH-#9C73, IRGKangXi=1480.140, RSKangXi=195.15
9C74 CJK UNIFIED IDEOGRAPH-#9C74, IRGKangXi=1480.150, RSKangXi=195.15
9C75 CJK UNIFIED IDEOGRAPH-#9C75, IRGKangXi=1480.160, RSKangXi=195.15
9C76 CJK UNIFIED IDEOGRAPH-#9C76, IRGKangXi=1480.170, RSKangXi=195.15, Def{a shark}
9C77 CJK UNIFIED IDEOGRAPH-#9C77, IRGKangXi=1480.220, RSKangXi=195.16, Def{crocodile, alligator}
9C78 CJK UNIFIED IDEOGRAPH-#9C78, IRGKangXi=1480.240, RSKangXi=195.16, Def{sea perch, sea bass}
9C79 CJK UNIFIED IDEOGRAPH-#9C79, IRGKangXi=1480.390, RSKangXi=195.18
9C7A CJK UNIFIED IDEOGRAPH-#9C7A, IRGKangXi=1480.450, RSKangXi=195.19, Def{eel}
9C7B CJK UNIFIED IDEOGRAPH-#9C7B, IRGKangXi=1480.500, RSKangXi=195.22, Def{fresh, new, delicious; rare, few}
9C7C CJK UNIFIED IDEOGRAPH-#9C7C, IRGKangXi=1480.511, RSKangXi=195.0, Def{fish; surname; KangXi radical 195}
9C7D CJK UNIFIED IDEOGRAPH-#9C7D, IRGKangXi=1480.511, RSKangXi=195.2, Def{the mullet}
9C7E CJK UNIFIED IDEOGRAPH-#9C7E, IRGKangXi=1480.511, RSKangXi=195.3, Def{name of fish}
9C7F CJK UNIFIED IDEOGRAPH-#9C7F, IRGKangXi=1480.511, RSKangXi=195.4, Def{cuttlefish}
9C80 CJK UNIFIED IDEOGRAPH-#9C80, IRGKangXi=1480.511, RSKangXi=195.4, Def{blowfish, globefish, Spheroides vermicular}
9C81 CJK UNIFIED IDEOGRAPH-#9C81, IRGKangXi=1480.511, RSKangXi=195.4, Def{foolish, stupid, rash; vulgar}
9C82 CJK UNIFIED IDEOGRAPH-#9C82, IRGKangXi=1480.511, RSKangXi=195.4, Def{bream}
9C83 CJK UNIFIED IDEOGRAPH-#9C83, IRGKangXi=1480.511, RSKangXi=195.4, Def{a kind of fish; a bonito, (same as 鮁) shark}
9C84 CJK UNIFIED IDEOGRAPH-#9C84, IRGKangXi=1480.511, RSKangXi=195.5
9C85 CJK UNIFIED IDEOGRAPH-#9C85, IRGKangXi=1480.511, RSKangXi=195.5, Def{fish name}
9C86 CJK UNIFIED IDEOGRAPH-#9C86, IRGKangXi=1480.511, RSKangXi=195.5, Def{sole}
9C87 CJK UNIFIED IDEOGRAPH-#9C87, IRGKangXi=1480.511, RSKangXi=195.5, Def{sheatfish, parasilurus asotus}
9C88 CJK UNIFIED IDEOGRAPH-#9C88, IRGKangXi=1480.511, RSKangXi=195.5, Def{sea perch, sea bass}
9C89 CJK UNIFIED IDEOGRAPH-#9C89, IRGKangXi=1480.511, RSKangXi=195.5
9C8A CJK UNIFIED IDEOGRAPH-#9C8A, IRGKangXi=1480.511, RSKangXi=195.5, Def{minced and salted fish; to preserve}
9C8B CJK UNIFIED IDEOGRAPH-#9C8B, IRGKangXi=1480.511, RSKangXi=195.5, Def{carp, carassicus auratus}
9C8C CJK UNIFIED IDEOGRAPH-#9C8C, IRGKangXi=1480.511, RSKangXi=195.5
9C8D CJK UNIFIED IDEOGRAPH-#9C8D, IRGKangXi=1480.511, RSKangXi=195.5, Def{abalone; dried fish; surname}
9C8E CJK UNIFIED IDEOGRAPH-#9C8E, IRGKangXi=1480.511, RSKangXi=195.5, Def{king crab}
9C8F CJK UNIFIED IDEOGRAPH-#9C8F, IRGKangXi=1480.511, RSKangXi=195.5
9C90 CJK UNIFIED IDEOGRAPH-#9C90, IRGKangXi=1480.511, RSKangXi=195.5, Def{globefish, tetraodon}
9C91 CJK UNIFIED IDEOGRAPH-#9C91, IRGKangXi=1480.511, RSKangXi=195.6, Def{salmon; spheroides vermicularis}
9C92 CJK UNIFIED IDEOGRAPH-#9C92, IRGKangXi=1480.511, RSKangXi=195.6, Def{clam; oyster}
9C93 CJK UNIFIED IDEOGRAPH-#9C93, IRGKangXi=1480.511, RSKangXi=195.6
9C94 CJK UNIFIED IDEOGRAPH-#9C94, IRGKangXi=1480.511, RSKangXi=195.6, Def{kind of sturgeon, tuna}
9C95 CJK UNIFIED IDEOGRAPH-#9C95, IRGKangXi=1480.511, RSKangXi=195.6, Def{roe}
9C96 CJK UNIFIED IDEOGRAPH-#9C96, IRGKangXi=1480.511, RSKangXi=195.6, Def{snakefish}
9C97 CJK UNIFIED IDEOGRAPH-#9C97, IRGKangXi=1480.511, RSKangXi=195.6, Def{cuttlefish}
9C98 CJK UNIFIED IDEOGRAPH-#9C98, IRGKangXi=1480.511
9C99 CJK UNIFIED IDEOGRAPH-#9C99, IRGKangXi=1480.511, RSKangXi=195.6, Def{minced fish; hash}
9C9A CJK UNIFIED IDEOGRAPH-#9C9A, IRGKangXi=1480.511, RSKangXi=195.6, Def{anchovy}
9C9B CJK UNIFIED IDEOGRAPH-#9C9B, IRGKangXi=1480.511, RSKangXi=195.6, Def{shark}
9C9C CJK UNIFIED IDEOGRAPH-#9C9C, IRGKangXi=1480.511, RSKangXi=195.6, Def{fresh; delicious; attractive}
9C9D CJK UNIFIED IDEOGRAPH-#9C9D, IRGKangXi=1480.511, RSKangXi=195.6
9C9E CJK UNIFIED IDEOGRAPH-#9C9E, IRGKangXi=1480.511, RSKangXi=195.6, Def{dried fish}
9C9F CJK UNIFIED IDEOGRAPH-#9C9F, IRGKangXi=1480.511, RSKangXi=195.6, Def{sturgeon}
9CA0 CJK UNIFIED IDEOGRAPH-#9CA0, IRGKangXi=1480.511, RSKangXi=195.7, Def{fish bones; honest, upright}
9CA1 CJK UNIFIED IDEOGRAPH-#9CA1, IRGKangXi=1480.511, RSKangXi=195.7, Def{eel}
9CA2 CJK UNIFIED IDEOGRAPH-#9CA2, IRGKangXi=1480.511, RSKangXi=195.8, Def{silver carp, hypophthalmiathys}
9CA3 CJK UNIFIED IDEOGRAPH-#9CA3, IRGKangXi=1480.511, RSKangXi=195.7, Def{skipjack, bonito}
9CA4 CJK UNIFIED IDEOGRAPH-#9CA4, IRGKangXi=1480.511, RSKangXi=195.7, Def{carp}
9CA5 CJK UNIFIED IDEOGRAPH-#9CA5, IRGKangXi=1480.511, RSKangXi=195.7, Def{reeves' shad; hilsa herring}
9CA6 CJK UNIFIED IDEOGRAPH-#9CA6, IRGKangXi=1480.511, RSKangXi=195.7, Def{minnow}
9CA7 CJK UNIFIED IDEOGRAPH-#9CA7, IRGKangXi=1480.511, RSKangXi=195.7, Def{giant fish; father of emperor}
9CA8 CJK UNIFIED IDEOGRAPH-#9CA8, IRGKangXi=1480.511, RSKangXi=195.7, Def{shark}
9CA9 CJK UNIFIED IDEOGRAPH-#9CA9, IRGKangXi=1480.511, RSKangXi=195.7, Def{carp}
9CAA CJK UNIFIED IDEOGRAPH-#9CAA, IRGKangXi=1480.511, RSKangXi=195.7
9CAB CJK UNIFIED IDEOGRAPH-#9CAB, IRGKangXi=1480.511, RSKangXi=195.7, Def{Carassius auratus, crucian carp}
9CAC CJK UNIFIED IDEOGRAPH-#9CAC, IRGKangXi=1480.511, RSKangXi=195.7, Def{a flathead (fish)}
9CAD CJK UNIFIED IDEOGRAPH-#9CAD, IRGKangXi=1480.511, RSKangXi=195.8, Def{mackerel}
9CAE CJK UNIFIED IDEOGRAPH-#9CAE, IRGKangXi=1480.511, RSKangXi=195.8, Def{carp}
9CAF CJK UNIFIED IDEOGRAPH-#9CAF, IRGKangXi=1480.511, RSKangXi=195.8, Def{coryphaena hippurus}
9CB0 CJK UNIFIED IDEOGRAPH-#9CB0, IRGKangXi=1480.511, RSKangXi=195.8, Def{small fish; small; minnow}
9CB1 CJK UNIFIED IDEOGRAPH-#9CB1, IRGKangXi=1480.511, RSKangXi=195.8, Def{herring}
9CB2 CJK UNIFIED IDEOGRAPH-#9CB2, IRGKangXi=1480.511, RSKangXi=195.8, Def{spawn; roe; fy}
9CB3 CJK UNIFIED IDEOGRAPH-#9CB3, IRGKangXi=1480.511, RSKangXi=195.8, Def{the silvery pomfret, Stromateoides argenteus}
9CB4 CJK UNIFIED IDEOGRAPH-#9CB4, IRGKangXi=1480.511, RSKangXi=195.8, Def{fish guts}
9CB5 CJK UNIFIED IDEOGRAPH-#9CB5, IRGKangXi=1480.511, RSKangXi=195.8, Def{Cryptobranchus japonicus; a salamander}
9CB6 CJK UNIFIED IDEOGRAPH-#9CB6, IRGKangXi=1480.511, RSKangXi=195.8, Def{sheat}
9CB7 CJK UNIFIED IDEOGRAPH-#9CB7, IRGKangXi=1480.511, RSKangXi=195.8, Def{pagrosomus major, porgy}
9CB8 CJK UNIFIED IDEOGRAPH-#9CB8, IRGKangXi=1480.511, RSKangXi=195.8, Def{whale}
9CB9 CJK UNIFIED IDEOGRAPH-#9CB9, IRGKangXi=1480.511, RSKangXi=195.8, Def{a horse mackerel}
9CBA CJK UNIFIED IDEOGRAPH-#9CBA, IRGKangXi=1480.511, RSKangXi=195.8, Def{cat fish}
9CBB CJK UNIFIED IDEOGRAPH-#9CBB, IRGKangXi=1480.511, RSKangXi=195.8, Def{mullet}
9CBC CJK UNIFIED IDEOGRAPH-#9CBC, IRGKangXi=1480.511, RSKangXi=195.9, Def{fish}
9CBD CJK UNIFIED IDEOGRAPH-#9CBD, IRGKangXi=1480.511, RSKangXi=195.9, Def{flatfish; flounder; sole}
9CBE CJK UNIFIED IDEOGRAPH-#9CBE, IRGKangXi=1480.511, RSKangXi=195.10
9CBF CJK UNIFIED IDEOGRAPH-#9CBF, IRGKangXi=1480.511, RSKangXi=195.9, Def{codfish}
9CC0 CJK UNIFIED IDEOGRAPH-#9CC0, IRGKangXi=1480.511, RSKangXi=195.9, Def{anchovy}
9CC1 CJK UNIFIED IDEOGRAPH-#9CC1, IRGKangXi=1480.511, RSKangXi=195.9, Def{sardine}
9CC2 CJK UNIFIED IDEOGRAPH-#9CC2, IRGKangXi=1480.511, RSKangXi=195.9, Def{name of fish}
9CC3 CJK UNIFIED IDEOGRAPH-#9CC3, IRGKangXi=1480.511, RSKangXi=195.9, Def{fish gills}
9CC4 CJK UNIFIED IDEOGRAPH-#9CC4, IRGKangXi=1480.511, RSKangXi=195.9, Def{alligator}
9CC5 CJK UNIFIED IDEOGRAPH-#9CC5, IRGKangXi=1480.511, RSKangXi=195.9, Def{loach}
9CC6 CJK UNIFIED IDEOGRAPH-#9CC6, IRGKangXi=1480.511, RSKangXi=195.9, Def{abalone}
9CC7 CJK UNIFIED IDEOGRAPH-#9CC7, IRGKangXi=1480.511, RSKangXi=195.9, Def{sturgeon}
9CC8 CJK UNIFIED IDEOGRAPH-#9CC8, IRGKangXi=1480.511, RSKangXi=195.9, Def{name of fish}
9CC9 CJK UNIFIED IDEOGRAPH-#9CC9, IRGKangXi=1480.511, RSKangXi=195.9, Def{name of fish}
9CCA CJK UNIFIED IDEOGRAPH-#9CCA, IRGKangXi=1480.511, RSKangXi=195.9, Def{bream}
9CCB CJK UNIFIED IDEOGRAPH-#9CCB, IRGKangXi=1480.511, RSKangXi=195.9, Def{carp}
9CCC CJK UNIFIED IDEOGRAPH-#9CCC, IRGKangXi=1480.511, RSKangXi=195.10, Def{huge sea turtle}
9CCD CJK UNIFIED IDEOGRAPH-#9CCD, IRGKangXi=1480.511, RSKangXi=195.10, Def{fin}
9CCE CJK UNIFIED IDEOGRAPH-#9CCE, IRGKangXi=1480.511, RSKangXi=195.10, Def{sole}
9CCF CJK UNIFIED IDEOGRAPH-#9CCF, IRGKangXi=1480.511, RSKangXi=195.10, Def{huge fish; widower; bachelor}
9CD0 CJK UNIFIED IDEOGRAPH-#9CD0, IRGKangXi=1480.511, RSKangXi=195.10, Def{the nautilus; the ray}
9CD1 CJK UNIFIED IDEOGRAPH-#9CD1, IRGKangXi=1480.511, RSKangXi=195.10
9CD2 CJK UNIFIED IDEOGRAPH-#9CD2, IRGKangXi=1480.511, RSKangXi=195.10, Def{big-mouthed flounder}
9CD3 CJK UNIFIED IDEOGRAPH-#9CD3, IRGKangXi=1480.511, RSKangXi=195.11, Def{Chinese herring; shad}
9CD4 CJK UNIFIED IDEOGRAPH-#9CD4, IRGKangXi=1480.511, RSKangXi=195.11, Def{swimming bladder of fish}
9CD5 CJK UNIFIED IDEOGRAPH-#9CD5, IRGKangXi=1480.511, RSKangXi=195.11, Def{codfish}
9CD6 CJK UNIFIED IDEOGRAPH-#9CD6, IRGKangXi=1480.511, RSKangXi=195.11, Def{turtle}
9CD7 CJK UNIFIED IDEOGRAPH-#9CD7, IRGKangXi=1480.511, RSKangXi=195.11, Def{eel}
9CD8 CJK UNIFIED IDEOGRAPH-#9CD8, IRGKangXi=1480.511, RSKangXi=195.11, Def{codfish}
9CD9 CJK UNIFIED IDEOGRAPH-#9CD9, IRGKangXi=1480.511, RSKangXi=195.11, Def{bighead}
9CDA CJK UNIFIED IDEOGRAPH-#9CDA, IRGKangXi=1480.511, RSKangXi=195.11, Def{general term of a kind of fish, a snake-like fish}
9CDB CJK UNIFIED IDEOGRAPH-#9CDB, IRGKangXi=1480.511, RSKangXi=195.11, Def{the weather or dojo loach, Misgurnus anguillicaudatus}
9CDC CJK UNIFIED IDEOGRAPH-#9CDC, IRGKangXi=1480.511, RSKangXi=195.12, Def{mandarin fish}
9CDD CJK UNIFIED IDEOGRAPH-#9CDD, IRGKangXi=1480.511, RSKangXi=195.12, Def{eel}
9CDE CJK UNIFIED IDEOGRAPH-#9CDE, IRGKangXi=1480.511, RSKangXi=195.12, Def{fish scales}
9CDF CJK UNIFIED IDEOGRAPH-#9CDF, IRGKangXi=1480.511, RSKangXi=195.12, Def{barbel}
9CE0 CJK UNIFIED IDEOGRAPH-#9CE0, IRGKangXi=1480.511, RSKangXi=195.13
9CE1 CJK UNIFIED IDEOGRAPH-#9CE1, IRGKangXi=1480.511, RSKangXi=195.13
9CE2 CJK UNIFIED IDEOGRAPH-#9CE2, IRGKangXi=1480.511, RSKangXi=195.13, Def{snakehead}
9CE3 CJK UNIFIED IDEOGRAPH-#9CE3, IRGKangXi=1480.511, RSKangXi=195.13, Def{sturgeon}
9CE4 CJK UNIFIED IDEOGRAPH-#9CE4, IRGKangXi=1480.511, RSKangXi=195.14
9CE5 CJK UNIFIED IDEOGRAPH-#9CE5, IRGKangXi=1480.520, RSKangXi=196.0, Def{bird; KangXi radical 196}
9CE6 CJK UNIFIED IDEOGRAPH-#9CE6, IRGKangXi=1481.010, RSKangXi=196.1, Def{swallow}
9CE7 CJK UNIFIED IDEOGRAPH-#9CE7, IRGKangXi=1481.070, RSKangXi=196.2, Def{wild duck, teal; swim}
9CE8 CJK UNIFIED IDEOGRAPH-#9CE8, IRGKangXi=1481.090, RSKangXi=196.2
9CE9 CJK UNIFIED IDEOGRAPH-#9CE9, IRGKangXi=1481.100, RSKangXi=196.2, Def{pigeon, dove; collect, assemble}
9CEA CJK UNIFIED IDEOGRAPH-#9CEA, IRGKangXi=1481.120, RSKangXi=196.2
9CEB CJK UNIFIED IDEOGRAPH-#9CEB, IRGKangXi=1482.010, RSKangXi=196.2, Def{wild goose}
9CEC CJK UNIFIED IDEOGRAPH-#9CEC, IRGKangXi=1482.021, RSKangXi=196.2, Def{wild duck, teal; swim}
9CED CJK UNIFIED IDEOGRAPH-#9CED, IRGKangXi=1482.021, RSKangXi=196.2
9CEE CJK UNIFIED IDEOGRAPH-#9CEE, IRGKangXi=1482.021, Def{chickens; domestic fowl}
9CEF CJK UNIFIED IDEOGRAPH-#9CEF, IRGKangXi=1482.021, Def{male phoenix; symbol of joy}
9CF0 CJK UNIFIED IDEOGRAPH-#9CF0, IRGKangXi=1482.021, RSKangXi=196.2
9CF1 CJK UNIFIED IDEOGRAPH-#9CF1, IRGKangXi=1482.030, RSKangXi=196.3
9CF2 CJK UNIFIED IDEOGRAPH-#9CF2, IRGKangXi=1482.100, RSKangXi=196.3, Def{turtledove, cuckoo}
9CF3 CJK UNIFIED IDEOGRAPH-#9CF3, IRGKangXi=1482.130, RSKangXi=196.3, Def{male phoenix; symbol of joy}
9CF4 CJK UNIFIED IDEOGRAPH-#9CF4, IRGKangXi=1482.180, RSKangXi=196.3, Def{cry of bird or animal; make sound}
9CF5 CJK UNIFIED IDEOGRAPH-#9CF5, IRGKangXi=1482.190, RSKangXi=196.3
9CF6 CJK UNIFIED IDEOGRAPH-#9CF6, IRGKangXi=1482.200, RSKangXi=196.3, Def{kite; Milvus species (various)}
9CF7 CJK UNIFIED IDEOGRAPH-#9CF7, IRGKangXi=1483.060, RSKangXi=196.4, Def{jay (Garrulus lidthi)}
9CF8 CJK UNIFIED IDEOGRAPH-#9CF8, IRGKangXi=1483.090, RSKangXi=196.4
9CF9 CJK UNIFIED IDEOGRAPH-#9CF9, IRGKangXi=1483.130, RSKangXi=196.4
9CFA CJK UNIFIED IDEOGRAPH-#9CFA, IRGKangXi=1483.140, RSKangXi=196.4
9CFB CJK UNIFIED IDEOGRAPH-#9CFB, IRGKangXi=1483.150, RSKangXi=196.4, Def{the wild pigeon}
9CFC CJK UNIFIED IDEOGRAPH-#9CFC, IRGKangXi=1483.160, RSKangXi=196.4
9CFD CJK UNIFIED IDEOGRAPH-#9CFD, IRGKangXi=1483.230, RSKangXi=196.4
9CFE CJK UNIFIED IDEOGRAPH-#9CFE, IRGKangXi=1483.280, RSKangXi=196.4, Def{general term for a group of small birds}
9CFF CJK UNIFIED IDEOGRAPH-#9CFF, IRGKangXi=1483.330, RSKangXi=196.4
9D00 CJK UNIFIED IDEOGRAPH-#9D00, IRGKangXi=1483.340, RSKangXi=196.4
9D01 CJK UNIFIED IDEOGRAPH-#9D01, IRGKangXi=1483.350, RSKangXi=196.4, Def{a legendary bird}
9D02 CJK UNIFIED IDEOGRAPH-#9D02, IRGKangXi=1483.370, RSKangXi=196.4, Def{the tailor-bird; the working bird}
9D03 CJK UNIFIED IDEOGRAPH-#9D03, IRGKangXi=1483.380, RSKangXi=196.4, Def{shrike; butcherbird}
9D04 CJK UNIFIED IDEOGRAPH-#9D04, IRGKangXi=1483.390, RSKangXi=196.4, Def{duck}
9D05 CJK UNIFIED IDEOGRAPH-#9D05, IRGKangXi=1484.010, RSKangXi=196.4
9D06 CJK UNIFIED IDEOGRAPH-#9D06, IRGKangXi=1484.020, RSKangXi=196.4, Def{a bird resembling the secretary falcon}
9D07 CJK UNIFIED IDEOGRAPH-#9D07, IRGKangXi=1484.050, RSKangXi=196.4, Def{bustard; procuress; Otis species (various)}
9D08 CJK UNIFIED IDEOGRAPH-#9D08, IRGKangXi=1484.080, RSKangXi=196.4, Def{wild goose}
9D09 CJK UNIFIED IDEOGRAPH-#9D09, IRGKangXi=1484.120, RSKangXi=196.4, Def{crow, raven; Corvus species (various)}
9D0A CJK UNIFIED IDEOGRAPH-#9D0A, IRGKangXi=1484.130, RSKangXi=196.5
9D0B CJK UNIFIED IDEOGRAPH-#9D0B, IRGKangXi=1484.160, RSKangXi=196.4
9D0C CJK UNIFIED IDEOGRAPH-#9D0C, IRGKangXi=1484.220, RSKangXi=196.4
9D0D CJK UNIFIED IDEOGRAPH-#9D0D, IRGKangXi=1484.240, RSKangXi=196.4
9D0E CJK UNIFIED IDEOGRAPH-#9D0E, IRGKangXi=1484.261, RSKangXi=196.4, Def{seagull, tern}
9D0F CJK UNIFIED IDEOGRAPH-#9D0F, IRGKangXi=1484.310, RSKangXi=196.5
9D10 CJK UNIFIED IDEOGRAPH-#9D10, IRGKangXi=1485.020, RSKangXi=196.5
9D11 CJK UNIFIED IDEOGRAPH-#9D11, IRGKangXi=1485.040, RSKangXi=196.5
9D12 CJK UNIFIED IDEOGRAPH-#9D12, IRGKangXi=1485.080, RSKangXi=196.5, Def{species of lark; wagtail; Motacilla species (various)}
9D13 CJK UNIFIED IDEOGRAPH-#9D13, IRGKangXi=1485.100, RSKangXi=196.5
9D14 CJK UNIFIED IDEOGRAPH-#9D14, IRGKangXi=1485.110, RSKangXi=196.5
9D15 CJK UNIFIED IDEOGRAPH-#9D15, IRGKangXi=1485.120, RSKangXi=196.5, Def{ostrich; Struthio camelus}
9D16 CJK UNIFIED IDEOGRAPH-#9D16, IRGKangXi=1485.130, RSKangXi=196.5
9D17 CJK UNIFIED IDEOGRAPH-#9D17, IRGKangXi=1485.180, RSKangXi=196.5, Def{kingfisher}
9D18 CJK UNIFIED IDEOGRAPH-#9D18, IRGKangXi=1485.190, RSKangXi=196.5
9D19 CJK UNIFIED IDEOGRAPH-#9D19, IRGKangXi=1485.210, RSKangXi=196.5
9D1A CJK UNIFIED IDEOGRAPH-#9D1A, IRGKangXi=1485.260, RSKangXi=196.5
9D1B CJK UNIFIED IDEOGRAPH-#9D1B, IRGKangXi=1485.280, RSKangXi=196.5, Def{male mandarin duck (Aix galericulata)}
9D1C CJK UNIFIED IDEOGRAPH-#9D1C, IRGKangXi=1485.290, RSKangXi=196.5
9D1D CJK UNIFIED IDEOGRAPH-#9D1D, IRGKangXi=1486.050, RSKangXi=196.5, Def{mynah; Erithacus species (various)}
9D1E CJK UNIFIED IDEOGRAPH-#9D1E, IRGKangXi=1486.080, RSKangXi=196.5, Def{owl}
9D1F CJK UNIFIED IDEOGRAPH-#9D1F, IRGKangXi=1486.100, RSKangXi=196.5, Def{kite, horned owl; wine cups}
9D20 CJK UNIFIED IDEOGRAPH-#9D20, IRGKangXi=1486.120, RSKangXi=196.5, Def{a kind of nightingale}
9D21 CJK UNIFIED IDEOGRAPH-#9D21, IRGKangXi=1486.130, RSKangXi=196.5
9D22 CJK UNIFIED IDEOGRAPH-#9D22, IRGKangXi=1486.160, RSKangXi=196.5
9D23 CJK UNIFIED IDEOGRAPH-#9D23, IRGKangXi=1486.170, RSKangXi=196.5, Def{species of Taiwan pigeon}
9D24 CJK UNIFIED IDEOGRAPH-#9D24, IRGKangXi=1487.020, RSKangXi=196.5
9D25 CJK UNIFIED IDEOGRAPH-#9D25, IRGKangXi=1487.050, RSKangXi=196.5, Def{swoop}
9D26 CJK UNIFIED IDEOGRAPH-#9D26, IRGKangXi=1487.060, RSKangXi=196.5, Def{female mandarin duck (Aix galericulata)}
9D27 CJK UNIFIED IDEOGRAPH-#9D27, IRGKangXi=1487.070, RSKangXi=196.5
9D28 CJK UNIFIED IDEOGRAPH-#9D28, IRGKangXi=1487.080, RSKangXi=196.5, Def{duck; Anas species (various)}
9D29 CJK UNIFIED IDEOGRAPH-#9D29, IRGKangXi=1487.151, RSKangXi=196.5
9D2A CJK UNIFIED IDEOGRAPH-#9D2A, IRGKangXi=1487.151, RSKangXi=196.5, Def{swoop}
9D2B CJK UNIFIED IDEOGRAPH-#9D2B, IRGKangXi=1487.151, RSKangXi=196.5, Def{a snipe}
9D2C CJK UNIFIED IDEOGRAPH-#9D2C, IRGKangXi=1487.151, RSKangXi=196.5, Def{oriole, green finch}
9D2D CJK UNIFIED IDEOGRAPH-#9D2D, IRGKangXi=1487.210, RSKangXi=196.6
9D2E CJK UNIFIED IDEOGRAPH-#9D2E, IRGKangXi=1487.250, RSKangXi=196.6
9D2F CJK UNIFIED IDEOGRAPH-#9D2F, IRGKangXi=1487.260, RSKangXi=196.6, Def{swallow}
9D30 CJK UNIFIED IDEOGRAPH-#9D30, IRGKangXi=1487.280, RSKangXi=196.6, Def{the crow}
9D31 CJK UNIFIED IDEOGRAPH-#9D31, IRGKangXi=1487.290, RSKangXi=196.6
9D32 CJK UNIFIED IDEOGRAPH-#9D32, IRGKangXi=1487.320, RSKangXi=196.6
9D33 CJK UNIFIED IDEOGRAPH-#9D33, IRGKangXi=1487.350, RSKangXi=196.6, Def{quail}
9D34 CJK UNIFIED IDEOGRAPH-#9D34, IRGKangXi=1488.010, RSKangXi=196.6
9D35 CJK UNIFIED IDEOGRAPH-#9D35, IRGKangXi=1488.020, RSKangXi=196.6
9D36 CJK UNIFIED IDEOGRAPH-#9D36, IRGKangXi=1488.040, RSKangXi=196.6
9D37 CJK UNIFIED IDEOGRAPH-#9D37, IRGKangXi=1488.060, RSKangXi=196.6, Def{a woodpecker}
9D38 CJK UNIFIED IDEOGRAPH-#9D38, IRGKangXi=1488.070, RSKangXi=196.6
9D39 CJK UNIFIED IDEOGRAPH-#9D39, IRGKangXi=1488.120
9D3A CJK UNIFIED IDEOGRAPH-#9D3A, IRGKangXi=1488.170, RSKangXi=196.6, Def{the pelican}
9D3B CJK UNIFIED IDEOGRAPH-#9D3B, IRGKangXi=1488.200, RSKangXi=196.6, Def{species of wild swan; vast}
9D3C CJK UNIFIED IDEOGRAPH-#9D3C, IRGKangXi=1488.260, RSKangXi=196.6
9D3D CJK UNIFIED IDEOGRAPH-#9D3D, IRGKangXi=1489.010, RSKangXi=196.6, Def{a species of bird resembling quail}
9D3E CJK UNIFIED IDEOGRAPH-#9D3E, IRGKangXi=1489.020, RSKangXi=196.6, Def{a crested ibis}
9D3F CJK UNIFIED IDEOGRAPH-#9D3F, IRGKangXi=1489.030, RSKangXi=196.6, Def{pigeon, dove; Columba species (various)}
9D40 CJK UNIFIED IDEOGRAPH-#9D40, IRGKangXi=1489.040, RSKangXi=196.6, Def{hoopoe}
9D41 CJK UNIFIED IDEOGRAPH-#9D41, IRGKangXi=1489.060, RSKangXi=196.6, Def{the fishing cormorant}
9D42 CJK UNIFIED IDEOGRAPH-#9D42, IRGKangXi=1489.070, RSKangXi=196.6, Def{horned owl, scops chinensis; bird of ill omen}
9D43 CJK UNIFIED IDEOGRAPH-#9D43, IRGKangXi=1489.080, RSKangXi=196.6
9D44 CJK UNIFIED IDEOGRAPH-#9D44, IRGKangXi=1489.150, RSKangXi=196.6, Def{variant of 鴟 U+9D1F, kite, horned owl; wine cups}
9D45 CJK UNIFIED IDEOGRAPH-#9D45, IRGKangXi=1489.161, RSKangXi=196.6
9D46 CJK UNIFIED IDEOGRAPH-#9D46, IRGKangXi=1489.161, RSKangXi=196.6
9D47 CJK UNIFIED IDEOGRAPH-#9D47, IRGKangXi=1489.161, RSKangXi=196.6
9D48 CJK UNIFIED IDEOGRAPH-#9D48, IRGKangXi=1489.161, RSKangXi=196.6
9D49 CJK UNIFIED IDEOGRAPH-#9D49, IRGKangXi=1489.161, RSKangXi=196.6
9D4A CJK UNIFIED IDEOGRAPH-#9D4A, IRGKangXi=1489.170, RSKangXi=196.7
9D4B CJK UNIFIED IDEOGRAPH-#9D4B, IRGKangXi=1489.200, RSKangXi=196.7
9D4C CJK UNIFIED IDEOGRAPH-#9D4C, IRGKangXi=1489.210, RSKangXi=196.7
9D4D CJK UNIFIED IDEOGRAPH-#9D4D, IRGKangXi=1489.230, RSKangXi=196.7
9D4E CJK UNIFIED IDEOGRAPH-#9D4E, IRGKangXi=1489.260, RSKangXi=196.7
9D4F CJK UNIFIED IDEOGRAPH-#9D4F, IRGKangXi=1489.280, RSKangXi=196.7
9D50 CJK UNIFIED IDEOGRAPH-#9D50, IRGKangXi=1490.020, RSKangXi=196.7
9D51 CJK UNIFIED IDEOGRAPH-#9D51, IRGKangXi=1490.040, RSKangXi=196.7, Def{cuckoo}
9D52 CJK UNIFIED IDEOGRAPH-#9D52, IRGKangXi=1490.060, RSKangXi=196.7, Def{mynah bird; Acridotheres tristis}
9D53 CJK UNIFIED IDEOGRAPH-#9D53, IRGKangXi=1490.070, RSKangXi=196.7, Def{species of pigeon}
9D54 CJK UNIFIED IDEOGRAPH-#9D54, IRGKangXi=1490.090, RSKangXi=196.7
9D55 CJK UNIFIED IDEOGRAPH-#9D55, IRGKangXi=1490.100, RSKangXi=196.7
9D56 CJK UNIFIED IDEOGRAPH-#9D56, IRGKangXi=1490.110, RSKangXi=196.7
9D57 CJK UNIFIED IDEOGRAPH-#9D57, IRGKangXi=1490.200, RSKangXi=196.7
9D58 CJK UNIFIED IDEOGRAPH-#9D58, IRGKangXi=1490.220, RSKangXi=196.7
9D59 CJK UNIFIED IDEOGRAPH-#9D59, IRGKangXi=1490.250, RSKangXi=196.7, Def{shrike; Lanius species (various)}
9D5A CJK UNIFIED IDEOGRAPH-#9D5A, IRGKangXi=1490.260, RSKangXi=196.7
9D5B CJK UNIFIED IDEOGRAPH-#9D5B, IRGKangXi=1490.270, RSKangXi=196.7
9D5C CJK UNIFIED IDEOGRAPH-#9D5C, IRGKangXi=1490.300, RSKangXi=196.7, Def{pelican}
9D5D CJK UNIFIED IDEOGRAPH-#9D5D, IRGKangXi=1490.310, RSKangXi=196.7, Def{goose}
9D5E CJK UNIFIED IDEOGRAPH-#9D5E, IRGKangXi=1491.020, RSKangXi=196.7, Def{goose}
9D5F CJK UNIFIED IDEOGRAPH-#9D5F, IRGKangXi=1491.040, RSKangXi=196.7
9D60 CJK UNIFIED IDEOGRAPH-#9D60, IRGKangXi=1491.060, RSKangXi=196.7, Def{target}
9D61 CJK UNIFIED IDEOGRAPH-#9D61, IRGKangXi=1491.080, RSKangXi=196.7, Def{species of parrot}
9D62 CJK UNIFIED IDEOGRAPH-#9D62, IRGKangXi=1491.180, RSKangXi=196.7
9D63 CJK UNIFIED IDEOGRAPH-#9D63, IRGKangXi=1491.241, RSKangXi=196.7
9D64 CJK UNIFIED IDEOGRAPH-#9D64, IRGKangXi=1491.241, RSKangXi=196.7
9D65 CJK UNIFIED IDEOGRAPH-#9D65, IRGKangXi=1491.241, RSKangXi=196.7
9D66 CJK UNIFIED IDEOGRAPH-#9D66, IRGKangXi=1491.270, RSKangXi=196.8
9D67 CJK UNIFIED IDEOGRAPH-#9D67, IRGKangXi=1491.360, RSKangXi=196.8
9D68 CJK UNIFIED IDEOGRAPH-#9D68, IRGKangXi=1491.380, RSKangXi=196.8
9D69 CJK UNIFIED IDEOGRAPH-#9D69, IRGKangXi=1491.390, RSKangXi=196.8, Def{owl-like bird; buzzard; Otus scops}
9D6A CJK UNIFIED IDEOGRAPH-#9D6A, IRGKangXi=1491.400, RSKangXi=196.8, Def{quail; Coturnix coturnix}
9D6B CJK UNIFIED IDEOGRAPH-#9D6B, IRGKangXi=1492.030, RSKangXi=196.8, Def{pheasant}
9D6C CJK UNIFIED IDEOGRAPH-#9D6C, IRGKangXi=1492.050, RSKangXi=196.8, Def{fabulous bird of enormous size}
9D6D CJK UNIFIED IDEOGRAPH-#9D6D, IRGKangXi=1492.070, RSKangXi=196.8, Def{a small bird with black neck}
9D6E CJK UNIFIED IDEOGRAPH-#9D6E, IRGKangXi=1492.080, Def{to peck, as birds}
9D6F CJK UNIFIED IDEOGRAPH-#9D6F, IRGKangXi=1492.090, RSKangXi=196.8, Def{Pycnonotus species (various)}
9D70 CJK UNIFIED IDEOGRAPH-#9D70, IRGKangXi=1492.110, RSKangXi=196.8, Def{eagle, vulture; Aquila species (various)}
9D71 CJK UNIFIED IDEOGRAPH-#9D71, IRGKangXi=1492.120, RSKangXi=196.8
9D72 CJK UNIFIED IDEOGRAPH-#9D72, IRGKangXi=1492.130, RSKangXi=196.8, Def{magpie; Pica species (various)}
9D73 CJK UNIFIED IDEOGRAPH-#9D73, IRGKangXi=1492.140, RSKangXi=196.8
9D74 CJK UNIFIED IDEOGRAPH-#9D74, IRGKangXi=1492.160, RSKangXi=196.8
9D75 CJK UNIFIED IDEOGRAPH-#9D75, IRGKangXi=1492.180, RSKangXi=196.8
9D76 CJK UNIFIED IDEOGRAPH-#9D76, IRGKangXi=1492.210, RSKangXi=196.8
9D77 CJK UNIFIED IDEOGRAPH-#9D77, IRGKangXi=1492.220, RSKangXi=196.8, Def{co-worker}
9D78 CJK UNIFIED IDEOGRAPH-#9D78, IRGKangXi=1492.240, RSKangXi=196.8
9D79 CJK UNIFIED IDEOGRAPH-#9D79, IRGKangXi=1492.270, RSKangXi=196.8
9D7A CJK UNIFIED IDEOGRAPH-#9D7A, IRGKangXi=1493.010, RSKangXi=196.8
9D7B CJK UNIFIED IDEOGRAPH-#9D7B, IRGKangXi=1493.020, RSKangXi=196.8, Def{pigeon; turtle-dove; a hawk}
9D7C CJK UNIFIED IDEOGRAPH-#9D7C, IRGKangXi=1493.040, RSKangXi=196.8, Def{a fabulous night-bird, grotesque monster}
9D7D CJK UNIFIED IDEOGRAPH-#9D7D, IRGKangXi=1493.050, RSKangXi=196.8
9D7E CJK UNIFIED IDEOGRAPH-#9D7E, IRGKangXi=1493.060, RSKangXi=196.8, Def{a bird resembling the crane}
9D7F CJK UNIFIED IDEOGRAPH-#9D7F, IRGKangXi=1493.090, RSKangXi=196.8
9D80 CJK UNIFIED IDEOGRAPH-#9D80, IRGKangXi=1493.110, RSKangXi=196.8
9D81 CJK UNIFIED IDEOGRAPH-#9D81, IRGKangXi=1493.140, RSKangXi=196.8
9D82 CJK UNIFIED IDEOGRAPH-#9D82, IRGKangXi=1493.150, RSKangXi=196.8, Def{hawk; Ardea cinerea}
9D83 CJK UNIFIED IDEOGRAPH-#9D83, IRGKangXi=1493.160, RSKangXi=196.8, Def{hawk; Ardea cinerea}
9D84 CJK UNIFIED IDEOGRAPH-#9D84, IRGKangXi=1493.170, RSKangXi=196.8, Def{a kind of water bird}
9D85 CJK UNIFIED IDEOGRAPH-#9D85, IRGKangXi=1493.180, RSKangXi=196.8
9D86 CJK UNIFIED IDEOGRAPH-#9D86, IRGKangXi=1493.200, RSKangXi=196.8
9D87 CJK UNIFIED IDEOGRAPH-#9D87, IRGKangXi=1493.210, RSKangXi=196.8, Def{thrush; Turdus species (various)}
9D88 CJK UNIFIED IDEOGRAPH-#9D88, IRGKangXi=1493.220, RSKangXi=196.8
9D89 CJK UNIFIED IDEOGRAPH-#9D89, IRGKangXi=1493.230, RSKangXi=196.8, Def{quail; Turnix species (various)}
9D8A CJK UNIFIED IDEOGRAPH-#9D8A, IRGKangXi=1493.240, RSKangXi=196.8, Def{oriole}
9D8B CJK UNIFIED IDEOGRAPH-#9D8B, IRGKangXi=1493.250, RSKangXi=196.8, Def{a sea-bird with a white breast}
9D8C CJK UNIFIED IDEOGRAPH-#9D8C, IRGKangXi=1494.010, RSKangXi=196.8
9D8D CJK UNIFIED IDEOGRAPH-#9D8D, IRGKangXi=1494.101, RSKangXi=196.8
9D8E CJK UNIFIED IDEOGRAPH-#9D8E, IRGKangXi=1494.101, RSKangXi=196.8
9D8F CJK UNIFIED IDEOGRAPH-#9D8F, IRGKangXi=1494.101, RSKangXi=196.8, Def{chicken}
9D90 CJK UNIFIED IDEOGRAPH-#9D90, IRGKangXi=1495.341, RSKangXi=196.9
9D91 CJK UNIFIED IDEOGRAPH-#9D91, IRGKangXi=1494.101, RSKangXi=196.8
9D92 CJK UNIFIED IDEOGRAPH-#9D92, IRGKangXi=1494.110, RSKangXi=196.9, Def{a duck-like bird}
9D93 CJK UNIFIED IDEOGRAPH-#9D93, IRGKangXi=1494.170, RSKangXi=196.9, Def{emu}
9D94 CJK UNIFIED IDEOGRAPH-#9D94, IRGKangXi=1494.210, RSKangXi=196.9
9D95 CJK UNIFIED IDEOGRAPH-#9D95, IRGKangXi=1494.220, RSKangXi=196.9
9D96 CJK UNIFIED IDEOGRAPH-#9D96, IRGKangXi=1494.260, RSKangXi=196.9, Def{large waterfowl with naked head; Garrulus glandarius}
9D97 CJK UNIFIED IDEOGRAPH-#9D97, IRGKangXi=1494.270, RSKangXi=196.9, Def{a kind of hawk; cuckoo}
9D98 CJK UNIFIED IDEOGRAPH-#9D98, IRGKangXi=1494.300, RSKangXi=196.9, Def{pelican}
9D99 CJK UNIFIED IDEOGRAPH-#9D99, IRGKangXi=1494.320, RSKangXi=196.9
9D9A CJK UNIFIED IDEOGRAPH-#9D9A, IRGKangXi=1494.360, RSKangXi=196.9, Def{osprey, fishhawk; Pandion haliaetus}
9D9B CJK UNIFIED IDEOGRAPH-#9D9B, IRGKangXi=1494.420, RSKangXi=196.9
9D9C CJK UNIFIED IDEOGRAPH-#9D9C, IRGKangXi=1494.450, RSKangXi=196.9
9D9D CJK UNIFIED IDEOGRAPH-#9D9D, IRGKangXi=1494.470, RSKangXi=196.9
9D9E CJK UNIFIED IDEOGRAPH-#9D9E, IRGKangXi=1494.500, RSKangXi=196.9
9D9F CJK UNIFIED IDEOGRAPH-#9D9F, IRGKangXi=1495.010, RSKangXi=196.9
9DA0 CJK UNIFIED IDEOGRAPH-#9DA0, IRGKangXi=1495.020, RSKangXi=196.9
9DA1 CJK UNIFIED IDEOGRAPH-#9DA1, IRGKangXi=1495.040, RSKangXi=196.9, Def{crossbill, species of nightingale}
9DA2 CJK UNIFIED IDEOGRAPH-#9DA2, IRGKangXi=1495.060, RSKangXi=196.9, Def{a bird which frequents the sea-shore}
9DA3 CJK UNIFIED IDEOGRAPH-#9DA3, IRGKangXi=1495.070, RSKangXi=196.9
9DA4 CJK UNIFIED IDEOGRAPH-#9DA4, IRGKangXi=1495.100, RSKangXi=196.9
9DA5 CJK UNIFIED IDEOGRAPH-#9DA5, IRGKangXi=1495.110, RSKangXi=196.9
9DA6 CJK UNIFIED IDEOGRAPH-#9DA6, IRGKangXi=1495.120, RSKangXi=196.9, Def{pelican}
9DA7 CJK UNIFIED IDEOGRAPH-#9DA7, IRGKangXi=1495.160, RSKangXi=196.9
9DA8 CJK UNIFIED IDEOGRAPH-#9DA8, IRGKangXi=1495.190, RSKangXi=196.9
9DA9 CJK UNIFIED IDEOGRAPH-#9DA9, IRGKangXi=1495.210, RSKangXi=196.9, Def{duck}
9DAA CJK UNIFIED IDEOGRAPH-#9DAA, IRGKangXi=1495.230, RSKangXi=196.9, Def{a shrike}
9DAB CJK UNIFIED IDEOGRAPH-#9DAB, IRGKangXi=1495.341, RSKangXi=196.9, Def{thrush; Turdus naumanni}
9DAC CJK UNIFIED IDEOGRAPH-#9DAC, IRGKangXi=1495.360, RSKangXi=196.10, Def{oriole}
9DAD CJK UNIFIED IDEOGRAPH-#9DAD, IRGKangXi=1496.010, RSKangXi=196.10
9DAE CJK UNIFIED IDEOGRAPH-#9DAE, IRGKangXi=1496.030, RSKangXi=196.10
9DAF CJK UNIFIED IDEOGRAPH-#9DAF, IRGKangXi=1496.050, RSKangXi=196.10, Def{oriole, green finch; Sylvia species (various)}
9DB0 CJK UNIFIED IDEOGRAPH-#9DB0, IRGKangXi=1496.080, RSKangXi=196.10
9DB1 CJK UNIFIED IDEOGRAPH-#9DB1, IRGKangXi=1496.120, RSKangXi=196.10, Def{soar}
9DB2 CJK UNIFIED IDEOGRAPH-#9DB2, IRGKangXi=1496.140, RSKangXi=196.10
9DB3 CJK UNIFIED IDEOGRAPH-#9DB3, IRGKangXi=1496.170, RSKangXi=196.10
9DB4 CJK UNIFIED IDEOGRAPH-#9DB4, IRGKangXi=1496.200, RSKangXi=196.10, Def{crane; Grus species (various)}
9DB5 CJK UNIFIED IDEOGRAPH-#9DB5, IRGKangXi=1496.210, RSKangXi=196.10, Def{chick, fledging; infant, toddler}
9DB6 CJK UNIFIED IDEOGRAPH-#9DB6, IRGKangXi=1496.240, RSKangXi=196.10
9DB7 CJK UNIFIED IDEOGRAPH-#9DB7, IRGKangXi=1496.250, RSKangXi=196.10
9DB8 CJK UNIFIED IDEOGRAPH-#9DB8, IRGKangXi=1496.270, RSKangXi=196.10, Def{light yellowish-green}
9DB9 CJK UNIFIED IDEOGRAPH-#9DB9, IRGKangXi=1496.290, RSKangXi=196.10, Def{the owl}
9DBA CJK UNIFIED IDEOGRAPH-#9DBA, IRGKangXi=1496.310, RSKangXi=196.10, Def{wagtail}
9DBB CJK UNIFIED IDEOGRAPH-#9DBB, IRGKangXi=1496.320, RSKangXi=196.10, Def{a kind of pigeon; falcon}
9DBC CJK UNIFIED IDEOGRAPH-#9DBC, IRGKangXi=1497.010, RSKangXi=196.10, Def{fabulous mythical bird}
9DBD CJK UNIFIED IDEOGRAPH-#9DBD, IRGKangXi=1497.020, RSKangXi=196.10, Def{a hawk}
9DBE CJK UNIFIED IDEOGRAPH-#9DBE, IRGKangXi=1497.030, RSKangXi=196.10
9DBF CJK UNIFIED IDEOGRAPH-#9DBF, IRGKangXi=1497.040, RSKangXi=196.10, Def{cormorant}
9DC0 CJK UNIFIED IDEOGRAPH-#9DC0, IRGKangXi=1497.050, RSKangXi=196.10, Def{the fishing cormorant}
9DC1 CJK UNIFIED IDEOGRAPH-#9DC1, IRGKangXi=1497.070, RSKangXi=196.10, Def{fishhawk; bow or prow}
9DC2 CJK UNIFIED IDEOGRAPH-#9DC2, IRGKangXi=1497.080, RSKangXi=196.10, Def{sparrow hawk; Circus species (various)}
9DC3 CJK UNIFIED IDEOGRAPH-#9DC3, IRGKangXi=1497.090, RSKangXi=196.10, Def{quail}
9DC4 CJK UNIFIED IDEOGRAPH-#9DC4, IRGKangXi=1497.100, RSKangXi=196.10, Def{chicken}
9DC5 CJK UNIFIED IDEOGRAPH-#9DC5, IRGKangXi=1498.020, RSKangXi=196.10
9DC6 CJK UNIFIED IDEOGRAPH-#9DC6, IRGKangXi=1498.030, RSKangXi=196.10, Def{bird name}
9DC7 CJK UNIFIED IDEOGRAPH-#9DC7, IRGKangXi=1498.070, RSKangXi=196.10, Def{chicks, fledglings}
9DC8 CJK UNIFIED IDEOGRAPH-#9DC8, IRGKangXi=1498.080, RSKangXi=196.10, Def{a kind of bird}
9DC9 CJK UNIFIED IDEOGRAPH-#9DC9, IRGKangXi=1498.090, RSKangXi=196.10
9DCA CJK UNIFIED IDEOGRAPH-#9DCA, IRGKangXi=1498.100, RSKangXi=196.10, Def{pheasant}
9DCB CJK UNIFIED IDEOGRAPH-#9DCB, IRGKangXi=1498.120, RSKangXi=196.11
9DCC CJK UNIFIED IDEOGRAPH-#9DCC, IRGKangXi=1498.130, RSKangXi=196.10
9DCD CJK UNIFIED IDEOGRAPH-#9DCD, IRGKangXi=1498.190, RSKangXi=196.10
9DCE CJK UNIFIED IDEOGRAPH-#9DCE, IRGKangXi=1498.201, RSKangXi=196.10
9DCF CJK UNIFIED IDEOGRAPH-#9DCF, IRGKangXi=1498.201, RSKangXi=196.10, Def{Caprimulgus indicus}
9DD0 CJK UNIFIED IDEOGRAPH-#9DD0, IRGKangXi=1498.220, RSKangXi=196.11
9DD1 CJK UNIFIED IDEOGRAPH-#9DD1, IRGKangXi=1498.310, RSKangXi=196.11
9DD2 CJK UNIFIED IDEOGRAPH-#9DD2, IRGKangXi=1498.320, RSKangXi=196.11
9DD3 CJK UNIFIED IDEOGRAPH-#9DD3, IRGKangXi=1498.330, RSKangXi=196.11, Def{partridge}
9DD4 CJK UNIFIED IDEOGRAPH-#9DD4, IRGKangXi=1498.420, RSKangXi=196.11, Def{a bird of ill-omen to the state}
9DD5 CJK UNIFIED IDEOGRAPH-#9DD5, IRGKangXi=1499.010, RSKangXi=196.11, Def{call}
9DD6 CJK UNIFIED IDEOGRAPH-#9DD6, IRGKangXi=1499.060, RSKangXi=196.11, Def{seagull}
9DD7 CJK UNIFIED IDEOGRAPH-#9DD7, IRGKangXi=1499.070, RSKangXi=196.11, Def{seagull, tern; Larus species (various)}
9DD8 CJK UNIFIED IDEOGRAPH-#9DD8, IRGKangXi=1499.110, RSKangXi=196.11
9DD9 CJK UNIFIED IDEOGRAPH-#9DD9, IRGKangXi=1499.130, RSKangXi=196.11, Def{hawk, vulture}
9DDA CJK UNIFIED IDEOGRAPH-#9DDA, IRGKangXi=1499.160, RSKangXi=196.11, Def{Anthus species (various)}
9DDB CJK UNIFIED IDEOGRAPH-#9DDB, IRGKangXi=1499.170, RSKangXi=196.11
9DDC CJK UNIFIED IDEOGRAPH-#9DDC, IRGKangXi=1499.190, RSKangXi=196.11
9DDD CJK UNIFIED IDEOGRAPH-#9DDD, IRGKangXi=1499.210, RSKangXi=196.11
9DDE CJK UNIFIED IDEOGRAPH-#9DDE, IRGKangXi=1499.240, RSKangXi=196.11, Def{turquoise kingfisher}
9DDF CJK UNIFIED IDEOGRAPH-#9DDF, IRGKangXi=1499.250, RSKangXi=196.11, Def{phoenix}
9DE0 CJK UNIFIED IDEOGRAPH-#9DE0, IRGKangXi=1500.010, RSKangXi=196.11
9DE1 CJK UNIFIED IDEOGRAPH-#9DE1, IRGKangXi=1500.100, RSKangXi=196.12
9DE2 CJK UNIFIED IDEOGRAPH-#9DE2, IRGKangXi=1500.130, RSKangXi=196.12
9DE3 CJK UNIFIED IDEOGRAPH-#9DE3, IRGKangXi=1500.140, RSKangXi=196.12
9DE4 CJK UNIFIED IDEOGRAPH-#9DE4, IRGKangXi=1500.150, RSKangXi=196.12
9DE5 CJK UNIFIED IDEOGRAPH-#9DE5, IRGKangXi=1500.160, RSKangXi=196.12, Def{egret; Egretta garzetta}
9DE6 CJK UNIFIED IDEOGRAPH-#9DE6, IRGKangXi=1500.200, RSKangXi=196.12, Def{wren}
9DE7 CJK UNIFIED IDEOGRAPH-#9DE7, IRGKangXi=1500.210, RSKangXi=196.12, Def{cormorant}
9DE8 CJK UNIFIED IDEOGRAPH-#9DE8, IRGKangXi=1500.240, RSKangXi=196.12
9DE9 CJK UNIFIED IDEOGRAPH-#9DE9, IRGKangXi=1500.310, RSKangXi=196.12, Def{pheasant}
9DEA CJK UNIFIED IDEOGRAPH-#9DEA, IRGKangXi=1500.320, RSKangXi=196.12
9DEB CJK UNIFIED IDEOGRAPH-#9DEB, IRGKangXi=1500.360, RSKangXi=196.12, Def{turquoise kingfisher}
9DEC CJK UNIFIED IDEOGRAPH-#9DEC, IRGKangXi=1500.370, RSKangXi=196.12
9DED CJK UNIFIED IDEOGRAPH-#9DED, IRGKangXi=1500.390, RSKangXi=196.12
9DEE CJK UNIFIED IDEOGRAPH-#9DEE, IRGKangXi=1501.010, RSKangXi=196.12
9DEF CJK UNIFIED IDEOGRAPH-#9DEF, IRGKangXi=1501.020, RSKangXi=196.12, Def{wren}
9DF0 CJK UNIFIED IDEOGRAPH-#9DF0, IRGKangXi=1501.030, RSKangXi=196.12
9DF1 CJK UNIFIED IDEOGRAPH-#9DF1, IRGKangXi=1501.040, RSKangXi=196.12
9DF2 CJK UNIFIED IDEOGRAPH-#9DF2, IRGKangXi=1501.050, RSKangXi=196.12, Def{condor, vulture}
9DF3 CJK UNIFIED IDEOGRAPH-#9DF3, IRGKangXi=1501.060, RSKangXi=196.12, Def{the silver pheasant, Lophura nycthemera}
9DF4 CJK UNIFIED IDEOGRAPH-#9DF4, IRGKangXi=1501.070, RSKangXi=196.12, Def{silver pheasant badge worn by civil officials of the 5th grade; Lophura species (various)}
9DF5 CJK UNIFIED IDEOGRAPH-#9DF5, IRGKangXi=1501.100, RSKangXi=196.12
9DF6 CJK UNIFIED IDEOGRAPH-#9DF6, IRGKangXi=1501.130, RSKangXi=196.12
9DF7 CJK UNIFIED IDEOGRAPH-#9DF7, IRGKangXi=1501.150, RSKangXi=196.12
9DF8 CJK UNIFIED IDEOGRAPH-#9DF8, IRGKangXi=1501.160, RSKangXi=196.12, Def{snipe, kingfisher; Tringa species (various)}
9DF9 CJK UNIFIED IDEOGRAPH-#9DF9, IRGKangXi=1501.180, RSKangXi=196.13, Def{eagle, falcon; Accipiter species (various)}
9DFA CJK UNIFIED IDEOGRAPH-#9DFA, IRGKangXi=1501.190, RSKangXi=196.12, Def{heron, egret; Ardea species (various)}
9DFB CJK UNIFIED IDEOGRAPH-#9DFB, IRGKangXi=1502.121, RSKangXi=196.12
9DFC CJK UNIFIED IDEOGRAPH-#9DFC, IRGKangXi=1502.121, RSKangXi=196.12
9DFD CJK UNIFIED IDEOGRAPH-#9DFD, IRGKangXi=1502.140, RSKangXi=196.13, Def{oriental bullfinch, weaver bird; Pyrrhula species (various)}
9DFE CJK UNIFIED IDEOGRAPH-#9DFE, IRGKangXi=1502.190, RSKangXi=196.13, Def{swallow}
9DFF CJK UNIFIED IDEOGRAPH-#9DFF, IRGKangXi=1502.220, RSKangXi=196.13, Def{a kind of bird resembling the duck; much smaller}
9E00 CJK UNIFIED IDEOGRAPH-#9E00, IRGKangXi=1502.230, RSKangXi=196.13
9E01 CJK UNIFIED IDEOGRAPH-#9E01, IRGKangXi=1502.250, RSKangXi=196.13
9E02 CJK UNIFIED IDEOGRAPH-#9E02, IRGKangXi=1502.270, RSKangXi=196.13, Def{Mandarin duck, Aix galericulata}
9E03 CJK UNIFIED IDEOGRAPH-#9E03, IRGKangXi=1502.280, RSKangXi=196.13
9E04 CJK UNIFIED IDEOGRAPH-#9E04, IRGKangXi=1502.330, RSKangXi=196.13
9E05 CJK UNIFIED IDEOGRAPH-#9E05, IRGKangXi=1503.030, RSKangXi=196.13
9E06 CJK UNIFIED IDEOGRAPH-#9E06, IRGKangXi=1503.040, RSKangXi=196.13
9E07 CJK UNIFIED IDEOGRAPH-#9E07, IRGKangXi=1503.060, RSKangXi=196.13, Def{hawk; Butastur indicus}
9E08 CJK UNIFIED IDEOGRAPH-#9E08, IRGKangXi=1503.090, RSKangXi=196.13
9E09 CJK UNIFIED IDEOGRAPH-#9E09, IRGKangXi=1503.100, RSKangXi=196.13
9E0A CJK UNIFIED IDEOGRAPH-#9E0A, IRGKangXi=1503.161, RSKangXi=196.13, Def{Podiceps ruficolus (a kind of duck)}
9E0B CJK UNIFIED IDEOGRAPH-#9E0B, IRGKangXi=1503.170, RSKangXi=196.14, Def{(archaic) a wren}
9E0C CJK UNIFIED IDEOGRAPH-#9E0C, IRGKangXi=1503.180, RSKangXi=196.14
9E0D CJK UNIFIED IDEOGRAPH-#9E0D, IRGKangXi=1503.210, RSKangXi=196.14
9E0E CJK UNIFIED IDEOGRAPH-#9E0E, IRGKangXi=1503.260, RSKangXi=196.14, Def{the mango-bird; the Chinese oriole}
9E0F CJK UNIFIED IDEOGRAPH-#9E0F, IRGKangXi=1503.270, RSKangXi=196.14
9E10 CJK UNIFIED IDEOGRAPH-#9E10, IRGKangXi=1503.320, RSKangXi=196.14
9E11 CJK UNIFIED IDEOGRAPH-#9E11, IRGKangXi=1503.330, RSKangXi=196.14, Def{a large, duck-like waterfowl with red eyes; a young phoenix}
9E12 CJK UNIFIED IDEOGRAPH-#9E12, IRGKangXi=1503.340, RSKangXi=196.14, Def{eastern jackdaw; Corvus monedula}
9E13 CJK UNIFIED IDEOGRAPH-#9E13, IRGKangXi=1504.120, RSKangXi=196.15
9E14 CJK UNIFIED IDEOGRAPH-#9E14, IRGKangXi=1504.131, RSKangXi=196.15
9E15 CJK UNIFIED IDEOGRAPH-#9E15, IRGKangXi=1504.140, RSKangXi=196.16, Def{cormorant}
9E16 CJK UNIFIED IDEOGRAPH-#9E16, IRGKangXi=1504.160, RSKangXi=196.16
9E17 CJK UNIFIED IDEOGRAPH-#9E17, IRGKangXi=1504.200, RSKangXi=196.16
9E18 CJK UNIFIED IDEOGRAPH-#9E18, IRGKangXi=1504.290, RSKangXi=196.17, Def{eagle}
9E19 CJK UNIFIED IDEOGRAPH-#9E19, IRGKangXi=1504.300, RSKangXi=196.17
9E1A CJK UNIFIED IDEOGRAPH-#9E1A, IRGKangXi=1504.310, RSKangXi=196.17, Def{parrot}
9E1B CJK UNIFIED IDEOGRAPH-#9E1B, IRGKangXi=1504.390, RSKangXi=196.18, Def{crane, Grus japonensis; stork; Ciconia species (various)}
9E1C CJK UNIFIED IDEOGRAPH-#9E1C, IRGKangXi=1504.400, RSKangXi=196.18, Def{a species of mynah}
9E1D CJK UNIFIED IDEOGRAPH-#9E1D, IRGKangXi=1504.440, RSKangXi=196.19, Def{Chinese oriole; Oriolus oriolus}
9E1E CJK UNIFIED IDEOGRAPH-#9E1E, IRGKangXi=1505.010, RSKangXi=196.19, Def{fabulous bird}
9E1F CJK UNIFIED IDEOGRAPH-#9E1F, IRGKangXi=1505.141, RSKangXi=196.0, Def{bird; KangXi radical 196}
9E20 CJK UNIFIED IDEOGRAPH-#9E20, IRGKangXi=1505.141, RSKangXi=196.2, Def{pigeon; collect, assemble}
9E21 CJK UNIFIED IDEOGRAPH-#9E21, IRGKangXi=1505.141, RSKangXi=196.2, Def{chicken}
9E22 CJK UNIFIED IDEOGRAPH-#9E22, IRGKangXi=1505.141, RSKangXi=196.3, Def{kite; Milvus species (various)}
9E23 CJK UNIFIED IDEOGRAPH-#9E23, IRGKangXi=1505.141, RSKangXi=30.5, Def{cry of bird or animal; make sound}
9E24 CJK UNIFIED IDEOGRAPH-#9E24, IRGKangXi=1505.141, RSKangXi=196.3, Def{turtledove, cuckoo}
9E25 CJK UNIFIED IDEOGRAPH-#9E25, IRGKangXi=1505.141, RSKangXi=196.4, Def{seagull, tern; Larus species (various)}
9E26 CJK UNIFIED IDEOGRAPH-#9E26, IRGKangXi=1505.141, RSKangXi=196.4, Def{crow; Corvus species (various)}
9E27 CJK UNIFIED IDEOGRAPH-#9E27, IRGKangXi=1505.141, RSKangXi=196.4, Def{oriole}
9E28 CJK UNIFIED IDEOGRAPH-#9E28, IRGKangXi=1505.141, RSKangXi=196.4, Def{bustard; procuress; Otis species (various)}
9E29 CJK UNIFIED IDEOGRAPH-#9E29, IRGKangXi=1505.141, RSKangXi=196.4, Def{a bird resembling the secretary falcon}
9E2A CJK UNIFIED IDEOGRAPH-#9E2A, IRGKangXi=1505.141, RSKangXi=196.5, Def{species of Taiwan pigeon}
9E2B CJK UNIFIED IDEOGRAPH-#9E2B, IRGKangXi=1505.141, RSKangXi=196.5, Def{thrush; Turdus species (various)}
9E2C CJK UNIFIED IDEOGRAPH-#9E2C, IRGKangXi=1505.141, RSKangXi=196.5, Def{cormorant}
9E2D CJK UNIFIED IDEOGRAPH-#9E2D, IRGKangXi=1505.141, RSKangXi=196.5, Def{duck; Anas species (various)}
9E2E CJK UNIFIED IDEOGRAPH-#9E2E, IRGKangXi=1505.141, RSKangXi=196.5, Def{owl}
9E2F CJK UNIFIED IDEOGRAPH-#9E2F, IRGKangXi=1505.141, RSKangXi=196.5, Def{female mandarin duck (Aix galericulata)}
9E30 CJK UNIFIED IDEOGRAPH-#9E30, IRGKangXi=1505.141, RSKangXi=196.5, Def{species of lark; wagtail; Motacilla species (various)}
9E31 CJK UNIFIED IDEOGRAPH-#9E31, IRGKangXi=1505.141, RSKangXi=196.5, Def{kite, horned owl; wine cups}
9E32 CJK UNIFIED IDEOGRAPH-#9E32, IRGKangXi=1505.141, RSKangXi=196.5, Def{mynah; Erithacus species (various)}
9E33 CJK UNIFIED IDEOGRAPH-#9E33, IRGKangXi=1505.141, RSKangXi=196.5, Def{male mandarin duck (Aix galericulata)}
9E34 CJK UNIFIED IDEOGRAPH-#9E34, IRGKangXi=1505.141, RSKangXi=196.13, Def{oriental bullfinch, weaver bird; Pyrrhula species (various)}
9E35 CJK UNIFIED IDEOGRAPH-#9E35, IRGKangXi=1505.141, RSKangXi=196.5, Def{ostrich}
9E36 CJK UNIFIED IDEOGRAPH-#9E36, IRGKangXi=1505.141, RSKangXi=196.5, Def{the eastern egret}
9E37 CJK UNIFIED IDEOGRAPH-#9E37, IRGKangXi=1505.141, RSKangXi=196.6, Def{hawk, vulture}
9E38 CJK UNIFIED IDEOGRAPH-#9E38, IRGKangXi=1505.141, RSKangXi=196.6, Def{swallow}
9E39 CJK UNIFIED IDEOGRAPH-#9E39, IRGKangXi=1505.141, RSKangXi=196.6, Def{the crow}
9E3A CJK UNIFIED IDEOGRAPH-#9E3A, IRGKangXi=1505.141, RSKangXi=196.6, Def{horned owl, scops chinensis}
9E3B CJK UNIFIED IDEOGRAPH-#9E3B, IRGKangXi=1505.141, RSKangXi=196.6
9E3C CJK UNIFIED IDEOGRAPH-#9E3C, IRGKangXi=1505.141, RSKangXi=196.6
9E3D CJK UNIFIED IDEOGRAPH-#9E3D, IRGKangXi=1505.141, RSKangXi=196.6, Def{pigeon, dove; Columba species (various)}
9E3E CJK UNIFIED IDEOGRAPH-#9E3E, IRGKangXi=1505.141, RSKangXi=196.6, Def{fabulous bird}
9E3F CJK UNIFIED IDEOGRAPH-#9E3F, IRGKangXi=1505.141, RSKangXi=196.6, Def{species of wild swan; vast}
9E40 CJK UNIFIED IDEOGRAPH-#9E40, IRGKangXi=1505.141, RSKangXi=196.7
9E41 CJK UNIFIED IDEOGRAPH-#9E41, IRGKangXi=1505.141, RSKangXi=196.7, Def{species of pigeon}
9E42 CJK UNIFIED IDEOGRAPH-#9E42, IRGKangXi=1505.141, RSKangXi=196.7, Def{Chinese oriole; Oriolus oriolus}
9E43 CJK UNIFIED IDEOGRAPH-#9E43, IRGKangXi=1505.141, RSKangXi=196.7, Def{cuckoo}
9E44 CJK UNIFIED IDEOGRAPH-#9E44, IRGKangXi=1505.141, RSKangXi=196.7, Def{target}
9E45 CJK UNIFIED IDEOGRAPH-#9E45, IRGKangXi=1505.141, RSKangXi=196.7, Def{goose}
9E46 CJK UNIFIED IDEOGRAPH-#9E46, IRGKangXi=1505.141, RSKangXi=196.7, Def{myna; manah; Acridotheres tristis}
9E47 CJK UNIFIED IDEOGRAPH-#9E47, IRGKangXi=1505.141, RSKangXi=196.7, Def{silver pheasant, Lophura nycthemera; Lophura species (various)}
9E48 CJK UNIFIED IDEOGRAPH-#9E48, IRGKangXi=1505.141, RSKangXi=196.7, Def{pelican}
9E49 CJK UNIFIED IDEOGRAPH-#9E49, IRGKangXi=1505.141, RSKangXi=196.8, Def{species of parrot}
9E4A CJK UNIFIED IDEOGRAPH-#9E4A, IRGKangXi=1505.141, RSKangXi=196.8, Def{magpie; Pica species (various)}
9E4B CJK UNIFIED IDEOGRAPH-#9E4B, IRGKangXi=1505.141, RSKangXi=196.9, Def{emu}
9E4C CJK UNIFIED IDEOGRAPH-#9E4C, IRGKangXi=1505.141, RSKangXi=196.8, Def{quail; Coturnix coturnix}
9E4D CJK UNIFIED IDEOGRAPH-#9E4D, IRGKangXi=1505.141, RSKangXi=196.8, Def{a bird resembling the crane}
9E4E CJK UNIFIED IDEOGRAPH-#9E4E, IRGKangXi=1505.141, RSKangXi=196.8, Def{bird}
9E4F CJK UNIFIED IDEOGRAPH-#9E4F, IRGKangXi=1505.141, RSKangXi=196.8, Def{fabulous bird of enormous size}
9E50 CJK UNIFIED IDEOGRAPH-#9E50, IRGKangXi=1505.141, Def{to peck, as birds}
9E51 CJK UNIFIED IDEOGRAPH-#9E51, IRGKangXi=1505.141, RSKangXi=196.8, Def{quail; Turnix species (various)}
9E52 CJK UNIFIED IDEOGRAPH-#9E52, IRGKangXi=1505.141, RSKangXi=196.8, Def{oriole}
9E53 CJK UNIFIED IDEOGRAPH-#9E53, IRGKangXi=1505.141, RSKangXi=196.8, Def{co-worker}
9E54 CJK UNIFIED IDEOGRAPH-#9E54, IRGKangXi=1505.141, RSKangXi=196.12, Def{turquoise kingfisher}
9E55 CJK UNIFIED IDEOGRAPH-#9E55, IRGKangXi=1505.141, RSKangXi=196.9, Def{pelican}
9E56 CJK UNIFIED IDEOGRAPH-#9E56, IRGKangXi=1505.141, RSKangXi=196.9, Def{crossbill, species of nightingale}
9E57 CJK UNIFIED IDEOGRAPH-#9E57, IRGKangXi=1505.141, RSKangXi=196.9, Def{osprey, fishhawk}
9E58 CJK UNIFIED IDEOGRAPH-#9E58, IRGKangXi=1505.141, RSKangXi=196.10, Def{a kind of pigeon; treron permagna}
9E59 CJK UNIFIED IDEOGRAPH-#9E59, IRGKangXi=1505.141, RSKangXi=196.9, Def{large waterfowl with naked head; Garrulus glandarius}
9E5A CJK UNIFIED IDEOGRAPH-#9E5A, IRGKangXi=1505.141, RSKangXi=196.9, Def{cormorant}
9E5B CJK UNIFIED IDEOGRAPH-#9E5B, IRGKangXi=1505.141, RSKangXi=196.9
9E5C CJK UNIFIED IDEOGRAPH-#9E5C, IRGKangXi=1505.141, RSKangXi=196.9, Def{duck}
9E5D CJK UNIFIED IDEOGRAPH-#9E5D, IRGKangXi=1505.141, RSKangXi=196.10, Def{pheasant}
9E5E CJK UNIFIED IDEOGRAPH-#9E5E, IRGKangXi=1505.141, RSKangXi=196.10, Def{sparrow hawk; kite shaped like}
9E5F CJK UNIFIED IDEOGRAPH-#9E5F, IRGKangXi=1505.141, RSKangXi=196.10
9E60 CJK UNIFIED IDEOGRAPH-#9E60, IRGKangXi=1505.141, RSKangXi=196.10, Def{the owl}
9E61 CJK UNIFIED IDEOGRAPH-#9E61, IRGKangXi=1505.141, RSKangXi=196.10, Def{wagtail}
9E62 CJK UNIFIED IDEOGRAPH-#9E62, IRGKangXi=1505.141, RSKangXi=196.10, Def{fishhawk bow or prow}
9E63 CJK UNIFIED IDEOGRAPH-#9E63, IRGKangXi=1505.141, RSKangXi=196.10, Def{fabulous mythical bird}
9E64 CJK UNIFIED IDEOGRAPH-#9E64, IRGKangXi=1505.141, RSKangXi=196.10, Def{crane; Grus species (various)}
9E65 CJK UNIFIED IDEOGRAPH-#9E65, IRGKangXi=1505.141, RSKangXi=196.11, Def{seagull}
9E66 CJK UNIFIED IDEOGRAPH-#9E66, IRGKangXi=1505.141, RSKangXi=196.11, Def{parrot}
9E67 CJK UNIFIED IDEOGRAPH-#9E67, IRGKangXi=1505.141, RSKangXi=196.11, Def{partridge}
9E68 CJK UNIFIED IDEOGRAPH-#9E68, IRGKangXi=1505.141, RSKangXi=196.11, Def{Anthus species (various)}
9E69 CJK UNIFIED IDEOGRAPH-#9E69, IRGKangXi=1505.141, RSKangXi=196.12, Def{wren}
9E6A CJK UNIFIED IDEOGRAPH-#9E6A, IRGKangXi=1505.141, RSKangXi=196.12, Def{wren}
9E6B CJK UNIFIED IDEOGRAPH-#9E6B, IRGKangXi=1505.141, RSKangXi=196.12, Def{condor, vulture}
9E6C CJK UNIFIED IDEOGRAPH-#9E6C, IRGKangXi=1505.141, RSKangXi=196.12, Def{snipe, kingfisher}
9E6D CJK UNIFIED IDEOGRAPH-#9E6D, IRGKangXi=1505.141, RSKangXi=196.13, Def{heron, egret; Ardea species (various)}
9E6E CJK UNIFIED IDEOGRAPH-#9E6E, IRGKangXi=1505.141, RSKangXi=196.13, Def{spoonbill; ibis; family Threskiornidae}
9E6F CJK UNIFIED IDEOGRAPH-#9E6F, IRGKangXi=1505.141, RSKangXi=196.13, Def{hawk; Butastur indicus}
9E70 CJK UNIFIED IDEOGRAPH-#9E70, IRGKangXi=1505.141, RSKangXi=196.13, Def{falcon; Accipiter species (various)}
9E71 CJK UNIFIED IDEOGRAPH-#9E71, IRGKangXi=1505.141, RSKangXi=196.14
9E72 CJK UNIFIED IDEOGRAPH-#9E72, IRGKangXi=1505.141, RSKangXi=196.14
9E73 CJK UNIFIED IDEOGRAPH-#9E73, IRGKangXi=1505.141, RSKangXi=196.17, Def{crane, grus japonensis; stork; Ciconia species (various)}
9E74 CJK UNIFIED IDEOGRAPH-#9E74, IRGKangXi=1505.141, RSKangXi=196.17, Def{eagle}
9E75 CJK UNIFIED IDEOGRAPH-#9E75, IRGKangXi=1507.010, RSKangXi=197.0, Def{saline soil; natural salt, rock}
9E76 CJK UNIFIED IDEOGRAPH-#9E76, IRGKangXi=1507.060, RSKangXi=197.4, Def{salty and bitter; pitiful}
9E77 CJK UNIFIED IDEOGRAPH-#9E77, IRGKangXi=1507.110, RSKangXi=197.5
9E78 CJK UNIFIED IDEOGRAPH-#9E78, IRGKangXi=1507.181, RSKangXi=197.8, Def{alkaline, alkali, lye, salt}
9E79 CJK UNIFIED IDEOGRAPH-#9E79, IRGKangXi=1507.200, RSKangXi=197.9, Def{salty, briny; salted; pickled}
9E7A CJK UNIFIED IDEOGRAPH-#9E7A, IRGKangXi=1507.290, RSKangXi=197.10, Def{salty; salt}
9E7B CJK UNIFIED IDEOGRAPH-#9E7B, IRGKangXi=1507.300, RSKangXi=197.10, Def{impure carbonate of sodium of natron}
9E7C CJK UNIFIED IDEOGRAPH-#9E7C, IRGKangXi=1508.040, RSKangXi=197.13, Def{alkaline, alkali, lye, salt}
9E7D CJK UNIFIED IDEOGRAPH-#9E7D, IRGKangXi=1508.070, RSKangXi=197.13, Def{(same as of U+5869 塩) salt}
9E7E CJK UNIFIED IDEOGRAPH-#9E7E, IRGKangXi=1508.131, RSKangXi=197.9, Def{salty; salt}
9E7F CJK UNIFIED IDEOGRAPH-#9E7F, IRGKangXi=1508.140, RSKangXi=198.0, Def{deer; surname; KangXi radical 198}
9E80 CJK UNIFIED IDEOGRAPH-#9E80, IRGKangXi=1508.150, RSKangXi=198.2, Def{female deer; roe, doe}
9E81 CJK UNIFIED IDEOGRAPH-#9E81, IRGKangXi=1509.010, RSKangXi=198.2, Def{rough, thick, course; rude}
9E82 CJK UNIFIED IDEOGRAPH-#9E82, IRGKangXi=1509.020, RSKangXi=198.2, Def{species of deer}
9E83 CJK UNIFIED IDEOGRAPH-#9E83, IRGKangXi=1509.110, RSKangXi=198.4, Def{till, plow}
9E84 CJK UNIFIED IDEOGRAPH-#9E84, IRGKangXi=1509.170, RSKangXi=198.4, Def{coarse, rough, rude}
9E85 CJK UNIFIED IDEOGRAPH-#9E85, IRGKangXi=1509.200, RSKangXi=198.5, Def{a small spotted deer found in north China}
9E86 CJK UNIFIED IDEOGRAPH-#9E86, IRGKangXi=1509.210, RSKangXi=198.5
9E87 CJK UNIFIED IDEOGRAPH-#9E87, IRGKangXi=1509.220, RSKangXi=198.5, Def{general name for the hornless deer; to collect to band together}
9E88 CJK UNIFIED IDEOGRAPH-#9E88, IRGKangXi=1509.260, RSKangXi=198.5, Def{species of deer}
9E89 CJK UNIFIED IDEOGRAPH-#9E89, IRGKangXi=1509.320, RSKangXi=198.6
9E8A CJK UNIFIED IDEOGRAPH-#9E8A, IRGKangXi=1509.330, RSKangXi=198.6
9E8B CJK UNIFIED IDEOGRAPH-#9E8B, IRGKangXi=1509.340, RSKangXi=198.6, Def{elk; surname}
9E8C CJK UNIFIED IDEOGRAPH-#9E8C, IRGKangXi=1510.040, RSKangXi=198.7, Def{stag; herd}
9E8D CJK UNIFIED IDEOGRAPH-#9E8D, IRGKangXi=1510.060, RSKangXi=198.7
9E8E CJK UNIFIED IDEOGRAPH-#9E8E, IRGKangXi=1510.070, RSKangXi=198.7
9E8F CJK UNIFIED IDEOGRAPH-#9E8F, IRGKangXi=1510.090, RSKangXi=198.7
9E90 CJK UNIFIED IDEOGRAPH-#9E90, IRGKangXi=1510.130, RSKangXi=198.7, Def{female of Chinese unicorn}
9E91 CJK UNIFIED IDEOGRAPH-#9E91, IRGKangXi=1510.230, RSKangXi=198.8, Def{fawn, young deer}
9E92 CJK UNIFIED IDEOGRAPH-#9E92, IRGKangXi=1510.240, RSKangXi=198.8, Def{legendary auspicious animal}
9E93 CJK UNIFIED IDEOGRAPH-#9E93, IRGKangXi=1510.250, RSKangXi=198.8, Def{foot of hill; foothill}
9E94 CJK UNIFIED IDEOGRAPH-#9E94, IRGKangXi=1510.270, RSKangXi=198.8
9E95 CJK UNIFIED IDEOGRAPH-#9E95, IRGKangXi=1510.280, RSKangXi=198.8, Def{muntjac deer, hornless river deer}
9E96 CJK UNIFIED IDEOGRAPH-#9E96, IRGKangXi=1510.290, RSKangXi=198.8
9E97 CJK UNIFIED IDEOGRAPH-#9E97, IRGKangXi=1510.310, RSKangXi=198.8, Def{beautiful, magnificent, elegant}
9E98 CJK UNIFIED IDEOGRAPH-#9E98, IRGKangXi=1511.020, RSKangXi=198.9, Def{scent}
9E99 CJK UNIFIED IDEOGRAPH-#9E99, IRGKangXi=1511.030, RSKangXi=198.9
9E9A CJK UNIFIED IDEOGRAPH-#9E9A, IRGKangXi=1511.040, RSKangXi=198.9
9E9B CJK UNIFIED IDEOGRAPH-#9E9B, IRGKangXi=1511.080, RSKangXi=198.9, Def{fawn}
9E9C CJK UNIFIED IDEOGRAPH-#9E9C, IRGKangXi=1511.110, RSKangXi=198.10
9E9D CJK UNIFIED IDEOGRAPH-#9E9D, IRGKangXi=1511.130, RSKangXi=198.10, Def{musk deer}
9E9E CJK UNIFIED IDEOGRAPH-#9E9E, IRGKangXi=1511.190, RSKangXi=198.11, Def{roebuck, Moschus chinloo}
9E9F CJK UNIFIED IDEOGRAPH-#9E9F, IRGKangXi=1511.200, RSKangXi=198.12, Def{female of Chinese unicorn}
9EA0 CJK UNIFIED IDEOGRAPH-#9EA0, IRGKangXi=1511.260, RSKangXi=198.13, Def{a large deer}
9EA1 CJK UNIFIED IDEOGRAPH-#9EA1, IRGKangXi=1511.290, RSKangXi=198.14
9EA2 CJK UNIFIED IDEOGRAPH-#9EA2, IRGKangXi=1512.030
9EA3 CJK UNIFIED IDEOGRAPH-#9EA3, IRGKangXi=1512.050, RSKangXi=198.20
9EA4 CJK UNIFIED IDEOGRAPH-#9EA4, IRGKangXi=1512.060, RSKangXi=198.22, Def{rough, coarse, big, rough}
9EA5 CJK UNIFIED IDEOGRAPH-#9EA5, IRGKangXi=1512.080, RSKangXi=199.0, Def{wheat, barley, oats; KangXi radical number 199}
9EA6 CJK UNIFIED IDEOGRAPH-#9EA6, IRGKangXi=1512.090, RSKangXi=199.0, Def{wheat, barley, oats; simplified form of KangXi radical number 199}
9EA7 CJK UNIFIED IDEOGRAPH-#9EA7, IRGKangXi=1512.180, RSKangXi=199.3
9EA8 CJK UNIFIED IDEOGRAPH-#9EA8, IRGKangXi=1512.210, RSKangXi=199.4
9EA9 CJK UNIFIED IDEOGRAPH-#9EA9, IRGKangXi=1512.270, RSKangXi=199.4, Def{bran}
9EAA CJK UNIFIED IDEOGRAPH-#9EAA, IRGKangXi=1512.300, RSKangXi=199.4, Def{flour, noodles, dough}
9EAB CJK UNIFIED IDEOGRAPH-#9EAB, IRGKangXi=1513.021, RSKangXi=199.4, Def{flour; vermicelli; dough}
9EAC CJK UNIFIED IDEOGRAPH-#9EAC, IRGKangXi=1513.050, RSKangXi=199.5
9EAD CJK UNIFIED IDEOGRAPH-#9EAD, IRGKangXi=1513.080, RSKangXi=199.5, Def{a sticky rice ball}
9EAE CJK UNIFIED IDEOGRAPH-#9EAE, IRGKangXi=1513.140, RSKangXi=199.5, Def{porridge}
9EAF CJK UNIFIED IDEOGRAPH-#9EAF, IRGKangXi=1513.190, RSKangXi=199.6, Def{yeast, leaven}
9EB0 CJK UNIFIED IDEOGRAPH-#9EB0, IRGKangXi=1513.220, RSKangXi=199.6, Def{barley}
9EB1 CJK UNIFIED IDEOGRAPH-#9EB1, IRGKangXi=1513.290, RSKangXi=199.7
9EB2 CJK UNIFIED IDEOGRAPH-#9EB2, IRGKangXi=1513.300, RSKangXi=199.7
9EB3 CJK UNIFIED IDEOGRAPH-#9EB3, IRGKangXi=1513.430, RSKangXi=199.8
9EB4 CJK UNIFIED IDEOGRAPH-#9EB4, IRGKangXi=1513.520, RSKangXi=199.8, Def{yeast, leaven; surname}
9EB5 CJK UNIFIED IDEOGRAPH-#9EB5, IRGKangXi=1514.070, RSKangXi=199.9, Def{flour, dough, noodles}
9EB6 CJK UNIFIED IDEOGRAPH-#9EB6, IRGKangXi=1514.361, RSKangXi=199.11
9EB7 CJK UNIFIED IDEOGRAPH-#9EB7, IRGKangXi=1514.550, RSKangXi=199.18
9EB8 CJK UNIFIED IDEOGRAPH-#9EB8, IRGKangXi=1514.571, RSKangXi=199.4, Def{bran}
9EB9 CJK UNIFIED IDEOGRAPH-#9EB9, IRGKangXi=1514.571, RSKangXi=199.8, Def{yeast, leaven; surname}
9EBA CJK UNIFIED IDEOGRAPH-#9EBA, IRGKangXi=1514.571, RSKangXi=199.9, Def{flour, dough, noodles}
9EBB CJK UNIFIED IDEOGRAPH-#9EBB, IRGKangXi=1515.010, RSKangXi=200.0, Def{hemp, jute, flax; sesame}
9EBC CJK UNIFIED IDEOGRAPH-#9EBC, IRGKangXi=1515.050, RSKangXi=200.3, Def{interrogative final particle; insignificant, small, tiny}
9EBD CJK UNIFIED IDEOGRAPH-#9EBD, IRGKangXi=1515.071, RSKangXi=200.3, Def{interrogative final particle; insignificant, small, tiny}
9EBE CJK UNIFIED IDEOGRAPH-#9EBE, IRGKangXi=1515.130, RSKangXi=200.4, Def{a pennant, flag, banner; to signal to}
9EBF CJK UNIFIED IDEOGRAPH-#9EBF, IRGKangXi=1515.211, RSKangXi=200.7, Def{I, personal name marker}
9EC0 CJK UNIFIED IDEOGRAPH-#9EC0, IRGKangXi=1515.230, RSKangXi=200.8
9EC1 CJK UNIFIED IDEOGRAPH-#9EC1, IRGKangXi=1515.260, RSKangXi=200.9
9EC2 CJK UNIFIED IDEOGRAPH-#9EC2, IRGKangXi=1515.350, RSKangXi=200.13
9EC3 CJK UNIFIED IDEOGRAPH-#9EC3, IRGKangXi=1516.030, RSKangXi=201.0, Def{yellow; surname}
9EC4 CJK UNIFIED IDEOGRAPH-#9EC4, IRGKangXi=1516.041, RSKangXi=201.0, Def{yellow; surname}
9EC5 CJK UNIFIED IDEOGRAPH-#9EC5, IRGKangXi=1516.050, RSKangXi=201.4
9EC6 CJK UNIFIED IDEOGRAPH-#9EC6, IRGKangXi=1516.060, RSKangXi=201.4
9EC7 CJK UNIFIED IDEOGRAPH-#9EC7, IRGKangXi=1516.100, RSKangXi=201.5
9EC8 CJK UNIFIED IDEOGRAPH-#9EC8, IRGKangXi=1516.120, RSKangXi=201.5, Def{yellow; augment, increase}
9EC9 CJK UNIFIED IDEOGRAPH-#9EC9, IRGKangXi=1516.121, RSKangXi=201.5, Def{school}
9ECA CJK UNIFIED IDEOGRAPH-#9ECA, IRGKangXi=1516.160, RSKangXi=201.6
9ECB CJK UNIFIED IDEOGRAPH-#9ECB, IRGKangXi=1516.190, RSKangXi=201.6
9ECC CJK UNIFIED IDEOGRAPH-#9ECC, IRGKangXi=1517.220, RSKangXi=201.13, Def{school}
9ECD CJK UNIFIED IDEOGRAPH-#9ECD, IRGKangXi=1517.250, RSKangXi=202.0, Def{glutinous millet; KangXi radical number 202}
9ECE CJK UNIFIED IDEOGRAPH-#9ECE, IRGKangXi=1517.280, RSKangXi=202.3, Def{surname; numerous, many; black}
9ECF CJK UNIFIED IDEOGRAPH-#9ECF, IRGKangXi=1518.050, RSKangXi=202.5, Def{stick to; glutinous, sticky; glue}
9ED0 CJK UNIFIED IDEOGRAPH-#9ED0, IRGKangXi=1518.260, RSKangXi=202.10, Def{to stick; sticky}
9ED1 CJK UNIFIED IDEOGRAPH-#9ED1, IRGKangXi=1518.360, RSKangXi=203.0, Def{black; dark; evil, sinister}
9ED2 CJK UNIFIED IDEOGRAPH-#9ED2, IRGKangXi=1518.361, RSKangXi=203.0, Def{black; dark; evil}
9ED3 CJK UNIFIED IDEOGRAPH-#9ED3, IRGKangXi=1519.010, RSKangXi=203.3, Def{black}
9ED4 CJK UNIFIED IDEOGRAPH-#9ED4, IRGKangXi=1519.040, RSKangXi=203.4, Def{black; Guizhou}
9ED5 CJK UNIFIED IDEOGRAPH-#9ED5, IRGKangXi=1519.060, RSKangXi=203.4, Def{red}
9ED6 CJK UNIFIED IDEOGRAPH-#9ED6, IRGKangXi=1519.070, RSKangXi=203.4
9ED7 CJK UNIFIED IDEOGRAPH-#9ED7, IRGKangXi=1519.100, RSKangXi=203.4
9ED8 CJK UNIFIED IDEOGRAPH-#9ED8, IRGKangXi=1519.110, RSKangXi=203.4, Def{silent; quiet, still; dark}
9ED9 CJK UNIFIED IDEOGRAPH-#9ED9, IRGKangXi=1519.181, RSKangXi=203.4, Def{silent; quiet, still; dark}
9EDA CJK UNIFIED IDEOGRAPH-#9EDA, IRGKangXi=1519.190, RSKangXi=203.5
9EDB CJK UNIFIED IDEOGRAPH-#9EDB, IRGKangXi=1519.200, RSKangXi=203.5, Def{blacken eyebrows; black}
9EDC CJK UNIFIED IDEOGRAPH-#9EDC, IRGKangXi=1519.210, RSKangXi=203.5, Def{dismiss; demote, downgrade}
9EDD CJK UNIFIED IDEOGRAPH-#9EDD, IRGKangXi=1519.270, RSKangXi=203.5, Def{black}
9EDE CJK UNIFIED IDEOGRAPH-#9EDE, IRGKangXi=1519.280, RSKangXi=203.5, Def{dot, speck, spot; point, degree}
9EDF CJK UNIFIED IDEOGRAPH-#9EDF, IRGKangXi=1519.320, RSKangXi=203.6, Def{black and shining; ebony}
9EE0 CJK UNIFIED IDEOGRAPH-#9EE0, IRGKangXi=1520.050, RSKangXi=203.6, Def{sly, cunning, shrewd; artful}
9EE1 CJK UNIFIED IDEOGRAPH-#9EE1, IRGKangXi=1520.061, RSKangXi=203.6, Def{mole, scar, blemish}
9EE2 CJK UNIFIED IDEOGRAPH-#9EE2, IRGKangXi=1520.070, RSKangXi=203.7, Def{black}
9EE3 CJK UNIFIED IDEOGRAPH-#9EE3, IRGKangXi=1520.140, RSKangXi=203.7
9EE4 CJK UNIFIED IDEOGRAPH-#9EE4, IRGKangXi=1520.200, RSKangXi=203.8, Def{blue-black}
9EE5 CJK UNIFIED IDEOGRAPH-#9EE5, IRGKangXi=1520.260, RSKangXi=203.8, Def{to tattoo; to brand the face of criminals}
9EE6 CJK UNIFIED IDEOGRAPH-#9EE6, IRGKangXi=1520.310, RSKangXi=203.8
9EE7 CJK UNIFIED IDEOGRAPH-#9EE7, IRGKangXi=1520.350, RSKangXi=203.8, Def{a dark, sallow colour}
9EE8 CJK UNIFIED IDEOGRAPH-#9EE8, IRGKangXi=1520.360, RSKangXi=203.8, Def{political party, gang, faction}
9EE9 CJK UNIFIED IDEOGRAPH-#9EE9, IRGKangXi=1521.011, RSKangXi=203.8, Def{to dishonor, defile, corrupt; soiled}
9EEA CJK UNIFIED IDEOGRAPH-#9EEA, IRGKangXi=1521.011, RSKangXi=203.8, Def{grey black}
9EEB CJK UNIFIED IDEOGRAPH-#9EEB, IRGKangXi=1521.070, RSKangXi=203.9
9EEC CJK UNIFIED IDEOGRAPH-#9EEC, IRGKangXi=1521.120, RSKangXi=203.9, Def{blackhead}
9EED CJK UNIFIED IDEOGRAPH-#9EED, IRGKangXi=1521.140, RSKangXi=203.9
9EEE CJK UNIFIED IDEOGRAPH-#9EEE, IRGKangXi=1521.190, RSKangXi=203.9, Def{black, dark; unclear; private}
9EEF CJK UNIFIED IDEOGRAPH-#9EEF, IRGKangXi=1521.230, RSKangXi=180.12, Def{dark, black; sullen, dreary}
9EF0 CJK UNIFIED IDEOGRAPH-#9EF0, IRGKangXi=1521.350, RSKangXi=203.10, Def{young girl's hair style}
9EF1 CJK UNIFIED IDEOGRAPH-#9EF1, IRGKangXi=1521.370, RSKangXi=203.10
9EF2 CJK UNIFIED IDEOGRAPH-#9EF2, IRGKangXi=1521.390, RSKangXi=203.11, Def{grey black}
9EF3 CJK UNIFIED IDEOGRAPH-#9EF3, IRGKangXi=1521.420, RSKangXi=203.11
9EF4 CJK UNIFIED IDEOGRAPH-#9EF4, IRGKangXi=1521.470, RSKangXi=203.11, Def{mold, mildew; bacteria, fungi}
9EF5 CJK UNIFIED IDEOGRAPH-#9EF5, IRGKangXi=1522.170, RSKangXi=203.13
9EF6 CJK UNIFIED IDEOGRAPH-#9EF6, IRGKangXi=1522.310, RSKangXi=203.14, Def{mole, scar, blemish}
9EF7 CJK UNIFIED IDEOGRAPH-#9EF7, IRGKangXi=1522.350, RSKangXi=203.15, Def{to dishonor, defile, corrupt; soiled}
9EF8 CJK UNIFIED IDEOGRAPH-#9EF8, IRGKangXi=1522.390, RSKangXi=203.16
9EF9 CJK UNIFIED IDEOGRAPH-#9EF9, IRGKangXi=1522.450, RSKangXi=204.0, Def{embroidery, needlework; radical}
9EFA CJK UNIFIED IDEOGRAPH-#9EFA, IRGKangXi=1523.010, RSKangXi=204.4
9EFB CJK UNIFIED IDEOGRAPH-#9EFB, IRGKangXi=1523.020, RSKangXi=204.5, Def{special pattern of embroidery}
9EFC CJK UNIFIED IDEOGRAPH-#9EFC, IRGKangXi=1523.040, RSKangXi=204.7, Def{embroidered official or sacrificial robe}
9EFD CJK UNIFIED IDEOGRAPH-#9EFD, IRGKangXi=1523.090, RSKangXi=205.0, Def{to strive; to endeavor}
9EFE CJK UNIFIED IDEOGRAPH-#9EFE, IRGKangXi=1523.100, RSKangXi=205.0, Def{to strive; to endeavor}
9EFF CJK UNIFIED IDEOGRAPH-#9EFF, IRGKangXi=1523.110, RSKangXi=205.4, Def{large turtle, sea turtle}
9F00 CJK UNIFIED IDEOGRAPH-#9F00, IRGKangXi=1523.160, RSKangXi=205.5
9F01 CJK UNIFIED IDEOGRAPH-#9F01, IRGKangXi=1524.020, RSKangXi=205.5
9F02 CJK UNIFIED IDEOGRAPH-#9F02, IRGKangXi=1524.040, RSKangXi=205.5, Def{a kind of sea turtle; surname}
9F03 CJK UNIFIED IDEOGRAPH-#9F03, IRGKangXi=1524.100, RSKangXi=205.6, Def{the edible water-frog}
9F04 CJK UNIFIED IDEOGRAPH-#9F04, IRGKangXi=1524.110, RSKangXi=205.6, Def{the spider}
9F05 CJK UNIFIED IDEOGRAPH-#9F05, IRGKangXi=1524.140, RSKangXi=205.8, Def{spider}
9F06 CJK UNIFIED IDEOGRAPH-#9F06, IRGKangXi=1524.230, RSKangXi=205.10
9F07 CJK UNIFIED IDEOGRAPH-#9F07, IRGKangXi=1524.240, RSKangXi=205.10, Def{huge sea turtle}
9F08 CJK UNIFIED IDEOGRAPH-#9F08, IRGKangXi=1524.270, RSKangXi=205.12, Def{a fresh-water turtle, Trionyx sinensis}
9F09 CJK UNIFIED IDEOGRAPH-#9F09, IRGKangXi=1525.010, RSKangXi=205.12, Def{large reptile, water lizard}
9F0A CJK UNIFIED IDEOGRAPH-#9F0A, IRGKangXi=1525.030, RSKangXi=205.13
9F0B CJK UNIFIED IDEOGRAPH-#9F0B, IRGKangXi=1525.071, RSKangXi=213.4, Def{large turtle, sea turtle}
9F0C CJK UNIFIED IDEOGRAPH-#9F0C, IRGKangXi=1525.071, RSKangXi=205.5
9F0D CJK UNIFIED IDEOGRAPH-#9F0D, IRGKangXi=1525.071, RSKangXi=205.12, Def{large reptile, water lizard}
9F0E CJK UNIFIED IDEOGRAPH-#9F0E, IRGKangXi=1525.080, RSKangXi=206.0, Def{large, three-legged bronze caldron}
9F0F CJK UNIFIED IDEOGRAPH-#9F0F, IRGKangXi=1525.110, RSKangXi=206.2, Def{cover of tripod caldron}
9F10 CJK UNIFIED IDEOGRAPH-#9F10, IRGKangXi=1525.120, RSKangXi=206.2, Def{incense tripod}
9F11 CJK UNIFIED IDEOGRAPH-#9F11, IRGKangXi=1525.130, RSKangXi=206.2
9F12 CJK UNIFIED IDEOGRAPH-#9F12, IRGKangXi=1525.150, RSKangXi=206.3, Def{large tripod caldron with small mouth}
9F13 CJK UNIFIED IDEOGRAPH-#9F13, IRGKangXi=1526.010, RSKangXi=207.0, Def{drum; beat, top, strike}
9F14 CJK UNIFIED IDEOGRAPH-#9F14, IRGKangXi=1526.030, RSKangXi=207.0, Def{a drum; to drum, from whence comes: to rouse; to swell; to bulge}
9F15 CJK UNIFIED IDEOGRAPH-#9F15, IRGKangXi=1526.100, RSKangXi=207.5, Def{rattle of drums}
9F16 CJK UNIFIED IDEOGRAPH-#9F16, IRGKangXi=1526.130, RSKangXi=207.5, Def{drum}
9F17 CJK UNIFIED IDEOGRAPH-#9F17, IRGKangXi=1526.210, RSKangXi=207.6, Def{small revolving drum with knobs}
9F18 CJK UNIFIED IDEOGRAPH-#9F18, IRGKangXi=1526.260, RSKangXi=207.8
9F19 CJK UNIFIED IDEOGRAPH-#9F19, IRGKangXi=1526.270, RSKangXi=207.8, Def{drum carried on horseback}
9F1A CJK UNIFIED IDEOGRAPH-#9F1A, IRGKangXi=1526.280, RSKangXi=207.8, Def{drumming}
9F1B CJK UNIFIED IDEOGRAPH-#9F1B, IRGKangXi=1526.310, RSKangXi=207.8, Def{drum}
9F1C CJK UNIFIED IDEOGRAPH-#9F1C, IRGKangXi=1527.030, RSKangXi=207.10
9F1D CJK UNIFIED IDEOGRAPH-#9F1D, IRGKangXi=1527.050, RSKangXi=207.11
9F1E CJK UNIFIED IDEOGRAPH-#9F1E, IRGKangXi=1527.060, RSKangXi=207.11
9F1F CJK UNIFIED IDEOGRAPH-#9F1F, IRGKangXi=1527.090, RSKangXi=207.12
9F20 CJK UNIFIED IDEOGRAPH-#9F20, IRGKangXi=1527.140, RSKangXi=208.0, Def{rat, mouse; KangXi radical 208}
9F21 CJK UNIFIED IDEOGRAPH-#9F21, IRGKangXi=1527.141, RSKangXi=208.0, Def{rat, mouse}
9F22 CJK UNIFIED IDEOGRAPH-#9F22, IRGKangXi=1527.230, RSKangXi=208.4, Def{a variety of mole}
9F23 CJK UNIFIED IDEOGRAPH-#9F23, IRGKangXi=1527.270, RSKangXi=208.4
9F24 CJK UNIFIED IDEOGRAPH-#9F24, IRGKangXi=1527.300, RSKangXi=208.4
9F25 CJK UNIFIED IDEOGRAPH-#9F25, IRGKangXi=1528.010, RSKangXi=208.5
9F26 CJK UNIFIED IDEOGRAPH-#9F26, IRGKangXi=1528.040, RSKangXi=208.5
9F27 CJK UNIFIED IDEOGRAPH-#9F27, IRGKangXi=1528.060, RSKangXi=208.5, Def{the marmot}
9F28 CJK UNIFIED IDEOGRAPH-#9F28, IRGKangXi=1528.090, RSKangXi=208.5
9F29 CJK UNIFIED IDEOGRAPH-#9F29, IRGKangXi=1528.100, RSKangXi=208.5
9F2A CJK UNIFIED IDEOGRAPH-#9F2A, IRGKangXi=1528.110, RSKangXi=208.5, Def{weasel}
9F2B CJK UNIFIED IDEOGRAPH-#9F2B, IRGKangXi=1528.120, RSKangXi=208.5, Def{marmot; squirrel}
9F2C CJK UNIFIED IDEOGRAPH-#9F2C, IRGKangXi=1528.140, RSKangXi=208.5, Def{weasel, mustela itatis}
9F2D CJK UNIFIED IDEOGRAPH-#9F2D, IRGKangXi=1528.200, RSKangXi=208.6
9F2E CJK UNIFIED IDEOGRAPH-#9F2E, IRGKangXi=1528.220, RSKangXi=208.7
9F2F CJK UNIFIED IDEOGRAPH-#9F2F, IRGKangXi=1528.250, RSKangXi=208.7, Def{flying squirrel}
9F30 CJK UNIFIED IDEOGRAPH-#9F30, IRGKangXi=1528.310, RSKangXi=208.7
9F31 CJK UNIFIED IDEOGRAPH-#9F31, IRGKangXi=1528.350, RSKangXi=208.8
9F32 CJK UNIFIED IDEOGRAPH-#9F32, IRGKangXi=1529.050, RSKangXi=208.9
9F33 CJK UNIFIED IDEOGRAPH-#9F33, IRGKangXi=1529.060, RSKangXi=208.9
9F34 CJK UNIFIED IDEOGRAPH-#9F34, IRGKangXi=1529.100, RSKangXi=208.9, Def{a kind of insectivorous rodent}
9F35 CJK UNIFIED IDEOGRAPH-#9F35, IRGKangXi=1529.110, RSKangXi=208.9
9F36 CJK UNIFIED IDEOGRAPH-#9F36, IRGKangXi=1529.200, RSKangXi=208.10
9F37 CJK UNIFIED IDEOGRAPH-#9F37, IRGKangXi=1529.220, RSKangXi=208.10, Def{a mouse}
9F38 CJK UNIFIED IDEOGRAPH-#9F38, IRGKangXi=1529.230, RSKangXi=208.10
9F39 CJK UNIFIED IDEOGRAPH-#9F39, IRGKangXi=1529.250, RSKangXi=208.10, Def{a kind of insectivorous rodent}
9F3A CJK UNIFIED IDEOGRAPH-#9F3A, IRGKangXi=1529.350, RSKangXi=208.15
9F3B CJK UNIFIED IDEOGRAPH-#9F3B, IRGKangXi=1530.010, RSKangXi=209.0, Def{nose; first; KangXi radical 209}
9F3C CJK UNIFIED IDEOGRAPH-#9F3C, IRGKangXi=1530.040, RSKangXi=209.2, Def{(Cant.) curving upwards}
9F3D CJK UNIFIED IDEOGRAPH-#9F3D, IRGKangXi=1530.060, RSKangXi=209.2, Def{clogged nose}
9F3E CJK UNIFIED IDEOGRAPH-#9F3E, IRGKangXi=1530.080, RSKangXi=209.3, Def{snore loudly}
9F3F CJK UNIFIED IDEOGRAPH-#9F3F, IRGKangXi=1530.090, RSKangXi=209.3
9F40 CJK UNIFIED IDEOGRAPH-#9F40, IRGKangXi=1530.170, RSKangXi=209.5
9F41 CJK UNIFIED IDEOGRAPH-#9F41, IRGKangXi=1530.200, RSKangXi=209.5, Def{snore loudly; very, extremely}
9F42 CJK UNIFIED IDEOGRAPH-#9F42, IRGKangXi=1530.330, RSKangXi=209.8
9F43 CJK UNIFIED IDEOGRAPH-#9F43, IRGKangXi=1530.350, RSKangXi=209.9
9F44 CJK UNIFIED IDEOGRAPH-#9F44, IRGKangXi=1530.361, RSKangXi=209.9, Def{red sores on nose}
9F45 CJK UNIFIED IDEOGRAPH-#9F45, IRGKangXi=1530.380, RSKangXi=209.10, Def{smell; to smell}
9F46 CJK UNIFIED IDEOGRAPH-#9F46, IRGKangXi=1530.390, RSKangXi=209.10, Def{stuffed nose}
9F47 CJK UNIFIED IDEOGRAPH-#9F47, IRGKangXi=1530.400, RSKangXi=209.11
9F48 CJK UNIFIED IDEOGRAPH-#9F48, IRGKangXi=1531.010, RSKangXi=209.13, Def{cold in the head; catarrh of the nose; mucus from the nose}
9F49 CJK UNIFIED IDEOGRAPH-#9F49, IRGKangXi=1531.051, RSKangXi=209.22, Def{stoppage of the nose to speak with a nasal twang}
9F4A CJK UNIFIED IDEOGRAPH-#9F4A, IRGKangXi=1531.060, RSKangXi=210.0, Def{even, uniform, of equal length}
9F4B CJK UNIFIED IDEOGRAPH-#9F4B, IRGKangXi=1531.120, RSKangXi=210.3, Def{vegetarian diet; study; to fast, abstain}
9F4C CJK UNIFIED IDEOGRAPH-#9F4C, IRGKangXi=1531.140, RSKangXi=210.4
9F4D CJK UNIFIED IDEOGRAPH-#9F4D, IRGKangXi=1531.160, RSKangXi=210.5
9F4E CJK UNIFIED IDEOGRAPH-#9F4E, IRGKangXi=1532.020, RSKangXi=210.7, Def{take in both hands and offer to}
9F4F CJK UNIFIED IDEOGRAPH-#9F4F, IRGKangXi=1532.040, RSKangXi=210.9, Def{break or smash into pieces, pulverize; hash}
9F50 CJK UNIFIED IDEOGRAPH-#9F50, IRGKangXi=1532.071, RSKangXi=210.0, Def{even, uniform, of equal length}
9F51 CJK UNIFIED IDEOGRAPH-#9F51, IRGKangXi=1532.071, RSKangXi=210.9, Def{break or smash into pieces, pulverize; hash}
9F52 CJK UNIFIED IDEOGRAPH-#9F52, IRGKangXi=1532.080, RSKangXi=211.0, Def{teeth; gears, cogs; age; KangXi radical 211}
9F53 CJK UNIFIED IDEOGRAPH-#9F53, IRGKangXi=1532.140, RSKangXi=211.1
9F54 CJK UNIFIED IDEOGRAPH-#9F54, IRGKangXi=1532.160, RSKangXi=211.2, Def{lose baby teeth and get adult teeth}
9F55 CJK UNIFIED IDEOGRAPH-#9F55, IRGKangXi=1532.180, RSKangXi=211.3, Def{gnaw, bite, nibble}
9F56 CJK UNIFIED IDEOGRAPH-#9F56, IRGKangXi=1532.260, RSKangXi=211.4
9F57 CJK UNIFIED IDEOGRAPH-#9F57, IRGKangXi=1532.270, RSKangXi=211.4, Def{gums (of the teeth); to dispute}
9F58 CJK UNIFIED IDEOGRAPH-#9F58, IRGKangXi=1533.030, RSKangXi=211.4
9F59 CJK UNIFIED IDEOGRAPH-#9F59, IRGKangXi=1533.070, RSKangXi=211.5, Def{projecting teeth}
9F5A CJK UNIFIED IDEOGRAPH-#9F5A, IRGKangXi=1533.090, RSKangXi=211.5, Def{to chew}
9F5B CJK UNIFIED IDEOGRAPH-#9F5B, IRGKangXi=1533.120, RSKangXi=211.5
9F5C CJK UNIFIED IDEOGRAPH-#9F5C, IRGKangXi=1533.140, RSKangXi=211.5, Def{to show the teeth; crooked teeth}
9F5D CJK UNIFIED IDEOGRAPH-#9F5D, IRGKangXi=1533.160, RSKangXi=211.5, Def{to chew the cud}
9F5E CJK UNIFIED IDEOGRAPH-#9F5E, IRGKangXi=1533.200, RSKangXi=211.5, Def{to display the teeth}
9F5F CJK UNIFIED IDEOGRAPH-#9F5F, IRGKangXi=1533.210, RSKangXi=211.5, Def{irregular teeth; discord}
9F60 CJK UNIFIED IDEOGRAPH-#9F60, IRGKangXi=1533.250, RSKangXi=211.5, Def{lose baby teeth and get adult teeth}
9F61 CJK UNIFIED IDEOGRAPH-#9F61, IRGKangXi=1533.260, RSKangXi=211.5, Def{age; years}
9F62 CJK UNIFIED IDEOGRAPH-#9F62, IRGKangXi=1533.281, RSKangXi=211.5, Def{age; years}
9F63 CJK UNIFIED IDEOGRAPH-#9F63, IRGKangXi=1533.281, RSKangXi=211.5, Def{act; stanza; time, occasion}
9F64 CJK UNIFIED IDEOGRAPH-#9F64, IRGKangXi=1533.330, RSKangXi=211.6
9F65 CJK UNIFIED IDEOGRAPH-#9F65, IRGKangXi=1533.370, RSKangXi=211.6
9F66 CJK UNIFIED IDEOGRAPH-#9F66, IRGKangXi=1534.020, RSKangXi=211.6, Def{gums}
9F67 CJK UNIFIED IDEOGRAPH-#9F67, IRGKangXi=1534.040, RSKangXi=211.6, Def{bite, gnaw; wear down, erode}
9F68 CJK UNIFIED IDEOGRAPH-#9F68, IRGKangXi=1534.050, RSKangXi=211.6
9F69 CJK UNIFIED IDEOGRAPH-#9F69, IRGKangXi=1534.060, RSKangXi=211.6, Def{to chew; to bite}
9F6A CJK UNIFIED IDEOGRAPH-#9F6A, IRGKangXi=1534.130, RSKangXi=211.7, Def{narrow, small; dirty}
9F6B CJK UNIFIED IDEOGRAPH-#9F6B, IRGKangXi=1534.200, RSKangXi=211.7
9F6C CJK UNIFIED IDEOGRAPH-#9F6C, IRGKangXi=1534.220, RSKangXi=211.7, Def{uneven teeth; to disagree}
9F6D CJK UNIFIED IDEOGRAPH-#9F6D, IRGKangXi=1534.290, RSKangXi=211.8, Def{toothache}
9F6E CJK UNIFIED IDEOGRAPH-#9F6E, IRGKangXi=1534.350, RSKangXi=211.8, Def{bite}
9F6F CJK UNIFIED IDEOGRAPH-#9F6F, IRGKangXi=1534.380, RSKangXi=211.8, Def{teeth grown in old age}
9F70 CJK UNIFIED IDEOGRAPH-#9F70, IRGKangXi=1534.410, RSKangXi=211.8, Def{to bite}
9F71 CJK UNIFIED IDEOGRAPH-#9F71, IRGKangXi=1535.010, RSKangXi=211.8
9F72 CJK UNIFIED IDEOGRAPH-#9F72, IRGKangXi=1535.050, RSKangXi=211.9, Def{tooth decay}
9F73 CJK UNIFIED IDEOGRAPH-#9F73, IRGKangXi=1535.090, RSKangXi=211.9, Def{toothless}
9F74 CJK UNIFIED IDEOGRAPH-#9F74, IRGKangXi=1535.110, RSKangXi=211.9
9F75 CJK UNIFIED IDEOGRAPH-#9F75, IRGKangXi=1535.120, RSKangXi=211.9, Def{uneven (teeth)}
9F76 CJK UNIFIED IDEOGRAPH-#9F76, IRGKangXi=1535.140, RSKangXi=211.9, Def{palate, roof of mouth}
9F77 CJK UNIFIED IDEOGRAPH-#9F77, IRGKangXi=1535.160, RSKangXi=211.9, Def{narrow, small; dirty}
9F78 CJK UNIFIED IDEOGRAPH-#9F78, IRGKangXi=1535.230, RSKangXi=211.10
9F79 CJK UNIFIED IDEOGRAPH-#9F79, IRGKangXi=1535.240, RSKangXi=211.10
9F7A CJK UNIFIED IDEOGRAPH-#9F7A, IRGKangXi=1535.310, RSKangXi=211.10
9F7B CJK UNIFIED IDEOGRAPH-#9F7B, IRGKangXi=1535.330, RSKangXi=211.10
9F7C CJK UNIFIED IDEOGRAPH-#9F7C, IRGKangXi=1536.130, RSKangXi=211.13
9F7D CJK UNIFIED IDEOGRAPH-#9F7D, IRGKangXi=1536.190, RSKangXi=211.13
9F7E CJK UNIFIED IDEOGRAPH-#9F7E, IRGKangXi=1536.310, RSKangXi=211.20
9F7F CJK UNIFIED IDEOGRAPH-#9F7F, IRGKangXi=1536.321, RSKangXi=211.0, Def{teeth; gears, cogs; age; simplified form of the KangXi radical number 211}
9F80 CJK UNIFIED IDEOGRAPH-#9F80, IRGKangXi=1536.321, RSKangXi=211.2, Def{lose baby teeth and get adult teeth}
9F81 CJK UNIFIED IDEOGRAPH-#9F81, IRGKangXi=1536.321, RSKangXi=211.3, Def{gnaw, bite, nibble}
9F82 CJK UNIFIED IDEOGRAPH-#9F82, IRGKangXi=1536.321, RSKangXi=211.4, Def{gums (of the teeth); to dispute}
9F83 CJK UNIFIED IDEOGRAPH-#9F83, IRGKangXi=1536.321, RSKangXi=211.5, Def{irregular teeth; discord}
9F84 CJK UNIFIED IDEOGRAPH-#9F84, IRGKangXi=1536.321, RSKangXi=211.5, Def{age; years}
9F85 CJK UNIFIED IDEOGRAPH-#9F85, IRGKangXi=1536.321, RSKangXi=211.5, Def{teeth protrude}
9F86 CJK UNIFIED IDEOGRAPH-#9F86, IRGKangXi=1536.321, RSKangXi=211.5, Def{lose baby teeth and get adult teeth}
9F87 CJK UNIFIED IDEOGRAPH-#9F87, IRGKangXi=1536.321, RSKangXi=211.6, Def{to show the teeth; crooked teeth}
9F88 CJK UNIFIED IDEOGRAPH-#9F88, IRGKangXi=1536.321, RSKangXi=211.6, Def{gums}
9F89 CJK UNIFIED IDEOGRAPH-#9F89, IRGKangXi=1536.321, RSKangXi=211.7, Def{uneven teeth; to disagree}
9F8A CJK UNIFIED IDEOGRAPH-#9F8A, IRGKangXi=1536.321, RSKangXi=211.7, Def{narrow, small; dirty}
9F8B CJK UNIFIED IDEOGRAPH-#9F8B, IRGKangXi=1536.321, RSKangXi=211.9, Def{tooth decay}
9F8C CJK UNIFIED IDEOGRAPH-#9F8C, IRGKangXi=1536.321, RSKangXi=211.9, Def{narrow, small; dirty}
9F8D CJK UNIFIED IDEOGRAPH-#9F8D, IRGKangXi=1536.330, RSKangXi=212.0, Def{dragon; symbolic of emperor}
9F8E CJK UNIFIED IDEOGRAPH-#9F8E, IRGKangXi=1536.411, RSKangXi=212.2, Def{disorderly, messy; huge, big}
9F8F CJK UNIFIED IDEOGRAPH-#9F8F, IRGKangXi=1537.020, RSKangXi=212.3
9F90 CJK UNIFIED IDEOGRAPH-#9F90, IRGKangXi=1537.030, RSKangXi=212.3, Def{disorderly, messy; huge, big}
9F91 CJK UNIFIED IDEOGRAPH-#9F91, IRGKangXi=1537.060, RSKangXi=212.4, Def{high and bright}
9F92 CJK UNIFIED IDEOGRAPH-#9F92, IRGKangXi=1537.090, RSKangXi=212.5, Def{dragon}
9F93 CJK UNIFIED IDEOGRAPH-#9F93, IRGKangXi=1537.110, RSKangXi=212.6, Def{a halter}
9F94 CJK UNIFIED IDEOGRAPH-#9F94, IRGKangXi=1537.140, RSKangXi=212.6, Def{give, present; reverential}
9F95 CJK UNIFIED IDEOGRAPH-#9F95, IRGKangXi=1537.160, RSKangXi=212.6, Def{niche, shrine}
9F96 CJK UNIFIED IDEOGRAPH-#9F96, IRGKangXi=1537.200, RSKangXi=212.16, Def{flight of a dragon}
9F97 CJK UNIFIED IDEOGRAPH-#9F97, IRGKangXi=1537.210, RSKangXi=212.17
9F98 CJK UNIFIED IDEOGRAPH-#9F98, IRGKangXi=1537.250, RSKangXi=212.32, Def{the appearance of a dragon walking}
9F99 CJK UNIFIED IDEOGRAPH-#9F99, IRGKangXi=1537.251, RSKangXi=212.0, Def{dragon; symbolic of emperor}
9F9A CJK UNIFIED IDEOGRAPH-#9F9A, IRGKangXi=1537.251, RSKangXi=212.6, Def{give, present; reverential}
9F9B CJK UNIFIED IDEOGRAPH-#9F9B, IRGKangXi=1537.251, RSKangXi=212.6, Def{niche, shrine}
9F9C CJK UNIFIED IDEOGRAPH-#9F9C, IRGKangXi=1538.010, RSKangXi=213.0, Def{turtle or tortoise; cuckold}
9F9D CJK UNIFIED IDEOGRAPH-#9F9D, IRGKangXi=1538.170, RSKangXi=115.16, Def{autumn, fall; year}
9F9E CJK UNIFIED IDEOGRAPH-#9F9E, IRGKangXi=1538.230, RSKangXi=213.12, Def{turtle}
9F9F CJK UNIFIED IDEOGRAPH-#9F9F, IRGKangXi=1538.241, RSKangXi=213.0, Def{turtle or tortoise; cuckold}
9FA0 CJK UNIFIED IDEOGRAPH-#9FA0, IRGKangXi=1538.250, RSKangXi=214.0, Def{flute; pipe, ancient measure}
9FA1 CJK UNIFIED IDEOGRAPH-#9FA1, IRGKangXi=1538.270, RSKangXi=214.4, Def{to blow, exhale}
9FA2 CJK UNIFIED IDEOGRAPH-#9FA2, IRGKangXi=1538.290, RSKangXi=214.5, Def{in harmony; calm, peaceful}
9FA3 CJK UNIFIED IDEOGRAPH-#9FA3, IRGKangXi=1538.300, RSKangXi=214.8
9FA4 CJK UNIFIED IDEOGRAPH-#9FA4, IRGKangXi=1538.350, RSKangXi=214.9, Def{to harmonize; to accord with; to agree}
9FA5 CJK UNIFIED IDEOGRAPH-#9FA5, IRGKangXi=1538.360, RSKangXi=214.9, Def{beg, appeal for help}
9FA6 CJK UNIFIED IDEOGRAPH-#9FA6
9FA7 CJK UNIFIED IDEOGRAPH-#9FA7
9FA8 CJK UNIFIED IDEOGRAPH-#9FA8
9FA9 CJK UNIFIED IDEOGRAPH-#9FA9
9FAA CJK UNIFIED IDEOGRAPH-#9FAA
9FAB CJK UNIFIED IDEOGRAPH-#9FAB
9FAC CJK UNIFIED IDEOGRAPH-#9FAC
9FAD CJK UNIFIED IDEOGRAPH-#9FAD
9FAE CJK UNIFIED IDEOGRAPH-#9FAE
9FAF CJK UNIFIED IDEOGRAPH-#9FAF
9FB0 CJK UNIFIED IDEOGRAPH-#9FB0
9FB1 CJK UNIFIED IDEOGRAPH-#9FB1
9FB2 CJK UNIFIED IDEOGRAPH-#9FB2
9FB3 CJK UNIFIED IDEOGRAPH-#9FB3
9FB4 CJK UNIFIED IDEOGRAPH-#9FB4
9FB5 CJK UNIFIED IDEOGRAPH-#9FB5
9FB6 CJK UNIFIED IDEOGRAPH-#9FB6
9FB7 CJK UNIFIED IDEOGRAPH-#9FB7
9FB8 CJK UNIFIED IDEOGRAPH-#9FB8
9FB9 CJK UNIFIED IDEOGRAPH-#9FB9
9FBA CJK UNIFIED IDEOGRAPH-#9FBA
9FBB CJK UNIFIED IDEOGRAPH-#9FBB
9FBC CJK UNIFIED IDEOGRAPH-#9FBC
9FBD CJK UNIFIED IDEOGRAPH-#9FBD
9FBE CJK UNIFIED IDEOGRAPH-#9FBE
9FBF CJK UNIFIED IDEOGRAPH-#9FBF
9FC0 CJK UNIFIED IDEOGRAPH-#9FC0
9FC1 CJK UNIFIED IDEOGRAPH-#9FC1
9FC2 CJK UNIFIED IDEOGRAPH-#9FC2
9FC3 CJK UNIFIED IDEOGRAPH-#9FC3, IRGKangXi=0809.020, Def{(same as U+7752 睒) to blink, twinkle}
9FC4 CJK UNIFIED IDEOGRAPH-#9FC4
9FC5 CJK UNIFIED IDEOGRAPH-#9FC5
9FC6 CJK UNIFIED IDEOGRAPH-#9FC6
9FC7 CJK UNIFIED IDEOGRAPH-#9FC7
9FC8 CJK UNIFIED IDEOGRAPH-#9FC8
9FC9 CJK UNIFIED IDEOGRAPH-#9FC9
9FCA CJK UNIFIED IDEOGRAPH-#9FCA
9FCB CJK UNIFIED IDEOGRAPH-#9FCB
9FCC CJK UNIFIED IDEOGRAPH-#9FCC
9FCD CJK UNIFIED IDEOGRAPH-#9FCD, Def{hill; long and narrow highland; used in place names}
9FCE CJK UNIFIED IDEOGRAPH-#9FCE, Def{(tǎ) place names in Guangdong and Zhejiang; (dá) cobblestone, water gate}
9FCF CJK UNIFIED IDEOGRAPH-#9FCF, Def{meitnerium}
9FD0 CJK UNIFIED IDEOGRAPH-#9FD0, Def{a kind of clam}
9FD1 CJK UNIFIED IDEOGRAPH-#9FD1
9FD2 CJK UNIFIED IDEOGRAPH-#9FD2, Def{caraway}
9FD3 CJK UNIFIED IDEOGRAPH-#9FD3, Def{caraway}
9FD4 CJK UNIFIED IDEOGRAPH-#9FD4, Def{copernicium}
9FD5 CJK UNIFIED IDEOGRAPH-#9FD5, Def{Danio chrysotaeniata}
9FD6 CJK UNIFIED IDEOGRAPH-#9FD6
9FD7 CJK UNIFIED IDEOGRAPH-#9FD7
9FD8 CJK UNIFIED IDEOGRAPH-#9FD8
9FD9 CJK UNIFIED IDEOGRAPH-#9FD9
9FDA CJK UNIFIED IDEOGRAPH-#9FDA
9FDB CJK UNIFIED IDEOGRAPH-#9FDB
9FDC CJK UNIFIED IDEOGRAPH-#9FDC
9FDD CJK UNIFIED IDEOGRAPH-#9FDD
9FDE CJK UNIFIED IDEOGRAPH-#9FDE
9FDF CJK UNIFIED IDEOGRAPH-#9FDF
9FE0 CJK UNIFIED IDEOGRAPH-#9FE0
9FE1 CJK UNIFIED IDEOGRAPH-#9FE1
9FE2 CJK UNIFIED IDEOGRAPH-#9FE2
9FE3 CJK UNIFIED IDEOGRAPH-#9FE3
9FE4 CJK UNIFIED IDEOGRAPH-#9FE4
9FE5 CJK UNIFIED IDEOGRAPH-#9FE5
9FE6 CJK UNIFIED IDEOGRAPH-#9FE6
9FE7 CJK UNIFIED IDEOGRAPH-#9FE7
9FE8 CJK UNIFIED IDEOGRAPH-#9FE8
9FE9 CJK UNIFIED IDEOGRAPH-#9FE9
9FEA CJK UNIFIED IDEOGRAPH-#9FEA
A000 YI SYLLABLE IT
A001 YI SYLLABLE IX
A002 YI SYLLABLE I
A003 YI SYLLABLE IP
A004 YI SYLLABLE IET
A005 YI SYLLABLE IEX
A006 YI SYLLABLE IE
A007 YI SYLLABLE IEP
A008 YI SYLLABLE AT
A009 YI SYLLABLE AX
A00A YI SYLLABLE A
A00B YI SYLLABLE AP
A00C YI SYLLABLE UOX
A00D YI SYLLABLE UO
A00E YI SYLLABLE UOP
A00F YI SYLLABLE OT
A010 YI SYLLABLE OX
A011 YI SYLLABLE O
A012 YI SYLLABLE OP
A013 YI SYLLABLE EX
A014 YI SYLLABLE E
A015 YI SYLLABLE WU
A016 YI SYLLABLE BIT
A017 YI SYLLABLE BIX
A018 YI SYLLABLE BI
A019 YI SYLLABLE BIP
A01A YI SYLLABLE BIET
A01B YI SYLLABLE BIEX
A01C YI SYLLABLE BIE
A01D YI SYLLABLE BIEP
A01E YI SYLLABLE BAT
A01F YI SYLLABLE BAX
A020 YI SYLLABLE BA
A021 YI SYLLABLE BAP
A022 YI SYLLABLE BUOX
A023 YI SYLLABLE BUO
A024 YI SYLLABLE BUOP
A025 YI SYLLABLE BOT
A026 YI SYLLABLE BOX
A027 YI SYLLABLE BO
A028 YI SYLLABLE BOP
A029 YI SYLLABLE BEX
A02A YI SYLLABLE BE
A02B YI SYLLABLE BEP
A02C YI SYLLABLE BUT
A02D YI SYLLABLE BUX
A02E YI SYLLABLE BU
A02F YI SYLLABLE BUP
A030 YI SYLLABLE BURX
A031 YI SYLLABLE BUR
A032 YI SYLLABLE BYT
A033 YI SYLLABLE BYX
A034 YI SYLLABLE BY
A035 YI SYLLABLE BYP
A036 YI SYLLABLE BYRX
A037 YI SYLLABLE BYR
A038 YI SYLLABLE PIT
A039 YI SYLLABLE PIX
A03A YI SYLLABLE PI
A03B YI SYLLABLE PIP
A03C YI SYLLABLE PIEX
A03D YI SYLLABLE PIE
A03E YI SYLLABLE PIEP
A03F YI SYLLABLE PAT
A040 YI SYLLABLE PAX
A041 YI SYLLABLE PA
A042 YI SYLLABLE PAP
A043 YI SYLLABLE PUOX
A044 YI SYLLABLE PUO
A045 YI SYLLABLE PUOP
A046 YI SYLLABLE POT
A047 YI SYLLABLE POX
A048 YI SYLLABLE PO
A049 YI SYLLABLE POP
A04A YI SYLLABLE PUT
A04B YI SYLLABLE PUX
A04C YI SYLLABLE PU
A04D YI SYLLABLE PUP
A04E YI SYLLABLE PURX
A04F YI SYLLABLE PUR
A050 YI SYLLABLE PYT
A051 YI SYLLABLE PYX
A052 YI SYLLABLE PY
A053 YI SYLLABLE PYP
A054 YI SYLLABLE PYRX
A055 YI SYLLABLE PYR
A056 YI SYLLABLE BBIT
A057 YI SYLLABLE BBIX
A058 YI SYLLABLE BBI
A059 YI SYLLABLE BBIP
A05A YI SYLLABLE BBIET
A05B YI SYLLABLE BBIEX
A05C YI SYLLABLE BBIE
A05D YI SYLLABLE BBIEP
A05E YI SYLLABLE BBAT
A05F YI SYLLABLE BBAX
A060 YI SYLLABLE BBA
A061 YI SYLLABLE BBAP
A062 YI SYLLABLE BBUOX
A063 YI SYLLABLE BBUO
A064 YI SYLLABLE BBUOP
A065 YI SYLLABLE BBOT
A066 YI SYLLABLE BBOX
A067 YI SYLLABLE BBO
A068 YI SYLLABLE BBOP
A069 YI SYLLABLE BBEX
A06A YI SYLLABLE BBE
A06B YI SYLLABLE BBEP
A06C YI SYLLABLE BBUT
A06D YI SYLLABLE BBUX
A06E YI SYLLABLE BBU
A06F YI SYLLABLE BBUP
A070 YI SYLLABLE BBURX
A071 YI SYLLABLE BBUR
A072 YI SYLLABLE BBYT
A073 YI SYLLABLE BBYX
A074 YI SYLLABLE BBY
A075 YI SYLLABLE BBYP
A076 YI SYLLABLE NBIT
A077 YI SYLLABLE NBIX
A078 YI SYLLABLE NBI
A079 YI SYLLABLE NBIP
A07A YI SYLLABLE NBIEX
A07B YI SYLLABLE NBIE
A07C YI SYLLABLE NBIEP
A07D YI SYLLABLE NBAT
A07E YI SYLLABLE NBAX
A07F YI SYLLABLE NBA
A080 YI SYLLABLE NBAP
A081 YI SYLLABLE NBOT
A082 YI SYLLABLE NBOX
A083 YI SYLLABLE NBO
A084 YI SYLLABLE NBOP
A085 YI SYLLABLE NBUT
A086 YI SYLLABLE NBUX
A087 YI SYLLABLE NBU
A088 YI SYLLABLE NBUP
A089 YI SYLLABLE NBURX
A08A YI SYLLABLE NBUR
A08B YI SYLLABLE NBYT
A08C YI SYLLABLE NBYX
A08D YI SYLLABLE NBY
A08E YI SYLLABLE NBYP
A08F YI SYLLABLE NBYRX
A090 YI SYLLABLE NBYR
A091 YI SYLLABLE HMIT
A092 YI SYLLABLE HMIX
A093 YI SYLLABLE HMI
A094 YI SYLLABLE HMIP
A095 YI SYLLABLE HMIEX
A096 YI SYLLABLE HMIE
A097 YI SYLLABLE HMIEP
A098 YI SYLLABLE HMAT
A099 YI SYLLABLE HMAX
A09A YI SYLLABLE HMA
A09B YI SYLLABLE HMAP
A09C YI SYLLABLE HMUOX
A09D YI SYLLABLE HMUO
A09E YI SYLLABLE HMUOP
A09F YI SYLLABLE HMOT
A0A0 YI SYLLABLE HMOX
A0A1 YI SYLLABLE HMO
A0A2 YI SYLLABLE HMOP
A0A3 YI SYLLABLE HMUT
A0A4 YI SYLLABLE HMUX
A0A5 YI SYLLABLE HMU
A0A6 YI SYLLABLE HMUP
A0A7 YI SYLLABLE HMURX
A0A8 YI SYLLABLE HMUR
A0A9 YI SYLLABLE HMYX
A0AA YI SYLLABLE HMY
A0AB YI SYLLABLE HMYP
A0AC YI SYLLABLE HMYRX
A0AD YI SYLLABLE HMYR
A0AE YI SYLLABLE MIT
A0AF YI SYLLABLE MIX
A0B0 YI SYLLABLE MI
A0B1 YI SYLLABLE MIP
A0B2 YI SYLLABLE MIEX
A0B3 YI SYLLABLE MIE
A0B4 YI SYLLABLE MIEP
A0B5 YI SYLLABLE MAT
A0B6 YI SYLLABLE MAX
A0B7 YI SYLLABLE MA
A0B8 YI SYLLABLE MAP
A0B9 YI SYLLABLE MUOT
A0BA YI SYLLABLE MUOX
A0BB YI SYLLABLE MUO
A0BC YI SYLLABLE MUOP
A0BD YI SYLLABLE MOT
A0BE YI SYLLABLE MOX
A0BF YI SYLLABLE MO
A0C0 YI SYLLABLE MOP
A0C1 YI SYLLABLE MEX
A0C2 YI SYLLABLE ME
A0C3 YI SYLLABLE MUT
A0C4 YI SYLLABLE MUX
A0C5 YI SYLLABLE MU
A0C6 YI SYLLABLE MUP
A0C7 YI SYLLABLE MURX
A0C8 YI SYLLABLE MUR
A0C9 YI SYLLABLE MYT
A0CA YI SYLLABLE MYX
A0CB YI SYLLABLE MY
A0CC YI SYLLABLE MYP
A0CD YI SYLLABLE FIT
A0CE YI SYLLABLE FIX
A0CF YI SYLLABLE FI
A0D0 YI SYLLABLE FIP
A0D1 YI SYLLABLE FAT
A0D2 YI SYLLABLE FAX
A0D3 YI SYLLABLE FA
A0D4 YI SYLLABLE FAP
A0D5 YI SYLLABLE FOX
A0D6 YI SYLLABLE FO
A0D7 YI SYLLABLE FOP
A0D8 YI SYLLABLE FUT
A0D9 YI SYLLABLE FUX
A0DA YI SYLLABLE FU
A0DB YI SYLLABLE FUP
A0DC YI SYLLABLE FURX
A0DD YI SYLLABLE FUR
A0DE YI SYLLABLE FYT
A0DF YI SYLLABLE FYX
A0E0 YI SYLLABLE FY
A0E1 YI SYLLABLE FYP
A0E2 YI SYLLABLE VIT
A0E3 YI SYLLABLE VIX
A0E4 YI SYLLABLE VI
A0E5 YI SYLLABLE VIP
A0E6 YI SYLLABLE VIET
A0E7 YI SYLLABLE VIEX
A0E8 YI SYLLABLE VIE
A0E9 YI SYLLABLE VIEP
A0EA YI SYLLABLE VAT
A0EB YI SYLLABLE VAX
A0EC YI SYLLABLE VA
A0ED YI SYLLABLE VAP
A0EE YI SYLLABLE VOT
A0EF YI SYLLABLE VOX
A0F0 YI SYLLABLE VO
A0F1 YI SYLLABLE VOP
A0F2 YI SYLLABLE VEX
A0F3 YI SYLLABLE VEP
A0F4 YI SYLLABLE VUT
A0F5 YI SYLLABLE VUX
A0F6 YI SYLLABLE VU
A0F7 YI SYLLABLE VUP
A0F8 YI SYLLABLE VURX
A0F9 YI SYLLABLE VUR
A0FA YI SYLLABLE VYT
A0FB YI SYLLABLE VYX
A0FC YI SYLLABLE VY
A0FD YI SYLLABLE VYP
A0FE YI SYLLABLE VYRX
A0FF YI SYLLABLE VYR
A100 YI SYLLABLE DIT
A101 YI SYLLABLE DIX
A102 YI SYLLABLE DI
A103 YI SYLLABLE DIP
A104 YI SYLLABLE DIEX
A105 YI SYLLABLE DIE
A106 YI SYLLABLE DIEP
A107 YI SYLLABLE DAT
A108 YI SYLLABLE DAX
A109 YI SYLLABLE DA
A10A YI SYLLABLE DAP
A10B YI SYLLABLE DUOX
A10C YI SYLLABLE DUO
A10D YI SYLLABLE DOT
A10E YI SYLLABLE DOX
A10F YI SYLLABLE DO
A110 YI SYLLABLE DOP
A111 YI SYLLABLE DEX
A112 YI SYLLABLE DE
A113 YI SYLLABLE DEP
A114 YI SYLLABLE DUT
A115 YI SYLLABLE DUX
A116 YI SYLLABLE DU
A117 YI SYLLABLE DUP
A118 YI SYLLABLE DURX
A119 YI SYLLABLE DUR
A11A YI SYLLABLE TIT
A11B YI SYLLABLE TIX
A11C YI SYLLABLE TI
A11D YI SYLLABLE TIP
A11E YI SYLLABLE TIEX
A11F YI SYLLABLE TIE
A120 YI SYLLABLE TIEP
A121 YI SYLLABLE TAT
A122 YI SYLLABLE TAX
A123 YI SYLLABLE TA
A124 YI SYLLABLE TAP
A125 YI SYLLABLE TUOT
A126 YI SYLLABLE TUOX
A127 YI SYLLABLE TUO
A128 YI SYLLABLE TUOP
A129 YI SYLLABLE TOT
A12A YI SYLLABLE TOX
A12B YI SYLLABLE TO
A12C YI SYLLABLE TOP
A12D YI SYLLABLE TEX
A12E YI SYLLABLE TE
A12F YI SYLLABLE TEP
A130 YI SYLLABLE TUT
A131 YI SYLLABLE TUX
A132 YI SYLLABLE TU
A133 YI SYLLABLE TUP
A134 YI SYLLABLE TURX
A135 YI SYLLABLE TUR
A136 YI SYLLABLE DDIT
A137 YI SYLLABLE DDIX
A138 YI SYLLABLE DDI
A139 YI SYLLABLE DDIP
A13A YI SYLLABLE DDIEX
A13B YI SYLLABLE DDIE
A13C YI SYLLABLE DDIEP
A13D YI SYLLABLE DDAT
A13E YI SYLLABLE DDAX
A13F YI SYLLABLE DDA
A140 YI SYLLABLE DDAP
A141 YI SYLLABLE DDUOX
A142 YI SYLLABLE DDUO
A143 YI SYLLABLE DDUOP
A144 YI SYLLABLE DDOT
A145 YI SYLLABLE DDOX
A146 YI SYLLABLE DDO
A147 YI SYLLABLE DDOP
A148 YI SYLLABLE DDEX
A149 YI SYLLABLE DDE
A14A YI SYLLABLE DDEP
A14B YI SYLLABLE DDUT
A14C YI SYLLABLE DDUX
A14D YI SYLLABLE DDU
A14E YI SYLLABLE DDUP
A14F YI SYLLABLE DDURX
A150 YI SYLLABLE DDUR
A151 YI SYLLABLE NDIT
A152 YI SYLLABLE NDIX
A153 YI SYLLABLE NDI
A154 YI SYLLABLE NDIP
A155 YI SYLLABLE NDIEX
A156 YI SYLLABLE NDIE
A157 YI SYLLABLE NDAT
A158 YI SYLLABLE NDAX
A159 YI SYLLABLE NDA
A15A YI SYLLABLE NDAP
A15B YI SYLLABLE NDOT
A15C YI SYLLABLE NDOX
A15D YI SYLLABLE NDO
A15E YI SYLLABLE NDOP
A15F YI SYLLABLE NDEX
A160 YI SYLLABLE NDE
A161 YI SYLLABLE NDEP
A162 YI SYLLABLE NDUT
A163 YI SYLLABLE NDUX
A164 YI SYLLABLE NDU
A165 YI SYLLABLE NDUP
A166 YI SYLLABLE NDURX
A167 YI SYLLABLE NDUR
A168 YI SYLLABLE HNIT
A169 YI SYLLABLE HNIX
A16A YI SYLLABLE HNI
A16B YI SYLLABLE HNIP
A16C YI SYLLABLE HNIET
A16D YI SYLLABLE HNIEX
A16E YI SYLLABLE HNIE
A16F YI SYLLABLE HNIEP
A170 YI SYLLABLE HNAT
A171 YI SYLLABLE HNAX
A172 YI SYLLABLE HNA
A173 YI SYLLABLE HNAP
A174 YI SYLLABLE HNUOX
A175 YI SYLLABLE HNUO
A176 YI SYLLABLE HNOT
A177 YI SYLLABLE HNOX
A178 YI SYLLABLE HNOP
A179 YI SYLLABLE HNEX
A17A YI SYLLABLE HNE
A17B YI SYLLABLE HNEP
A17C YI SYLLABLE HNUT
A17D YI SYLLABLE NIT
A17E YI SYLLABLE NIX
A17F YI SYLLABLE NI
A180 YI SYLLABLE NIP
A181 YI SYLLABLE NIEX
A182 YI SYLLABLE NIE
A183 YI SYLLABLE NIEP
A184 YI SYLLABLE NAX
A185 YI SYLLABLE NA
A186 YI SYLLABLE NAP
A187 YI SYLLABLE NUOX
A188 YI SYLLABLE NUO
A189 YI SYLLABLE NUOP
A18A YI SYLLABLE NOT
A18B YI SYLLABLE NOX
A18C YI SYLLABLE NO
A18D YI SYLLABLE NOP
A18E YI SYLLABLE NEX
A18F YI SYLLABLE NE
A190 YI SYLLABLE NEP
A191 YI SYLLABLE NUT
A192 YI SYLLABLE NUX
A193 YI SYLLABLE NU
A194 YI SYLLABLE NUP
A195 YI SYLLABLE NURX
A196 YI SYLLABLE NUR
A197 YI SYLLABLE HLIT
A198 YI SYLLABLE HLIX
A199 YI SYLLABLE HLI
A19A YI SYLLABLE HLIP
A19B YI SYLLABLE HLIEX
A19C YI SYLLABLE HLIE
A19D YI SYLLABLE HLIEP
A19E YI SYLLABLE HLAT
A19F YI SYLLABLE HLAX
A1A0 YI SYLLABLE HLA
A1A1 YI SYLLABLE HLAP
A1A2 YI SYLLABLE HLUOX
A1A3 YI SYLLABLE HLUO
A1A4 YI SYLLABLE HLUOP
A1A5 YI SYLLABLE HLOX
A1A6 YI SYLLABLE HLO
A1A7 YI SYLLABLE HLOP
A1A8 YI SYLLABLE HLEX
A1A9 YI SYLLABLE HLE
A1AA YI SYLLABLE HLEP
A1AB YI SYLLABLE HLUT
A1AC YI SYLLABLE HLUX
A1AD YI SYLLABLE HLU
A1AE YI SYLLABLE HLUP
A1AF YI SYLLABLE HLURX
A1B0 YI SYLLABLE HLUR
A1B1 YI SYLLABLE HLYT
A1B2 YI SYLLABLE HLYX
A1B3 YI SYLLABLE HLY
A1B4 YI SYLLABLE HLYP
A1B5 YI SYLLABLE HLYRX
A1B6 YI SYLLABLE HLYR
A1B7 YI SYLLABLE LIT
A1B8 YI SYLLABLE LIX
A1B9 YI SYLLABLE LI
A1BA YI SYLLABLE LIP
A1BB YI SYLLABLE LIET
A1BC YI SYLLABLE LIEX
A1BD YI SYLLABLE LIE
A1BE YI SYLLABLE LIEP
A1BF YI SYLLABLE LAT
A1C0 YI SYLLABLE LAX
A1C1 YI SYLLABLE LA
A1C2 YI SYLLABLE LAP
A1C3 YI SYLLABLE LUOT
A1C4 YI SYLLABLE LUOX
A1C5 YI SYLLABLE LUO
A1C6 YI SYLLABLE LUOP
A1C7 YI SYLLABLE LOT
A1C8 YI SYLLABLE LOX
A1C9 YI SYLLABLE LO
A1CA YI SYLLABLE LOP
A1CB YI SYLLABLE LEX
A1CC YI SYLLABLE LE
A1CD YI SYLLABLE LEP
A1CE YI SYLLABLE LUT
A1CF YI SYLLABLE LUX
A1D0 YI SYLLABLE LU
A1D1 YI SYLLABLE LUP
A1D2 YI SYLLABLE LURX
A1D3 YI SYLLABLE LUR
A1D4 YI SYLLABLE LYT
A1D5 YI SYLLABLE LYX
A1D6 YI SYLLABLE LY
A1D7 YI SYLLABLE LYP
A1D8 YI SYLLABLE LYRX
A1D9 YI SYLLABLE LYR
A1DA YI SYLLABLE GIT
A1DB YI SYLLABLE GIX
A1DC YI SYLLABLE GI
A1DD YI SYLLABLE GIP
A1DE YI SYLLABLE GIET
A1DF YI SYLLABLE GIEX
A1E0 YI SYLLABLE GIE
A1E1 YI SYLLABLE GIEP
A1E2 YI SYLLABLE GAT
A1E3 YI SYLLABLE GAX
A1E4 YI SYLLABLE GA
A1E5 YI SYLLABLE GAP
A1E6 YI SYLLABLE GUOT
A1E7 YI SYLLABLE GUOX
A1E8 YI SYLLABLE GUO
A1E9 YI SYLLABLE GUOP
A1EA YI SYLLABLE GOT
A1EB YI SYLLABLE GOX
A1EC YI SYLLABLE GO
A1ED YI SYLLABLE GOP
A1EE YI SYLLABLE GET
A1EF YI SYLLABLE GEX
A1F0 YI SYLLABLE GE
A1F1 YI SYLLABLE GEP
A1F2 YI SYLLABLE GUT
A1F3 YI SYLLABLE GUX
A1F4 YI SYLLABLE GU
A1F5 YI SYLLABLE GUP
A1F6 YI SYLLABLE GURX
A1F7 YI SYLLABLE GUR
A1F8 YI SYLLABLE KIT
A1F9 YI SYLLABLE KIX
A1FA YI SYLLABLE KI
A1FB YI SYLLABLE KIP
A1FC YI SYLLABLE KIEX
A1FD YI SYLLABLE KIE
A1FE YI SYLLABLE KIEP
A1FF YI SYLLABLE KAT
A200 YI SYLLABLE KAX
A201 YI SYLLABLE KA
A202 YI SYLLABLE KAP
A203 YI SYLLABLE KUOX
A204 YI SYLLABLE KUO
A205 YI SYLLABLE KUOP
A206 YI SYLLABLE KOT
A207 YI SYLLABLE KOX
A208 YI SYLLABLE KO
A209 YI SYLLABLE KOP
A20A YI SYLLABLE KET
A20B YI SYLLABLE KEX
A20C YI SYLLABLE KE
A20D YI SYLLABLE KEP
A20E YI SYLLABLE KUT
A20F YI SYLLABLE KUX
A210 YI SYLLABLE KU
A211 YI SYLLABLE KUP
A212 YI SYLLABLE KURX
A213 YI SYLLABLE KUR
A214 YI SYLLABLE GGIT
A215 YI SYLLABLE GGIX
A216 YI SYLLABLE GGI
A217 YI SYLLABLE GGIEX
A218 YI SYLLABLE GGIE
A219 YI SYLLABLE GGIEP
A21A YI SYLLABLE GGAT
A21B YI SYLLABLE GGAX
A21C YI SYLLABLE GGA
A21D YI SYLLABLE GGAP
A21E YI SYLLABLE GGUOT
A21F YI SYLLABLE GGUOX
A220 YI SYLLABLE GGUO
A221 YI SYLLABLE GGUOP
A222 YI SYLLABLE GGOT
A223 YI SYLLABLE GGOX
A224 YI SYLLABLE GGO
A225 YI SYLLABLE GGOP
A226 YI SYLLABLE GGET
A227 YI SYLLABLE GGEX
A228 YI SYLLABLE GGE
A229 YI SYLLABLE GGEP
A22A YI SYLLABLE GGUT
A22B YI SYLLABLE GGUX
A22C YI SYLLABLE GGU
A22D YI SYLLABLE GGUP
A22E YI SYLLABLE GGURX
A22F YI SYLLABLE GGUR
A230 YI SYLLABLE MGIEX
A231 YI SYLLABLE MGIE
A232 YI SYLLABLE MGAT
A233 YI SYLLABLE MGAX
A234 YI SYLLABLE MGA
A235 YI SYLLABLE MGAP
A236 YI SYLLABLE MGUOX
A237 YI SYLLABLE MGUO
A238 YI SYLLABLE MGUOP
A239 YI SYLLABLE MGOT
A23A YI SYLLABLE MGOX
A23B YI SYLLABLE MGO
A23C YI SYLLABLE MGOP
A23D YI SYLLABLE MGEX
A23E YI SYLLABLE MGE
A23F YI SYLLABLE MGEP
A240 YI SYLLABLE MGUT
A241 YI SYLLABLE MGUX
A242 YI SYLLABLE MGU
A243 YI SYLLABLE MGUP
A244 YI SYLLABLE MGURX
A245 YI SYLLABLE MGUR
A246 YI SYLLABLE HXIT
A247 YI SYLLABLE HXIX
A248 YI SYLLABLE HXI
A249 YI SYLLABLE HXIP
A24A YI SYLLABLE HXIET
A24B YI SYLLABLE HXIEX
A24C YI SYLLABLE HXIE
A24D YI SYLLABLE HXIEP
A24E YI SYLLABLE HXAT
A24F YI SYLLABLE HXAX
A250 YI SYLLABLE HXA
A251 YI SYLLABLE HXAP
A252 YI SYLLABLE HXUOT
A253 YI SYLLABLE HXUOX
A254 YI SYLLABLE HXUO
A255 YI SYLLABLE HXUOP
A256 YI SYLLABLE HXOT
A257 YI SYLLABLE HXOX
A258 YI SYLLABLE HXO
A259 YI SYLLABLE HXOP
A25A YI SYLLABLE HXEX
A25B YI SYLLABLE HXE
A25C YI SYLLABLE HXEP
A25D YI SYLLABLE NGIEX
A25E YI SYLLABLE NGIE
A25F YI SYLLABLE NGIEP
A260 YI SYLLABLE NGAT
A261 YI SYLLABLE NGAX
A262 YI SYLLABLE NGA
A263 YI SYLLABLE NGAP
A264 YI SYLLABLE NGUOT
A265 YI SYLLABLE NGUOX
A266 YI SYLLABLE NGUO
A267 YI SYLLABLE NGOT
A268 YI SYLLABLE NGOX
A269 YI SYLLABLE NGO
A26A YI SYLLABLE NGOP
A26B YI SYLLABLE NGEX
A26C YI SYLLABLE NGE
A26D YI SYLLABLE NGEP
A26E YI SYLLABLE HIT
A26F YI SYLLABLE HIEX
A270 YI SYLLABLE HIE
A271 YI SYLLABLE HAT
A272 YI SYLLABLE HAX
A273 YI SYLLABLE HA
A274 YI SYLLABLE HAP
A275 YI SYLLABLE HUOT
A276 YI SYLLABLE HUOX
A277 YI SYLLABLE HUO
A278 YI SYLLABLE HUOP
A279 YI SYLLABLE HOT
A27A YI SYLLABLE HOX
A27B YI SYLLABLE HO
A27C YI SYLLABLE HOP
A27D YI SYLLABLE HEX
A27E YI SYLLABLE HE
A27F YI SYLLABLE HEP
A280 YI SYLLABLE WAT
A281 YI SYLLABLE WAX
A282 YI SYLLABLE WA
A283 YI SYLLABLE WAP
A284 YI SYLLABLE WUOX
A285 YI SYLLABLE WUO
A286 YI SYLLABLE WUOP
A287 YI SYLLABLE WOX
A288 YI SYLLABLE WO
A289 YI SYLLABLE WOP
A28A YI SYLLABLE WEX
A28B YI SYLLABLE WE
A28C YI SYLLABLE WEP
A28D YI SYLLABLE ZIT
A28E YI SYLLABLE ZIX
A28F YI SYLLABLE ZI
A290 YI SYLLABLE ZIP
A291 YI SYLLABLE ZIEX
A292 YI SYLLABLE ZIE
A293 YI SYLLABLE ZIEP
A294 YI SYLLABLE ZAT
A295 YI SYLLABLE ZAX
A296 YI SYLLABLE ZA
A297 YI SYLLABLE ZAP
A298 YI SYLLABLE ZUOX
A299 YI SYLLABLE ZUO
A29A YI SYLLABLE ZUOP
A29B YI SYLLABLE ZOT
A29C YI SYLLABLE ZOX
A29D YI SYLLABLE ZO
A29E YI SYLLABLE ZOP
A29F YI SYLLABLE ZEX
A2A0 YI SYLLABLE ZE
A2A1 YI SYLLABLE ZEP
A2A2 YI SYLLABLE ZUT
A2A3 YI SYLLABLE ZUX
A2A4 YI SYLLABLE ZU
A2A5 YI SYLLABLE ZUP
A2A6 YI SYLLABLE ZURX
A2A7 YI SYLLABLE ZUR
A2A8 YI SYLLABLE ZYT
A2A9 YI SYLLABLE ZYX
A2AA YI SYLLABLE ZY
A2AB YI SYLLABLE ZYP
A2AC YI SYLLABLE ZYRX
A2AD YI SYLLABLE ZYR
A2AE YI SYLLABLE CIT
A2AF YI SYLLABLE CIX
A2B0 YI SYLLABLE CI
A2B1 YI SYLLABLE CIP
A2B2 YI SYLLABLE CIET
A2B3 YI SYLLABLE CIEX
A2B4 YI SYLLABLE CIE
A2B5 YI SYLLABLE CIEP
A2B6 YI SYLLABLE CAT
A2B7 YI SYLLABLE CAX
A2B8 YI SYLLABLE CA
A2B9 YI SYLLABLE CAP
A2BA YI SYLLABLE CUOX
A2BB YI SYLLABLE CUO
A2BC YI SYLLABLE CUOP
A2BD YI SYLLABLE COT
A2BE YI SYLLABLE COX
A2BF YI SYLLABLE CO
A2C0 YI SYLLABLE COP
A2C1 YI SYLLABLE CEX
A2C2 YI SYLLABLE CE
A2C3 YI SYLLABLE CEP
A2C4 YI SYLLABLE CUT
A2C5 YI SYLLABLE CUX
A2C6 YI SYLLABLE CU
A2C7 YI SYLLABLE CUP
A2C8 YI SYLLABLE CURX
A2C9 YI SYLLABLE CUR
A2CA YI SYLLABLE CYT
A2CB YI SYLLABLE CYX
A2CC YI SYLLABLE CY
A2CD YI SYLLABLE CYP
A2CE YI SYLLABLE CYRX
A2CF YI SYLLABLE CYR
A2D0 YI SYLLABLE ZZIT
A2D1 YI SYLLABLE ZZIX
A2D2 YI SYLLABLE ZZI
A2D3 YI SYLLABLE ZZIP
A2D4 YI SYLLABLE ZZIET
A2D5 YI SYLLABLE ZZIEX
A2D6 YI SYLLABLE ZZIE
A2D7 YI SYLLABLE ZZIEP
A2D8 YI SYLLABLE ZZAT
A2D9 YI SYLLABLE ZZAX
A2DA YI SYLLABLE ZZA
A2DB YI SYLLABLE ZZAP
A2DC YI SYLLABLE ZZOX
A2DD YI SYLLABLE ZZO
A2DE YI SYLLABLE ZZOP
A2DF YI SYLLABLE ZZEX
A2E0 YI SYLLABLE ZZE
A2E1 YI SYLLABLE ZZEP
A2E2 YI SYLLABLE ZZUX
A2E3 YI SYLLABLE ZZU
A2E4 YI SYLLABLE ZZUP
A2E5 YI SYLLABLE ZZURX
A2E6 YI SYLLABLE ZZUR
A2E7 YI SYLLABLE ZZYT
A2E8 YI SYLLABLE ZZYX
A2E9 YI SYLLABLE ZZY
A2EA YI SYLLABLE ZZYP
A2EB YI SYLLABLE ZZYRX
A2EC YI SYLLABLE ZZYR
A2ED YI SYLLABLE NZIT
A2EE YI SYLLABLE NZIX
A2EF YI SYLLABLE NZI
A2F0 YI SYLLABLE NZIP
A2F1 YI SYLLABLE NZIEX
A2F2 YI SYLLABLE NZIE
A2F3 YI SYLLABLE NZIEP
A2F4 YI SYLLABLE NZAT
A2F5 YI SYLLABLE NZAX
A2F6 YI SYLLABLE NZA
A2F7 YI SYLLABLE NZAP
A2F8 YI SYLLABLE NZUOX
A2F9 YI SYLLABLE NZUO
A2FA YI SYLLABLE NZOX
A2FB YI SYLLABLE NZOP
A2FC YI SYLLABLE NZEX
A2FD YI SYLLABLE NZE
A2FE YI SYLLABLE NZUX
A2FF YI SYLLABLE NZU
A300 YI SYLLABLE NZUP
A301 YI SYLLABLE NZURX
A302 YI SYLLABLE NZUR
A303 YI SYLLABLE NZYT
A304 YI SYLLABLE NZYX
A305 YI SYLLABLE NZY
A306 YI SYLLABLE NZYP
A307 YI SYLLABLE NZYRX
A308 YI SYLLABLE NZYR
A309 YI SYLLABLE SIT
A30A YI SYLLABLE SIX
A30B YI SYLLABLE SI
A30C YI SYLLABLE SIP
A30D YI SYLLABLE SIEX
A30E YI SYLLABLE SIE
A30F YI SYLLABLE SIEP
A310 YI SYLLABLE SAT
A311 YI SYLLABLE SAX
A312 YI SYLLABLE SA
A313 YI SYLLABLE SAP
A314 YI SYLLABLE SUOX
A315 YI SYLLABLE SUO
A316 YI SYLLABLE SUOP
A317 YI SYLLABLE SOT
A318 YI SYLLABLE SOX
A319 YI SYLLABLE SO
A31A YI SYLLABLE SOP
A31B YI SYLLABLE SEX
A31C YI SYLLABLE SE
A31D YI SYLLABLE SEP
A31E YI SYLLABLE SUT
A31F YI SYLLABLE SUX
A320 YI SYLLABLE SU
A321 YI SYLLABLE SUP
A322 YI SYLLABLE SURX
A323 YI SYLLABLE SUR
A324 YI SYLLABLE SYT
A325 YI SYLLABLE SYX
A326 YI SYLLABLE SY
A327 YI SYLLABLE SYP
A328 YI SYLLABLE SYRX
A329 YI SYLLABLE SYR
A32A YI SYLLABLE SSIT
A32B YI SYLLABLE SSIX
A32C YI SYLLABLE SSI
A32D YI SYLLABLE SSIP
A32E YI SYLLABLE SSIEX
A32F YI SYLLABLE SSIE
A330 YI SYLLABLE SSIEP
A331 YI SYLLABLE SSAT
A332 YI SYLLABLE SSAX
A333 YI SYLLABLE SSA
A334 YI SYLLABLE SSAP
A335 YI SYLLABLE SSOT
A336 YI SYLLABLE SSOX
A337 YI SYLLABLE SSO
A338 YI SYLLABLE SSOP
A339 YI SYLLABLE SSEX
A33A YI SYLLABLE SSE
A33B YI SYLLABLE SSEP
A33C YI SYLLABLE SSUT
A33D YI SYLLABLE SSUX
A33E YI SYLLABLE SSU
A33F YI SYLLABLE SSUP
A340 YI SYLLABLE SSYT
A341 YI SYLLABLE SSYX
A342 YI SYLLABLE SSY
A343 YI SYLLABLE SSYP
A344 YI SYLLABLE SSYRX
A345 YI SYLLABLE SSYR
A346 YI SYLLABLE ZHAT
A347 YI SYLLABLE ZHAX
A348 YI SYLLABLE ZHA
A349 YI SYLLABLE ZHAP
A34A YI SYLLABLE ZHUOX
A34B YI SYLLABLE ZHUO
A34C YI SYLLABLE ZHUOP
A34D YI SYLLABLE ZHOT
A34E YI SYLLABLE ZHOX
A34F YI SYLLABLE ZHO
A350 YI SYLLABLE ZHOP
A351 YI SYLLABLE ZHET
A352 YI SYLLABLE ZHEX
A353 YI SYLLABLE ZHE
A354 YI SYLLABLE ZHEP
A355 YI SYLLABLE ZHUT
A356 YI SYLLABLE ZHUX
A357 YI SYLLABLE ZHU
A358 YI SYLLABLE ZHUP
A359 YI SYLLABLE ZHURX
A35A YI SYLLABLE ZHUR
A35B YI SYLLABLE ZHYT
A35C YI SYLLABLE ZHYX
A35D YI SYLLABLE ZHY
A35E YI SYLLABLE ZHYP
A35F YI SYLLABLE ZHYRX
A360 YI SYLLABLE ZHYR
A361 YI SYLLABLE CHAT
A362 YI SYLLABLE CHAX
A363 YI SYLLABLE CHA
A364 YI SYLLABLE CHAP
A365 YI SYLLABLE CHUOT
A366 YI SYLLABLE CHUOX
A367 YI SYLLABLE CHUO
A368 YI SYLLABLE CHUOP
A369 YI SYLLABLE CHOT
A36A YI SYLLABLE CHOX
A36B YI SYLLABLE CHO
A36C YI SYLLABLE CHOP
A36D YI SYLLABLE CHET
A36E YI SYLLABLE CHEX
A36F YI SYLLABLE CHE
A370 YI SYLLABLE CHEP
A371 YI SYLLABLE CHUX
A372 YI SYLLABLE CHU
A373 YI SYLLABLE CHUP
A374 YI SYLLABLE CHURX
A375 YI SYLLABLE CHUR
A376 YI SYLLABLE CHYT
A377 YI SYLLABLE CHYX
A378 YI SYLLABLE CHY
A379 YI SYLLABLE CHYP
A37A YI SYLLABLE CHYRX
A37B YI SYLLABLE CHYR
A37C YI SYLLABLE RRAX
A37D YI SYLLABLE RRA
A37E YI SYLLABLE RRUOX
A37F YI SYLLABLE RRUO
A380 YI SYLLABLE RROT
A381 YI SYLLABLE RROX
A382 YI SYLLABLE RRO
A383 YI SYLLABLE RROP
A384 YI SYLLABLE RRET
A385 YI SYLLABLE RREX
A386 YI SYLLABLE RRE
A387 YI SYLLABLE RREP
A388 YI SYLLABLE RRUT
A389 YI SYLLABLE RRUX
A38A YI SYLLABLE RRU
A38B YI SYLLABLE RRUP
A38C YI SYLLABLE RRURX
A38D YI SYLLABLE RRUR
A38E YI SYLLABLE RRYT
A38F YI SYLLABLE RRYX
A390 YI SYLLABLE RRY
A391 YI SYLLABLE RRYP
A392 YI SYLLABLE RRYRX
A393 YI SYLLABLE RRYR
A394 YI SYLLABLE NRAT
A395 YI SYLLABLE NRAX
A396 YI SYLLABLE NRA
A397 YI SYLLABLE NRAP
A398 YI SYLLABLE NROX
A399 YI SYLLABLE NRO
A39A YI SYLLABLE NROP
A39B YI SYLLABLE NRET
A39C YI SYLLABLE NREX
A39D YI SYLLABLE NRE
A39E YI SYLLABLE NREP
A39F YI SYLLABLE NRUT
A3A0 YI SYLLABLE NRUX
A3A1 YI SYLLABLE NRU
A3A2 YI SYLLABLE NRUP
A3A3 YI SYLLABLE NRURX
A3A4 YI SYLLABLE NRUR
A3A5 YI SYLLABLE NRYT
A3A6 YI SYLLABLE NRYX
A3A7 YI SYLLABLE NRY
A3A8 YI SYLLABLE NRYP
A3A9 YI SYLLABLE NRYRX
A3AA YI SYLLABLE NRYR
A3AB YI SYLLABLE SHAT
A3AC YI SYLLABLE SHAX
A3AD YI SYLLABLE SHA
A3AE YI SYLLABLE SHAP
A3AF YI SYLLABLE SHUOX
A3B0 YI SYLLABLE SHUO
A3B1 YI SYLLABLE SHUOP
A3B2 YI SYLLABLE SHOT
A3B3 YI SYLLABLE SHOX
A3B4 YI SYLLABLE SHO
A3B5 YI SYLLABLE SHOP
A3B6 YI SYLLABLE SHET
A3B7 YI SYLLABLE SHEX
A3B8 YI SYLLABLE SHE
A3B9 YI SYLLABLE SHEP
A3BA YI SYLLABLE SHUT
A3BB YI SYLLABLE SHUX
A3BC YI SYLLABLE SHU
A3BD YI SYLLABLE SHUP
A3BE YI SYLLABLE SHURX
A3BF YI SYLLABLE SHUR
A3C0 YI SYLLABLE SHYT
A3C1 YI SYLLABLE SHYX
A3C2 YI SYLLABLE SHY
A3C3 YI SYLLABLE SHYP
A3C4 YI SYLLABLE SHYRX
A3C5 YI SYLLABLE SHYR
A3C6 YI SYLLABLE RAT
A3C7 YI SYLLABLE RAX
A3C8 YI SYLLABLE RA
A3C9 YI SYLLABLE RAP
A3CA YI SYLLABLE RUOX
A3CB YI SYLLABLE RUO
A3CC YI SYLLABLE RUOP
A3CD YI SYLLABLE ROT
A3CE YI SYLLABLE ROX
A3CF YI SYLLABLE RO
A3D0 YI SYLLABLE ROP
A3D1 YI SYLLABLE REX
A3D2 YI SYLLABLE RE
A3D3 YI SYLLABLE REP
A3D4 YI SYLLABLE RUT
A3D5 YI SYLLABLE RUX
A3D6 YI SYLLABLE RU
A3D7 YI SYLLABLE RUP
A3D8 YI SYLLABLE RURX
A3D9 YI SYLLABLE RUR
A3DA YI SYLLABLE RYT
A3DB YI SYLLABLE RYX
A3DC YI SYLLABLE RY
A3DD YI SYLLABLE RYP
A3DE YI SYLLABLE RYRX
A3DF YI SYLLABLE RYR
A3E0 YI SYLLABLE JIT
A3E1 YI SYLLABLE JIX
A3E2 YI SYLLABLE JI
A3E3 YI SYLLABLE JIP
A3E4 YI SYLLABLE JIET
A3E5 YI SYLLABLE JIEX
A3E6 YI SYLLABLE JIE
A3E7 YI SYLLABLE JIEP
A3E8 YI SYLLABLE JUOT
A3E9 YI SYLLABLE JUOX
A3EA YI SYLLABLE JUO
A3EB YI SYLLABLE JUOP
A3EC YI SYLLABLE JOT
A3ED YI SYLLABLE JOX
A3EE YI SYLLABLE JO
A3EF YI SYLLABLE JOP
A3F0 YI SYLLABLE JUT
A3F1 YI SYLLABLE JUX
A3F2 YI SYLLABLE JU
A3F3 YI SYLLABLE JUP
A3F4 YI SYLLABLE JURX
A3F5 YI SYLLABLE JUR
A3F6 YI SYLLABLE JYT
A3F7 YI SYLLABLE JYX
A3F8 YI SYLLABLE JY
A3F9 YI SYLLABLE JYP
A3FA YI SYLLABLE JYRX
A3FB YI SYLLABLE JYR
A3FC YI SYLLABLE QIT
A3FD YI SYLLABLE QIX
A3FE YI SYLLABLE QI
A3FF YI SYLLABLE QIP
A400 YI SYLLABLE QIET
A401 YI SYLLABLE QIEX
A402 YI SYLLABLE QIE
A403 YI SYLLABLE QIEP
A404 YI SYLLABLE QUOT
A405 YI SYLLABLE QUOX
A406 YI SYLLABLE QUO
A407 YI SYLLABLE QUOP
A408 YI SYLLABLE QOT
A409 YI SYLLABLE QOX
A40A YI SYLLABLE QO
A40B YI SYLLABLE QOP
A40C YI SYLLABLE QUT
A40D YI SYLLABLE QUX
A40E YI SYLLABLE QU
A40F YI SYLLABLE QUP
A410 YI SYLLABLE QURX
A411 YI SYLLABLE QUR
A412 YI SYLLABLE QYT
A413 YI SYLLABLE QYX
A414 YI SYLLABLE QY
A415 YI SYLLABLE QYP
A416 YI SYLLABLE QYRX
A417 YI SYLLABLE QYR
A418 YI SYLLABLE JJIT
A419 YI SYLLABLE JJIX
A41A YI SYLLABLE JJI
A41B YI SYLLABLE JJIP
A41C YI SYLLABLE JJIET
A41D YI SYLLABLE JJIEX
A41E YI SYLLABLE JJIE
A41F YI SYLLABLE JJIEP
A420 YI SYLLABLE JJUOX
A421 YI SYLLABLE JJUO
A422 YI SYLLABLE JJUOP
A423 YI SYLLABLE JJOT
A424 YI SYLLABLE JJOX
A425 YI SYLLABLE JJO
A426 YI SYLLABLE JJOP
A427 YI SYLLABLE JJUT
A428 YI SYLLABLE JJUX
A429 YI SYLLABLE JJU
A42A YI SYLLABLE JJUP
A42B YI SYLLABLE JJURX
A42C YI SYLLABLE JJUR
A42D YI SYLLABLE JJYT
A42E YI SYLLABLE JJYX
A42F YI SYLLABLE JJY
A430 YI SYLLABLE JJYP
A431 YI SYLLABLE NJIT
A432 YI SYLLABLE NJIX
A433 YI SYLLABLE NJI
A434 YI SYLLABLE NJIP
A435 YI SYLLABLE NJIET
A436 YI SYLLABLE NJIEX
A437 YI SYLLABLE NJIE
A438 YI SYLLABLE NJIEP
A439 YI SYLLABLE NJUOX
A43A YI SYLLABLE NJUO
A43B YI SYLLABLE NJOT
A43C YI SYLLABLE NJOX
A43D YI SYLLABLE NJO
A43E YI SYLLABLE NJOP
A43F YI SYLLABLE NJUX
A440 YI SYLLABLE NJU
A441 YI SYLLABLE NJUP
A442 YI SYLLABLE NJURX
A443 YI SYLLABLE NJUR
A444 YI SYLLABLE NJYT
A445 YI SYLLABLE NJYX
A446 YI SYLLABLE NJY
A447 YI SYLLABLE NJYP
A448 YI SYLLABLE NJYRX
A449 YI SYLLABLE NJYR
A44A YI SYLLABLE NYIT
A44B YI SYLLABLE NYIX
A44C YI SYLLABLE NYI
A44D YI SYLLABLE NYIP
A44E YI SYLLABLE NYIET
A44F YI SYLLABLE NYIEX
A450 YI SYLLABLE NYIE
A451 YI SYLLABLE NYIEP
A452 YI SYLLABLE NYUOX
A453 YI SYLLABLE NYUO
A454 YI SYLLABLE NYUOP
A455 YI SYLLABLE NYOT
A456 YI SYLLABLE NYOX
A457 YI SYLLABLE NYO
A458 YI SYLLABLE NYOP
A459 YI SYLLABLE NYUT
A45A YI SYLLABLE NYUX
A45B YI SYLLABLE NYU
A45C YI SYLLABLE NYUP
A45D YI SYLLABLE XIT
A45E YI SYLLABLE XIX
A45F YI SYLLABLE XI
A460 YI SYLLABLE XIP
A461 YI SYLLABLE XIET
A462 YI SYLLABLE XIEX
A463 YI SYLLABLE XIE
A464 YI SYLLABLE XIEP
A465 YI SYLLABLE XUOX
A466 YI SYLLABLE XUO
A467 YI SYLLABLE XOT
A468 YI SYLLABLE XOX
A469 YI SYLLABLE XO
A46A YI SYLLABLE XOP
A46B YI SYLLABLE XYT
A46C YI SYLLABLE XYX
A46D YI SYLLABLE XY
A46E YI SYLLABLE XYP
A46F YI SYLLABLE XYRX
A470 YI SYLLABLE XYR
A471 YI SYLLABLE YIT
A472 YI SYLLABLE YIX
A473 YI SYLLABLE YI
A474 YI SYLLABLE YIP
A475 YI SYLLABLE YIET
A476 YI SYLLABLE YIEX
A477 YI SYLLABLE YIE
A478 YI SYLLABLE YIEP
A479 YI SYLLABLE YUOT
A47A YI SYLLABLE YUOX
A47B YI SYLLABLE YUO
A47C YI SYLLABLE YUOP
A47D YI SYLLABLE YOT
A47E YI SYLLABLE YOX
A47F YI SYLLABLE YO
A480 YI SYLLABLE YOP
A481 YI SYLLABLE YUT
A482 YI SYLLABLE YUX
A483 YI SYLLABLE YU
A484 YI SYLLABLE YUP
A485 YI SYLLABLE YURX
A486 YI SYLLABLE YUR
A487 YI SYLLABLE YYT
A488 YI SYLLABLE YYX
A489 YI SYLLABLE YY
A48A YI SYLLABLE YYP
A48B YI SYLLABLE YYRX
A48C YI SYLLABLE YYR
A490 YI RADICAL QOT
A491 YI RADICAL LI
A492 YI RADICAL KIT
A493 YI RADICAL NYIP
A494 YI RADICAL CYP
A495 YI RADICAL SSI
A496 YI RADICAL GGOP
A497 YI RADICAL GEP
A498 YI RADICAL MI
A499 YI RADICAL HXIT
A49A YI RADICAL LYR
A49B YI RADICAL BBUT
A49C YI RADICAL MOP
A49D YI RADICAL YO
A49E YI RADICAL PUT
A49F YI RADICAL HXUO
A4A0 YI RADICAL TAT
A4A1 YI RADICAL GA
A4A2 YI RADICAL ZUP
A4A3 YI RADICAL CYT
A4A4 YI RADICAL DDUR
A4A5 YI RADICAL BUR
A4A6 YI RADICAL GGUO
A4A7 YI RADICAL NYOP
A4A8 YI RADICAL TU
A4A9 YI RADICAL OP
A4AA YI RADICAL JJUT
A4AB YI RADICAL ZOT
A4AC YI RADICAL PYT
A4AD YI RADICAL HMO
A4AE YI RADICAL YIT
A4AF YI RADICAL VUR
A4B0 YI RADICAL SHY
A4B1 YI RADICAL VEP
A4B2 YI RADICAL ZA
A4B3 YI RADICAL JO
A4B4 YI RADICAL NZUP
A4B5 YI RADICAL JJY
A4B6 YI RADICAL GOT
A4B7 YI RADICAL JJIE
A4B8 YI RADICAL WO
A4B9 YI RADICAL DU
A4BA YI RADICAL SHUR
A4BB YI RADICAL LIE
A4BC YI RADICAL CY
A4BD YI RADICAL CUOP
A4BE YI RADICAL CIP
A4BF YI RADICAL HXOP
A4C0 YI RADICAL SHAT
A4C1 YI RADICAL ZUR
A4C2 YI RADICAL SHOP
A4C3 YI RADICAL CHE
A4C4 YI RADICAL ZZIET
A4C5 YI RADICAL NBIE
A4C6 YI RADICAL KE
A4D0 LISU LETTER BA
A4D1 LISU LETTER PA
A4D2 LISU LETTER PHA
A4D3 LISU LETTER DA
A4D4 LISU LETTER TA
A4D5 LISU LETTER THA
A4D6 LISU LETTER GA
A4D7 LISU LETTER KA
A4D8 LISU LETTER KHA
A4D9 LISU LETTER JA
A4DA LISU LETTER CA
A4DB LISU LETTER CHA
A4DC LISU LETTER DZA
A4DD LISU LETTER TSA
A4DE LISU LETTER TSHA
A4DF LISU LETTER MA
A4E0 LISU LETTER NA
A4E1 LISU LETTER LA
A4E2 LISU LETTER SA
A4E3 LISU LETTER ZHA
A4E4 LISU LETTER ZA
A4E5 LISU LETTER NGA
A4E6 LISU LETTER HA
A4E7 LISU LETTER XA
A4E8 LISU LETTER HHA
A4E9 LISU LETTER FA
A4EA LISU LETTER WA
A4EB LISU LETTER SHA
A4EC LISU LETTER YA
A4ED LISU LETTER GHA
A4EE LISU LETTER A
A4EF LISU LETTER AE
A4F0 LISU LETTER E
A4F1 LISU LETTER EU
A4F2 LISU LETTER I
A4F3 LISU LETTER O
A4F4 LISU LETTER U
A4F5 LISU LETTER UE
A4F6 LISU LETTER UH
A4F7 LISU LETTER OE
A4F8 LISU LETTER TONE MYA TI
A4F9 LISU LETTER TONE NA PO
A4FA LISU LETTER TONE MYA CYA
A4FB LISU LETTER TONE MYA BO
A4FC LISU LETTER TONE MYA NA
A4FD LISU LETTER TONE MYA JEU
A4FE LISU PUNCTUATION COMMA
A4FF LISU PUNCTUATION FULL STOP
A500 VAI SYLLABLE EE
A501 VAI SYLLABLE EEN
A502 VAI SYLLABLE HEE
A503 VAI SYLLABLE WEE
A504 VAI SYLLABLE WEEN
A505 VAI SYLLABLE PEE
A506 VAI SYLLABLE BHEE
A507 VAI SYLLABLE BEE
A508 VAI SYLLABLE MBEE
A509 VAI SYLLABLE KPEE
A50A VAI SYLLABLE MGBEE
A50B VAI SYLLABLE GBEE
A50C VAI SYLLABLE FEE
A50D VAI SYLLABLE VEE
A50E VAI SYLLABLE TEE
A50F VAI SYLLABLE THEE
A510 VAI SYLLABLE DHEE
A511 VAI SYLLABLE DHHEE
A512 VAI SYLLABLE LEE
A513 VAI SYLLABLE REE
A514 VAI SYLLABLE DEE
A515 VAI SYLLABLE NDEE
A516 VAI SYLLABLE SEE
A517 VAI SYLLABLE SHEE
A518 VAI SYLLABLE ZEE
A519 VAI SYLLABLE ZHEE
A51A VAI SYLLABLE CEE
A51B VAI SYLLABLE JEE
A51C VAI SYLLABLE NJEE
A51D VAI SYLLABLE YEE
A51E VAI SYLLABLE KEE
A51F VAI SYLLABLE NGGEE
A520 VAI SYLLABLE GEE
A521 VAI SYLLABLE MEE
A522 VAI SYLLABLE NEE
A523 VAI SYLLABLE NYEE
A524 VAI SYLLABLE I
A525 VAI SYLLABLE IN
A526 VAI SYLLABLE HI
A527 VAI SYLLABLE HIN
A528 VAI SYLLABLE WI
A529 VAI SYLLABLE WIN
A52A VAI SYLLABLE PI
A52B VAI SYLLABLE BHI
A52C VAI SYLLABLE BI
A52D VAI SYLLABLE MBI
A52E VAI SYLLABLE KPI
A52F VAI SYLLABLE MGBI
A530 VAI SYLLABLE GBI
A531 VAI SYLLABLE FI
A532 VAI SYLLABLE VI
A533 VAI SYLLABLE TI
A534 VAI SYLLABLE THI
A535 VAI SYLLABLE DHI
A536 VAI SYLLABLE DHHI
A537 VAI SYLLABLE LI
A538 VAI SYLLABLE RI
A539 VAI SYLLABLE DI
A53A VAI SYLLABLE NDI
A53B VAI SYLLABLE SI
A53C VAI SYLLABLE SHI
A53D VAI SYLLABLE ZI
A53E VAI SYLLABLE ZHI
A53F VAI SYLLABLE CI
A540 VAI SYLLABLE JI
A541 VAI SYLLABLE NJI
A542 VAI SYLLABLE YI
A543 VAI SYLLABLE KI
A544 VAI SYLLABLE NGGI
A545 VAI SYLLABLE GI
A546 VAI SYLLABLE MI
A547 VAI SYLLABLE NI
A548 VAI SYLLABLE NYI
A549 VAI SYLLABLE A
A54A VAI SYLLABLE AN
A54B VAI SYLLABLE NGAN
A54C VAI SYLLABLE HA
A54D VAI SYLLABLE HAN
A54E VAI SYLLABLE WA
A54F VAI SYLLABLE WAN
A550 VAI SYLLABLE PA
A551 VAI SYLLABLE BHA
A552 VAI SYLLABLE BA
A553 VAI SYLLABLE MBA
A554 VAI SYLLABLE KPA
A555 VAI SYLLABLE KPAN
A556 VAI SYLLABLE MGBA
A557 VAI SYLLABLE GBA
A558 VAI SYLLABLE FA
A559 VAI SYLLABLE VA
A55A VAI SYLLABLE TA
A55B VAI SYLLABLE THA
A55C VAI SYLLABLE DHA
A55D VAI SYLLABLE DHHA
A55E VAI SYLLABLE LA
A55F VAI SYLLABLE RA
A560 VAI SYLLABLE DA
A561 VAI SYLLABLE NDA
A562 VAI SYLLABLE SA
A563 VAI SYLLABLE SHA
A564 VAI SYLLABLE ZA
A565 VAI SYLLABLE ZHA
A566 VAI SYLLABLE CA
A567 VAI SYLLABLE JA
A568 VAI SYLLABLE NJA
A569 VAI SYLLABLE YA
A56A VAI SYLLABLE KA
A56B VAI SYLLABLE KAN
A56C VAI SYLLABLE NGGA
A56D VAI SYLLABLE GA
A56E VAI SYLLABLE MA
A56F VAI SYLLABLE NA
A570 VAI SYLLABLE NYA
A571 VAI SYLLABLE OO
A572 VAI SYLLABLE OON
A573 VAI SYLLABLE HOO
A574 VAI SYLLABLE WOO
A575 VAI SYLLABLE WOON
A576 VAI SYLLABLE POO
A577 VAI SYLLABLE BHOO
A578 VAI SYLLABLE BOO
A579 VAI SYLLABLE MBOO
A57A VAI SYLLABLE KPOO
A57B VAI SYLLABLE MGBOO
A57C VAI SYLLABLE GBOO
A57D VAI SYLLABLE FOO
A57E VAI SYLLABLE VOO
A57F VAI SYLLABLE TOO
A580 VAI SYLLABLE THOO
A581 VAI SYLLABLE DHOO
A582 VAI SYLLABLE DHHOO
A583 VAI SYLLABLE LOO
A584 VAI SYLLABLE ROO
A585 VAI SYLLABLE DOO
A586 VAI SYLLABLE NDOO
A587 VAI SYLLABLE SOO
A588 VAI SYLLABLE SHOO
A589 VAI SYLLABLE ZOO
A58A VAI SYLLABLE ZHOO
A58B VAI SYLLABLE COO
A58C VAI SYLLABLE JOO
A58D VAI SYLLABLE NJOO
A58E VAI SYLLABLE YOO
A58F VAI SYLLABLE KOO
A590 VAI SYLLABLE NGGOO
A591 VAI SYLLABLE GOO
A592 VAI SYLLABLE MOO
A593 VAI SYLLABLE NOO
A594 VAI SYLLABLE NYOO
A595 VAI SYLLABLE U
A596 VAI SYLLABLE UN
A597 VAI SYLLABLE HU
A598 VAI SYLLABLE HUN
A599 VAI SYLLABLE WU
A59A VAI SYLLABLE WUN
A59B VAI SYLLABLE PU
A59C VAI SYLLABLE BHU
A59D VAI SYLLABLE BU
A59E VAI SYLLABLE MBU
A59F VAI SYLLABLE KPU
A5A0 VAI SYLLABLE MGBU
A5A1 VAI SYLLABLE GBU
A5A2 VAI SYLLABLE FU
A5A3 VAI SYLLABLE VU
A5A4 VAI SYLLABLE TU
A5A5 VAI SYLLABLE THU
A5A6 VAI SYLLABLE DHU
A5A7 VAI SYLLABLE DHHU
A5A8 VAI SYLLABLE LU
A5A9 VAI SYLLABLE RU
A5AA VAI SYLLABLE DU
A5AB VAI SYLLABLE NDU
A5AC VAI SYLLABLE SU
A5AD VAI SYLLABLE SHU
A5AE VAI SYLLABLE ZU
A5AF VAI SYLLABLE ZHU
A5B0 VAI SYLLABLE CU
A5B1 VAI SYLLABLE JU
A5B2 VAI SYLLABLE NJU
A5B3 VAI SYLLABLE YU
A5B4 VAI SYLLABLE KU
A5B5 VAI SYLLABLE NGGU
A5B6 VAI SYLLABLE GU
A5B7 VAI SYLLABLE MU
A5B8 VAI SYLLABLE NU
A5B9 VAI SYLLABLE NYU
A5BA VAI SYLLABLE O
A5BB VAI SYLLABLE ON
A5BC VAI SYLLABLE NGON
A5BD VAI SYLLABLE HO
A5BE VAI SYLLABLE HON
A5BF VAI SYLLABLE WO
A5C0 VAI SYLLABLE WON
A5C1 VAI SYLLABLE PO
A5C2 VAI SYLLABLE BHO
A5C3 VAI SYLLABLE BO
A5C4 VAI SYLLABLE MBO
A5C5 VAI SYLLABLE KPO
A5C6 VAI SYLLABLE MGBO
A5C7 VAI SYLLABLE GBO
A5C8 VAI SYLLABLE GBON
A5C9 VAI SYLLABLE FO
A5CA VAI SYLLABLE VO
A5CB VAI SYLLABLE TO
A5CC VAI SYLLABLE THO
A5CD VAI SYLLABLE DHO
A5CE VAI SYLLABLE DHHO
A5CF VAI SYLLABLE LO
A5D0 VAI SYLLABLE RO
A5D1 VAI SYLLABLE DO
A5D2 VAI SYLLABLE NDO
A5D3 VAI SYLLABLE SO
A5D4 VAI SYLLABLE SHO
A5D5 VAI SYLLABLE ZO
A5D6 VAI SYLLABLE ZHO
A5D7 VAI SYLLABLE CO
A5D8 VAI SYLLABLE JO
A5D9 VAI SYLLABLE NJO
A5DA VAI SYLLABLE YO
A5DB VAI SYLLABLE KO
A5DC VAI SYLLABLE NGGO
A5DD VAI SYLLABLE GO
A5DE VAI SYLLABLE MO
A5DF VAI SYLLABLE NO
A5E0 VAI SYLLABLE NYO
A5E1 VAI SYLLABLE E
A5E2 VAI SYLLABLE EN
A5E3 VAI SYLLABLE NGEN
A5E4 VAI SYLLABLE HE
A5E5 VAI SYLLABLE HEN
A5E6 VAI SYLLABLE WE
A5E7 VAI SYLLABLE WEN
A5E8 VAI SYLLABLE PE
A5E9 VAI SYLLABLE BHE
A5EA VAI SYLLABLE BE
A5EB VAI SYLLABLE MBE
A5EC VAI SYLLABLE KPE
A5ED VAI SYLLABLE KPEN
A5EE VAI SYLLABLE MGBE
A5EF VAI SYLLABLE GBE
A5F0 VAI SYLLABLE GBEN
A5F1 VAI SYLLABLE FE
A5F2 VAI SYLLABLE VE
A5F3 VAI SYLLABLE TE
A5F4 VAI SYLLABLE THE
A5F5 VAI SYLLABLE DHE
A5F6 VAI SYLLABLE DHHE
A5F7 VAI SYLLABLE LE
A5F8 VAI SYLLABLE RE
A5F9 VAI SYLLABLE DE
A5FA VAI SYLLABLE NDE
A5FB VAI SYLLABLE SE
A5FC VAI SYLLABLE SHE
A5FD VAI SYLLABLE ZE
A5FE VAI SYLLABLE ZHE
A5FF VAI SYLLABLE CE
A600 VAI SYLLABLE JE
A601 VAI SYLLABLE NJE
A602 VAI SYLLABLE YE
A603 VAI SYLLABLE KE
A604 VAI SYLLABLE NGGE
A605 VAI SYLLABLE NGGEN
A606 VAI SYLLABLE GE
A607 VAI SYLLABLE GEN
A608 VAI SYLLABLE ME
A609 VAI SYLLABLE NE
A60A VAI SYLLABLE NYE
A60B VAI SYLLABLE NG
A60C VAI SYLLABLE LENGTHENER
A60D VAI COMMA
A60E VAI FULL STOP
A60F VAI QUESTION MARK
A610 VAI SYLLABLE NDOLE FA
A611 VAI SYLLABLE NDOLE KA
A612 VAI SYLLABLE NDOLE SOO
A613 VAI SYMBOL FEENG
A614 VAI SYMBOL KEENG
A615 VAI SYMBOL TING
A616 VAI SYMBOL NII
A617 VAI SYMBOL BANG
A618 VAI SYMBOL FAA
A619 VAI SYMBOL TAA
A61A VAI SYMBOL DANG
A61B VAI SYMBOL DOONG
A61C VAI SYMBOL KUNG
A61D VAI SYMBOL TONG
A61E VAI SYMBOL DO-O
A61F VAI SYMBOL JONG
A620 VAI DIGIT ZERO
A621 VAI DIGIT ONE
A622 VAI DIGIT TWO
A623 VAI DIGIT THREE
A624 VAI DIGIT FOUR
A625 VAI DIGIT FIVE
A626 VAI DIGIT SIX
A627 VAI DIGIT SEVEN
A628 VAI DIGIT EIGHT
A629 VAI DIGIT NINE
A62A VAI SYLLABLE NDOLE MA
A62B VAI SYLLABLE NDOLE DO
A640 CYRILLIC CAPITAL LETTER ZEMLYA
A641 CYRILLIC SMALL LETTER ZEMLYA
A642 CYRILLIC CAPITAL LETTER DZELO
A643 CYRILLIC SMALL LETTER DZELO
A644 CYRILLIC CAPITAL LETTER REVERSED DZE
A645 CYRILLIC SMALL LETTER REVERSED DZE
A646 CYRILLIC CAPITAL LETTER IOTA
A647 CYRILLIC SMALL LETTER IOTA
A648 CYRILLIC CAPITAL LETTER DJERV
A649 CYRILLIC SMALL LETTER DJERV
A64A CYRILLIC CAPITAL LETTER MONOGRAPH UK
A64B CYRILLIC SMALL LETTER MONOGRAPH UK
A64C CYRILLIC CAPITAL LETTER BROAD OMEGA
A64D CYRILLIC SMALL LETTER BROAD OMEGA
A64E CYRILLIC CAPITAL LETTER NEUTRAL YER
A64F CYRILLIC SMALL LETTER NEUTRAL YER
A650 CYRILLIC CAPITAL LETTER YERU WITH BACK YER
A651 CYRILLIC SMALL LETTER YERU WITH BACK YER
A652 CYRILLIC CAPITAL LETTER IOTIFIED YAT
A653 CYRILLIC SMALL LETTER IOTIFIED YAT
A654 CYRILLIC CAPITAL LETTER REVERSED YU
A655 CYRILLIC SMALL LETTER REVERSED YU
A656 CYRILLIC CAPITAL LETTER IOTIFIED A
A657 CYRILLIC SMALL LETTER IOTIFIED A
A658 CYRILLIC CAPITAL LETTER CLOSED LITTLE YUS
A659 CYRILLIC SMALL LETTER CLOSED LITTLE YUS
A65A CYRILLIC CAPITAL LETTER BLENDED YUS
A65B CYRILLIC SMALL LETTER BLENDED YUS
A65C CYRILLIC CAPITAL LETTER IOTIFIED CLOSED LITTLE YUS
A65D CYRILLIC SMALL LETTER IOTIFIED CLOSED LITTLE YUS
A65E CYRILLIC CAPITAL LETTER YN
A65F CYRILLIC SMALL LETTER YN
A660 CYRILLIC CAPITAL LETTER REVERSED TSE
A661 CYRILLIC SMALL LETTER REVERSED TSE
A662 CYRILLIC CAPITAL LETTER SOFT DE
A663 CYRILLIC SMALL LETTER SOFT DE
A664 CYRILLIC CAPITAL LETTER SOFT EL
A665 CYRILLIC SMALL LETTER SOFT EL
A666 CYRILLIC CAPITAL LETTER SOFT EM
A667 CYRILLIC SMALL LETTER SOFT EM
A668 CYRILLIC CAPITAL LETTER MONOCULAR O
A669 CYRILLIC SMALL LETTER MONOCULAR O
A66A CYRILLIC CAPITAL LETTER BINOCULAR O
A66B CYRILLIC SMALL LETTER BINOCULAR O
A66C CYRILLIC CAPITAL LETTER DOUBLE MONOCULAR O
A66D CYRILLIC SMALL LETTER DOUBLE MONOCULAR O
A66E CYRILLIC LETTER MULTIOCULAR O
A66F COMBINING CYRILLIC VZMET
A670 COMBINING CYRILLIC TEN MILLIONS SIGN
A671 COMBINING CYRILLIC HUNDRED MILLIONS SIGN
A672 COMBINING CYRILLIC THOUSAND MILLIONS SIGN
A673 SLAVONIC ASTERISK
A674 COMBINING CYRILLIC LETTER UKRAINIAN IE
A675 COMBINING CYRILLIC LETTER I
A676 COMBINING CYRILLIC LETTER YI
A677 COMBINING CYRILLIC LETTER U
A678 COMBINING CYRILLIC LETTER HARD SIGN
A679 COMBINING CYRILLIC LETTER YERU
A67A COMBINING CYRILLIC LETTER SOFT SIGN
A67B COMBINING CYRILLIC LETTER OMEGA
A67C COMBINING CYRILLIC KAVYKA
A67D COMBINING CYRILLIC PAYEROK
A67E CYRILLIC KAVYKA
A67F CYRILLIC PAYEROK
A680 CYRILLIC CAPITAL LETTER DWE
A681 CYRILLIC SMALL LETTER DWE
A682 CYRILLIC CAPITAL LETTER DZWE
A683 CYRILLIC SMALL LETTER DZWE
A684 CYRILLIC CAPITAL LETTER ZHWE
A685 CYRILLIC SMALL LETTER ZHWE
A686 CYRILLIC CAPITAL LETTER CCHE
A687 CYRILLIC SMALL LETTER CCHE
A688 CYRILLIC CAPITAL LETTER DZZE
A689 CYRILLIC SMALL LETTER DZZE
A68A CYRILLIC CAPITAL LETTER TE WITH MIDDLE HOOK
A68B CYRILLIC SMALL LETTER TE WITH MIDDLE HOOK
A68C CYRILLIC CAPITAL LETTER TWE
A68D CYRILLIC SMALL LETTER TWE
A68E CYRILLIC CAPITAL LETTER TSWE
A68F CYRILLIC SMALL LETTER TSWE
A690 CYRILLIC CAPITAL LETTER TSSE
A691 CYRILLIC SMALL LETTER TSSE
A692 CYRILLIC CAPITAL LETTER TCHE
A693 CYRILLIC SMALL LETTER TCHE
A694 CYRILLIC CAPITAL LETTER HWE
A695 CYRILLIC SMALL LETTER HWE
A696 CYRILLIC CAPITAL LETTER SHWE
A697 CYRILLIC SMALL LETTER SHWE
A698 CYRILLIC CAPITAL LETTER DOUBLE O
A699 CYRILLIC SMALL LETTER DOUBLE O
A69A CYRILLIC CAPITAL LETTER CROSSED O
A69B CYRILLIC SMALL LETTER CROSSED O
A69C MODIFIER LETTER CYRILLIC HARD SIGN
A69D MODIFIER LETTER CYRILLIC SOFT SIGN
A69E COMBINING CYRILLIC LETTER EF
A69F COMBINING CYRILLIC LETTER IOTIFIED E
A6A0 BAMUM LETTER A
A6A1 BAMUM LETTER KA
A6A2 BAMUM LETTER U
A6A3 BAMUM LETTER KU
A6A4 BAMUM LETTER EE
A6A5 BAMUM LETTER REE
A6A6 BAMUM LETTER TAE
A6A7 BAMUM LETTER O
A6A8 BAMUM LETTER NYI
A6A9 BAMUM LETTER I
A6AA BAMUM LETTER LA
A6AB BAMUM LETTER PA
A6AC BAMUM LETTER RII
A6AD BAMUM LETTER RIEE
A6AE BAMUM LETTER LEEEE
A6AF BAMUM LETTER MEEEE
A6B0 BAMUM LETTER TAA
A6B1 BAMUM LETTER NDAA
A6B2 BAMUM LETTER NJAEM
A6B3 BAMUM LETTER M
A6B4 BAMUM LETTER SUU
A6B5 BAMUM LETTER MU
A6B6 BAMUM LETTER SHII
A6B7 BAMUM LETTER SI
A6B8 BAMUM LETTER SHEUX
A6B9 BAMUM LETTER SEUX
A6BA BAMUM LETTER KYEE
A6BB BAMUM LETTER KET
A6BC BAMUM LETTER NUAE
A6BD BAMUM LETTER NU
A6BE BAMUM LETTER NJUAE
A6BF BAMUM LETTER YOQ
A6C0 BAMUM LETTER SHU
A6C1 BAMUM LETTER YUQ
A6C2 BAMUM LETTER YA
A6C3 BAMUM LETTER NSHA
A6C4 BAMUM LETTER KEUX
A6C5 BAMUM LETTER PEUX
A6C6 BAMUM LETTER NJEE
A6C7 BAMUM LETTER NTEE
A6C8 BAMUM LETTER PUE
A6C9 BAMUM LETTER WUE
A6CA BAMUM LETTER PEE
A6CB BAMUM LETTER FEE
A6CC BAMUM LETTER RU
A6CD BAMUM LETTER LU
A6CE BAMUM LETTER MI
A6CF BAMUM LETTER NI
A6D0 BAMUM LETTER REUX
A6D1 BAMUM LETTER RAE
A6D2 BAMUM LETTER KEN
A6D3 BAMUM LETTER NGKWAEN
A6D4 BAMUM LETTER NGGA
A6D5 BAMUM LETTER NGA
A6D6 BAMUM LETTER SHO
A6D7 BAMUM LETTER PUAE
A6D8 BAMUM LETTER FU
A6D9 BAMUM LETTER FOM
A6DA BAMUM LETTER WA
A6DB BAMUM LETTER NA
A6DC BAMUM LETTER LI
A6DD BAMUM LETTER PI
A6DE BAMUM LETTER LOQ
A6DF BAMUM LETTER KO
A6E0 BAMUM LETTER MBEN
A6E1 BAMUM LETTER REN
A6E2 BAMUM LETTER MEN
A6E3 BAMUM LETTER MA
A6E4 BAMUM LETTER TI
A6E5 BAMUM LETTER KI
A6E6 BAMUM LETTER MO
A6E7 BAMUM LETTER MBAA
A6E8 BAMUM LETTER TET
A6E9 BAMUM LETTER KPA
A6EA BAMUM LETTER TEN
A6EB BAMUM LETTER NTUU
A6EC BAMUM LETTER SAMBA
A6ED BAMUM LETTER FAAMAE
A6EE BAMUM LETTER KOVUU
A6EF BAMUM LETTER KOGHOM
A6F0 BAMUM COMBINING MARK KOQNDON
A6F1 BAMUM COMBINING MARK TUKWENTIS
A6F2 BAMUM NJAEMLI
A6F3 BAMUM FULL STOP
A6F4 BAMUM COLON
A6F5 BAMUM COMMA
A6F6 BAMUM SEMICOLON
A6F7 BAMUM QUESTION MARK
A700 MODIFIER LETTER CHINESE TONE YIN PING
A701 MODIFIER LETTER CHINESE TONE YANG PING
A702 MODIFIER LETTER CHINESE TONE YIN SHANG
A703 MODIFIER LETTER CHINESE TONE YANG SHANG
A704 MODIFIER LETTER CHINESE TONE YIN QU
A705 MODIFIER LETTER CHINESE TONE YANG QU
A706 MODIFIER LETTER CHINESE TONE YIN RU
A707 MODIFIER LETTER CHINESE TONE YANG RU
A708 MODIFIER LETTER EXTRA-HIGH DOTTED TONE BAR
A709 MODIFIER LETTER HIGH DOTTED TONE BAR
A70A MODIFIER LETTER MID DOTTED TONE BAR
A70B MODIFIER LETTER LOW DOTTED TONE BAR
A70C MODIFIER LETTER EXTRA-LOW DOTTED TONE BAR
A70D MODIFIER LETTER EXTRA-HIGH DOTTED LEFT-STEM TONE BAR
A70E MODIFIER LETTER HIGH DOTTED LEFT-STEM TONE BAR
A70F MODIFIER LETTER MID DOTTED LEFT-STEM TONE BAR
A710 MODIFIER LETTER LOW DOTTED LEFT-STEM TONE BAR
A711 MODIFIER LETTER EXTRA-LOW DOTTED LEFT-STEM TONE BAR
A712 MODIFIER LETTER EXTRA-HIGH LEFT-STEM TONE BAR
A713 MODIFIER LETTER HIGH LEFT-STEM TONE BAR
A714 MODIFIER LETTER MID LEFT-STEM TONE BAR
A715 MODIFIER LETTER LOW LEFT-STEM TONE BAR
A716 MODIFIER LETTER EXTRA-LOW LEFT-STEM TONE BAR
A717 MODIFIER LETTER DOT VERTICAL BAR
A718 MODIFIER LETTER DOT SLASH
A719 MODIFIER LETTER DOT HORIZONTAL BAR
A71A MODIFIER LETTER LOWER RIGHT CORNER ANGLE
A71B MODIFIER LETTER RAISED UP ARROW
A71C MODIFIER LETTER RAISED DOWN ARROW
A71D MODIFIER LETTER RAISED EXCLAMATION MARK
A71E MODIFIER LETTER RAISED INVERTED EXCLAMATION MARK
A71F MODIFIER LETTER LOW INVERTED EXCLAMATION MARK
A720 MODIFIER LETTER STRESS AND HIGH TONE
A721 MODIFIER LETTER STRESS AND LOW TONE
A722 LATIN CAPITAL LETTER EGYPTOLOGICAL ALEF
A723 LATIN SMALL LETTER EGYPTOLOGICAL ALEF
A724 LATIN CAPITAL LETTER EGYPTOLOGICAL AIN
A725 LATIN SMALL LETTER EGYPTOLOGICAL AIN
A726 LATIN CAPITAL LETTER HENG
A727 LATIN SMALL LETTER HENG
A728 LATIN CAPITAL LETTER TZ
A729 LATIN SMALL LETTER TZ
A72A LATIN CAPITAL LETTER TRESILLO
A72B LATIN SMALL LETTER TRESILLO
A72C LATIN CAPITAL LETTER CUATRILLO
A72D LATIN SMALL LETTER CUATRILLO
A72E LATIN CAPITAL LETTER CUATRILLO WITH COMMA
A72F LATIN SMALL LETTER CUATRILLO WITH COMMA
A730 LATIN LETTER SMALL CAPITAL F
A731 LATIN LETTER SMALL CAPITAL S
A732 LATIN CAPITAL LETTER AA
A733 LATIN SMALL LETTER AA
A734 LATIN CAPITAL LETTER AO
A735 LATIN SMALL LETTER AO
A736 LATIN CAPITAL LETTER AU
A737 LATIN SMALL LETTER AU
A738 LATIN CAPITAL LETTER AV
A739 LATIN SMALL LETTER AV
A73A LATIN CAPITAL LETTER AV WITH HORIZONTAL BAR
A73B LATIN SMALL LETTER AV WITH HORIZONTAL BAR
A73C LATIN CAPITAL LETTER AY
A73D LATIN SMALL LETTER AY
A73E LATIN CAPITAL LETTER REVERSED C WITH DOT
A73F LATIN SMALL LETTER REVERSED C WITH DOT
A740 LATIN CAPITAL LETTER K WITH STROKE
A741 LATIN SMALL LETTER K WITH STROKE
A742 LATIN CAPITAL LETTER K WITH DIAGONAL STROKE
A743 LATIN SMALL LETTER K WITH DIAGONAL STROKE
A744 LATIN CAPITAL LETTER K WITH STROKE AND DIAGONAL STROKE
A745 LATIN SMALL LETTER K WITH STROKE AND DIAGONAL STROKE
A746 LATIN CAPITAL LETTER BROKEN L
A747 LATIN SMALL LETTER BROKEN L
A748 LATIN CAPITAL LETTER L WITH HIGH STROKE
A749 LATIN SMALL LETTER L WITH HIGH STROKE
A74A LATIN CAPITAL LETTER O WITH LONG STROKE OVERLAY
A74B LATIN SMALL LETTER O WITH LONG STROKE OVERLAY
A74C LATIN CAPITAL LETTER O WITH LOOP
A74D LATIN SMALL LETTER O WITH LOOP
A74E LATIN CAPITAL LETTER OO
A74F LATIN SMALL LETTER OO
A750 LATIN CAPITAL LETTER P WITH STROKE THROUGH DESCENDER
A751 LATIN SMALL LETTER P WITH STROKE THROUGH DESCENDER
A752 LATIN CAPITAL LETTER P WITH FLOURISH
A753 LATIN SMALL LETTER P WITH FLOURISH
A754 LATIN CAPITAL LETTER P WITH SQUIRREL TAIL
A755 LATIN SMALL LETTER P WITH SQUIRREL TAIL
A756 LATIN CAPITAL LETTER Q WITH STROKE THROUGH DESCENDER
A757 LATIN SMALL LETTER Q WITH STROKE THROUGH DESCENDER
A758 LATIN CAPITAL LETTER Q WITH DIAGONAL STROKE
A759 LATIN SMALL LETTER Q WITH DIAGONAL STROKE
A75A LATIN CAPITAL LETTER R ROTUNDA
A75B LATIN SMALL LETTER R ROTUNDA
A75C LATIN CAPITAL LETTER RUM ROTUNDA
A75D LATIN SMALL LETTER RUM ROTUNDA
A75E LATIN CAPITAL LETTER V WITH DIAGONAL STROKE
A75F LATIN SMALL LETTER V WITH DIAGONAL STROKE
A760 LATIN CAPITAL LETTER VY
A761 LATIN SMALL LETTER VY
A762 LATIN CAPITAL LETTER VISIGOTHIC Z
A763 LATIN SMALL LETTER VISIGOTHIC Z
A764 LATIN CAPITAL LETTER THORN WITH STROKE
A765 LATIN SMALL LETTER THORN WITH STROKE
A766 LATIN CAPITAL LETTER THORN WITH STROKE THROUGH DESCENDER
A767 LATIN SMALL LETTER THORN WITH STROKE THROUGH DESCENDER
A768 LATIN CAPITAL LETTER VEND
A769 LATIN SMALL LETTER VEND
A76A LATIN CAPITAL LETTER ET
A76B LATIN SMALL LETTER ET
A76C LATIN CAPITAL LETTER IS
A76D LATIN SMALL LETTER IS
A76E LATIN CAPITAL LETTER CON
A76F LATIN SMALL LETTER CON
A770 MODIFIER LETTER US
A771 LATIN SMALL LETTER DUM
A772 LATIN SMALL LETTER LUM
A773 LATIN SMALL LETTER MUM
A774 LATIN SMALL LETTER NUM
A775 LATIN SMALL LETTER RUM
A776 LATIN LETTER SMALL CAPITAL RUM
A777 LATIN SMALL LETTER TUM
A778 LATIN SMALL LETTER UM
A779 LATIN CAPITAL LETTER INSULAR D
A77A LATIN SMALL LETTER INSULAR D
A77B LATIN CAPITAL LETTER INSULAR F
A77C LATIN SMALL LETTER INSULAR F
A77D LATIN CAPITAL LETTER INSULAR G
A77E LATIN CAPITAL LETTER TURNED INSULAR G
A77F LATIN SMALL LETTER TURNED INSULAR G
A780 LATIN CAPITAL LETTER TURNED L
A781 LATIN SMALL LETTER TURNED L
A782 LATIN CAPITAL LETTER INSULAR R
A783 LATIN SMALL LETTER INSULAR R
A784 LATIN CAPITAL LETTER INSULAR S
A785 LATIN SMALL LETTER INSULAR S
A786 LATIN CAPITAL LETTER INSULAR T
A787 LATIN SMALL LETTER INSULAR T
A788 MODIFIER LETTER LOW CIRCUMFLEX ACCENT
A789 MODIFIER LETTER COLON
A78A MODIFIER LETTER SHORT EQUALS SIGN
A78B LATIN CAPITAL LETTER SALTILLO
A78C LATIN SMALL LETTER SALTILLO
A78D LATIN CAPITAL LETTER TURNED H
A78E LATIN SMALL LETTER L WITH RETROFLEX HOOK AND BELT
A78F LATIN LETTER SINOLOGICAL DOT
A790 LATIN CAPITAL LETTER N WITH DESCENDER
A791 LATIN SMALL LETTER N WITH DESCENDER
A792 LATIN CAPITAL LETTER C WITH BAR
A793 LATIN SMALL LETTER C WITH BAR
A794 LATIN SMALL LETTER C WITH PALATAL HOOK
A795 LATIN SMALL LETTER H WITH PALATAL HOOK
A796 LATIN CAPITAL LETTER B WITH FLOURISH
A797 LATIN SMALL LETTER B WITH FLOURISH
A798 LATIN CAPITAL LETTER F WITH STROKE
A799 LATIN SMALL LETTER F WITH STROKE
A79A LATIN CAPITAL LETTER VOLAPUK AE
A79B LATIN SMALL LETTER VOLAPUK AE
A79C LATIN CAPITAL LETTER VOLAPUK OE
A79D LATIN SMALL LETTER VOLAPUK OE
A79E LATIN CAPITAL LETTER VOLAPUK UE
A79F LATIN SMALL LETTER VOLAPUK UE
A7A0 LATIN CAPITAL LETTER G WITH OBLIQUE STROKE
A7A1 LATIN SMALL LETTER G WITH OBLIQUE STROKE
A7A2 LATIN CAPITAL LETTER K WITH OBLIQUE STROKE
A7A3 LATIN SMALL LETTER K WITH OBLIQUE STROKE
A7A4 LATIN CAPITAL LETTER N WITH OBLIQUE STROKE
A7A5 LATIN SMALL LETTER N WITH OBLIQUE STROKE
A7A6 LATIN CAPITAL LETTER R WITH OBLIQUE STROKE
A7A7 LATIN SMALL LETTER R WITH OBLIQUE STROKE
A7A8 LATIN CAPITAL LETTER S WITH OBLIQUE STROKE
A7A9 LATIN SMALL LETTER S WITH OBLIQUE STROKE
A7AA LATIN CAPITAL LETTER H WITH HOOK
A7AB LATIN CAPITAL LETTER REVERSED OPEN E
A7AC LATIN CAPITAL LETTER SCRIPT G
A7AD LATIN CAPITAL LETTER L WITH BELT
A7AE LATIN CAPITAL LETTER SMALL CAPITAL I
A7B0 LATIN CAPITAL LETTER TURNED K
A7B1 LATIN CAPITAL LETTER TURNED T
A7B2 LATIN CAPITAL LETTER J WITH CROSSED-TAIL
A7B3 LATIN CAPITAL LETTER CHI
A7B4 LATIN CAPITAL LETTER BETA
A7B5 LATIN SMALL LETTER BETA
A7B6 LATIN CAPITAL LETTER OMEGA
A7B7 LATIN SMALL LETTER OMEGA
A7F7 LATIN EPIGRAPHIC LETTER SIDEWAYS I
A7F8 MODIFIER LETTER CAPITAL H WITH STROKE
A7F9 MODIFIER LETTER SMALL LIGATURE OE
A7FA LATIN LETTER SMALL CAPITAL TURNED M
A7FB LATIN EPIGRAPHIC LETTER REVERSED F
A7FC LATIN EPIGRAPHIC LETTER REVERSED P
A7FD LATIN EPIGRAPHIC LETTER INVERTED M
A7FE LATIN EPIGRAPHIC LETTER I LONGA
A7FF LATIN EPIGRAPHIC LETTER ARCHAIC M
A800 SYLOTI NAGRI LETTER A
A801 SYLOTI NAGRI LETTER I
A802 SYLOTI NAGRI SIGN DVISVARA
A803 SYLOTI NAGRI LETTER U
A804 SYLOTI NAGRI LETTER E
A805 SYLOTI NAGRI LETTER O
A806 SYLOTI NAGRI SIGN HASANTA
A807 SYLOTI NAGRI LETTER KO
A808 SYLOTI NAGRI LETTER KHO
A809 SYLOTI NAGRI LETTER GO
A80A SYLOTI NAGRI LETTER GHO
A80B SYLOTI NAGRI SIGN ANUSVARA
A80C SYLOTI NAGRI LETTER CO
A80D SYLOTI NAGRI LETTER CHO
A80E SYLOTI NAGRI LETTER JO
A80F SYLOTI NAGRI LETTER JHO
A810 SYLOTI NAGRI LETTER TTO
A811 SYLOTI NAGRI LETTER TTHO
A812 SYLOTI NAGRI LETTER DDO
A813 SYLOTI NAGRI LETTER DDHO
A814 SYLOTI NAGRI LETTER TO
A815 SYLOTI NAGRI LETTER THO
A816 SYLOTI NAGRI LETTER DO
A817 SYLOTI NAGRI LETTER DHO
A818 SYLOTI NAGRI LETTER NO
A819 SYLOTI NAGRI LETTER PO
A81A SYLOTI NAGRI LETTER PHO
A81B SYLOTI NAGRI LETTER BO
A81C SYLOTI NAGRI LETTER BHO
A81D SYLOTI NAGRI LETTER MO
A81E SYLOTI NAGRI LETTER RO
A81F SYLOTI NAGRI LETTER LO
A820 SYLOTI NAGRI LETTER RRO
A821 SYLOTI NAGRI LETTER SO
A822 SYLOTI NAGRI LETTER HO
A823 SYLOTI NAGRI VOWEL SIGN A
A824 SYLOTI NAGRI VOWEL SIGN I
A825 SYLOTI NAGRI VOWEL SIGN U
A826 SYLOTI NAGRI VOWEL SIGN E
A827 SYLOTI NAGRI VOWEL SIGN OO
A828 SYLOTI NAGRI POETRY MARK-1
A829 SYLOTI NAGRI POETRY MARK-2
A82A SYLOTI NAGRI POETRY MARK-3
A82B SYLOTI NAGRI POETRY MARK-4
A830 NORTH INDIC FRACTION ONE QUARTER
A831 NORTH INDIC FRACTION ONE HALF
A832 NORTH INDIC FRACTION THREE QUARTERS
A833 NORTH INDIC FRACTION ONE SIXTEENTH
A834 NORTH INDIC FRACTION ONE EIGHTH
A835 NORTH INDIC FRACTION THREE SIXTEENTHS
A836 NORTH INDIC QUARTER MARK
A837 NORTH INDIC PLACEHOLDER MARK
A838 NORTH INDIC RUPEE MARK
A839 NORTH INDIC QUANTITY MARK
A840 PHAGS-PA LETTER KA
A841 PHAGS-PA LETTER KHA
A842 PHAGS-PA LETTER GA
A843 PHAGS-PA LETTER NGA
A844 PHAGS-PA LETTER CA
A845 PHAGS-PA LETTER CHA
A846 PHAGS-PA LETTER JA
A847 PHAGS-PA LETTER NYA
A848 PHAGS-PA LETTER TA
A849 PHAGS-PA LETTER THA
A84A PHAGS-PA LETTER DA
A84B PHAGS-PA LETTER NA
A84C PHAGS-PA LETTER PA
A84D PHAGS-PA LETTER PHA
A84E PHAGS-PA LETTER BA
A84F PHAGS-PA LETTER MA
A850 PHAGS-PA LETTER TSA
A851 PHAGS-PA LETTER TSHA
A852 PHAGS-PA LETTER DZA
A853 PHAGS-PA LETTER WA
A854 PHAGS-PA LETTER ZHA
A855 PHAGS-PA LETTER ZA
A856 PHAGS-PA LETTER SMALL A
A857 PHAGS-PA LETTER YA
A858 PHAGS-PA LETTER RA
A859 PHAGS-PA LETTER LA
A85A PHAGS-PA LETTER SHA
A85B PHAGS-PA LETTER SA
A85C PHAGS-PA LETTER HA
A85D PHAGS-PA LETTER A
A85E PHAGS-PA LETTER I
A85F PHAGS-PA LETTER U
A860 PHAGS-PA LETTER E
A861 PHAGS-PA LETTER O
A862 PHAGS-PA LETTER QA
A863 PHAGS-PA LETTER XA
A864 PHAGS-PA LETTER FA
A865 PHAGS-PA LETTER GGA
A866 PHAGS-PA LETTER EE
A867 PHAGS-PA SUBJOINED LETTER WA
A868 PHAGS-PA SUBJOINED LETTER YA
A869 PHAGS-PA LETTER TTA
A86A PHAGS-PA LETTER TTHA
A86B PHAGS-PA LETTER DDA
A86C PHAGS-PA LETTER NNA
A86D PHAGS-PA LETTER ALTERNATE YA
A86E PHAGS-PA LETTER VOICELESS SHA
A86F PHAGS-PA LETTER VOICED HA
A870 PHAGS-PA LETTER ASPIRATED FA
A871 PHAGS-PA SUBJOINED LETTER RA
A872 PHAGS-PA SUPERFIXED LETTER RA
A873 PHAGS-PA LETTER CANDRABINDU
A874 PHAGS-PA SINGLE HEAD MARK
A875 PHAGS-PA DOUBLE HEAD MARK
A876 PHAGS-PA MARK SHAD
A877 PHAGS-PA MARK DOUBLE SHAD
A880 SAURASHTRA SIGN ANUSVARA
A881 SAURASHTRA SIGN VISARGA
A882 SAURASHTRA LETTER A
A883 SAURASHTRA LETTER AA
A884 SAURASHTRA LETTER I
A885 SAURASHTRA LETTER II
A886 SAURASHTRA LETTER U
A887 SAURASHTRA LETTER UU
A888 SAURASHTRA LETTER VOCALIC R
A889 SAURASHTRA LETTER VOCALIC RR
A88A SAURASHTRA LETTER VOCALIC L
A88B SAURASHTRA LETTER VOCALIC LL
A88C SAURASHTRA LETTER E
A88D SAURASHTRA LETTER EE
A88E SAURASHTRA LETTER AI
A88F SAURASHTRA LETTER O
A890 SAURASHTRA LETTER OO
A891 SAURASHTRA LETTER AU
A892 SAURASHTRA LETTER KA
A893 SAURASHTRA LETTER KHA
A894 SAURASHTRA LETTER GA
A895 SAURASHTRA LETTER GHA
A896 SAURASHTRA LETTER NGA
A897 SAURASHTRA LETTER CA
A898 SAURASHTRA LETTER CHA
A899 SAURASHTRA LETTER JA
A89A SAURASHTRA LETTER JHA
A89B SAURASHTRA LETTER NYA
A89C SAURASHTRA LETTER TTA
A89D SAURASHTRA LETTER TTHA
A89E SAURASHTRA LETTER DDA
A89F SAURASHTRA LETTER DDHA
A8A0 SAURASHTRA LETTER NNA
A8A1 SAURASHTRA LETTER TA
A8A2 SAURASHTRA LETTER THA
A8A3 SAURASHTRA LETTER DA
A8A4 SAURASHTRA LETTER DHA
A8A5 SAURASHTRA LETTER NA
A8A6 SAURASHTRA LETTER PA
A8A7 SAURASHTRA LETTER PHA
A8A8 SAURASHTRA LETTER BA
A8A9 SAURASHTRA LETTER BHA
A8AA SAURASHTRA LETTER MA
A8AB SAURASHTRA LETTER YA
A8AC SAURASHTRA LETTER RA
A8AD SAURASHTRA LETTER LA
A8AE SAURASHTRA LETTER VA
A8AF SAURASHTRA LETTER SHA
A8B0 SAURASHTRA LETTER SSA
A8B1 SAURASHTRA LETTER SA
A8B2 SAURASHTRA LETTER HA
A8B3 SAURASHTRA LETTER LLA
A8B4 SAURASHTRA CONSONANT SIGN HAARU
A8B5 SAURASHTRA VOWEL SIGN AA
A8B6 SAURASHTRA VOWEL SIGN I
A8B7 SAURASHTRA VOWEL SIGN II
A8B8 SAURASHTRA VOWEL SIGN U
A8B9 SAURASHTRA VOWEL SIGN UU
A8BA SAURASHTRA VOWEL SIGN VOCALIC R
A8BB SAURASHTRA VOWEL SIGN VOCALIC RR
A8BC SAURASHTRA VOWEL SIGN VOCALIC L
A8BD SAURASHTRA VOWEL SIGN VOCALIC LL
A8BE SAURASHTRA VOWEL SIGN E
A8BF SAURASHTRA VOWEL SIGN EE
A8C0 SAURASHTRA VOWEL SIGN AI
A8C1 SAURASHTRA VOWEL SIGN O
A8C2 SAURASHTRA VOWEL SIGN OO
A8C3 SAURASHTRA VOWEL SIGN AU
A8C4 SAURASHTRA SIGN VIRAMA
A8C5 SAURASHTRA SIGN CANDRABINDU
A8CE SAURASHTRA DANDA
A8CF SAURASHTRA DOUBLE DANDA
A8D0 SAURASHTRA DIGIT ZERO
A8D1 SAURASHTRA DIGIT ONE
A8D2 SAURASHTRA DIGIT TWO
A8D3 SAURASHTRA DIGIT THREE
A8D4 SAURASHTRA DIGIT FOUR
A8D5 SAURASHTRA DIGIT FIVE
A8D6 SAURASHTRA DIGIT SIX
A8D7 SAURASHTRA DIGIT SEVEN
A8D8 SAURASHTRA DIGIT EIGHT
A8D9 SAURASHTRA DIGIT NINE
A8E0 COMBINING DEVANAGARI DIGIT ZERO
A8E1 COMBINING DEVANAGARI DIGIT ONE
A8E2 COMBINING DEVANAGARI DIGIT TWO
A8E3 COMBINING DEVANAGARI DIGIT THREE
A8E4 COMBINING DEVANAGARI DIGIT FOUR
A8E5 COMBINING DEVANAGARI DIGIT FIVE
A8E6 COMBINING DEVANAGARI DIGIT SIX
A8E7 COMBINING DEVANAGARI DIGIT SEVEN
A8E8 COMBINING DEVANAGARI DIGIT EIGHT
A8E9 COMBINING DEVANAGARI DIGIT NINE
A8EA COMBINING DEVANAGARI LETTER A
A8EB COMBINING DEVANAGARI LETTER U
A8EC COMBINING DEVANAGARI LETTER KA
A8ED COMBINING DEVANAGARI LETTER NA
A8EE COMBINING DEVANAGARI LETTER PA
A8EF COMBINING DEVANAGARI LETTER RA
A8F0 COMBINING DEVANAGARI LETTER VI
A8F1 COMBINING DEVANAGARI SIGN AVAGRAHA
A8F2 DEVANAGARI SIGN SPACING CANDRABINDU
A8F3 DEVANAGARI SIGN CANDRABINDU VIRAMA
A8F4 DEVANAGARI SIGN DOUBLE CANDRABINDU VIRAMA
A8F5 DEVANAGARI SIGN CANDRABINDU TWO
A8F6 DEVANAGARI SIGN CANDRABINDU THREE
A8F7 DEVANAGARI SIGN CANDRABINDU AVAGRAHA
A8F8 DEVANAGARI SIGN PUSHPIKA
A8F9 DEVANAGARI GAP FILLER
A8FA DEVANAGARI CARET
A8FB DEVANAGARI HEADSTROKE
A8FC DEVANAGARI SIGN SIDDHAM
A8FD DEVANAGARI JAIN OM
A900 KAYAH LI DIGIT ZERO
A901 KAYAH LI DIGIT ONE
A902 KAYAH LI DIGIT TWO
A903 KAYAH LI DIGIT THREE
A904 KAYAH LI DIGIT FOUR
A905 KAYAH LI DIGIT FIVE
A906 KAYAH LI DIGIT SIX
A907 KAYAH LI DIGIT SEVEN
A908 KAYAH LI DIGIT EIGHT
A909 KAYAH LI DIGIT NINE
A90A KAYAH LI LETTER KA
A90B KAYAH LI LETTER KHA
A90C KAYAH LI LETTER GA
A90D KAYAH LI LETTER NGA
A90E KAYAH LI LETTER SA
A90F KAYAH LI LETTER SHA
A910 KAYAH LI LETTER ZA
A911 KAYAH LI LETTER NYA
A912 KAYAH LI LETTER TA
A913 KAYAH LI LETTER HTA
A914 KAYAH LI LETTER NA
A915 KAYAH LI LETTER PA
A916 KAYAH LI LETTER PHA
A917 KAYAH LI LETTER MA
A918 KAYAH LI LETTER DA
A919 KAYAH LI LETTER BA
A91A KAYAH LI LETTER RA
A91B KAYAH LI LETTER YA
A91C KAYAH LI LETTER LA
A91D KAYAH LI LETTER WA
A91E KAYAH LI LETTER THA
A91F KAYAH LI LETTER HA
A920 KAYAH LI LETTER VA
A921 KAYAH LI LETTER CA
A922 KAYAH LI LETTER A
A923 KAYAH LI LETTER OE
A924 KAYAH LI LETTER I
A925 KAYAH LI LETTER OO
A926 KAYAH LI VOWEL UE
A927 KAYAH LI VOWEL E
A928 KAYAH LI VOWEL U
A929 KAYAH LI VOWEL EE
A92A KAYAH LI VOWEL O
A92B KAYAH LI TONE PLOPHU
A92C KAYAH LI TONE CALYA
A92D KAYAH LI TONE CALYA PLOPHU
A92E KAYAH LI SIGN CWI
A92F KAYAH LI SIGN SHYA
A930 REJANG LETTER KA
A931 REJANG LETTER GA
A932 REJANG LETTER NGA
A933 REJANG LETTER TA
A934 REJANG LETTER DA
A935 REJANG LETTER NA
A936 REJANG LETTER PA
A937 REJANG LETTER BA
A938 REJANG LETTER MA
A939 REJANG LETTER CA
A93A REJANG LETTER JA
A93B REJANG LETTER NYA
A93C REJANG LETTER SA
A93D REJANG LETTER RA
A93E REJANG LETTER LA
A93F REJANG LETTER YA
A940 REJANG LETTER WA
A941 REJANG LETTER HA
A942 REJANG LETTER MBA
A943 REJANG LETTER NGGA
A944 REJANG LETTER NDA
A945 REJANG LETTER NYJA
A946 REJANG LETTER A
A947 REJANG VOWEL SIGN I
A948 REJANG VOWEL SIGN U
A949 REJANG VOWEL SIGN E
A94A REJANG VOWEL SIGN AI
A94B REJANG VOWEL SIGN O
A94C REJANG VOWEL SIGN AU
A94D REJANG VOWEL SIGN EU
A94E REJANG VOWEL SIGN EA
A94F REJANG CONSONANT SIGN NG
A950 REJANG CONSONANT SIGN N
A951 REJANG CONSONANT SIGN R
A952 REJANG CONSONANT SIGN H
A953 REJANG VIRAMA
A95F REJANG SECTION MARK
A960 HANGUL CHOSEONG TIKEUT-MIEUM
A961 HANGUL CHOSEONG TIKEUT-PIEUP
A962 HANGUL CHOSEONG TIKEUT-SIOS
A963 HANGUL CHOSEONG TIKEUT-CIEUC
A964 HANGUL CHOSEONG RIEUL-KIYEOK
A965 HANGUL CHOSEONG RIEUL-SSANGKIYEOK
A966 HANGUL CHOSEONG RIEUL-TIKEUT
A967 HANGUL CHOSEONG RIEUL-SSANGTIKEUT
A968 HANGUL CHOSEONG RIEUL-MIEUM
A969 HANGUL CHOSEONG RIEUL-PIEUP
A96A HANGUL CHOSEONG RIEUL-SSANGPIEUP
A96B HANGUL CHOSEONG RIEUL-KAPYEOUNPIEUP
A96C HANGUL CHOSEONG RIEUL-SIOS
A96D HANGUL CHOSEONG RIEUL-CIEUC
A96E HANGUL CHOSEONG RIEUL-KHIEUKH
A96F HANGUL CHOSEONG MIEUM-KIYEOK
A970 HANGUL CHOSEONG MIEUM-TIKEUT
A971 HANGUL CHOSEONG MIEUM-SIOS
A972 HANGUL CHOSEONG PIEUP-SIOS-THIEUTH
A973 HANGUL CHOSEONG PIEUP-KHIEUKH
A974 HANGUL CHOSEONG PIEUP-HIEUH
A975 HANGUL CHOSEONG SSANGSIOS-PIEUP
A976 HANGUL CHOSEONG IEUNG-RIEUL
A977 HANGUL CHOSEONG IEUNG-HIEUH
A978 HANGUL CHOSEONG SSANGCIEUC-HIEUH
A979 HANGUL CHOSEONG SSANGTHIEUTH
A97A HANGUL CHOSEONG PHIEUPH-HIEUH
A97B HANGUL CHOSEONG HIEUH-SIOS
A97C HANGUL CHOSEONG SSANGYEORINHIEUH
A980 JAVANESE SIGN PANYANGGA
A981 JAVANESE SIGN CECAK
A982 JAVANESE SIGN LAYAR
A983 JAVANESE SIGN WIGNYAN
A984 JAVANESE LETTER A
A985 JAVANESE LETTER I KAWI
A986 JAVANESE LETTER I
A987 JAVANESE LETTER II
A988 JAVANESE LETTER U
A989 JAVANESE LETTER PA CEREK
A98A JAVANESE LETTER NGA LELET
A98B JAVANESE LETTER NGA LELET RASWADI
A98C JAVANESE LETTER E
A98D JAVANESE LETTER AI
A98E JAVANESE LETTER O
A98F JAVANESE LETTER KA
A990 JAVANESE LETTER KA SASAK
A991 JAVANESE LETTER KA MURDA
A992 JAVANESE LETTER GA
A993 JAVANESE LETTER GA MURDA
A994 JAVANESE LETTER NGA
A995 JAVANESE LETTER CA
A996 JAVANESE LETTER CA MURDA
A997 JAVANESE LETTER JA
A998 JAVANESE LETTER NYA MURDA
A999 JAVANESE LETTER JA MAHAPRANA
A99A JAVANESE LETTER NYA
A99B JAVANESE LETTER TTA
A99C JAVANESE LETTER TTA MAHAPRANA
A99D JAVANESE LETTER DDA
A99E JAVANESE LETTER DDA MAHAPRANA
A99F JAVANESE LETTER NA MURDA
A9A0 JAVANESE LETTER TA
A9A1 JAVANESE LETTER TA MURDA
A9A2 JAVANESE LETTER DA
A9A3 JAVANESE LETTER DA MAHAPRANA
A9A4 JAVANESE LETTER NA
A9A5 JAVANESE LETTER PA
A9A6 JAVANESE LETTER PA MURDA
A9A7 JAVANESE LETTER BA
A9A8 JAVANESE LETTER BA MURDA
A9A9 JAVANESE LETTER MA
A9AA JAVANESE LETTER YA
A9AB JAVANESE LETTER RA
A9AC JAVANESE LETTER RA AGUNG
A9AD JAVANESE LETTER LA
A9AE JAVANESE LETTER WA
A9AF JAVANESE LETTER SA MURDA
A9B0 JAVANESE LETTER SA MAHAPRANA
A9B1 JAVANESE LETTER SA
A9B2 JAVANESE LETTER HA
A9B3 JAVANESE SIGN CECAK TELU
A9B4 JAVANESE VOWEL SIGN TARUNG
A9B5 JAVANESE VOWEL SIGN TOLONG
A9B6 JAVANESE VOWEL SIGN WULU
A9B7 JAVANESE VOWEL SIGN WULU MELIK
A9B8 JAVANESE VOWEL SIGN SUKU
A9B9 JAVANESE VOWEL SIGN SUKU MENDUT
A9BA JAVANESE VOWEL SIGN TALING
A9BB JAVANESE VOWEL SIGN DIRGA MURE
A9BC JAVANESE VOWEL SIGN PEPET
A9BD JAVANESE CONSONANT SIGN KERET
A9BE JAVANESE CONSONANT SIGN PENGKAL
A9BF JAVANESE CONSONANT SIGN CAKRA
A9C0 JAVANESE PANGKON
A9C1 JAVANESE LEFT RERENGGAN
A9C2 JAVANESE RIGHT RERENGGAN
A9C3 JAVANESE PADA ANDAP
A9C4 JAVANESE PADA MADYA
A9C5 JAVANESE PADA LUHUR
A9C6 JAVANESE PADA WINDU
A9C7 JAVANESE PADA PANGKAT
A9C8 JAVANESE PADA LINGSA
A9C9 JAVANESE PADA LUNGSI
A9CA JAVANESE PADA ADEG
A9CB JAVANESE PADA ADEG ADEG
A9CC JAVANESE PADA PISELEH
A9CD JAVANESE TURNED PADA PISELEH
A9CF JAVANESE PANGRANGKEP
A9D0 JAVANESE DIGIT ZERO
A9D1 JAVANESE DIGIT ONE
A9D2 JAVANESE DIGIT TWO
A9D3 JAVANESE DIGIT THREE
A9D4 JAVANESE DIGIT FOUR
A9D5 JAVANESE DIGIT FIVE
A9D6 JAVANESE DIGIT SIX
A9D7 JAVANESE DIGIT SEVEN
A9D8 JAVANESE DIGIT EIGHT
A9D9 JAVANESE DIGIT NINE
A9DE JAVANESE PADA TIRTA TUMETES
A9DF JAVANESE PADA ISEN-ISEN
A9E0 MYANMAR LETTER SHAN GHA
A9E1 MYANMAR LETTER SHAN CHA
A9E2 MYANMAR LETTER SHAN JHA
A9E3 MYANMAR LETTER SHAN NNA
A9E4 MYANMAR LETTER SHAN BHA
A9E5 MYANMAR SIGN SHAN SAW
A9E6 MYANMAR MODIFIER LETTER SHAN REDUPLICATION
A9E7 MYANMAR LETTER TAI LAING NYA
A9E8 MYANMAR LETTER TAI LAING FA
A9E9 MYANMAR LETTER TAI LAING GA
A9EA MYANMAR LETTER TAI LAING GHA
A9EB MYANMAR LETTER TAI LAING JA
A9EC MYANMAR LETTER TAI LAING JHA
A9ED MYANMAR LETTER TAI LAING DDA
A9EE MYANMAR LETTER TAI LAING DDHA
A9EF MYANMAR LETTER TAI LAING NNA
A9F0 MYANMAR TAI LAING DIGIT ZERO
A9F1 MYANMAR TAI LAING DIGIT ONE
A9F2 MYANMAR TAI LAING DIGIT TWO
A9F3 MYANMAR TAI LAING DIGIT THREE
A9F4 MYANMAR TAI LAING DIGIT FOUR
A9F5 MYANMAR TAI LAING DIGIT FIVE
A9F6 MYANMAR TAI LAING DIGIT SIX
A9F7 MYANMAR TAI LAING DIGIT SEVEN
A9F8 MYANMAR TAI LAING DIGIT EIGHT
A9F9 MYANMAR TAI LAING DIGIT NINE
A9FA MYANMAR LETTER TAI LAING LLA
A9FB MYANMAR LETTER TAI LAING DA
A9FC MYANMAR LETTER TAI LAING DHA
A9FD MYANMAR LETTER TAI LAING BA
A9FE MYANMAR LETTER TAI LAING BHA
AA00 CHAM LETTER A
AA01 CHAM LETTER I
AA02 CHAM LETTER U
AA03 CHAM LETTER E
AA04 CHAM LETTER AI
AA05 CHAM LETTER O
AA06 CHAM LETTER KA
AA07 CHAM LETTER KHA
AA08 CHAM LETTER GA
AA09 CHAM LETTER GHA
AA0A CHAM LETTER NGUE
AA0B CHAM LETTER NGA
AA0C CHAM LETTER CHA
AA0D CHAM LETTER CHHA
AA0E CHAM LETTER JA
AA0F CHAM LETTER JHA
AA10 CHAM LETTER NHUE
AA11 CHAM LETTER NHA
AA12 CHAM LETTER NHJA
AA13 CHAM LETTER TA
AA14 CHAM LETTER THA
AA15 CHAM LETTER DA
AA16 CHAM LETTER DHA
AA17 CHAM LETTER NUE
AA18 CHAM LETTER NA
AA19 CHAM LETTER DDA
AA1A CHAM LETTER PA
AA1B CHAM LETTER PPA
AA1C CHAM LETTER PHA
AA1D CHAM LETTER BA
AA1E CHAM LETTER BHA
AA1F CHAM LETTER MUE
AA20 CHAM LETTER MA
AA21 CHAM LETTER BBA
AA22 CHAM LETTER YA
AA23 CHAM LETTER RA
AA24 CHAM LETTER LA
AA25 CHAM LETTER VA
AA26 CHAM LETTER SSA
AA27 CHAM LETTER SA
AA28 CHAM LETTER HA
AA29 CHAM VOWEL SIGN AA
AA2A CHAM VOWEL SIGN I
AA2B CHAM VOWEL SIGN II
AA2C CHAM VOWEL SIGN EI
AA2D CHAM VOWEL SIGN U
AA2E CHAM VOWEL SIGN OE
AA2F CHAM VOWEL SIGN O
AA30 CHAM VOWEL SIGN AI
AA31 CHAM VOWEL SIGN AU
AA32 CHAM VOWEL SIGN UE
AA33 CHAM CONSONANT SIGN YA
AA34 CHAM CONSONANT SIGN RA
AA35 CHAM CONSONANT SIGN LA
AA36 CHAM CONSONANT SIGN WA
AA40 CHAM LETTER FINAL K
AA41 CHAM LETTER FINAL G
AA42 CHAM LETTER FINAL NG
AA43 CHAM CONSONANT SIGN FINAL NG
AA44 CHAM LETTER FINAL CH
AA45 CHAM LETTER FINAL T
AA46 CHAM LETTER FINAL N
AA47 CHAM LETTER FINAL P
AA48 CHAM LETTER FINAL Y
AA49 CHAM LETTER FINAL R
AA4A CHAM LETTER FINAL L
AA4B CHAM LETTER FINAL SS
AA4C CHAM CONSONANT SIGN FINAL M
AA4D CHAM CONSONANT SIGN FINAL H
AA50 CHAM DIGIT ZERO
AA51 CHAM DIGIT ONE
AA52 CHAM DIGIT TWO
AA53 CHAM DIGIT THREE
AA54 CHAM DIGIT FOUR
AA55 CHAM DIGIT FIVE
AA56 CHAM DIGIT SIX
AA57 CHAM DIGIT SEVEN
AA58 CHAM DIGIT EIGHT
AA59 CHAM DIGIT NINE
AA5C CHAM PUNCTUATION SPIRAL
AA5D CHAM PUNCTUATION DANDA
AA5E CHAM PUNCTUATION DOUBLE DANDA
AA5F CHAM PUNCTUATION TRIPLE DANDA
AA60 MYANMAR LETTER KHAMTI GA
AA61 MYANMAR LETTER KHAMTI CA
AA62 MYANMAR LETTER KHAMTI CHA
AA63 MYANMAR LETTER KHAMTI JA
AA64 MYANMAR LETTER KHAMTI JHA
AA65 MYANMAR LETTER KHAMTI NYA
AA66 MYANMAR LETTER KHAMTI TTA
AA67 MYANMAR LETTER KHAMTI TTHA
AA68 MYANMAR LETTER KHAMTI DDA
AA69 MYANMAR LETTER KHAMTI DDHA
AA6A MYANMAR LETTER KHAMTI DHA
AA6B MYANMAR LETTER KHAMTI NA
AA6C MYANMAR LETTER KHAMTI SA
AA6D MYANMAR LETTER KHAMTI HA
AA6E MYANMAR LETTER KHAMTI HHA
AA6F MYANMAR LETTER KHAMTI FA
AA70 MYANMAR MODIFIER LETTER KHAMTI REDUPLICATION
AA71 MYANMAR LETTER KHAMTI XA
AA72 MYANMAR LETTER KHAMTI ZA
AA73 MYANMAR LETTER KHAMTI RA
AA74 MYANMAR LOGOGRAM KHAMTI OAY
AA75 MYANMAR LOGOGRAM KHAMTI QN
AA76 MYANMAR LOGOGRAM KHAMTI HM
AA77 MYANMAR SYMBOL AITON EXCLAMATION
AA78 MYANMAR SYMBOL AITON ONE
AA79 MYANMAR SYMBOL AITON TWO
AA7A MYANMAR LETTER AITON RA
AA7B MYANMAR SIGN PAO KAREN TONE
AA7C MYANMAR SIGN TAI LAING TONE-2
AA7D MYANMAR SIGN TAI LAING TONE-5
AA7E MYANMAR LETTER SHWE PALAUNG CHA
AA7F MYANMAR LETTER SHWE PALAUNG SHA
AA80 TAI VIET LETTER LOW KO
AA81 TAI VIET LETTER HIGH KO
AA82 TAI VIET LETTER LOW KHO
AA83 TAI VIET LETTER HIGH KHO
AA84 TAI VIET LETTER LOW KHHO
AA85 TAI VIET LETTER HIGH KHHO
AA86 TAI VIET LETTER LOW GO
AA87 TAI VIET LETTER HIGH GO
AA88 TAI VIET LETTER LOW NGO
AA89 TAI VIET LETTER HIGH NGO
AA8A TAI VIET LETTER LOW CO
AA8B TAI VIET LETTER HIGH CO
AA8C TAI VIET LETTER LOW CHO
AA8D TAI VIET LETTER HIGH CHO
AA8E TAI VIET LETTER LOW SO
AA8F TAI VIET LETTER HIGH SO
AA90 TAI VIET LETTER LOW NYO
AA91 TAI VIET LETTER HIGH NYO
AA92 TAI VIET LETTER LOW DO
AA93 TAI VIET LETTER HIGH DO
AA94 TAI VIET LETTER LOW TO
AA95 TAI VIET LETTER HIGH TO
AA96 TAI VIET LETTER LOW THO
AA97 TAI VIET LETTER HIGH THO
AA98 TAI VIET LETTER LOW NO
AA99 TAI VIET LETTER HIGH NO
AA9A TAI VIET LETTER LOW BO
AA9B TAI VIET LETTER HIGH BO
AA9C TAI VIET LETTER LOW PO
AA9D TAI VIET LETTER HIGH PO
AA9E TAI VIET LETTER LOW PHO
AA9F TAI VIET LETTER HIGH PHO
AAA0 TAI VIET LETTER LOW FO
AAA1 TAI VIET LETTER HIGH FO
AAA2 TAI VIET LETTER LOW MO
AAA3 TAI VIET LETTER HIGH MO
AAA4 TAI VIET LETTER LOW YO
AAA5 TAI VIET LETTER HIGH YO
AAA6 TAI VIET LETTER LOW RO
AAA7 TAI VIET LETTER HIGH RO
AAA8 TAI VIET LETTER LOW LO
AAA9 TAI VIET LETTER HIGH LO
AAAA TAI VIET LETTER LOW VO
AAAB TAI VIET LETTER HIGH VO
AAAC TAI VIET LETTER LOW HO
AAAD TAI VIET LETTER HIGH HO
AAAE TAI VIET LETTER LOW O
AAAF TAI VIET LETTER HIGH O
AAB0 TAI VIET MAI KANG
AAB1 TAI VIET VOWEL AA
AAB2 TAI VIET VOWEL I
AAB3 TAI VIET VOWEL UE
AAB4 TAI VIET VOWEL U
AAB5 TAI VIET VOWEL E
AAB6 TAI VIET VOWEL O
AAB7 TAI VIET MAI KHIT
AAB8 TAI VIET VOWEL IA
AAB9 TAI VIET VOWEL UEA
AABA TAI VIET VOWEL UA
AABB TAI VIET VOWEL AUE
AABC TAI VIET VOWEL AY
AABD TAI VIET VOWEL AN
AABE TAI VIET VOWEL AM
AABF TAI VIET TONE MAI EK
AAC0 TAI VIET TONE MAI NUENG
AAC1 TAI VIET TONE MAI THO
AAC2 TAI VIET TONE MAI SONG
AADB TAI VIET SYMBOL KON
AADC TAI VIET SYMBOL NUENG
AADD TAI VIET SYMBOL SAM
AADE TAI VIET SYMBOL HO HOI
AADF TAI VIET SYMBOL KOI KOI
AAE0 MEETEI MAYEK LETTER E
AAE1 MEETEI MAYEK LETTER O
AAE2 MEETEI MAYEK LETTER CHA
AAE3 MEETEI MAYEK LETTER NYA
AAE4 MEETEI MAYEK LETTER TTA
AAE5 MEETEI MAYEK LETTER TTHA
AAE6 MEETEI MAYEK LETTER DDA
AAE7 MEETEI MAYEK LETTER DDHA
AAE8 MEETEI MAYEK LETTER NNA
AAE9 MEETEI MAYEK LETTER SHA
AAEA MEETEI MAYEK LETTER SSA
AAEB MEETEI MAYEK VOWEL SIGN II
AAEC MEETEI MAYEK VOWEL SIGN UU
AAED MEETEI MAYEK VOWEL SIGN AAI
AAEE MEETEI MAYEK VOWEL SIGN AU
AAEF MEETEI MAYEK VOWEL SIGN AAU
AAF0 MEETEI MAYEK CHEIKHAN
AAF1 MEETEI MAYEK AHANG KHUDAM
AAF2 MEETEI MAYEK ANJI
AAF3 MEETEI MAYEK SYLLABLE REPETITION MARK
AAF4 MEETEI MAYEK WORD REPETITION MARK
AAF5 MEETEI MAYEK VOWEL SIGN VISARGA
AAF6 MEETEI MAYEK VIRAMA
AB01 ETHIOPIC SYLLABLE TTHU
AB02 ETHIOPIC SYLLABLE TTHI
AB03 ETHIOPIC SYLLABLE TTHAA
AB04 ETHIOPIC SYLLABLE TTHEE
AB05 ETHIOPIC SYLLABLE TTHE
AB06 ETHIOPIC SYLLABLE TTHO
AB09 ETHIOPIC SYLLABLE DDHU
AB0A ETHIOPIC SYLLABLE DDHI
AB0B ETHIOPIC SYLLABLE DDHAA
AB0C ETHIOPIC SYLLABLE DDHEE
AB0D ETHIOPIC SYLLABLE DDHE
AB0E ETHIOPIC SYLLABLE DDHO
AB11 ETHIOPIC SYLLABLE DZU
AB12 ETHIOPIC SYLLABLE DZI
AB13 ETHIOPIC SYLLABLE DZAA
AB14 ETHIOPIC SYLLABLE DZEE
AB15 ETHIOPIC SYLLABLE DZE
AB16 ETHIOPIC SYLLABLE DZO
AB20 ETHIOPIC SYLLABLE CCHHA
AB21 ETHIOPIC SYLLABLE CCHHU
AB22 ETHIOPIC SYLLABLE CCHHI
AB23 ETHIOPIC SYLLABLE CCHHAA
AB24 ETHIOPIC SYLLABLE CCHHEE
AB25 ETHIOPIC SYLLABLE CCHHE
AB26 ETHIOPIC SYLLABLE CCHHO
AB28 ETHIOPIC SYLLABLE BBA
AB29 ETHIOPIC SYLLABLE BBU
AB2A ETHIOPIC SYLLABLE BBI
AB2B ETHIOPIC SYLLABLE BBAA
AB2C ETHIOPIC SYLLABLE BBEE
AB2D ETHIOPIC SYLLABLE BBE
AB2E ETHIOPIC SYLLABLE BBO
AB30 LATIN SMALL LETTER BARRED ALPHA
AB31 LATIN SMALL LETTER A REVERSED-SCHWA
AB32 LATIN SMALL LETTER BLACKLETTER E
AB33 LATIN SMALL LETTER BARRED E
AB34 LATIN SMALL LETTER E WITH FLOURISH
AB35 LATIN SMALL LETTER LENIS F
AB36 LATIN SMALL LETTER SCRIPT G WITH CROSSED-TAIL
AB37 LATIN SMALL LETTER L WITH INVERTED LAZY S
AB38 LATIN SMALL LETTER L WITH DOUBLE MIDDLE TILDE
AB39 LATIN SMALL LETTER L WITH MIDDLE RING
AB3A LATIN SMALL LETTER M WITH CROSSED-TAIL
AB3B LATIN SMALL LETTER N WITH CROSSED-TAIL
AB3C LATIN SMALL LETTER ENG WITH CROSSED-TAIL
AB3D LATIN SMALL LETTER BLACKLETTER O
AB3E LATIN SMALL LETTER BLACKLETTER O WITH STROKE
AB3F LATIN SMALL LETTER OPEN O WITH STROKE
AB40 LATIN SMALL LETTER INVERTED OE
AB41 LATIN SMALL LETTER TURNED OE WITH STROKE
AB42 LATIN SMALL LETTER TURNED OE WITH HORIZONTAL STROKE
AB43 LATIN SMALL LETTER TURNED O OPEN-O
AB44 LATIN SMALL LETTER TURNED O OPEN-O WITH STROKE
AB45 LATIN SMALL LETTER STIRRUP R
AB46 LATIN LETTER SMALL CAPITAL R WITH RIGHT LEG
AB47 LATIN SMALL LETTER R WITHOUT HANDLE
AB48 LATIN SMALL LETTER DOUBLE R
AB49 LATIN SMALL LETTER R WITH CROSSED-TAIL
AB4A LATIN SMALL LETTER DOUBLE R WITH CROSSED-TAIL
AB4B LATIN SMALL LETTER SCRIPT R
AB4C LATIN SMALL LETTER SCRIPT R WITH RING
AB4D LATIN SMALL LETTER BASELINE ESH
AB4E LATIN SMALL LETTER U WITH SHORT RIGHT LEG
AB4F LATIN SMALL LETTER U BAR WITH SHORT RIGHT LEG
AB50 LATIN SMALL LETTER UI
AB51 LATIN SMALL LETTER TURNED UI
AB52 LATIN SMALL LETTER U WITH LEFT HOOK
AB53 LATIN SMALL LETTER CHI
AB54 LATIN SMALL LETTER CHI WITH LOW RIGHT RING
AB55 LATIN SMALL LETTER CHI WITH LOW LEFT SERIF
AB56 LATIN SMALL LETTER X WITH LOW RIGHT RING
AB57 LATIN SMALL LETTER X WITH LONG LEFT LEG
AB58 LATIN SMALL LETTER X WITH LONG LEFT LEG AND LOW RIGHT RING
AB59 LATIN SMALL LETTER X WITH LONG LEFT LEG WITH SERIF
AB5A LATIN SMALL LETTER Y WITH SHORT RIGHT LEG
AB5B MODIFIER BREVE WITH INVERTED BREVE
AB5C MODIFIER LETTER SMALL HENG
AB5D MODIFIER LETTER SMALL L WITH INVERTED LAZY S
AB5E MODIFIER LETTER SMALL L WITH MIDDLE TILDE
AB5F MODIFIER LETTER SMALL U WITH LEFT HOOK
AB60 LATIN SMALL LETTER SAKHA YAT
AB61 LATIN SMALL LETTER IOTIFIED E
AB62 LATIN SMALL LETTER OPEN OE
AB63 LATIN SMALL LETTER UO
AB64 LATIN SMALL LETTER INVERTED ALPHA
AB65 GREEK LETTER SMALL CAPITAL OMEGA
AB70 CHEROKEE SMALL LETTER A
AB71 CHEROKEE SMALL LETTER E
AB72 CHEROKEE SMALL LETTER I
AB73 CHEROKEE SMALL LETTER O
AB74 CHEROKEE SMALL LETTER U
AB75 CHEROKEE SMALL LETTER V
AB76 CHEROKEE SMALL LETTER GA
AB77 CHEROKEE SMALL LETTER KA
AB78 CHEROKEE SMALL LETTER GE
AB79 CHEROKEE SMALL LETTER GI
AB7A CHEROKEE SMALL LETTER GO
AB7B CHEROKEE SMALL LETTER GU
AB7C CHEROKEE SMALL LETTER GV
AB7D CHEROKEE SMALL LETTER HA
AB7E CHEROKEE SMALL LETTER HE
AB7F CHEROKEE SMALL LETTER HI
AB80 CHEROKEE SMALL LETTER HO
AB81 CHEROKEE SMALL LETTER HU
AB82 CHEROKEE SMALL LETTER HV
AB83 CHEROKEE SMALL LETTER LA
AB84 CHEROKEE SMALL LETTER LE
AB85 CHEROKEE SMALL LETTER LI
AB86 CHEROKEE SMALL LETTER LO
AB87 CHEROKEE SMALL LETTER LU
AB88 CHEROKEE SMALL LETTER LV
AB89 CHEROKEE SMALL LETTER MA
AB8A CHEROKEE SMALL LETTER ME
AB8B CHEROKEE SMALL LETTER MI
AB8C CHEROKEE SMALL LETTER MO
AB8D CHEROKEE SMALL LETTER MU
AB8E CHEROKEE SMALL LETTER NA
AB8F CHEROKEE SMALL LETTER HNA
AB90 CHEROKEE SMALL LETTER NAH
AB91 CHEROKEE SMALL LETTER NE
AB92 CHEROKEE SMALL LETTER NI
AB93 CHEROKEE SMALL LETTER NO
AB94 CHEROKEE SMALL LETTER NU
AB95 CHEROKEE SMALL LETTER NV
AB96 CHEROKEE SMALL LETTER QUA
AB97 CHEROKEE SMALL LETTER QUE
AB98 CHEROKEE SMALL LETTER QUI
AB99 CHEROKEE SMALL LETTER QUO
AB9A CHEROKEE SMALL LETTER QUU
AB9B CHEROKEE SMALL LETTER QUV
AB9C CHEROKEE SMALL LETTER SA
AB9D CHEROKEE SMALL LETTER S
AB9E CHEROKEE SMALL LETTER SE
AB9F CHEROKEE SMALL LETTER SI
ABA0 CHEROKEE SMALL LETTER SO
ABA1 CHEROKEE SMALL LETTER SU
ABA2 CHEROKEE SMALL LETTER SV
ABA3 CHEROKEE SMALL LETTER DA
ABA4 CHEROKEE SMALL LETTER TA
ABA5 CHEROKEE SMALL LETTER DE
ABA6 CHEROKEE SMALL LETTER TE
ABA7 CHEROKEE SMALL LETTER DI
ABA8 CHEROKEE SMALL LETTER TI
ABA9 CHEROKEE SMALL LETTER DO
ABAA CHEROKEE SMALL LETTER DU
ABAB CHEROKEE SMALL LETTER DV
ABAC CHEROKEE SMALL LETTER DLA
ABAD CHEROKEE SMALL LETTER TLA
ABAE CHEROKEE SMALL LETTER TLE
ABAF CHEROKEE SMALL LETTER TLI
ABB0 CHEROKEE SMALL LETTER TLO
ABB1 CHEROKEE SMALL LETTER TLU
ABB2 CHEROKEE SMALL LETTER TLV
ABB3 CHEROKEE SMALL LETTER TSA
ABB4 CHEROKEE SMALL LETTER TSE
ABB5 CHEROKEE SMALL LETTER TSI
ABB6 CHEROKEE SMALL LETTER TSO
ABB7 CHEROKEE SMALL LETTER TSU
ABB8 CHEROKEE SMALL LETTER TSV
ABB9 CHEROKEE SMALL LETTER WA
ABBA CHEROKEE SMALL LETTER WE
ABBB CHEROKEE SMALL LETTER WI
ABBC CHEROKEE SMALL LETTER WO
ABBD CHEROKEE SMALL LETTER WU
ABBE CHEROKEE SMALL LETTER WV
ABBF CHEROKEE SMALL LETTER YA
ABC0 MEETEI MAYEK LETTER KOK
ABC1 MEETEI MAYEK LETTER SAM
ABC2 MEETEI MAYEK LETTER LAI
ABC3 MEETEI MAYEK LETTER MIT
ABC4 MEETEI MAYEK LETTER PA
ABC5 MEETEI MAYEK LETTER NA
ABC6 MEETEI MAYEK LETTER CHIL
ABC7 MEETEI MAYEK LETTER TIL
ABC8 MEETEI MAYEK LETTER KHOU
ABC9 MEETEI MAYEK LETTER NGOU
ABCA MEETEI MAYEK LETTER THOU
ABCB MEETEI MAYEK LETTER WAI
ABCC MEETEI MAYEK LETTER YANG
ABCD MEETEI MAYEK LETTER HUK
ABCE MEETEI MAYEK LETTER UN
ABCF MEETEI MAYEK LETTER I
ABD0 MEETEI MAYEK LETTER PHAM
ABD1 MEETEI MAYEK LETTER ATIYA
ABD2 MEETEI MAYEK LETTER GOK
ABD3 MEETEI MAYEK LETTER JHAM
ABD4 MEETEI MAYEK LETTER RAI
ABD5 MEETEI MAYEK LETTER BA
ABD6 MEETEI MAYEK LETTER JIL
ABD7 MEETEI MAYEK LETTER DIL
ABD8 MEETEI MAYEK LETTER GHOU
ABD9 MEETEI MAYEK LETTER DHOU
ABDA MEETEI MAYEK LETTER BHAM
ABDB MEETEI MAYEK LETTER KOK LONSUM
ABDC MEETEI MAYEK LETTER LAI LONSUM
ABDD MEETEI MAYEK LETTER MIT LONSUM
ABDE MEETEI MAYEK LETTER PA LONSUM
ABDF MEETEI MAYEK LETTER NA LONSUM
ABE0 MEETEI MAYEK LETTER TIL LONSUM
ABE1 MEETEI MAYEK LETTER NGOU LONSUM
ABE2 MEETEI MAYEK LETTER I LONSUM
ABE3 MEETEI MAYEK VOWEL SIGN ONAP
ABE4 MEETEI MAYEK VOWEL SIGN INAP
ABE5 MEETEI MAYEK VOWEL SIGN ANAP
ABE6 MEETEI MAYEK VOWEL SIGN YENAP
ABE7 MEETEI MAYEK VOWEL SIGN SOUNAP
ABE8 MEETEI MAYEK VOWEL SIGN UNAP
ABE9 MEETEI MAYEK VOWEL SIGN CHEINAP
ABEA MEETEI MAYEK VOWEL SIGN NUNG
ABEB MEETEI MAYEK CHEIKHEI
ABEC MEETEI MAYEK LUM IYEK
ABED MEETEI MAYEK APUN IYEK
ABF0 MEETEI MAYEK DIGIT ZERO
ABF1 MEETEI MAYEK DIGIT ONE
ABF2 MEETEI MAYEK DIGIT TWO
ABF3 MEETEI MAYEK DIGIT THREE
ABF4 MEETEI MAYEK DIGIT FOUR
ABF5 MEETEI MAYEK DIGIT FIVE
ABF6 MEETEI MAYEK DIGIT SIX
ABF7 MEETEI MAYEK DIGIT SEVEN
ABF8 MEETEI MAYEK DIGIT EIGHT
ABF9 MEETEI MAYEK DIGIT NINE
AC00 HANGUL SYLLABLE GA
AC01 HANGUL SYLLABLE GAG
AC02 HANGUL SYLLABLE GAGG
AC03 HANGUL SYLLABLE GAGS
AC04 HANGUL SYLLABLE GAN
AC05 HANGUL SYLLABLE GANJ
AC06 HANGUL SYLLABLE GANH
AC07 HANGUL SYLLABLE GAD
AC08 HANGUL SYLLABLE GAL
AC09 HANGUL SYLLABLE GALG
AC0A HANGUL SYLLABLE GALM
AC0B HANGUL SYLLABLE GALB
AC0C HANGUL SYLLABLE GALS
AC0D HANGUL SYLLABLE GALT
AC0E HANGUL SYLLABLE GALP
AC0F HANGUL SYLLABLE GALH
AC10 HANGUL SYLLABLE GAM
AC11 HANGUL SYLLABLE GAB
AC12 HANGUL SYLLABLE GABS
AC13 HANGUL SYLLABLE GAS
AC14 HANGUL SYLLABLE GASS
AC15 HANGUL SYLLABLE GANG
AC16 HANGUL SYLLABLE GAJ
AC17 HANGUL SYLLABLE GAC
AC18 HANGUL SYLLABLE GAK
AC19 HANGUL SYLLABLE GAT
AC1A HANGUL SYLLABLE GAP
AC1B HANGUL SYLLABLE GAH
AC1C HANGUL SYLLABLE GAE
AC1D HANGUL SYLLABLE GAEG
AC1E HANGUL SYLLABLE GAEGG
AC1F HANGUL SYLLABLE GAEGS
AC20 HANGUL SYLLABLE GAEN
AC21 HANGUL SYLLABLE GAENJ
AC22 HANGUL SYLLABLE GAENH
AC23 HANGUL SYLLABLE GAED
AC24 HANGUL SYLLABLE GAEL
AC25 HANGUL SYLLABLE GAELG
AC26 HANGUL SYLLABLE GAELM
AC27 HANGUL SYLLABLE GAELB
AC28 HANGUL SYLLABLE GAELS
AC29 HANGUL SYLLABLE GAELT
AC2A HANGUL SYLLABLE GAELP
AC2B HANGUL SYLLABLE GAELH
AC2C HANGUL SYLLABLE GAEM
AC2D HANGUL SYLLABLE GAEB
AC2E HANGUL SYLLABLE GAEBS
AC2F HANGUL SYLLABLE GAES
AC30 HANGUL SYLLABLE GAESS
AC31 HANGUL SYLLABLE GAENG
AC32 HANGUL SYLLABLE GAEJ
AC33 HANGUL SYLLABLE GAEC
AC34 HANGUL SYLLABLE GAEK
AC35 HANGUL SYLLABLE GAET
AC36 HANGUL SYLLABLE GAEP
AC37 HANGUL SYLLABLE GAEH
AC38 HANGUL SYLLABLE GYA
AC39 HANGUL SYLLABLE GYAG
AC3A HANGUL SYLLABLE GYAGG
AC3B HANGUL SYLLABLE GYAGS
AC3C HANGUL SYLLABLE GYAN
AC3D HANGUL SYLLABLE GYANJ
AC3E HANGUL SYLLABLE GYANH
AC3F HANGUL SYLLABLE GYAD
AC40 HANGUL SYLLABLE GYAL
AC41 HANGUL SYLLABLE GYALG
AC42 HANGUL SYLLABLE GYALM
AC43 HANGUL SYLLABLE GYALB
AC44 HANGUL SYLLABLE GYALS
AC45 HANGUL SYLLABLE GYALT
AC46 HANGUL SYLLABLE GYALP
AC47 HANGUL SYLLABLE GYALH
AC48 HANGUL SYLLABLE GYAM
AC49 HANGUL SYLLABLE GYAB
AC4A HANGUL SYLLABLE GYABS
AC4B HANGUL SYLLABLE GYAS
AC4C HANGUL SYLLABLE GYASS
AC4D HANGUL SYLLABLE GYANG
AC4E HANGUL SYLLABLE GYAJ
AC4F HANGUL SYLLABLE GYAC
AC50 HANGUL SYLLABLE GYAK
AC51 HANGUL SYLLABLE GYAT
AC52 HANGUL SYLLABLE GYAP
AC53 HANGUL SYLLABLE GYAH
AC54 HANGUL SYLLABLE GYAE
AC55 HANGUL SYLLABLE GYAEG
AC56 HANGUL SYLLABLE GYAEGG
AC57 HANGUL SYLLABLE GYAEGS
AC58 HANGUL SYLLABLE GYAEN
AC59 HANGUL SYLLABLE GYAENJ
AC5A HANGUL SYLLABLE GYAENH
AC5B HANGUL SYLLABLE GYAED
AC5C HANGUL SYLLABLE GYAEL
AC5D HANGUL SYLLABLE GYAELG
AC5E HANGUL SYLLABLE GYAELM
AC5F HANGUL SYLLABLE GYAELB
AC60 HANGUL SYLLABLE GYAELS
AC61 HANGUL SYLLABLE GYAELT
AC62 HANGUL SYLLABLE GYAELP
AC63 HANGUL SYLLABLE GYAELH
AC64 HANGUL SYLLABLE GYAEM
AC65 HANGUL SYLLABLE GYAEB
AC66 HANGUL SYLLABLE GYAEBS
AC67 HANGUL SYLLABLE GYAES
AC68 HANGUL SYLLABLE GYAESS
AC69 HANGUL SYLLABLE GYAENG
AC6A HANGUL SYLLABLE GYAEJ
AC6B HANGUL SYLLABLE GYAEC
AC6C HANGUL SYLLABLE GYAEK
AC6D HANGUL SYLLABLE GYAET
AC6E HANGUL SYLLABLE GYAEP
AC6F HANGUL SYLLABLE GYAEH
AC70 HANGUL SYLLABLE GEO
AC71 HANGUL SYLLABLE GEOG
AC72 HANGUL SYLLABLE GEOGG
AC73 HANGUL SYLLABLE GEOGS
AC74 HANGUL SYLLABLE GEON
AC75 HANGUL SYLLABLE GEONJ
AC76 HANGUL SYLLABLE GEONH
AC77 HANGUL SYLLABLE GEOD
AC78 HANGUL SYLLABLE GEOL
AC79 HANGUL SYLLABLE GEOLG
AC7A HANGUL SYLLABLE GEOLM
AC7B HANGUL SYLLABLE GEOLB
AC7C HANGUL SYLLABLE GEOLS
AC7D HANGUL SYLLABLE GEOLT
AC7E HANGUL SYLLABLE GEOLP
AC7F HANGUL SYLLABLE GEOLH
AC80 HANGUL SYLLABLE GEOM
AC81 HANGUL SYLLABLE GEOB
AC82 HANGUL SYLLABLE GEOBS
AC83 HANGUL SYLLABLE GEOS
AC84 HANGUL SYLLABLE GEOSS
AC85 HANGUL SYLLABLE GEONG
AC86 HANGUL SYLLABLE GEOJ
AC87 HANGUL SYLLABLE GEOC
AC88 HANGUL SYLLABLE GEOK
AC89 HANGUL SYLLABLE GEOT
AC8A HANGUL SYLLABLE GEOP
AC8B HANGUL SYLLABLE GEOH
AC8C HANGUL SYLLABLE GE
AC8D HANGUL SYLLABLE GEG
AC8E HANGUL SYLLABLE GEGG
AC8F HANGUL SYLLABLE GEGS
AC90 HANGUL SYLLABLE GEN
AC91 HANGUL SYLLABLE GENJ
AC92 HANGUL SYLLABLE GENH
AC93 HANGUL SYLLABLE GED
AC94 HANGUL SYLLABLE GEL
AC95 HANGUL SYLLABLE GELG
AC96 HANGUL SYLLABLE GELM
AC97 HANGUL SYLLABLE GELB
AC98 HANGUL SYLLABLE GELS
AC99 HANGUL SYLLABLE GELT
AC9A HANGUL SYLLABLE GELP
AC9B HANGUL SYLLABLE GELH
AC9C HANGUL SYLLABLE GEM
AC9D HANGUL SYLLABLE GEB
AC9E HANGUL SYLLABLE GEBS
AC9F HANGUL SYLLABLE GES
ACA0 HANGUL SYLLABLE GESS
ACA1 HANGUL SYLLABLE GENG
ACA2 HANGUL SYLLABLE GEJ
ACA3 HANGUL SYLLABLE GEC
ACA4 HANGUL SYLLABLE GEK
ACA5 HANGUL SYLLABLE GET
ACA6 HANGUL SYLLABLE GEP
ACA7 HANGUL SYLLABLE GEH
ACA8 HANGUL SYLLABLE GYEO
ACA9 HANGUL SYLLABLE GYEOG
ACAA HANGUL SYLLABLE GYEOGG
ACAB HANGUL SYLLABLE GYEOGS
ACAC HANGUL SYLLABLE GYEON
ACAD HANGUL SYLLABLE GYEONJ
ACAE HANGUL SYLLABLE GYEONH
ACAF HANGUL SYLLABLE GYEOD
ACB0 HANGUL SYLLABLE GYEOL
ACB1 HANGUL SYLLABLE GYEOLG
ACB2 HANGUL SYLLABLE GYEOLM
ACB3 HANGUL SYLLABLE GYEOLB
ACB4 HANGUL SYLLABLE GYEOLS
ACB5 HANGUL SYLLABLE GYEOLT
ACB6 HANGUL SYLLABLE GYEOLP
ACB7 HANGUL SYLLABLE GYEOLH
ACB8 HANGUL SYLLABLE GYEOM
ACB9 HANGUL SYLLABLE GYEOB
ACBA HANGUL SYLLABLE GYEOBS
ACBB HANGUL SYLLABLE GYEOS
ACBC HANGUL SYLLABLE GYEOSS
ACBD HANGUL SYLLABLE GYEONG
ACBE HANGUL SYLLABLE GYEOJ
ACBF HANGUL SYLLABLE GYEOC
ACC0 HANGUL SYLLABLE GYEOK
ACC1 HANGUL SYLLABLE GYEOT
ACC2 HANGUL SYLLABLE GYEOP
ACC3 HANGUL SYLLABLE GYEOH
ACC4 HANGUL SYLLABLE GYE
ACC5 HANGUL SYLLABLE GYEG
ACC6 HANGUL SYLLABLE GYEGG
ACC7 HANGUL SYLLABLE GYEGS
ACC8 HANGUL SYLLABLE GYEN
ACC9 HANGUL SYLLABLE GYENJ
ACCA HANGUL SYLLABLE GYENH
ACCB HANGUL SYLLABLE GYED
ACCC HANGUL SYLLABLE GYEL
ACCD HANGUL SYLLABLE GYELG
ACCE HANGUL SYLLABLE GYELM
ACCF HANGUL SYLLABLE GYELB
ACD0 HANGUL SYLLABLE GYELS
ACD1 HANGUL SYLLABLE GYELT
ACD2 HANGUL SYLLABLE GYELP
ACD3 HANGUL SYLLABLE GYELH
ACD4 HANGUL SYLLABLE GYEM
ACD5 HANGUL SYLLABLE GYEB
ACD6 HANGUL SYLLABLE GYEBS
ACD7 HANGUL SYLLABLE GYES
ACD8 HANGUL SYLLABLE GYESS
ACD9 HANGUL SYLLABLE GYENG
ACDA HANGUL SYLLABLE GYEJ
ACDB HANGUL SYLLABLE GYEC
ACDC HANGUL SYLLABLE GYEK
ACDD HANGUL SYLLABLE GYET
ACDE HANGUL SYLLABLE GYEP
ACDF HANGUL SYLLABLE GYEH
ACE0 HANGUL SYLLABLE GO
ACE1 HANGUL SYLLABLE GOG
ACE2 HANGUL SYLLABLE GOGG
ACE3 HANGUL SYLLABLE GOGS
ACE4 HANGUL SYLLABLE GON
ACE5 HANGUL SYLLABLE GONJ
ACE6 HANGUL SYLLABLE GONH
ACE7 HANGUL SYLLABLE GOD
ACE8 HANGUL SYLLABLE GOL
ACE9 HANGUL SYLLABLE GOLG
ACEA HANGUL SYLLABLE GOLM
ACEB HANGUL SYLLABLE GOLB
ACEC HANGUL SYLLABLE GOLS
ACED HANGUL SYLLABLE GOLT
ACEE HANGUL SYLLABLE GOLP
ACEF HANGUL SYLLABLE GOLH
ACF0 HANGUL SYLLABLE GOM
ACF1 HANGUL SYLLABLE GOB
ACF2 HANGUL SYLLABLE GOBS
ACF3 HANGUL SYLLABLE GOS
ACF4 HANGUL SYLLABLE GOSS
ACF5 HANGUL SYLLABLE GONG
ACF6 HANGUL SYLLABLE GOJ
ACF7 HANGUL SYLLABLE GOC
ACF8 HANGUL SYLLABLE GOK
ACF9 HANGUL SYLLABLE GOT
ACFA HANGUL SYLLABLE GOP
ACFB HANGUL SYLLABLE GOH
ACFC HANGUL SYLLABLE GWA
ACFD HANGUL SYLLABLE GWAG
ACFE HANGUL SYLLABLE GWAGG
ACFF HANGUL SYLLABLE GWAGS
AD00 HANGUL SYLLABLE GWAN
AD01 HANGUL SYLLABLE GWANJ
AD02 HANGUL SYLLABLE GWANH
AD03 HANGUL SYLLABLE GWAD
AD04 HANGUL SYLLABLE GWAL
AD05 HANGUL SYLLABLE GWALG
AD06 HANGUL SYLLABLE GWALM
AD07 HANGUL SYLLABLE GWALB
AD08 HANGUL SYLLABLE GWALS
AD09 HANGUL SYLLABLE GWALT
AD0A HANGUL SYLLABLE GWALP
AD0B HANGUL SYLLABLE GWALH
AD0C HANGUL SYLLABLE GWAM
AD0D HANGUL SYLLABLE GWAB
AD0E HANGUL SYLLABLE GWABS
AD0F HANGUL SYLLABLE GWAS
AD10 HANGUL SYLLABLE GWASS
AD11 HANGUL SYLLABLE GWANG
AD12 HANGUL SYLLABLE GWAJ
AD13 HANGUL SYLLABLE GWAC
AD14 HANGUL SYLLABLE GWAK
AD15 HANGUL SYLLABLE GWAT
AD16 HANGUL SYLLABLE GWAP
AD17 HANGUL SYLLABLE GWAH
AD18 HANGUL SYLLABLE GWAE
AD19 HANGUL SYLLABLE GWAEG
AD1A HANGUL SYLLABLE GWAEGG
AD1B HANGUL SYLLABLE GWAEGS
AD1C HANGUL SYLLABLE GWAEN
AD1D HANGUL SYLLABLE GWAENJ
AD1E HANGUL SYLLABLE GWAENH
AD1F HANGUL SYLLABLE GWAED
AD20 HANGUL SYLLABLE GWAEL
AD21 HANGUL SYLLABLE GWAELG
AD22 HANGUL SYLLABLE GWAELM
AD23 HANGUL SYLLABLE GWAELB
AD24 HANGUL SYLLABLE GWAELS
AD25 HANGUL SYLLABLE GWAELT
AD26 HANGUL SYLLABLE GWAELP
AD27 HANGUL SYLLABLE GWAELH
AD28 HANGUL SYLLABLE GWAEM
AD29 HANGUL SYLLABLE GWAEB
AD2A HANGUL SYLLABLE GWAEBS
AD2B HANGUL SYLLABLE GWAES
AD2C HANGUL SYLLABLE GWAESS
AD2D HANGUL SYLLABLE GWAENG
AD2E HANGUL SYLLABLE GWAEJ
AD2F HANGUL SYLLABLE GWAEC
AD30 HANGUL SYLLABLE GWAEK
AD31 HANGUL SYLLABLE GWAET
AD32 HANGUL SYLLABLE GWAEP
AD33 HANGUL SYLLABLE GWAEH
AD34 HANGUL SYLLABLE GOE
AD35 HANGUL SYLLABLE GOEG
AD36 HANGUL SYLLABLE GOEGG
AD37 HANGUL SYLLABLE GOEGS
AD38 HANGUL SYLLABLE GOEN
AD39 HANGUL SYLLABLE GOENJ
AD3A HANGUL SYLLABLE GOENH
AD3B HANGUL SYLLABLE GOED
AD3C HANGUL SYLLABLE GOEL
AD3D HANGUL SYLLABLE GOELG
AD3E HANGUL SYLLABLE GOELM
AD3F HANGUL SYLLABLE GOELB
AD40 HANGUL SYLLABLE GOELS
AD41 HANGUL SYLLABLE GOELT
AD42 HANGUL SYLLABLE GOELP
AD43 HANGUL SYLLABLE GOELH
AD44 HANGUL SYLLABLE GOEM
AD45 HANGUL SYLLABLE GOEB
AD46 HANGUL SYLLABLE GOEBS
AD47 HANGUL SYLLABLE GOES
AD48 HANGUL SYLLABLE GOESS
AD49 HANGUL SYLLABLE GOENG
AD4A HANGUL SYLLABLE GOEJ
AD4B HANGUL SYLLABLE GOEC
AD4C HANGUL SYLLABLE GOEK
AD4D HANGUL SYLLABLE GOET
AD4E HANGUL SYLLABLE GOEP
AD4F HANGUL SYLLABLE GOEH
AD50 HANGUL SYLLABLE GYO
AD51 HANGUL SYLLABLE GYOG
AD52 HANGUL SYLLABLE GYOGG
AD53 HANGUL SYLLABLE GYOGS
AD54 HANGUL SYLLABLE GYON
AD55 HANGUL SYLLABLE GYONJ
AD56 HANGUL SYLLABLE GYONH
AD57 HANGUL SYLLABLE GYOD
AD58 HANGUL SYLLABLE GYOL
AD59 HANGUL SYLLABLE GYOLG
AD5A HANGUL SYLLABLE GYOLM
AD5B HANGUL SYLLABLE GYOLB
AD5C HANGUL SYLLABLE GYOLS
AD5D HANGUL SYLLABLE GYOLT
AD5E HANGUL SYLLABLE GYOLP
AD5F HANGUL SYLLABLE GYOLH
AD60 HANGUL SYLLABLE GYOM
AD61 HANGUL SYLLABLE GYOB
AD62 HANGUL SYLLABLE GYOBS
AD63 HANGUL SYLLABLE GYOS
AD64 HANGUL SYLLABLE GYOSS
AD65 HANGUL SYLLABLE GYONG
AD66 HANGUL SYLLABLE GYOJ
AD67 HANGUL SYLLABLE GYOC
AD68 HANGUL SYLLABLE GYOK
AD69 HANGUL SYLLABLE GYOT
AD6A HANGUL SYLLABLE GYOP
AD6B HANGUL SYLLABLE GYOH
AD6C HANGUL SYLLABLE GU
AD6D HANGUL SYLLABLE GUG
AD6E HANGUL SYLLABLE GUGG
AD6F HANGUL SYLLABLE GUGS
AD70 HANGUL SYLLABLE GUN
AD71 HANGUL SYLLABLE GUNJ
AD72 HANGUL SYLLABLE GUNH
AD73 HANGUL SYLLABLE GUD
AD74 HANGUL SYLLABLE GUL
AD75 HANGUL SYLLABLE GULG
AD76 HANGUL SYLLABLE GULM
AD77 HANGUL SYLLABLE GULB
AD78 HANGUL SYLLABLE GULS
AD79 HANGUL SYLLABLE GULT
AD7A HANGUL SYLLABLE GULP
AD7B HANGUL SYLLABLE GULH
AD7C HANGUL SYLLABLE GUM
AD7D HANGUL SYLLABLE GUB
AD7E HANGUL SYLLABLE GUBS
AD7F HANGUL SYLLABLE GUS
AD80 HANGUL SYLLABLE GUSS
AD81 HANGUL SYLLABLE GUNG
AD82 HANGUL SYLLABLE GUJ
AD83 HANGUL SYLLABLE GUC
AD84 HANGUL SYLLABLE GUK
AD85 HANGUL SYLLABLE GUT
AD86 HANGUL SYLLABLE GUP
AD87 HANGUL SYLLABLE GUH
AD88 HANGUL SYLLABLE GWEO
AD89 HANGUL SYLLABLE GWEOG
AD8A HANGUL SYLLABLE GWEOGG
AD8B HANGUL SYLLABLE GWEOGS
AD8C HANGUL SYLLABLE GWEON
AD8D HANGUL SYLLABLE GWEONJ
AD8E HANGUL SYLLABLE GWEONH
AD8F HANGUL SYLLABLE GWEOD
AD90 HANGUL SYLLABLE GWEOL
AD91 HANGUL SYLLABLE GWEOLG
AD92 HANGUL SYLLABLE GWEOLM
AD93 HANGUL SYLLABLE GWEOLB
AD94 HANGUL SYLLABLE GWEOLS
AD95 HANGUL SYLLABLE GWEOLT
AD96 HANGUL SYLLABLE GWEOLP
AD97 HANGUL SYLLABLE GWEOLH
AD98 HANGUL SYLLABLE GWEOM
AD99 HANGUL SYLLABLE GWEOB
AD9A HANGUL SYLLABLE GWEOBS
AD9B HANGUL SYLLABLE GWEOS
AD9C HANGUL SYLLABLE GWEOSS
AD9D HANGUL SYLLABLE GWEONG
AD9E HANGUL SYLLABLE GWEOJ
AD9F HANGUL SYLLABLE GWEOC
ADA0 HANGUL SYLLABLE GWEOK
ADA1 HANGUL SYLLABLE GWEOT
ADA2 HANGUL SYLLABLE GWEOP
ADA3 HANGUL SYLLABLE GWEOH
ADA4 HANGUL SYLLABLE GWE
ADA5 HANGUL SYLLABLE GWEG
ADA6 HANGUL SYLLABLE GWEGG
ADA7 HANGUL SYLLABLE GWEGS
ADA8 HANGUL SYLLABLE GWEN
ADA9 HANGUL SYLLABLE GWENJ
ADAA HANGUL SYLLABLE GWENH
ADAB HANGUL SYLLABLE GWED
ADAC HANGUL SYLLABLE GWEL
ADAD HANGUL SYLLABLE GWELG
ADAE HANGUL SYLLABLE GWELM
ADAF HANGUL SYLLABLE GWELB
ADB0 HANGUL SYLLABLE GWELS
ADB1 HANGUL SYLLABLE GWELT
ADB2 HANGUL SYLLABLE GWELP
ADB3 HANGUL SYLLABLE GWELH
ADB4 HANGUL SYLLABLE GWEM
ADB5 HANGUL SYLLABLE GWEB
ADB6 HANGUL SYLLABLE GWEBS
ADB7 HANGUL SYLLABLE GWES
ADB8 HANGUL SYLLABLE GWESS
ADB9 HANGUL SYLLABLE GWENG
ADBA HANGUL SYLLABLE GWEJ
ADBB HANGUL SYLLABLE GWEC
ADBC HANGUL SYLLABLE GWEK
ADBD HANGUL SYLLABLE GWET
ADBE HANGUL SYLLABLE GWEP
ADBF HANGUL SYLLABLE GWEH
ADC0 HANGUL SYLLABLE GWI
ADC1 HANGUL SYLLABLE GWIG
ADC2 HANGUL SYLLABLE GWIGG
ADC3 HANGUL SYLLABLE GWIGS
ADC4 HANGUL SYLLABLE GWIN
ADC5 HANGUL SYLLABLE GWINJ
ADC6 HANGUL SYLLABLE GWINH
ADC7 HANGUL SYLLABLE GWID
ADC8 HANGUL SYLLABLE GWIL
ADC9 HANGUL SYLLABLE GWILG
ADCA HANGUL SYLLABLE GWILM
ADCB HANGUL SYLLABLE GWILB
ADCC HANGUL SYLLABLE GWILS
ADCD HANGUL SYLLABLE GWILT
ADCE HANGUL SYLLABLE GWILP
ADCF HANGUL SYLLABLE GWILH
ADD0 HANGUL SYLLABLE GWIM
ADD1 HANGUL SYLLABLE GWIB
ADD2 HANGUL SYLLABLE GWIBS
ADD3 HANGUL SYLLABLE GWIS
ADD4 HANGUL SYLLABLE GWISS
ADD5 HANGUL SYLLABLE GWING
ADD6 HANGUL SYLLABLE GWIJ
ADD7 HANGUL SYLLABLE GWIC
ADD8 HANGUL SYLLABLE GWIK
ADD9 HANGUL SYLLABLE GWIT
ADDA HANGUL SYLLABLE GWIP
ADDB HANGUL SYLLABLE GWIH
ADDC HANGUL SYLLABLE GYU
ADDD HANGUL SYLLABLE GYUG
ADDE HANGUL SYLLABLE GYUGG
ADDF HANGUL SYLLABLE GYUGS
ADE0 HANGUL SYLLABLE GYUN
ADE1 HANGUL SYLLABLE GYUNJ
ADE2 HANGUL SYLLABLE GYUNH
ADE3 HANGUL SYLLABLE GYUD
ADE4 HANGUL SYLLABLE GYUL
ADE5 HANGUL SYLLABLE GYULG
ADE6 HANGUL SYLLABLE GYULM
ADE7 HANGUL SYLLABLE GYULB
ADE8 HANGUL SYLLABLE GYULS
ADE9 HANGUL SYLLABLE GYULT
ADEA HANGUL SYLLABLE GYULP
ADEB HANGUL SYLLABLE GYULH
ADEC HANGUL SYLLABLE GYUM
ADED HANGUL SYLLABLE GYUB
ADEE HANGUL SYLLABLE GYUBS
ADEF HANGUL SYLLABLE GYUS
ADF0 HANGUL SYLLABLE GYUSS
ADF1 HANGUL SYLLABLE GYUNG
ADF2 HANGUL SYLLABLE GYUJ
ADF3 HANGUL SYLLABLE GYUC
ADF4 HANGUL SYLLABLE GYUK
ADF5 HANGUL SYLLABLE GYUT
ADF6 HANGUL SYLLABLE GYUP
ADF7 HANGUL SYLLABLE GYUH
ADF8 HANGUL SYLLABLE GEU
ADF9 HANGUL SYLLABLE GEUG
ADFA HANGUL SYLLABLE GEUGG
ADFB HANGUL SYLLABLE GEUGS
ADFC HANGUL SYLLABLE GEUN
ADFD HANGUL SYLLABLE GEUNJ
ADFE HANGUL SYLLABLE GEUNH
ADFF HANGUL SYLLABLE GEUD
AE00 HANGUL SYLLABLE GEUL
AE01 HANGUL SYLLABLE GEULG
AE02 HANGUL SYLLABLE GEULM
AE03 HANGUL SYLLABLE GEULB
AE04 HANGUL SYLLABLE GEULS
AE05 HANGUL SYLLABLE GEULT
AE06 HANGUL SYLLABLE GEULP
AE07 HANGUL SYLLABLE GEULH
AE08 HANGUL SYLLABLE GEUM
AE09 HANGUL SYLLABLE GEUB
AE0A HANGUL SYLLABLE GEUBS
AE0B HANGUL SYLLABLE GEUS
AE0C HANGUL SYLLABLE GEUSS
AE0D HANGUL SYLLABLE GEUNG
AE0E HANGUL SYLLABLE GEUJ
AE0F HANGUL SYLLABLE GEUC
AE10 HANGUL SYLLABLE GEUK
AE11 HANGUL SYLLABLE GEUT
AE12 HANGUL SYLLABLE GEUP
AE13 HANGUL SYLLABLE GEUH
AE14 HANGUL SYLLABLE GYI
AE15 HANGUL SYLLABLE GYIG
AE16 HANGUL SYLLABLE GYIGG
AE17 HANGUL SYLLABLE GYIGS
AE18 HANGUL SYLLABLE GYIN
AE19 HANGUL SYLLABLE GYINJ
AE1A HANGUL SYLLABLE GYINH
AE1B HANGUL SYLLABLE GYID
AE1C HANGUL SYLLABLE GYIL
AE1D HANGUL SYLLABLE GYILG
AE1E HANGUL SYLLABLE GYILM
AE1F HANGUL SYLLABLE GYILB
AE20 HANGUL SYLLABLE GYILS
AE21 HANGUL SYLLABLE GYILT
AE22 HANGUL SYLLABLE GYILP
AE23 HANGUL SYLLABLE GYILH
AE24 HANGUL SYLLABLE GYIM
AE25 HANGUL SYLLABLE GYIB
AE26 HANGUL SYLLABLE GYIBS
AE27 HANGUL SYLLABLE GYIS
AE28 HANGUL SYLLABLE GYISS
AE29 HANGUL SYLLABLE GYING
AE2A HANGUL SYLLABLE GYIJ
AE2B HANGUL SYLLABLE GYIC
AE2C HANGUL SYLLABLE GYIK
AE2D HANGUL SYLLABLE GYIT
AE2E HANGUL SYLLABLE GYIP
AE2F HANGUL SYLLABLE GYIH
AE30 HANGUL SYLLABLE GI
AE31 HANGUL SYLLABLE GIG
AE32 HANGUL SYLLABLE GIGG
AE33 HANGUL SYLLABLE GIGS
AE34 HANGUL SYLLABLE GIN
AE35 HANGUL SYLLABLE GINJ
AE36 HANGUL SYLLABLE GINH
AE37 HANGUL SYLLABLE GID
AE38 HANGUL SYLLABLE GIL
AE39 HANGUL SYLLABLE GILG
AE3A HANGUL SYLLABLE GILM
AE3B HANGUL SYLLABLE GILB
AE3C HANGUL SYLLABLE GILS
AE3D HANGUL SYLLABLE GILT
AE3E HANGUL SYLLABLE GILP
AE3F HANGUL SYLLABLE GILH
AE40 HANGUL SYLLABLE GIM
AE41 HANGUL SYLLABLE GIB
AE42 HANGUL SYLLABLE GIBS
AE43 HANGUL SYLLABLE GIS
AE44 HANGUL SYLLABLE GISS
AE45 HANGUL SYLLABLE GING
AE46 HANGUL SYLLABLE GIJ
AE47 HANGUL SYLLABLE GIC
AE48 HANGUL SYLLABLE GIK
AE49 HANGUL SYLLABLE GIT
AE4A HANGUL SYLLABLE GIP
AE4B HANGUL SYLLABLE GIH
AE4C HANGUL SYLLABLE GGA
AE4D HANGUL SYLLABLE GGAG
AE4E HANGUL SYLLABLE GGAGG
AE4F HANGUL SYLLABLE GGAGS
AE50 HANGUL SYLLABLE GGAN
AE51 HANGUL SYLLABLE GGANJ
AE52 HANGUL SYLLABLE GGANH
AE53 HANGUL SYLLABLE GGAD
AE54 HANGUL SYLLABLE GGAL
AE55 HANGUL SYLLABLE GGALG
AE56 HANGUL SYLLABLE GGALM
AE57 HANGUL SYLLABLE GGALB
AE58 HANGUL SYLLABLE GGALS
AE59 HANGUL SYLLABLE GGALT
AE5A HANGUL SYLLABLE GGALP
AE5B HANGUL SYLLABLE GGALH
AE5C HANGUL SYLLABLE GGAM
AE5D HANGUL SYLLABLE GGAB
AE5E HANGUL SYLLABLE GGABS
AE5F HANGUL SYLLABLE GGAS
AE60 HANGUL SYLLABLE GGASS
AE61 HANGUL SYLLABLE GGANG
AE62 HANGUL SYLLABLE GGAJ
AE63 HANGUL SYLLABLE GGAC
AE64 HANGUL SYLLABLE GGAK
AE65 HANGUL SYLLABLE GGAT
AE66 HANGUL SYLLABLE GGAP
AE67 HANGUL SYLLABLE GGAH
AE68 HANGUL SYLLABLE GGAE
AE69 HANGUL SYLLABLE GGAEG
AE6A HANGUL SYLLABLE GGAEGG
AE6B HANGUL SYLLABLE GGAEGS
AE6C HANGUL SYLLABLE GGAEN
AE6D HANGUL SYLLABLE GGAENJ
AE6E HANGUL SYLLABLE GGAENH
AE6F HANGUL SYLLABLE GGAED
AE70 HANGUL SYLLABLE GGAEL
AE71 HANGUL SYLLABLE GGAELG
AE72 HANGUL SYLLABLE GGAELM
AE73 HANGUL SYLLABLE GGAELB
AE74 HANGUL SYLLABLE GGAELS
AE75 HANGUL SYLLABLE GGAELT
AE76 HANGUL SYLLABLE GGAELP
AE77 HANGUL SYLLABLE GGAELH
AE78 HANGUL SYLLABLE GGAEM
AE79 HANGUL SYLLABLE GGAEB
AE7A HANGUL SYLLABLE GGAEBS
AE7B HANGUL SYLLABLE GGAES
AE7C HANGUL SYLLABLE GGAESS
AE7D HANGUL SYLLABLE GGAENG
AE7E HANGUL SYLLABLE GGAEJ
AE7F HANGUL SYLLABLE GGAEC
AE80 HANGUL SYLLABLE GGAEK
AE81 HANGUL SYLLABLE GGAET
AE82 HANGUL SYLLABLE GGAEP
AE83 HANGUL SYLLABLE GGAEH
AE84 HANGUL SYLLABLE GGYA
AE85 HANGUL SYLLABLE GGYAG
AE86 HANGUL SYLLABLE GGYAGG
AE87 HANGUL SYLLABLE GGYAGS
AE88 HANGUL SYLLABLE GGYAN
AE89 HANGUL SYLLABLE GGYANJ
AE8A HANGUL SYLLABLE GGYANH
AE8B HANGUL SYLLABLE GGYAD
AE8C HANGUL SYLLABLE GGYAL
AE8D HANGUL SYLLABLE GGYALG
AE8E HANGUL SYLLABLE GGYALM
AE8F HANGUL SYLLABLE GGYALB
AE90 HANGUL SYLLABLE GGYALS
AE91 HANGUL SYLLABLE GGYALT
AE92 HANGUL SYLLABLE GGYALP
AE93 HANGUL SYLLABLE GGYALH
AE94 HANGUL SYLLABLE GGYAM
AE95 HANGUL SYLLABLE GGYAB
AE96 HANGUL SYLLABLE GGYABS
AE97 HANGUL SYLLABLE GGYAS
AE98 HANGUL SYLLABLE GGYASS
AE99 HANGUL SYLLABLE GGYANG
AE9A HANGUL SYLLABLE GGYAJ
AE9B HANGUL SYLLABLE GGYAC
AE9C HANGUL SYLLABLE GGYAK
AE9D HANGUL SYLLABLE GGYAT
AE9E HANGUL SYLLABLE GGYAP
AE9F HANGUL SYLLABLE GGYAH
AEA0 HANGUL SYLLABLE GGYAE
AEA1 HANGUL SYLLABLE GGYAEG
AEA2 HANGUL SYLLABLE GGYAEGG
AEA3 HANGUL SYLLABLE GGYAEGS
AEA4 HANGUL SYLLABLE GGYAEN
AEA5 HANGUL SYLLABLE GGYAENJ
AEA6 HANGUL SYLLABLE GGYAENH
AEA7 HANGUL SYLLABLE GGYAED
AEA8 HANGUL SYLLABLE GGYAEL
AEA9 HANGUL SYLLABLE GGYAELG
AEAA HANGUL SYLLABLE GGYAELM
AEAB HANGUL SYLLABLE GGYAELB
AEAC HANGUL SYLLABLE GGYAELS
AEAD HANGUL SYLLABLE GGYAELT
AEAE HANGUL SYLLABLE GGYAELP
AEAF HANGUL SYLLABLE GGYAELH
AEB0 HANGUL SYLLABLE GGYAEM
AEB1 HANGUL SYLLABLE GGYAEB
AEB2 HANGUL SYLLABLE GGYAEBS
AEB3 HANGUL SYLLABLE GGYAES
AEB4 HANGUL SYLLABLE GGYAESS
AEB5 HANGUL SYLLABLE GGYAENG
AEB6 HANGUL SYLLABLE GGYAEJ
AEB7 HANGUL SYLLABLE GGYAEC
AEB8 HANGUL SYLLABLE GGYAEK
AEB9 HANGUL SYLLABLE GGYAET
AEBA HANGUL SYLLABLE GGYAEP
AEBB HANGUL SYLLABLE GGYAEH
AEBC HANGUL SYLLABLE GGEO
AEBD HANGUL SYLLABLE GGEOG
AEBE HANGUL SYLLABLE GGEOGG
AEBF HANGUL SYLLABLE GGEOGS
AEC0 HANGUL SYLLABLE GGEON
AEC1 HANGUL SYLLABLE GGEONJ
AEC2 HANGUL SYLLABLE GGEONH
AEC3 HANGUL SYLLABLE GGEOD
AEC4 HANGUL SYLLABLE GGEOL
AEC5 HANGUL SYLLABLE GGEOLG
AEC6 HANGUL SYLLABLE GGEOLM
AEC7 HANGUL SYLLABLE GGEOLB
AEC8 HANGUL SYLLABLE GGEOLS
AEC9 HANGUL SYLLABLE GGEOLT
AECA HANGUL SYLLABLE GGEOLP
AECB HANGUL SYLLABLE GGEOLH
AECC HANGUL SYLLABLE GGEOM
AECD HANGUL SYLLABLE GGEOB
AECE HANGUL SYLLABLE GGEOBS
AECF HANGUL SYLLABLE GGEOS
AED0 HANGUL SYLLABLE GGEOSS
AED1 HANGUL SYLLABLE GGEONG
AED2 HANGUL SYLLABLE GGEOJ
AED3 HANGUL SYLLABLE GGEOC
AED4 HANGUL SYLLABLE GGEOK
AED5 HANGUL SYLLABLE GGEOT
AED6 HANGUL SYLLABLE GGEOP
AED7 HANGUL SYLLABLE GGEOH
AED8 HANGUL SYLLABLE GGE
AED9 HANGUL SYLLABLE GGEG
AEDA HANGUL SYLLABLE GGEGG
AEDB HANGUL SYLLABLE GGEGS
AEDC HANGUL SYLLABLE GGEN
AEDD HANGUL SYLLABLE GGENJ
AEDE HANGUL SYLLABLE GGENH
AEDF HANGUL SYLLABLE GGED
AEE0 HANGUL SYLLABLE GGEL
AEE1 HANGUL SYLLABLE GGELG
AEE2 HANGUL SYLLABLE GGELM
AEE3 HANGUL SYLLABLE GGELB
AEE4 HANGUL SYLLABLE GGELS
AEE5 HANGUL SYLLABLE GGELT
AEE6 HANGUL SYLLABLE GGELP
AEE7 HANGUL SYLLABLE GGELH
AEE8 HANGUL SYLLABLE GGEM
AEE9 HANGUL SYLLABLE GGEB
AEEA HANGUL SYLLABLE GGEBS
AEEB HANGUL SYLLABLE GGES
AEEC HANGUL SYLLABLE GGESS
AEED HANGUL SYLLABLE GGENG
AEEE HANGUL SYLLABLE GGEJ
AEEF HANGUL SYLLABLE GGEC
AEF0 HANGUL SYLLABLE GGEK
AEF1 HANGUL SYLLABLE GGET
AEF2 HANGUL SYLLABLE GGEP
AEF3 HANGUL SYLLABLE GGEH
AEF4 HANGUL SYLLABLE GGYEO
AEF5 HANGUL SYLLABLE GGYEOG
AEF6 HANGUL SYLLABLE GGYEOGG
AEF7 HANGUL SYLLABLE GGYEOGS
AEF8 HANGUL SYLLABLE GGYEON
AEF9 HANGUL SYLLABLE GGYEONJ
AEFA HANGUL SYLLABLE GGYEONH
AEFB HANGUL SYLLABLE GGYEOD
AEFC HANGUL SYLLABLE GGYEOL
AEFD HANGUL SYLLABLE GGYEOLG
AEFE HANGUL SYLLABLE GGYEOLM
AEFF HANGUL SYLLABLE GGYEOLB
AF00 HANGUL SYLLABLE GGYEOLS
AF01 HANGUL SYLLABLE GGYEOLT
AF02 HANGUL SYLLABLE GGYEOLP
AF03 HANGUL SYLLABLE GGYEOLH
AF04 HANGUL SYLLABLE GGYEOM
AF05 HANGUL SYLLABLE GGYEOB
AF06 HANGUL SYLLABLE GGYEOBS
AF07 HANGUL SYLLABLE GGYEOS
AF08 HANGUL SYLLABLE GGYEOSS
AF09 HANGUL SYLLABLE GGYEONG
AF0A HANGUL SYLLABLE GGYEOJ
AF0B HANGUL SYLLABLE GGYEOC
AF0C HANGUL SYLLABLE GGYEOK
AF0D HANGUL SYLLABLE GGYEOT
AF0E HANGUL SYLLABLE GGYEOP
AF0F HANGUL SYLLABLE GGYEOH
AF10 HANGUL SYLLABLE GGYE
AF11 HANGUL SYLLABLE GGYEG
AF12 HANGUL SYLLABLE GGYEGG
AF13 HANGUL SYLLABLE GGYEGS
AF14 HANGUL SYLLABLE GGYEN
AF15 HANGUL SYLLABLE GGYENJ
AF16 HANGUL SYLLABLE GGYENH
AF17 HANGUL SYLLABLE GGYED
AF18 HANGUL SYLLABLE GGYEL
AF19 HANGUL SYLLABLE GGYELG
AF1A HANGUL SYLLABLE GGYELM
AF1B HANGUL SYLLABLE GGYELB
AF1C HANGUL SYLLABLE GGYELS
AF1D HANGUL SYLLABLE GGYELT
AF1E HANGUL SYLLABLE GGYELP
AF1F HANGUL SYLLABLE GGYELH
AF20 HANGUL SYLLABLE GGYEM
AF21 HANGUL SYLLABLE GGYEB
AF22 HANGUL SYLLABLE GGYEBS
AF23 HANGUL SYLLABLE GGYES
AF24 HANGUL SYLLABLE GGYESS
AF25 HANGUL SYLLABLE GGYENG
AF26 HANGUL SYLLABLE GGYEJ
AF27 HANGUL SYLLABLE GGYEC
AF28 HANGUL SYLLABLE GGYEK
AF29 HANGUL SYLLABLE GGYET
AF2A HANGUL SYLLABLE GGYEP
AF2B HANGUL SYLLABLE GGYEH
AF2C HANGUL SYLLABLE GGO
AF2D HANGUL SYLLABLE GGOG
AF2E HANGUL SYLLABLE GGOGG
AF2F HANGUL SYLLABLE GGOGS
AF30 HANGUL SYLLABLE GGON
AF31 HANGUL SYLLABLE GGONJ
AF32 HANGUL SYLLABLE GGONH
AF33 HANGUL SYLLABLE GGOD
AF34 HANGUL SYLLABLE GGOL
AF35 HANGUL SYLLABLE GGOLG
AF36 HANGUL SYLLABLE GGOLM
AF37 HANGUL SYLLABLE GGOLB
AF38 HANGUL SYLLABLE GGOLS
AF39 HANGUL SYLLABLE GGOLT
AF3A HANGUL SYLLABLE GGOLP
AF3B HANGUL SYLLABLE GGOLH
AF3C HANGUL SYLLABLE GGOM
AF3D HANGUL SYLLABLE GGOB
AF3E HANGUL SYLLABLE GGOBS
AF3F HANGUL SYLLABLE GGOS
AF40 HANGUL SYLLABLE GGOSS
AF41 HANGUL SYLLABLE GGONG
AF42 HANGUL SYLLABLE GGOJ
AF43 HANGUL SYLLABLE GGOC
AF44 HANGUL SYLLABLE GGOK
AF45 HANGUL SYLLABLE GGOT
AF46 HANGUL SYLLABLE GGOP
AF47 HANGUL SYLLABLE GGOH
AF48 HANGUL SYLLABLE GGWA
AF49 HANGUL SYLLABLE GGWAG
AF4A HANGUL SYLLABLE GGWAGG
AF4B HANGUL SYLLABLE GGWAGS
AF4C HANGUL SYLLABLE GGWAN
AF4D HANGUL SYLLABLE GGWANJ
AF4E HANGUL SYLLABLE GGWANH
AF4F HANGUL SYLLABLE GGWAD
AF50 HANGUL SYLLABLE GGWAL
AF51 HANGUL SYLLABLE GGWALG
AF52 HANGUL SYLLABLE GGWALM
AF53 HANGUL SYLLABLE GGWALB
AF54 HANGUL SYLLABLE GGWALS
AF55 HANGUL SYLLABLE GGWALT
AF56 HANGUL SYLLABLE GGWALP
AF57 HANGUL SYLLABLE GGWALH
AF58 HANGUL SYLLABLE GGWAM
AF59 HANGUL SYLLABLE GGWAB
AF5A HANGUL SYLLABLE GGWABS
AF5B HANGUL SYLLABLE GGWAS
AF5C HANGUL SYLLABLE GGWASS
AF5D HANGUL SYLLABLE GGWANG
AF5E HANGUL SYLLABLE GGWAJ
AF5F HANGUL SYLLABLE GGWAC
AF60 HANGUL SYLLABLE GGWAK
AF61 HANGUL SYLLABLE GGWAT
AF62 HANGUL SYLLABLE GGWAP
AF63 HANGUL SYLLABLE GGWAH
AF64 HANGUL SYLLABLE GGWAE
AF65 HANGUL SYLLABLE GGWAEG
AF66 HANGUL SYLLABLE GGWAEGG
AF67 HANGUL SYLLABLE GGWAEGS
AF68 HANGUL SYLLABLE GGWAEN
AF69 HANGUL SYLLABLE GGWAENJ
AF6A HANGUL SYLLABLE GGWAENH
AF6B HANGUL SYLLABLE GGWAED
AF6C HANGUL SYLLABLE GGWAEL
AF6D HANGUL SYLLABLE GGWAELG
AF6E HANGUL SYLLABLE GGWAELM
AF6F HANGUL SYLLABLE GGWAELB
AF70 HANGUL SYLLABLE GGWAELS
AF71 HANGUL SYLLABLE GGWAELT
AF72 HANGUL SYLLABLE GGWAELP
AF73 HANGUL SYLLABLE GGWAELH
AF74 HANGUL SYLLABLE GGWAEM
AF75 HANGUL SYLLABLE GGWAEB
AF76 HANGUL SYLLABLE GGWAEBS
AF77 HANGUL SYLLABLE GGWAES
AF78 HANGUL SYLLABLE GGWAESS
AF79 HANGUL SYLLABLE GGWAENG
AF7A HANGUL SYLLABLE GGWAEJ
AF7B HANGUL SYLLABLE GGWAEC
AF7C HANGUL SYLLABLE GGWAEK
AF7D HANGUL SYLLABLE GGWAET
AF7E HANGUL SYLLABLE GGWAEP
AF7F HANGUL SYLLABLE GGWAEH
AF80 HANGUL SYLLABLE GGOE
AF81 HANGUL SYLLABLE GGOEG
AF82 HANGUL SYLLABLE GGOEGG
AF83 HANGUL SYLLABLE GGOEGS
AF84 HANGUL SYLLABLE GGOEN
AF85 HANGUL SYLLABLE GGOENJ
AF86 HANGUL SYLLABLE GGOENH
AF87 HANGUL SYLLABLE GGOED
AF88 HANGUL SYLLABLE GGOEL
AF89 HANGUL SYLLABLE GGOELG
AF8A HANGUL SYLLABLE GGOELM
AF8B HANGUL SYLLABLE GGOELB
AF8C HANGUL SYLLABLE GGOELS
AF8D HANGUL SYLLABLE GGOELT
AF8E HANGUL SYLLABLE GGOELP
AF8F HANGUL SYLLABLE GGOELH
AF90 HANGUL SYLLABLE GGOEM
AF91 HANGUL SYLLABLE GGOEB
AF92 HANGUL SYLLABLE GGOEBS
AF93 HANGUL SYLLABLE GGOES
AF94 HANGUL SYLLABLE GGOESS
AF95 HANGUL SYLLABLE GGOENG
AF96 HANGUL SYLLABLE GGOEJ
AF97 HANGUL SYLLABLE GGOEC
AF98 HANGUL SYLLABLE GGOEK
AF99 HANGUL SYLLABLE GGOET
AF9A HANGUL SYLLABLE GGOEP
AF9B HANGUL SYLLABLE GGOEH
AF9C HANGUL SYLLABLE GGYO
AF9D HANGUL SYLLABLE GGYOG
AF9E HANGUL SYLLABLE GGYOGG
AF9F HANGUL SYLLABLE GGYOGS
AFA0 HANGUL SYLLABLE GGYON
AFA1 HANGUL SYLLABLE GGYONJ
AFA2 HANGUL SYLLABLE GGYONH
AFA3 HANGUL SYLLABLE GGYOD
AFA4 HANGUL SYLLABLE GGYOL
AFA5 HANGUL SYLLABLE GGYOLG
AFA6 HANGUL SYLLABLE GGYOLM
AFA7 HANGUL SYLLABLE GGYOLB
AFA8 HANGUL SYLLABLE GGYOLS
AFA9 HANGUL SYLLABLE GGYOLT
AFAA HANGUL SYLLABLE GGYOLP
AFAB HANGUL SYLLABLE GGYOLH
AFAC HANGUL SYLLABLE GGYOM
AFAD HANGUL SYLLABLE GGYOB
AFAE HANGUL SYLLABLE GGYOBS
AFAF HANGUL SYLLABLE GGYOS
AFB0 HANGUL SYLLABLE GGYOSS
AFB1 HANGUL SYLLABLE GGYONG
AFB2 HANGUL SYLLABLE GGYOJ
AFB3 HANGUL SYLLABLE GGYOC
AFB4 HANGUL SYLLABLE GGYOK
AFB5 HANGUL SYLLABLE GGYOT
AFB6 HANGUL SYLLABLE GGYOP
AFB7 HANGUL SYLLABLE GGYOH
AFB8 HANGUL SYLLABLE GGU
AFB9 HANGUL SYLLABLE GGUG
AFBA HANGUL SYLLABLE GGUGG
AFBB HANGUL SYLLABLE GGUGS
AFBC HANGUL SYLLABLE GGUN
AFBD HANGUL SYLLABLE GGUNJ
AFBE HANGUL SYLLABLE GGUNH
AFBF HANGUL SYLLABLE GGUD
AFC0 HANGUL SYLLABLE GGUL
AFC1 HANGUL SYLLABLE GGULG
AFC2 HANGUL SYLLABLE GGULM
AFC3 HANGUL SYLLABLE GGULB
AFC4 HANGUL SYLLABLE GGULS
AFC5 HANGUL SYLLABLE GGULT
AFC6 HANGUL SYLLABLE GGULP
AFC7 HANGUL SYLLABLE GGULH
AFC8 HANGUL SYLLABLE GGUM
AFC9 HANGUL SYLLABLE GGUB
AFCA HANGUL SYLLABLE GGUBS
AFCB HANGUL SYLLABLE GGUS
AFCC HANGUL SYLLABLE GGUSS
AFCD HANGUL SYLLABLE GGUNG
AFCE HANGUL SYLLABLE GGUJ
AFCF HANGUL SYLLABLE GGUC
AFD0 HANGUL SYLLABLE GGUK
AFD1 HANGUL SYLLABLE GGUT
AFD2 HANGUL SYLLABLE GGUP
AFD3 HANGUL SYLLABLE GGUH
AFD4 HANGUL SYLLABLE GGWEO
AFD5 HANGUL SYLLABLE GGWEOG
AFD6 HANGUL SYLLABLE GGWEOGG
AFD7 HANGUL SYLLABLE GGWEOGS
AFD8 HANGUL SYLLABLE GGWEON
AFD9 HANGUL SYLLABLE GGWEONJ
AFDA HANGUL SYLLABLE GGWEONH
AFDB HANGUL SYLLABLE GGWEOD
AFDC HANGUL SYLLABLE GGWEOL
AFDD HANGUL SYLLABLE GGWEOLG
AFDE HANGUL SYLLABLE GGWEOLM
AFDF HANGUL SYLLABLE GGWEOLB
AFE0 HANGUL SYLLABLE GGWEOLS
AFE1 HANGUL SYLLABLE GGWEOLT
AFE2 HANGUL SYLLABLE GGWEOLP
AFE3 HANGUL SYLLABLE GGWEOLH
AFE4 HANGUL SYLLABLE GGWEOM
AFE5 HANGUL SYLLABLE GGWEOB
AFE6 HANGUL SYLLABLE GGWEOBS
AFE7 HANGUL SYLLABLE GGWEOS
AFE8 HANGUL SYLLABLE GGWEOSS
AFE9 HANGUL SYLLABLE GGWEONG
AFEA HANGUL SYLLABLE GGWEOJ
AFEB HANGUL SYLLABLE GGWEOC
AFEC HANGUL SYLLABLE GGWEOK
AFED HANGUL SYLLABLE GGWEOT
AFEE HANGUL SYLLABLE GGWEOP
AFEF HANGUL SYLLABLE GGWEOH
AFF0 HANGUL SYLLABLE GGWE
AFF1 HANGUL SYLLABLE GGWEG
AFF2 HANGUL SYLLABLE GGWEGG
AFF3 HANGUL SYLLABLE GGWEGS
AFF4 HANGUL SYLLABLE GGWEN
AFF5 HANGUL SYLLABLE GGWENJ
AFF6 HANGUL SYLLABLE GGWENH
AFF7 HANGUL SYLLABLE GGWED
AFF8 HANGUL SYLLABLE GGWEL
AFF9 HANGUL SYLLABLE GGWELG
AFFA HANGUL SYLLABLE GGWELM
AFFB HANGUL SYLLABLE GGWELB
AFFC HANGUL SYLLABLE GGWELS
AFFD HANGUL SYLLABLE GGWELT
AFFE HANGUL SYLLABLE GGWELP
AFFF HANGUL SYLLABLE GGWELH
B000 HANGUL SYLLABLE GGWEM
B001 HANGUL SYLLABLE GGWEB
B002 HANGUL SYLLABLE GGWEBS
B003 HANGUL SYLLABLE GGWES
B004 HANGUL SYLLABLE GGWESS
B005 HANGUL SYLLABLE GGWENG
B006 HANGUL SYLLABLE GGWEJ
B007 HANGUL SYLLABLE GGWEC
B008 HANGUL SYLLABLE GGWEK
B009 HANGUL SYLLABLE GGWET
B00A HANGUL SYLLABLE GGWEP
B00B HANGUL SYLLABLE GGWEH
B00C HANGUL SYLLABLE GGWI
B00D HANGUL SYLLABLE GGWIG
B00E HANGUL SYLLABLE GGWIGG
B00F HANGUL SYLLABLE GGWIGS
B010 HANGUL SYLLABLE GGWIN
B011 HANGUL SYLLABLE GGWINJ
B012 HANGUL SYLLABLE GGWINH
B013 HANGUL SYLLABLE GGWID
B014 HANGUL SYLLABLE GGWIL
B015 HANGUL SYLLABLE GGWILG
B016 HANGUL SYLLABLE GGWILM
B017 HANGUL SYLLABLE GGWILB
B018 HANGUL SYLLABLE GGWILS
B019 HANGUL SYLLABLE GGWILT
B01A HANGUL SYLLABLE GGWILP
B01B HANGUL SYLLABLE GGWILH
B01C HANGUL SYLLABLE GGWIM
B01D HANGUL SYLLABLE GGWIB
B01E HANGUL SYLLABLE GGWIBS
B01F HANGUL SYLLABLE GGWIS
B020 HANGUL SYLLABLE GGWISS
B021 HANGUL SYLLABLE GGWING
B022 HANGUL SYLLABLE GGWIJ
B023 HANGUL SYLLABLE GGWIC
B024 HANGUL SYLLABLE GGWIK
B025 HANGUL SYLLABLE GGWIT
B026 HANGUL SYLLABLE GGWIP
B027 HANGUL SYLLABLE GGWIH
B028 HANGUL SYLLABLE GGYU
B029 HANGUL SYLLABLE GGYUG
B02A HANGUL SYLLABLE GGYUGG
B02B HANGUL SYLLABLE GGYUGS
B02C HANGUL SYLLABLE GGYUN
B02D HANGUL SYLLABLE GGYUNJ
B02E HANGUL SYLLABLE GGYUNH
B02F HANGUL SYLLABLE GGYUD
B030 HANGUL SYLLABLE GGYUL
B031 HANGUL SYLLABLE GGYULG
B032 HANGUL SYLLABLE GGYULM
B033 HANGUL SYLLABLE GGYULB
B034 HANGUL SYLLABLE GGYULS
B035 HANGUL SYLLABLE GGYULT
B036 HANGUL SYLLABLE GGYULP
B037 HANGUL SYLLABLE GGYULH
B038 HANGUL SYLLABLE GGYUM
B039 HANGUL SYLLABLE GGYUB
B03A HANGUL SYLLABLE GGYUBS
B03B HANGUL SYLLABLE GGYUS
B03C HANGUL SYLLABLE GGYUSS
B03D HANGUL SYLLABLE GGYUNG
B03E HANGUL SYLLABLE GGYUJ
B03F HANGUL SYLLABLE GGYUC
B040 HANGUL SYLLABLE GGYUK
B041 HANGUL SYLLABLE GGYUT
B042 HANGUL SYLLABLE GGYUP
B043 HANGUL SYLLABLE GGYUH
B044 HANGUL SYLLABLE GGEU
B045 HANGUL SYLLABLE GGEUG
B046 HANGUL SYLLABLE GGEUGG
B047 HANGUL SYLLABLE GGEUGS
B048 HANGUL SYLLABLE GGEUN
B049 HANGUL SYLLABLE GGEUNJ
B04A HANGUL SYLLABLE GGEUNH
B04B HANGUL SYLLABLE GGEUD
B04C HANGUL SYLLABLE GGEUL
B04D HANGUL SYLLABLE GGEULG
B04E HANGUL SYLLABLE GGEULM
B04F HANGUL SYLLABLE GGEULB
B050 HANGUL SYLLABLE GGEULS
B051 HANGUL SYLLABLE GGEULT
B052 HANGUL SYLLABLE GGEULP
B053 HANGUL SYLLABLE GGEULH
B054 HANGUL SYLLABLE GGEUM
B055 HANGUL SYLLABLE GGEUB
B056 HANGUL SYLLABLE GGEUBS
B057 HANGUL SYLLABLE GGEUS
B058 HANGUL SYLLABLE GGEUSS
B059 HANGUL SYLLABLE GGEUNG
B05A HANGUL SYLLABLE GGEUJ
B05B HANGUL SYLLABLE GGEUC
B05C HANGUL SYLLABLE GGEUK
B05D HANGUL SYLLABLE GGEUT
B05E HANGUL SYLLABLE GGEUP
B05F HANGUL SYLLABLE GGEUH
B060 HANGUL SYLLABLE GGYI
B061 HANGUL SYLLABLE GGYIG
B062 HANGUL SYLLABLE GGYIGG
B063 HANGUL SYLLABLE GGYIGS
B064 HANGUL SYLLABLE GGYIN
B065 HANGUL SYLLABLE GGYINJ
B066 HANGUL SYLLABLE GGYINH
B067 HANGUL SYLLABLE GGYID
B068 HANGUL SYLLABLE GGYIL
B069 HANGUL SYLLABLE GGYILG
B06A HANGUL SYLLABLE GGYILM
B06B HANGUL SYLLABLE GGYILB
B06C HANGUL SYLLABLE GGYILS
B06D HANGUL SYLLABLE GGYILT
B06E HANGUL SYLLABLE GGYILP
B06F HANGUL SYLLABLE GGYILH
B070 HANGUL SYLLABLE GGYIM
B071 HANGUL SYLLABLE GGYIB
B072 HANGUL SYLLABLE GGYIBS
B073 HANGUL SYLLABLE GGYIS
B074 HANGUL SYLLABLE GGYISS
B075 HANGUL SYLLABLE GGYING
B076 HANGUL SYLLABLE GGYIJ
B077 HANGUL SYLLABLE GGYIC
B078 HANGUL SYLLABLE GGYIK
B079 HANGUL SYLLABLE GGYIT
B07A HANGUL SYLLABLE GGYIP
B07B HANGUL SYLLABLE GGYIH
B07C HANGUL SYLLABLE GGI
B07D HANGUL SYLLABLE GGIG
B07E HANGUL SYLLABLE GGIGG
B07F HANGUL SYLLABLE GGIGS
B080 HANGUL SYLLABLE GGIN
B081 HANGUL SYLLABLE GGINJ
B082 HANGUL SYLLABLE GGINH
B083 HANGUL SYLLABLE GGID
B084 HANGUL SYLLABLE GGIL
B085 HANGUL SYLLABLE GGILG
B086 HANGUL SYLLABLE GGILM
B087 HANGUL SYLLABLE GGILB
B088 HANGUL SYLLABLE GGILS
B089 HANGUL SYLLABLE GGILT
B08A HANGUL SYLLABLE GGILP
B08B HANGUL SYLLABLE GGILH
B08C HANGUL SYLLABLE GGIM
B08D HANGUL SYLLABLE GGIB
B08E HANGUL SYLLABLE GGIBS
B08F HANGUL SYLLABLE GGIS
B090 HANGUL SYLLABLE GGISS
B091 HANGUL SYLLABLE GGING
B092 HANGUL SYLLABLE GGIJ
B093 HANGUL SYLLABLE GGIC
B094 HANGUL SYLLABLE GGIK
B095 HANGUL SYLLABLE GGIT
B096 HANGUL SYLLABLE GGIP
B097 HANGUL SYLLABLE GGIH
B098 HANGUL SYLLABLE NA
B099 HANGUL SYLLABLE NAG
B09A HANGUL SYLLABLE NAGG
B09B HANGUL SYLLABLE NAGS
B09C HANGUL SYLLABLE NAN
B09D HANGUL SYLLABLE NANJ
B09E HANGUL SYLLABLE NANH
B09F HANGUL SYLLABLE NAD
B0A0 HANGUL SYLLABLE NAL
B0A1 HANGUL SYLLABLE NALG
B0A2 HANGUL SYLLABLE NALM
B0A3 HANGUL SYLLABLE NALB
B0A4 HANGUL SYLLABLE NALS
B0A5 HANGUL SYLLABLE NALT
B0A6 HANGUL SYLLABLE NALP
B0A7 HANGUL SYLLABLE NALH
B0A8 HANGUL SYLLABLE NAM
B0A9 HANGUL SYLLABLE NAB
B0AA HANGUL SYLLABLE NABS
B0AB HANGUL SYLLABLE NAS
B0AC HANGUL SYLLABLE NASS
B0AD HANGUL SYLLABLE NANG
B0AE HANGUL SYLLABLE NAJ
B0AF HANGUL SYLLABLE NAC
B0B0 HANGUL SYLLABLE NAK
B0B1 HANGUL SYLLABLE NAT
B0B2 HANGUL SYLLABLE NAP
B0B3 HANGUL SYLLABLE NAH
B0B4 HANGUL SYLLABLE NAE
B0B5 HANGUL SYLLABLE NAEG
B0B6 HANGUL SYLLABLE NAEGG
B0B7 HANGUL SYLLABLE NAEGS
B0B8 HANGUL SYLLABLE NAEN
B0B9 HANGUL SYLLABLE NAENJ
B0BA HANGUL SYLLABLE NAENH
B0BB HANGUL SYLLABLE NAED
B0BC HANGUL SYLLABLE NAEL
B0BD HANGUL SYLLABLE NAELG
B0BE HANGUL SYLLABLE NAELM
B0BF HANGUL SYLLABLE NAELB
B0C0 HANGUL SYLLABLE NAELS
B0C1 HANGUL SYLLABLE NAELT
B0C2 HANGUL SYLLABLE NAELP
B0C3 HANGUL SYLLABLE NAELH
B0C4 HANGUL SYLLABLE NAEM
B0C5 HANGUL SYLLABLE NAEB
B0C6 HANGUL SYLLABLE NAEBS
B0C7 HANGUL SYLLABLE NAES
B0C8 HANGUL SYLLABLE NAESS
B0C9 HANGUL SYLLABLE NAENG
B0CA HANGUL SYLLABLE NAEJ
B0CB HANGUL SYLLABLE NAEC
B0CC HANGUL SYLLABLE NAEK
B0CD HANGUL SYLLABLE NAET
B0CE HANGUL SYLLABLE NAEP
B0CF HANGUL SYLLABLE NAEH
B0D0 HANGUL SYLLABLE NYA
B0D1 HANGUL SYLLABLE NYAG
B0D2 HANGUL SYLLABLE NYAGG
B0D3 HANGUL SYLLABLE NYAGS
B0D4 HANGUL SYLLABLE NYAN
B0D5 HANGUL SYLLABLE NYANJ
B0D6 HANGUL SYLLABLE NYANH
B0D7 HANGUL SYLLABLE NYAD
B0D8 HANGUL SYLLABLE NYAL
B0D9 HANGUL SYLLABLE NYALG
B0DA HANGUL SYLLABLE NYALM
B0DB HANGUL SYLLABLE NYALB
B0DC HANGUL SYLLABLE NYALS
B0DD HANGUL SYLLABLE NYALT
B0DE HANGUL SYLLABLE NYALP
B0DF HANGUL SYLLABLE NYALH
B0E0 HANGUL SYLLABLE NYAM
B0E1 HANGUL SYLLABLE NYAB
B0E2 HANGUL SYLLABLE NYABS
B0E3 HANGUL SYLLABLE NYAS
B0E4 HANGUL SYLLABLE NYASS
B0E5 HANGUL SYLLABLE NYANG
B0E6 HANGUL SYLLABLE NYAJ
B0E7 HANGUL SYLLABLE NYAC
B0E8 HANGUL SYLLABLE NYAK
B0E9 HANGUL SYLLABLE NYAT
B0EA HANGUL SYLLABLE NYAP
B0EB HANGUL SYLLABLE NYAH
B0EC HANGUL SYLLABLE NYAE
B0ED HANGUL SYLLABLE NYAEG
B0EE HANGUL SYLLABLE NYAEGG
B0EF HANGUL SYLLABLE NYAEGS
B0F0 HANGUL SYLLABLE NYAEN
B0F1 HANGUL SYLLABLE NYAENJ
B0F2 HANGUL SYLLABLE NYAENH
B0F3 HANGUL SYLLABLE NYAED
B0F4 HANGUL SYLLABLE NYAEL
B0F5 HANGUL SYLLABLE NYAELG
B0F6 HANGUL SYLLABLE NYAELM
B0F7 HANGUL SYLLABLE NYAELB
B0F8 HANGUL SYLLABLE NYAELS
B0F9 HANGUL SYLLABLE NYAELT
B0FA HANGUL SYLLABLE NYAELP
B0FB HANGUL SYLLABLE NYAELH
B0FC HANGUL SYLLABLE NYAEM
B0FD HANGUL SYLLABLE NYAEB
B0FE HANGUL SYLLABLE NYAEBS
B0FF HANGUL SYLLABLE NYAES
B100 HANGUL SYLLABLE NYAESS
B101 HANGUL SYLLABLE NYAENG
B102 HANGUL SYLLABLE NYAEJ
B103 HANGUL SYLLABLE NYAEC
B104 HANGUL SYLLABLE NYAEK
B105 HANGUL SYLLABLE NYAET
B106 HANGUL SYLLABLE NYAEP
B107 HANGUL SYLLABLE NYAEH
B108 HANGUL SYLLABLE NEO
B109 HANGUL SYLLABLE NEOG
B10A HANGUL SYLLABLE NEOGG
B10B HANGUL SYLLABLE NEOGS
B10C HANGUL SYLLABLE NEON
B10D HANGUL SYLLABLE NEONJ
B10E HANGUL SYLLABLE NEONH
B10F HANGUL SYLLABLE NEOD
B110 HANGUL SYLLABLE NEOL
B111 HANGUL SYLLABLE NEOLG
B112 HANGUL SYLLABLE NEOLM
B113 HANGUL SYLLABLE NEOLB
B114 HANGUL SYLLABLE NEOLS
B115 HANGUL SYLLABLE NEOLT
B116 HANGUL SYLLABLE NEOLP
B117 HANGUL SYLLABLE NEOLH
B118 HANGUL SYLLABLE NEOM
B119 HANGUL SYLLABLE NEOB
B11A HANGUL SYLLABLE NEOBS
B11B HANGUL SYLLABLE NEOS
B11C HANGUL SYLLABLE NEOSS
B11D HANGUL SYLLABLE NEONG
B11E HANGUL SYLLABLE NEOJ
B11F HANGUL SYLLABLE NEOC
B120 HANGUL SYLLABLE NEOK
B121 HANGUL SYLLABLE NEOT
B122 HANGUL SYLLABLE NEOP
B123 HANGUL SYLLABLE NEOH
B124 HANGUL SYLLABLE NE
B125 HANGUL SYLLABLE NEG
B126 HANGUL SYLLABLE NEGG
B127 HANGUL SYLLABLE NEGS
B128 HANGUL SYLLABLE NEN
B129 HANGUL SYLLABLE NENJ
B12A HANGUL SYLLABLE NENH
B12B HANGUL SYLLABLE NED
B12C HANGUL SYLLABLE NEL
B12D HANGUL SYLLABLE NELG
B12E HANGUL SYLLABLE NELM
B12F HANGUL SYLLABLE NELB
B130 HANGUL SYLLABLE NELS
B131 HANGUL SYLLABLE NELT
B132 HANGUL SYLLABLE NELP
B133 HANGUL SYLLABLE NELH
B134 HANGUL SYLLABLE NEM
B135 HANGUL SYLLABLE NEB
B136 HANGUL SYLLABLE NEBS
B137 HANGUL SYLLABLE NES
B138 HANGUL SYLLABLE NESS
B139 HANGUL SYLLABLE NENG
B13A HANGUL SYLLABLE NEJ
B13B HANGUL SYLLABLE NEC
B13C HANGUL SYLLABLE NEK
B13D HANGUL SYLLABLE NET
B13E HANGUL SYLLABLE NEP
B13F HANGUL SYLLABLE NEH
B140 HANGUL SYLLABLE NYEO
B141 HANGUL SYLLABLE NYEOG
B142 HANGUL SYLLABLE NYEOGG
B143 HANGUL SYLLABLE NYEOGS
B144 HANGUL SYLLABLE NYEON
B145 HANGUL SYLLABLE NYEONJ
B146 HANGUL SYLLABLE NYEONH
B147 HANGUL SYLLABLE NYEOD
B148 HANGUL SYLLABLE NYEOL
B149 HANGUL SYLLABLE NYEOLG
B14A HANGUL SYLLABLE NYEOLM
B14B HANGUL SYLLABLE NYEOLB
B14C HANGUL SYLLABLE NYEOLS
B14D HANGUL SYLLABLE NYEOLT
B14E HANGUL SYLLABLE NYEOLP
B14F HANGUL SYLLABLE NYEOLH
B150 HANGUL SYLLABLE NYEOM
B151 HANGUL SYLLABLE NYEOB
B152 HANGUL SYLLABLE NYEOBS
B153 HANGUL SYLLABLE NYEOS
B154 HANGUL SYLLABLE NYEOSS
B155 HANGUL SYLLABLE NYEONG
B156 HANGUL SYLLABLE NYEOJ
B157 HANGUL SYLLABLE NYEOC
B158 HANGUL SYLLABLE NYEOK
B159 HANGUL SYLLABLE NYEOT
B15A HANGUL SYLLABLE NYEOP
B15B HANGUL SYLLABLE NYEOH
B15C HANGUL SYLLABLE NYE
B15D HANGUL SYLLABLE NYEG
B15E HANGUL SYLLABLE NYEGG
B15F HANGUL SYLLABLE NYEGS
B160 HANGUL SYLLABLE NYEN
B161 HANGUL SYLLABLE NYENJ
B162 HANGUL SYLLABLE NYENH
B163 HANGUL SYLLABLE NYED
B164 HANGUL SYLLABLE NYEL
B165 HANGUL SYLLABLE NYELG
B166 HANGUL SYLLABLE NYELM
B167 HANGUL SYLLABLE NYELB
B168 HANGUL SYLLABLE NYELS
B169 HANGUL SYLLABLE NYELT
B16A HANGUL SYLLABLE NYELP
B16B HANGUL SYLLABLE NYELH
B16C HANGUL SYLLABLE NYEM
B16D HANGUL SYLLABLE NYEB
B16E HANGUL SYLLABLE NYEBS
B16F HANGUL SYLLABLE NYES
B170 HANGUL SYLLABLE NYESS
B171 HANGUL SYLLABLE NYENG
B172 HANGUL SYLLABLE NYEJ
B173 HANGUL SYLLABLE NYEC
B174 HANGUL SYLLABLE NYEK
B175 HANGUL SYLLABLE NYET
B176 HANGUL SYLLABLE NYEP
B177 HANGUL SYLLABLE NYEH
B178 HANGUL SYLLABLE NO
B179 HANGUL SYLLABLE NOG
B17A HANGUL SYLLABLE NOGG
B17B HANGUL SYLLABLE NOGS
B17C HANGUL SYLLABLE NON
B17D HANGUL SYLLABLE NONJ
B17E HANGUL SYLLABLE NONH
B17F HANGUL SYLLABLE NOD
B180 HANGUL SYLLABLE NOL
B181 HANGUL SYLLABLE NOLG
B182 HANGUL SYLLABLE NOLM
B183 HANGUL SYLLABLE NOLB
B184 HANGUL SYLLABLE NOLS
B185 HANGUL SYLLABLE NOLT
B186 HANGUL SYLLABLE NOLP
B187 HANGUL SYLLABLE NOLH
B188 HANGUL SYLLABLE NOM
B189 HANGUL SYLLABLE NOB
B18A HANGUL SYLLABLE NOBS
B18B HANGUL SYLLABLE NOS
B18C HANGUL SYLLABLE NOSS
B18D HANGUL SYLLABLE NONG
B18E HANGUL SYLLABLE NOJ
B18F HANGUL SYLLABLE NOC
B190 HANGUL SYLLABLE NOK
B191 HANGUL SYLLABLE NOT
B192 HANGUL SYLLABLE NOP
B193 HANGUL SYLLABLE NOH
B194 HANGUL SYLLABLE NWA
B195 HANGUL SYLLABLE NWAG
B196 HANGUL SYLLABLE NWAGG
B197 HANGUL SYLLABLE NWAGS
B198 HANGUL SYLLABLE NWAN
B199 HANGUL SYLLABLE NWANJ
B19A HANGUL SYLLABLE NWANH
B19B HANGUL SYLLABLE NWAD
B19C HANGUL SYLLABLE NWAL
B19D HANGUL SYLLABLE NWALG
B19E HANGUL SYLLABLE NWALM
B19F HANGUL SYLLABLE NWALB
B1A0 HANGUL SYLLABLE NWALS
B1A1 HANGUL SYLLABLE NWALT
B1A2 HANGUL SYLLABLE NWALP
B1A3 HANGUL SYLLABLE NWALH
B1A4 HANGUL SYLLABLE NWAM
B1A5 HANGUL SYLLABLE NWAB
B1A6 HANGUL SYLLABLE NWABS
B1A7 HANGUL SYLLABLE NWAS
B1A8 HANGUL SYLLABLE NWASS
B1A9 HANGUL SYLLABLE NWANG
B1AA HANGUL SYLLABLE NWAJ
B1AB HANGUL SYLLABLE NWAC
B1AC HANGUL SYLLABLE NWAK
B1AD HANGUL SYLLABLE NWAT
B1AE HANGUL SYLLABLE NWAP
B1AF HANGUL SYLLABLE NWAH
B1B0 HANGUL SYLLABLE NWAE
B1B1 HANGUL SYLLABLE NWAEG
B1B2 HANGUL SYLLABLE NWAEGG
B1B3 HANGUL SYLLABLE NWAEGS
B1B4 HANGUL SYLLABLE NWAEN
B1B5 HANGUL SYLLABLE NWAENJ
B1B6 HANGUL SYLLABLE NWAENH
B1B7 HANGUL SYLLABLE NWAED
B1B8 HANGUL SYLLABLE NWAEL
B1B9 HANGUL SYLLABLE NWAELG
B1BA HANGUL SYLLABLE NWAELM
B1BB HANGUL SYLLABLE NWAELB
B1BC HANGUL SYLLABLE NWAELS
B1BD HANGUL SYLLABLE NWAELT
B1BE HANGUL SYLLABLE NWAELP
B1BF HANGUL SYLLABLE NWAELH
B1C0 HANGUL SYLLABLE NWAEM
B1C1 HANGUL SYLLABLE NWAEB
B1C2 HANGUL SYLLABLE NWAEBS
B1C3 HANGUL SYLLABLE NWAES
B1C4 HANGUL SYLLABLE NWAESS
B1C5 HANGUL SYLLABLE NWAENG
B1C6 HANGUL SYLLABLE NWAEJ
B1C7 HANGUL SYLLABLE NWAEC
B1C8 HANGUL SYLLABLE NWAEK
B1C9 HANGUL SYLLABLE NWAET
B1CA HANGUL SYLLABLE NWAEP
B1CB HANGUL SYLLABLE NWAEH
B1CC HANGUL SYLLABLE NOE
B1CD HANGUL SYLLABLE NOEG
B1CE HANGUL SYLLABLE NOEGG
B1CF HANGUL SYLLABLE NOEGS
B1D0 HANGUL SYLLABLE NOEN
B1D1 HANGUL SYLLABLE NOENJ
B1D2 HANGUL SYLLABLE NOENH
B1D3 HANGUL SYLLABLE NOED
B1D4 HANGUL SYLLABLE NOEL
B1D5 HANGUL SYLLABLE NOELG
B1D6 HANGUL SYLLABLE NOELM
B1D7 HANGUL SYLLABLE NOELB
B1D8 HANGUL SYLLABLE NOELS
B1D9 HANGUL SYLLABLE NOELT
B1DA HANGUL SYLLABLE NOELP
B1DB HANGUL SYLLABLE NOELH
B1DC HANGUL SYLLABLE NOEM
B1DD HANGUL SYLLABLE NOEB
B1DE HANGUL SYLLABLE NOEBS
B1DF HANGUL SYLLABLE NOES
B1E0 HANGUL SYLLABLE NOESS
B1E1 HANGUL SYLLABLE NOENG
B1E2 HANGUL SYLLABLE NOEJ
B1E3 HANGUL SYLLABLE NOEC
B1E4 HANGUL SYLLABLE NOEK
B1E5 HANGUL SYLLABLE NOET
B1E6 HANGUL SYLLABLE NOEP
B1E7 HANGUL SYLLABLE NOEH
B1E8 HANGUL SYLLABLE NYO
B1E9 HANGUL SYLLABLE NYOG
B1EA HANGUL SYLLABLE NYOGG
B1EB HANGUL SYLLABLE NYOGS
B1EC HANGUL SYLLABLE NYON
B1ED HANGUL SYLLABLE NYONJ
B1EE HANGUL SYLLABLE NYONH
B1EF HANGUL SYLLABLE NYOD
B1F0 HANGUL SYLLABLE NYOL
B1F1 HANGUL SYLLABLE NYOLG
B1F2 HANGUL SYLLABLE NYOLM
B1F3 HANGUL SYLLABLE NYOLB
B1F4 HANGUL SYLLABLE NYOLS
B1F5 HANGUL SYLLABLE NYOLT
B1F6 HANGUL SYLLABLE NYOLP
B1F7 HANGUL SYLLABLE NYOLH
B1F8 HANGUL SYLLABLE NYOM
B1F9 HANGUL SYLLABLE NYOB
B1FA HANGUL SYLLABLE NYOBS
B1FB HANGUL SYLLABLE NYOS
B1FC HANGUL SYLLABLE NYOSS
B1FD HANGUL SYLLABLE NYONG
B1FE HANGUL SYLLABLE NYOJ
B1FF HANGUL SYLLABLE NYOC
B200 HANGUL SYLLABLE NYOK
B201 HANGUL SYLLABLE NYOT
B202 HANGUL SYLLABLE NYOP
B203 HANGUL SYLLABLE NYOH
B204 HANGUL SYLLABLE NU
B205 HANGUL SYLLABLE NUG
B206 HANGUL SYLLABLE NUGG
B207 HANGUL SYLLABLE NUGS
B208 HANGUL SYLLABLE NUN
B209 HANGUL SYLLABLE NUNJ
B20A HANGUL SYLLABLE NUNH
B20B HANGUL SYLLABLE NUD
B20C HANGUL SYLLABLE NUL
B20D HANGUL SYLLABLE NULG
B20E HANGUL SYLLABLE NULM
B20F HANGUL SYLLABLE NULB
B210 HANGUL SYLLABLE NULS
B211 HANGUL SYLLABLE NULT
B212 HANGUL SYLLABLE NULP
B213 HANGUL SYLLABLE NULH
B214 HANGUL SYLLABLE NUM
B215 HANGUL SYLLABLE NUB
B216 HANGUL SYLLABLE NUBS
B217 HANGUL SYLLABLE NUS
B218 HANGUL SYLLABLE NUSS
B219 HANGUL SYLLABLE NUNG
B21A HANGUL SYLLABLE NUJ
B21B HANGUL SYLLABLE NUC
B21C HANGUL SYLLABLE NUK
B21D HANGUL SYLLABLE NUT
B21E HANGUL SYLLABLE NUP
B21F HANGUL SYLLABLE NUH
B220 HANGUL SYLLABLE NWEO
B221 HANGUL SYLLABLE NWEOG
B222 HANGUL SYLLABLE NWEOGG
B223 HANGUL SYLLABLE NWEOGS
B224 HANGUL SYLLABLE NWEON
B225 HANGUL SYLLABLE NWEONJ
B226 HANGUL SYLLABLE NWEONH
B227 HANGUL SYLLABLE NWEOD
B228 HANGUL SYLLABLE NWEOL
B229 HANGUL SYLLABLE NWEOLG
B22A HANGUL SYLLABLE NWEOLM
B22B HANGUL SYLLABLE NWEOLB
B22C HANGUL SYLLABLE NWEOLS
B22D HANGUL SYLLABLE NWEOLT
B22E HANGUL SYLLABLE NWEOLP
B22F HANGUL SYLLABLE NWEOLH
B230 HANGUL SYLLABLE NWEOM
B231 HANGUL SYLLABLE NWEOB
B232 HANGUL SYLLABLE NWEOBS
B233 HANGUL SYLLABLE NWEOS
B234 HANGUL SYLLABLE NWEOSS
B235 HANGUL SYLLABLE NWEONG
B236 HANGUL SYLLABLE NWEOJ
B237 HANGUL SYLLABLE NWEOC
B238 HANGUL SYLLABLE NWEOK
B239 HANGUL SYLLABLE NWEOT
B23A HANGUL SYLLABLE NWEOP
B23B HANGUL SYLLABLE NWEOH
B23C HANGUL SYLLABLE NWE
B23D HANGUL SYLLABLE NWEG
B23E HANGUL SYLLABLE NWEGG
B23F HANGUL SYLLABLE NWEGS
B240 HANGUL SYLLABLE NWEN
B241 HANGUL SYLLABLE NWENJ
B242 HANGUL SYLLABLE NWENH
B243 HANGUL SYLLABLE NWED
B244 HANGUL SYLLABLE NWEL
B245 HANGUL SYLLABLE NWELG
B246 HANGUL SYLLABLE NWELM
B247 HANGUL SYLLABLE NWELB
B248 HANGUL SYLLABLE NWELS
B249 HANGUL SYLLABLE NWELT
B24A HANGUL SYLLABLE NWELP
B24B HANGUL SYLLABLE NWELH
B24C HANGUL SYLLABLE NWEM
B24D HANGUL SYLLABLE NWEB
B24E HANGUL SYLLABLE NWEBS
B24F HANGUL SYLLABLE NWES
B250 HANGUL SYLLABLE NWESS
B251 HANGUL SYLLABLE NWENG
B252 HANGUL SYLLABLE NWEJ
B253 HANGUL SYLLABLE NWEC
B254 HANGUL SYLLABLE NWEK
B255 HANGUL SYLLABLE NWET
B256 HANGUL SYLLABLE NWEP
B257 HANGUL SYLLABLE NWEH
B258 HANGUL SYLLABLE NWI
B259 HANGUL SYLLABLE NWIG
B25A HANGUL SYLLABLE NWIGG
B25B HANGUL SYLLABLE NWIGS
B25C HANGUL SYLLABLE NWIN
B25D HANGUL SYLLABLE NWINJ
B25E HANGUL SYLLABLE NWINH
B25F HANGUL SYLLABLE NWID
B260 HANGUL SYLLABLE NWIL
B261 HANGUL SYLLABLE NWILG
B262 HANGUL SYLLABLE NWILM
B263 HANGUL SYLLABLE NWILB
B264 HANGUL SYLLABLE NWILS
B265 HANGUL SYLLABLE NWILT
B266 HANGUL SYLLABLE NWILP
B267 HANGUL SYLLABLE NWILH
B268 HANGUL SYLLABLE NWIM
B269 HANGUL SYLLABLE NWIB
B26A HANGUL SYLLABLE NWIBS
B26B HANGUL SYLLABLE NWIS
B26C HANGUL SYLLABLE NWISS
B26D HANGUL SYLLABLE NWING
B26E HANGUL SYLLABLE NWIJ
B26F HANGUL SYLLABLE NWIC
B270 HANGUL SYLLABLE NWIK
B271 HANGUL SYLLABLE NWIT
B272 HANGUL SYLLABLE NWIP
B273 HANGUL SYLLABLE NWIH
B274 HANGUL SYLLABLE NYU
B275 HANGUL SYLLABLE NYUG
B276 HANGUL SYLLABLE NYUGG
B277 HANGUL SYLLABLE NYUGS
B278 HANGUL SYLLABLE NYUN
B279 HANGUL SYLLABLE NYUNJ
B27A HANGUL SYLLABLE NYUNH
B27B HANGUL SYLLABLE NYUD
B27C HANGUL SYLLABLE NYUL
B27D HANGUL SYLLABLE NYULG
B27E HANGUL SYLLABLE NYULM
B27F HANGUL SYLLABLE NYULB
B280 HANGUL SYLLABLE NYULS
B281 HANGUL SYLLABLE NYULT
B282 HANGUL SYLLABLE NYULP
B283 HANGUL SYLLABLE NYULH
B284 HANGUL SYLLABLE NYUM
B285 HANGUL SYLLABLE NYUB
B286 HANGUL SYLLABLE NYUBS
B287 HANGUL SYLLABLE NYUS
B288 HANGUL SYLLABLE NYUSS
B289 HANGUL SYLLABLE NYUNG
B28A HANGUL SYLLABLE NYUJ
B28B HANGUL SYLLABLE NYUC
B28C HANGUL SYLLABLE NYUK
B28D HANGUL SYLLABLE NYUT
B28E HANGUL SYLLABLE NYUP
B28F HANGUL SYLLABLE NYUH
B290 HANGUL SYLLABLE NEU
B291 HANGUL SYLLABLE NEUG
B292 HANGUL SYLLABLE NEUGG
B293 HANGUL SYLLABLE NEUGS
B294 HANGUL SYLLABLE NEUN
B295 HANGUL SYLLABLE NEUNJ
B296 HANGUL SYLLABLE NEUNH
B297 HANGUL SYLLABLE NEUD
B298 HANGUL SYLLABLE NEUL
B299 HANGUL SYLLABLE NEULG
B29A HANGUL SYLLABLE NEULM
B29B HANGUL SYLLABLE NEULB
B29C HANGUL SYLLABLE NEULS
B29D HANGUL SYLLABLE NEULT
B29E HANGUL SYLLABLE NEULP
B29F HANGUL SYLLABLE NEULH
B2A0 HANGUL SYLLABLE NEUM
B2A1 HANGUL SYLLABLE NEUB
B2A2 HANGUL SYLLABLE NEUBS
B2A3 HANGUL SYLLABLE NEUS
B2A4 HANGUL SYLLABLE NEUSS
B2A5 HANGUL SYLLABLE NEUNG
B2A6 HANGUL SYLLABLE NEUJ
B2A7 HANGUL SYLLABLE NEUC
B2A8 HANGUL SYLLABLE NEUK
B2A9 HANGUL SYLLABLE NEUT
B2AA HANGUL SYLLABLE NEUP
B2AB HANGUL SYLLABLE NEUH
B2AC HANGUL SYLLABLE NYI
B2AD HANGUL SYLLABLE NYIG
B2AE HANGUL SYLLABLE NYIGG
B2AF HANGUL SYLLABLE NYIGS
B2B0 HANGUL SYLLABLE NYIN
B2B1 HANGUL SYLLABLE NYINJ
B2B2 HANGUL SYLLABLE NYINH
B2B3 HANGUL SYLLABLE NYID
B2B4 HANGUL SYLLABLE NYIL
B2B5 HANGUL SYLLABLE NYILG
B2B6 HANGUL SYLLABLE NYILM
B2B7 HANGUL SYLLABLE NYILB
B2B8 HANGUL SYLLABLE NYILS
B2B9 HANGUL SYLLABLE NYILT
B2BA HANGUL SYLLABLE NYILP
B2BB HANGUL SYLLABLE NYILH
B2BC HANGUL SYLLABLE NYIM
B2BD HANGUL SYLLABLE NYIB
B2BE HANGUL SYLLABLE NYIBS
B2BF HANGUL SYLLABLE NYIS
B2C0 HANGUL SYLLABLE NYISS
B2C1 HANGUL SYLLABLE NYING
B2C2 HANGUL SYLLABLE NYIJ
B2C3 HANGUL SYLLABLE NYIC
B2C4 HANGUL SYLLABLE NYIK
B2C5 HANGUL SYLLABLE NYIT
B2C6 HANGUL SYLLABLE NYIP
B2C7 HANGUL SYLLABLE NYIH
B2C8 HANGUL SYLLABLE NI
B2C9 HANGUL SYLLABLE NIG
B2CA HANGUL SYLLABLE NIGG
B2CB HANGUL SYLLABLE NIGS
B2CC HANGUL SYLLABLE NIN
B2CD HANGUL SYLLABLE NINJ
B2CE HANGUL SYLLABLE NINH
B2CF HANGUL SYLLABLE NID
B2D0 HANGUL SYLLABLE NIL
B2D1 HANGUL SYLLABLE NILG
B2D2 HANGUL SYLLABLE NILM
B2D3 HANGUL SYLLABLE NILB
B2D4 HANGUL SYLLABLE NILS
B2D5 HANGUL SYLLABLE NILT
B2D6 HANGUL SYLLABLE NILP
B2D7 HANGUL SYLLABLE NILH
B2D8 HANGUL SYLLABLE NIM
B2D9 HANGUL SYLLABLE NIB
B2DA HANGUL SYLLABLE NIBS
B2DB HANGUL SYLLABLE NIS
B2DC HANGUL SYLLABLE NISS
B2DD HANGUL SYLLABLE NING
B2DE HANGUL SYLLABLE NIJ
B2DF HANGUL SYLLABLE NIC
B2E0 HANGUL SYLLABLE NIK
B2E1 HANGUL SYLLABLE NIT
B2E2 HANGUL SYLLABLE NIP
B2E3 HANGUL SYLLABLE NIH
B2E4 HANGUL SYLLABLE DA
B2E5 HANGUL SYLLABLE DAG
B2E6 HANGUL SYLLABLE DAGG
B2E7 HANGUL SYLLABLE DAGS
B2E8 HANGUL SYLLABLE DAN
B2E9 HANGUL SYLLABLE DANJ
B2EA HANGUL SYLLABLE DANH
B2EB HANGUL SYLLABLE DAD
B2EC HANGUL SYLLABLE DAL
B2ED HANGUL SYLLABLE DALG
B2EE HANGUL SYLLABLE DALM
B2EF HANGUL SYLLABLE DALB
B2F0 HANGUL SYLLABLE DALS
B2F1 HANGUL SYLLABLE DALT
B2F2 HANGUL SYLLABLE DALP
B2F3 HANGUL SYLLABLE DALH
B2F4 HANGUL SYLLABLE DAM
B2F5 HANGUL SYLLABLE DAB
B2F6 HANGUL SYLLABLE DABS
B2F7 HANGUL SYLLABLE DAS
B2F8 HANGUL SYLLABLE DASS
B2F9 HANGUL SYLLABLE DANG
B2FA HANGUL SYLLABLE DAJ
B2FB HANGUL SYLLABLE DAC
B2FC HANGUL SYLLABLE DAK
B2FD HANGUL SYLLABLE DAT
B2FE HANGUL SYLLABLE DAP
B2FF HANGUL SYLLABLE DAH
B300 HANGUL SYLLABLE DAE
B301 HANGUL SYLLABLE DAEG
B302 HANGUL SYLLABLE DAEGG
B303 HANGUL SYLLABLE DAEGS
B304 HANGUL SYLLABLE DAEN
B305 HANGUL SYLLABLE DAENJ
B306 HANGUL SYLLABLE DAENH
B307 HANGUL SYLLABLE DAED
B308 HANGUL SYLLABLE DAEL
B309 HANGUL SYLLABLE DAELG
B30A HANGUL SYLLABLE DAELM
B30B HANGUL SYLLABLE DAELB
B30C HANGUL SYLLABLE DAELS
B30D HANGUL SYLLABLE DAELT
B30E HANGUL SYLLABLE DAELP
B30F HANGUL SYLLABLE DAELH
B310 HANGUL SYLLABLE DAEM
B311 HANGUL SYLLABLE DAEB
B312 HANGUL SYLLABLE DAEBS
B313 HANGUL SYLLABLE DAES
B314 HANGUL SYLLABLE DAESS
B315 HANGUL SYLLABLE DAENG
B316 HANGUL SYLLABLE DAEJ
B317 HANGUL SYLLABLE DAEC
B318 HANGUL SYLLABLE DAEK
B319 HANGUL SYLLABLE DAET
B31A HANGUL SYLLABLE DAEP
B31B HANGUL SYLLABLE DAEH
B31C HANGUL SYLLABLE DYA
B31D HANGUL SYLLABLE DYAG
B31E HANGUL SYLLABLE DYAGG
B31F HANGUL SYLLABLE DYAGS
B320 HANGUL SYLLABLE DYAN
B321 HANGUL SYLLABLE DYANJ
B322 HANGUL SYLLABLE DYANH
B323 HANGUL SYLLABLE DYAD
B324 HANGUL SYLLABLE DYAL
B325 HANGUL SYLLABLE DYALG
B326 HANGUL SYLLABLE DYALM
B327 HANGUL SYLLABLE DYALB
B328 HANGUL SYLLABLE DYALS
B329 HANGUL SYLLABLE DYALT
B32A HANGUL SYLLABLE DYALP
B32B HANGUL SYLLABLE DYALH
B32C HANGUL SYLLABLE DYAM
B32D HANGUL SYLLABLE DYAB
B32E HANGUL SYLLABLE DYABS
B32F HANGUL SYLLABLE DYAS
B330 HANGUL SYLLABLE DYASS
B331 HANGUL SYLLABLE DYANG
B332 HANGUL SYLLABLE DYAJ
B333 HANGUL SYLLABLE DYAC
B334 HANGUL SYLLABLE DYAK
B335 HANGUL SYLLABLE DYAT
B336 HANGUL SYLLABLE DYAP
B337 HANGUL SYLLABLE DYAH
B338 HANGUL SYLLABLE DYAE
B339 HANGUL SYLLABLE DYAEG
B33A HANGUL SYLLABLE DYAEGG
B33B HANGUL SYLLABLE DYAEGS
B33C HANGUL SYLLABLE DYAEN
B33D HANGUL SYLLABLE DYAENJ
B33E HANGUL SYLLABLE DYAENH
B33F HANGUL SYLLABLE DYAED
B340 HANGUL SYLLABLE DYAEL
B341 HANGUL SYLLABLE DYAELG
B342 HANGUL SYLLABLE DYAELM
B343 HANGUL SYLLABLE DYAELB
B344 HANGUL SYLLABLE DYAELS
B345 HANGUL SYLLABLE DYAELT
B346 HANGUL SYLLABLE DYAELP
B347 HANGUL SYLLABLE DYAELH
B348 HANGUL SYLLABLE DYAEM
B349 HANGUL SYLLABLE DYAEB
B34A HANGUL SYLLABLE DYAEBS
B34B HANGUL SYLLABLE DYAES
B34C HANGUL SYLLABLE DYAESS
B34D HANGUL SYLLABLE DYAENG
B34E HANGUL SYLLABLE DYAEJ
B34F HANGUL SYLLABLE DYAEC
B350 HANGUL SYLLABLE DYAEK
B351 HANGUL SYLLABLE DYAET
B352 HANGUL SYLLABLE DYAEP
B353 HANGUL SYLLABLE DYAEH
B354 HANGUL SYLLABLE DEO
B355 HANGUL SYLLABLE DEOG
B356 HANGUL SYLLABLE DEOGG
B357 HANGUL SYLLABLE DEOGS
B358 HANGUL SYLLABLE DEON
B359 HANGUL SYLLABLE DEONJ
B35A HANGUL SYLLABLE DEONH
B35B HANGUL SYLLABLE DEOD
B35C HANGUL SYLLABLE DEOL
B35D HANGUL SYLLABLE DEOLG
B35E HANGUL SYLLABLE DEOLM
B35F HANGUL SYLLABLE DEOLB
B360 HANGUL SYLLABLE DEOLS
B361 HANGUL SYLLABLE DEOLT
B362 HANGUL SYLLABLE DEOLP
B363 HANGUL SYLLABLE DEOLH
B364 HANGUL SYLLABLE DEOM
B365 HANGUL SYLLABLE DEOB
B366 HANGUL SYLLABLE DEOBS
B367 HANGUL SYLLABLE DEOS
B368 HANGUL SYLLABLE DEOSS
B369 HANGUL SYLLABLE DEONG
B36A HANGUL SYLLABLE DEOJ
B36B HANGUL SYLLABLE DEOC
B36C HANGUL SYLLABLE DEOK
B36D HANGUL SYLLABLE DEOT
B36E HANGUL SYLLABLE DEOP
B36F HANGUL SYLLABLE DEOH
B370 HANGUL SYLLABLE DE
B371 HANGUL SYLLABLE DEG
B372 HANGUL SYLLABLE DEGG
B373 HANGUL SYLLABLE DEGS
B374 HANGUL SYLLABLE DEN
B375 HANGUL SYLLABLE DENJ
B376 HANGUL SYLLABLE DENH
B377 HANGUL SYLLABLE DED
B378 HANGUL SYLLABLE DEL
B379 HANGUL SYLLABLE DELG
B37A HANGUL SYLLABLE DELM
B37B HANGUL SYLLABLE DELB
B37C HANGUL SYLLABLE DELS
B37D HANGUL SYLLABLE DELT
B37E HANGUL SYLLABLE DELP
B37F HANGUL SYLLABLE DELH
B380 HANGUL SYLLABLE DEM
B381 HANGUL SYLLABLE DEB
B382 HANGUL SYLLABLE DEBS
B383 HANGUL SYLLABLE DES
B384 HANGUL SYLLABLE DESS
B385 HANGUL SYLLABLE DENG
B386 HANGUL SYLLABLE DEJ
B387 HANGUL SYLLABLE DEC
B388 HANGUL SYLLABLE DEK
B389 HANGUL SYLLABLE DET
B38A HANGUL SYLLABLE DEP
B38B HANGUL SYLLABLE DEH
B38C HANGUL SYLLABLE DYEO
B38D HANGUL SYLLABLE DYEOG
B38E HANGUL SYLLABLE DYEOGG
B38F HANGUL SYLLABLE DYEOGS
B390 HANGUL SYLLABLE DYEON
B391 HANGUL SYLLABLE DYEONJ
B392 HANGUL SYLLABLE DYEONH
B393 HANGUL SYLLABLE DYEOD
B394 HANGUL SYLLABLE DYEOL
B395 HANGUL SYLLABLE DYEOLG
B396 HANGUL SYLLABLE DYEOLM
B397 HANGUL SYLLABLE DYEOLB
B398 HANGUL SYLLABLE DYEOLS
B399 HANGUL SYLLABLE DYEOLT
B39A HANGUL SYLLABLE DYEOLP
B39B HANGUL SYLLABLE DYEOLH
B39C HANGUL SYLLABLE DYEOM
B39D HANGUL SYLLABLE DYEOB
B39E HANGUL SYLLABLE DYEOBS
B39F HANGUL SYLLABLE DYEOS
B3A0 HANGUL SYLLABLE DYEOSS
B3A1 HANGUL SYLLABLE DYEONG
B3A2 HANGUL SYLLABLE DYEOJ
B3A3 HANGUL SYLLABLE DYEOC
B3A4 HANGUL SYLLABLE DYEOK
B3A5 HANGUL SYLLABLE DYEOT
B3A6 HANGUL SYLLABLE DYEOP
B3A7 HANGUL SYLLABLE DYEOH
B3A8 HANGUL SYLLABLE DYE
B3A9 HANGUL SYLLABLE DYEG
B3AA HANGUL SYLLABLE DYEGG
B3AB HANGUL SYLLABLE DYEGS
B3AC HANGUL SYLLABLE DYEN
B3AD HANGUL SYLLABLE DYENJ
B3AE HANGUL SYLLABLE DYENH
B3AF HANGUL SYLLABLE DYED
B3B0 HANGUL SYLLABLE DYEL
B3B1 HANGUL SYLLABLE DYELG
B3B2 HANGUL SYLLABLE DYELM
B3B3 HANGUL SYLLABLE DYELB
B3B4 HANGUL SYLLABLE DYELS
B3B5 HANGUL SYLLABLE DYELT
B3B6 HANGUL SYLLABLE DYELP
B3B7 HANGUL SYLLABLE DYELH
B3B8 HANGUL SYLLABLE DYEM
B3B9 HANGUL SYLLABLE DYEB
B3BA HANGUL SYLLABLE DYEBS
B3BB HANGUL SYLLABLE DYES
B3BC HANGUL SYLLABLE DYESS
B3BD HANGUL SYLLABLE DYENG
B3BE HANGUL SYLLABLE DYEJ
B3BF HANGUL SYLLABLE DYEC
B3C0 HANGUL SYLLABLE DYEK
B3C1 HANGUL SYLLABLE DYET
B3C2 HANGUL SYLLABLE DYEP
B3C3 HANGUL SYLLABLE DYEH
B3C4 HANGUL SYLLABLE DO
B3C5 HANGUL SYLLABLE DOG
B3C6 HANGUL SYLLABLE DOGG
B3C7 HANGUL SYLLABLE DOGS
B3C8 HANGUL SYLLABLE DON
B3C9 HANGUL SYLLABLE DONJ
B3CA HANGUL SYLLABLE DONH
B3CB HANGUL SYLLABLE DOD
B3CC HANGUL SYLLABLE DOL
B3CD HANGUL SYLLABLE DOLG
B3CE HANGUL SYLLABLE DOLM
B3CF HANGUL SYLLABLE DOLB
B3D0 HANGUL SYLLABLE DOLS
B3D1 HANGUL SYLLABLE DOLT
B3D2 HANGUL SYLLABLE DOLP
B3D3 HANGUL SYLLABLE DOLH
B3D4 HANGUL SYLLABLE DOM
B3D5 HANGUL SYLLABLE DOB
B3D6 HANGUL SYLLABLE DOBS
B3D7 HANGUL SYLLABLE DOS
B3D8 HANGUL SYLLABLE DOSS
B3D9 HANGUL SYLLABLE DONG
B3DA HANGUL SYLLABLE DOJ
B3DB HANGUL SYLLABLE DOC
B3DC HANGUL SYLLABLE DOK
B3DD HANGUL SYLLABLE DOT
B3DE HANGUL SYLLABLE DOP
B3DF HANGUL SYLLABLE DOH
B3E0 HANGUL SYLLABLE DWA
B3E1 HANGUL SYLLABLE DWAG
B3E2 HANGUL SYLLABLE DWAGG
B3E3 HANGUL SYLLABLE DWAGS
B3E4 HANGUL SYLLABLE DWAN
B3E5 HANGUL SYLLABLE DWANJ
B3E6 HANGUL SYLLABLE DWANH
B3E7 HANGUL SYLLABLE DWAD
B3E8 HANGUL SYLLABLE DWAL
B3E9 HANGUL SYLLABLE DWALG
B3EA HANGUL SYLLABLE DWALM
B3EB HANGUL SYLLABLE DWALB
B3EC HANGUL SYLLABLE DWALS
B3ED HANGUL SYLLABLE DWALT
B3EE HANGUL SYLLABLE DWALP
B3EF HANGUL SYLLABLE DWALH
B3F0 HANGUL SYLLABLE DWAM
B3F1 HANGUL SYLLABLE DWAB
B3F2 HANGUL SYLLABLE DWABS
B3F3 HANGUL SYLLABLE DWAS
B3F4 HANGUL SYLLABLE DWASS
B3F5 HANGUL SYLLABLE DWANG
B3F6 HANGUL SYLLABLE DWAJ
B3F7 HANGUL SYLLABLE DWAC
B3F8 HANGUL SYLLABLE DWAK
B3F9 HANGUL SYLLABLE DWAT
B3FA HANGUL SYLLABLE DWAP
B3FB HANGUL SYLLABLE DWAH
B3FC HANGUL SYLLABLE DWAE
B3FD HANGUL SYLLABLE DWAEG
B3FE HANGUL SYLLABLE DWAEGG
B3FF HANGUL SYLLABLE DWAEGS
B400 HANGUL SYLLABLE DWAEN
B401 HANGUL SYLLABLE DWAENJ
B402 HANGUL SYLLABLE DWAENH
B403 HANGUL SYLLABLE DWAED
B404 HANGUL SYLLABLE DWAEL
B405 HANGUL SYLLABLE DWAELG
B406 HANGUL SYLLABLE DWAELM
B407 HANGUL SYLLABLE DWAELB
B408 HANGUL SYLLABLE DWAELS
B409 HANGUL SYLLABLE DWAELT
B40A HANGUL SYLLABLE DWAELP
B40B HANGUL SYLLABLE DWAELH
B40C HANGUL SYLLABLE DWAEM
B40D HANGUL SYLLABLE DWAEB
B40E HANGUL SYLLABLE DWAEBS
B40F HANGUL SYLLABLE DWAES
B410 HANGUL SYLLABLE DWAESS
B411 HANGUL SYLLABLE DWAENG
B412 HANGUL SYLLABLE DWAEJ
B413 HANGUL SYLLABLE DWAEC
B414 HANGUL SYLLABLE DWAEK
B415 HANGUL SYLLABLE DWAET
B416 HANGUL SYLLABLE DWAEP
B417 HANGUL SYLLABLE DWAEH
B418 HANGUL SYLLABLE DOE
B419 HANGUL SYLLABLE DOEG
B41A HANGUL SYLLABLE DOEGG
B41B HANGUL SYLLABLE DOEGS
B41C HANGUL SYLLABLE DOEN
B41D HANGUL SYLLABLE DOENJ
B41E HANGUL SYLLABLE DOENH
B41F HANGUL SYLLABLE DOED
B420 HANGUL SYLLABLE DOEL
B421 HANGUL SYLLABLE DOELG
B422 HANGUL SYLLABLE DOELM
B423 HANGUL SYLLABLE DOELB
B424 HANGUL SYLLABLE DOELS
B425 HANGUL SYLLABLE DOELT
B426 HANGUL SYLLABLE DOELP
B427 HANGUL SYLLABLE DOELH
B428 HANGUL SYLLABLE DOEM
B429 HANGUL SYLLABLE DOEB
B42A HANGUL SYLLABLE DOEBS
B42B HANGUL SYLLABLE DOES
B42C HANGUL SYLLABLE DOESS
B42D HANGUL SYLLABLE DOENG
B42E HANGUL SYLLABLE DOEJ
B42F HANGUL SYLLABLE DOEC
B430 HANGUL SYLLABLE DOEK
B431 HANGUL SYLLABLE DOET
B432 HANGUL SYLLABLE DOEP
B433 HANGUL SYLLABLE DOEH
B434 HANGUL SYLLABLE DYO
B435 HANGUL SYLLABLE DYOG
B436 HANGUL SYLLABLE DYOGG
B437 HANGUL SYLLABLE DYOGS
B438 HANGUL SYLLABLE DYON
B439 HANGUL SYLLABLE DYONJ
B43A HANGUL SYLLABLE DYONH
B43B HANGUL SYLLABLE DYOD
B43C HANGUL SYLLABLE DYOL
B43D HANGUL SYLLABLE DYOLG
B43E HANGUL SYLLABLE DYOLM
B43F HANGUL SYLLABLE DYOLB
B440 HANGUL SYLLABLE DYOLS
B441 HANGUL SYLLABLE DYOLT
B442 HANGUL SYLLABLE DYOLP
B443 HANGUL SYLLABLE DYOLH
B444 HANGUL SYLLABLE DYOM
B445 HANGUL SYLLABLE DYOB
B446 HANGUL SYLLABLE DYOBS
B447 HANGUL SYLLABLE DYOS
B448 HANGUL SYLLABLE DYOSS
B449 HANGUL SYLLABLE DYONG
B44A HANGUL SYLLABLE DYOJ
B44B HANGUL SYLLABLE DYOC
B44C HANGUL SYLLABLE DYOK
B44D HANGUL SYLLABLE DYOT
B44E HANGUL SYLLABLE DYOP
B44F HANGUL SYLLABLE DYOH
B450 HANGUL SYLLABLE DU
B451 HANGUL SYLLABLE DUG
B452 HANGUL SYLLABLE DUGG
B453 HANGUL SYLLABLE DUGS
B454 HANGUL SYLLABLE DUN
B455 HANGUL SYLLABLE DUNJ
B456 HANGUL SYLLABLE DUNH
B457 HANGUL SYLLABLE DUD
B458 HANGUL SYLLABLE DUL
B459 HANGUL SYLLABLE DULG
B45A HANGUL SYLLABLE DULM
B45B HANGUL SYLLABLE DULB
B45C HANGUL SYLLABLE DULS
B45D HANGUL SYLLABLE DULT
B45E HANGUL SYLLABLE DULP
B45F HANGUL SYLLABLE DULH
B460 HANGUL SYLLABLE DUM
B461 HANGUL SYLLABLE DUB
B462 HANGUL SYLLABLE DUBS
B463 HANGUL SYLLABLE DUS
B464 HANGUL SYLLABLE DUSS
B465 HANGUL SYLLABLE DUNG
B466 HANGUL SYLLABLE DUJ
B467 HANGUL SYLLABLE DUC
B468 HANGUL SYLLABLE DUK
B469 HANGUL SYLLABLE DUT
B46A HANGUL SYLLABLE DUP
B46B HANGUL SYLLABLE DUH
B46C HANGUL SYLLABLE DWEO
B46D HANGUL SYLLABLE DWEOG
B46E HANGUL SYLLABLE DWEOGG
B46F HANGUL SYLLABLE DWEOGS
B470 HANGUL SYLLABLE DWEON
B471 HANGUL SYLLABLE DWEONJ
B472 HANGUL SYLLABLE DWEONH
B473 HANGUL SYLLABLE DWEOD
B474 HANGUL SYLLABLE DWEOL
B475 HANGUL SYLLABLE DWEOLG
B476 HANGUL SYLLABLE DWEOLM
B477 HANGUL SYLLABLE DWEOLB
B478 HANGUL SYLLABLE DWEOLS
B479 HANGUL SYLLABLE DWEOLT
B47A HANGUL SYLLABLE DWEOLP
B47B HANGUL SYLLABLE DWEOLH
B47C HANGUL SYLLABLE DWEOM
B47D HANGUL SYLLABLE DWEOB
B47E HANGUL SYLLABLE DWEOBS
B47F HANGUL SYLLABLE DWEOS
B480 HANGUL SYLLABLE DWEOSS
B481 HANGUL SYLLABLE DWEONG
B482 HANGUL SYLLABLE DWEOJ
B483 HANGUL SYLLABLE DWEOC
B484 HANGUL SYLLABLE DWEOK
B485 HANGUL SYLLABLE DWEOT
B486 HANGUL SYLLABLE DWEOP
B487 HANGUL SYLLABLE DWEOH
B488 HANGUL SYLLABLE DWE
B489 HANGUL SYLLABLE DWEG
B48A HANGUL SYLLABLE DWEGG
B48B HANGUL SYLLABLE DWEGS
B48C HANGUL SYLLABLE DWEN
B48D HANGUL SYLLABLE DWENJ
B48E HANGUL SYLLABLE DWENH
B48F HANGUL SYLLABLE DWED
B490 HANGUL SYLLABLE DWEL
B491 HANGUL SYLLABLE DWELG
B492 HANGUL SYLLABLE DWELM
B493 HANGUL SYLLABLE DWELB
B494 HANGUL SYLLABLE DWELS
B495 HANGUL SYLLABLE DWELT
B496 HANGUL SYLLABLE DWELP
B497 HANGUL SYLLABLE DWELH
B498 HANGUL SYLLABLE DWEM
B499 HANGUL SYLLABLE DWEB
B49A HANGUL SYLLABLE DWEBS
B49B HANGUL SYLLABLE DWES
B49C HANGUL SYLLABLE DWESS
B49D HANGUL SYLLABLE DWENG
B49E HANGUL SYLLABLE DWEJ
B49F HANGUL SYLLABLE DWEC
B4A0 HANGUL SYLLABLE DWEK
B4A1 HANGUL SYLLABLE DWET
B4A2 HANGUL SYLLABLE DWEP
B4A3 HANGUL SYLLABLE DWEH
B4A4 HANGUL SYLLABLE DWI
B4A5 HANGUL SYLLABLE DWIG
B4A6 HANGUL SYLLABLE DWIGG
B4A7 HANGUL SYLLABLE DWIGS
B4A8 HANGUL SYLLABLE DWIN
B4A9 HANGUL SYLLABLE DWINJ
B4AA HANGUL SYLLABLE DWINH
B4AB HANGUL SYLLABLE DWID
B4AC HANGUL SYLLABLE DWIL
B4AD HANGUL SYLLABLE DWILG
B4AE HANGUL SYLLABLE DWILM
B4AF HANGUL SYLLABLE DWILB
B4B0 HANGUL SYLLABLE DWILS
B4B1 HANGUL SYLLABLE DWILT
B4B2 HANGUL SYLLABLE DWILP
B4B3 HANGUL SYLLABLE DWILH
B4B4 HANGUL SYLLABLE DWIM
B4B5 HANGUL SYLLABLE DWIB
B4B6 HANGUL SYLLABLE DWIBS
B4B7 HANGUL SYLLABLE DWIS
B4B8 HANGUL SYLLABLE DWISS
B4B9 HANGUL SYLLABLE DWING
B4BA HANGUL SYLLABLE DWIJ
B4BB HANGUL SYLLABLE DWIC
B4BC HANGUL SYLLABLE DWIK
B4BD HANGUL SYLLABLE DWIT
B4BE HANGUL SYLLABLE DWIP
B4BF HANGUL SYLLABLE DWIH
B4C0 HANGUL SYLLABLE DYU
B4C1 HANGUL SYLLABLE DYUG
B4C2 HANGUL SYLLABLE DYUGG
B4C3 HANGUL SYLLABLE DYUGS
B4C4 HANGUL SYLLABLE DYUN
B4C5 HANGUL SYLLABLE DYUNJ
B4C6 HANGUL SYLLABLE DYUNH
B4C7 HANGUL SYLLABLE DYUD
B4C8 HANGUL SYLLABLE DYUL
B4C9 HANGUL SYLLABLE DYULG
B4CA HANGUL SYLLABLE DYULM
B4CB HANGUL SYLLABLE DYULB
B4CC HANGUL SYLLABLE DYULS
B4CD HANGUL SYLLABLE DYULT
B4CE HANGUL SYLLABLE DYULP
B4CF HANGUL SYLLABLE DYULH
B4D0 HANGUL SYLLABLE DYUM
B4D1 HANGUL SYLLABLE DYUB
B4D2 HANGUL SYLLABLE DYUBS
B4D3 HANGUL SYLLABLE DYUS
B4D4 HANGUL SYLLABLE DYUSS
B4D5 HANGUL SYLLABLE DYUNG
B4D6 HANGUL SYLLABLE DYUJ
B4D7 HANGUL SYLLABLE DYUC
B4D8 HANGUL SYLLABLE DYUK
B4D9 HANGUL SYLLABLE DYUT
B4DA HANGUL SYLLABLE DYUP
B4DB HANGUL SYLLABLE DYUH
B4DC HANGUL SYLLABLE DEU
B4DD HANGUL SYLLABLE DEUG
B4DE HANGUL SYLLABLE DEUGG
B4DF HANGUL SYLLABLE DEUGS
B4E0 HANGUL SYLLABLE DEUN
B4E1 HANGUL SYLLABLE DEUNJ
B4E2 HANGUL SYLLABLE DEUNH
B4E3 HANGUL SYLLABLE DEUD
B4E4 HANGUL SYLLABLE DEUL
B4E5 HANGUL SYLLABLE DEULG
B4E6 HANGUL SYLLABLE DEULM
B4E7 HANGUL SYLLABLE DEULB
B4E8 HANGUL SYLLABLE DEULS
B4E9 HANGUL SYLLABLE DEULT
B4EA HANGUL SYLLABLE DEULP
B4EB HANGUL SYLLABLE DEULH
B4EC HANGUL SYLLABLE DEUM
B4ED HANGUL SYLLABLE DEUB
B4EE HANGUL SYLLABLE DEUBS
B4EF HANGUL SYLLABLE DEUS
B4F0 HANGUL SYLLABLE DEUSS
B4F1 HANGUL SYLLABLE DEUNG
B4F2 HANGUL SYLLABLE DEUJ
B4F3 HANGUL SYLLABLE DEUC
B4F4 HANGUL SYLLABLE DEUK
B4F5 HANGUL SYLLABLE DEUT
B4F6 HANGUL SYLLABLE DEUP
B4F7 HANGUL SYLLABLE DEUH
B4F8 HANGUL SYLLABLE DYI
B4F9 HANGUL SYLLABLE DYIG
B4FA HANGUL SYLLABLE DYIGG
B4FB HANGUL SYLLABLE DYIGS
B4FC HANGUL SYLLABLE DYIN
B4FD HANGUL SYLLABLE DYINJ
B4FE HANGUL SYLLABLE DYINH
B4FF HANGUL SYLLABLE DYID
B500 HANGUL SYLLABLE DYIL
B501 HANGUL SYLLABLE DYILG
B502 HANGUL SYLLABLE DYILM
B503 HANGUL SYLLABLE DYILB
B504 HANGUL SYLLABLE DYILS
B505 HANGUL SYLLABLE DYILT
B506 HANGUL SYLLABLE DYILP
B507 HANGUL SYLLABLE DYILH
B508 HANGUL SYLLABLE DYIM
B509 HANGUL SYLLABLE DYIB
B50A HANGUL SYLLABLE DYIBS
B50B HANGUL SYLLABLE DYIS
B50C HANGUL SYLLABLE DYISS
B50D HANGUL SYLLABLE DYING
B50E HANGUL SYLLABLE DYIJ
B50F HANGUL SYLLABLE DYIC
B510 HANGUL SYLLABLE DYIK
B511 HANGUL SYLLABLE DYIT
B512 HANGUL SYLLABLE DYIP
B513 HANGUL SYLLABLE DYIH
B514 HANGUL SYLLABLE DI
B515 HANGUL SYLLABLE DIG
B516 HANGUL SYLLABLE DIGG
B517 HANGUL SYLLABLE DIGS
B518 HANGUL SYLLABLE DIN
B519 HANGUL SYLLABLE DINJ
B51A HANGUL SYLLABLE DINH
B51B HANGUL SYLLABLE DID
B51C HANGUL SYLLABLE DIL
B51D HANGUL SYLLABLE DILG
B51E HANGUL SYLLABLE DILM
B51F HANGUL SYLLABLE DILB
B520 HANGUL SYLLABLE DILS
B521 HANGUL SYLLABLE DILT
B522 HANGUL SYLLABLE DILP
B523 HANGUL SYLLABLE DILH
B524 HANGUL SYLLABLE DIM
B525 HANGUL SYLLABLE DIB
B526 HANGUL SYLLABLE DIBS
B527 HANGUL SYLLABLE DIS
B528 HANGUL SYLLABLE DISS
B529 HANGUL SYLLABLE DING
B52A HANGUL SYLLABLE DIJ
B52B HANGUL SYLLABLE DIC
B52C HANGUL SYLLABLE DIK
B52D HANGUL SYLLABLE DIT
B52E HANGUL SYLLABLE DIP
B52F HANGUL SYLLABLE DIH
B530 HANGUL SYLLABLE DDA
B531 HANGUL SYLLABLE DDAG
B532 HANGUL SYLLABLE DDAGG
B533 HANGUL SYLLABLE DDAGS
B534 HANGUL SYLLABLE DDAN
B535 HANGUL SYLLABLE DDANJ
B536 HANGUL SYLLABLE DDANH
B537 HANGUL SYLLABLE DDAD
B538 HANGUL SYLLABLE DDAL
B539 HANGUL SYLLABLE DDALG
B53A HANGUL SYLLABLE DDALM
B53B HANGUL SYLLABLE DDALB
B53C HANGUL SYLLABLE DDALS
B53D HANGUL SYLLABLE DDALT
B53E HANGUL SYLLABLE DDALP
B53F HANGUL SYLLABLE DDALH
B540 HANGUL SYLLABLE DDAM
B541 HANGUL SYLLABLE DDAB
B542 HANGUL SYLLABLE DDABS
B543 HANGUL SYLLABLE DDAS
B544 HANGUL SYLLABLE DDASS
B545 HANGUL SYLLABLE DDANG
B546 HANGUL SYLLABLE DDAJ
B547 HANGUL SYLLABLE DDAC
B548 HANGUL SYLLABLE DDAK
B549 HANGUL SYLLABLE DDAT
B54A HANGUL SYLLABLE DDAP
B54B HANGUL SYLLABLE DDAH
B54C HANGUL SYLLABLE DDAE
B54D HANGUL SYLLABLE DDAEG
B54E HANGUL SYLLABLE DDAEGG
B54F HANGUL SYLLABLE DDAEGS
B550 HANGUL SYLLABLE DDAEN
B551 HANGUL SYLLABLE DDAENJ
B552 HANGUL SYLLABLE DDAENH
B553 HANGUL SYLLABLE DDAED
B554 HANGUL SYLLABLE DDAEL
B555 HANGUL SYLLABLE DDAELG
B556 HANGUL SYLLABLE DDAELM
B557 HANGUL SYLLABLE DDAELB
B558 HANGUL SYLLABLE DDAELS
B559 HANGUL SYLLABLE DDAELT
B55A HANGUL SYLLABLE DDAELP
B55B HANGUL SYLLABLE DDAELH
B55C HANGUL SYLLABLE DDAEM
B55D HANGUL SYLLABLE DDAEB
B55E HANGUL SYLLABLE DDAEBS
B55F HANGUL SYLLABLE DDAES
B560 HANGUL SYLLABLE DDAESS
B561 HANGUL SYLLABLE DDAENG
B562 HANGUL SYLLABLE DDAEJ
B563 HANGUL SYLLABLE DDAEC
B564 HANGUL SYLLABLE DDAEK
B565 HANGUL SYLLABLE DDAET
B566 HANGUL SYLLABLE DDAEP
B567 HANGUL SYLLABLE DDAEH
B568 HANGUL SYLLABLE DDYA
B569 HANGUL SYLLABLE DDYAG
B56A HANGUL SYLLABLE DDYAGG
B56B HANGUL SYLLABLE DDYAGS
B56C HANGUL SYLLABLE DDYAN
B56D HANGUL SYLLABLE DDYANJ
B56E HANGUL SYLLABLE DDYANH
B56F HANGUL SYLLABLE DDYAD
B570 HANGUL SYLLABLE DDYAL
B571 HANGUL SYLLABLE DDYALG
B572 HANGUL SYLLABLE DDYALM
B573 HANGUL SYLLABLE DDYALB
B574 HANGUL SYLLABLE DDYALS
B575 HANGUL SYLLABLE DDYALT
B576 HANGUL SYLLABLE DDYALP
B577 HANGUL SYLLABLE DDYALH
B578 HANGUL SYLLABLE DDYAM
B579 HANGUL SYLLABLE DDYAB
B57A HANGUL SYLLABLE DDYABS
B57B HANGUL SYLLABLE DDYAS
B57C HANGUL SYLLABLE DDYASS
B57D HANGUL SYLLABLE DDYANG
B57E HANGUL SYLLABLE DDYAJ
B57F HANGUL SYLLABLE DDYAC
B580 HANGUL SYLLABLE DDYAK
B581 HANGUL SYLLABLE DDYAT
B582 HANGUL SYLLABLE DDYAP
B583 HANGUL SYLLABLE DDYAH
B584 HANGUL SYLLABLE DDYAE
B585 HANGUL SYLLABLE DDYAEG
B586 HANGUL SYLLABLE DDYAEGG
B587 HANGUL SYLLABLE DDYAEGS
B588 HANGUL SYLLABLE DDYAEN
B589 HANGUL SYLLABLE DDYAENJ
B58A HANGUL SYLLABLE DDYAENH
B58B HANGUL SYLLABLE DDYAED
B58C HANGUL SYLLABLE DDYAEL
B58D HANGUL SYLLABLE DDYAELG
B58E HANGUL SYLLABLE DDYAELM
B58F HANGUL SYLLABLE DDYAELB
B590 HANGUL SYLLABLE DDYAELS
B591 HANGUL SYLLABLE DDYAELT
B592 HANGUL SYLLABLE DDYAELP
B593 HANGUL SYLLABLE DDYAELH
B594 HANGUL SYLLABLE DDYAEM
B595 HANGUL SYLLABLE DDYAEB
B596 HANGUL SYLLABLE DDYAEBS
B597 HANGUL SYLLABLE DDYAES
B598 HANGUL SYLLABLE DDYAESS
B599 HANGUL SYLLABLE DDYAENG
B59A HANGUL SYLLABLE DDYAEJ
B59B HANGUL SYLLABLE DDYAEC
B59C HANGUL SYLLABLE DDYAEK
B59D HANGUL SYLLABLE DDYAET
B59E HANGUL SYLLABLE DDYAEP
B59F HANGUL SYLLABLE DDYAEH
B5A0 HANGUL SYLLABLE DDEO
B5A1 HANGUL SYLLABLE DDEOG
B5A2 HANGUL SYLLABLE DDEOGG
B5A3 HANGUL SYLLABLE DDEOGS
B5A4 HANGUL SYLLABLE DDEON
B5A5 HANGUL SYLLABLE DDEONJ
B5A6 HANGUL SYLLABLE DDEONH
B5A7 HANGUL SYLLABLE DDEOD
B5A8 HANGUL SYLLABLE DDEOL
B5A9 HANGUL SYLLABLE DDEOLG
B5AA HANGUL SYLLABLE DDEOLM
B5AB HANGUL SYLLABLE DDEOLB
B5AC HANGUL SYLLABLE DDEOLS
B5AD HANGUL SYLLABLE DDEOLT
B5AE HANGUL SYLLABLE DDEOLP
B5AF HANGUL SYLLABLE DDEOLH
B5B0 HANGUL SYLLABLE DDEOM
B5B1 HANGUL SYLLABLE DDEOB
B5B2 HANGUL SYLLABLE DDEOBS
B5B3 HANGUL SYLLABLE DDEOS
B5B4 HANGUL SYLLABLE DDEOSS
B5B5 HANGUL SYLLABLE DDEONG
B5B6 HANGUL SYLLABLE DDEOJ
B5B7 HANGUL SYLLABLE DDEOC
B5B8 HANGUL SYLLABLE DDEOK
B5B9 HANGUL SYLLABLE DDEOT
B5BA HANGUL SYLLABLE DDEOP
B5BB HANGUL SYLLABLE DDEOH
B5BC HANGUL SYLLABLE DDE
B5BD HANGUL SYLLABLE DDEG
B5BE HANGUL SYLLABLE DDEGG
B5BF HANGUL SYLLABLE DDEGS
B5C0 HANGUL SYLLABLE DDEN
B5C1 HANGUL SYLLABLE DDENJ
B5C2 HANGUL SYLLABLE DDENH
B5C3 HANGUL SYLLABLE DDED
B5C4 HANGUL SYLLABLE DDEL
B5C5 HANGUL SYLLABLE DDELG
B5C6 HANGUL SYLLABLE DDELM
B5C7 HANGUL SYLLABLE DDELB
B5C8 HANGUL SYLLABLE DDELS
B5C9 HANGUL SYLLABLE DDELT
B5CA HANGUL SYLLABLE DDELP
B5CB HANGUL SYLLABLE DDELH
B5CC HANGUL SYLLABLE DDEM
B5CD HANGUL SYLLABLE DDEB
B5CE HANGUL SYLLABLE DDEBS
B5CF HANGUL SYLLABLE DDES
B5D0 HANGUL SYLLABLE DDESS
B5D1 HANGUL SYLLABLE DDENG
B5D2 HANGUL SYLLABLE DDEJ
B5D3 HANGUL SYLLABLE DDEC
B5D4 HANGUL SYLLABLE DDEK
B5D5 HANGUL SYLLABLE DDET
B5D6 HANGUL SYLLABLE DDEP
B5D7 HANGUL SYLLABLE DDEH
B5D8 HANGUL SYLLABLE DDYEO
B5D9 HANGUL SYLLABLE DDYEOG
B5DA HANGUL SYLLABLE DDYEOGG
B5DB HANGUL SYLLABLE DDYEOGS
B5DC HANGUL SYLLABLE DDYEON
B5DD HANGUL SYLLABLE DDYEONJ
B5DE HANGUL SYLLABLE DDYEONH
B5DF HANGUL SYLLABLE DDYEOD
B5E0 HANGUL SYLLABLE DDYEOL
B5E1 HANGUL SYLLABLE DDYEOLG
B5E2 HANGUL SYLLABLE DDYEOLM
B5E3 HANGUL SYLLABLE DDYEOLB
B5E4 HANGUL SYLLABLE DDYEOLS
B5E5 HANGUL SYLLABLE DDYEOLT
B5E6 HANGUL SYLLABLE DDYEOLP
B5E7 HANGUL SYLLABLE DDYEOLH
B5E8 HANGUL SYLLABLE DDYEOM
B5E9 HANGUL SYLLABLE DDYEOB
B5EA HANGUL SYLLABLE DDYEOBS
B5EB HANGUL SYLLABLE DDYEOS
B5EC HANGUL SYLLABLE DDYEOSS
B5ED HANGUL SYLLABLE DDYEONG
B5EE HANGUL SYLLABLE DDYEOJ
B5EF HANGUL SYLLABLE DDYEOC
B5F0 HANGUL SYLLABLE DDYEOK
B5F1 HANGUL SYLLABLE DDYEOT
B5F2 HANGUL SYLLABLE DDYEOP
B5F3 HANGUL SYLLABLE DDYEOH
B5F4 HANGUL SYLLABLE DDYE
B5F5 HANGUL SYLLABLE DDYEG
B5F6 HANGUL SYLLABLE DDYEGG
B5F7 HANGUL SYLLABLE DDYEGS
B5F8 HANGUL SYLLABLE DDYEN
B5F9 HANGUL SYLLABLE DDYENJ
B5FA HANGUL SYLLABLE DDYENH
B5FB HANGUL SYLLABLE DDYED
B5FC HANGUL SYLLABLE DDYEL
B5FD HANGUL SYLLABLE DDYELG
B5FE HANGUL SYLLABLE DDYELM
B5FF HANGUL SYLLABLE DDYELB
B600 HANGUL SYLLABLE DDYELS
B601 HANGUL SYLLABLE DDYELT
B602 HANGUL SYLLABLE DDYELP
B603 HANGUL SYLLABLE DDYELH
B604 HANGUL SYLLABLE DDYEM
B605 HANGUL SYLLABLE DDYEB
B606 HANGUL SYLLABLE DDYEBS
B607 HANGUL SYLLABLE DDYES
B608 HANGUL SYLLABLE DDYESS
B609 HANGUL SYLLABLE DDYENG
B60A HANGUL SYLLABLE DDYEJ
B60B HANGUL SYLLABLE DDYEC
B60C HANGUL SYLLABLE DDYEK
B60D HANGUL SYLLABLE DDYET
B60E HANGUL SYLLABLE DDYEP
B60F HANGUL SYLLABLE DDYEH
B610 HANGUL SYLLABLE DDO
B611 HANGUL SYLLABLE DDOG
B612 HANGUL SYLLABLE DDOGG
B613 HANGUL SYLLABLE DDOGS
B614 HANGUL SYLLABLE DDON
B615 HANGUL SYLLABLE DDONJ
B616 HANGUL SYLLABLE DDONH
B617 HANGUL SYLLABLE DDOD
B618 HANGUL SYLLABLE DDOL
B619 HANGUL SYLLABLE DDOLG
B61A HANGUL SYLLABLE DDOLM
B61B HANGUL SYLLABLE DDOLB
B61C HANGUL SYLLABLE DDOLS
B61D HANGUL SYLLABLE DDOLT
B61E HANGUL SYLLABLE DDOLP
B61F HANGUL SYLLABLE DDOLH
B620 HANGUL SYLLABLE DDOM
B621 HANGUL SYLLABLE DDOB
B622 HANGUL SYLLABLE DDOBS
B623 HANGUL SYLLABLE DDOS
B624 HANGUL SYLLABLE DDOSS
B625 HANGUL SYLLABLE DDONG
B626 HANGUL SYLLABLE DDOJ
B627 HANGUL SYLLABLE DDOC
B628 HANGUL SYLLABLE DDOK
B629 HANGUL SYLLABLE DDOT
B62A HANGUL SYLLABLE DDOP
B62B HANGUL SYLLABLE DDOH
B62C HANGUL SYLLABLE DDWA
B62D HANGUL SYLLABLE DDWAG
B62E HANGUL SYLLABLE DDWAGG
B62F HANGUL SYLLABLE DDWAGS
B630 HANGUL SYLLABLE DDWAN
B631 HANGUL SYLLABLE DDWANJ
B632 HANGUL SYLLABLE DDWANH
B633 HANGUL SYLLABLE DDWAD
B634 HANGUL SYLLABLE DDWAL
B635 HANGUL SYLLABLE DDWALG
B636 HANGUL SYLLABLE DDWALM
B637 HANGUL SYLLABLE DDWALB
B638 HANGUL SYLLABLE DDWALS
B639 HANGUL SYLLABLE DDWALT
B63A HANGUL SYLLABLE DDWALP
B63B HANGUL SYLLABLE DDWALH
B63C HANGUL SYLLABLE DDWAM
B63D HANGUL SYLLABLE DDWAB
B63E HANGUL SYLLABLE DDWABS
B63F HANGUL SYLLABLE DDWAS
B640 HANGUL SYLLABLE DDWASS
B641 HANGUL SYLLABLE DDWANG
B642 HANGUL SYLLABLE DDWAJ
B643 HANGUL SYLLABLE DDWAC
B644 HANGUL SYLLABLE DDWAK
B645 HANGUL SYLLABLE DDWAT
B646 HANGUL SYLLABLE DDWAP
B647 HANGUL SYLLABLE DDWAH
B648 HANGUL SYLLABLE DDWAE
B649 HANGUL SYLLABLE DDWAEG
B64A HANGUL SYLLABLE DDWAEGG
B64B HANGUL SYLLABLE DDWAEGS
B64C HANGUL SYLLABLE DDWAEN
B64D HANGUL SYLLABLE DDWAENJ
B64E HANGUL SYLLABLE DDWAENH
B64F HANGUL SYLLABLE DDWAED
B650 HANGUL SYLLABLE DDWAEL
B651 HANGUL SYLLABLE DDWAELG
B652 HANGUL SYLLABLE DDWAELM
B653 HANGUL SYLLABLE DDWAELB
B654 HANGUL SYLLABLE DDWAELS
B655 HANGUL SYLLABLE DDWAELT
B656 HANGUL SYLLABLE DDWAELP
B657 HANGUL SYLLABLE DDWAELH
B658 HANGUL SYLLABLE DDWAEM
B659 HANGUL SYLLABLE DDWAEB
B65A HANGUL SYLLABLE DDWAEBS
B65B HANGUL SYLLABLE DDWAES
B65C HANGUL SYLLABLE DDWAESS
B65D HANGUL SYLLABLE DDWAENG
B65E HANGUL SYLLABLE DDWAEJ
B65F HANGUL SYLLABLE DDWAEC
B660 HANGUL SYLLABLE DDWAEK
B661 HANGUL SYLLABLE DDWAET
B662 HANGUL SYLLABLE DDWAEP
B663 HANGUL SYLLABLE DDWAEH
B664 HANGUL SYLLABLE DDOE
B665 HANGUL SYLLABLE DDOEG
B666 HANGUL SYLLABLE DDOEGG
B667 HANGUL SYLLABLE DDOEGS
B668 HANGUL SYLLABLE DDOEN
B669 HANGUL SYLLABLE DDOENJ
B66A HANGUL SYLLABLE DDOENH
B66B HANGUL SYLLABLE DDOED
B66C HANGUL SYLLABLE DDOEL
B66D HANGUL SYLLABLE DDOELG
B66E HANGUL SYLLABLE DDOELM
B66F HANGUL SYLLABLE DDOELB
B670 HANGUL SYLLABLE DDOELS
B671 HANGUL SYLLABLE DDOELT
B672 HANGUL SYLLABLE DDOELP
B673 HANGUL SYLLABLE DDOELH
B674 HANGUL SYLLABLE DDOEM
B675 HANGUL SYLLABLE DDOEB
B676 HANGUL SYLLABLE DDOEBS
B677 HANGUL SYLLABLE DDOES
B678 HANGUL SYLLABLE DDOESS
B679 HANGUL SYLLABLE DDOENG
B67A HANGUL SYLLABLE DDOEJ
B67B HANGUL SYLLABLE DDOEC
B67C HANGUL SYLLABLE DDOEK
B67D HANGUL SYLLABLE DDOET
B67E HANGUL SYLLABLE DDOEP
B67F HANGUL SYLLABLE DDOEH
B680 HANGUL SYLLABLE DDYO
B681 HANGUL SYLLABLE DDYOG
B682 HANGUL SYLLABLE DDYOGG
B683 HANGUL SYLLABLE DDYOGS
B684 HANGUL SYLLABLE DDYON
B685 HANGUL SYLLABLE DDYONJ
B686 HANGUL SYLLABLE DDYONH
B687 HANGUL SYLLABLE DDYOD
B688 HANGUL SYLLABLE DDYOL
B689 HANGUL SYLLABLE DDYOLG
B68A HANGUL SYLLABLE DDYOLM
B68B HANGUL SYLLABLE DDYOLB
B68C HANGUL SYLLABLE DDYOLS
B68D HANGUL SYLLABLE DDYOLT
B68E HANGUL SYLLABLE DDYOLP
B68F HANGUL SYLLABLE DDYOLH
B690 HANGUL SYLLABLE DDYOM
B691 HANGUL SYLLABLE DDYOB
B692 HANGUL SYLLABLE DDYOBS
B693 HANGUL SYLLABLE DDYOS
B694 HANGUL SYLLABLE DDYOSS
B695 HANGUL SYLLABLE DDYONG
B696 HANGUL SYLLABLE DDYOJ
B697 HANGUL SYLLABLE DDYOC
B698 HANGUL SYLLABLE DDYOK
B699 HANGUL SYLLABLE DDYOT
B69A HANGUL SYLLABLE DDYOP
B69B HANGUL SYLLABLE DDYOH
B69C HANGUL SYLLABLE DDU
B69D HANGUL SYLLABLE DDUG
B69E HANGUL SYLLABLE DDUGG
B69F HANGUL SYLLABLE DDUGS
B6A0 HANGUL SYLLABLE DDUN
B6A1 HANGUL SYLLABLE DDUNJ
B6A2 HANGUL SYLLABLE DDUNH
B6A3 HANGUL SYLLABLE DDUD
B6A4 HANGUL SYLLABLE DDUL
B6A5 HANGUL SYLLABLE DDULG
B6A6 HANGUL SYLLABLE DDULM
B6A7 HANGUL SYLLABLE DDULB
B6A8 HANGUL SYLLABLE DDULS
B6A9 HANGUL SYLLABLE DDULT
B6AA HANGUL SYLLABLE DDULP
B6AB HANGUL SYLLABLE DDULH
B6AC HANGUL SYLLABLE DDUM
B6AD HANGUL SYLLABLE DDUB
B6AE HANGUL SYLLABLE DDUBS
B6AF HANGUL SYLLABLE DDUS
B6B0 HANGUL SYLLABLE DDUSS
B6B1 HANGUL SYLLABLE DDUNG
B6B2 HANGUL SYLLABLE DDUJ
B6B3 HANGUL SYLLABLE DDUC
B6B4 HANGUL SYLLABLE DDUK
B6B5 HANGUL SYLLABLE DDUT
B6B6 HANGUL SYLLABLE DDUP
B6B7 HANGUL SYLLABLE DDUH
B6B8 HANGUL SYLLABLE DDWEO
B6B9 HANGUL SYLLABLE DDWEOG
B6BA HANGUL SYLLABLE DDWEOGG
B6BB HANGUL SYLLABLE DDWEOGS
B6BC HANGUL SYLLABLE DDWEON
B6BD HANGUL SYLLABLE DDWEONJ
B6BE HANGUL SYLLABLE DDWEONH
B6BF HANGUL SYLLABLE DDWEOD
B6C0 HANGUL SYLLABLE DDWEOL
B6C1 HANGUL SYLLABLE DDWEOLG
B6C2 HANGUL SYLLABLE DDWEOLM
B6C3 HANGUL SYLLABLE DDWEOLB
B6C4 HANGUL SYLLABLE DDWEOLS
B6C5 HANGUL SYLLABLE DDWEOLT
B6C6 HANGUL SYLLABLE DDWEOLP
B6C7 HANGUL SYLLABLE DDWEOLH
B6C8 HANGUL SYLLABLE DDWEOM
B6C9 HANGUL SYLLABLE DDWEOB
B6CA HANGUL SYLLABLE DDWEOBS
B6CB HANGUL SYLLABLE DDWEOS
B6CC HANGUL SYLLABLE DDWEOSS
B6CD HANGUL SYLLABLE DDWEONG
B6CE HANGUL SYLLABLE DDWEOJ
B6CF HANGUL SYLLABLE DDWEOC
B6D0 HANGUL SYLLABLE DDWEOK
B6D1 HANGUL SYLLABLE DDWEOT
B6D2 HANGUL SYLLABLE DDWEOP
B6D3 HANGUL SYLLABLE DDWEOH
B6D4 HANGUL SYLLABLE DDWE
B6D5 HANGUL SYLLABLE DDWEG
B6D6 HANGUL SYLLABLE DDWEGG
B6D7 HANGUL SYLLABLE DDWEGS
B6D8 HANGUL SYLLABLE DDWEN
B6D9 HANGUL SYLLABLE DDWENJ
B6DA HANGUL SYLLABLE DDWENH
B6DB HANGUL SYLLABLE DDWED
B6DC HANGUL SYLLABLE DDWEL
B6DD HANGUL SYLLABLE DDWELG
B6DE HANGUL SYLLABLE DDWELM
B6DF HANGUL SYLLABLE DDWELB
B6E0 HANGUL SYLLABLE DDWELS
B6E1 HANGUL SYLLABLE DDWELT
B6E2 HANGUL SYLLABLE DDWELP
B6E3 HANGUL SYLLABLE DDWELH
B6E4 HANGUL SYLLABLE DDWEM
B6E5 HANGUL SYLLABLE DDWEB
B6E6 HANGUL SYLLABLE DDWEBS
B6E7 HANGUL SYLLABLE DDWES
B6E8 HANGUL SYLLABLE DDWESS
B6E9 HANGUL SYLLABLE DDWENG
B6EA HANGUL SYLLABLE DDWEJ
B6EB HANGUL SYLLABLE DDWEC
B6EC HANGUL SYLLABLE DDWEK
B6ED HANGUL SYLLABLE DDWET
B6EE HANGUL SYLLABLE DDWEP
B6EF HANGUL SYLLABLE DDWEH
B6F0 HANGUL SYLLABLE DDWI
B6F1 HANGUL SYLLABLE DDWIG
B6F2 HANGUL SYLLABLE DDWIGG
B6F3 HANGUL SYLLABLE DDWIGS
B6F4 HANGUL SYLLABLE DDWIN
B6F5 HANGUL SYLLABLE DDWINJ
B6F6 HANGUL SYLLABLE DDWINH
B6F7 HANGUL SYLLABLE DDWID
B6F8 HANGUL SYLLABLE DDWIL
B6F9 HANGUL SYLLABLE DDWILG
B6FA HANGUL SYLLABLE DDWILM
B6FB HANGUL SYLLABLE DDWILB
B6FC HANGUL SYLLABLE DDWILS
B6FD HANGUL SYLLABLE DDWILT
B6FE HANGUL SYLLABLE DDWILP
B6FF HANGUL SYLLABLE DDWILH
B700 HANGUL SYLLABLE DDWIM
B701 HANGUL SYLLABLE DDWIB
B702 HANGUL SYLLABLE DDWIBS
B703 HANGUL SYLLABLE DDWIS
B704 HANGUL SYLLABLE DDWISS
B705 HANGUL SYLLABLE DDWING
B706 HANGUL SYLLABLE DDWIJ
B707 HANGUL SYLLABLE DDWIC
B708 HANGUL SYLLABLE DDWIK
B709 HANGUL SYLLABLE DDWIT
B70A HANGUL SYLLABLE DDWIP
B70B HANGUL SYLLABLE DDWIH
B70C HANGUL SYLLABLE DDYU
B70D HANGUL SYLLABLE DDYUG
B70E HANGUL SYLLABLE DDYUGG
B70F HANGUL SYLLABLE DDYUGS
B710 HANGUL SYLLABLE DDYUN
B711 HANGUL SYLLABLE DDYUNJ
B712 HANGUL SYLLABLE DDYUNH
B713 HANGUL SYLLABLE DDYUD
B714 HANGUL SYLLABLE DDYUL
B715 HANGUL SYLLABLE DDYULG
B716 HANGUL SYLLABLE DDYULM
B717 HANGUL SYLLABLE DDYULB
B718 HANGUL SYLLABLE DDYULS
B719 HANGUL SYLLABLE DDYULT
B71A HANGUL SYLLABLE DDYULP
B71B HANGUL SYLLABLE DDYULH
B71C HANGUL SYLLABLE DDYUM
B71D HANGUL SYLLABLE DDYUB
B71E HANGUL SYLLABLE DDYUBS
B71F HANGUL SYLLABLE DDYUS
B720 HANGUL SYLLABLE DDYUSS
B721 HANGUL SYLLABLE DDYUNG
B722 HANGUL SYLLABLE DDYUJ
B723 HANGUL SYLLABLE DDYUC
B724 HANGUL SYLLABLE DDYUK
B725 HANGUL SYLLABLE DDYUT
B726 HANGUL SYLLABLE DDYUP
B727 HANGUL SYLLABLE DDYUH
B728 HANGUL SYLLABLE DDEU
B729 HANGUL SYLLABLE DDEUG
B72A HANGUL SYLLABLE DDEUGG
B72B HANGUL SYLLABLE DDEUGS
B72C HANGUL SYLLABLE DDEUN
B72D HANGUL SYLLABLE DDEUNJ
B72E HANGUL SYLLABLE DDEUNH
B72F HANGUL SYLLABLE DDEUD
B730 HANGUL SYLLABLE DDEUL
B731 HANGUL SYLLABLE DDEULG
B732 HANGUL SYLLABLE DDEULM
B733 HANGUL SYLLABLE DDEULB
B734 HANGUL SYLLABLE DDEULS
B735 HANGUL SYLLABLE DDEULT
B736 HANGUL SYLLABLE DDEULP
B737 HANGUL SYLLABLE DDEULH
B738 HANGUL SYLLABLE DDEUM
B739 HANGUL SYLLABLE DDEUB
B73A HANGUL SYLLABLE DDEUBS
B73B HANGUL SYLLABLE DDEUS
B73C HANGUL SYLLABLE DDEUSS
B73D HANGUL SYLLABLE DDEUNG
B73E HANGUL SYLLABLE DDEUJ
B73F HANGUL SYLLABLE DDEUC
B740 HANGUL SYLLABLE DDEUK
B741 HANGUL SYLLABLE DDEUT
B742 HANGUL SYLLABLE DDEUP
B743 HANGUL SYLLABLE DDEUH
B744 HANGUL SYLLABLE DDYI
B745 HANGUL SYLLABLE DDYIG
B746 HANGUL SYLLABLE DDYIGG
B747 HANGUL SYLLABLE DDYIGS
B748 HANGUL SYLLABLE DDYIN
B749 HANGUL SYLLABLE DDYINJ
B74A HANGUL SYLLABLE DDYINH
B74B HANGUL SYLLABLE DDYID
B74C HANGUL SYLLABLE DDYIL
B74D HANGUL SYLLABLE DDYILG
B74E HANGUL SYLLABLE DDYILM
B74F HANGUL SYLLABLE DDYILB
B750 HANGUL SYLLABLE DDYILS
B751 HANGUL SYLLABLE DDYILT
B752 HANGUL SYLLABLE DDYILP
B753 HANGUL SYLLABLE DDYILH
B754 HANGUL SYLLABLE DDYIM
B755 HANGUL SYLLABLE DDYIB
B756 HANGUL SYLLABLE DDYIBS
B757 HANGUL SYLLABLE DDYIS
B758 HANGUL SYLLABLE DDYISS
B759 HANGUL SYLLABLE DDYING
B75A HANGUL SYLLABLE DDYIJ
B75B HANGUL SYLLABLE DDYIC
B75C HANGUL SYLLABLE DDYIK
B75D HANGUL SYLLABLE DDYIT
B75E HANGUL SYLLABLE DDYIP
B75F HANGUL SYLLABLE DDYIH
B760 HANGUL SYLLABLE DDI
B761 HANGUL SYLLABLE DDIG
B762 HANGUL SYLLABLE DDIGG
B763 HANGUL SYLLABLE DDIGS
B764 HANGUL SYLLABLE DDIN
B765 HANGUL SYLLABLE DDINJ
B766 HANGUL SYLLABLE DDINH
B767 HANGUL SYLLABLE DDID
B768 HANGUL SYLLABLE DDIL
B769 HANGUL SYLLABLE DDILG
B76A HANGUL SYLLABLE DDILM
B76B HANGUL SYLLABLE DDILB
B76C HANGUL SYLLABLE DDILS
B76D HANGUL SYLLABLE DDILT
B76E HANGUL SYLLABLE DDILP
B76F HANGUL SYLLABLE DDILH
B770 HANGUL SYLLABLE DDIM
B771 HANGUL SYLLABLE DDIB
B772 HANGUL SYLLABLE DDIBS
B773 HANGUL SYLLABLE DDIS
B774 HANGUL SYLLABLE DDISS
B775 HANGUL SYLLABLE DDING
B776 HANGUL SYLLABLE DDIJ
B777 HANGUL SYLLABLE DDIC
B778 HANGUL SYLLABLE DDIK
B779 HANGUL SYLLABLE DDIT
B77A HANGUL SYLLABLE DDIP
B77B HANGUL SYLLABLE DDIH
B77C HANGUL SYLLABLE RA
B77D HANGUL SYLLABLE RAG
B77E HANGUL SYLLABLE RAGG
B77F HANGUL SYLLABLE RAGS
B780 HANGUL SYLLABLE RAN
B781 HANGUL SYLLABLE RANJ
B782 HANGUL SYLLABLE RANH
B783 HANGUL SYLLABLE RAD
B784 HANGUL SYLLABLE RAL
B785 HANGUL SYLLABLE RALG
B786 HANGUL SYLLABLE RALM
B787 HANGUL SYLLABLE RALB
B788 HANGUL SYLLABLE RALS
B789 HANGUL SYLLABLE RALT
B78A HANGUL SYLLABLE RALP
B78B HANGUL SYLLABLE RALH
B78C HANGUL SYLLABLE RAM
B78D HANGUL SYLLABLE RAB
B78E HANGUL SYLLABLE RABS
B78F HANGUL SYLLABLE RAS
B790 HANGUL SYLLABLE RASS
B791 HANGUL SYLLABLE RANG
B792 HANGUL SYLLABLE RAJ
B793 HANGUL SYLLABLE RAC
B794 HANGUL SYLLABLE RAK
B795 HANGUL SYLLABLE RAT
B796 HANGUL SYLLABLE RAP
B797 HANGUL SYLLABLE RAH
B798 HANGUL SYLLABLE RAE
B799 HANGUL SYLLABLE RAEG
B79A HANGUL SYLLABLE RAEGG
B79B HANGUL SYLLABLE RAEGS
B79C HANGUL SYLLABLE RAEN
B79D HANGUL SYLLABLE RAENJ
B79E HANGUL SYLLABLE RAENH
B79F HANGUL SYLLABLE RAED
B7A0 HANGUL SYLLABLE RAEL
B7A1 HANGUL SYLLABLE RAELG
B7A2 HANGUL SYLLABLE RAELM
B7A3 HANGUL SYLLABLE RAELB
B7A4 HANGUL SYLLABLE RAELS
B7A5 HANGUL SYLLABLE RAELT
B7A6 HANGUL SYLLABLE RAELP
B7A7 HANGUL SYLLABLE RAELH
B7A8 HANGUL SYLLABLE RAEM
B7A9 HANGUL SYLLABLE RAEB
B7AA HANGUL SYLLABLE RAEBS
B7AB HANGUL SYLLABLE RAES
B7AC HANGUL SYLLABLE RAESS
B7AD HANGUL SYLLABLE RAENG
B7AE HANGUL SYLLABLE RAEJ
B7AF HANGUL SYLLABLE RAEC
B7B0 HANGUL SYLLABLE RAEK
B7B1 HANGUL SYLLABLE RAET
B7B2 HANGUL SYLLABLE RAEP
B7B3 HANGUL SYLLABLE RAEH
B7B4 HANGUL SYLLABLE RYA
B7B5 HANGUL SYLLABLE RYAG
B7B6 HANGUL SYLLABLE RYAGG
B7B7 HANGUL SYLLABLE RYAGS
B7B8 HANGUL SYLLABLE RYAN
B7B9 HANGUL SYLLABLE RYANJ
B7BA HANGUL SYLLABLE RYANH
B7BB HANGUL SYLLABLE RYAD
B7BC HANGUL SYLLABLE RYAL
B7BD HANGUL SYLLABLE RYALG
B7BE HANGUL SYLLABLE RYALM
B7BF HANGUL SYLLABLE RYALB
B7C0 HANGUL SYLLABLE RYALS
B7C1 HANGUL SYLLABLE RYALT
B7C2 HANGUL SYLLABLE RYALP
B7C3 HANGUL SYLLABLE RYALH
B7C4 HANGUL SYLLABLE RYAM
B7C5 HANGUL SYLLABLE RYAB
B7C6 HANGUL SYLLABLE RYABS
B7C7 HANGUL SYLLABLE RYAS
B7C8 HANGUL SYLLABLE RYASS
B7C9 HANGUL SYLLABLE RYANG
B7CA HANGUL SYLLABLE RYAJ
B7CB HANGUL SYLLABLE RYAC
B7CC HANGUL SYLLABLE RYAK
B7CD HANGUL SYLLABLE RYAT
B7CE HANGUL SYLLABLE RYAP
B7CF HANGUL SYLLABLE RYAH
B7D0 HANGUL SYLLABLE RYAE
B7D1 HANGUL SYLLABLE RYAEG
B7D2 HANGUL SYLLABLE RYAEGG
B7D3 HANGUL SYLLABLE RYAEGS
B7D4 HANGUL SYLLABLE RYAEN
B7D5 HANGUL SYLLABLE RYAENJ
B7D6 HANGUL SYLLABLE RYAENH
B7D7 HANGUL SYLLABLE RYAED
B7D8 HANGUL SYLLABLE RYAEL
B7D9 HANGUL SYLLABLE RYAELG
B7DA HANGUL SYLLABLE RYAELM
B7DB HANGUL SYLLABLE RYAELB
B7DC HANGUL SYLLABLE RYAELS
B7DD HANGUL SYLLABLE RYAELT
B7DE HANGUL SYLLABLE RYAELP
B7DF HANGUL SYLLABLE RYAELH
B7E0 HANGUL SYLLABLE RYAEM
B7E1 HANGUL SYLLABLE RYAEB
B7E2 HANGUL SYLLABLE RYAEBS
B7E3 HANGUL SYLLABLE RYAES
B7E4 HANGUL SYLLABLE RYAESS
B7E5 HANGUL SYLLABLE RYAENG
B7E6 HANGUL SYLLABLE RYAEJ
B7E7 HANGUL SYLLABLE RYAEC
B7E8 HANGUL SYLLABLE RYAEK
B7E9 HANGUL SYLLABLE RYAET
B7EA HANGUL SYLLABLE RYAEP
B7EB HANGUL SYLLABLE RYAEH
B7EC HANGUL SYLLABLE REO
B7ED HANGUL SYLLABLE REOG
B7EE HANGUL SYLLABLE REOGG
B7EF HANGUL SYLLABLE REOGS
B7F0 HANGUL SYLLABLE REON
B7F1 HANGUL SYLLABLE REONJ
B7F2 HANGUL SYLLABLE REONH
B7F3 HANGUL SYLLABLE REOD
B7F4 HANGUL SYLLABLE REOL
B7F5 HANGUL SYLLABLE REOLG
B7F6 HANGUL SYLLABLE REOLM
B7F7 HANGUL SYLLABLE REOLB
B7F8 HANGUL SYLLABLE REOLS
B7F9 HANGUL SYLLABLE REOLT
B7FA HANGUL SYLLABLE REOLP
B7FB HANGUL SYLLABLE REOLH
B7FC HANGUL SYLLABLE REOM
B7FD HANGUL SYLLABLE REOB
B7FE HANGUL SYLLABLE REOBS
B7FF HANGUL SYLLABLE REOS
B800 HANGUL SYLLABLE REOSS
B801 HANGUL SYLLABLE REONG
B802 HANGUL SYLLABLE REOJ
B803 HANGUL SYLLABLE REOC
B804 HANGUL SYLLABLE REOK
B805 HANGUL SYLLABLE REOT
B806 HANGUL SYLLABLE REOP
B807 HANGUL SYLLABLE REOH
B808 HANGUL SYLLABLE RE
B809 HANGUL SYLLABLE REG
B80A HANGUL SYLLABLE REGG
B80B HANGUL SYLLABLE REGS
B80C HANGUL SYLLABLE REN
B80D HANGUL SYLLABLE RENJ
B80E HANGUL SYLLABLE RENH
B80F HANGUL SYLLABLE RED
B810 HANGUL SYLLABLE REL
B811 HANGUL SYLLABLE RELG
B812 HANGUL SYLLABLE RELM
B813 HANGUL SYLLABLE RELB
B814 HANGUL SYLLABLE RELS
B815 HANGUL SYLLABLE RELT
B816 HANGUL SYLLABLE RELP
B817 HANGUL SYLLABLE RELH
B818 HANGUL SYLLABLE REM
B819 HANGUL SYLLABLE REB
B81A HANGUL SYLLABLE REBS
B81B HANGUL SYLLABLE RES
B81C HANGUL SYLLABLE RESS
B81D HANGUL SYLLABLE RENG
B81E HANGUL SYLLABLE REJ
B81F HANGUL SYLLABLE REC
B820 HANGUL SYLLABLE REK
B821 HANGUL SYLLABLE RET
B822 HANGUL SYLLABLE REP
B823 HANGUL SYLLABLE REH
B824 HANGUL SYLLABLE RYEO
B825 HANGUL SYLLABLE RYEOG
B826 HANGUL SYLLABLE RYEOGG
B827 HANGUL SYLLABLE RYEOGS
B828 HANGUL SYLLABLE RYEON
B829 HANGUL SYLLABLE RYEONJ
B82A HANGUL SYLLABLE RYEONH
B82B HANGUL SYLLABLE RYEOD
B82C HANGUL SYLLABLE RYEOL
B82D HANGUL SYLLABLE RYEOLG
B82E HANGUL SYLLABLE RYEOLM
B82F HANGUL SYLLABLE RYEOLB
B830 HANGUL SYLLABLE RYEOLS
B831 HANGUL SYLLABLE RYEOLT
B832 HANGUL SYLLABLE RYEOLP
B833 HANGUL SYLLABLE RYEOLH
B834 HANGUL SYLLABLE RYEOM
B835 HANGUL SYLLABLE RYEOB
B836 HANGUL SYLLABLE RYEOBS
B837 HANGUL SYLLABLE RYEOS
B838 HANGUL SYLLABLE RYEOSS
B839 HANGUL SYLLABLE RYEONG
B83A HANGUL SYLLABLE RYEOJ
B83B HANGUL SYLLABLE RYEOC
B83C HANGUL SYLLABLE RYEOK
B83D HANGUL SYLLABLE RYEOT
B83E HANGUL SYLLABLE RYEOP
B83F HANGUL SYLLABLE RYEOH
B840 HANGUL SYLLABLE RYE
B841 HANGUL SYLLABLE RYEG
B842 HANGUL SYLLABLE RYEGG
B843 HANGUL SYLLABLE RYEGS
B844 HANGUL SYLLABLE RYEN
B845 HANGUL SYLLABLE RYENJ
B846 HANGUL SYLLABLE RYENH
B847 HANGUL SYLLABLE RYED
B848 HANGUL SYLLABLE RYEL
B849 HANGUL SYLLABLE RYELG
B84A HANGUL SYLLABLE RYELM
B84B HANGUL SYLLABLE RYELB
B84C HANGUL SYLLABLE RYELS
B84D HANGUL SYLLABLE RYELT
B84E HANGUL SYLLABLE RYELP
B84F HANGUL SYLLABLE RYELH
B850 HANGUL SYLLABLE RYEM
B851 HANGUL SYLLABLE RYEB
B852 HANGUL SYLLABLE RYEBS
B853 HANGUL SYLLABLE RYES
B854 HANGUL SYLLABLE RYESS
B855 HANGUL SYLLABLE RYENG
B856 HANGUL SYLLABLE RYEJ
B857 HANGUL SYLLABLE RYEC
B858 HANGUL SYLLABLE RYEK
B859 HANGUL SYLLABLE RYET
B85A HANGUL SYLLABLE RYEP
B85B HANGUL SYLLABLE RYEH
B85C HANGUL SYLLABLE RO
B85D HANGUL SYLLABLE ROG
B85E HANGUL SYLLABLE ROGG
B85F HANGUL SYLLABLE ROGS
B860 HANGUL SYLLABLE RON
B861 HANGUL SYLLABLE RONJ
B862 HANGUL SYLLABLE RONH
B863 HANGUL SYLLABLE ROD
B864 HANGUL SYLLABLE ROL
B865 HANGUL SYLLABLE ROLG
B866 HANGUL SYLLABLE ROLM
B867 HANGUL SYLLABLE ROLB
B868 HANGUL SYLLABLE ROLS
B869 HANGUL SYLLABLE ROLT
B86A HANGUL SYLLABLE ROLP
B86B HANGUL SYLLABLE ROLH
B86C HANGUL SYLLABLE ROM
B86D HANGUL SYLLABLE ROB
B86E HANGUL SYLLABLE ROBS
B86F HANGUL SYLLABLE ROS
B870 HANGUL SYLLABLE ROSS
B871 HANGUL SYLLABLE RONG
B872 HANGUL SYLLABLE ROJ
B873 HANGUL SYLLABLE ROC
B874 HANGUL SYLLABLE ROK
B875 HANGUL SYLLABLE ROT
B876 HANGUL SYLLABLE ROP
B877 HANGUL SYLLABLE ROH
B878 HANGUL SYLLABLE RWA
B879 HANGUL SYLLABLE RWAG
B87A HANGUL SYLLABLE RWAGG
B87B HANGUL SYLLABLE RWAGS
B87C HANGUL SYLLABLE RWAN
B87D HANGUL SYLLABLE RWANJ
B87E HANGUL SYLLABLE RWANH
B87F HANGUL SYLLABLE RWAD
B880 HANGUL SYLLABLE RWAL
B881 HANGUL SYLLABLE RWALG
B882 HANGUL SYLLABLE RWALM
B883 HANGUL SYLLABLE RWALB
B884 HANGUL SYLLABLE RWALS
B885 HANGUL SYLLABLE RWALT
B886 HANGUL SYLLABLE RWALP
B887 HANGUL SYLLABLE RWALH
B888 HANGUL SYLLABLE RWAM
B889 HANGUL SYLLABLE RWAB
B88A HANGUL SYLLABLE RWABS
B88B HANGUL SYLLABLE RWAS
B88C HANGUL SYLLABLE RWASS
B88D HANGUL SYLLABLE RWANG
B88E HANGUL SYLLABLE RWAJ
B88F HANGUL SYLLABLE RWAC
B890 HANGUL SYLLABLE RWAK
B891 HANGUL SYLLABLE RWAT
B892 HANGUL SYLLABLE RWAP
B893 HANGUL SYLLABLE RWAH
B894 HANGUL SYLLABLE RWAE
B895 HANGUL SYLLABLE RWAEG
B896 HANGUL SYLLABLE RWAEGG
B897 HANGUL SYLLABLE RWAEGS
B898 HANGUL SYLLABLE RWAEN
B899 HANGUL SYLLABLE RWAENJ
B89A HANGUL SYLLABLE RWAENH
B89B HANGUL SYLLABLE RWAED
B89C HANGUL SYLLABLE RWAEL
B89D HANGUL SYLLABLE RWAELG
B89E HANGUL SYLLABLE RWAELM
B89F HANGUL SYLLABLE RWAELB
B8A0 HANGUL SYLLABLE RWAELS
B8A1 HANGUL SYLLABLE RWAELT
B8A2 HANGUL SYLLABLE RWAELP
B8A3 HANGUL SYLLABLE RWAELH
B8A4 HANGUL SYLLABLE RWAEM
B8A5 HANGUL SYLLABLE RWAEB
B8A6 HANGUL SYLLABLE RWAEBS
B8A7 HANGUL SYLLABLE RWAES
B8A8 HANGUL SYLLABLE RWAESS
B8A9 HANGUL SYLLABLE RWAENG
B8AA HANGUL SYLLABLE RWAEJ
B8AB HANGUL SYLLABLE RWAEC
B8AC HANGUL SYLLABLE RWAEK
B8AD HANGUL SYLLABLE RWAET
B8AE HANGUL SYLLABLE RWAEP
B8AF HANGUL SYLLABLE RWAEH
B8B0 HANGUL SYLLABLE ROE
B8B1 HANGUL SYLLABLE ROEG
B8B2 HANGUL SYLLABLE ROEGG
B8B3 HANGUL SYLLABLE ROEGS
B8B4 HANGUL SYLLABLE ROEN
B8B5 HANGUL SYLLABLE ROENJ
B8B6 HANGUL SYLLABLE ROENH
B8B7 HANGUL SYLLABLE ROED
B8B8 HANGUL SYLLABLE ROEL
B8B9 HANGUL SYLLABLE ROELG
B8BA HANGUL SYLLABLE ROELM
B8BB HANGUL SYLLABLE ROELB
B8BC HANGUL SYLLABLE ROELS
B8BD HANGUL SYLLABLE ROELT
B8BE HANGUL SYLLABLE ROELP
B8BF HANGUL SYLLABLE ROELH
B8C0 HANGUL SYLLABLE ROEM
B8C1 HANGUL SYLLABLE ROEB
B8C2 HANGUL SYLLABLE ROEBS
B8C3 HANGUL SYLLABLE ROES
B8C4 HANGUL SYLLABLE ROESS
B8C5 HANGUL SYLLABLE ROENG
B8C6 HANGUL SYLLABLE ROEJ
B8C7 HANGUL SYLLABLE ROEC
B8C8 HANGUL SYLLABLE ROEK
B8C9 HANGUL SYLLABLE ROET
B8CA HANGUL SYLLABLE ROEP
B8CB HANGUL SYLLABLE ROEH
B8CC HANGUL SYLLABLE RYO
B8CD HANGUL SYLLABLE RYOG
B8CE HANGUL SYLLABLE RYOGG
B8CF HANGUL SYLLABLE RYOGS
B8D0 HANGUL SYLLABLE RYON
B8D1 HANGUL SYLLABLE RYONJ
B8D2 HANGUL SYLLABLE RYONH
B8D3 HANGUL SYLLABLE RYOD
B8D4 HANGUL SYLLABLE RYOL
B8D5 HANGUL SYLLABLE RYOLG
B8D6 HANGUL SYLLABLE RYOLM
B8D7 HANGUL SYLLABLE RYOLB
B8D8 HANGUL SYLLABLE RYOLS
B8D9 HANGUL SYLLABLE RYOLT
B8DA HANGUL SYLLABLE RYOLP
B8DB HANGUL SYLLABLE RYOLH
B8DC HANGUL SYLLABLE RYOM
B8DD HANGUL SYLLABLE RYOB
B8DE HANGUL SYLLABLE RYOBS
B8DF HANGUL SYLLABLE RYOS
B8E0 HANGUL SYLLABLE RYOSS
B8E1 HANGUL SYLLABLE RYONG
B8E2 HANGUL SYLLABLE RYOJ
B8E3 HANGUL SYLLABLE RYOC
B8E4 HANGUL SYLLABLE RYOK
B8E5 HANGUL SYLLABLE RYOT
B8E6 HANGUL SYLLABLE RYOP
B8E7 HANGUL SYLLABLE RYOH
B8E8 HANGUL SYLLABLE RU
B8E9 HANGUL SYLLABLE RUG
B8EA HANGUL SYLLABLE RUGG
B8EB HANGUL SYLLABLE RUGS
B8EC HANGUL SYLLABLE RUN
B8ED HANGUL SYLLABLE RUNJ
B8EE HANGUL SYLLABLE RUNH
B8EF HANGUL SYLLABLE RUD
B8F0 HANGUL SYLLABLE RUL
B8F1 HANGUL SYLLABLE RULG
B8F2 HANGUL SYLLABLE RULM
B8F3 HANGUL SYLLABLE RULB
B8F4 HANGUL SYLLABLE RULS
B8F5 HANGUL SYLLABLE RULT
B8F6 HANGUL SYLLABLE RULP
B8F7 HANGUL SYLLABLE RULH
B8F8 HANGUL SYLLABLE RUM
B8F9 HANGUL SYLLABLE RUB
B8FA HANGUL SYLLABLE RUBS
B8FB HANGUL SYLLABLE RUS
B8FC HANGUL SYLLABLE RUSS
B8FD HANGUL SYLLABLE RUNG
B8FE HANGUL SYLLABLE RUJ
B8FF HANGUL SYLLABLE RUC
B900 HANGUL SYLLABLE RUK
B901 HANGUL SYLLABLE RUT
B902 HANGUL SYLLABLE RUP
B903 HANGUL SYLLABLE RUH
B904 HANGUL SYLLABLE RWEO
B905 HANGUL SYLLABLE RWEOG
B906 HANGUL SYLLABLE RWEOGG
B907 HANGUL SYLLABLE RWEOGS
B908 HANGUL SYLLABLE RWEON
B909 HANGUL SYLLABLE RWEONJ
B90A HANGUL SYLLABLE RWEONH
B90B HANGUL SYLLABLE RWEOD
B90C HANGUL SYLLABLE RWEOL
B90D HANGUL SYLLABLE RWEOLG
B90E HANGUL SYLLABLE RWEOLM
B90F HANGUL SYLLABLE RWEOLB
B910 HANGUL SYLLABLE RWEOLS
B911 HANGUL SYLLABLE RWEOLT
B912 HANGUL SYLLABLE RWEOLP
B913 HANGUL SYLLABLE RWEOLH
B914 HANGUL SYLLABLE RWEOM
B915 HANGUL SYLLABLE RWEOB
B916 HANGUL SYLLABLE RWEOBS
B917 HANGUL SYLLABLE RWEOS
B918 HANGUL SYLLABLE RWEOSS
B919 HANGUL SYLLABLE RWEONG
B91A HANGUL SYLLABLE RWEOJ
B91B HANGUL SYLLABLE RWEOC
B91C HANGUL SYLLABLE RWEOK
B91D HANGUL SYLLABLE RWEOT
B91E HANGUL SYLLABLE RWEOP
B91F HANGUL SYLLABLE RWEOH
B920 HANGUL SYLLABLE RWE
B921 HANGUL SYLLABLE RWEG
B922 HANGUL SYLLABLE RWEGG
B923 HANGUL SYLLABLE RWEGS
B924 HANGUL SYLLABLE RWEN
B925 HANGUL SYLLABLE RWENJ
B926 HANGUL SYLLABLE RWENH
B927 HANGUL SYLLABLE RWED
B928 HANGUL SYLLABLE RWEL
B929 HANGUL SYLLABLE RWELG
B92A HANGUL SYLLABLE RWELM
B92B HANGUL SYLLABLE RWELB
B92C HANGUL SYLLABLE RWELS
B92D HANGUL SYLLABLE RWELT
B92E HANGUL SYLLABLE RWELP
B92F HANGUL SYLLABLE RWELH
B930 HANGUL SYLLABLE RWEM
B931 HANGUL SYLLABLE RWEB
B932 HANGUL SYLLABLE RWEBS
B933 HANGUL SYLLABLE RWES
B934 HANGUL SYLLABLE RWESS
B935 HANGUL SYLLABLE RWENG
B936 HANGUL SYLLABLE RWEJ
B937 HANGUL SYLLABLE RWEC
B938 HANGUL SYLLABLE RWEK
B939 HANGUL SYLLABLE RWET
B93A HANGUL SYLLABLE RWEP
B93B HANGUL SYLLABLE RWEH
B93C HANGUL SYLLABLE RWI
B93D HANGUL SYLLABLE RWIG
B93E HANGUL SYLLABLE RWIGG
B93F HANGUL SYLLABLE RWIGS
B940 HANGUL SYLLABLE RWIN
B941 HANGUL SYLLABLE RWINJ
B942 HANGUL SYLLABLE RWINH
B943 HANGUL SYLLABLE RWID
B944 HANGUL SYLLABLE RWIL
B945 HANGUL SYLLABLE RWILG
B946 HANGUL SYLLABLE RWILM
B947 HANGUL SYLLABLE RWILB
B948 HANGUL SYLLABLE RWILS
B949 HANGUL SYLLABLE RWILT
B94A HANGUL SYLLABLE RWILP
B94B HANGUL SYLLABLE RWILH
B94C HANGUL SYLLABLE RWIM
B94D HANGUL SYLLABLE RWIB
B94E HANGUL SYLLABLE RWIBS
B94F HANGUL SYLLABLE RWIS
B950 HANGUL SYLLABLE RWISS
B951 HANGUL SYLLABLE RWING
B952 HANGUL SYLLABLE RWIJ
B953 HANGUL SYLLABLE RWIC
B954 HANGUL SYLLABLE RWIK
B955 HANGUL SYLLABLE RWIT
B956 HANGUL SYLLABLE RWIP
B957 HANGUL SYLLABLE RWIH
B958 HANGUL SYLLABLE RYU
B959 HANGUL SYLLABLE RYUG
B95A HANGUL SYLLABLE RYUGG
B95B HANGUL SYLLABLE RYUGS
B95C HANGUL SYLLABLE RYUN
B95D HANGUL SYLLABLE RYUNJ
B95E HANGUL SYLLABLE RYUNH
B95F HANGUL SYLLABLE RYUD
B960 HANGUL SYLLABLE RYUL
B961 HANGUL SYLLABLE RYULG
B962 HANGUL SYLLABLE RYULM
B963 HANGUL SYLLABLE RYULB
B964 HANGUL SYLLABLE RYULS
B965 HANGUL SYLLABLE RYULT
B966 HANGUL SYLLABLE RYULP
B967 HANGUL SYLLABLE RYULH
B968 HANGUL SYLLABLE RYUM
B969 HANGUL SYLLABLE RYUB
B96A HANGUL SYLLABLE RYUBS
B96B HANGUL SYLLABLE RYUS
B96C HANGUL SYLLABLE RYUSS
B96D HANGUL SYLLABLE RYUNG
B96E HANGUL SYLLABLE RYUJ
B96F HANGUL SYLLABLE RYUC
B970 HANGUL SYLLABLE RYUK
B971 HANGUL SYLLABLE RYUT
B972 HANGUL SYLLABLE RYUP
B973 HANGUL SYLLABLE RYUH
B974 HANGUL SYLLABLE REU
B975 HANGUL SYLLABLE REUG
B976 HANGUL SYLLABLE REUGG
B977 HANGUL SYLLABLE REUGS
B978 HANGUL SYLLABLE REUN
B979 HANGUL SYLLABLE REUNJ
B97A HANGUL SYLLABLE REUNH
B97B HANGUL SYLLABLE REUD
B97C HANGUL SYLLABLE REUL
B97D HANGUL SYLLABLE REULG
B97E HANGUL SYLLABLE REULM
B97F HANGUL SYLLABLE REULB
B980 HANGUL SYLLABLE REULS
B981 HANGUL SYLLABLE REULT
B982 HANGUL SYLLABLE REULP
B983 HANGUL SYLLABLE REULH
B984 HANGUL SYLLABLE REUM
B985 HANGUL SYLLABLE REUB
B986 HANGUL SYLLABLE REUBS
B987 HANGUL SYLLABLE REUS
B988 HANGUL SYLLABLE REUSS
B989 HANGUL SYLLABLE REUNG
B98A HANGUL SYLLABLE REUJ
B98B HANGUL SYLLABLE REUC
B98C HANGUL SYLLABLE REUK
B98D HANGUL SYLLABLE REUT
B98E HANGUL SYLLABLE REUP
B98F HANGUL SYLLABLE REUH
B990 HANGUL SYLLABLE RYI
B991 HANGUL SYLLABLE RYIG
B992 HANGUL SYLLABLE RYIGG
B993 HANGUL SYLLABLE RYIGS
B994 HANGUL SYLLABLE RYIN
B995 HANGUL SYLLABLE RYINJ
B996 HANGUL SYLLABLE RYINH
B997 HANGUL SYLLABLE RYID
B998 HANGUL SYLLABLE RYIL
B999 HANGUL SYLLABLE RYILG
B99A HANGUL SYLLABLE RYILM
B99B HANGUL SYLLABLE RYILB
B99C HANGUL SYLLABLE RYILS
B99D HANGUL SYLLABLE RYILT
B99E HANGUL SYLLABLE RYILP
B99F HANGUL SYLLABLE RYILH
B9A0 HANGUL SYLLABLE RYIM
B9A1 HANGUL SYLLABLE RYIB
B9A2 HANGUL SYLLABLE RYIBS
B9A3 HANGUL SYLLABLE RYIS
B9A4 HANGUL SYLLABLE RYISS
B9A5 HANGUL SYLLABLE RYING
B9A6 HANGUL SYLLABLE RYIJ
B9A7 HANGUL SYLLABLE RYIC
B9A8 HANGUL SYLLABLE RYIK
B9A9 HANGUL SYLLABLE RYIT
B9AA HANGUL SYLLABLE RYIP
B9AB HANGUL SYLLABLE RYIH
B9AC HANGUL SYLLABLE RI
B9AD HANGUL SYLLABLE RIG
B9AE HANGUL SYLLABLE RIGG
B9AF HANGUL SYLLABLE RIGS
B9B0 HANGUL SYLLABLE RIN
B9B1 HANGUL SYLLABLE RINJ
B9B2 HANGUL SYLLABLE RINH
B9B3 HANGUL SYLLABLE RID
B9B4 HANGUL SYLLABLE RIL
B9B5 HANGUL SYLLABLE RILG
B9B6 HANGUL SYLLABLE RILM
B9B7 HANGUL SYLLABLE RILB
B9B8 HANGUL SYLLABLE RILS
B9B9 HANGUL SYLLABLE RILT
B9BA HANGUL SYLLABLE RILP
B9BB HANGUL SYLLABLE RILH
B9BC HANGUL SYLLABLE RIM
B9BD HANGUL SYLLABLE RIB
B9BE HANGUL SYLLABLE RIBS
B9BF HANGUL SYLLABLE RIS
B9C0 HANGUL SYLLABLE RISS
B9C1 HANGUL SYLLABLE RING
B9C2 HANGUL SYLLABLE RIJ
B9C3 HANGUL SYLLABLE RIC
B9C4 HANGUL SYLLABLE RIK
B9C5 HANGUL SYLLABLE RIT
B9C6 HANGUL SYLLABLE RIP
B9C7 HANGUL SYLLABLE RIH
B9C8 HANGUL SYLLABLE MA
B9C9 HANGUL SYLLABLE MAG
B9CA HANGUL SYLLABLE MAGG
B9CB HANGUL SYLLABLE MAGS
B9CC HANGUL SYLLABLE MAN
B9CD HANGUL SYLLABLE MANJ
B9CE HANGUL SYLLABLE MANH
B9CF HANGUL SYLLABLE MAD
B9D0 HANGUL SYLLABLE MAL
B9D1 HANGUL SYLLABLE MALG
B9D2 HANGUL SYLLABLE MALM
B9D3 HANGUL SYLLABLE MALB
B9D4 HANGUL SYLLABLE MALS
B9D5 HANGUL SYLLABLE MALT
B9D6 HANGUL SYLLABLE MALP
B9D7 HANGUL SYLLABLE MALH
B9D8 HANGUL SYLLABLE MAM
B9D9 HANGUL SYLLABLE MAB
B9DA HANGUL SYLLABLE MABS
B9DB HANGUL SYLLABLE MAS
B9DC HANGUL SYLLABLE MASS
B9DD HANGUL SYLLABLE MANG
B9DE HANGUL SYLLABLE MAJ
B9DF HANGUL SYLLABLE MAC
B9E0 HANGUL SYLLABLE MAK
B9E1 HANGUL SYLLABLE MAT
B9E2 HANGUL SYLLABLE MAP
B9E3 HANGUL SYLLABLE MAH
B9E4 HANGUL SYLLABLE MAE
B9E5 HANGUL SYLLABLE MAEG
B9E6 HANGUL SYLLABLE MAEGG
B9E7 HANGUL SYLLABLE MAEGS
B9E8 HANGUL SYLLABLE MAEN
B9E9 HANGUL SYLLABLE MAENJ
B9EA HANGUL SYLLABLE MAENH
B9EB HANGUL SYLLABLE MAED
B9EC HANGUL SYLLABLE MAEL
B9ED HANGUL SYLLABLE MAELG
B9EE HANGUL SYLLABLE MAELM
B9EF HANGUL SYLLABLE MAELB
B9F0 HANGUL SYLLABLE MAELS
B9F1 HANGUL SYLLABLE MAELT
B9F2 HANGUL SYLLABLE MAELP
B9F3 HANGUL SYLLABLE MAELH
B9F4 HANGUL SYLLABLE MAEM
B9F5 HANGUL SYLLABLE MAEB
B9F6 HANGUL SYLLABLE MAEBS
B9F7 HANGUL SYLLABLE MAES
B9F8 HANGUL SYLLABLE MAESS
B9F9 HANGUL SYLLABLE MAENG
B9FA HANGUL SYLLABLE MAEJ
B9FB HANGUL SYLLABLE MAEC
B9FC HANGUL SYLLABLE MAEK
B9FD HANGUL SYLLABLE MAET
B9FE HANGUL SYLLABLE MAEP
B9FF HANGUL SYLLABLE MAEH
BA00 HANGUL SYLLABLE MYA
BA01 HANGUL SYLLABLE MYAG
BA02 HANGUL SYLLABLE MYAGG
BA03 HANGUL SYLLABLE MYAGS
BA04 HANGUL SYLLABLE MYAN
BA05 HANGUL SYLLABLE MYANJ
BA06 HANGUL SYLLABLE MYANH
BA07 HANGUL SYLLABLE MYAD
BA08 HANGUL SYLLABLE MYAL
BA09 HANGUL SYLLABLE MYALG
BA0A HANGUL SYLLABLE MYALM
BA0B HANGUL SYLLABLE MYALB
BA0C HANGUL SYLLABLE MYALS
BA0D HANGUL SYLLABLE MYALT
BA0E HANGUL SYLLABLE MYALP
BA0F HANGUL SYLLABLE MYALH
BA10 HANGUL SYLLABLE MYAM
BA11 HANGUL SYLLABLE MYAB
BA12 HANGUL SYLLABLE MYABS
BA13 HANGUL SYLLABLE MYAS
BA14 HANGUL SYLLABLE MYASS
BA15 HANGUL SYLLABLE MYANG
BA16 HANGUL SYLLABLE MYAJ
BA17 HANGUL SYLLABLE MYAC
BA18 HANGUL SYLLABLE MYAK
BA19 HANGUL SYLLABLE MYAT
BA1A HANGUL SYLLABLE MYAP
BA1B HANGUL SYLLABLE MYAH
BA1C HANGUL SYLLABLE MYAE
BA1D HANGUL SYLLABLE MYAEG
BA1E HANGUL SYLLABLE MYAEGG
BA1F HANGUL SYLLABLE MYAEGS
BA20 HANGUL SYLLABLE MYAEN
BA21 HANGUL SYLLABLE MYAENJ
BA22 HANGUL SYLLABLE MYAENH
BA23 HANGUL SYLLABLE MYAED
BA24 HANGUL SYLLABLE MYAEL
BA25 HANGUL SYLLABLE MYAELG
BA26 HANGUL SYLLABLE MYAELM
BA27 HANGUL SYLLABLE MYAELB
BA28 HANGUL SYLLABLE MYAELS
BA29 HANGUL SYLLABLE MYAELT
BA2A HANGUL SYLLABLE MYAELP
BA2B HANGUL SYLLABLE MYAELH
BA2C HANGUL SYLLABLE MYAEM
BA2D HANGUL SYLLABLE MYAEB
BA2E HANGUL SYLLABLE MYAEBS
BA2F HANGUL SYLLABLE MYAES
BA30 HANGUL SYLLABLE MYAESS
BA31 HANGUL SYLLABLE MYAENG
BA32 HANGUL SYLLABLE MYAEJ
BA33 HANGUL SYLLABLE MYAEC
BA34 HANGUL SYLLABLE MYAEK
BA35 HANGUL SYLLABLE MYAET
BA36 HANGUL SYLLABLE MYAEP
BA37 HANGUL SYLLABLE MYAEH
BA38 HANGUL SYLLABLE MEO
BA39 HANGUL SYLLABLE MEOG
BA3A HANGUL SYLLABLE MEOGG
BA3B HANGUL SYLLABLE MEOGS
BA3C HANGUL SYLLABLE MEON
BA3D HANGUL SYLLABLE MEONJ
BA3E HANGUL SYLLABLE MEONH
BA3F HANGUL SYLLABLE MEOD
BA40 HANGUL SYLLABLE MEOL
BA41 HANGUL SYLLABLE MEOLG
BA42 HANGUL SYLLABLE MEOLM
BA43 HANGUL SYLLABLE MEOLB
BA44 HANGUL SYLLABLE MEOLS
BA45 HANGUL SYLLABLE MEOLT
BA46 HANGUL SYLLABLE MEOLP
BA47 HANGUL SYLLABLE MEOLH
BA48 HANGUL SYLLABLE MEOM
BA49 HANGUL SYLLABLE MEOB
BA4A HANGUL SYLLABLE MEOBS
BA4B HANGUL SYLLABLE MEOS
BA4C HANGUL SYLLABLE MEOSS
BA4D HANGUL SYLLABLE MEONG
BA4E HANGUL SYLLABLE MEOJ
BA4F HANGUL SYLLABLE MEOC
BA50 HANGUL SYLLABLE MEOK
BA51 HANGUL SYLLABLE MEOT
BA52 HANGUL SYLLABLE MEOP
BA53 HANGUL SYLLABLE MEOH
BA54 HANGUL SYLLABLE ME
BA55 HANGUL SYLLABLE MEG
BA56 HANGUL SYLLABLE MEGG
BA57 HANGUL SYLLABLE MEGS
BA58 HANGUL SYLLABLE MEN
BA59 HANGUL SYLLABLE MENJ
BA5A HANGUL SYLLABLE MENH
BA5B HANGUL SYLLABLE MED
BA5C HANGUL SYLLABLE MEL
BA5D HANGUL SYLLABLE MELG
BA5E HANGUL SYLLABLE MELM
BA5F HANGUL SYLLABLE MELB
BA60 HANGUL SYLLABLE MELS
BA61 HANGUL SYLLABLE MELT
BA62 HANGUL SYLLABLE MELP
BA63 HANGUL SYLLABLE MELH
BA64 HANGUL SYLLABLE MEM
BA65 HANGUL SYLLABLE MEB
BA66 HANGUL SYLLABLE MEBS
BA67 HANGUL SYLLABLE MES
BA68 HANGUL SYLLABLE MESS
BA69 HANGUL SYLLABLE MENG
BA6A HANGUL SYLLABLE MEJ
BA6B HANGUL SYLLABLE MEC
BA6C HANGUL SYLLABLE MEK
BA6D HANGUL SYLLABLE MET
BA6E HANGUL SYLLABLE MEP
BA6F HANGUL SYLLABLE MEH
BA70 HANGUL SYLLABLE MYEO
BA71 HANGUL SYLLABLE MYEOG
BA72 HANGUL SYLLABLE MYEOGG
BA73 HANGUL SYLLABLE MYEOGS
BA74 HANGUL SYLLABLE MYEON
BA75 HANGUL SYLLABLE MYEONJ
BA76 HANGUL SYLLABLE MYEONH
BA77 HANGUL SYLLABLE MYEOD
BA78 HANGUL SYLLABLE MYEOL
BA79 HANGUL SYLLABLE MYEOLG
BA7A HANGUL SYLLABLE MYEOLM
BA7B HANGUL SYLLABLE MYEOLB
BA7C HANGUL SYLLABLE MYEOLS
BA7D HANGUL SYLLABLE MYEOLT
BA7E HANGUL SYLLABLE MYEOLP
BA7F HANGUL SYLLABLE MYEOLH
BA80 HANGUL SYLLABLE MYEOM
BA81 HANGUL SYLLABLE MYEOB
BA82 HANGUL SYLLABLE MYEOBS
BA83 HANGUL SYLLABLE MYEOS
BA84 HANGUL SYLLABLE MYEOSS
BA85 HANGUL SYLLABLE MYEONG
BA86 HANGUL SYLLABLE MYEOJ
BA87 HANGUL SYLLABLE MYEOC
BA88 HANGUL SYLLABLE MYEOK
BA89 HANGUL SYLLABLE MYEOT
BA8A HANGUL SYLLABLE MYEOP
BA8B HANGUL SYLLABLE MYEOH
BA8C HANGUL SYLLABLE MYE
BA8D HANGUL SYLLABLE MYEG
BA8E HANGUL SYLLABLE MYEGG
BA8F HANGUL SYLLABLE MYEGS
BA90 HANGUL SYLLABLE MYEN
BA91 HANGUL SYLLABLE MYENJ
BA92 HANGUL SYLLABLE MYENH
BA93 HANGUL SYLLABLE MYED
BA94 HANGUL SYLLABLE MYEL
BA95 HANGUL SYLLABLE MYELG
BA96 HANGUL SYLLABLE MYELM
BA97 HANGUL SYLLABLE MYELB
BA98 HANGUL SYLLABLE MYELS
BA99 HANGUL SYLLABLE MYELT
BA9A HANGUL SYLLABLE MYELP
BA9B HANGUL SYLLABLE MYELH
BA9C HANGUL SYLLABLE MYEM
BA9D HANGUL SYLLABLE MYEB
BA9E HANGUL SYLLABLE MYEBS
BA9F HANGUL SYLLABLE MYES
BAA0 HANGUL SYLLABLE MYESS
BAA1 HANGUL SYLLABLE MYENG
BAA2 HANGUL SYLLABLE MYEJ
BAA3 HANGUL SYLLABLE MYEC
BAA4 HANGUL SYLLABLE MYEK
BAA5 HANGUL SYLLABLE MYET
BAA6 HANGUL SYLLABLE MYEP
BAA7 HANGUL SYLLABLE MYEH
BAA8 HANGUL SYLLABLE MO
BAA9 HANGUL SYLLABLE MOG
BAAA HANGUL SYLLABLE MOGG
BAAB HANGUL SYLLABLE MOGS
BAAC HANGUL SYLLABLE MON
BAAD HANGUL SYLLABLE MONJ
BAAE HANGUL SYLLABLE MONH
BAAF HANGUL SYLLABLE MOD
BAB0 HANGUL SYLLABLE MOL
BAB1 HANGUL SYLLABLE MOLG
BAB2 HANGUL SYLLABLE MOLM
BAB3 HANGUL SYLLABLE MOLB
BAB4 HANGUL SYLLABLE MOLS
BAB5 HANGUL SYLLABLE MOLT
BAB6 HANGUL SYLLABLE MOLP
BAB7 HANGUL SYLLABLE MOLH
BAB8 HANGUL SYLLABLE MOM
BAB9 HANGUL SYLLABLE MOB
BABA HANGUL SYLLABLE MOBS
BABB HANGUL SYLLABLE MOS
BABC HANGUL SYLLABLE MOSS
BABD HANGUL SYLLABLE MONG
BABE HANGUL SYLLABLE MOJ
BABF HANGUL SYLLABLE MOC
BAC0 HANGUL SYLLABLE MOK
BAC1 HANGUL SYLLABLE MOT
BAC2 HANGUL SYLLABLE MOP
BAC3 HANGUL SYLLABLE MOH
BAC4 HANGUL SYLLABLE MWA
BAC5 HANGUL SYLLABLE MWAG
BAC6 HANGUL SYLLABLE MWAGG
BAC7 HANGUL SYLLABLE MWAGS
BAC8 HANGUL SYLLABLE MWAN
BAC9 HANGUL SYLLABLE MWANJ
BACA HANGUL SYLLABLE MWANH
BACB HANGUL SYLLABLE MWAD
BACC HANGUL SYLLABLE MWAL
BACD HANGUL SYLLABLE MWALG
BACE HANGUL SYLLABLE MWALM
BACF HANGUL SYLLABLE MWALB
BAD0 HANGUL SYLLABLE MWALS
BAD1 HANGUL SYLLABLE MWALT
BAD2 HANGUL SYLLABLE MWALP
BAD3 HANGUL SYLLABLE MWALH
BAD4 HANGUL SYLLABLE MWAM
BAD5 HANGUL SYLLABLE MWAB
BAD6 HANGUL SYLLABLE MWABS
BAD7 HANGUL SYLLABLE MWAS
BAD8 HANGUL SYLLABLE MWASS
BAD9 HANGUL SYLLABLE MWANG
BADA HANGUL SYLLABLE MWAJ
BADB HANGUL SYLLABLE MWAC
BADC HANGUL SYLLABLE MWAK
BADD HANGUL SYLLABLE MWAT
BADE HANGUL SYLLABLE MWAP
BADF HANGUL SYLLABLE MWAH
BAE0 HANGUL SYLLABLE MWAE
BAE1 HANGUL SYLLABLE MWAEG
BAE2 HANGUL SYLLABLE MWAEGG
BAE3 HANGUL SYLLABLE MWAEGS
BAE4 HANGUL SYLLABLE MWAEN
BAE5 HANGUL SYLLABLE MWAENJ
BAE6 HANGUL SYLLABLE MWAENH
BAE7 HANGUL SYLLABLE MWAED
BAE8 HANGUL SYLLABLE MWAEL
BAE9 HANGUL SYLLABLE MWAELG
BAEA HANGUL SYLLABLE MWAELM
BAEB HANGUL SYLLABLE MWAELB
BAEC HANGUL SYLLABLE MWAELS
BAED HANGUL SYLLABLE MWAELT
BAEE HANGUL SYLLABLE MWAELP
BAEF HANGUL SYLLABLE MWAELH
BAF0 HANGUL SYLLABLE MWAEM
BAF1 HANGUL SYLLABLE MWAEB
BAF2 HANGUL SYLLABLE MWAEBS
BAF3 HANGUL SYLLABLE MWAES
BAF4 HANGUL SYLLABLE MWAESS
BAF5 HANGUL SYLLABLE MWAENG
BAF6 HANGUL SYLLABLE MWAEJ
BAF7 HANGUL SYLLABLE MWAEC
BAF8 HANGUL SYLLABLE MWAEK
BAF9 HANGUL SYLLABLE MWAET
BAFA HANGUL SYLLABLE MWAEP
BAFB HANGUL SYLLABLE MWAEH
BAFC HANGUL SYLLABLE MOE
BAFD HANGUL SYLLABLE MOEG
BAFE HANGUL SYLLABLE MOEGG
BAFF HANGUL SYLLABLE MOEGS
BB00 HANGUL SYLLABLE MOEN
BB01 HANGUL SYLLABLE MOENJ
BB02 HANGUL SYLLABLE MOENH
BB03 HANGUL SYLLABLE MOED
BB04 HANGUL SYLLABLE MOEL
BB05 HANGUL SYLLABLE MOELG
BB06 HANGUL SYLLABLE MOELM
BB07 HANGUL SYLLABLE MOELB
BB08 HANGUL SYLLABLE MOELS
BB09 HANGUL SYLLABLE MOELT
BB0A HANGUL SYLLABLE MOELP
BB0B HANGUL SYLLABLE MOELH
BB0C HANGUL SYLLABLE MOEM
BB0D HANGUL SYLLABLE MOEB
BB0E HANGUL SYLLABLE MOEBS
BB0F HANGUL SYLLABLE MOES
BB10 HANGUL SYLLABLE MOESS
BB11 HANGUL SYLLABLE MOENG
BB12 HANGUL SYLLABLE MOEJ
BB13 HANGUL SYLLABLE MOEC
BB14 HANGUL SYLLABLE MOEK
BB15 HANGUL SYLLABLE MOET
BB16 HANGUL SYLLABLE MOEP
BB17 HANGUL SYLLABLE MOEH
BB18 HANGUL SYLLABLE MYO
BB19 HANGUL SYLLABLE MYOG
BB1A HANGUL SYLLABLE MYOGG
BB1B HANGUL SYLLABLE MYOGS
BB1C HANGUL SYLLABLE MYON
BB1D HANGUL SYLLABLE MYONJ
BB1E HANGUL SYLLABLE MYONH
BB1F HANGUL SYLLABLE MYOD
BB20 HANGUL SYLLABLE MYOL
BB21 HANGUL SYLLABLE MYOLG
BB22 HANGUL SYLLABLE MYOLM
BB23 HANGUL SYLLABLE MYOLB
BB24 HANGUL SYLLABLE MYOLS
BB25 HANGUL SYLLABLE MYOLT
BB26 HANGUL SYLLABLE MYOLP
BB27 HANGUL SYLLABLE MYOLH
BB28 HANGUL SYLLABLE MYOM
BB29 HANGUL SYLLABLE MYOB
BB2A HANGUL SYLLABLE MYOBS
BB2B HANGUL SYLLABLE MYOS
BB2C HANGUL SYLLABLE MYOSS
BB2D HANGUL SYLLABLE MYONG
BB2E HANGUL SYLLABLE MYOJ
BB2F HANGUL SYLLABLE MYOC
BB30 HANGUL SYLLABLE MYOK
BB31 HANGUL SYLLABLE MYOT
BB32 HANGUL SYLLABLE MYOP
BB33 HANGUL SYLLABLE MYOH
BB34 HANGUL SYLLABLE MU
BB35 HANGUL SYLLABLE MUG
BB36 HANGUL SYLLABLE MUGG
BB37 HANGUL SYLLABLE MUGS
BB38 HANGUL SYLLABLE MUN
BB39 HANGUL SYLLABLE MUNJ
BB3A HANGUL SYLLABLE MUNH
BB3B HANGUL SYLLABLE MUD
BB3C HANGUL SYLLABLE MUL
BB3D HANGUL SYLLABLE MULG
BB3E HANGUL SYLLABLE MULM
BB3F HANGUL SYLLABLE MULB
BB40 HANGUL SYLLABLE MULS
BB41 HANGUL SYLLABLE MULT
BB42 HANGUL SYLLABLE MULP
BB43 HANGUL SYLLABLE MULH
BB44 HANGUL SYLLABLE MUM
BB45 HANGUL SYLLABLE MUB
BB46 HANGUL SYLLABLE MUBS
BB47 HANGUL SYLLABLE MUS
BB48 HANGUL SYLLABLE MUSS
BB49 HANGUL SYLLABLE MUNG
BB4A HANGUL SYLLABLE MUJ
BB4B HANGUL SYLLABLE MUC
BB4C HANGUL SYLLABLE MUK
BB4D HANGUL SYLLABLE MUT
BB4E HANGUL SYLLABLE MUP
BB4F HANGUL SYLLABLE MUH
BB50 HANGUL SYLLABLE MWEO
BB51 HANGUL SYLLABLE MWEOG
BB52 HANGUL SYLLABLE MWEOGG
BB53 HANGUL SYLLABLE MWEOGS
BB54 HANGUL SYLLABLE MWEON
BB55 HANGUL SYLLABLE MWEONJ
BB56 HANGUL SYLLABLE MWEONH
BB57 HANGUL SYLLABLE MWEOD
BB58 HANGUL SYLLABLE MWEOL
BB59 HANGUL SYLLABLE MWEOLG
BB5A HANGUL SYLLABLE MWEOLM
BB5B HANGUL SYLLABLE MWEOLB
BB5C HANGUL SYLLABLE MWEOLS
BB5D HANGUL SYLLABLE MWEOLT
BB5E HANGUL SYLLABLE MWEOLP
BB5F HANGUL SYLLABLE MWEOLH
BB60 HANGUL SYLLABLE MWEOM
BB61 HANGUL SYLLABLE MWEOB
BB62 HANGUL SYLLABLE MWEOBS
BB63 HANGUL SYLLABLE MWEOS
BB64 HANGUL SYLLABLE MWEOSS
BB65 HANGUL SYLLABLE MWEONG
BB66 HANGUL SYLLABLE MWEOJ
BB67 HANGUL SYLLABLE MWEOC
BB68 HANGUL SYLLABLE MWEOK
BB69 HANGUL SYLLABLE MWEOT
BB6A HANGUL SYLLABLE MWEOP
BB6B HANGUL SYLLABLE MWEOH
BB6C HANGUL SYLLABLE MWE
BB6D HANGUL SYLLABLE MWEG
BB6E HANGUL SYLLABLE MWEGG
BB6F HANGUL SYLLABLE MWEGS
BB70 HANGUL SYLLABLE MWEN
BB71 HANGUL SYLLABLE MWENJ
BB72 HANGUL SYLLABLE MWENH
BB73 HANGUL SYLLABLE MWED
BB74 HANGUL SYLLABLE MWEL
BB75 HANGUL SYLLABLE MWELG
BB76 HANGUL SYLLABLE MWELM
BB77 HANGUL SYLLABLE MWELB
BB78 HANGUL SYLLABLE MWELS
BB79 HANGUL SYLLABLE MWELT
BB7A HANGUL SYLLABLE MWELP
BB7B HANGUL SYLLABLE MWELH
BB7C HANGUL SYLLABLE MWEM
BB7D HANGUL SYLLABLE MWEB
BB7E HANGUL SYLLABLE MWEBS
BB7F HANGUL SYLLABLE MWES
BB80 HANGUL SYLLABLE MWESS
BB81 HANGUL SYLLABLE MWENG
BB82 HANGUL SYLLABLE MWEJ
BB83 HANGUL SYLLABLE MWEC
BB84 HANGUL SYLLABLE MWEK
BB85 HANGUL SYLLABLE MWET
BB86 HANGUL SYLLABLE MWEP
BB87 HANGUL SYLLABLE MWEH
BB88 HANGUL SYLLABLE MWI
BB89 HANGUL SYLLABLE MWIG
BB8A HANGUL SYLLABLE MWIGG
BB8B HANGUL SYLLABLE MWIGS
BB8C HANGUL SYLLABLE MWIN
BB8D HANGUL SYLLABLE MWINJ
BB8E HANGUL SYLLABLE MWINH
BB8F HANGUL SYLLABLE MWID
BB90 HANGUL SYLLABLE MWIL
BB91 HANGUL SYLLABLE MWILG
BB92 HANGUL SYLLABLE MWILM
BB93 HANGUL SYLLABLE MWILB
BB94 HANGUL SYLLABLE MWILS
BB95 HANGUL SYLLABLE MWILT
BB96 HANGUL SYLLABLE MWILP
BB97 HANGUL SYLLABLE MWILH
BB98 HANGUL SYLLABLE MWIM
BB99 HANGUL SYLLABLE MWIB
BB9A HANGUL SYLLABLE MWIBS
BB9B HANGUL SYLLABLE MWIS
BB9C HANGUL SYLLABLE MWISS
BB9D HANGUL SYLLABLE MWING
BB9E HANGUL SYLLABLE MWIJ
BB9F HANGUL SYLLABLE MWIC
BBA0 HANGUL SYLLABLE MWIK
BBA1 HANGUL SYLLABLE MWIT
BBA2 HANGUL SYLLABLE MWIP
BBA3 HANGUL SYLLABLE MWIH
BBA4 HANGUL SYLLABLE MYU
BBA5 HANGUL SYLLABLE MYUG
BBA6 HANGUL SYLLABLE MYUGG
BBA7 HANGUL SYLLABLE MYUGS
BBA8 HANGUL SYLLABLE MYUN
BBA9 HANGUL SYLLABLE MYUNJ
BBAA HANGUL SYLLABLE MYUNH
BBAB HANGUL SYLLABLE MYUD
BBAC HANGUL SYLLABLE MYUL
BBAD HANGUL SYLLABLE MYULG
BBAE HANGUL SYLLABLE MYULM
BBAF HANGUL SYLLABLE MYULB
BBB0 HANGUL SYLLABLE MYULS
BBB1 HANGUL SYLLABLE MYULT
BBB2 HANGUL SYLLABLE MYULP
BBB3 HANGUL SYLLABLE MYULH
BBB4 HANGUL SYLLABLE MYUM
BBB5 HANGUL SYLLABLE MYUB
BBB6 HANGUL SYLLABLE MYUBS
BBB7 HANGUL SYLLABLE MYUS
BBB8 HANGUL SYLLABLE MYUSS
BBB9 HANGUL SYLLABLE MYUNG
BBBA HANGUL SYLLABLE MYUJ
BBBB HANGUL SYLLABLE MYUC
BBBC HANGUL SYLLABLE MYUK
BBBD HANGUL SYLLABLE MYUT
BBBE HANGUL SYLLABLE MYUP
BBBF HANGUL SYLLABLE MYUH
BBC0 HANGUL SYLLABLE MEU
BBC1 HANGUL SYLLABLE MEUG
BBC2 HANGUL SYLLABLE MEUGG
BBC3 HANGUL SYLLABLE MEUGS
BBC4 HANGUL SYLLABLE MEUN
BBC5 HANGUL SYLLABLE MEUNJ
BBC6 HANGUL SYLLABLE MEUNH
BBC7 HANGUL SYLLABLE MEUD
BBC8 HANGUL SYLLABLE MEUL
BBC9 HANGUL SYLLABLE MEULG
BBCA HANGUL SYLLABLE MEULM
BBCB HANGUL SYLLABLE MEULB
BBCC HANGUL SYLLABLE MEULS
BBCD HANGUL SYLLABLE MEULT
BBCE HANGUL SYLLABLE MEULP
BBCF HANGUL SYLLABLE MEULH
BBD0 HANGUL SYLLABLE MEUM
BBD1 HANGUL SYLLABLE MEUB
BBD2 HANGUL SYLLABLE MEUBS
BBD3 HANGUL SYLLABLE MEUS
BBD4 HANGUL SYLLABLE MEUSS
BBD5 HANGUL SYLLABLE MEUNG
BBD6 HANGUL SYLLABLE MEUJ
BBD7 HANGUL SYLLABLE MEUC
BBD8 HANGUL SYLLABLE MEUK
BBD9 HANGUL SYLLABLE MEUT
BBDA HANGUL SYLLABLE MEUP
BBDB HANGUL SYLLABLE MEUH
BBDC HANGUL SYLLABLE MYI
BBDD HANGUL SYLLABLE MYIG
BBDE HANGUL SYLLABLE MYIGG
BBDF HANGUL SYLLABLE MYIGS
BBE0 HANGUL SYLLABLE MYIN
BBE1 HANGUL SYLLABLE MYINJ
BBE2 HANGUL SYLLABLE MYINH
BBE3 HANGUL SYLLABLE MYID
BBE4 HANGUL SYLLABLE MYIL
BBE5 HANGUL SYLLABLE MYILG
BBE6 HANGUL SYLLABLE MYILM
BBE7 HANGUL SYLLABLE MYILB
BBE8 HANGUL SYLLABLE MYILS
BBE9 HANGUL SYLLABLE MYILT
BBEA HANGUL SYLLABLE MYILP
BBEB HANGUL SYLLABLE MYILH
BBEC HANGUL SYLLABLE MYIM
BBED HANGUL SYLLABLE MYIB
BBEE HANGUL SYLLABLE MYIBS
BBEF HANGUL SYLLABLE MYIS
BBF0 HANGUL SYLLABLE MYISS
BBF1 HANGUL SYLLABLE MYING
BBF2 HANGUL SYLLABLE MYIJ
BBF3 HANGUL SYLLABLE MYIC
BBF4 HANGUL SYLLABLE MYIK
BBF5 HANGUL SYLLABLE MYIT
BBF6 HANGUL SYLLABLE MYIP
BBF7 HANGUL SYLLABLE MYIH
BBF8 HANGUL SYLLABLE MI
BBF9 HANGUL SYLLABLE MIG
BBFA HANGUL SYLLABLE MIGG
BBFB HANGUL SYLLABLE MIGS
BBFC HANGUL SYLLABLE MIN
BBFD HANGUL SYLLABLE MINJ
BBFE HANGUL SYLLABLE MINH
BBFF HANGUL SYLLABLE MID
BC00 HANGUL SYLLABLE MIL
BC01 HANGUL SYLLABLE MILG
BC02 HANGUL SYLLABLE MILM
BC03 HANGUL SYLLABLE MILB
BC04 HANGUL SYLLABLE MILS
BC05 HANGUL SYLLABLE MILT
BC06 HANGUL SYLLABLE MILP
BC07 HANGUL SYLLABLE MILH
BC08 HANGUL SYLLABLE MIM
BC09 HANGUL SYLLABLE MIB
BC0A HANGUL SYLLABLE MIBS
BC0B HANGUL SYLLABLE MIS
BC0C HANGUL SYLLABLE MISS
BC0D HANGUL SYLLABLE MING
BC0E HANGUL SYLLABLE MIJ
BC0F HANGUL SYLLABLE MIC
BC10 HANGUL SYLLABLE MIK
BC11 HANGUL SYLLABLE MIT
BC12 HANGUL SYLLABLE MIP
BC13 HANGUL SYLLABLE MIH
BC14 HANGUL SYLLABLE BA
BC15 HANGUL SYLLABLE BAG
BC16 HANGUL SYLLABLE BAGG
BC17 HANGUL SYLLABLE BAGS
BC18 HANGUL SYLLABLE BAN
BC19 HANGUL SYLLABLE BANJ
BC1A HANGUL SYLLABLE BANH
BC1B HANGUL SYLLABLE BAD
BC1C HANGUL SYLLABLE BAL
BC1D HANGUL SYLLABLE BALG
BC1E HANGUL SYLLABLE BALM
BC1F HANGUL SYLLABLE BALB
BC20 HANGUL SYLLABLE BALS
BC21 HANGUL SYLLABLE BALT
BC22 HANGUL SYLLABLE BALP
BC23 HANGUL SYLLABLE BALH
BC24 HANGUL SYLLABLE BAM
BC25 HANGUL SYLLABLE BAB
BC26 HANGUL SYLLABLE BABS
BC27 HANGUL SYLLABLE BAS
BC28 HANGUL SYLLABLE BASS
BC29 HANGUL SYLLABLE BANG
BC2A HANGUL SYLLABLE BAJ
BC2B HANGUL SYLLABLE BAC
BC2C HANGUL SYLLABLE BAK
BC2D HANGUL SYLLABLE BAT
BC2E HANGUL SYLLABLE BAP
BC2F HANGUL SYLLABLE BAH
BC30 HANGUL SYLLABLE BAE
BC31 HANGUL SYLLABLE BAEG
BC32 HANGUL SYLLABLE BAEGG
BC33 HANGUL SYLLABLE BAEGS
BC34 HANGUL SYLLABLE BAEN
BC35 HANGUL SYLLABLE BAENJ
BC36 HANGUL SYLLABLE BAENH
BC37 HANGUL SYLLABLE BAED
BC38 HANGUL SYLLABLE BAEL
BC39 HANGUL SYLLABLE BAELG
BC3A HANGUL SYLLABLE BAELM
BC3B HANGUL SYLLABLE BAELB
BC3C HANGUL SYLLABLE BAELS
BC3D HANGUL SYLLABLE BAELT
BC3E HANGUL SYLLABLE BAELP
BC3F HANGUL SYLLABLE BAELH
BC40 HANGUL SYLLABLE BAEM
BC41 HANGUL SYLLABLE BAEB
BC42 HANGUL SYLLABLE BAEBS
BC43 HANGUL SYLLABLE BAES
BC44 HANGUL SYLLABLE BAESS
BC45 HANGUL SYLLABLE BAENG
BC46 HANGUL SYLLABLE BAEJ
BC47 HANGUL SYLLABLE BAEC
BC48 HANGUL SYLLABLE BAEK
BC49 HANGUL SYLLABLE BAET
BC4A HANGUL SYLLABLE BAEP
BC4B HANGUL SYLLABLE BAEH
BC4C HANGUL SYLLABLE BYA
BC4D HANGUL SYLLABLE BYAG
BC4E HANGUL SYLLABLE BYAGG
BC4F HANGUL SYLLABLE BYAGS
BC50 HANGUL SYLLABLE BYAN
BC51 HANGUL SYLLABLE BYANJ
BC52 HANGUL SYLLABLE BYANH
BC53 HANGUL SYLLABLE BYAD
BC54 HANGUL SYLLABLE BYAL
BC55 HANGUL SYLLABLE BYALG
BC56 HANGUL SYLLABLE BYALM
BC57 HANGUL SYLLABLE BYALB
BC58 HANGUL SYLLABLE BYALS
BC59 HANGUL SYLLABLE BYALT
BC5A HANGUL SYLLABLE BYALP
BC5B HANGUL SYLLABLE BYALH
BC5C HANGUL SYLLABLE BYAM
BC5D HANGUL SYLLABLE BYAB
BC5E HANGUL SYLLABLE BYABS
BC5F HANGUL SYLLABLE BYAS
BC60 HANGUL SYLLABLE BYASS
BC61 HANGUL SYLLABLE BYANG
BC62 HANGUL SYLLABLE BYAJ
BC63 HANGUL SYLLABLE BYAC
BC64 HANGUL SYLLABLE BYAK
BC65 HANGUL SYLLABLE BYAT
BC66 HANGUL SYLLABLE BYAP
BC67 HANGUL SYLLABLE BYAH
BC68 HANGUL SYLLABLE BYAE
BC69 HANGUL SYLLABLE BYAEG
BC6A HANGUL SYLLABLE BYAEGG
BC6B HANGUL SYLLABLE BYAEGS
BC6C HANGUL SYLLABLE BYAEN
BC6D HANGUL SYLLABLE BYAENJ
BC6E HANGUL SYLLABLE BYAENH
BC6F HANGUL SYLLABLE BYAED
BC70 HANGUL SYLLABLE BYAEL
BC71 HANGUL SYLLABLE BYAELG
BC72 HANGUL SYLLABLE BYAELM
BC73 HANGUL SYLLABLE BYAELB
BC74 HANGUL SYLLABLE BYAELS
BC75 HANGUL SYLLABLE BYAELT
BC76 HANGUL SYLLABLE BYAELP
BC77 HANGUL SYLLABLE BYAELH
BC78 HANGUL SYLLABLE BYAEM
BC79 HANGUL SYLLABLE BYAEB
BC7A HANGUL SYLLABLE BYAEBS
BC7B HANGUL SYLLABLE BYAES
BC7C HANGUL SYLLABLE BYAESS
BC7D HANGUL SYLLABLE BYAENG
BC7E HANGUL SYLLABLE BYAEJ
BC7F HANGUL SYLLABLE BYAEC
BC80 HANGUL SYLLABLE BYAEK
BC81 HANGUL SYLLABLE BYAET
BC82 HANGUL SYLLABLE BYAEP
BC83 HANGUL SYLLABLE BYAEH
BC84 HANGUL SYLLABLE BEO
BC85 HANGUL SYLLABLE BEOG
BC86 HANGUL SYLLABLE BEOGG
BC87 HANGUL SYLLABLE BEOGS
BC88 HANGUL SYLLABLE BEON
BC89 HANGUL SYLLABLE BEONJ
BC8A HANGUL SYLLABLE BEONH
BC8B HANGUL SYLLABLE BEOD
BC8C HANGUL SYLLABLE BEOL
BC8D HANGUL SYLLABLE BEOLG
BC8E HANGUL SYLLABLE BEOLM
BC8F HANGUL SYLLABLE BEOLB
BC90 HANGUL SYLLABLE BEOLS
BC91 HANGUL SYLLABLE BEOLT
BC92 HANGUL SYLLABLE BEOLP
BC93 HANGUL SYLLABLE BEOLH
BC94 HANGUL SYLLABLE BEOM
BC95 HANGUL SYLLABLE BEOB
BC96 HANGUL SYLLABLE BEOBS
BC97 HANGUL SYLLABLE BEOS
BC98 HANGUL SYLLABLE BEOSS
BC99 HANGUL SYLLABLE BEONG
BC9A HANGUL SYLLABLE BEOJ
BC9B HANGUL SYLLABLE BEOC
BC9C HANGUL SYLLABLE BEOK
BC9D HANGUL SYLLABLE BEOT
BC9E HANGUL SYLLABLE BEOP
BC9F HANGUL SYLLABLE BEOH
BCA0 HANGUL SYLLABLE BE
BCA1 HANGUL SYLLABLE BEG
BCA2 HANGUL SYLLABLE BEGG
BCA3 HANGUL SYLLABLE BEGS
BCA4 HANGUL SYLLABLE BEN
BCA5 HANGUL SYLLABLE BENJ
BCA6 HANGUL SYLLABLE BENH
BCA7 HANGUL SYLLABLE BED
BCA8 HANGUL SYLLABLE BEL
BCA9 HANGUL SYLLABLE BELG
BCAA HANGUL SYLLABLE BELM
BCAB HANGUL SYLLABLE BELB
BCAC HANGUL SYLLABLE BELS
BCAD HANGUL SYLLABLE BELT
BCAE HANGUL SYLLABLE BELP
BCAF HANGUL SYLLABLE BELH
BCB0 HANGUL SYLLABLE BEM
BCB1 HANGUL SYLLABLE BEB
BCB2 HANGUL SYLLABLE BEBS
BCB3 HANGUL SYLLABLE BES
BCB4 HANGUL SYLLABLE BESS
BCB5 HANGUL SYLLABLE BENG
BCB6 HANGUL SYLLABLE BEJ
BCB7 HANGUL SYLLABLE BEC
BCB8 HANGUL SYLLABLE BEK
BCB9 HANGUL SYLLABLE BET
BCBA HANGUL SYLLABLE BEP
BCBB HANGUL SYLLABLE BEH
BCBC HANGUL SYLLABLE BYEO
BCBD HANGUL SYLLABLE BYEOG
BCBE HANGUL SYLLABLE BYEOGG
BCBF HANGUL SYLLABLE BYEOGS
BCC0 HANGUL SYLLABLE BYEON
BCC1 HANGUL SYLLABLE BYEONJ
BCC2 HANGUL SYLLABLE BYEONH
BCC3 HANGUL SYLLABLE BYEOD
BCC4 HANGUL SYLLABLE BYEOL
BCC5 HANGUL SYLLABLE BYEOLG
BCC6 HANGUL SYLLABLE BYEOLM
BCC7 HANGUL SYLLABLE BYEOLB
BCC8 HANGUL SYLLABLE BYEOLS
BCC9 HANGUL SYLLABLE BYEOLT
BCCA HANGUL SYLLABLE BYEOLP
BCCB HANGUL SYLLABLE BYEOLH
BCCC HANGUL SYLLABLE BYEOM
BCCD HANGUL SYLLABLE BYEOB
BCCE HANGUL SYLLABLE BYEOBS
BCCF HANGUL SYLLABLE BYEOS
BCD0 HANGUL SYLLABLE BYEOSS
BCD1 HANGUL SYLLABLE BYEONG
BCD2 HANGUL SYLLABLE BYEOJ
BCD3 HANGUL SYLLABLE BYEOC
BCD4 HANGUL SYLLABLE BYEOK
BCD5 HANGUL SYLLABLE BYEOT
BCD6 HANGUL SYLLABLE BYEOP
BCD7 HANGUL SYLLABLE BYEOH
BCD8 HANGUL SYLLABLE BYE
BCD9 HANGUL SYLLABLE BYEG
BCDA HANGUL SYLLABLE BYEGG
BCDB HANGUL SYLLABLE BYEGS
BCDC HANGUL SYLLABLE BYEN
BCDD HANGUL SYLLABLE BYENJ
BCDE HANGUL SYLLABLE BYENH
BCDF HANGUL SYLLABLE BYED
BCE0 HANGUL SYLLABLE BYEL
BCE1 HANGUL SYLLABLE BYELG
BCE2 HANGUL SYLLABLE BYELM
BCE3 HANGUL SYLLABLE BYELB
BCE4 HANGUL SYLLABLE BYELS
BCE5 HANGUL SYLLABLE BYELT
BCE6 HANGUL SYLLABLE BYELP
BCE7 HANGUL SYLLABLE BYELH
BCE8 HANGUL SYLLABLE BYEM
BCE9 HANGUL SYLLABLE BYEB
BCEA HANGUL SYLLABLE BYEBS
BCEB HANGUL SYLLABLE BYES
BCEC HANGUL SYLLABLE BYESS
BCED HANGUL SYLLABLE BYENG
BCEE HANGUL SYLLABLE BYEJ
BCEF HANGUL SYLLABLE BYEC
BCF0 HANGUL SYLLABLE BYEK
BCF1 HANGUL SYLLABLE BYET
BCF2 HANGUL SYLLABLE BYEP
BCF3 HANGUL SYLLABLE BYEH
BCF4 HANGUL SYLLABLE BO
BCF5 HANGUL SYLLABLE BOG
BCF6 HANGUL SYLLABLE BOGG
BCF7 HANGUL SYLLABLE BOGS
BCF8 HANGUL SYLLABLE BON
BCF9 HANGUL SYLLABLE BONJ
BCFA HANGUL SYLLABLE BONH
BCFB HANGUL SYLLABLE BOD
BCFC HANGUL SYLLABLE BOL
BCFD HANGUL SYLLABLE BOLG
BCFE HANGUL SYLLABLE BOLM
BCFF HANGUL SYLLABLE BOLB
BD00 HANGUL SYLLABLE BOLS
BD01 HANGUL SYLLABLE BOLT
BD02 HANGUL SYLLABLE BOLP
BD03 HANGUL SYLLABLE BOLH
BD04 HANGUL SYLLABLE BOM
BD05 HANGUL SYLLABLE BOB
BD06 HANGUL SYLLABLE BOBS
BD07 HANGUL SYLLABLE BOS
BD08 HANGUL SYLLABLE BOSS
BD09 HANGUL SYLLABLE BONG
BD0A HANGUL SYLLABLE BOJ
BD0B HANGUL SYLLABLE BOC
BD0C HANGUL SYLLABLE BOK
BD0D HANGUL SYLLABLE BOT
BD0E HANGUL SYLLABLE BOP
BD0F HANGUL SYLLABLE BOH
BD10 HANGUL SYLLABLE BWA
BD11 HANGUL SYLLABLE BWAG
BD12 HANGUL SYLLABLE BWAGG
BD13 HANGUL SYLLABLE BWAGS
BD14 HANGUL SYLLABLE BWAN
BD15 HANGUL SYLLABLE BWANJ
BD16 HANGUL SYLLABLE BWANH
BD17 HANGUL SYLLABLE BWAD
BD18 HANGUL SYLLABLE BWAL
BD19 HANGUL SYLLABLE BWALG
BD1A HANGUL SYLLABLE BWALM
BD1B HANGUL SYLLABLE BWALB
BD1C HANGUL SYLLABLE BWALS
BD1D HANGUL SYLLABLE BWALT
BD1E HANGUL SYLLABLE BWALP
BD1F HANGUL SYLLABLE BWALH
BD20 HANGUL SYLLABLE BWAM
BD21 HANGUL SYLLABLE BWAB
BD22 HANGUL SYLLABLE BWABS
BD23 HANGUL SYLLABLE BWAS
BD24 HANGUL SYLLABLE BWASS
BD25 HANGUL SYLLABLE BWANG
BD26 HANGUL SYLLABLE BWAJ
BD27 HANGUL SYLLABLE BWAC
BD28 HANGUL SYLLABLE BWAK
BD29 HANGUL SYLLABLE BWAT
BD2A HANGUL SYLLABLE BWAP
BD2B HANGUL SYLLABLE BWAH
BD2C HANGUL SYLLABLE BWAE
BD2D HANGUL SYLLABLE BWAEG
BD2E HANGUL SYLLABLE BWAEGG
BD2F HANGUL SYLLABLE BWAEGS
BD30 HANGUL SYLLABLE BWAEN
BD31 HANGUL SYLLABLE BWAENJ
BD32 HANGUL SYLLABLE BWAENH
BD33 HANGUL SYLLABLE BWAED
BD34 HANGUL SYLLABLE BWAEL
BD35 HANGUL SYLLABLE BWAELG
BD36 HANGUL SYLLABLE BWAELM
BD37 HANGUL SYLLABLE BWAELB
BD38 HANGUL SYLLABLE BWAELS
BD39 HANGUL SYLLABLE BWAELT
BD3A HANGUL SYLLABLE BWAELP
BD3B HANGUL SYLLABLE BWAELH
BD3C HANGUL SYLLABLE BWAEM
BD3D HANGUL SYLLABLE BWAEB
BD3E HANGUL SYLLABLE BWAEBS
BD3F HANGUL SYLLABLE BWAES
BD40 HANGUL SYLLABLE BWAESS
BD41 HANGUL SYLLABLE BWAENG
BD42 HANGUL SYLLABLE BWAEJ
BD43 HANGUL SYLLABLE BWAEC
BD44 HANGUL SYLLABLE BWAEK
BD45 HANGUL SYLLABLE BWAET
BD46 HANGUL SYLLABLE BWAEP
BD47 HANGUL SYLLABLE BWAEH
BD48 HANGUL SYLLABLE BOE
BD49 HANGUL SYLLABLE BOEG
BD4A HANGUL SYLLABLE BOEGG
BD4B HANGUL SYLLABLE BOEGS
BD4C HANGUL SYLLABLE BOEN
BD4D HANGUL SYLLABLE BOENJ
BD4E HANGUL SYLLABLE BOENH
BD4F HANGUL SYLLABLE BOED
BD50 HANGUL SYLLABLE BOEL
BD51 HANGUL SYLLABLE BOELG
BD52 HANGUL SYLLABLE BOELM
BD53 HANGUL SYLLABLE BOELB
BD54 HANGUL SYLLABLE BOELS
BD55 HANGUL SYLLABLE BOELT
BD56 HANGUL SYLLABLE BOELP
BD57 HANGUL SYLLABLE BOELH
BD58 HANGUL SYLLABLE BOEM
BD59 HANGUL SYLLABLE BOEB
BD5A HANGUL SYLLABLE BOEBS
BD5B HANGUL SYLLABLE BOES
BD5C HANGUL SYLLABLE BOESS
BD5D HANGUL SYLLABLE BOENG
BD5E HANGUL SYLLABLE BOEJ
BD5F HANGUL SYLLABLE BOEC
BD60 HANGUL SYLLABLE BOEK
BD61 HANGUL SYLLABLE BOET
BD62 HANGUL SYLLABLE BOEP
BD63 HANGUL SYLLABLE BOEH
BD64 HANGUL SYLLABLE BYO
BD65 HANGUL SYLLABLE BYOG
BD66 HANGUL SYLLABLE BYOGG
BD67 HANGUL SYLLABLE BYOGS
BD68 HANGUL SYLLABLE BYON
BD69 HANGUL SYLLABLE BYONJ
BD6A HANGUL SYLLABLE BYONH
BD6B HANGUL SYLLABLE BYOD
BD6C HANGUL SYLLABLE BYOL
BD6D HANGUL SYLLABLE BYOLG
BD6E HANGUL SYLLABLE BYOLM
BD6F HANGUL SYLLABLE BYOLB
BD70 HANGUL SYLLABLE BYOLS
BD71 HANGUL SYLLABLE BYOLT
BD72 HANGUL SYLLABLE BYOLP
BD73 HANGUL SYLLABLE BYOLH
BD74 HANGUL SYLLABLE BYOM
BD75 HANGUL SYLLABLE BYOB
BD76 HANGUL SYLLABLE BYOBS
BD77 HANGUL SYLLABLE BYOS
BD78 HANGUL SYLLABLE BYOSS
BD79 HANGUL SYLLABLE BYONG
BD7A HANGUL SYLLABLE BYOJ
BD7B HANGUL SYLLABLE BYOC
BD7C HANGUL SYLLABLE BYOK
BD7D HANGUL SYLLABLE BYOT
BD7E HANGUL SYLLABLE BYOP
BD7F HANGUL SYLLABLE BYOH
BD80 HANGUL SYLLABLE BU
BD81 HANGUL SYLLABLE BUG
BD82 HANGUL SYLLABLE BUGG
BD83 HANGUL SYLLABLE BUGS
BD84 HANGUL SYLLABLE BUN
BD85 HANGUL SYLLABLE BUNJ
BD86 HANGUL SYLLABLE BUNH
BD87 HANGUL SYLLABLE BUD
BD88 HANGUL SYLLABLE BUL
BD89 HANGUL SYLLABLE BULG
BD8A HANGUL SYLLABLE BULM
BD8B HANGUL SYLLABLE BULB
BD8C HANGUL SYLLABLE BULS
BD8D HANGUL SYLLABLE BULT
BD8E HANGUL SYLLABLE BULP
BD8F HANGUL SYLLABLE BULH
BD90 HANGUL SYLLABLE BUM
BD91 HANGUL SYLLABLE BUB
BD92 HANGUL SYLLABLE BUBS
BD93 HANGUL SYLLABLE BUS
BD94 HANGUL SYLLABLE BUSS
BD95 HANGUL SYLLABLE BUNG
BD96 HANGUL SYLLABLE BUJ
BD97 HANGUL SYLLABLE BUC
BD98 HANGUL SYLLABLE BUK
BD99 HANGUL SYLLABLE BUT
BD9A HANGUL SYLLABLE BUP
BD9B HANGUL SYLLABLE BUH
BD9C HANGUL SYLLABLE BWEO
BD9D HANGUL SYLLABLE BWEOG
BD9E HANGUL SYLLABLE BWEOGG
BD9F HANGUL SYLLABLE BWEOGS
BDA0 HANGUL SYLLABLE BWEON
BDA1 HANGUL SYLLABLE BWEONJ
BDA2 HANGUL SYLLABLE BWEONH
BDA3 HANGUL SYLLABLE BWEOD
BDA4 HANGUL SYLLABLE BWEOL
BDA5 HANGUL SYLLABLE BWEOLG
BDA6 HANGUL SYLLABLE BWEOLM
BDA7 HANGUL SYLLABLE BWEOLB
BDA8 HANGUL SYLLABLE BWEOLS
BDA9 HANGUL SYLLABLE BWEOLT
BDAA HANGUL SYLLABLE BWEOLP
BDAB HANGUL SYLLABLE BWEOLH
BDAC HANGUL SYLLABLE BWEOM
BDAD HANGUL SYLLABLE BWEOB
BDAE HANGUL SYLLABLE BWEOBS
BDAF HANGUL SYLLABLE BWEOS
BDB0 HANGUL SYLLABLE BWEOSS
BDB1 HANGUL SYLLABLE BWEONG
BDB2 HANGUL SYLLABLE BWEOJ
BDB3 HANGUL SYLLABLE BWEOC
BDB4 HANGUL SYLLABLE BWEOK
BDB5 HANGUL SYLLABLE BWEOT
BDB6 HANGUL SYLLABLE BWEOP
BDB7 HANGUL SYLLABLE BWEOH
BDB8 HANGUL SYLLABLE BWE
BDB9 HANGUL SYLLABLE BWEG
BDBA HANGUL SYLLABLE BWEGG
BDBB HANGUL SYLLABLE BWEGS
BDBC HANGUL SYLLABLE BWEN
BDBD HANGUL SYLLABLE BWENJ
BDBE HANGUL SYLLABLE BWENH
BDBF HANGUL SYLLABLE BWED
BDC0 HANGUL SYLLABLE BWEL
BDC1 HANGUL SYLLABLE BWELG
BDC2 HANGUL SYLLABLE BWELM
BDC3 HANGUL SYLLABLE BWELB
BDC4 HANGUL SYLLABLE BWELS
BDC5 HANGUL SYLLABLE BWELT
BDC6 HANGUL SYLLABLE BWELP
BDC7 HANGUL SYLLABLE BWELH
BDC8 HANGUL SYLLABLE BWEM
BDC9 HANGUL SYLLABLE BWEB
BDCA HANGUL SYLLABLE BWEBS
BDCB HANGUL SYLLABLE BWES
BDCC HANGUL SYLLABLE BWESS
BDCD HANGUL SYLLABLE BWENG
BDCE HANGUL SYLLABLE BWEJ
BDCF HANGUL SYLLABLE BWEC
BDD0 HANGUL SYLLABLE BWEK
BDD1 HANGUL SYLLABLE BWET
BDD2 HANGUL SYLLABLE BWEP
BDD3 HANGUL SYLLABLE BWEH
BDD4 HANGUL SYLLABLE BWI
BDD5 HANGUL SYLLABLE BWIG
BDD6 HANGUL SYLLABLE BWIGG
BDD7 HANGUL SYLLABLE BWIGS
BDD8 HANGUL SYLLABLE BWIN
BDD9 HANGUL SYLLABLE BWINJ
BDDA HANGUL SYLLABLE BWINH
BDDB HANGUL SYLLABLE BWID
BDDC HANGUL SYLLABLE BWIL
BDDD HANGUL SYLLABLE BWILG
BDDE HANGUL SYLLABLE BWILM
BDDF HANGUL SYLLABLE BWILB
BDE0 HANGUL SYLLABLE BWILS
BDE1 HANGUL SYLLABLE BWILT
BDE2 HANGUL SYLLABLE BWILP
BDE3 HANGUL SYLLABLE BWILH
BDE4 HANGUL SYLLABLE BWIM
BDE5 HANGUL SYLLABLE BWIB
BDE6 HANGUL SYLLABLE BWIBS
BDE7 HANGUL SYLLABLE BWIS
BDE8 HANGUL SYLLABLE BWISS
BDE9 HANGUL SYLLABLE BWING
BDEA HANGUL SYLLABLE BWIJ
BDEB HANGUL SYLLABLE BWIC
BDEC HANGUL SYLLABLE BWIK
BDED HANGUL SYLLABLE BWIT
BDEE HANGUL SYLLABLE BWIP
BDEF HANGUL SYLLABLE BWIH
BDF0 HANGUL SYLLABLE BYU
BDF1 HANGUL SYLLABLE BYUG
BDF2 HANGUL SYLLABLE BYUGG
BDF3 HANGUL SYLLABLE BYUGS
BDF4 HANGUL SYLLABLE BYUN
BDF5 HANGUL SYLLABLE BYUNJ
BDF6 HANGUL SYLLABLE BYUNH
BDF7 HANGUL SYLLABLE BYUD
BDF8 HANGUL SYLLABLE BYUL
BDF9 HANGUL SYLLABLE BYULG
BDFA HANGUL SYLLABLE BYULM
BDFB HANGUL SYLLABLE BYULB
BDFC HANGUL SYLLABLE BYULS
BDFD HANGUL SYLLABLE BYULT
BDFE HANGUL SYLLABLE BYULP
BDFF HANGUL SYLLABLE BYULH
BE00 HANGUL SYLLABLE BYUM
BE01 HANGUL SYLLABLE BYUB
BE02 HANGUL SYLLABLE BYUBS
BE03 HANGUL SYLLABLE BYUS
BE04 HANGUL SYLLABLE BYUSS
BE05 HANGUL SYLLABLE BYUNG
BE06 HANGUL SYLLABLE BYUJ
BE07 HANGUL SYLLABLE BYUC
BE08 HANGUL SYLLABLE BYUK
BE09 HANGUL SYLLABLE BYUT
BE0A HANGUL SYLLABLE BYUP
BE0B HANGUL SYLLABLE BYUH
BE0C HANGUL SYLLABLE BEU
BE0D HANGUL SYLLABLE BEUG
BE0E HANGUL SYLLABLE BEUGG
BE0F HANGUL SYLLABLE BEUGS
BE10 HANGUL SYLLABLE BEUN
BE11 HANGUL SYLLABLE BEUNJ
BE12 HANGUL SYLLABLE BEUNH
BE13 HANGUL SYLLABLE BEUD
BE14 HANGUL SYLLABLE BEUL
BE15 HANGUL SYLLABLE BEULG
BE16 HANGUL SYLLABLE BEULM
BE17 HANGUL SYLLABLE BEULB
BE18 HANGUL SYLLABLE BEULS
BE19 HANGUL SYLLABLE BEULT
BE1A HANGUL SYLLABLE BEULP
BE1B HANGUL SYLLABLE BEULH
BE1C HANGUL SYLLABLE BEUM
BE1D HANGUL SYLLABLE BEUB
BE1E HANGUL SYLLABLE BEUBS
BE1F HANGUL SYLLABLE BEUS
BE20 HANGUL SYLLABLE BEUSS
BE21 HANGUL SYLLABLE BEUNG
BE22 HANGUL SYLLABLE BEUJ
BE23 HANGUL SYLLABLE BEUC
BE24 HANGUL SYLLABLE BEUK
BE25 HANGUL SYLLABLE BEUT
BE26 HANGUL SYLLABLE BEUP
BE27 HANGUL SYLLABLE BEUH
BE28 HANGUL SYLLABLE BYI
BE29 HANGUL SYLLABLE BYIG
BE2A HANGUL SYLLABLE BYIGG
BE2B HANGUL SYLLABLE BYIGS
BE2C HANGUL SYLLABLE BYIN
BE2D HANGUL SYLLABLE BYINJ
BE2E HANGUL SYLLABLE BYINH
BE2F HANGUL SYLLABLE BYID
BE30 HANGUL SYLLABLE BYIL
BE31 HANGUL SYLLABLE BYILG
BE32 HANGUL SYLLABLE BYILM
BE33 HANGUL SYLLABLE BYILB
BE34 HANGUL SYLLABLE BYILS
BE35 HANGUL SYLLABLE BYILT
BE36 HANGUL SYLLABLE BYILP
BE37 HANGUL SYLLABLE BYILH
BE38 HANGUL SYLLABLE BYIM
BE39 HANGUL SYLLABLE BYIB
BE3A HANGUL SYLLABLE BYIBS
BE3B HANGUL SYLLABLE BYIS
BE3C HANGUL SYLLABLE BYISS
BE3D HANGUL SYLLABLE BYING
BE3E HANGUL SYLLABLE BYIJ
BE3F HANGUL SYLLABLE BYIC
BE40 HANGUL SYLLABLE BYIK
BE41 HANGUL SYLLABLE BYIT
BE42 HANGUL SYLLABLE BYIP
BE43 HANGUL SYLLABLE BYIH
BE44 HANGUL SYLLABLE BI
BE45 HANGUL SYLLABLE BIG
BE46 HANGUL SYLLABLE BIGG
BE47 HANGUL SYLLABLE BIGS
BE48 HANGUL SYLLABLE BIN
BE49 HANGUL SYLLABLE BINJ
BE4A HANGUL SYLLABLE BINH
BE4B HANGUL SYLLABLE BID
BE4C HANGUL SYLLABLE BIL
BE4D HANGUL SYLLABLE BILG
BE4E HANGUL SYLLABLE BILM
BE4F HANGUL SYLLABLE BILB
BE50 HANGUL SYLLABLE BILS
BE51 HANGUL SYLLABLE BILT
BE52 HANGUL SYLLABLE BILP
BE53 HANGUL SYLLABLE BILH
BE54 HANGUL SYLLABLE BIM
BE55 HANGUL SYLLABLE BIB
BE56 HANGUL SYLLABLE BIBS
BE57 HANGUL SYLLABLE BIS
BE58 HANGUL SYLLABLE BISS
BE59 HANGUL SYLLABLE BING
BE5A HANGUL SYLLABLE BIJ
BE5B HANGUL SYLLABLE BIC
BE5C HANGUL SYLLABLE BIK
BE5D HANGUL SYLLABLE BIT
BE5E HANGUL SYLLABLE BIP
BE5F HANGUL SYLLABLE BIH
BE60 HANGUL SYLLABLE BBA
BE61 HANGUL SYLLABLE BBAG
BE62 HANGUL SYLLABLE BBAGG
BE63 HANGUL SYLLABLE BBAGS
BE64 HANGUL SYLLABLE BBAN
BE65 HANGUL SYLLABLE BBANJ
BE66 HANGUL SYLLABLE BBANH
BE67 HANGUL SYLLABLE BBAD
BE68 HANGUL SYLLABLE BBAL
BE69 HANGUL SYLLABLE BBALG
BE6A HANGUL SYLLABLE BBALM
BE6B HANGUL SYLLABLE BBALB
BE6C HANGUL SYLLABLE BBALS
BE6D HANGUL SYLLABLE BBALT
BE6E HANGUL SYLLABLE BBALP
BE6F HANGUL SYLLABLE BBALH
BE70 HANGUL SYLLABLE BBAM
BE71 HANGUL SYLLABLE BBAB
BE72 HANGUL SYLLABLE BBABS
BE73 HANGUL SYLLABLE BBAS
BE74 HANGUL SYLLABLE BBASS
BE75 HANGUL SYLLABLE BBANG
BE76 HANGUL SYLLABLE BBAJ
BE77 HANGUL SYLLABLE BBAC
BE78 HANGUL SYLLABLE BBAK
BE79 HANGUL SYLLABLE BBAT
BE7A HANGUL SYLLABLE BBAP
BE7B HANGUL SYLLABLE BBAH
BE7C HANGUL SYLLABLE BBAE
BE7D HANGUL SYLLABLE BBAEG
BE7E HANGUL SYLLABLE BBAEGG
BE7F HANGUL SYLLABLE BBAEGS
BE80 HANGUL SYLLABLE BBAEN
BE81 HANGUL SYLLABLE BBAENJ
BE82 HANGUL SYLLABLE BBAENH
BE83 HANGUL SYLLABLE BBAED
BE84 HANGUL SYLLABLE BBAEL
BE85 HANGUL SYLLABLE BBAELG
BE86 HANGUL SYLLABLE BBAELM
BE87 HANGUL SYLLABLE BBAELB
BE88 HANGUL SYLLABLE BBAELS
BE89 HANGUL SYLLABLE BBAELT
BE8A HANGUL SYLLABLE BBAELP
BE8B HANGUL SYLLABLE BBAELH
BE8C HANGUL SYLLABLE BBAEM
BE8D HANGUL SYLLABLE BBAEB
BE8E HANGUL SYLLABLE BBAEBS
BE8F HANGUL SYLLABLE BBAES
BE90 HANGUL SYLLABLE BBAESS
BE91 HANGUL SYLLABLE BBAENG
BE92 HANGUL SYLLABLE BBAEJ
BE93 HANGUL SYLLABLE BBAEC
BE94 HANGUL SYLLABLE BBAEK
BE95 HANGUL SYLLABLE BBAET
BE96 HANGUL SYLLABLE BBAEP
BE97 HANGUL SYLLABLE BBAEH
BE98 HANGUL SYLLABLE BBYA
BE99 HANGUL SYLLABLE BBYAG
BE9A HANGUL SYLLABLE BBYAGG
BE9B HANGUL SYLLABLE BBYAGS
BE9C HANGUL SYLLABLE BBYAN
BE9D HANGUL SYLLABLE BBYANJ
BE9E HANGUL SYLLABLE BBYANH
BE9F HANGUL SYLLABLE BBYAD
BEA0 HANGUL SYLLABLE BBYAL
BEA1 HANGUL SYLLABLE BBYALG
BEA2 HANGUL SYLLABLE BBYALM
BEA3 HANGUL SYLLABLE BBYALB
BEA4 HANGUL SYLLABLE BBYALS
BEA5 HANGUL SYLLABLE BBYALT
BEA6 HANGUL SYLLABLE BBYALP
BEA7 HANGUL SYLLABLE BBYALH
BEA8 HANGUL SYLLABLE BBYAM
BEA9 HANGUL SYLLABLE BBYAB
BEAA HANGUL SYLLABLE BBYABS
BEAB HANGUL SYLLABLE BBYAS
BEAC HANGUL SYLLABLE BBYASS
BEAD HANGUL SYLLABLE BBYANG
BEAE HANGUL SYLLABLE BBYAJ
BEAF HANGUL SYLLABLE BBYAC
BEB0 HANGUL SYLLABLE BBYAK
BEB1 HANGUL SYLLABLE BBYAT
BEB2 HANGUL SYLLABLE BBYAP
BEB3 HANGUL SYLLABLE BBYAH
BEB4 HANGUL SYLLABLE BBYAE
BEB5 HANGUL SYLLABLE BBYAEG
BEB6 HANGUL SYLLABLE BBYAEGG
BEB7 HANGUL SYLLABLE BBYAEGS
BEB8 HANGUL SYLLABLE BBYAEN
BEB9 HANGUL SYLLABLE BBYAENJ
BEBA HANGUL SYLLABLE BBYAENH
BEBB HANGUL SYLLABLE BBYAED
BEBC HANGUL SYLLABLE BBYAEL
BEBD HANGUL SYLLABLE BBYAELG
BEBE HANGUL SYLLABLE BBYAELM
BEBF HANGUL SYLLABLE BBYAELB
BEC0 HANGUL SYLLABLE BBYAELS
BEC1 HANGUL SYLLABLE BBYAELT
BEC2 HANGUL SYLLABLE BBYAELP
BEC3 HANGUL SYLLABLE BBYAELH
BEC4 HANGUL SYLLABLE BBYAEM
BEC5 HANGUL SYLLABLE BBYAEB
BEC6 HANGUL SYLLABLE BBYAEBS
BEC7 HANGUL SYLLABLE BBYAES
BEC8 HANGUL SYLLABLE BBYAESS
BEC9 HANGUL SYLLABLE BBYAENG
BECA HANGUL SYLLABLE BBYAEJ
BECB HANGUL SYLLABLE BBYAEC
BECC HANGUL SYLLABLE BBYAEK
BECD HANGUL SYLLABLE BBYAET
BECE HANGUL SYLLABLE BBYAEP
BECF HANGUL SYLLABLE BBYAEH
BED0 HANGUL SYLLABLE BBEO
BED1 HANGUL SYLLABLE BBEOG
BED2 HANGUL SYLLABLE BBEOGG
BED3 HANGUL SYLLABLE BBEOGS
BED4 HANGUL SYLLABLE BBEON
BED5 HANGUL SYLLABLE BBEONJ
BED6 HANGUL SYLLABLE BBEONH
BED7 HANGUL SYLLABLE BBEOD
BED8 HANGUL SYLLABLE BBEOL
BED9 HANGUL SYLLABLE BBEOLG
BEDA HANGUL SYLLABLE BBEOLM
BEDB HANGUL SYLLABLE BBEOLB
BEDC HANGUL SYLLABLE BBEOLS
BEDD HANGUL SYLLABLE BBEOLT
BEDE HANGUL SYLLABLE BBEOLP
BEDF HANGUL SYLLABLE BBEOLH
BEE0 HANGUL SYLLABLE BBEOM
BEE1 HANGUL SYLLABLE BBEOB
BEE2 HANGUL SYLLABLE BBEOBS
BEE3 HANGUL SYLLABLE BBEOS
BEE4 HANGUL SYLLABLE BBEOSS
BEE5 HANGUL SYLLABLE BBEONG
BEE6 HANGUL SYLLABLE BBEOJ
BEE7 HANGUL SYLLABLE BBEOC
BEE8 HANGUL SYLLABLE BBEOK
BEE9 HANGUL SYLLABLE BBEOT
BEEA HANGUL SYLLABLE BBEOP
BEEB HANGUL SYLLABLE BBEOH
BEEC HANGUL SYLLABLE BBE
BEED HANGUL SYLLABLE BBEG
BEEE HANGUL SYLLABLE BBEGG
BEEF HANGUL SYLLABLE BBEGS
BEF0 HANGUL SYLLABLE BBEN
BEF1 HANGUL SYLLABLE BBENJ
BEF2 HANGUL SYLLABLE BBENH
BEF3 HANGUL SYLLABLE BBED
BEF4 HANGUL SYLLABLE BBEL
BEF5 HANGUL SYLLABLE BBELG
BEF6 HANGUL SYLLABLE BBELM
BEF7 HANGUL SYLLABLE BBELB
BEF8 HANGUL SYLLABLE BBELS
BEF9 HANGUL SYLLABLE BBELT
BEFA HANGUL SYLLABLE BBELP
BEFB HANGUL SYLLABLE BBELH
BEFC HANGUL SYLLABLE BBEM
BEFD HANGUL SYLLABLE BBEB
BEFE HANGUL SYLLABLE BBEBS
BEFF HANGUL SYLLABLE BBES
BF00 HANGUL SYLLABLE BBESS
BF01 HANGUL SYLLABLE BBENG
BF02 HANGUL SYLLABLE BBEJ
BF03 HANGUL SYLLABLE BBEC
BF04 HANGUL SYLLABLE BBEK
BF05 HANGUL SYLLABLE BBET
BF06 HANGUL SYLLABLE BBEP
BF07 HANGUL SYLLABLE BBEH
BF08 HANGUL SYLLABLE BBYEO
BF09 HANGUL SYLLABLE BBYEOG
BF0A HANGUL SYLLABLE BBYEOGG
BF0B HANGUL SYLLABLE BBYEOGS
BF0C HANGUL SYLLABLE BBYEON
BF0D HANGUL SYLLABLE BBYEONJ
BF0E HANGUL SYLLABLE BBYEONH
BF0F HANGUL SYLLABLE BBYEOD
BF10 HANGUL SYLLABLE BBYEOL
BF11 HANGUL SYLLABLE BBYEOLG
BF12 HANGUL SYLLABLE BBYEOLM
BF13 HANGUL SYLLABLE BBYEOLB
BF14 HANGUL SYLLABLE BBYEOLS
BF15 HANGUL SYLLABLE BBYEOLT
BF16 HANGUL SYLLABLE BBYEOLP
BF17 HANGUL SYLLABLE BBYEOLH
BF18 HANGUL SYLLABLE BBYEOM
BF19 HANGUL SYLLABLE BBYEOB
BF1A HANGUL SYLLABLE BBYEOBS
BF1B HANGUL SYLLABLE BBYEOS
BF1C HANGUL SYLLABLE BBYEOSS
BF1D HANGUL SYLLABLE BBYEONG
BF1E HANGUL SYLLABLE BBYEOJ
BF1F HANGUL SYLLABLE BBYEOC
BF20 HANGUL SYLLABLE BBYEOK
BF21 HANGUL SYLLABLE BBYEOT
BF22 HANGUL SYLLABLE BBYEOP
BF23 HANGUL SYLLABLE BBYEOH
BF24 HANGUL SYLLABLE BBYE
BF25 HANGUL SYLLABLE BBYEG
BF26 HANGUL SYLLABLE BBYEGG
BF27 HANGUL SYLLABLE BBYEGS
BF28 HANGUL SYLLABLE BBYEN
BF29 HANGUL SYLLABLE BBYENJ
BF2A HANGUL SYLLABLE BBYENH
BF2B HANGUL SYLLABLE BBYED
BF2C HANGUL SYLLABLE BBYEL
BF2D HANGUL SYLLABLE BBYELG
BF2E HANGUL SYLLABLE BBYELM
BF2F HANGUL SYLLABLE BBYELB
BF30 HANGUL SYLLABLE BBYELS
BF31 HANGUL SYLLABLE BBYELT
BF32 HANGUL SYLLABLE BBYELP
BF33 HANGUL SYLLABLE BBYELH
BF34 HANGUL SYLLABLE BBYEM
BF35 HANGUL SYLLABLE BBYEB
BF36 HANGUL SYLLABLE BBYEBS
BF37 HANGUL SYLLABLE BBYES
BF38 HANGUL SYLLABLE BBYESS
BF39 HANGUL SYLLABLE BBYENG
BF3A HANGUL SYLLABLE BBYEJ
BF3B HANGUL SYLLABLE BBYEC
BF3C HANGUL SYLLABLE BBYEK
BF3D HANGUL SYLLABLE BBYET
BF3E HANGUL SYLLABLE BBYEP
BF3F HANGUL SYLLABLE BBYEH
BF40 HANGUL SYLLABLE BBO
BF41 HANGUL SYLLABLE BBOG
BF42 HANGUL SYLLABLE BBOGG
BF43 HANGUL SYLLABLE BBOGS
BF44 HANGUL SYLLABLE BBON
BF45 HANGUL SYLLABLE BBONJ
BF46 HANGUL SYLLABLE BBONH
BF47 HANGUL SYLLABLE BBOD
BF48 HANGUL SYLLABLE BBOL
BF49 HANGUL SYLLABLE BBOLG
BF4A HANGUL SYLLABLE BBOLM
BF4B HANGUL SYLLABLE BBOLB
BF4C HANGUL SYLLABLE BBOLS
BF4D HANGUL SYLLABLE BBOLT
BF4E HANGUL SYLLABLE BBOLP
BF4F HANGUL SYLLABLE BBOLH
BF50 HANGUL SYLLABLE BBOM
BF51 HANGUL SYLLABLE BBOB
BF52 HANGUL SYLLABLE BBOBS
BF53 HANGUL SYLLABLE BBOS
BF54 HANGUL SYLLABLE BBOSS
BF55 HANGUL SYLLABLE BBONG
BF56 HANGUL SYLLABLE BBOJ
BF57 HANGUL SYLLABLE BBOC
BF58 HANGUL SYLLABLE BBOK
BF59 HANGUL SYLLABLE BBOT
BF5A HANGUL SYLLABLE BBOP
BF5B HANGUL SYLLABLE BBOH
BF5C HANGUL SYLLABLE BBWA
BF5D HANGUL SYLLABLE BBWAG
BF5E HANGUL SYLLABLE BBWAGG
BF5F HANGUL SYLLABLE BBWAGS
BF60 HANGUL SYLLABLE BBWAN
BF61 HANGUL SYLLABLE BBWANJ
BF62 HANGUL SYLLABLE BBWANH
BF63 HANGUL SYLLABLE BBWAD
BF64 HANGUL SYLLABLE BBWAL
BF65 HANGUL SYLLABLE BBWALG
BF66 HANGUL SYLLABLE BBWALM
BF67 HANGUL SYLLABLE BBWALB
BF68 HANGUL SYLLABLE BBWALS
BF69 HANGUL SYLLABLE BBWALT
BF6A HANGUL SYLLABLE BBWALP
BF6B HANGUL SYLLABLE BBWALH
BF6C HANGUL SYLLABLE BBWAM
BF6D HANGUL SYLLABLE BBWAB
BF6E HANGUL SYLLABLE BBWABS
BF6F HANGUL SYLLABLE BBWAS
BF70 HANGUL SYLLABLE BBWASS
BF71 HANGUL SYLLABLE BBWANG
BF72 HANGUL SYLLABLE BBWAJ
BF73 HANGUL SYLLABLE BBWAC
BF74 HANGUL SYLLABLE BBWAK
BF75 HANGUL SYLLABLE BBWAT
BF76 HANGUL SYLLABLE BBWAP
BF77 HANGUL SYLLABLE BBWAH
BF78 HANGUL SYLLABLE BBWAE
BF79 HANGUL SYLLABLE BBWAEG
BF7A HANGUL SYLLABLE BBWAEGG
BF7B HANGUL SYLLABLE BBWAEGS
BF7C HANGUL SYLLABLE BBWAEN
BF7D HANGUL SYLLABLE BBWAENJ
BF7E HANGUL SYLLABLE BBWAENH
BF7F HANGUL SYLLABLE BBWAED
BF80 HANGUL SYLLABLE BBWAEL
BF81 HANGUL SYLLABLE BBWAELG
BF82 HANGUL SYLLABLE BBWAELM
BF83 HANGUL SYLLABLE BBWAELB
BF84 HANGUL SYLLABLE BBWAELS
BF85 HANGUL SYLLABLE BBWAELT
BF86 HANGUL SYLLABLE BBWAELP
BF87 HANGUL SYLLABLE BBWAELH
BF88 HANGUL SYLLABLE BBWAEM
BF89 HANGUL SYLLABLE BBWAEB
BF8A HANGUL SYLLABLE BBWAEBS
BF8B HANGUL SYLLABLE BBWAES
BF8C HANGUL SYLLABLE BBWAESS
BF8D HANGUL SYLLABLE BBWAENG
BF8E HANGUL SYLLABLE BBWAEJ
BF8F HANGUL SYLLABLE BBWAEC
BF90 HANGUL SYLLABLE BBWAEK
BF91 HANGUL SYLLABLE BBWAET
BF92 HANGUL SYLLABLE BBWAEP
BF93 HANGUL SYLLABLE BBWAEH
BF94 HANGUL SYLLABLE BBOE
BF95 HANGUL SYLLABLE BBOEG
BF96 HANGUL SYLLABLE BBOEGG
BF97 HANGUL SYLLABLE BBOEGS
BF98 HANGUL SYLLABLE BBOEN
BF99 HANGUL SYLLABLE BBOENJ
BF9A HANGUL SYLLABLE BBOENH
BF9B HANGUL SYLLABLE BBOED
BF9C HANGUL SYLLABLE BBOEL
BF9D HANGUL SYLLABLE BBOELG
BF9E HANGUL SYLLABLE BBOELM
BF9F HANGUL SYLLABLE BBOELB
BFA0 HANGUL SYLLABLE BBOELS
BFA1 HANGUL SYLLABLE BBOELT
BFA2 HANGUL SYLLABLE BBOELP
BFA3 HANGUL SYLLABLE BBOELH
BFA4 HANGUL SYLLABLE BBOEM
BFA5 HANGUL SYLLABLE BBOEB
BFA6 HANGUL SYLLABLE BBOEBS
BFA7 HANGUL SYLLABLE BBOES
BFA8 HANGUL SYLLABLE BBOESS
BFA9 HANGUL SYLLABLE BBOENG
BFAA HANGUL SYLLABLE BBOEJ
BFAB HANGUL SYLLABLE BBOEC
BFAC HANGUL SYLLABLE BBOEK
BFAD HANGUL SYLLABLE BBOET
BFAE HANGUL SYLLABLE BBOEP
BFAF HANGUL SYLLABLE BBOEH
BFB0 HANGUL SYLLABLE BBYO
BFB1 HANGUL SYLLABLE BBYOG
BFB2 HANGUL SYLLABLE BBYOGG
BFB3 HANGUL SYLLABLE BBYOGS
BFB4 HANGUL SYLLABLE BBYON
BFB5 HANGUL SYLLABLE BBYONJ
BFB6 HANGUL SYLLABLE BBYONH
BFB7 HANGUL SYLLABLE BBYOD
BFB8 HANGUL SYLLABLE BBYOL
BFB9 HANGUL SYLLABLE BBYOLG
BFBA HANGUL SYLLABLE BBYOLM
BFBB HANGUL SYLLABLE BBYOLB
BFBC HANGUL SYLLABLE BBYOLS
BFBD HANGUL SYLLABLE BBYOLT
BFBE HANGUL SYLLABLE BBYOLP
BFBF HANGUL SYLLABLE BBYOLH
BFC0 HANGUL SYLLABLE BBYOM
BFC1 HANGUL SYLLABLE BBYOB
BFC2 HANGUL SYLLABLE BBYOBS
BFC3 HANGUL SYLLABLE BBYOS
BFC4 HANGUL SYLLABLE BBYOSS
BFC5 HANGUL SYLLABLE BBYONG
BFC6 HANGUL SYLLABLE BBYOJ
BFC7 HANGUL SYLLABLE BBYOC
BFC8 HANGUL SYLLABLE BBYOK
BFC9 HANGUL SYLLABLE BBYOT
BFCA HANGUL SYLLABLE BBYOP
BFCB HANGUL SYLLABLE BBYOH
BFCC HANGUL SYLLABLE BBU
BFCD HANGUL SYLLABLE BBUG
BFCE HANGUL SYLLABLE BBUGG
BFCF HANGUL SYLLABLE BBUGS
BFD0 HANGUL SYLLABLE BBUN
BFD1 HANGUL SYLLABLE BBUNJ
BFD2 HANGUL SYLLABLE BBUNH
BFD3 HANGUL SYLLABLE BBUD
BFD4 HANGUL SYLLABLE BBUL
BFD5 HANGUL SYLLABLE BBULG
BFD6 HANGUL SYLLABLE BBULM
BFD7 HANGUL SYLLABLE BBULB
BFD8 HANGUL SYLLABLE BBULS
BFD9 HANGUL SYLLABLE BBULT
BFDA HANGUL SYLLABLE BBULP
BFDB HANGUL SYLLABLE BBULH
BFDC HANGUL SYLLABLE BBUM
BFDD HANGUL SYLLABLE BBUB
BFDE HANGUL SYLLABLE BBUBS
BFDF HANGUL SYLLABLE BBUS
BFE0 HANGUL SYLLABLE BBUSS
BFE1 HANGUL SYLLABLE BBUNG
BFE2 HANGUL SYLLABLE BBUJ
BFE3 HANGUL SYLLABLE BBUC
BFE4 HANGUL SYLLABLE BBUK
BFE5 HANGUL SYLLABLE BBUT
BFE6 HANGUL SYLLABLE BBUP
BFE7 HANGUL SYLLABLE BBUH
BFE8 HANGUL SYLLABLE BBWEO
BFE9 HANGUL SYLLABLE BBWEOG
BFEA HANGUL SYLLABLE BBWEOGG
BFEB HANGUL SYLLABLE BBWEOGS
BFEC HANGUL SYLLABLE BBWEON
BFED HANGUL SYLLABLE BBWEONJ
BFEE HANGUL SYLLABLE BBWEONH
BFEF HANGUL SYLLABLE BBWEOD
BFF0 HANGUL SYLLABLE BBWEOL
BFF1 HANGUL SYLLABLE BBWEOLG
BFF2 HANGUL SYLLABLE BBWEOLM
BFF3 HANGUL SYLLABLE BBWEOLB
BFF4 HANGUL SYLLABLE BBWEOLS
BFF5 HANGUL SYLLABLE BBWEOLT
BFF6 HANGUL SYLLABLE BBWEOLP
BFF7 HANGUL SYLLABLE BBWEOLH
BFF8 HANGUL SYLLABLE BBWEOM
BFF9 HANGUL SYLLABLE BBWEOB
BFFA HANGUL SYLLABLE BBWEOBS
BFFB HANGUL SYLLABLE BBWEOS
BFFC HANGUL SYLLABLE BBWEOSS
BFFD HANGUL SYLLABLE BBWEONG
BFFE HANGUL SYLLABLE BBWEOJ
BFFF HANGUL SYLLABLE BBWEOC
C000 HANGUL SYLLABLE BBWEOK
C001 HANGUL SYLLABLE BBWEOT
C002 HANGUL SYLLABLE BBWEOP
C003 HANGUL SYLLABLE BBWEOH
C004 HANGUL SYLLABLE BBWE
C005 HANGUL SYLLABLE BBWEG
C006 HANGUL SYLLABLE BBWEGG
C007 HANGUL SYLLABLE BBWEGS
C008 HANGUL SYLLABLE BBWEN
C009 HANGUL SYLLABLE BBWENJ
C00A HANGUL SYLLABLE BBWENH
C00B HANGUL SYLLABLE BBWED
C00C HANGUL SYLLABLE BBWEL
C00D HANGUL SYLLABLE BBWELG
C00E HANGUL SYLLABLE BBWELM
C00F HANGUL SYLLABLE BBWELB
C010 HANGUL SYLLABLE BBWELS
C011 HANGUL SYLLABLE BBWELT
C012 HANGUL SYLLABLE BBWELP
C013 HANGUL SYLLABLE BBWELH
C014 HANGUL SYLLABLE BBWEM
C015 HANGUL SYLLABLE BBWEB
C016 HANGUL SYLLABLE BBWEBS
C017 HANGUL SYLLABLE BBWES
C018 HANGUL SYLLABLE BBWESS
C019 HANGUL SYLLABLE BBWENG
C01A HANGUL SYLLABLE BBWEJ
C01B HANGUL SYLLABLE BBWEC
C01C HANGUL SYLLABLE BBWEK
C01D HANGUL SYLLABLE BBWET
C01E HANGUL SYLLABLE BBWEP
C01F HANGUL SYLLABLE BBWEH
C020 HANGUL SYLLABLE BBWI
C021 HANGUL SYLLABLE BBWIG
C022 HANGUL SYLLABLE BBWIGG
C023 HANGUL SYLLABLE BBWIGS
C024 HANGUL SYLLABLE BBWIN
C025 HANGUL SYLLABLE BBWINJ
C026 HANGUL SYLLABLE BBWINH
C027 HANGUL SYLLABLE BBWID
C028 HANGUL SYLLABLE BBWIL
C029 HANGUL SYLLABLE BBWILG
C02A HANGUL SYLLABLE BBWILM
C02B HANGUL SYLLABLE BBWILB
C02C HANGUL SYLLABLE BBWILS
C02D HANGUL SYLLABLE BBWILT
C02E HANGUL SYLLABLE BBWILP
C02F HANGUL SYLLABLE BBWILH
C030 HANGUL SYLLABLE BBWIM
C031 HANGUL SYLLABLE BBWIB
C032 HANGUL SYLLABLE BBWIBS
C033 HANGUL SYLLABLE BBWIS
C034 HANGUL SYLLABLE BBWISS
C035 HANGUL SYLLABLE BBWING
C036 HANGUL SYLLABLE BBWIJ
C037 HANGUL SYLLABLE BBWIC
C038 HANGUL SYLLABLE BBWIK
C039 HANGUL SYLLABLE BBWIT
C03A HANGUL SYLLABLE BBWIP
C03B HANGUL SYLLABLE BBWIH
C03C HANGUL SYLLABLE BBYU
C03D HANGUL SYLLABLE BBYUG
C03E HANGUL SYLLABLE BBYUGG
C03F HANGUL SYLLABLE BBYUGS
C040 HANGUL SYLLABLE BBYUN
C041 HANGUL SYLLABLE BBYUNJ
C042 HANGUL SYLLABLE BBYUNH
C043 HANGUL SYLLABLE BBYUD
C044 HANGUL SYLLABLE BBYUL
C045 HANGUL SYLLABLE BBYULG
C046 HANGUL SYLLABLE BBYULM
C047 HANGUL SYLLABLE BBYULB
C048 HANGUL SYLLABLE BBYULS
C049 HANGUL SYLLABLE BBYULT
C04A HANGUL SYLLABLE BBYULP
C04B HANGUL SYLLABLE BBYULH
C04C HANGUL SYLLABLE BBYUM
C04D HANGUL SYLLABLE BBYUB
C04E HANGUL SYLLABLE BBYUBS
C04F HANGUL SYLLABLE BBYUS
C050 HANGUL SYLLABLE BBYUSS
C051 HANGUL SYLLABLE BBYUNG
C052 HANGUL SYLLABLE BBYUJ
C053 HANGUL SYLLABLE BBYUC
C054 HANGUL SYLLABLE BBYUK
C055 HANGUL SYLLABLE BBYUT
C056 HANGUL SYLLABLE BBYUP
C057 HANGUL SYLLABLE BBYUH
C058 HANGUL SYLLABLE BBEU
C059 HANGUL SYLLABLE BBEUG
C05A HANGUL SYLLABLE BBEUGG
C05B HANGUL SYLLABLE BBEUGS
C05C HANGUL SYLLABLE BBEUN
C05D HANGUL SYLLABLE BBEUNJ
C05E HANGUL SYLLABLE BBEUNH
C05F HANGUL SYLLABLE BBEUD
C060 HANGUL SYLLABLE BBEUL
C061 HANGUL SYLLABLE BBEULG
C062 HANGUL SYLLABLE BBEULM
C063 HANGUL SYLLABLE BBEULB
C064 HANGUL SYLLABLE BBEULS
C065 HANGUL SYLLABLE BBEULT
C066 HANGUL SYLLABLE BBEULP
C067 HANGUL SYLLABLE BBEULH
C068 HANGUL SYLLABLE BBEUM
C069 HANGUL SYLLABLE BBEUB
C06A HANGUL SYLLABLE BBEUBS
C06B HANGUL SYLLABLE BBEUS
C06C HANGUL SYLLABLE BBEUSS
C06D HANGUL SYLLABLE BBEUNG
C06E HANGUL SYLLABLE BBEUJ
C06F HANGUL SYLLABLE BBEUC
C070 HANGUL SYLLABLE BBEUK
C071 HANGUL SYLLABLE BBEUT
C072 HANGUL SYLLABLE BBEUP
C073 HANGUL SYLLABLE BBEUH
C074 HANGUL SYLLABLE BBYI
C075 HANGUL SYLLABLE BBYIG
C076 HANGUL SYLLABLE BBYIGG
C077 HANGUL SYLLABLE BBYIGS
C078 HANGUL SYLLABLE BBYIN
C079 HANGUL SYLLABLE BBYINJ
C07A HANGUL SYLLABLE BBYINH
C07B HANGUL SYLLABLE BBYID
C07C HANGUL SYLLABLE BBYIL
C07D HANGUL SYLLABLE BBYILG
C07E HANGUL SYLLABLE BBYILM
C07F HANGUL SYLLABLE BBYILB
C080 HANGUL SYLLABLE BBYILS
C081 HANGUL SYLLABLE BBYILT
C082 HANGUL SYLLABLE BBYILP
C083 HANGUL SYLLABLE BBYILH
C084 HANGUL SYLLABLE BBYIM
C085 HANGUL SYLLABLE BBYIB
C086 HANGUL SYLLABLE BBYIBS
C087 HANGUL SYLLABLE BBYIS
C088 HANGUL SYLLABLE BBYISS
C089 HANGUL SYLLABLE BBYING
C08A HANGUL SYLLABLE BBYIJ
C08B HANGUL SYLLABLE BBYIC
C08C HANGUL SYLLABLE BBYIK
C08D HANGUL SYLLABLE BBYIT
C08E HANGUL SYLLABLE BBYIP
C08F HANGUL SYLLABLE BBYIH
C090 HANGUL SYLLABLE BBI
C091 HANGUL SYLLABLE BBIG
C092 HANGUL SYLLABLE BBIGG
C093 HANGUL SYLLABLE BBIGS
C094 HANGUL SYLLABLE BBIN
C095 HANGUL SYLLABLE BBINJ
C096 HANGUL SYLLABLE BBINH
C097 HANGUL SYLLABLE BBID
C098 HANGUL SYLLABLE BBIL
C099 HANGUL SYLLABLE BBILG
C09A HANGUL SYLLABLE BBILM
C09B HANGUL SYLLABLE BBILB
C09C HANGUL SYLLABLE BBILS
C09D HANGUL SYLLABLE BBILT
C09E HANGUL SYLLABLE BBILP
C09F HANGUL SYLLABLE BBILH
C0A0 HANGUL SYLLABLE BBIM
C0A1 HANGUL SYLLABLE BBIB
C0A2 HANGUL SYLLABLE BBIBS
C0A3 HANGUL SYLLABLE BBIS
C0A4 HANGUL SYLLABLE BBISS
C0A5 HANGUL SYLLABLE BBING
C0A6 HANGUL SYLLABLE BBIJ
C0A7 HANGUL SYLLABLE BBIC
C0A8 HANGUL SYLLABLE BBIK
C0A9 HANGUL SYLLABLE BBIT
C0AA HANGUL SYLLABLE BBIP
C0AB HANGUL SYLLABLE BBIH
C0AC HANGUL SYLLABLE SA
C0AD HANGUL SYLLABLE SAG
C0AE HANGUL SYLLABLE SAGG
C0AF HANGUL SYLLABLE SAGS
C0B0 HANGUL SYLLABLE SAN
C0B1 HANGUL SYLLABLE SANJ
C0B2 HANGUL SYLLABLE SANH
C0B3 HANGUL SYLLABLE SAD
C0B4 HANGUL SYLLABLE SAL
C0B5 HANGUL SYLLABLE SALG
C0B6 HANGUL SYLLABLE SALM
C0B7 HANGUL SYLLABLE SALB
C0B8 HANGUL SYLLABLE SALS
C0B9 HANGUL SYLLABLE SALT
C0BA HANGUL SYLLABLE SALP
C0BB HANGUL SYLLABLE SALH
C0BC HANGUL SYLLABLE SAM
C0BD HANGUL SYLLABLE SAB
C0BE HANGUL SYLLABLE SABS
C0BF HANGUL SYLLABLE SAS
C0C0 HANGUL SYLLABLE SASS
C0C1 HANGUL SYLLABLE SANG
C0C2 HANGUL SYLLABLE SAJ
C0C3 HANGUL SYLLABLE SAC
C0C4 HANGUL SYLLABLE SAK
C0C5 HANGUL SYLLABLE SAT
C0C6 HANGUL SYLLABLE SAP
C0C7 HANGUL SYLLABLE SAH
C0C8 HANGUL SYLLABLE SAE
C0C9 HANGUL SYLLABLE SAEG
C0CA HANGUL SYLLABLE SAEGG
C0CB HANGUL SYLLABLE SAEGS
C0CC HANGUL SYLLABLE SAEN
C0CD HANGUL SYLLABLE SAENJ
C0CE HANGUL SYLLABLE SAENH
C0CF HANGUL SYLLABLE SAED
C0D0 HANGUL SYLLABLE SAEL
C0D1 HANGUL SYLLABLE SAELG
C0D2 HANGUL SYLLABLE SAELM
C0D3 HANGUL SYLLABLE SAELB
C0D4 HANGUL SYLLABLE SAELS
C0D5 HANGUL SYLLABLE SAELT
C0D6 HANGUL SYLLABLE SAELP
C0D7 HANGUL SYLLABLE SAELH
C0D8 HANGUL SYLLABLE SAEM
C0D9 HANGUL SYLLABLE SAEB
C0DA HANGUL SYLLABLE SAEBS
C0DB HANGUL SYLLABLE SAES
C0DC HANGUL SYLLABLE SAESS
C0DD HANGUL SYLLABLE SAENG
C0DE HANGUL SYLLABLE SAEJ
C0DF HANGUL SYLLABLE SAEC
C0E0 HANGUL SYLLABLE SAEK
C0E1 HANGUL SYLLABLE SAET
C0E2 HANGUL SYLLABLE SAEP
C0E3 HANGUL SYLLABLE SAEH
C0E4 HANGUL SYLLABLE SYA
C0E5 HANGUL SYLLABLE SYAG
C0E6 HANGUL SYLLABLE SYAGG
C0E7 HANGUL SYLLABLE SYAGS
C0E8 HANGUL SYLLABLE SYAN
C0E9 HANGUL SYLLABLE SYANJ
C0EA HANGUL SYLLABLE SYANH
C0EB HANGUL SYLLABLE SYAD
C0EC HANGUL SYLLABLE SYAL
C0ED HANGUL SYLLABLE SYALG
C0EE HANGUL SYLLABLE SYALM
C0EF HANGUL SYLLABLE SYALB
C0F0 HANGUL SYLLABLE SYALS
C0F1 HANGUL SYLLABLE SYALT
C0F2 HANGUL SYLLABLE SYALP
C0F3 HANGUL SYLLABLE SYALH
C0F4 HANGUL SYLLABLE SYAM
C0F5 HANGUL SYLLABLE SYAB
C0F6 HANGUL SYLLABLE SYABS
C0F7 HANGUL SYLLABLE SYAS
C0F8 HANGUL SYLLABLE SYASS
C0F9 HANGUL SYLLABLE SYANG
C0FA HANGUL SYLLABLE SYAJ
C0FB HANGUL SYLLABLE SYAC
C0FC HANGUL SYLLABLE SYAK
C0FD HANGUL SYLLABLE SYAT
C0FE HANGUL SYLLABLE SYAP
C0FF HANGUL SYLLABLE SYAH
C100 HANGUL SYLLABLE SYAE
C101 HANGUL SYLLABLE SYAEG
C102 HANGUL SYLLABLE SYAEGG
C103 HANGUL SYLLABLE SYAEGS
C104 HANGUL SYLLABLE SYAEN
C105 HANGUL SYLLABLE SYAENJ
C106 HANGUL SYLLABLE SYAENH
C107 HANGUL SYLLABLE SYAED
C108 HANGUL SYLLABLE SYAEL
C109 HANGUL SYLLABLE SYAELG
C10A HANGUL SYLLABLE SYAELM
C10B HANGUL SYLLABLE SYAELB
C10C HANGUL SYLLABLE SYAELS
C10D HANGUL SYLLABLE SYAELT
C10E HANGUL SYLLABLE SYAELP
C10F HANGUL SYLLABLE SYAELH
C110 HANGUL SYLLABLE SYAEM
C111 HANGUL SYLLABLE SYAEB
C112 HANGUL SYLLABLE SYAEBS
C113 HANGUL SYLLABLE SYAES
C114 HANGUL SYLLABLE SYAESS
C115 HANGUL SYLLABLE SYAENG
C116 HANGUL SYLLABLE SYAEJ
C117 HANGUL SYLLABLE SYAEC
C118 HANGUL SYLLABLE SYAEK
C119 HANGUL SYLLABLE SYAET
C11A HANGUL SYLLABLE SYAEP
C11B HANGUL SYLLABLE SYAEH
C11C HANGUL SYLLABLE SEO
C11D HANGUL SYLLABLE SEOG
C11E HANGUL SYLLABLE SEOGG
C11F HANGUL SYLLABLE SEOGS
C120 HANGUL SYLLABLE SEON
C121 HANGUL SYLLABLE SEONJ
C122 HANGUL SYLLABLE SEONH
C123 HANGUL SYLLABLE SEOD
C124 HANGUL SYLLABLE SEOL
C125 HANGUL SYLLABLE SEOLG
C126 HANGUL SYLLABLE SEOLM
C127 HANGUL SYLLABLE SEOLB
C128 HANGUL SYLLABLE SEOLS
C129 HANGUL SYLLABLE SEOLT
C12A HANGUL SYLLABLE SEOLP
C12B HANGUL SYLLABLE SEOLH
C12C HANGUL SYLLABLE SEOM
C12D HANGUL SYLLABLE SEOB
C12E HANGUL SYLLABLE SEOBS
C12F HANGUL SYLLABLE SEOS
C130 HANGUL SYLLABLE SEOSS
C131 HANGUL SYLLABLE SEONG
C132 HANGUL SYLLABLE SEOJ
C133 HANGUL SYLLABLE SEOC
C134 HANGUL SYLLABLE SEOK
C135 HANGUL SYLLABLE SEOT
C136 HANGUL SYLLABLE SEOP
C137 HANGUL SYLLABLE SEOH
C138 HANGUL SYLLABLE SE
C139 HANGUL SYLLABLE SEG
C13A HANGUL SYLLABLE SEGG
C13B HANGUL SYLLABLE SEGS
C13C HANGUL SYLLABLE SEN
C13D HANGUL SYLLABLE SENJ
C13E HANGUL SYLLABLE SENH
C13F HANGUL SYLLABLE SED
C140 HANGUL SYLLABLE SEL
C141 HANGUL SYLLABLE SELG
C142 HANGUL SYLLABLE SELM
C143 HANGUL SYLLABLE SELB
C144 HANGUL SYLLABLE SELS
C145 HANGUL SYLLABLE SELT
C146 HANGUL SYLLABLE SELP
C147 HANGUL SYLLABLE SELH
C148 HANGUL SYLLABLE SEM
C149 HANGUL SYLLABLE SEB
C14A HANGUL SYLLABLE SEBS
C14B HANGUL SYLLABLE SES
C14C HANGUL SYLLABLE SESS
C14D HANGUL SYLLABLE SENG
C14E HANGUL SYLLABLE SEJ
C14F HANGUL SYLLABLE SEC
C150 HANGUL SYLLABLE SEK
C151 HANGUL SYLLABLE SET
C152 HANGUL SYLLABLE SEP
C153 HANGUL SYLLABLE SEH
C154 HANGUL SYLLABLE SYEO
C155 HANGUL SYLLABLE SYEOG
C156 HANGUL SYLLABLE SYEOGG
C157 HANGUL SYLLABLE SYEOGS
C158 HANGUL SYLLABLE SYEON
C159 HANGUL SYLLABLE SYEONJ
C15A HANGUL SYLLABLE SYEONH
C15B HANGUL SYLLABLE SYEOD
C15C HANGUL SYLLABLE SYEOL
C15D HANGUL SYLLABLE SYEOLG
C15E HANGUL SYLLABLE SYEOLM
C15F HANGUL SYLLABLE SYEOLB
C160 HANGUL SYLLABLE SYEOLS
C161 HANGUL SYLLABLE SYEOLT
C162 HANGUL SYLLABLE SYEOLP
C163 HANGUL SYLLABLE SYEOLH
C164 HANGUL SYLLABLE SYEOM
C165 HANGUL SYLLABLE SYEOB
C166 HANGUL SYLLABLE SYEOBS
C167 HANGUL SYLLABLE SYEOS
C168 HANGUL SYLLABLE SYEOSS
C169 HANGUL SYLLABLE SYEONG
C16A HANGUL SYLLABLE SYEOJ
C16B HANGUL SYLLABLE SYEOC
C16C HANGUL SYLLABLE SYEOK
C16D HANGUL SYLLABLE SYEOT
C16E HANGUL SYLLABLE SYEOP
C16F HANGUL SYLLABLE SYEOH
C170 HANGUL SYLLABLE SYE
C171 HANGUL SYLLABLE SYEG
C172 HANGUL SYLLABLE SYEGG
C173 HANGUL SYLLABLE SYEGS
C174 HANGUL SYLLABLE SYEN
C175 HANGUL SYLLABLE SYENJ
C176 HANGUL SYLLABLE SYENH
C177 HANGUL SYLLABLE SYED
C178 HANGUL SYLLABLE SYEL
C179 HANGUL SYLLABLE SYELG
C17A HANGUL SYLLABLE SYELM
C17B HANGUL SYLLABLE SYELB
C17C HANGUL SYLLABLE SYELS
C17D HANGUL SYLLABLE SYELT
C17E HANGUL SYLLABLE SYELP
C17F HANGUL SYLLABLE SYELH
C180 HANGUL SYLLABLE SYEM
C181 HANGUL SYLLABLE SYEB
C182 HANGUL SYLLABLE SYEBS
C183 HANGUL SYLLABLE SYES
C184 HANGUL SYLLABLE SYESS
C185 HANGUL SYLLABLE SYENG
C186 HANGUL SYLLABLE SYEJ
C187 HANGUL SYLLABLE SYEC
C188 HANGUL SYLLABLE SYEK
C189 HANGUL SYLLABLE SYET
C18A HANGUL SYLLABLE SYEP
C18B HANGUL SYLLABLE SYEH
C18C HANGUL SYLLABLE SO
C18D HANGUL SYLLABLE SOG
C18E HANGUL SYLLABLE SOGG
C18F HANGUL SYLLABLE SOGS
C190 HANGUL SYLLABLE SON
C191 HANGUL SYLLABLE SONJ
C192 HANGUL SYLLABLE SONH
C193 HANGUL SYLLABLE SOD
C194 HANGUL SYLLABLE SOL
C195 HANGUL SYLLABLE SOLG
C196 HANGUL SYLLABLE SOLM
C197 HANGUL SYLLABLE SOLB
C198 HANGUL SYLLABLE SOLS
C199 HANGUL SYLLABLE SOLT
C19A HANGUL SYLLABLE SOLP
C19B HANGUL SYLLABLE SOLH
C19C HANGUL SYLLABLE SOM
C19D HANGUL SYLLABLE SOB
C19E HANGUL SYLLABLE SOBS
C19F HANGUL SYLLABLE SOS
C1A0 HANGUL SYLLABLE SOSS
C1A1 HANGUL SYLLABLE SONG
C1A2 HANGUL SYLLABLE SOJ
C1A3 HANGUL SYLLABLE SOC
C1A4 HANGUL SYLLABLE SOK
C1A5 HANGUL SYLLABLE SOT
C1A6 HANGUL SYLLABLE SOP
C1A7 HANGUL SYLLABLE SOH
C1A8 HANGUL SYLLABLE SWA
C1A9 HANGUL SYLLABLE SWAG
C1AA HANGUL SYLLABLE SWAGG
C1AB HANGUL SYLLABLE SWAGS
C1AC HANGUL SYLLABLE SWAN
C1AD HANGUL SYLLABLE SWANJ
C1AE HANGUL SYLLABLE SWANH
C1AF HANGUL SYLLABLE SWAD
C1B0 HANGUL SYLLABLE SWAL
C1B1 HANGUL SYLLABLE SWALG
C1B2 HANGUL SYLLABLE SWALM
C1B3 HANGUL SYLLABLE SWALB
C1B4 HANGUL SYLLABLE SWALS
C1B5 HANGUL SYLLABLE SWALT
C1B6 HANGUL SYLLABLE SWALP
C1B7 HANGUL SYLLABLE SWALH
C1B8 HANGUL SYLLABLE SWAM
C1B9 HANGUL SYLLABLE SWAB
C1BA HANGUL SYLLABLE SWABS
C1BB HANGUL SYLLABLE SWAS
C1BC HANGUL SYLLABLE SWASS
C1BD HANGUL SYLLABLE SWANG
C1BE HANGUL SYLLABLE SWAJ
C1BF HANGUL SYLLABLE SWAC
C1C0 HANGUL SYLLABLE SWAK
C1C1 HANGUL SYLLABLE SWAT
C1C2 HANGUL SYLLABLE SWAP
C1C3 HANGUL SYLLABLE SWAH
C1C4 HANGUL SYLLABLE SWAE
C1C5 HANGUL SYLLABLE SWAEG
C1C6 HANGUL SYLLABLE SWAEGG
C1C7 HANGUL SYLLABLE SWAEGS
C1C8 HANGUL SYLLABLE SWAEN
C1C9 HANGUL SYLLABLE SWAENJ
C1CA HANGUL SYLLABLE SWAENH
C1CB HANGUL SYLLABLE SWAED
C1CC HANGUL SYLLABLE SWAEL
C1CD HANGUL SYLLABLE SWAELG
C1CE HANGUL SYLLABLE SWAELM
C1CF HANGUL SYLLABLE SWAELB
C1D0 HANGUL SYLLABLE SWAELS
C1D1 HANGUL SYLLABLE SWAELT
C1D2 HANGUL SYLLABLE SWAELP
C1D3 HANGUL SYLLABLE SWAELH
C1D4 HANGUL SYLLABLE SWAEM
C1D5 HANGUL SYLLABLE SWAEB
C1D6 HANGUL SYLLABLE SWAEBS
C1D7 HANGUL SYLLABLE SWAES
C1D8 HANGUL SYLLABLE SWAESS
C1D9 HANGUL SYLLABLE SWAENG
C1DA HANGUL SYLLABLE SWAEJ
C1DB HANGUL SYLLABLE SWAEC
C1DC HANGUL SYLLABLE SWAEK
C1DD HANGUL SYLLABLE SWAET
C1DE HANGUL SYLLABLE SWAEP
C1DF HANGUL SYLLABLE SWAEH
C1E0 HANGUL SYLLABLE SOE
C1E1 HANGUL SYLLABLE SOEG
C1E2 HANGUL SYLLABLE SOEGG
C1E3 HANGUL SYLLABLE SOEGS
C1E4 HANGUL SYLLABLE SOEN
C1E5 HANGUL SYLLABLE SOENJ
C1E6 HANGUL SYLLABLE SOENH
C1E7 HANGUL SYLLABLE SOED
C1E8 HANGUL SYLLABLE SOEL
C1E9 HANGUL SYLLABLE SOELG
C1EA HANGUL SYLLABLE SOELM
C1EB HANGUL SYLLABLE SOELB
C1EC HANGUL SYLLABLE SOELS
C1ED HANGUL SYLLABLE SOELT
C1EE HANGUL SYLLABLE SOELP
C1EF HANGUL SYLLABLE SOELH
C1F0 HANGUL SYLLABLE SOEM
C1F1 HANGUL SYLLABLE SOEB
C1F2 HANGUL SYLLABLE SOEBS
C1F3 HANGUL SYLLABLE SOES
C1F4 HANGUL SYLLABLE SOESS
C1F5 HANGUL SYLLABLE SOENG
C1F6 HANGUL SYLLABLE SOEJ
C1F7 HANGUL SYLLABLE SOEC
C1F8 HANGUL SYLLABLE SOEK
C1F9 HANGUL SYLLABLE SOET
C1FA HANGUL SYLLABLE SOEP
C1FB HANGUL SYLLABLE SOEH
C1FC HANGUL SYLLABLE SYO
C1FD HANGUL SYLLABLE SYOG
C1FE HANGUL SYLLABLE SYOGG
C1FF HANGUL SYLLABLE SYOGS
C200 HANGUL SYLLABLE SYON
C201 HANGUL SYLLABLE SYONJ
C202 HANGUL SYLLABLE SYONH
C203 HANGUL SYLLABLE SYOD
C204 HANGUL SYLLABLE SYOL
C205 HANGUL SYLLABLE SYOLG
C206 HANGUL SYLLABLE SYOLM
C207 HANGUL SYLLABLE SYOLB
C208 HANGUL SYLLABLE SYOLS
C209 HANGUL SYLLABLE SYOLT
C20A HANGUL SYLLABLE SYOLP
C20B HANGUL SYLLABLE SYOLH
C20C HANGUL SYLLABLE SYOM
C20D HANGUL SYLLABLE SYOB
C20E HANGUL SYLLABLE SYOBS
C20F HANGUL SYLLABLE SYOS
C210 HANGUL SYLLABLE SYOSS
C211 HANGUL SYLLABLE SYONG
C212 HANGUL SYLLABLE SYOJ
C213 HANGUL SYLLABLE SYOC
C214 HANGUL SYLLABLE SYOK
C215 HANGUL SYLLABLE SYOT
C216 HANGUL SYLLABLE SYOP
C217 HANGUL SYLLABLE SYOH
C218 HANGUL SYLLABLE SU
C219 HANGUL SYLLABLE SUG
C21A HANGUL SYLLABLE SUGG
C21B HANGUL SYLLABLE SUGS
C21C HANGUL SYLLABLE SUN
C21D HANGUL SYLLABLE SUNJ
C21E HANGUL SYLLABLE SUNH
C21F HANGUL SYLLABLE SUD
C220 HANGUL SYLLABLE SUL
C221 HANGUL SYLLABLE SULG
C222 HANGUL SYLLABLE SULM
C223 HANGUL SYLLABLE SULB
C224 HANGUL SYLLABLE SULS
C225 HANGUL SYLLABLE SULT
C226 HANGUL SYLLABLE SULP
C227 HANGUL SYLLABLE SULH
C228 HANGUL SYLLABLE SUM
C229 HANGUL SYLLABLE SUB
C22A HANGUL SYLLABLE SUBS
C22B HANGUL SYLLABLE SUS
C22C HANGUL SYLLABLE SUSS
C22D HANGUL SYLLABLE SUNG
C22E HANGUL SYLLABLE SUJ
C22F HANGUL SYLLABLE SUC
C230 HANGUL SYLLABLE SUK
C231 HANGUL SYLLABLE SUT
C232 HANGUL SYLLABLE SUP
C233 HANGUL SYLLABLE SUH
C234 HANGUL SYLLABLE SWEO
C235 HANGUL SYLLABLE SWEOG
C236 HANGUL SYLLABLE SWEOGG
C237 HANGUL SYLLABLE SWEOGS
C238 HANGUL SYLLABLE SWEON
C239 HANGUL SYLLABLE SWEONJ
C23A HANGUL SYLLABLE SWEONH
C23B HANGUL SYLLABLE SWEOD
C23C HANGUL SYLLABLE SWEOL
C23D HANGUL SYLLABLE SWEOLG
C23E HANGUL SYLLABLE SWEOLM
C23F HANGUL SYLLABLE SWEOLB
C240 HANGUL SYLLABLE SWEOLS
C241 HANGUL SYLLABLE SWEOLT
C242 HANGUL SYLLABLE SWEOLP
C243 HANGUL SYLLABLE SWEOLH
C244 HANGUL SYLLABLE SWEOM
C245 HANGUL SYLLABLE SWEOB
C246 HANGUL SYLLABLE SWEOBS
C247 HANGUL SYLLABLE SWEOS
C248 HANGUL SYLLABLE SWEOSS
C249 HANGUL SYLLABLE SWEONG
C24A HANGUL SYLLABLE SWEOJ
C24B HANGUL SYLLABLE SWEOC
C24C HANGUL SYLLABLE SWEOK
C24D HANGUL SYLLABLE SWEOT
C24E HANGUL SYLLABLE SWEOP
C24F HANGUL SYLLABLE SWEOH
C250 HANGUL SYLLABLE SWE
C251 HANGUL SYLLABLE SWEG
C252 HANGUL SYLLABLE SWEGG
C253 HANGUL SYLLABLE SWEGS
C254 HANGUL SYLLABLE SWEN
C255 HANGUL SYLLABLE SWENJ
C256 HANGUL SYLLABLE SWENH
C257 HANGUL SYLLABLE SWED
C258 HANGUL SYLLABLE SWEL
C259 HANGUL SYLLABLE SWELG
C25A HANGUL SYLLABLE SWELM
C25B HANGUL SYLLABLE SWELB
C25C HANGUL SYLLABLE SWELS
C25D HANGUL SYLLABLE SWELT
C25E HANGUL SYLLABLE SWELP
C25F HANGUL SYLLABLE SWELH
C260 HANGUL SYLLABLE SWEM
C261 HANGUL SYLLABLE SWEB
C262 HANGUL SYLLABLE SWEBS
C263 HANGUL SYLLABLE SWES
C264 HANGUL SYLLABLE SWESS
C265 HANGUL SYLLABLE SWENG
C266 HANGUL SYLLABLE SWEJ
C267 HANGUL SYLLABLE SWEC
C268 HANGUL SYLLABLE SWEK
C269 HANGUL SYLLABLE SWET
C26A HANGUL SYLLABLE SWEP
C26B HANGUL SYLLABLE SWEH
C26C HANGUL SYLLABLE SWI
C26D HANGUL SYLLABLE SWIG
C26E HANGUL SYLLABLE SWIGG
C26F HANGUL SYLLABLE SWIGS
C270 HANGUL SYLLABLE SWIN
C271 HANGUL SYLLABLE SWINJ
C272 HANGUL SYLLABLE SWINH
C273 HANGUL SYLLABLE SWID
C274 HANGUL SYLLABLE SWIL
C275 HANGUL SYLLABLE SWILG
C276 HANGUL SYLLABLE SWILM
C277 HANGUL SYLLABLE SWILB
C278 HANGUL SYLLABLE SWILS
C279 HANGUL SYLLABLE SWILT
C27A HANGUL SYLLABLE SWILP
C27B HANGUL SYLLABLE SWILH
C27C HANGUL SYLLABLE SWIM
C27D HANGUL SYLLABLE SWIB
C27E HANGUL SYLLABLE SWIBS
C27F HANGUL SYLLABLE SWIS
C280 HANGUL SYLLABLE SWISS
C281 HANGUL SYLLABLE SWING
C282 HANGUL SYLLABLE SWIJ
C283 HANGUL SYLLABLE SWIC
C284 HANGUL SYLLABLE SWIK
C285 HANGUL SYLLABLE SWIT
C286 HANGUL SYLLABLE SWIP
C287 HANGUL SYLLABLE SWIH
C288 HANGUL SYLLABLE SYU
C289 HANGUL SYLLABLE SYUG
C28A HANGUL SYLLABLE SYUGG
C28B HANGUL SYLLABLE SYUGS
C28C HANGUL SYLLABLE SYUN
C28D HANGUL SYLLABLE SYUNJ
C28E HANGUL SYLLABLE SYUNH
C28F HANGUL SYLLABLE SYUD
C290 HANGUL SYLLABLE SYUL
C291 HANGUL SYLLABLE SYULG
C292 HANGUL SYLLABLE SYULM
C293 HANGUL SYLLABLE SYULB
C294 HANGUL SYLLABLE SYULS
C295 HANGUL SYLLABLE SYULT
C296 HANGUL SYLLABLE SYULP
C297 HANGUL SYLLABLE SYULH
C298 HANGUL SYLLABLE SYUM
C299 HANGUL SYLLABLE SYUB
C29A HANGUL SYLLABLE SYUBS
C29B HANGUL SYLLABLE SYUS
C29C HANGUL SYLLABLE SYUSS
C29D HANGUL SYLLABLE SYUNG
C29E HANGUL SYLLABLE SYUJ
C29F HANGUL SYLLABLE SYUC
C2A0 HANGUL SYLLABLE SYUK
C2A1 HANGUL SYLLABLE SYUT
C2A2 HANGUL SYLLABLE SYUP
C2A3 HANGUL SYLLABLE SYUH
C2A4 HANGUL SYLLABLE SEU
C2A5 HANGUL SYLLABLE SEUG
C2A6 HANGUL SYLLABLE SEUGG
C2A7 HANGUL SYLLABLE SEUGS
C2A8 HANGUL SYLLABLE SEUN
C2A9 HANGUL SYLLABLE SEUNJ
C2AA HANGUL SYLLABLE SEUNH
C2AB HANGUL SYLLABLE SEUD
C2AC HANGUL SYLLABLE SEUL
C2AD HANGUL SYLLABLE SEULG
C2AE HANGUL SYLLABLE SEULM
C2AF HANGUL SYLLABLE SEULB
C2B0 HANGUL SYLLABLE SEULS
C2B1 HANGUL SYLLABLE SEULT
C2B2 HANGUL SYLLABLE SEULP
C2B3 HANGUL SYLLABLE SEULH
C2B4 HANGUL SYLLABLE SEUM
C2B5 HANGUL SYLLABLE SEUB
C2B6 HANGUL SYLLABLE SEUBS
C2B7 HANGUL SYLLABLE SEUS
C2B8 HANGUL SYLLABLE SEUSS
C2B9 HANGUL SYLLABLE SEUNG
C2BA HANGUL SYLLABLE SEUJ
C2BB HANGUL SYLLABLE SEUC
C2BC HANGUL SYLLABLE SEUK
C2BD HANGUL SYLLABLE SEUT
C2BE HANGUL SYLLABLE SEUP
C2BF HANGUL SYLLABLE SEUH
C2C0 HANGUL SYLLABLE SYI
C2C1 HANGUL SYLLABLE SYIG
C2C2 HANGUL SYLLABLE SYIGG
C2C3 HANGUL SYLLABLE SYIGS
C2C4 HANGUL SYLLABLE SYIN
C2C5 HANGUL SYLLABLE SYINJ
C2C6 HANGUL SYLLABLE SYINH
C2C7 HANGUL SYLLABLE SYID
C2C8 HANGUL SYLLABLE SYIL
C2C9 HANGUL SYLLABLE SYILG
C2CA HANGUL SYLLABLE SYILM
C2CB HANGUL SYLLABLE SYILB
C2CC HANGUL SYLLABLE SYILS
C2CD HANGUL SYLLABLE SYILT
C2CE HANGUL SYLLABLE SYILP
C2CF HANGUL SYLLABLE SYILH
C2D0 HANGUL SYLLABLE SYIM
C2D1 HANGUL SYLLABLE SYIB
C2D2 HANGUL SYLLABLE SYIBS
C2D3 HANGUL SYLLABLE SYIS
C2D4 HANGUL SYLLABLE SYISS
C2D5 HANGUL SYLLABLE SYING
C2D6 HANGUL SYLLABLE SYIJ
C2D7 HANGUL SYLLABLE SYIC
C2D8 HANGUL SYLLABLE SYIK
C2D9 HANGUL SYLLABLE SYIT
C2DA HANGUL SYLLABLE SYIP
C2DB HANGUL SYLLABLE SYIH
C2DC HANGUL SYLLABLE SI
C2DD HANGUL SYLLABLE SIG
C2DE HANGUL SYLLABLE SIGG
C2DF HANGUL SYLLABLE SIGS
C2E0 HANGUL SYLLABLE SIN
C2E1 HANGUL SYLLABLE SINJ
C2E2 HANGUL SYLLABLE SINH
C2E3 HANGUL SYLLABLE SID
C2E4 HANGUL SYLLABLE SIL
C2E5 HANGUL SYLLABLE SILG
C2E6 HANGUL SYLLABLE SILM
C2E7 HANGUL SYLLABLE SILB
C2E8 HANGUL SYLLABLE SILS
C2E9 HANGUL SYLLABLE SILT
C2EA HANGUL SYLLABLE SILP
C2EB HANGUL SYLLABLE SILH
C2EC HANGUL SYLLABLE SIM
C2ED HANGUL SYLLABLE SIB
C2EE HANGUL SYLLABLE SIBS
C2EF HANGUL SYLLABLE SIS
C2F0 HANGUL SYLLABLE SISS
C2F1 HANGUL SYLLABLE SING
C2F2 HANGUL SYLLABLE SIJ
C2F3 HANGUL SYLLABLE SIC
C2F4 HANGUL SYLLABLE SIK
C2F5 HANGUL SYLLABLE SIT
C2F6 HANGUL SYLLABLE SIP
C2F7 HANGUL SYLLABLE SIH
C2F8 HANGUL SYLLABLE SSA
C2F9 HANGUL SYLLABLE SSAG
C2FA HANGUL SYLLABLE SSAGG
C2FB HANGUL SYLLABLE SSAGS
C2FC HANGUL SYLLABLE SSAN
C2FD HANGUL SYLLABLE SSANJ
C2FE HANGUL SYLLABLE SSANH
C2FF HANGUL SYLLABLE SSAD
C300 HANGUL SYLLABLE SSAL
C301 HANGUL SYLLABLE SSALG
C302 HANGUL SYLLABLE SSALM
C303 HANGUL SYLLABLE SSALB
C304 HANGUL SYLLABLE SSALS
C305 HANGUL SYLLABLE SSALT
C306 HANGUL SYLLABLE SSALP
C307 HANGUL SYLLABLE SSALH
C308 HANGUL SYLLABLE SSAM
C309 HANGUL SYLLABLE SSAB
C30A HANGUL SYLLABLE SSABS
C30B HANGUL SYLLABLE SSAS
C30C HANGUL SYLLABLE SSASS
C30D HANGUL SYLLABLE SSANG
C30E HANGUL SYLLABLE SSAJ
C30F HANGUL SYLLABLE SSAC
C310 HANGUL SYLLABLE SSAK
C311 HANGUL SYLLABLE SSAT
C312 HANGUL SYLLABLE SSAP
C313 HANGUL SYLLABLE SSAH
C314 HANGUL SYLLABLE SSAE
C315 HANGUL SYLLABLE SSAEG
C316 HANGUL SYLLABLE SSAEGG
C317 HANGUL SYLLABLE SSAEGS
C318 HANGUL SYLLABLE SSAEN
C319 HANGUL SYLLABLE SSAENJ
C31A HANGUL SYLLABLE SSAENH
C31B HANGUL SYLLABLE SSAED
C31C HANGUL SYLLABLE SSAEL
C31D HANGUL SYLLABLE SSAELG
C31E HANGUL SYLLABLE SSAELM
C31F HANGUL SYLLABLE SSAELB
C320 HANGUL SYLLABLE SSAELS
C321 HANGUL SYLLABLE SSAELT
C322 HANGUL SYLLABLE SSAELP
C323 HANGUL SYLLABLE SSAELH
C324 HANGUL SYLLABLE SSAEM
C325 HANGUL SYLLABLE SSAEB
C326 HANGUL SYLLABLE SSAEBS
C327 HANGUL SYLLABLE SSAES
C328 HANGUL SYLLABLE SSAESS
C329 HANGUL SYLLABLE SSAENG
C32A HANGUL SYLLABLE SSAEJ
C32B HANGUL SYLLABLE SSAEC
C32C HANGUL SYLLABLE SSAEK
C32D HANGUL SYLLABLE SSAET
C32E HANGUL SYLLABLE SSAEP
C32F HANGUL SYLLABLE SSAEH
C330 HANGUL SYLLABLE SSYA
C331 HANGUL SYLLABLE SSYAG
C332 HANGUL SYLLABLE SSYAGG
C333 HANGUL SYLLABLE SSYAGS
C334 HANGUL SYLLABLE SSYAN
C335 HANGUL SYLLABLE SSYANJ
C336 HANGUL SYLLABLE SSYANH
C337 HANGUL SYLLABLE SSYAD
C338 HANGUL SYLLABLE SSYAL
C339 HANGUL SYLLABLE SSYALG
C33A HANGUL SYLLABLE SSYALM
C33B HANGUL SYLLABLE SSYALB
C33C HANGUL SYLLABLE SSYALS
C33D HANGUL SYLLABLE SSYALT
C33E HANGUL SYLLABLE SSYALP
C33F HANGUL SYLLABLE SSYALH
C340 HANGUL SYLLABLE SSYAM
C341 HANGUL SYLLABLE SSYAB
C342 HANGUL SYLLABLE SSYABS
C343 HANGUL SYLLABLE SSYAS
C344 HANGUL SYLLABLE SSYASS
C345 HANGUL SYLLABLE SSYANG
C346 HANGUL SYLLABLE SSYAJ
C347 HANGUL SYLLABLE SSYAC
C348 HANGUL SYLLABLE SSYAK
C349 HANGUL SYLLABLE SSYAT
C34A HANGUL SYLLABLE SSYAP
C34B HANGUL SYLLABLE SSYAH
C34C HANGUL SYLLABLE SSYAE
C34D HANGUL SYLLABLE SSYAEG
C34E HANGUL SYLLABLE SSYAEGG
C34F HANGUL SYLLABLE SSYAEGS
C350 HANGUL SYLLABLE SSYAEN
C351 HANGUL SYLLABLE SSYAENJ
C352 HANGUL SYLLABLE SSYAENH
C353 HANGUL SYLLABLE SSYAED
C354 HANGUL SYLLABLE SSYAEL
C355 HANGUL SYLLABLE SSYAELG
C356 HANGUL SYLLABLE SSYAELM
C357 HANGUL SYLLABLE SSYAELB
C358 HANGUL SYLLABLE SSYAELS
C359 HANGUL SYLLABLE SSYAELT
C35A HANGUL SYLLABLE SSYAELP
C35B HANGUL SYLLABLE SSYAELH
C35C HANGUL SYLLABLE SSYAEM
C35D HANGUL SYLLABLE SSYAEB
C35E HANGUL SYLLABLE SSYAEBS
C35F HANGUL SYLLABLE SSYAES
C360 HANGUL SYLLABLE SSYAESS
C361 HANGUL SYLLABLE SSYAENG
C362 HANGUL SYLLABLE SSYAEJ
C363 HANGUL SYLLABLE SSYAEC
C364 HANGUL SYLLABLE SSYAEK
C365 HANGUL SYLLABLE SSYAET
C366 HANGUL SYLLABLE SSYAEP
C367 HANGUL SYLLABLE SSYAEH
C368 HANGUL SYLLABLE SSEO
C369 HANGUL SYLLABLE SSEOG
C36A HANGUL SYLLABLE SSEOGG
C36B HANGUL SYLLABLE SSEOGS
C36C HANGUL SYLLABLE SSEON
C36D HANGUL SYLLABLE SSEONJ
C36E HANGUL SYLLABLE SSEONH
C36F HANGUL SYLLABLE SSEOD
C370 HANGUL SYLLABLE SSEOL
C371 HANGUL SYLLABLE SSEOLG
C372 HANGUL SYLLABLE SSEOLM
C373 HANGUL SYLLABLE SSEOLB
C374 HANGUL SYLLABLE SSEOLS
C375 HANGUL SYLLABLE SSEOLT
C376 HANGUL SYLLABLE SSEOLP
C377 HANGUL SYLLABLE SSEOLH
C378 HANGUL SYLLABLE SSEOM
C379 HANGUL SYLLABLE SSEOB
C37A HANGUL SYLLABLE SSEOBS
C37B HANGUL SYLLABLE SSEOS
C37C HANGUL SYLLABLE SSEOSS
C37D HANGUL SYLLABLE SSEONG
C37E HANGUL SYLLABLE SSEOJ
C37F HANGUL SYLLABLE SSEOC
C380 HANGUL SYLLABLE SSEOK
C381 HANGUL SYLLABLE SSEOT
C382 HANGUL SYLLABLE SSEOP
C383 HANGUL SYLLABLE SSEOH
C384 HANGUL SYLLABLE SSE
C385 HANGUL SYLLABLE SSEG
C386 HANGUL SYLLABLE SSEGG
C387 HANGUL SYLLABLE SSEGS
C388 HANGUL SYLLABLE SSEN
C389 HANGUL SYLLABLE SSENJ
C38A HANGUL SYLLABLE SSENH
C38B HANGUL SYLLABLE SSED
C38C HANGUL SYLLABLE SSEL
C38D HANGUL SYLLABLE SSELG
C38E HANGUL SYLLABLE SSELM
C38F HANGUL SYLLABLE SSELB
C390 HANGUL SYLLABLE SSELS
C391 HANGUL SYLLABLE SSELT
C392 HANGUL SYLLABLE SSELP
C393 HANGUL SYLLABLE SSELH
C394 HANGUL SYLLABLE SSEM
C395 HANGUL SYLLABLE SSEB
C396 HANGUL SYLLABLE SSEBS
C397 HANGUL SYLLABLE SSES
C398 HANGUL SYLLABLE SSESS
C399 HANGUL SYLLABLE SSENG
C39A HANGUL SYLLABLE SSEJ
C39B HANGUL SYLLABLE SSEC
C39C HANGUL SYLLABLE SSEK
C39D HANGUL SYLLABLE SSET
C39E HANGUL SYLLABLE SSEP
C39F HANGUL SYLLABLE SSEH
C3A0 HANGUL SYLLABLE SSYEO
C3A1 HANGUL SYLLABLE SSYEOG
C3A2 HANGUL SYLLABLE SSYEOGG
C3A3 HANGUL SYLLABLE SSYEOGS
C3A4 HANGUL SYLLABLE SSYEON
C3A5 HANGUL SYLLABLE SSYEONJ
C3A6 HANGUL SYLLABLE SSYEONH
C3A7 HANGUL SYLLABLE SSYEOD
C3A8 HANGUL SYLLABLE SSYEOL
C3A9 HANGUL SYLLABLE SSYEOLG
C3AA HANGUL SYLLABLE SSYEOLM
C3AB HANGUL SYLLABLE SSYEOLB
C3AC HANGUL SYLLABLE SSYEOLS
C3AD HANGUL SYLLABLE SSYEOLT
C3AE HANGUL SYLLABLE SSYEOLP
C3AF HANGUL SYLLABLE SSYEOLH
C3B0 HANGUL SYLLABLE SSYEOM
C3B1 HANGUL SYLLABLE SSYEOB
C3B2 HANGUL SYLLABLE SSYEOBS
C3B3 HANGUL SYLLABLE SSYEOS
C3B4 HANGUL SYLLABLE SSYEOSS
C3B5 HANGUL SYLLABLE SSYEONG
C3B6 HANGUL SYLLABLE SSYEOJ
C3B7 HANGUL SYLLABLE SSYEOC
C3B8 HANGUL SYLLABLE SSYEOK
C3B9 HANGUL SYLLABLE SSYEOT
C3BA HANGUL SYLLABLE SSYEOP
C3BB HANGUL SYLLABLE SSYEOH
C3BC HANGUL SYLLABLE SSYE
C3BD HANGUL SYLLABLE SSYEG
C3BE HANGUL SYLLABLE SSYEGG
C3BF HANGUL SYLLABLE SSYEGS
C3C0 HANGUL SYLLABLE SSYEN
C3C1 HANGUL SYLLABLE SSYENJ
C3C2 HANGUL SYLLABLE SSYENH
C3C3 HANGUL SYLLABLE SSYED
C3C4 HANGUL SYLLABLE SSYEL
C3C5 HANGUL SYLLABLE SSYELG
C3C6 HANGUL SYLLABLE SSYELM
C3C7 HANGUL SYLLABLE SSYELB
C3C8 HANGUL SYLLABLE SSYELS
C3C9 HANGUL SYLLABLE SSYELT
C3CA HANGUL SYLLABLE SSYELP
C3CB HANGUL SYLLABLE SSYELH
C3CC HANGUL SYLLABLE SSYEM
C3CD HANGUL SYLLABLE SSYEB
C3CE HANGUL SYLLABLE SSYEBS
C3CF HANGUL SYLLABLE SSYES
C3D0 HANGUL SYLLABLE SSYESS
C3D1 HANGUL SYLLABLE SSYENG
C3D2 HANGUL SYLLABLE SSYEJ
C3D3 HANGUL SYLLABLE SSYEC
C3D4 HANGUL SYLLABLE SSYEK
C3D5 HANGUL SYLLABLE SSYET
C3D6 HANGUL SYLLABLE SSYEP
C3D7 HANGUL SYLLABLE SSYEH
C3D8 HANGUL SYLLABLE SSO
C3D9 HANGUL SYLLABLE SSOG
C3DA HANGUL SYLLABLE SSOGG
C3DB HANGUL SYLLABLE SSOGS
C3DC HANGUL SYLLABLE SSON
C3DD HANGUL SYLLABLE SSONJ
C3DE HANGUL SYLLABLE SSONH
C3DF HANGUL SYLLABLE SSOD
C3E0 HANGUL SYLLABLE SSOL
C3E1 HANGUL SYLLABLE SSOLG
C3E2 HANGUL SYLLABLE SSOLM
C3E3 HANGUL SYLLABLE SSOLB
C3E4 HANGUL SYLLABLE SSOLS
C3E5 HANGUL SYLLABLE SSOLT
C3E6 HANGUL SYLLABLE SSOLP
C3E7 HANGUL SYLLABLE SSOLH
C3E8 HANGUL SYLLABLE SSOM
C3E9 HANGUL SYLLABLE SSOB
C3EA HANGUL SYLLABLE SSOBS
C3EB HANGUL SYLLABLE SSOS
C3EC HANGUL SYLLABLE SSOSS
C3ED HANGUL SYLLABLE SSONG
C3EE HANGUL SYLLABLE SSOJ
C3EF HANGUL SYLLABLE SSOC
C3F0 HANGUL SYLLABLE SSOK
C3F1 HANGUL SYLLABLE SSOT
C3F2 HANGUL SYLLABLE SSOP
C3F3 HANGUL SYLLABLE SSOH
C3F4 HANGUL SYLLABLE SSWA
C3F5 HANGUL SYLLABLE SSWAG
C3F6 HANGUL SYLLABLE SSWAGG
C3F7 HANGUL SYLLABLE SSWAGS
C3F8 HANGUL SYLLABLE SSWAN
C3F9 HANGUL SYLLABLE SSWANJ
C3FA HANGUL SYLLABLE SSWANH
C3FB HANGUL SYLLABLE SSWAD
C3FC HANGUL SYLLABLE SSWAL
C3FD HANGUL SYLLABLE SSWALG
C3FE HANGUL SYLLABLE SSWALM
C3FF HANGUL SYLLABLE SSWALB
C400 HANGUL SYLLABLE SSWALS
C401 HANGUL SYLLABLE SSWALT
C402 HANGUL SYLLABLE SSWALP
C403 HANGUL SYLLABLE SSWALH
C404 HANGUL SYLLABLE SSWAM
C405 HANGUL SYLLABLE SSWAB
C406 HANGUL SYLLABLE SSWABS
C407 HANGUL SYLLABLE SSWAS
C408 HANGUL SYLLABLE SSWASS
C409 HANGUL SYLLABLE SSWANG
C40A HANGUL SYLLABLE SSWAJ
C40B HANGUL SYLLABLE SSWAC
C40C HANGUL SYLLABLE SSWAK
C40D HANGUL SYLLABLE SSWAT
C40E HANGUL SYLLABLE SSWAP
C40F HANGUL SYLLABLE SSWAH
C410 HANGUL SYLLABLE SSWAE
C411 HANGUL SYLLABLE SSWAEG
C412 HANGUL SYLLABLE SSWAEGG
C413 HANGUL SYLLABLE SSWAEGS
C414 HANGUL SYLLABLE SSWAEN
C415 HANGUL SYLLABLE SSWAENJ
C416 HANGUL SYLLABLE SSWAENH
C417 HANGUL SYLLABLE SSWAED
C418 HANGUL SYLLABLE SSWAEL
C419 HANGUL SYLLABLE SSWAELG
C41A HANGUL SYLLABLE SSWAELM
C41B HANGUL SYLLABLE SSWAELB
C41C HANGUL SYLLABLE SSWAELS
C41D HANGUL SYLLABLE SSWAELT
C41E HANGUL SYLLABLE SSWAELP
C41F HANGUL SYLLABLE SSWAELH
C420 HANGUL SYLLABLE SSWAEM
C421 HANGUL SYLLABLE SSWAEB
C422 HANGUL SYLLABLE SSWAEBS
C423 HANGUL SYLLABLE SSWAES
C424 HANGUL SYLLABLE SSWAESS
C425 HANGUL SYLLABLE SSWAENG
C426 HANGUL SYLLABLE SSWAEJ
C427 HANGUL SYLLABLE SSWAEC
C428 HANGUL SYLLABLE SSWAEK
C429 HANGUL SYLLABLE SSWAET
C42A HANGUL SYLLABLE SSWAEP
C42B HANGUL SYLLABLE SSWAEH
C42C HANGUL SYLLABLE SSOE
C42D HANGUL SYLLABLE SSOEG
C42E HANGUL SYLLABLE SSOEGG
C42F HANGUL SYLLABLE SSOEGS
C430 HANGUL SYLLABLE SSOEN
C431 HANGUL SYLLABLE SSOENJ
C432 HANGUL SYLLABLE SSOENH
C433 HANGUL SYLLABLE SSOED
C434 HANGUL SYLLABLE SSOEL
C435 HANGUL SYLLABLE SSOELG
C436 HANGUL SYLLABLE SSOELM
C437 HANGUL SYLLABLE SSOELB
C438 HANGUL SYLLABLE SSOELS
C439 HANGUL SYLLABLE SSOELT
C43A HANGUL SYLLABLE SSOELP
C43B HANGUL SYLLABLE SSOELH
C43C HANGUL SYLLABLE SSOEM
C43D HANGUL SYLLABLE SSOEB
C43E HANGUL SYLLABLE SSOEBS
C43F HANGUL SYLLABLE SSOES
C440 HANGUL SYLLABLE SSOESS
C441 HANGUL SYLLABLE SSOENG
C442 HANGUL SYLLABLE SSOEJ
C443 HANGUL SYLLABLE SSOEC
C444 HANGUL SYLLABLE SSOEK
C445 HANGUL SYLLABLE SSOET
C446 HANGUL SYLLABLE SSOEP
C447 HANGUL SYLLABLE SSOEH
C448 HANGUL SYLLABLE SSYO
C449 HANGUL SYLLABLE SSYOG
C44A HANGUL SYLLABLE SSYOGG
C44B HANGUL SYLLABLE SSYOGS
C44C HANGUL SYLLABLE SSYON
C44D HANGUL SYLLABLE SSYONJ
C44E HANGUL SYLLABLE SSYONH
C44F HANGUL SYLLABLE SSYOD
C450 HANGUL SYLLABLE SSYOL
C451 HANGUL SYLLABLE SSYOLG
C452 HANGUL SYLLABLE SSYOLM
C453 HANGUL SYLLABLE SSYOLB
C454 HANGUL SYLLABLE SSYOLS
C455 HANGUL SYLLABLE SSYOLT
C456 HANGUL SYLLABLE SSYOLP
C457 HANGUL SYLLABLE SSYOLH
C458 HANGUL SYLLABLE SSYOM
C459 HANGUL SYLLABLE SSYOB
C45A HANGUL SYLLABLE SSYOBS
C45B HANGUL SYLLABLE SSYOS
C45C HANGUL SYLLABLE SSYOSS
C45D HANGUL SYLLABLE SSYONG
C45E HANGUL SYLLABLE SSYOJ
C45F HANGUL SYLLABLE SSYOC
C460 HANGUL SYLLABLE SSYOK
C461 HANGUL SYLLABLE SSYOT
C462 HANGUL SYLLABLE SSYOP
C463 HANGUL SYLLABLE SSYOH
C464 HANGUL SYLLABLE SSU
C465 HANGUL SYLLABLE SSUG
C466 HANGUL SYLLABLE SSUGG
C467 HANGUL SYLLABLE SSUGS
C468 HANGUL SYLLABLE SSUN
C469 HANGUL SYLLABLE SSUNJ
C46A HANGUL SYLLABLE SSUNH
C46B HANGUL SYLLABLE SSUD
C46C HANGUL SYLLABLE SSUL
C46D HANGUL SYLLABLE SSULG
C46E HANGUL SYLLABLE SSULM
C46F HANGUL SYLLABLE SSULB
C470 HANGUL SYLLABLE SSULS
C471 HANGUL SYLLABLE SSULT
C472 HANGUL SYLLABLE SSULP
C473 HANGUL SYLLABLE SSULH
C474 HANGUL SYLLABLE SSUM
C475 HANGUL SYLLABLE SSUB
C476 HANGUL SYLLABLE SSUBS
C477 HANGUL SYLLABLE SSUS
C478 HANGUL SYLLABLE SSUSS
C479 HANGUL SYLLABLE SSUNG
C47A HANGUL SYLLABLE SSUJ
C47B HANGUL SYLLABLE SSUC
C47C HANGUL SYLLABLE SSUK
C47D HANGUL SYLLABLE SSUT
C47E HANGUL SYLLABLE SSUP
C47F HANGUL SYLLABLE SSUH
C480 HANGUL SYLLABLE SSWEO
C481 HANGUL SYLLABLE SSWEOG
C482 HANGUL SYLLABLE SSWEOGG
C483 HANGUL SYLLABLE SSWEOGS
C484 HANGUL SYLLABLE SSWEON
C485 HANGUL SYLLABLE SSWEONJ
C486 HANGUL SYLLABLE SSWEONH
C487 HANGUL SYLLABLE SSWEOD
C488 HANGUL SYLLABLE SSWEOL
C489 HANGUL SYLLABLE SSWEOLG
C48A HANGUL SYLLABLE SSWEOLM
C48B HANGUL SYLLABLE SSWEOLB
C48C HANGUL SYLLABLE SSWEOLS
C48D HANGUL SYLLABLE SSWEOLT
C48E HANGUL SYLLABLE SSWEOLP
C48F HANGUL SYLLABLE SSWEOLH
C490 HANGUL SYLLABLE SSWEOM
C491 HANGUL SYLLABLE SSWEOB
C492 HANGUL SYLLABLE SSWEOBS
C493 HANGUL SYLLABLE SSWEOS
C494 HANGUL SYLLABLE SSWEOSS
C495 HANGUL SYLLABLE SSWEONG
C496 HANGUL SYLLABLE SSWEOJ
C497 HANGUL SYLLABLE SSWEOC
C498 HANGUL SYLLABLE SSWEOK
C499 HANGUL SYLLABLE SSWEOT
C49A HANGUL SYLLABLE SSWEOP
C49B HANGUL SYLLABLE SSWEOH
C49C HANGUL SYLLABLE SSWE
C49D HANGUL SYLLABLE SSWEG
C49E HANGUL SYLLABLE SSWEGG
C49F HANGUL SYLLABLE SSWEGS
C4A0 HANGUL SYLLABLE SSWEN
C4A1 HANGUL SYLLABLE SSWENJ
C4A2 HANGUL SYLLABLE SSWENH
C4A3 HANGUL SYLLABLE SSWED
C4A4 HANGUL SYLLABLE SSWEL
C4A5 HANGUL SYLLABLE SSWELG
C4A6 HANGUL SYLLABLE SSWELM
C4A7 HANGUL SYLLABLE SSWELB
C4A8 HANGUL SYLLABLE SSWELS
C4A9 HANGUL SYLLABLE SSWELT
C4AA HANGUL SYLLABLE SSWELP
C4AB HANGUL SYLLABLE SSWELH
C4AC HANGUL SYLLABLE SSWEM
C4AD HANGUL SYLLABLE SSWEB
C4AE HANGUL SYLLABLE SSWEBS
C4AF HANGUL SYLLABLE SSWES
C4B0 HANGUL SYLLABLE SSWESS
C4B1 HANGUL SYLLABLE SSWENG
C4B2 HANGUL SYLLABLE SSWEJ
C4B3 HANGUL SYLLABLE SSWEC
C4B4 HANGUL SYLLABLE SSWEK
C4B5 HANGUL SYLLABLE SSWET
C4B6 HANGUL SYLLABLE SSWEP
C4B7 HANGUL SYLLABLE SSWEH
C4B8 HANGUL SYLLABLE SSWI
C4B9 HANGUL SYLLABLE SSWIG
C4BA HANGUL SYLLABLE SSWIGG
C4BB HANGUL SYLLABLE SSWIGS
C4BC HANGUL SYLLABLE SSWIN
C4BD HANGUL SYLLABLE SSWINJ
C4BE HANGUL SYLLABLE SSWINH
C4BF HANGUL SYLLABLE SSWID
C4C0 HANGUL SYLLABLE SSWIL
C4C1 HANGUL SYLLABLE SSWILG
C4C2 HANGUL SYLLABLE SSWILM
C4C3 HANGUL SYLLABLE SSWILB
C4C4 HANGUL SYLLABLE SSWILS
C4C5 HANGUL SYLLABLE SSWILT
C4C6 HANGUL SYLLABLE SSWILP
C4C7 HANGUL SYLLABLE SSWILH
C4C8 HANGUL SYLLABLE SSWIM
C4C9 HANGUL SYLLABLE SSWIB
C4CA HANGUL SYLLABLE SSWIBS
C4CB HANGUL SYLLABLE SSWIS
C4CC HANGUL SYLLABLE SSWISS
C4CD HANGUL SYLLABLE SSWING
C4CE HANGUL SYLLABLE SSWIJ
C4CF HANGUL SYLLABLE SSWIC
C4D0 HANGUL SYLLABLE SSWIK
C4D1 HANGUL SYLLABLE SSWIT
C4D2 HANGUL SYLLABLE SSWIP
C4D3 HANGUL SYLLABLE SSWIH
C4D4 HANGUL SYLLABLE SSYU
C4D5 HANGUL SYLLABLE SSYUG
C4D6 HANGUL SYLLABLE SSYUGG
C4D7 HANGUL SYLLABLE SSYUGS
C4D8 HANGUL SYLLABLE SSYUN
C4D9 HANGUL SYLLABLE SSYUNJ
C4DA HANGUL SYLLABLE SSYUNH
C4DB HANGUL SYLLABLE SSYUD
C4DC HANGUL SYLLABLE SSYUL
C4DD HANGUL SYLLABLE SSYULG
C4DE HANGUL SYLLABLE SSYULM
C4DF HANGUL SYLLABLE SSYULB
C4E0 HANGUL SYLLABLE SSYULS
C4E1 HANGUL SYLLABLE SSYULT
C4E2 HANGUL SYLLABLE SSYULP
C4E3 HANGUL SYLLABLE SSYULH
C4E4 HANGUL SYLLABLE SSYUM
C4E5 HANGUL SYLLABLE SSYUB
C4E6 HANGUL SYLLABLE SSYUBS
C4E7 HANGUL SYLLABLE SSYUS
C4E8 HANGUL SYLLABLE SSYUSS
C4E9 HANGUL SYLLABLE SSYUNG
C4EA HANGUL SYLLABLE SSYUJ
C4EB HANGUL SYLLABLE SSYUC
C4EC HANGUL SYLLABLE SSYUK
C4ED HANGUL SYLLABLE SSYUT
C4EE HANGUL SYLLABLE SSYUP
C4EF HANGUL SYLLABLE SSYUH
C4F0 HANGUL SYLLABLE SSEU
C4F1 HANGUL SYLLABLE SSEUG
C4F2 HANGUL SYLLABLE SSEUGG
C4F3 HANGUL SYLLABLE SSEUGS
C4F4 HANGUL SYLLABLE SSEUN
C4F5 HANGUL SYLLABLE SSEUNJ
C4F6 HANGUL SYLLABLE SSEUNH
C4F7 HANGUL SYLLABLE SSEUD
C4F8 HANGUL SYLLABLE SSEUL
C4F9 HANGUL SYLLABLE SSEULG
C4FA HANGUL SYLLABLE SSEULM
C4FB HANGUL SYLLABLE SSEULB
C4FC HANGUL SYLLABLE SSEULS
C4FD HANGUL SYLLABLE SSEULT
C4FE HANGUL SYLLABLE SSEULP
C4FF HANGUL SYLLABLE SSEULH
C500 HANGUL SYLLABLE SSEUM
C501 HANGUL SYLLABLE SSEUB
C502 HANGUL SYLLABLE SSEUBS
C503 HANGUL SYLLABLE SSEUS
C504 HANGUL SYLLABLE SSEUSS
C505 HANGUL SYLLABLE SSEUNG
C506 HANGUL SYLLABLE SSEUJ
C507 HANGUL SYLLABLE SSEUC
C508 HANGUL SYLLABLE SSEUK
C509 HANGUL SYLLABLE SSEUT
C50A HANGUL SYLLABLE SSEUP
C50B HANGUL SYLLABLE SSEUH
C50C HANGUL SYLLABLE SSYI
C50D HANGUL SYLLABLE SSYIG
C50E HANGUL SYLLABLE SSYIGG
C50F HANGUL SYLLABLE SSYIGS
C510 HANGUL SYLLABLE SSYIN
C511 HANGUL SYLLABLE SSYINJ
C512 HANGUL SYLLABLE SSYINH
C513 HANGUL SYLLABLE SSYID
C514 HANGUL SYLLABLE SSYIL
C515 HANGUL SYLLABLE SSYILG
C516 HANGUL SYLLABLE SSYILM
C517 HANGUL SYLLABLE SSYILB
C518 HANGUL SYLLABLE SSYILS
C519 HANGUL SYLLABLE SSYILT
C51A HANGUL SYLLABLE SSYILP
C51B HANGUL SYLLABLE SSYILH
C51C HANGUL SYLLABLE SSYIM
C51D HANGUL SYLLABLE SSYIB
C51E HANGUL SYLLABLE SSYIBS
C51F HANGUL SYLLABLE SSYIS
C520 HANGUL SYLLABLE SSYISS
C521 HANGUL SYLLABLE SSYING
C522 HANGUL SYLLABLE SSYIJ
C523 HANGUL SYLLABLE SSYIC
C524 HANGUL SYLLABLE SSYIK
C525 HANGUL SYLLABLE SSYIT
C526 HANGUL SYLLABLE SSYIP
C527 HANGUL SYLLABLE SSYIH
C528 HANGUL SYLLABLE SSI
C529 HANGUL SYLLABLE SSIG
C52A HANGUL SYLLABLE SSIGG
C52B HANGUL SYLLABLE SSIGS
C52C HANGUL SYLLABLE SSIN
C52D HANGUL SYLLABLE SSINJ
C52E HANGUL SYLLABLE SSINH
C52F HANGUL SYLLABLE SSID
C530 HANGUL SYLLABLE SSIL
C531 HANGUL SYLLABLE SSILG
C532 HANGUL SYLLABLE SSILM
C533 HANGUL SYLLABLE SSILB
C534 HANGUL SYLLABLE SSILS
C535 HANGUL SYLLABLE SSILT
C536 HANGUL SYLLABLE SSILP
C537 HANGUL SYLLABLE SSILH
C538 HANGUL SYLLABLE SSIM
C539 HANGUL SYLLABLE SSIB
C53A HANGUL SYLLABLE SSIBS
C53B HANGUL SYLLABLE SSIS
C53C HANGUL SYLLABLE SSISS
C53D HANGUL SYLLABLE SSING
C53E HANGUL SYLLABLE SSIJ
C53F HANGUL SYLLABLE SSIC
C540 HANGUL SYLLABLE SSIK
C541 HANGUL SYLLABLE SSIT
C542 HANGUL SYLLABLE SSIP
C543 HANGUL SYLLABLE SSIH
C544 HANGUL SYLLABLE A
C545 HANGUL SYLLABLE AG
C546 HANGUL SYLLABLE AGG
C547 HANGUL SYLLABLE AGS
C548 HANGUL SYLLABLE AN
C549 HANGUL SYLLABLE ANJ
C54A HANGUL SYLLABLE ANH
C54B HANGUL SYLLABLE AD
C54C HANGUL SYLLABLE AL
C54D HANGUL SYLLABLE ALG
C54E HANGUL SYLLABLE ALM
C54F HANGUL SYLLABLE ALB
C550 HANGUL SYLLABLE ALS
C551 HANGUL SYLLABLE ALT
C552 HANGUL SYLLABLE ALP
C553 HANGUL SYLLABLE ALH
C554 HANGUL SYLLABLE AM
C555 HANGUL SYLLABLE AB
C556 HANGUL SYLLABLE ABS
C557 HANGUL SYLLABLE AS
C558 HANGUL SYLLABLE ASS
C559 HANGUL SYLLABLE ANG
C55A HANGUL SYLLABLE AJ
C55B HANGUL SYLLABLE AC
C55C HANGUL SYLLABLE AK
C55D HANGUL SYLLABLE AT
C55E HANGUL SYLLABLE AP
C55F HANGUL SYLLABLE AH
C560 HANGUL SYLLABLE AE
C561 HANGUL SYLLABLE AEG
C562 HANGUL SYLLABLE AEGG
C563 HANGUL SYLLABLE AEGS
C564 HANGUL SYLLABLE AEN
C565 HANGUL SYLLABLE AENJ
C566 HANGUL SYLLABLE AENH
C567 HANGUL SYLLABLE AED
C568 HANGUL SYLLABLE AEL
C569 HANGUL SYLLABLE AELG
C56A HANGUL SYLLABLE AELM
C56B HANGUL SYLLABLE AELB
C56C HANGUL SYLLABLE AELS
C56D HANGUL SYLLABLE AELT
C56E HANGUL SYLLABLE AELP
C56F HANGUL SYLLABLE AELH
C570 HANGUL SYLLABLE AEM
C571 HANGUL SYLLABLE AEB
C572 HANGUL SYLLABLE AEBS
C573 HANGUL SYLLABLE AES
C574 HANGUL SYLLABLE AESS
C575 HANGUL SYLLABLE AENG
C576 HANGUL SYLLABLE AEJ
C577 HANGUL SYLLABLE AEC
C578 HANGUL SYLLABLE AEK
C579 HANGUL SYLLABLE AET
C57A HANGUL SYLLABLE AEP
C57B HANGUL SYLLABLE AEH
C57C HANGUL SYLLABLE YA
C57D HANGUL SYLLABLE YAG
C57E HANGUL SYLLABLE YAGG
C57F HANGUL SYLLABLE YAGS
C580 HANGUL SYLLABLE YAN
C581 HANGUL SYLLABLE YANJ
C582 HANGUL SYLLABLE YANH
C583 HANGUL SYLLABLE YAD
C584 HANGUL SYLLABLE YAL
C585 HANGUL SYLLABLE YALG
C586 HANGUL SYLLABLE YALM
C587 HANGUL SYLLABLE YALB
C588 HANGUL SYLLABLE YALS
C589 HANGUL SYLLABLE YALT
C58A HANGUL SYLLABLE YALP
C58B HANGUL SYLLABLE YALH
C58C HANGUL SYLLABLE YAM
C58D HANGUL SYLLABLE YAB
C58E HANGUL SYLLABLE YABS
C58F HANGUL SYLLABLE YAS
C590 HANGUL SYLLABLE YASS
C591 HANGUL SYLLABLE YANG
C592 HANGUL SYLLABLE YAJ
C593 HANGUL SYLLABLE YAC
C594 HANGUL SYLLABLE YAK
C595 HANGUL SYLLABLE YAT
C596 HANGUL SYLLABLE YAP
C597 HANGUL SYLLABLE YAH
C598 HANGUL SYLLABLE YAE
C599 HANGUL SYLLABLE YAEG
C59A HANGUL SYLLABLE YAEGG
C59B HANGUL SYLLABLE YAEGS
C59C HANGUL SYLLABLE YAEN
C59D HANGUL SYLLABLE YAENJ
C59E HANGUL SYLLABLE YAENH
C59F HANGUL SYLLABLE YAED
C5A0 HANGUL SYLLABLE YAEL
C5A1 HANGUL SYLLABLE YAELG
C5A2 HANGUL SYLLABLE YAELM
C5A3 HANGUL SYLLABLE YAELB
C5A4 HANGUL SYLLABLE YAELS
C5A5 HANGUL SYLLABLE YAELT
C5A6 HANGUL SYLLABLE YAELP
C5A7 HANGUL SYLLABLE YAELH
C5A8 HANGUL SYLLABLE YAEM
C5A9 HANGUL SYLLABLE YAEB
C5AA HANGUL SYLLABLE YAEBS
C5AB HANGUL SYLLABLE YAES
C5AC HANGUL SYLLABLE YAESS
C5AD HANGUL SYLLABLE YAENG
C5AE HANGUL SYLLABLE YAEJ
C5AF HANGUL SYLLABLE YAEC
C5B0 HANGUL SYLLABLE YAEK
C5B1 HANGUL SYLLABLE YAET
C5B2 HANGUL SYLLABLE YAEP
C5B3 HANGUL SYLLABLE YAEH
C5B4 HANGUL SYLLABLE EO
C5B5 HANGUL SYLLABLE EOG
C5B6 HANGUL SYLLABLE EOGG
C5B7 HANGUL SYLLABLE EOGS
C5B8 HANGUL SYLLABLE EON
C5B9 HANGUL SYLLABLE EONJ
C5BA HANGUL SYLLABLE EONH
C5BB HANGUL SYLLABLE EOD
C5BC HANGUL SYLLABLE EOL
C5BD HANGUL SYLLABLE EOLG
C5BE HANGUL SYLLABLE EOLM
C5BF HANGUL SYLLABLE EOLB
C5C0 HANGUL SYLLABLE EOLS
C5C1 HANGUL SYLLABLE EOLT
C5C2 HANGUL SYLLABLE EOLP
C5C3 HANGUL SYLLABLE EOLH
C5C4 HANGUL SYLLABLE EOM
C5C5 HANGUL SYLLABLE EOB
C5C6 HANGUL SYLLABLE EOBS
C5C7 HANGUL SYLLABLE EOS
C5C8 HANGUL SYLLABLE EOSS
C5C9 HANGUL SYLLABLE EONG
C5CA HANGUL SYLLABLE EOJ
C5CB HANGUL SYLLABLE EOC
C5CC HANGUL SYLLABLE EOK
C5CD HANGUL SYLLABLE EOT
C5CE HANGUL SYLLABLE EOP
C5CF HANGUL SYLLABLE EOH
C5D0 HANGUL SYLLABLE E
C5D1 HANGUL SYLLABLE EG
C5D2 HANGUL SYLLABLE EGG
C5D3 HANGUL SYLLABLE EGS
C5D4 HANGUL SYLLABLE EN
C5D5 HANGUL SYLLABLE ENJ
C5D6 HANGUL SYLLABLE ENH
C5D7 HANGUL SYLLABLE ED
C5D8 HANGUL SYLLABLE EL
C5D9 HANGUL SYLLABLE ELG
C5DA HANGUL SYLLABLE ELM
C5DB HANGUL SYLLABLE ELB
C5DC HANGUL SYLLABLE ELS
C5DD HANGUL SYLLABLE ELT
C5DE HANGUL SYLLABLE ELP
C5DF HANGUL SYLLABLE ELH
C5E0 HANGUL SYLLABLE EM
C5E1 HANGUL SYLLABLE EB
C5E2 HANGUL SYLLABLE EBS
C5E3 HANGUL SYLLABLE ES
C5E4 HANGUL SYLLABLE ESS
C5E5 HANGUL SYLLABLE ENG
C5E6 HANGUL SYLLABLE EJ
C5E7 HANGUL SYLLABLE EC
C5E8 HANGUL SYLLABLE EK
C5E9 HANGUL SYLLABLE ET
C5EA HANGUL SYLLABLE EP
C5EB HANGUL SYLLABLE EH
C5EC HANGUL SYLLABLE YEO
C5ED HANGUL SYLLABLE YEOG
C5EE HANGUL SYLLABLE YEOGG
C5EF HANGUL SYLLABLE YEOGS
C5F0 HANGUL SYLLABLE YEON
C5F1 HANGUL SYLLABLE YEONJ
C5F2 HANGUL SYLLABLE YEONH
C5F3 HANGUL SYLLABLE YEOD
C5F4 HANGUL SYLLABLE YEOL
C5F5 HANGUL SYLLABLE YEOLG
C5F6 HANGUL SYLLABLE YEOLM
C5F7 HANGUL SYLLABLE YEOLB
C5F8 HANGUL SYLLABLE YEOLS
C5F9 HANGUL SYLLABLE YEOLT
C5FA HANGUL SYLLABLE YEOLP
C5FB HANGUL SYLLABLE YEOLH
C5FC HANGUL SYLLABLE YEOM
C5FD HANGUL SYLLABLE YEOB
C5FE HANGUL SYLLABLE YEOBS
C5FF HANGUL SYLLABLE YEOS
C600 HANGUL SYLLABLE YEOSS
C601 HANGUL SYLLABLE YEONG
C602 HANGUL SYLLABLE YEOJ
C603 HANGUL SYLLABLE YEOC
C604 HANGUL SYLLABLE YEOK
C605 HANGUL SYLLABLE YEOT
C606 HANGUL SYLLABLE YEOP
C607 HANGUL SYLLABLE YEOH
C608 HANGUL SYLLABLE YE
C609 HANGUL SYLLABLE YEG
C60A HANGUL SYLLABLE YEGG
C60B HANGUL SYLLABLE YEGS
C60C HANGUL SYLLABLE YEN
C60D HANGUL SYLLABLE YENJ
C60E HANGUL SYLLABLE YENH
C60F HANGUL SYLLABLE YED
C610 HANGUL SYLLABLE YEL
C611 HANGUL SYLLABLE YELG
C612 HANGUL SYLLABLE YELM
C613 HANGUL SYLLABLE YELB
C614 HANGUL SYLLABLE YELS
C615 HANGUL SYLLABLE YELT
C616 HANGUL SYLLABLE YELP
C617 HANGUL SYLLABLE YELH
C618 HANGUL SYLLABLE YEM
C619 HANGUL SYLLABLE YEB
C61A HANGUL SYLLABLE YEBS
C61B HANGUL SYLLABLE YES
C61C HANGUL SYLLABLE YESS
C61D HANGUL SYLLABLE YENG
C61E HANGUL SYLLABLE YEJ
C61F HANGUL SYLLABLE YEC
C620 HANGUL SYLLABLE YEK
C621 HANGUL SYLLABLE YET
C622 HANGUL SYLLABLE YEP
C623 HANGUL SYLLABLE YEH
C624 HANGUL SYLLABLE O
C625 HANGUL SYLLABLE OG
C626 HANGUL SYLLABLE OGG
C627 HANGUL SYLLABLE OGS
C628 HANGUL SYLLABLE ON
C629 HANGUL SYLLABLE ONJ
C62A HANGUL SYLLABLE ONH
C62B HANGUL SYLLABLE OD
C62C HANGUL SYLLABLE OL
C62D HANGUL SYLLABLE OLG
C62E HANGUL SYLLABLE OLM
C62F HANGUL SYLLABLE OLB
C630 HANGUL SYLLABLE OLS
C631 HANGUL SYLLABLE OLT
C632 HANGUL SYLLABLE OLP
C633 HANGUL SYLLABLE OLH
C634 HANGUL SYLLABLE OM
C635 HANGUL SYLLABLE OB
C636 HANGUL SYLLABLE OBS
C637 HANGUL SYLLABLE OS
C638 HANGUL SYLLABLE OSS
C639 HANGUL SYLLABLE ONG
C63A HANGUL SYLLABLE OJ
C63B HANGUL SYLLABLE OC
C63C HANGUL SYLLABLE OK
C63D HANGUL SYLLABLE OT
C63E HANGUL SYLLABLE OP
C63F HANGUL SYLLABLE OH
C640 HANGUL SYLLABLE WA
C641 HANGUL SYLLABLE WAG
C642 HANGUL SYLLABLE WAGG
C643 HANGUL SYLLABLE WAGS
C644 HANGUL SYLLABLE WAN
C645 HANGUL SYLLABLE WANJ
C646 HANGUL SYLLABLE WANH
C647 HANGUL SYLLABLE WAD
C648 HANGUL SYLLABLE WAL
C649 HANGUL SYLLABLE WALG
C64A HANGUL SYLLABLE WALM
C64B HANGUL SYLLABLE WALB
C64C HANGUL SYLLABLE WALS
C64D HANGUL SYLLABLE WALT
C64E HANGUL SYLLABLE WALP
C64F HANGUL SYLLABLE WALH
C650 HANGUL SYLLABLE WAM
C651 HANGUL SYLLABLE WAB
C652 HANGUL SYLLABLE WABS
C653 HANGUL SYLLABLE WAS
C654 HANGUL SYLLABLE WASS
C655 HANGUL SYLLABLE WANG
C656 HANGUL SYLLABLE WAJ
C657 HANGUL SYLLABLE WAC
C658 HANGUL SYLLABLE WAK
C659 HANGUL SYLLABLE WAT
C65A HANGUL SYLLABLE WAP
C65B HANGUL SYLLABLE WAH
C65C HANGUL SYLLABLE WAE
C65D HANGUL SYLLABLE WAEG
C65E HANGUL SYLLABLE WAEGG
C65F HANGUL SYLLABLE WAEGS
C660 HANGUL SYLLABLE WAEN
C661 HANGUL SYLLABLE WAENJ
C662 HANGUL SYLLABLE WAENH
C663 HANGUL SYLLABLE WAED
C664 HANGUL SYLLABLE WAEL
C665 HANGUL SYLLABLE WAELG
C666 HANGUL SYLLABLE WAELM
C667 HANGUL SYLLABLE WAELB
C668 HANGUL SYLLABLE WAELS
C669 HANGUL SYLLABLE WAELT
C66A HANGUL SYLLABLE WAELP
C66B HANGUL SYLLABLE WAELH
C66C HANGUL SYLLABLE WAEM
C66D HANGUL SYLLABLE WAEB
C66E HANGUL SYLLABLE WAEBS
C66F HANGUL SYLLABLE WAES
C670 HANGUL SYLLABLE WAESS
C671 HANGUL SYLLABLE WAENG
C672 HANGUL SYLLABLE WAEJ
C673 HANGUL SYLLABLE WAEC
C674 HANGUL SYLLABLE WAEK
C675 HANGUL SYLLABLE WAET
C676 HANGUL SYLLABLE WAEP
C677 HANGUL SYLLABLE WAEH
C678 HANGUL SYLLABLE OE
C679 HANGUL SYLLABLE OEG
C67A HANGUL SYLLABLE OEGG
C67B HANGUL SYLLABLE OEGS
C67C HANGUL SYLLABLE OEN
C67D HANGUL SYLLABLE OENJ
C67E HANGUL SYLLABLE OENH
C67F HANGUL SYLLABLE OED
C680 HANGUL SYLLABLE OEL
C681 HANGUL SYLLABLE OELG
C682 HANGUL SYLLABLE OELM
C683 HANGUL SYLLABLE OELB
C684 HANGUL SYLLABLE OELS
C685 HANGUL SYLLABLE OELT
C686 HANGUL SYLLABLE OELP
C687 HANGUL SYLLABLE OELH
C688 HANGUL SYLLABLE OEM
C689 HANGUL SYLLABLE OEB
C68A HANGUL SYLLABLE OEBS
C68B HANGUL SYLLABLE OES
C68C HANGUL SYLLABLE OESS
C68D HANGUL SYLLABLE OENG
C68E HANGUL SYLLABLE OEJ
C68F HANGUL SYLLABLE OEC
C690 HANGUL SYLLABLE OEK
C691 HANGUL SYLLABLE OET
C692 HANGUL SYLLABLE OEP
C693 HANGUL SYLLABLE OEH
C694 HANGUL SYLLABLE YO
C695 HANGUL SYLLABLE YOG
C696 HANGUL SYLLABLE YOGG
C697 HANGUL SYLLABLE YOGS
C698 HANGUL SYLLABLE YON
C699 HANGUL SYLLABLE YONJ
C69A HANGUL SYLLABLE YONH
C69B HANGUL SYLLABLE YOD
C69C HANGUL SYLLABLE YOL
C69D HANGUL SYLLABLE YOLG
C69E HANGUL SYLLABLE YOLM
C69F HANGUL SYLLABLE YOLB
C6A0 HANGUL SYLLABLE YOLS
C6A1 HANGUL SYLLABLE YOLT
C6A2 HANGUL SYLLABLE YOLP
C6A3 HANGUL SYLLABLE YOLH
C6A4 HANGUL SYLLABLE YOM
C6A5 HANGUL SYLLABLE YOB
C6A6 HANGUL SYLLABLE YOBS
C6A7 HANGUL SYLLABLE YOS
C6A8 HANGUL SYLLABLE YOSS
C6A9 HANGUL SYLLABLE YONG
C6AA HANGUL SYLLABLE YOJ
C6AB HANGUL SYLLABLE YOC
C6AC HANGUL SYLLABLE YOK
C6AD HANGUL SYLLABLE YOT
C6AE HANGUL SYLLABLE YOP
C6AF HANGUL SYLLABLE YOH
C6B0 HANGUL SYLLABLE U
C6B1 HANGUL SYLLABLE UG
C6B2 HANGUL SYLLABLE UGG
C6B3 HANGUL SYLLABLE UGS
C6B4 HANGUL SYLLABLE UN
C6B5 HANGUL SYLLABLE UNJ
C6B6 HANGUL SYLLABLE UNH
C6B7 HANGUL SYLLABLE UD
C6B8 HANGUL SYLLABLE UL
C6B9 HANGUL SYLLABLE ULG
C6BA HANGUL SYLLABLE ULM
C6BB HANGUL SYLLABLE ULB
C6BC HANGUL SYLLABLE ULS
C6BD HANGUL SYLLABLE ULT
C6BE HANGUL SYLLABLE ULP
C6BF HANGUL SYLLABLE ULH
C6C0 HANGUL SYLLABLE UM
C6C1 HANGUL SYLLABLE UB
C6C2 HANGUL SYLLABLE UBS
C6C3 HANGUL SYLLABLE US
C6C4 HANGUL SYLLABLE USS
C6C5 HANGUL SYLLABLE UNG
C6C6 HANGUL SYLLABLE UJ
C6C7 HANGUL SYLLABLE UC
C6C8 HANGUL SYLLABLE UK
C6C9 HANGUL SYLLABLE UT
C6CA HANGUL SYLLABLE UP
C6CB HANGUL SYLLABLE UH
C6CC HANGUL SYLLABLE WEO
C6CD HANGUL SYLLABLE WEOG
C6CE HANGUL SYLLABLE WEOGG
C6CF HANGUL SYLLABLE WEOGS
C6D0 HANGUL SYLLABLE WEON
C6D1 HANGUL SYLLABLE WEONJ
C6D2 HANGUL SYLLABLE WEONH
C6D3 HANGUL SYLLABLE WEOD
C6D4 HANGUL SYLLABLE WEOL
C6D5 HANGUL SYLLABLE WEOLG
C6D6 HANGUL SYLLABLE WEOLM
C6D7 HANGUL SYLLABLE WEOLB
C6D8 HANGUL SYLLABLE WEOLS
C6D9 HANGUL SYLLABLE WEOLT
C6DA HANGUL SYLLABLE WEOLP
C6DB HANGUL SYLLABLE WEOLH
C6DC HANGUL SYLLABLE WEOM
C6DD HANGUL SYLLABLE WEOB
C6DE HANGUL SYLLABLE WEOBS
C6DF HANGUL SYLLABLE WEOS
C6E0 HANGUL SYLLABLE WEOSS
C6E1 HANGUL SYLLABLE WEONG
C6E2 HANGUL SYLLABLE WEOJ
C6E3 HANGUL SYLLABLE WEOC
C6E4 HANGUL SYLLABLE WEOK
C6E5 HANGUL SYLLABLE WEOT
C6E6 HANGUL SYLLABLE WEOP
C6E7 HANGUL SYLLABLE WEOH
C6E8 HANGUL SYLLABLE WE
C6E9 HANGUL SYLLABLE WEG
C6EA HANGUL SYLLABLE WEGG
C6EB HANGUL SYLLABLE WEGS
C6EC HANGUL SYLLABLE WEN
C6ED HANGUL SYLLABLE WENJ
C6EE HANGUL SYLLABLE WENH
C6EF HANGUL SYLLABLE WED
C6F0 HANGUL SYLLABLE WEL
C6F1 HANGUL SYLLABLE WELG
C6F2 HANGUL SYLLABLE WELM
C6F3 HANGUL SYLLABLE WELB
C6F4 HANGUL SYLLABLE WELS
C6F5 HANGUL SYLLABLE WELT
C6F6 HANGUL SYLLABLE WELP
C6F7 HANGUL SYLLABLE WELH
C6F8 HANGUL SYLLABLE WEM
C6F9 HANGUL SYLLABLE WEB
C6FA HANGUL SYLLABLE WEBS
C6FB HANGUL SYLLABLE WES
C6FC HANGUL SYLLABLE WESS
C6FD HANGUL SYLLABLE WENG
C6FE HANGUL SYLLABLE WEJ
C6FF HANGUL SYLLABLE WEC
C700 HANGUL SYLLABLE WEK
C701 HANGUL SYLLABLE WET
C702 HANGUL SYLLABLE WEP
C703 HANGUL SYLLABLE WEH
C704 HANGUL SYLLABLE WI
C705 HANGUL SYLLABLE WIG
C706 HANGUL SYLLABLE WIGG
C707 HANGUL SYLLABLE WIGS
C708 HANGUL SYLLABLE WIN
C709 HANGUL SYLLABLE WINJ
C70A HANGUL SYLLABLE WINH
C70B HANGUL SYLLABLE WID
C70C HANGUL SYLLABLE WIL
C70D HANGUL SYLLABLE WILG
C70E HANGUL SYLLABLE WILM
C70F HANGUL SYLLABLE WILB
C710 HANGUL SYLLABLE WILS
C711 HANGUL SYLLABLE WILT
C712 HANGUL SYLLABLE WILP
C713 HANGUL SYLLABLE WILH
C714 HANGUL SYLLABLE WIM
C715 HANGUL SYLLABLE WIB
C716 HANGUL SYLLABLE WIBS
C717 HANGUL SYLLABLE WIS
C718 HANGUL SYLLABLE WISS
C719 HANGUL SYLLABLE WING
C71A HANGUL SYLLABLE WIJ
C71B HANGUL SYLLABLE WIC
C71C HANGUL SYLLABLE WIK
C71D HANGUL SYLLABLE WIT
C71E HANGUL SYLLABLE WIP
C71F HANGUL SYLLABLE WIH
C720 HANGUL SYLLABLE YU
C721 HANGUL SYLLABLE YUG
C722 HANGUL SYLLABLE YUGG
C723 HANGUL SYLLABLE YUGS
C724 HANGUL SYLLABLE YUN
C725 HANGUL SYLLABLE YUNJ
C726 HANGUL SYLLABLE YUNH
C727 HANGUL SYLLABLE YUD
C728 HANGUL SYLLABLE YUL
C729 HANGUL SYLLABLE YULG
C72A HANGUL SYLLABLE YULM
C72B HANGUL SYLLABLE YULB
C72C HANGUL SYLLABLE YULS
C72D HANGUL SYLLABLE YULT
C72E HANGUL SYLLABLE YULP
C72F HANGUL SYLLABLE YULH
C730 HANGUL SYLLABLE YUM
C731 HANGUL SYLLABLE YUB
C732 HANGUL SYLLABLE YUBS
C733 HANGUL SYLLABLE YUS
C734 HANGUL SYLLABLE YUSS
C735 HANGUL SYLLABLE YUNG
C736 HANGUL SYLLABLE YUJ
C737 HANGUL SYLLABLE YUC
C738 HANGUL SYLLABLE YUK
C739 HANGUL SYLLABLE YUT
C73A HANGUL SYLLABLE YUP
C73B HANGUL SYLLABLE YUH
C73C HANGUL SYLLABLE EU
C73D HANGUL SYLLABLE EUG
C73E HANGUL SYLLABLE EUGG
C73F HANGUL SYLLABLE EUGS
C740 HANGUL SYLLABLE EUN
C741 HANGUL SYLLABLE EUNJ
C742 HANGUL SYLLABLE EUNH
C743 HANGUL SYLLABLE EUD
C744 HANGUL SYLLABLE EUL
C745 HANGUL SYLLABLE EULG
C746 HANGUL SYLLABLE EULM
C747 HANGUL SYLLABLE EULB
C748 HANGUL SYLLABLE EULS
C749 HANGUL SYLLABLE EULT
C74A HANGUL SYLLABLE EULP
C74B HANGUL SYLLABLE EULH
C74C HANGUL SYLLABLE EUM
C74D HANGUL SYLLABLE EUB
C74E HANGUL SYLLABLE EUBS
C74F HANGUL SYLLABLE EUS
C750 HANGUL SYLLABLE EUSS
C751 HANGUL SYLLABLE EUNG
C752 HANGUL SYLLABLE EUJ
C753 HANGUL SYLLABLE EUC
C754 HANGUL SYLLABLE EUK
C755 HANGUL SYLLABLE EUT
C756 HANGUL SYLLABLE EUP
C757 HANGUL SYLLABLE EUH
C758 HANGUL SYLLABLE YI
C759 HANGUL SYLLABLE YIG
C75A HANGUL SYLLABLE YIGG
C75B HANGUL SYLLABLE YIGS
C75C HANGUL SYLLABLE YIN
C75D HANGUL SYLLABLE YINJ
C75E HANGUL SYLLABLE YINH
C75F HANGUL SYLLABLE YID
C760 HANGUL SYLLABLE YIL
C761 HANGUL SYLLABLE YILG
C762 HANGUL SYLLABLE YILM
C763 HANGUL SYLLABLE YILB
C764 HANGUL SYLLABLE YILS
C765 HANGUL SYLLABLE YILT
C766 HANGUL SYLLABLE YILP
C767 HANGUL SYLLABLE YILH
C768 HANGUL SYLLABLE YIM
C769 HANGUL SYLLABLE YIB
C76A HANGUL SYLLABLE YIBS
C76B HANGUL SYLLABLE YIS
C76C HANGUL SYLLABLE YISS
C76D HANGUL SYLLABLE YING
C76E HANGUL SYLLABLE YIJ
C76F HANGUL SYLLABLE YIC
C770 HANGUL SYLLABLE YIK
C771 HANGUL SYLLABLE YIT
C772 HANGUL SYLLABLE YIP
C773 HANGUL SYLLABLE YIH
C774 HANGUL SYLLABLE I
C775 HANGUL SYLLABLE IG
C776 HANGUL SYLLABLE IGG
C777 HANGUL SYLLABLE IGS
C778 HANGUL SYLLABLE IN
C779 HANGUL SYLLABLE INJ
C77A HANGUL SYLLABLE INH
C77B HANGUL SYLLABLE ID
C77C HANGUL SYLLABLE IL
C77D HANGUL SYLLABLE ILG
C77E HANGUL SYLLABLE ILM
C77F HANGUL SYLLABLE ILB
C780 HANGUL SYLLABLE ILS
C781 HANGUL SYLLABLE ILT
C782 HANGUL SYLLABLE ILP
C783 HANGUL SYLLABLE ILH
C784 HANGUL SYLLABLE IM
C785 HANGUL SYLLABLE IB
C786 HANGUL SYLLABLE IBS
C787 HANGUL SYLLABLE IS
C788 HANGUL SYLLABLE ISS
C789 HANGUL SYLLABLE ING
C78A HANGUL SYLLABLE IJ
C78B HANGUL SYLLABLE IC
C78C HANGUL SYLLABLE IK
C78D HANGUL SYLLABLE IT
C78E HANGUL SYLLABLE IP
C78F HANGUL SYLLABLE IH
C790 HANGUL SYLLABLE JA
C791 HANGUL SYLLABLE JAG
C792 HANGUL SYLLABLE JAGG
C793 HANGUL SYLLABLE JAGS
C794 HANGUL SYLLABLE JAN
C795 HANGUL SYLLABLE JANJ
C796 HANGUL SYLLABLE JANH
C797 HANGUL SYLLABLE JAD
C798 HANGUL SYLLABLE JAL
C799 HANGUL SYLLABLE JALG
C79A HANGUL SYLLABLE JALM
C79B HANGUL SYLLABLE JALB
C79C HANGUL SYLLABLE JALS
C79D HANGUL SYLLABLE JALT
C79E HANGUL SYLLABLE JALP
C79F HANGUL SYLLABLE JALH
C7A0 HANGUL SYLLABLE JAM
C7A1 HANGUL SYLLABLE JAB
C7A2 HANGUL SYLLABLE JABS
C7A3 HANGUL SYLLABLE JAS
C7A4 HANGUL SYLLABLE JASS
C7A5 HANGUL SYLLABLE JANG
C7A6 HANGUL SYLLABLE JAJ
C7A7 HANGUL SYLLABLE JAC
C7A8 HANGUL SYLLABLE JAK
C7A9 HANGUL SYLLABLE JAT
C7AA HANGUL SYLLABLE JAP
C7AB HANGUL SYLLABLE JAH
C7AC HANGUL SYLLABLE JAE
C7AD HANGUL SYLLABLE JAEG
C7AE HANGUL SYLLABLE JAEGG
C7AF HANGUL SYLLABLE JAEGS
C7B0 HANGUL SYLLABLE JAEN
C7B1 HANGUL SYLLABLE JAENJ
C7B2 HANGUL SYLLABLE JAENH
C7B3 HANGUL SYLLABLE JAED
C7B4 HANGUL SYLLABLE JAEL
C7B5 HANGUL SYLLABLE JAELG
C7B6 HANGUL SYLLABLE JAELM
C7B7 HANGUL SYLLABLE JAELB
C7B8 HANGUL SYLLABLE JAELS
C7B9 HANGUL SYLLABLE JAELT
C7BA HANGUL SYLLABLE JAELP
C7BB HANGUL SYLLABLE JAELH
C7BC HANGUL SYLLABLE JAEM
C7BD HANGUL SYLLABLE JAEB
C7BE HANGUL SYLLABLE JAEBS
C7BF HANGUL SYLLABLE JAES
C7C0 HANGUL SYLLABLE JAESS
C7C1 HANGUL SYLLABLE JAENG
C7C2 HANGUL SYLLABLE JAEJ
C7C3 HANGUL SYLLABLE JAEC
C7C4 HANGUL SYLLABLE JAEK
C7C5 HANGUL SYLLABLE JAET
C7C6 HANGUL SYLLABLE JAEP
C7C7 HANGUL SYLLABLE JAEH
C7C8 HANGUL SYLLABLE JYA
C7C9 HANGUL SYLLABLE JYAG
C7CA HANGUL SYLLABLE JYAGG
C7CB HANGUL SYLLABLE JYAGS
C7CC HANGUL SYLLABLE JYAN
C7CD HANGUL SYLLABLE JYANJ
C7CE HANGUL SYLLABLE JYANH
C7CF HANGUL SYLLABLE JYAD
C7D0 HANGUL SYLLABLE JYAL
C7D1 HANGUL SYLLABLE JYALG
C7D2 HANGUL SYLLABLE JYALM
C7D3 HANGUL SYLLABLE JYALB
C7D4 HANGUL SYLLABLE JYALS
C7D5 HANGUL SYLLABLE JYALT
C7D6 HANGUL SYLLABLE JYALP
C7D7 HANGUL SYLLABLE JYALH
C7D8 HANGUL SYLLABLE JYAM
C7D9 HANGUL SYLLABLE JYAB
C7DA HANGUL SYLLABLE JYABS
C7DB HANGUL SYLLABLE JYAS
C7DC HANGUL SYLLABLE JYASS
C7DD HANGUL SYLLABLE JYANG
C7DE HANGUL SYLLABLE JYAJ
C7DF HANGUL SYLLABLE JYAC
C7E0 HANGUL SYLLABLE JYAK
C7E1 HANGUL SYLLABLE JYAT
C7E2 HANGUL SYLLABLE JYAP
C7E3 HANGUL SYLLABLE JYAH
C7E4 HANGUL SYLLABLE JYAE
C7E5 HANGUL SYLLABLE JYAEG
C7E6 HANGUL SYLLABLE JYAEGG
C7E7 HANGUL SYLLABLE JYAEGS
C7E8 HANGUL SYLLABLE JYAEN
C7E9 HANGUL SYLLABLE JYAENJ
C7EA HANGUL SYLLABLE JYAENH
C7EB HANGUL SYLLABLE JYAED
C7EC HANGUL SYLLABLE JYAEL
C7ED HANGUL SYLLABLE JYAELG
C7EE HANGUL SYLLABLE JYAELM
C7EF HANGUL SYLLABLE JYAELB
C7F0 HANGUL SYLLABLE JYAELS
C7F1 HANGUL SYLLABLE JYAELT
C7F2 HANGUL SYLLABLE JYAELP
C7F3 HANGUL SYLLABLE JYAELH
C7F4 HANGUL SYLLABLE JYAEM
C7F5 HANGUL SYLLABLE JYAEB
C7F6 HANGUL SYLLABLE JYAEBS
C7F7 HANGUL SYLLABLE JYAES
C7F8 HANGUL SYLLABLE JYAESS
C7F9 HANGUL SYLLABLE JYAENG
C7FA HANGUL SYLLABLE JYAEJ
C7FB HANGUL SYLLABLE JYAEC
C7FC HANGUL SYLLABLE JYAEK
C7FD HANGUL SYLLABLE JYAET
C7FE HANGUL SYLLABLE JYAEP
C7FF HANGUL SYLLABLE JYAEH
C800 HANGUL SYLLABLE JEO
C801 HANGUL SYLLABLE JEOG
C802 HANGUL SYLLABLE JEOGG
C803 HANGUL SYLLABLE JEOGS
C804 HANGUL SYLLABLE JEON
C805 HANGUL SYLLABLE JEONJ
C806 HANGUL SYLLABLE JEONH
C807 HANGUL SYLLABLE JEOD
C808 HANGUL SYLLABLE JEOL
C809 HANGUL SYLLABLE JEOLG
C80A HANGUL SYLLABLE JEOLM
C80B HANGUL SYLLABLE JEOLB
C80C HANGUL SYLLABLE JEOLS
C80D HANGUL SYLLABLE JEOLT
C80E HANGUL SYLLABLE JEOLP
C80F HANGUL SYLLABLE JEOLH
C810 HANGUL SYLLABLE JEOM
C811 HANGUL SYLLABLE JEOB
C812 HANGUL SYLLABLE JEOBS
C813 HANGUL SYLLABLE JEOS
C814 HANGUL SYLLABLE JEOSS
C815 HANGUL SYLLABLE JEONG
C816 HANGUL SYLLABLE JEOJ
C817 HANGUL SYLLABLE JEOC
C818 HANGUL SYLLABLE JEOK
C819 HANGUL SYLLABLE JEOT
C81A HANGUL SYLLABLE JEOP
C81B HANGUL SYLLABLE JEOH
C81C HANGUL SYLLABLE JE
C81D HANGUL SYLLABLE JEG
C81E HANGUL SYLLABLE JEGG
C81F HANGUL SYLLABLE JEGS
C820 HANGUL SYLLABLE JEN
C821 HANGUL SYLLABLE JENJ
C822 HANGUL SYLLABLE JENH
C823 HANGUL SYLLABLE JED
C824 HANGUL SYLLABLE JEL
C825 HANGUL SYLLABLE JELG
C826 HANGUL SYLLABLE JELM
C827 HANGUL SYLLABLE JELB
C828 HANGUL SYLLABLE JELS
C829 HANGUL SYLLABLE JELT
C82A HANGUL SYLLABLE JELP
C82B HANGUL SYLLABLE JELH
C82C HANGUL SYLLABLE JEM
C82D HANGUL SYLLABLE JEB
C82E HANGUL SYLLABLE JEBS
C82F HANGUL SYLLABLE JES
C830 HANGUL SYLLABLE JESS
C831 HANGUL SYLLABLE JENG
C832 HANGUL SYLLABLE JEJ
C833 HANGUL SYLLABLE JEC
C834 HANGUL SYLLABLE JEK
C835 HANGUL SYLLABLE JET
C836 HANGUL SYLLABLE JEP
C837 HANGUL SYLLABLE JEH
C838 HANGUL SYLLABLE JYEO
C839 HANGUL SYLLABLE JYEOG
C83A HANGUL SYLLABLE JYEOGG
C83B HANGUL SYLLABLE JYEOGS
C83C HANGUL SYLLABLE JYEON
C83D HANGUL SYLLABLE JYEONJ
C83E HANGUL SYLLABLE JYEONH
C83F HANGUL SYLLABLE JYEOD
C840 HANGUL SYLLABLE JYEOL
C841 HANGUL SYLLABLE JYEOLG
C842 HANGUL SYLLABLE JYEOLM
C843 HANGUL SYLLABLE JYEOLB
C844 HANGUL SYLLABLE JYEOLS
C845 HANGUL SYLLABLE JYEOLT
C846 HANGUL SYLLABLE JYEOLP
C847 HANGUL SYLLABLE JYEOLH
C848 HANGUL SYLLABLE JYEOM
C849 HANGUL SYLLABLE JYEOB
C84A HANGUL SYLLABLE JYEOBS
C84B HANGUL SYLLABLE JYEOS
C84C HANGUL SYLLABLE JYEOSS
C84D HANGUL SYLLABLE JYEONG
C84E HANGUL SYLLABLE JYEOJ
C84F HANGUL SYLLABLE JYEOC
C850 HANGUL SYLLABLE JYEOK
C851 HANGUL SYLLABLE JYEOT
C852 HANGUL SYLLABLE JYEOP
C853 HANGUL SYLLABLE JYEOH
C854 HANGUL SYLLABLE JYE
C855 HANGUL SYLLABLE JYEG
C856 HANGUL SYLLABLE JYEGG
C857 HANGUL SYLLABLE JYEGS
C858 HANGUL SYLLABLE JYEN
C859 HANGUL SYLLABLE JYENJ
C85A HANGUL SYLLABLE JYENH
C85B HANGUL SYLLABLE JYED
C85C HANGUL SYLLABLE JYEL
C85D HANGUL SYLLABLE JYELG
C85E HANGUL SYLLABLE JYELM
C85F HANGUL SYLLABLE JYELB
C860 HANGUL SYLLABLE JYELS
C861 HANGUL SYLLABLE JYELT
C862 HANGUL SYLLABLE JYELP
C863 HANGUL SYLLABLE JYELH
C864 HANGUL SYLLABLE JYEM
C865 HANGUL SYLLABLE JYEB
C866 HANGUL SYLLABLE JYEBS
C867 HANGUL SYLLABLE JYES
C868 HANGUL SYLLABLE JYESS
C869 HANGUL SYLLABLE JYENG
C86A HANGUL SYLLABLE JYEJ
C86B HANGUL SYLLABLE JYEC
C86C HANGUL SYLLABLE JYEK
C86D HANGUL SYLLABLE JYET
C86E HANGUL SYLLABLE JYEP
C86F HANGUL SYLLABLE JYEH
C870 HANGUL SYLLABLE JO
C871 HANGUL SYLLABLE JOG
C872 HANGUL SYLLABLE JOGG
C873 HANGUL SYLLABLE JOGS
C874 HANGUL SYLLABLE JON
C875 HANGUL SYLLABLE JONJ
C876 HANGUL SYLLABLE JONH
C877 HANGUL SYLLABLE JOD
C878 HANGUL SYLLABLE JOL
C879 HANGUL SYLLABLE JOLG
C87A HANGUL SYLLABLE JOLM
C87B HANGUL SYLLABLE JOLB
C87C HANGUL SYLLABLE JOLS
C87D HANGUL SYLLABLE JOLT
C87E HANGUL SYLLABLE JOLP
C87F HANGUL SYLLABLE JOLH
C880 HANGUL SYLLABLE JOM
C881 HANGUL SYLLABLE JOB
C882 HANGUL SYLLABLE JOBS
C883 HANGUL SYLLABLE JOS
C884 HANGUL SYLLABLE JOSS
C885 HANGUL SYLLABLE JONG
C886 HANGUL SYLLABLE JOJ
C887 HANGUL SYLLABLE JOC
C888 HANGUL SYLLABLE JOK
C889 HANGUL SYLLABLE JOT
C88A HANGUL SYLLABLE JOP
C88B HANGUL SYLLABLE JOH
C88C HANGUL SYLLABLE JWA
C88D HANGUL SYLLABLE JWAG
C88E HANGUL SYLLABLE JWAGG
C88F HANGUL SYLLABLE JWAGS
C890 HANGUL SYLLABLE JWAN
C891 HANGUL SYLLABLE JWANJ
C892 HANGUL SYLLABLE JWANH
C893 HANGUL SYLLABLE JWAD
C894 HANGUL SYLLABLE JWAL
C895 HANGUL SYLLABLE JWALG
C896 HANGUL SYLLABLE JWALM
C897 HANGUL SYLLABLE JWALB
C898 HANGUL SYLLABLE JWALS
C899 HANGUL SYLLABLE JWALT
C89A HANGUL SYLLABLE JWALP
C89B HANGUL SYLLABLE JWALH
C89C HANGUL SYLLABLE JWAM
C89D HANGUL SYLLABLE JWAB
C89E HANGUL SYLLABLE JWABS
C89F HANGUL SYLLABLE JWAS
C8A0 HANGUL SYLLABLE JWASS
C8A1 HANGUL SYLLABLE JWANG
C8A2 HANGUL SYLLABLE JWAJ
C8A3 HANGUL SYLLABLE JWAC
C8A4 HANGUL SYLLABLE JWAK
C8A5 HANGUL SYLLABLE JWAT
C8A6 HANGUL SYLLABLE JWAP
C8A7 HANGUL SYLLABLE JWAH
C8A8 HANGUL SYLLABLE JWAE
C8A9 HANGUL SYLLABLE JWAEG
C8AA HANGUL SYLLABLE JWAEGG
C8AB HANGUL SYLLABLE JWAEGS
C8AC HANGUL SYLLABLE JWAEN
C8AD HANGUL SYLLABLE JWAENJ
C8AE HANGUL SYLLABLE JWAENH
C8AF HANGUL SYLLABLE JWAED
C8B0 HANGUL SYLLABLE JWAEL
C8B1 HANGUL SYLLABLE JWAELG
C8B2 HANGUL SYLLABLE JWAELM
C8B3 HANGUL SYLLABLE JWAELB
C8B4 HANGUL SYLLABLE JWAELS
C8B5 HANGUL SYLLABLE JWAELT
C8B6 HANGUL SYLLABLE JWAELP
C8B7 HANGUL SYLLABLE JWAELH
C8B8 HANGUL SYLLABLE JWAEM
C8B9 HANGUL SYLLABLE JWAEB
C8BA HANGUL SYLLABLE JWAEBS
C8BB HANGUL SYLLABLE JWAES
C8BC HANGUL SYLLABLE JWAESS
C8BD HANGUL SYLLABLE JWAENG
C8BE HANGUL SYLLABLE JWAEJ
C8BF HANGUL SYLLABLE JWAEC
C8C0 HANGUL SYLLABLE JWAEK
C8C1 HANGUL SYLLABLE JWAET
C8C2 HANGUL SYLLABLE JWAEP
C8C3 HANGUL SYLLABLE JWAEH
C8C4 HANGUL SYLLABLE JOE
C8C5 HANGUL SYLLABLE JOEG
C8C6 HANGUL SYLLABLE JOEGG
C8C7 HANGUL SYLLABLE JOEGS
C8C8 HANGUL SYLLABLE JOEN
C8C9 HANGUL SYLLABLE JOENJ
C8CA HANGUL SYLLABLE JOENH
C8CB HANGUL SYLLABLE JOED
C8CC HANGUL SYLLABLE JOEL
C8CD HANGUL SYLLABLE JOELG
C8CE HANGUL SYLLABLE JOELM
C8CF HANGUL SYLLABLE JOELB
C8D0 HANGUL SYLLABLE JOELS
C8D1 HANGUL SYLLABLE JOELT
C8D2 HANGUL SYLLABLE JOELP
C8D3 HANGUL SYLLABLE JOELH
C8D4 HANGUL SYLLABLE JOEM
C8D5 HANGUL SYLLABLE JOEB
C8D6 HANGUL SYLLABLE JOEBS
C8D7 HANGUL SYLLABLE JOES
C8D8 HANGUL SYLLABLE JOESS
C8D9 HANGUL SYLLABLE JOENG
C8DA HANGUL SYLLABLE JOEJ
C8DB HANGUL SYLLABLE JOEC
C8DC HANGUL SYLLABLE JOEK
C8DD HANGUL SYLLABLE JOET
C8DE HANGUL SYLLABLE JOEP
C8DF HANGUL SYLLABLE JOEH
C8E0 HANGUL SYLLABLE JYO
C8E1 HANGUL SYLLABLE JYOG
C8E2 HANGUL SYLLABLE JYOGG
C8E3 HANGUL SYLLABLE JYOGS
C8E4 HANGUL SYLLABLE JYON
C8E5 HANGUL SYLLABLE JYONJ
C8E6 HANGUL SYLLABLE JYONH
C8E7 HANGUL SYLLABLE JYOD
C8E8 HANGUL SYLLABLE JYOL
C8E9 HANGUL SYLLABLE JYOLG
C8EA HANGUL SYLLABLE JYOLM
C8EB HANGUL SYLLABLE JYOLB
C8EC HANGUL SYLLABLE JYOLS
C8ED HANGUL SYLLABLE JYOLT
C8EE HANGUL SYLLABLE JYOLP
C8EF HANGUL SYLLABLE JYOLH
C8F0 HANGUL SYLLABLE JYOM
C8F1 HANGUL SYLLABLE JYOB
C8F2 HANGUL SYLLABLE JYOBS
C8F3 HANGUL SYLLABLE JYOS
C8F4 HANGUL SYLLABLE JYOSS
C8F5 HANGUL SYLLABLE JYONG
C8F6 HANGUL SYLLABLE JYOJ
C8F7 HANGUL SYLLABLE JYOC
C8F8 HANGUL SYLLABLE JYOK
C8F9 HANGUL SYLLABLE JYOT
C8FA HANGUL SYLLABLE JYOP
C8FB HANGUL SYLLABLE JYOH
C8FC HANGUL SYLLABLE JU
C8FD HANGUL SYLLABLE JUG
C8FE HANGUL SYLLABLE JUGG
C8FF HANGUL SYLLABLE JUGS
C900 HANGUL SYLLABLE JUN
C901 HANGUL SYLLABLE JUNJ
C902 HANGUL SYLLABLE JUNH
C903 HANGUL SYLLABLE JUD
C904 HANGUL SYLLABLE JUL
C905 HANGUL SYLLABLE JULG
C906 HANGUL SYLLABLE JULM
C907 HANGUL SYLLABLE JULB
C908 HANGUL SYLLABLE JULS
C909 HANGUL SYLLABLE JULT
C90A HANGUL SYLLABLE JULP
C90B HANGUL SYLLABLE JULH
C90C HANGUL SYLLABLE JUM
C90D HANGUL SYLLABLE JUB
C90E HANGUL SYLLABLE JUBS
C90F HANGUL SYLLABLE JUS
C910 HANGUL SYLLABLE JUSS
C911 HANGUL SYLLABLE JUNG
C912 HANGUL SYLLABLE JUJ
C913 HANGUL SYLLABLE JUC
C914 HANGUL SYLLABLE JUK
C915 HANGUL SYLLABLE JUT
C916 HANGUL SYLLABLE JUP
C917 HANGUL SYLLABLE JUH
C918 HANGUL SYLLABLE JWEO
C919 HANGUL SYLLABLE JWEOG
C91A HANGUL SYLLABLE JWEOGG
C91B HANGUL SYLLABLE JWEOGS
C91C HANGUL SYLLABLE JWEON
C91D HANGUL SYLLABLE JWEONJ
C91E HANGUL SYLLABLE JWEONH
C91F HANGUL SYLLABLE JWEOD
C920 HANGUL SYLLABLE JWEOL
C921 HANGUL SYLLABLE JWEOLG
C922 HANGUL SYLLABLE JWEOLM
C923 HANGUL SYLLABLE JWEOLB
C924 HANGUL SYLLABLE JWEOLS
C925 HANGUL SYLLABLE JWEOLT
C926 HANGUL SYLLABLE JWEOLP
C927 HANGUL SYLLABLE JWEOLH
C928 HANGUL SYLLABLE JWEOM
C929 HANGUL SYLLABLE JWEOB
C92A HANGUL SYLLABLE JWEOBS
C92B HANGUL SYLLABLE JWEOS
C92C HANGUL SYLLABLE JWEOSS
C92D HANGUL SYLLABLE JWEONG
C92E HANGUL SYLLABLE JWEOJ
C92F HANGUL SYLLABLE JWEOC
C930 HANGUL SYLLABLE JWEOK
C931 HANGUL SYLLABLE JWEOT
C932 HANGUL SYLLABLE JWEOP
C933 HANGUL SYLLABLE JWEOH
C934 HANGUL SYLLABLE JWE
C935 HANGUL SYLLABLE JWEG
C936 HANGUL SYLLABLE JWEGG
C937 HANGUL SYLLABLE JWEGS
C938 HANGUL SYLLABLE JWEN
C939 HANGUL SYLLABLE JWENJ
C93A HANGUL SYLLABLE JWENH
C93B HANGUL SYLLABLE JWED
C93C HANGUL SYLLABLE JWEL
C93D HANGUL SYLLABLE JWELG
C93E HANGUL SYLLABLE JWELM
C93F HANGUL SYLLABLE JWELB
C940 HANGUL SYLLABLE JWELS
C941 HANGUL SYLLABLE JWELT
C942 HANGUL SYLLABLE JWELP
C943 HANGUL SYLLABLE JWELH
C944 HANGUL SYLLABLE JWEM
C945 HANGUL SYLLABLE JWEB
C946 HANGUL SYLLABLE JWEBS
C947 HANGUL SYLLABLE JWES
C948 HANGUL SYLLABLE JWESS
C949 HANGUL SYLLABLE JWENG
C94A HANGUL SYLLABLE JWEJ
C94B HANGUL SYLLABLE JWEC
C94C HANGUL SYLLABLE JWEK
C94D HANGUL SYLLABLE JWET
C94E HANGUL SYLLABLE JWEP
C94F HANGUL SYLLABLE JWEH
C950 HANGUL SYLLABLE JWI
C951 HANGUL SYLLABLE JWIG
C952 HANGUL SYLLABLE JWIGG
C953 HANGUL SYLLABLE JWIGS
C954 HANGUL SYLLABLE JWIN
C955 HANGUL SYLLABLE JWINJ
C956 HANGUL SYLLABLE JWINH
C957 HANGUL SYLLABLE JWID
C958 HANGUL SYLLABLE JWIL
C959 HANGUL SYLLABLE JWILG
C95A HANGUL SYLLABLE JWILM
C95B HANGUL SYLLABLE JWILB
C95C HANGUL SYLLABLE JWILS
C95D HANGUL SYLLABLE JWILT
C95E HANGUL SYLLABLE JWILP
C95F HANGUL SYLLABLE JWILH
C960 HANGUL SYLLABLE JWIM
C961 HANGUL SYLLABLE JWIB
C962 HANGUL SYLLABLE JWIBS
C963 HANGUL SYLLABLE JWIS
C964 HANGUL SYLLABLE JWISS
C965 HANGUL SYLLABLE JWING
C966 HANGUL SYLLABLE JWIJ
C967 HANGUL SYLLABLE JWIC
C968 HANGUL SYLLABLE JWIK
C969 HANGUL SYLLABLE JWIT
C96A HANGUL SYLLABLE JWIP
C96B HANGUL SYLLABLE JWIH
C96C HANGUL SYLLABLE JYU
C96D HANGUL SYLLABLE JYUG
C96E HANGUL SYLLABLE JYUGG
C96F HANGUL SYLLABLE JYUGS
C970 HANGUL SYLLABLE JYUN
C971 HANGUL SYLLABLE JYUNJ
C972 HANGUL SYLLABLE JYUNH
C973 HANGUL SYLLABLE JYUD
C974 HANGUL SYLLABLE JYUL
C975 HANGUL SYLLABLE JYULG
C976 HANGUL SYLLABLE JYULM
C977 HANGUL SYLLABLE JYULB
C978 HANGUL SYLLABLE JYULS
C979 HANGUL SYLLABLE JYULT
C97A HANGUL SYLLABLE JYULP
C97B HANGUL SYLLABLE JYULH
C97C HANGUL SYLLABLE JYUM
C97D HANGUL SYLLABLE JYUB
C97E HANGUL SYLLABLE JYUBS
C97F HANGUL SYLLABLE JYUS
C980 HANGUL SYLLABLE JYUSS
C981 HANGUL SYLLABLE JYUNG
C982 HANGUL SYLLABLE JYUJ
C983 HANGUL SYLLABLE JYUC
C984 HANGUL SYLLABLE JYUK
C985 HANGUL SYLLABLE JYUT
C986 HANGUL SYLLABLE JYUP
C987 HANGUL SYLLABLE JYUH
C988 HANGUL SYLLABLE JEU
C989 HANGUL SYLLABLE JEUG
C98A HANGUL SYLLABLE JEUGG
C98B HANGUL SYLLABLE JEUGS
C98C HANGUL SYLLABLE JEUN
C98D HANGUL SYLLABLE JEUNJ
C98E HANGUL SYLLABLE JEUNH
C98F HANGUL SYLLABLE JEUD
C990 HANGUL SYLLABLE JEUL
C991 HANGUL SYLLABLE JEULG
C992 HANGUL SYLLABLE JEULM
C993 HANGUL SYLLABLE JEULB
C994 HANGUL SYLLABLE JEULS
C995 HANGUL SYLLABLE JEULT
C996 HANGUL SYLLABLE JEULP
C997 HANGUL SYLLABLE JEULH
C998 HANGUL SYLLABLE JEUM
C999 HANGUL SYLLABLE JEUB
C99A HANGUL SYLLABLE JEUBS
C99B HANGUL SYLLABLE JEUS
C99C HANGUL SYLLABLE JEUSS
C99D HANGUL SYLLABLE JEUNG
C99E HANGUL SYLLABLE JEUJ
C99F HANGUL SYLLABLE JEUC
C9A0 HANGUL SYLLABLE JEUK
C9A1 HANGUL SYLLABLE JEUT
C9A2 HANGUL SYLLABLE JEUP
C9A3 HANGUL SYLLABLE JEUH
C9A4 HANGUL SYLLABLE JYI
C9A5 HANGUL SYLLABLE JYIG
C9A6 HANGUL SYLLABLE JYIGG
C9A7 HANGUL SYLLABLE JYIGS
C9A8 HANGUL SYLLABLE JYIN
C9A9 HANGUL SYLLABLE JYINJ
C9AA HANGUL SYLLABLE JYINH
C9AB HANGUL SYLLABLE JYID
C9AC HANGUL SYLLABLE JYIL
C9AD HANGUL SYLLABLE JYILG
C9AE HANGUL SYLLABLE JYILM
C9AF HANGUL SYLLABLE JYILB
C9B0 HANGUL SYLLABLE JYILS
C9B1 HANGUL SYLLABLE JYILT
C9B2 HANGUL SYLLABLE JYILP
C9B3 HANGUL SYLLABLE JYILH
C9B4 HANGUL SYLLABLE JYIM
C9B5 HANGUL SYLLABLE JYIB
C9B6 HANGUL SYLLABLE JYIBS
C9B7 HANGUL SYLLABLE JYIS
C9B8 HANGUL SYLLABLE JYISS
C9B9 HANGUL SYLLABLE JYING
C9BA HANGUL SYLLABLE JYIJ
C9BB HANGUL SYLLABLE JYIC
C9BC HANGUL SYLLABLE JYIK
C9BD HANGUL SYLLABLE JYIT
C9BE HANGUL SYLLABLE JYIP
C9BF HANGUL SYLLABLE JYIH
C9C0 HANGUL SYLLABLE JI
C9C1 HANGUL SYLLABLE JIG
C9C2 HANGUL SYLLABLE JIGG
C9C3 HANGUL SYLLABLE JIGS
C9C4 HANGUL SYLLABLE JIN
C9C5 HANGUL SYLLABLE JINJ
C9C6 HANGUL SYLLABLE JINH
C9C7 HANGUL SYLLABLE JID
C9C8 HANGUL SYLLABLE JIL
C9C9 HANGUL SYLLABLE JILG
C9CA HANGUL SYLLABLE JILM
C9CB HANGUL SYLLABLE JILB
C9CC HANGUL SYLLABLE JILS
C9CD HANGUL SYLLABLE JILT
C9CE HANGUL SYLLABLE JILP
C9CF HANGUL SYLLABLE JILH
C9D0 HANGUL SYLLABLE JIM
C9D1 HANGUL SYLLABLE JIB
C9D2 HANGUL SYLLABLE JIBS
C9D3 HANGUL SYLLABLE JIS
C9D4 HANGUL SYLLABLE JISS
C9D5 HANGUL SYLLABLE JING
C9D6 HANGUL SYLLABLE JIJ
C9D7 HANGUL SYLLABLE JIC
C9D8 HANGUL SYLLABLE JIK
C9D9 HANGUL SYLLABLE JIT
C9DA HANGUL SYLLABLE JIP
C9DB HANGUL SYLLABLE JIH
C9DC HANGUL SYLLABLE JJA
C9DD HANGUL SYLLABLE JJAG
C9DE HANGUL SYLLABLE JJAGG
C9DF HANGUL SYLLABLE JJAGS
C9E0 HANGUL SYLLABLE JJAN
C9E1 HANGUL SYLLABLE JJANJ
C9E2 HANGUL SYLLABLE JJANH
C9E3 HANGUL SYLLABLE JJAD
C9E4 HANGUL SYLLABLE JJAL
C9E5 HANGUL SYLLABLE JJALG
C9E6 HANGUL SYLLABLE JJALM
C9E7 HANGUL SYLLABLE JJALB
C9E8 HANGUL SYLLABLE JJALS
C9E9 HANGUL SYLLABLE JJALT
C9EA HANGUL SYLLABLE JJALP
C9EB HANGUL SYLLABLE JJALH
C9EC HANGUL SYLLABLE JJAM
C9ED HANGUL SYLLABLE JJAB
C9EE HANGUL SYLLABLE JJABS
C9EF HANGUL SYLLABLE JJAS
C9F0 HANGUL SYLLABLE JJASS
C9F1 HANGUL SYLLABLE JJANG
C9F2 HANGUL SYLLABLE JJAJ
C9F3 HANGUL SYLLABLE JJAC
C9F4 HANGUL SYLLABLE JJAK
C9F5 HANGUL SYLLABLE JJAT
C9F6 HANGUL SYLLABLE JJAP
C9F7 HANGUL SYLLABLE JJAH
C9F8 HANGUL SYLLABLE JJAE
C9F9 HANGUL SYLLABLE JJAEG
C9FA HANGUL SYLLABLE JJAEGG
C9FB HANGUL SYLLABLE JJAEGS
C9FC HANGUL SYLLABLE JJAEN
C9FD HANGUL SYLLABLE JJAENJ
C9FE HANGUL SYLLABLE JJAENH
C9FF HANGUL SYLLABLE JJAED
CA00 HANGUL SYLLABLE JJAEL
CA01 HANGUL SYLLABLE JJAELG
CA02 HANGUL SYLLABLE JJAELM
CA03 HANGUL SYLLABLE JJAELB
CA04 HANGUL SYLLABLE JJAELS
CA05 HANGUL SYLLABLE JJAELT
CA06 HANGUL SYLLABLE JJAELP
CA07 HANGUL SYLLABLE JJAELH
CA08 HANGUL SYLLABLE JJAEM
CA09 HANGUL SYLLABLE JJAEB
CA0A HANGUL SYLLABLE JJAEBS
CA0B HANGUL SYLLABLE JJAES
CA0C HANGUL SYLLABLE JJAESS
CA0D HANGUL SYLLABLE JJAENG
CA0E HANGUL SYLLABLE JJAEJ
CA0F HANGUL SYLLABLE JJAEC
CA10 HANGUL SYLLABLE JJAEK
CA11 HANGUL SYLLABLE JJAET
CA12 HANGUL SYLLABLE JJAEP
CA13 HANGUL SYLLABLE JJAEH
CA14 HANGUL SYLLABLE JJYA
CA15 HANGUL SYLLABLE JJYAG
CA16 HANGUL SYLLABLE JJYAGG
CA17 HANGUL SYLLABLE JJYAGS
CA18 HANGUL SYLLABLE JJYAN
CA19 HANGUL SYLLABLE JJYANJ
CA1A HANGUL SYLLABLE JJYANH
CA1B HANGUL SYLLABLE JJYAD
CA1C HANGUL SYLLABLE JJYAL
CA1D HANGUL SYLLABLE JJYALG
CA1E HANGUL SYLLABLE JJYALM
CA1F HANGUL SYLLABLE JJYALB
CA20 HANGUL SYLLABLE JJYALS
CA21 HANGUL SYLLABLE JJYALT
CA22 HANGUL SYLLABLE JJYALP
CA23 HANGUL SYLLABLE JJYALH
CA24 HANGUL SYLLABLE JJYAM
CA25 HANGUL SYLLABLE JJYAB
CA26 HANGUL SYLLABLE JJYABS
CA27 HANGUL SYLLABLE JJYAS
CA28 HANGUL SYLLABLE JJYASS
CA29 HANGUL SYLLABLE JJYANG
CA2A HANGUL SYLLABLE JJYAJ
CA2B HANGUL SYLLABLE JJYAC
CA2C HANGUL SYLLABLE JJYAK
CA2D HANGUL SYLLABLE JJYAT
CA2E HANGUL SYLLABLE JJYAP
CA2F HANGUL SYLLABLE JJYAH
CA30 HANGUL SYLLABLE JJYAE
CA31 HANGUL SYLLABLE JJYAEG
CA32 HANGUL SYLLABLE JJYAEGG
CA33 HANGUL SYLLABLE JJYAEGS
CA34 HANGUL SYLLABLE JJYAEN
CA35 HANGUL SYLLABLE JJYAENJ
CA36 HANGUL SYLLABLE JJYAENH
CA37 HANGUL SYLLABLE JJYAED
CA38 HANGUL SYLLABLE JJYAEL
CA39 HANGUL SYLLABLE JJYAELG
CA3A HANGUL SYLLABLE JJYAELM
CA3B HANGUL SYLLABLE JJYAELB
CA3C HANGUL SYLLABLE JJYAELS
CA3D HANGUL SYLLABLE JJYAELT
CA3E HANGUL SYLLABLE JJYAELP
CA3F HANGUL SYLLABLE JJYAELH
CA40 HANGUL SYLLABLE JJYAEM
CA41 HANGUL SYLLABLE JJYAEB
CA42 HANGUL SYLLABLE JJYAEBS
CA43 HANGUL SYLLABLE JJYAES
CA44 HANGUL SYLLABLE JJYAESS
CA45 HANGUL SYLLABLE JJYAENG
CA46 HANGUL SYLLABLE JJYAEJ
CA47 HANGUL SYLLABLE JJYAEC
CA48 HANGUL SYLLABLE JJYAEK
CA49 HANGUL SYLLABLE JJYAET
CA4A HANGUL SYLLABLE JJYAEP
CA4B HANGUL SYLLABLE JJYAEH
CA4C HANGUL SYLLABLE JJEO
CA4D HANGUL SYLLABLE JJEOG
CA4E HANGUL SYLLABLE JJEOGG
CA4F HANGUL SYLLABLE JJEOGS
CA50 HANGUL SYLLABLE JJEON
CA51 HANGUL SYLLABLE JJEONJ
CA52 HANGUL SYLLABLE JJEONH
CA53 HANGUL SYLLABLE JJEOD
CA54 HANGUL SYLLABLE JJEOL
CA55 HANGUL SYLLABLE JJEOLG
CA56 HANGUL SYLLABLE JJEOLM
CA57 HANGUL SYLLABLE JJEOLB
CA58 HANGUL SYLLABLE JJEOLS
CA59 HANGUL SYLLABLE JJEOLT
CA5A HANGUL SYLLABLE JJEOLP
CA5B HANGUL SYLLABLE JJEOLH
CA5C HANGUL SYLLABLE JJEOM
CA5D HANGUL SYLLABLE JJEOB
CA5E HANGUL SYLLABLE JJEOBS
CA5F HANGUL SYLLABLE JJEOS
CA60 HANGUL SYLLABLE JJEOSS
CA61 HANGUL SYLLABLE JJEONG
CA62 HANGUL SYLLABLE JJEOJ
CA63 HANGUL SYLLABLE JJEOC
CA64 HANGUL SYLLABLE JJEOK
CA65 HANGUL SYLLABLE JJEOT
CA66 HANGUL SYLLABLE JJEOP
CA67 HANGUL SYLLABLE JJEOH
CA68 HANGUL SYLLABLE JJE
CA69 HANGUL SYLLABLE JJEG
CA6A HANGUL SYLLABLE JJEGG
CA6B HANGUL SYLLABLE JJEGS
CA6C HANGUL SYLLABLE JJEN
CA6D HANGUL SYLLABLE JJENJ
CA6E HANGUL SYLLABLE JJENH
CA6F HANGUL SYLLABLE JJED
CA70 HANGUL SYLLABLE JJEL
CA71 HANGUL SYLLABLE JJELG
CA72 HANGUL SYLLABLE JJELM
CA73 HANGUL SYLLABLE JJELB
CA74 HANGUL SYLLABLE JJELS
CA75 HANGUL SYLLABLE JJELT
CA76 HANGUL SYLLABLE JJELP
CA77 HANGUL SYLLABLE JJELH
CA78 HANGUL SYLLABLE JJEM
CA79 HANGUL SYLLABLE JJEB
CA7A HANGUL SYLLABLE JJEBS
CA7B HANGUL SYLLABLE JJES
CA7C HANGUL SYLLABLE JJESS
CA7D HANGUL SYLLABLE JJENG
CA7E HANGUL SYLLABLE JJEJ
CA7F HANGUL SYLLABLE JJEC
CA80 HANGUL SYLLABLE JJEK
CA81 HANGUL SYLLABLE JJET
CA82 HANGUL SYLLABLE JJEP
CA83 HANGUL SYLLABLE JJEH
CA84 HANGUL SYLLABLE JJYEO
CA85 HANGUL SYLLABLE JJYEOG
CA86 HANGUL SYLLABLE JJYEOGG
CA87 HANGUL SYLLABLE JJYEOGS
CA88 HANGUL SYLLABLE JJYEON
CA89 HANGUL SYLLABLE JJYEONJ
CA8A HANGUL SYLLABLE JJYEONH
CA8B HANGUL SYLLABLE JJYEOD
CA8C HANGUL SYLLABLE JJYEOL
CA8D HANGUL SYLLABLE JJYEOLG
CA8E HANGUL SYLLABLE JJYEOLM
CA8F HANGUL SYLLABLE JJYEOLB
CA90 HANGUL SYLLABLE JJYEOLS
CA91 HANGUL SYLLABLE JJYEOLT
CA92 HANGUL SYLLABLE JJYEOLP
CA93 HANGUL SYLLABLE JJYEOLH
CA94 HANGUL SYLLABLE JJYEOM
CA95 HANGUL SYLLABLE JJYEOB
CA96 HANGUL SYLLABLE JJYEOBS
CA97 HANGUL SYLLABLE JJYEOS
CA98 HANGUL SYLLABLE JJYEOSS
CA99 HANGUL SYLLABLE JJYEONG
CA9A HANGUL SYLLABLE JJYEOJ
CA9B HANGUL SYLLABLE JJYEOC
CA9C HANGUL SYLLABLE JJYEOK
CA9D HANGUL SYLLABLE JJYEOT
CA9E HANGUL SYLLABLE JJYEOP
CA9F HANGUL SYLLABLE JJYEOH
CAA0 HANGUL SYLLABLE JJYE
CAA1 HANGUL SYLLABLE JJYEG
CAA2 HANGUL SYLLABLE JJYEGG
CAA3 HANGUL SYLLABLE JJYEGS
CAA4 HANGUL SYLLABLE JJYEN
CAA5 HANGUL SYLLABLE JJYENJ
CAA6 HANGUL SYLLABLE JJYENH
CAA7 HANGUL SYLLABLE JJYED
CAA8 HANGUL SYLLABLE JJYEL
CAA9 HANGUL SYLLABLE JJYELG
CAAA HANGUL SYLLABLE JJYELM
CAAB HANGUL SYLLABLE JJYELB
CAAC HANGUL SYLLABLE JJYELS
CAAD HANGUL SYLLABLE JJYELT
CAAE HANGUL SYLLABLE JJYELP
CAAF HANGUL SYLLABLE JJYELH
CAB0 HANGUL SYLLABLE JJYEM
CAB1 HANGUL SYLLABLE JJYEB
CAB2 HANGUL SYLLABLE JJYEBS
CAB3 HANGUL SYLLABLE JJYES
CAB4 HANGUL SYLLABLE JJYESS
CAB5 HANGUL SYLLABLE JJYENG
CAB6 HANGUL SYLLABLE JJYEJ
CAB7 HANGUL SYLLABLE JJYEC
CAB8 HANGUL SYLLABLE JJYEK
CAB9 HANGUL SYLLABLE JJYET
CABA HANGUL SYLLABLE JJYEP
CABB HANGUL SYLLABLE JJYEH
CABC HANGUL SYLLABLE JJO
CABD HANGUL SYLLABLE JJOG
CABE HANGUL SYLLABLE JJOGG
CABF HANGUL SYLLABLE JJOGS
CAC0 HANGUL SYLLABLE JJON
CAC1 HANGUL SYLLABLE JJONJ
CAC2 HANGUL SYLLABLE JJONH
CAC3 HANGUL SYLLABLE JJOD
CAC4 HANGUL SYLLABLE JJOL
CAC5 HANGUL SYLLABLE JJOLG
CAC6 HANGUL SYLLABLE JJOLM
CAC7 HANGUL SYLLABLE JJOLB
CAC8 HANGUL SYLLABLE JJOLS
CAC9 HANGUL SYLLABLE JJOLT
CACA HANGUL SYLLABLE JJOLP
CACB HANGUL SYLLABLE JJOLH
CACC HANGUL SYLLABLE JJOM
CACD HANGUL SYLLABLE JJOB
CACE HANGUL SYLLABLE JJOBS
CACF HANGUL SYLLABLE JJOS
CAD0 HANGUL SYLLABLE JJOSS
CAD1 HANGUL SYLLABLE JJONG
CAD2 HANGUL SYLLABLE JJOJ
CAD3 HANGUL SYLLABLE JJOC
CAD4 HANGUL SYLLABLE JJOK
CAD5 HANGUL SYLLABLE JJOT
CAD6 HANGUL SYLLABLE JJOP
CAD7 HANGUL SYLLABLE JJOH
CAD8 HANGUL SYLLABLE JJWA
CAD9 HANGUL SYLLABLE JJWAG
CADA HANGUL SYLLABLE JJWAGG
CADB HANGUL SYLLABLE JJWAGS
CADC HANGUL SYLLABLE JJWAN
CADD HANGUL SYLLABLE JJWANJ
CADE HANGUL SYLLABLE JJWANH
CADF HANGUL SYLLABLE JJWAD
CAE0 HANGUL SYLLABLE JJWAL
CAE1 HANGUL SYLLABLE JJWALG
CAE2 HANGUL SYLLABLE JJWALM
CAE3 HANGUL SYLLABLE JJWALB
CAE4 HANGUL SYLLABLE JJWALS
CAE5 HANGUL SYLLABLE JJWALT
CAE6 HANGUL SYLLABLE JJWALP
CAE7 HANGUL SYLLABLE JJWALH
CAE8 HANGUL SYLLABLE JJWAM
CAE9 HANGUL SYLLABLE JJWAB
CAEA HANGUL SYLLABLE JJWABS
CAEB HANGUL SYLLABLE JJWAS
CAEC HANGUL SYLLABLE JJWASS
CAED HANGUL SYLLABLE JJWANG
CAEE HANGUL SYLLABLE JJWAJ
CAEF HANGUL SYLLABLE JJWAC
CAF0 HANGUL SYLLABLE JJWAK
CAF1 HANGUL SYLLABLE JJWAT
CAF2 HANGUL SYLLABLE JJWAP
CAF3 HANGUL SYLLABLE JJWAH
CAF4 HANGUL SYLLABLE JJWAE
CAF5 HANGUL SYLLABLE JJWAEG
CAF6 HANGUL SYLLABLE JJWAEGG
CAF7 HANGUL SYLLABLE JJWAEGS
CAF8 HANGUL SYLLABLE JJWAEN
CAF9 HANGUL SYLLABLE JJWAENJ
CAFA HANGUL SYLLABLE JJWAENH
CAFB HANGUL SYLLABLE JJWAED
CAFC HANGUL SYLLABLE JJWAEL
CAFD HANGUL SYLLABLE JJWAELG
CAFE HANGUL SYLLABLE JJWAELM
CAFF HANGUL SYLLABLE JJWAELB
CB00 HANGUL SYLLABLE JJWAELS
CB01 HANGUL SYLLABLE JJWAELT
CB02 HANGUL SYLLABLE JJWAELP
CB03 HANGUL SYLLABLE JJWAELH
CB04 HANGUL SYLLABLE JJWAEM
CB05 HANGUL SYLLABLE JJWAEB
CB06 HANGUL SYLLABLE JJWAEBS
CB07 HANGUL SYLLABLE JJWAES
CB08 HANGUL SYLLABLE JJWAESS
CB09 HANGUL SYLLABLE JJWAENG
CB0A HANGUL SYLLABLE JJWAEJ
CB0B HANGUL SYLLABLE JJWAEC
CB0C HANGUL SYLLABLE JJWAEK
CB0D HANGUL SYLLABLE JJWAET
CB0E HANGUL SYLLABLE JJWAEP
CB0F HANGUL SYLLABLE JJWAEH
CB10 HANGUL SYLLABLE JJOE
CB11 HANGUL SYLLABLE JJOEG
CB12 HANGUL SYLLABLE JJOEGG
CB13 HANGUL SYLLABLE JJOEGS
CB14 HANGUL SYLLABLE JJOEN
CB15 HANGUL SYLLABLE JJOENJ
CB16 HANGUL SYLLABLE JJOENH
CB17 HANGUL SYLLABLE JJOED
CB18 HANGUL SYLLABLE JJOEL
CB19 HANGUL SYLLABLE JJOELG
CB1A HANGUL SYLLABLE JJOELM
CB1B HANGUL SYLLABLE JJOELB
CB1C HANGUL SYLLABLE JJOELS
CB1D HANGUL SYLLABLE JJOELT
CB1E HANGUL SYLLABLE JJOELP
CB1F HANGUL SYLLABLE JJOELH
CB20 HANGUL SYLLABLE JJOEM
CB21 HANGUL SYLLABLE JJOEB
CB22 HANGUL SYLLABLE JJOEBS
CB23 HANGUL SYLLABLE JJOES
CB24 HANGUL SYLLABLE JJOESS
CB25 HANGUL SYLLABLE JJOENG
CB26 HANGUL SYLLABLE JJOEJ
CB27 HANGUL SYLLABLE JJOEC
CB28 HANGUL SYLLABLE JJOEK
CB29 HANGUL SYLLABLE JJOET
CB2A HANGUL SYLLABLE JJOEP
CB2B HANGUL SYLLABLE JJOEH
CB2C HANGUL SYLLABLE JJYO
CB2D HANGUL SYLLABLE JJYOG
CB2E HANGUL SYLLABLE JJYOGG
CB2F HANGUL SYLLABLE JJYOGS
CB30 HANGUL SYLLABLE JJYON
CB31 HANGUL SYLLABLE JJYONJ
CB32 HANGUL SYLLABLE JJYONH
CB33 HANGUL SYLLABLE JJYOD
CB34 HANGUL SYLLABLE JJYOL
CB35 HANGUL SYLLABLE JJYOLG
CB36 HANGUL SYLLABLE JJYOLM
CB37 HANGUL SYLLABLE JJYOLB
CB38 HANGUL SYLLABLE JJYOLS
CB39 HANGUL SYLLABLE JJYOLT
CB3A HANGUL SYLLABLE JJYOLP
CB3B HANGUL SYLLABLE JJYOLH
CB3C HANGUL SYLLABLE JJYOM
CB3D HANGUL SYLLABLE JJYOB
CB3E HANGUL SYLLABLE JJYOBS
CB3F HANGUL SYLLABLE JJYOS
CB40 HANGUL SYLLABLE JJYOSS
CB41 HANGUL SYLLABLE JJYONG
CB42 HANGUL SYLLABLE JJYOJ
CB43 HANGUL SYLLABLE JJYOC
CB44 HANGUL SYLLABLE JJYOK
CB45 HANGUL SYLLABLE JJYOT
CB46 HANGUL SYLLABLE JJYOP
CB47 HANGUL SYLLABLE JJYOH
CB48 HANGUL SYLLABLE JJU
CB49 HANGUL SYLLABLE JJUG
CB4A HANGUL SYLLABLE JJUGG
CB4B HANGUL SYLLABLE JJUGS
CB4C HANGUL SYLLABLE JJUN
CB4D HANGUL SYLLABLE JJUNJ
CB4E HANGUL SYLLABLE JJUNH
CB4F HANGUL SYLLABLE JJUD
CB50 HANGUL SYLLABLE JJUL
CB51 HANGUL SYLLABLE JJULG
CB52 HANGUL SYLLABLE JJULM
CB53 HANGUL SYLLABLE JJULB
CB54 HANGUL SYLLABLE JJULS
CB55 HANGUL SYLLABLE JJULT
CB56 HANGUL SYLLABLE JJULP
CB57 HANGUL SYLLABLE JJULH
CB58 HANGUL SYLLABLE JJUM
CB59 HANGUL SYLLABLE JJUB
CB5A HANGUL SYLLABLE JJUBS
CB5B HANGUL SYLLABLE JJUS
CB5C HANGUL SYLLABLE JJUSS
CB5D HANGUL SYLLABLE JJUNG
CB5E HANGUL SYLLABLE JJUJ
CB5F HANGUL SYLLABLE JJUC
CB60 HANGUL SYLLABLE JJUK
CB61 HANGUL SYLLABLE JJUT
CB62 HANGUL SYLLABLE JJUP
CB63 HANGUL SYLLABLE JJUH
CB64 HANGUL SYLLABLE JJWEO
CB65 HANGUL SYLLABLE JJWEOG
CB66 HANGUL SYLLABLE JJWEOGG
CB67 HANGUL SYLLABLE JJWEOGS
CB68 HANGUL SYLLABLE JJWEON
CB69 HANGUL SYLLABLE JJWEONJ
CB6A HANGUL SYLLABLE JJWEONH
CB6B HANGUL SYLLABLE JJWEOD
CB6C HANGUL SYLLABLE JJWEOL
CB6D HANGUL SYLLABLE JJWEOLG
CB6E HANGUL SYLLABLE JJWEOLM
CB6F HANGUL SYLLABLE JJWEOLB
CB70 HANGUL SYLLABLE JJWEOLS
CB71 HANGUL SYLLABLE JJWEOLT
CB72 HANGUL SYLLABLE JJWEOLP
CB73 HANGUL SYLLABLE JJWEOLH
CB74 HANGUL SYLLABLE JJWEOM
CB75 HANGUL SYLLABLE JJWEOB
CB76 HANGUL SYLLABLE JJWEOBS
CB77 HANGUL SYLLABLE JJWEOS
CB78 HANGUL SYLLABLE JJWEOSS
CB79 HANGUL SYLLABLE JJWEONG
CB7A HANGUL SYLLABLE JJWEOJ
CB7B HANGUL SYLLABLE JJWEOC
CB7C HANGUL SYLLABLE JJWEOK
CB7D HANGUL SYLLABLE JJWEOT
CB7E HANGUL SYLLABLE JJWEOP
CB7F HANGUL SYLLABLE JJWEOH
CB80 HANGUL SYLLABLE JJWE
CB81 HANGUL SYLLABLE JJWEG
CB82 HANGUL SYLLABLE JJWEGG
CB83 HANGUL SYLLABLE JJWEGS
CB84 HANGUL SYLLABLE JJWEN
CB85 HANGUL SYLLABLE JJWENJ
CB86 HANGUL SYLLABLE JJWENH
CB87 HANGUL SYLLABLE JJWED
CB88 HANGUL SYLLABLE JJWEL
CB89 HANGUL SYLLABLE JJWELG
CB8A HANGUL SYLLABLE JJWELM
CB8B HANGUL SYLLABLE JJWELB
CB8C HANGUL SYLLABLE JJWELS
CB8D HANGUL SYLLABLE JJWELT
CB8E HANGUL SYLLABLE JJWELP
CB8F HANGUL SYLLABLE JJWELH
CB90 HANGUL SYLLABLE JJWEM
CB91 HANGUL SYLLABLE JJWEB
CB92 HANGUL SYLLABLE JJWEBS
CB93 HANGUL SYLLABLE JJWES
CB94 HANGUL SYLLABLE JJWESS
CB95 HANGUL SYLLABLE JJWENG
CB96 HANGUL SYLLABLE JJWEJ
CB97 HANGUL SYLLABLE JJWEC
CB98 HANGUL SYLLABLE JJWEK
CB99 HANGUL SYLLABLE JJWET
CB9A HANGUL SYLLABLE JJWEP
CB9B HANGUL SYLLABLE JJWEH
CB9C HANGUL SYLLABLE JJWI
CB9D HANGUL SYLLABLE JJWIG
CB9E HANGUL SYLLABLE JJWIGG
CB9F HANGUL SYLLABLE JJWIGS
CBA0 HANGUL SYLLABLE JJWIN
CBA1 HANGUL SYLLABLE JJWINJ
CBA2 HANGUL SYLLABLE JJWINH
CBA3 HANGUL SYLLABLE JJWID
CBA4 HANGUL SYLLABLE JJWIL
CBA5 HANGUL SYLLABLE JJWILG
CBA6 HANGUL SYLLABLE JJWILM
CBA7 HANGUL SYLLABLE JJWILB
CBA8 HANGUL SYLLABLE JJWILS
CBA9 HANGUL SYLLABLE JJWILT
CBAA HANGUL SYLLABLE JJWILP
CBAB HANGUL SYLLABLE JJWILH
CBAC HANGUL SYLLABLE JJWIM
CBAD HANGUL SYLLABLE JJWIB
CBAE HANGUL SYLLABLE JJWIBS
CBAF HANGUL SYLLABLE JJWIS
CBB0 HANGUL SYLLABLE JJWISS
CBB1 HANGUL SYLLABLE JJWING
CBB2 HANGUL SYLLABLE JJWIJ
CBB3 HANGUL SYLLABLE JJWIC
CBB4 HANGUL SYLLABLE JJWIK
CBB5 HANGUL SYLLABLE JJWIT
CBB6 HANGUL SYLLABLE JJWIP
CBB7 HANGUL SYLLABLE JJWIH
CBB8 HANGUL SYLLABLE JJYU
CBB9 HANGUL SYLLABLE JJYUG
CBBA HANGUL SYLLABLE JJYUGG
CBBB HANGUL SYLLABLE JJYUGS
CBBC HANGUL SYLLABLE JJYUN
CBBD HANGUL SYLLABLE JJYUNJ
CBBE HANGUL SYLLABLE JJYUNH
CBBF HANGUL SYLLABLE JJYUD
CBC0 HANGUL SYLLABLE JJYUL
CBC1 HANGUL SYLLABLE JJYULG
CBC2 HANGUL SYLLABLE JJYULM
CBC3 HANGUL SYLLABLE JJYULB
CBC4 HANGUL SYLLABLE JJYULS
CBC5 HANGUL SYLLABLE JJYULT
CBC6 HANGUL SYLLABLE JJYULP
CBC7 HANGUL SYLLABLE JJYULH
CBC8 HANGUL SYLLABLE JJYUM
CBC9 HANGUL SYLLABLE JJYUB
CBCA HANGUL SYLLABLE JJYUBS
CBCB HANGUL SYLLABLE JJYUS
CBCC HANGUL SYLLABLE JJYUSS
CBCD HANGUL SYLLABLE JJYUNG
CBCE HANGUL SYLLABLE JJYUJ
CBCF HANGUL SYLLABLE JJYUC
CBD0 HANGUL SYLLABLE JJYUK
CBD1 HANGUL SYLLABLE JJYUT
CBD2 HANGUL SYLLABLE JJYUP
CBD3 HANGUL SYLLABLE JJYUH
CBD4 HANGUL SYLLABLE JJEU
CBD5 HANGUL SYLLABLE JJEUG
CBD6 HANGUL SYLLABLE JJEUGG
CBD7 HANGUL SYLLABLE JJEUGS
CBD8 HANGUL SYLLABLE JJEUN
CBD9 HANGUL SYLLABLE JJEUNJ
CBDA HANGUL SYLLABLE JJEUNH
CBDB HANGUL SYLLABLE JJEUD
CBDC HANGUL SYLLABLE JJEUL
CBDD HANGUL SYLLABLE JJEULG
CBDE HANGUL SYLLABLE JJEULM
CBDF HANGUL SYLLABLE JJEULB
CBE0 HANGUL SYLLABLE JJEULS
CBE1 HANGUL SYLLABLE JJEULT
CBE2 HANGUL SYLLABLE JJEULP
CBE3 HANGUL SYLLABLE JJEULH
CBE4 HANGUL SYLLABLE JJEUM
CBE5 HANGUL SYLLABLE JJEUB
CBE6 HANGUL SYLLABLE JJEUBS
CBE7 HANGUL SYLLABLE JJEUS
CBE8 HANGUL SYLLABLE JJEUSS
CBE9 HANGUL SYLLABLE JJEUNG
CBEA HANGUL SYLLABLE JJEUJ
CBEB HANGUL SYLLABLE JJEUC
CBEC HANGUL SYLLABLE JJEUK
CBED HANGUL SYLLABLE JJEUT
CBEE HANGUL SYLLABLE JJEUP
CBEF HANGUL SYLLABLE JJEUH
CBF0 HANGUL SYLLABLE JJYI
CBF1 HANGUL SYLLABLE JJYIG
CBF2 HANGUL SYLLABLE JJYIGG
CBF3 HANGUL SYLLABLE JJYIGS
CBF4 HANGUL SYLLABLE JJYIN
CBF5 HANGUL SYLLABLE JJYINJ
CBF6 HANGUL SYLLABLE JJYINH
CBF7 HANGUL SYLLABLE JJYID
CBF8 HANGUL SYLLABLE JJYIL
CBF9 HANGUL SYLLABLE JJYILG
CBFA HANGUL SYLLABLE JJYILM
CBFB HANGUL SYLLABLE JJYILB
CBFC HANGUL SYLLABLE JJYILS
CBFD HANGUL SYLLABLE JJYILT
CBFE HANGUL SYLLABLE JJYILP
CBFF HANGUL SYLLABLE JJYILH
CC00 HANGUL SYLLABLE JJYIM
CC01 HANGUL SYLLABLE JJYIB
CC02 HANGUL SYLLABLE JJYIBS
CC03 HANGUL SYLLABLE JJYIS
CC04 HANGUL SYLLABLE JJYISS
CC05 HANGUL SYLLABLE JJYING
CC06 HANGUL SYLLABLE JJYIJ
CC07 HANGUL SYLLABLE JJYIC
CC08 HANGUL SYLLABLE JJYIK
CC09 HANGUL SYLLABLE JJYIT
CC0A HANGUL SYLLABLE JJYIP
CC0B HANGUL SYLLABLE JJYIH
CC0C HANGUL SYLLABLE JJI
CC0D HANGUL SYLLABLE JJIG
CC0E HANGUL SYLLABLE JJIGG
CC0F HANGUL SYLLABLE JJIGS
CC10 HANGUL SYLLABLE JJIN
CC11 HANGUL SYLLABLE JJINJ
CC12 HANGUL SYLLABLE JJINH
CC13 HANGUL SYLLABLE JJID
CC14 HANGUL SYLLABLE JJIL
CC15 HANGUL SYLLABLE JJILG
CC16 HANGUL SYLLABLE JJILM
CC17 HANGUL SYLLABLE JJILB
CC18 HANGUL SYLLABLE JJILS
CC19 HANGUL SYLLABLE JJILT
CC1A HANGUL SYLLABLE JJILP
CC1B HANGUL SYLLABLE JJILH
CC1C HANGUL SYLLABLE JJIM
CC1D HANGUL SYLLABLE JJIB
CC1E HANGUL SYLLABLE JJIBS
CC1F HANGUL SYLLABLE JJIS
CC20 HANGUL SYLLABLE JJISS
CC21 HANGUL SYLLABLE JJING
CC22 HANGUL SYLLABLE JJIJ
CC23 HANGUL SYLLABLE JJIC
CC24 HANGUL SYLLABLE JJIK
CC25 HANGUL SYLLABLE JJIT
CC26 HANGUL SYLLABLE JJIP
CC27 HANGUL SYLLABLE JJIH
CC28 HANGUL SYLLABLE CA
CC29 HANGUL SYLLABLE CAG
CC2A HANGUL SYLLABLE CAGG
CC2B HANGUL SYLLABLE CAGS
CC2C HANGUL SYLLABLE CAN
CC2D HANGUL SYLLABLE CANJ
CC2E HANGUL SYLLABLE CANH
CC2F HANGUL SYLLABLE CAD
CC30 HANGUL SYLLABLE CAL
CC31 HANGUL SYLLABLE CALG
CC32 HANGUL SYLLABLE CALM
CC33 HANGUL SYLLABLE CALB
CC34 HANGUL SYLLABLE CALS
CC35 HANGUL SYLLABLE CALT
CC36 HANGUL SYLLABLE CALP
CC37 HANGUL SYLLABLE CALH
CC38 HANGUL SYLLABLE CAM
CC39 HANGUL SYLLABLE CAB
CC3A HANGUL SYLLABLE CABS
CC3B HANGUL SYLLABLE CAS
CC3C HANGUL SYLLABLE CASS
CC3D HANGUL SYLLABLE CANG
CC3E HANGUL SYLLABLE CAJ
CC3F HANGUL SYLLABLE CAC
CC40 HANGUL SYLLABLE CAK
CC41 HANGUL SYLLABLE CAT
CC42 HANGUL SYLLABLE CAP
CC43 HANGUL SYLLABLE CAH
CC44 HANGUL SYLLABLE CAE
CC45 HANGUL SYLLABLE CAEG
CC46 HANGUL SYLLABLE CAEGG
CC47 HANGUL SYLLABLE CAEGS
CC48 HANGUL SYLLABLE CAEN
CC49 HANGUL SYLLABLE CAENJ
CC4A HANGUL SYLLABLE CAENH
CC4B HANGUL SYLLABLE CAED
CC4C HANGUL SYLLABLE CAEL
CC4D HANGUL SYLLABLE CAELG
CC4E HANGUL SYLLABLE CAELM
CC4F HANGUL SYLLABLE CAELB
CC50 HANGUL SYLLABLE CAELS
CC51 HANGUL SYLLABLE CAELT
CC52 HANGUL SYLLABLE CAELP
CC53 HANGUL SYLLABLE CAELH
CC54 HANGUL SYLLABLE CAEM
CC55 HANGUL SYLLABLE CAEB
CC56 HANGUL SYLLABLE CAEBS
CC57 HANGUL SYLLABLE CAES
CC58 HANGUL SYLLABLE CAESS
CC59 HANGUL SYLLABLE CAENG
CC5A HANGUL SYLLABLE CAEJ
CC5B HANGUL SYLLABLE CAEC
CC5C HANGUL SYLLABLE CAEK
CC5D HANGUL SYLLABLE CAET
CC5E HANGUL SYLLABLE CAEP
CC5F HANGUL SYLLABLE CAEH
CC60 HANGUL SYLLABLE CYA
CC61 HANGUL SYLLABLE CYAG
CC62 HANGUL SYLLABLE CYAGG
CC63 HANGUL SYLLABLE CYAGS
CC64 HANGUL SYLLABLE CYAN
CC65 HANGUL SYLLABLE CYANJ
CC66 HANGUL SYLLABLE CYANH
CC67 HANGUL SYLLABLE CYAD
CC68 HANGUL SYLLABLE CYAL
CC69 HANGUL SYLLABLE CYALG
CC6A HANGUL SYLLABLE CYALM
CC6B HANGUL SYLLABLE CYALB
CC6C HANGUL SYLLABLE CYALS
CC6D HANGUL SYLLABLE CYALT
CC6E HANGUL SYLLABLE CYALP
CC6F HANGUL SYLLABLE CYALH
CC70 HANGUL SYLLABLE CYAM
CC71 HANGUL SYLLABLE CYAB
CC72 HANGUL SYLLABLE CYABS
CC73 HANGUL SYLLABLE CYAS
CC74 HANGUL SYLLABLE CYASS
CC75 HANGUL SYLLABLE CYANG
CC76 HANGUL SYLLABLE CYAJ
CC77 HANGUL SYLLABLE CYAC
CC78 HANGUL SYLLABLE CYAK
CC79 HANGUL SYLLABLE CYAT
CC7A HANGUL SYLLABLE CYAP
CC7B HANGUL SYLLABLE CYAH
CC7C HANGUL SYLLABLE CYAE
CC7D HANGUL SYLLABLE CYAEG
CC7E HANGUL SYLLABLE CYAEGG
CC7F HANGUL SYLLABLE CYAEGS
CC80 HANGUL SYLLABLE CYAEN
CC81 HANGUL SYLLABLE CYAENJ
CC82 HANGUL SYLLABLE CYAENH
CC83 HANGUL SYLLABLE CYAED
CC84 HANGUL SYLLABLE CYAEL
CC85 HANGUL SYLLABLE CYAELG
CC86 HANGUL SYLLABLE CYAELM
CC87 HANGUL SYLLABLE CYAELB
CC88 HANGUL SYLLABLE CYAELS
CC89 HANGUL SYLLABLE CYAELT
CC8A HANGUL SYLLABLE CYAELP
CC8B HANGUL SYLLABLE CYAELH
CC8C HANGUL SYLLABLE CYAEM
CC8D HANGUL SYLLABLE CYAEB
CC8E HANGUL SYLLABLE CYAEBS
CC8F HANGUL SYLLABLE CYAES
CC90 HANGUL SYLLABLE CYAESS
CC91 HANGUL SYLLABLE CYAENG
CC92 HANGUL SYLLABLE CYAEJ
CC93 HANGUL SYLLABLE CYAEC
CC94 HANGUL SYLLABLE CYAEK
CC95 HANGUL SYLLABLE CYAET
CC96 HANGUL SYLLABLE CYAEP
CC97 HANGUL SYLLABLE CYAEH
CC98 HANGUL SYLLABLE CEO
CC99 HANGUL SYLLABLE CEOG
CC9A HANGUL SYLLABLE CEOGG
CC9B HANGUL SYLLABLE CEOGS
CC9C HANGUL SYLLABLE CEON
CC9D HANGUL SYLLABLE CEONJ
CC9E HANGUL SYLLABLE CEONH
CC9F HANGUL SYLLABLE CEOD
CCA0 HANGUL SYLLABLE CEOL
CCA1 HANGUL SYLLABLE CEOLG
CCA2 HANGUL SYLLABLE CEOLM
CCA3 HANGUL SYLLABLE CEOLB
CCA4 HANGUL SYLLABLE CEOLS
CCA5 HANGUL SYLLABLE CEOLT
CCA6 HANGUL SYLLABLE CEOLP
CCA7 HANGUL SYLLABLE CEOLH
CCA8 HANGUL SYLLABLE CEOM
CCA9 HANGUL SYLLABLE CEOB
CCAA HANGUL SYLLABLE CEOBS
CCAB HANGUL SYLLABLE CEOS
CCAC HANGUL SYLLABLE CEOSS
CCAD HANGUL SYLLABLE CEONG
CCAE HANGUL SYLLABLE CEOJ
CCAF HANGUL SYLLABLE CEOC
CCB0 HANGUL SYLLABLE CEOK
CCB1 HANGUL SYLLABLE CEOT
CCB2 HANGUL SYLLABLE CEOP
CCB3 HANGUL SYLLABLE CEOH
CCB4 HANGUL SYLLABLE CE
CCB5 HANGUL SYLLABLE CEG
CCB6 HANGUL SYLLABLE CEGG
CCB7 HANGUL SYLLABLE CEGS
CCB8 HANGUL SYLLABLE CEN
CCB9 HANGUL SYLLABLE CENJ
CCBA HANGUL SYLLABLE CENH
CCBB HANGUL SYLLABLE CED
CCBC HANGUL SYLLABLE CEL
CCBD HANGUL SYLLABLE CELG
CCBE HANGUL SYLLABLE CELM
CCBF HANGUL SYLLABLE CELB
CCC0 HANGUL SYLLABLE CELS
CCC1 HANGUL SYLLABLE CELT
CCC2 HANGUL SYLLABLE CELP
CCC3 HANGUL SYLLABLE CELH
CCC4 HANGUL SYLLABLE CEM
CCC5 HANGUL SYLLABLE CEB
CCC6 HANGUL SYLLABLE CEBS
CCC7 HANGUL SYLLABLE CES
CCC8 HANGUL SYLLABLE CESS
CCC9 HANGUL SYLLABLE CENG
CCCA HANGUL SYLLABLE CEJ
CCCB HANGUL SYLLABLE CEC
CCCC HANGUL SYLLABLE CEK
CCCD HANGUL SYLLABLE CET
CCCE HANGUL SYLLABLE CEP
CCCF HANGUL SYLLABLE CEH
CCD0 HANGUL SYLLABLE CYEO
CCD1 HANGUL SYLLABLE CYEOG
CCD2 HANGUL SYLLABLE CYEOGG
CCD3 HANGUL SYLLABLE CYEOGS
CCD4 HANGUL SYLLABLE CYEON
CCD5 HANGUL SYLLABLE CYEONJ
CCD6 HANGUL SYLLABLE CYEONH
CCD7 HANGUL SYLLABLE CYEOD
CCD8 HANGUL SYLLABLE CYEOL
CCD9 HANGUL SYLLABLE CYEOLG
CCDA HANGUL SYLLABLE CYEOLM
CCDB HANGUL SYLLABLE CYEOLB
CCDC HANGUL SYLLABLE CYEOLS
CCDD HANGUL SYLLABLE CYEOLT
CCDE HANGUL SYLLABLE CYEOLP
CCDF HANGUL SYLLABLE CYEOLH
CCE0 HANGUL SYLLABLE CYEOM
CCE1 HANGUL SYLLABLE CYEOB
CCE2 HANGUL SYLLABLE CYEOBS
CCE3 HANGUL SYLLABLE CYEOS
CCE4 HANGUL SYLLABLE CYEOSS
CCE5 HANGUL SYLLABLE CYEONG
CCE6 HANGUL SYLLABLE CYEOJ
CCE7 HANGUL SYLLABLE CYEOC
CCE8 HANGUL SYLLABLE CYEOK
CCE9 HANGUL SYLLABLE CYEOT
CCEA HANGUL SYLLABLE CYEOP
CCEB HANGUL SYLLABLE CYEOH
CCEC HANGUL SYLLABLE CYE
CCED HANGUL SYLLABLE CYEG
CCEE HANGUL SYLLABLE CYEGG
CCEF HANGUL SYLLABLE CYEGS
CCF0 HANGUL SYLLABLE CYEN
CCF1 HANGUL SYLLABLE CYENJ
CCF2 HANGUL SYLLABLE CYENH
CCF3 HANGUL SYLLABLE CYED
CCF4 HANGUL SYLLABLE CYEL
CCF5 HANGUL SYLLABLE CYELG
CCF6 HANGUL SYLLABLE CYELM
CCF7 HANGUL SYLLABLE CYELB
CCF8 HANGUL SYLLABLE CYELS
CCF9 HANGUL SYLLABLE CYELT
CCFA HANGUL SYLLABLE CYELP
CCFB HANGUL SYLLABLE CYELH
CCFC HANGUL SYLLABLE CYEM
CCFD HANGUL SYLLABLE CYEB
CCFE HANGUL SYLLABLE CYEBS
CCFF HANGUL SYLLABLE CYES
CD00 HANGUL SYLLABLE CYESS
CD01 HANGUL SYLLABLE CYENG
CD02 HANGUL SYLLABLE CYEJ
CD03 HANGUL SYLLABLE CYEC
CD04 HANGUL SYLLABLE CYEK
CD05 HANGUL SYLLABLE CYET
CD06 HANGUL SYLLABLE CYEP
CD07 HANGUL SYLLABLE CYEH
CD08 HANGUL SYLLABLE CO
CD09 HANGUL SYLLABLE COG
CD0A HANGUL SYLLABLE COGG
CD0B HANGUL SYLLABLE COGS
CD0C HANGUL SYLLABLE CON
CD0D HANGUL SYLLABLE CONJ
CD0E HANGUL SYLLABLE CONH
CD0F HANGUL SYLLABLE COD
CD10 HANGUL SYLLABLE COL
CD11 HANGUL SYLLABLE COLG
CD12 HANGUL SYLLABLE COLM
CD13 HANGUL SYLLABLE COLB
CD14 HANGUL SYLLABLE COLS
CD15 HANGUL SYLLABLE COLT
CD16 HANGUL SYLLABLE COLP
CD17 HANGUL SYLLABLE COLH
CD18 HANGUL SYLLABLE COM
CD19 HANGUL SYLLABLE COB
CD1A HANGUL SYLLABLE COBS
CD1B HANGUL SYLLABLE COS
CD1C HANGUL SYLLABLE COSS
CD1D HANGUL SYLLABLE CONG
CD1E HANGUL SYLLABLE COJ
CD1F HANGUL SYLLABLE COC
CD20 HANGUL SYLLABLE COK
CD21 HANGUL SYLLABLE COT
CD22 HANGUL SYLLABLE COP
CD23 HANGUL SYLLABLE COH
CD24 HANGUL SYLLABLE CWA
CD25 HANGUL SYLLABLE CWAG
CD26 HANGUL SYLLABLE CWAGG
CD27 HANGUL SYLLABLE CWAGS
CD28 HANGUL SYLLABLE CWAN
CD29 HANGUL SYLLABLE CWANJ
CD2A HANGUL SYLLABLE CWANH
CD2B HANGUL SYLLABLE CWAD
CD2C HANGUL SYLLABLE CWAL
CD2D HANGUL SYLLABLE CWALG
CD2E HANGUL SYLLABLE CWALM
CD2F HANGUL SYLLABLE CWALB
CD30 HANGUL SYLLABLE CWALS
CD31 HANGUL SYLLABLE CWALT
CD32 HANGUL SYLLABLE CWALP
CD33 HANGUL SYLLABLE CWALH
CD34 HANGUL SYLLABLE CWAM
CD35 HANGUL SYLLABLE CWAB
CD36 HANGUL SYLLABLE CWABS
CD37 HANGUL SYLLABLE CWAS
CD38 HANGUL SYLLABLE CWASS
CD39 HANGUL SYLLABLE CWANG
CD3A HANGUL SYLLABLE CWAJ
CD3B HANGUL SYLLABLE CWAC
CD3C HANGUL SYLLABLE CWAK
CD3D HANGUL SYLLABLE CWAT
CD3E HANGUL SYLLABLE CWAP
CD3F HANGUL SYLLABLE CWAH
CD40 HANGUL SYLLABLE CWAE
CD41 HANGUL SYLLABLE CWAEG
CD42 HANGUL SYLLABLE CWAEGG
CD43 HANGUL SYLLABLE CWAEGS
CD44 HANGUL SYLLABLE CWAEN
CD45 HANGUL SYLLABLE CWAENJ
CD46 HANGUL SYLLABLE CWAENH
CD47 HANGUL SYLLABLE CWAED
CD48 HANGUL SYLLABLE CWAEL
CD49 HANGUL SYLLABLE CWAELG
CD4A HANGUL SYLLABLE CWAELM
CD4B HANGUL SYLLABLE CWAELB
CD4C HANGUL SYLLABLE CWAELS
CD4D HANGUL SYLLABLE CWAELT
CD4E HANGUL SYLLABLE CWAELP
CD4F HANGUL SYLLABLE CWAELH
CD50 HANGUL SYLLABLE CWAEM
CD51 HANGUL SYLLABLE CWAEB
CD52 HANGUL SYLLABLE CWAEBS
CD53 HANGUL SYLLABLE CWAES
CD54 HANGUL SYLLABLE CWAESS
CD55 HANGUL SYLLABLE CWAENG
CD56 HANGUL SYLLABLE CWAEJ
CD57 HANGUL SYLLABLE CWAEC
CD58 HANGUL SYLLABLE CWAEK
CD59 HANGUL SYLLABLE CWAET
CD5A HANGUL SYLLABLE CWAEP
CD5B HANGUL SYLLABLE CWAEH
CD5C HANGUL SYLLABLE COE
CD5D HANGUL SYLLABLE COEG
CD5E HANGUL SYLLABLE COEGG
CD5F HANGUL SYLLABLE COEGS
CD60 HANGUL SYLLABLE COEN
CD61 HANGUL SYLLABLE COENJ
CD62 HANGUL SYLLABLE COENH
CD63 HANGUL SYLLABLE COED
CD64 HANGUL SYLLABLE COEL
CD65 HANGUL SYLLABLE COELG
CD66 HANGUL SYLLABLE COELM
CD67 HANGUL SYLLABLE COELB
CD68 HANGUL SYLLABLE COELS
CD69 HANGUL SYLLABLE COELT
CD6A HANGUL SYLLABLE COELP
CD6B HANGUL SYLLABLE COELH
CD6C HANGUL SYLLABLE COEM
CD6D HANGUL SYLLABLE COEB
CD6E HANGUL SYLLABLE COEBS
CD6F HANGUL SYLLABLE COES
CD70 HANGUL SYLLABLE COESS
CD71 HANGUL SYLLABLE COENG
CD72 HANGUL SYLLABLE COEJ
CD73 HANGUL SYLLABLE COEC
CD74 HANGUL SYLLABLE COEK
CD75 HANGUL SYLLABLE COET
CD76 HANGUL SYLLABLE COEP
CD77 HANGUL SYLLABLE COEH
CD78 HANGUL SYLLABLE CYO
CD79 HANGUL SYLLABLE CYOG
CD7A HANGUL SYLLABLE CYOGG
CD7B HANGUL SYLLABLE CYOGS
CD7C HANGUL SYLLABLE CYON
CD7D HANGUL SYLLABLE CYONJ
CD7E HANGUL SYLLABLE CYONH
CD7F HANGUL SYLLABLE CYOD
CD80 HANGUL SYLLABLE CYOL
CD81 HANGUL SYLLABLE CYOLG
CD82 HANGUL SYLLABLE CYOLM
CD83 HANGUL SYLLABLE CYOLB
CD84 HANGUL SYLLABLE CYOLS
CD85 HANGUL SYLLABLE CYOLT
CD86 HANGUL SYLLABLE CYOLP
CD87 HANGUL SYLLABLE CYOLH
CD88 HANGUL SYLLABLE CYOM
CD89 HANGUL SYLLABLE CYOB
CD8A HANGUL SYLLABLE CYOBS
CD8B HANGUL SYLLABLE CYOS
CD8C HANGUL SYLLABLE CYOSS
CD8D HANGUL SYLLABLE CYONG
CD8E HANGUL SYLLABLE CYOJ
CD8F HANGUL SYLLABLE CYOC
CD90 HANGUL SYLLABLE CYOK
CD91 HANGUL SYLLABLE CYOT
CD92 HANGUL SYLLABLE CYOP
CD93 HANGUL SYLLABLE CYOH
CD94 HANGUL SYLLABLE CU
CD95 HANGUL SYLLABLE CUG
CD96 HANGUL SYLLABLE CUGG
CD97 HANGUL SYLLABLE CUGS
CD98 HANGUL SYLLABLE CUN
CD99 HANGUL SYLLABLE CUNJ
CD9A HANGUL SYLLABLE CUNH
CD9B HANGUL SYLLABLE CUD
CD9C HANGUL SYLLABLE CUL
CD9D HANGUL SYLLABLE CULG
CD9E HANGUL SYLLABLE CULM
CD9F HANGUL SYLLABLE CULB
CDA0 HANGUL SYLLABLE CULS
CDA1 HANGUL SYLLABLE CULT
CDA2 HANGUL SYLLABLE CULP
CDA3 HANGUL SYLLABLE CULH
CDA4 HANGUL SYLLABLE CUM
CDA5 HANGUL SYLLABLE CUB
CDA6 HANGUL SYLLABLE CUBS
CDA7 HANGUL SYLLABLE CUS
CDA8 HANGUL SYLLABLE CUSS
CDA9 HANGUL SYLLABLE CUNG
CDAA HANGUL SYLLABLE CUJ
CDAB HANGUL SYLLABLE CUC
CDAC HANGUL SYLLABLE CUK
CDAD HANGUL SYLLABLE CUT
CDAE HANGUL SYLLABLE CUP
CDAF HANGUL SYLLABLE CUH
CDB0 HANGUL SYLLABLE CWEO
CDB1 HANGUL SYLLABLE CWEOG
CDB2 HANGUL SYLLABLE CWEOGG
CDB3 HANGUL SYLLABLE CWEOGS
CDB4 HANGUL SYLLABLE CWEON
CDB5 HANGUL SYLLABLE CWEONJ
CDB6 HANGUL SYLLABLE CWEONH
CDB7 HANGUL SYLLABLE CWEOD
CDB8 HANGUL SYLLABLE CWEOL
CDB9 HANGUL SYLLABLE CWEOLG
CDBA HANGUL SYLLABLE CWEOLM
CDBB HANGUL SYLLABLE CWEOLB
CDBC HANGUL SYLLABLE CWEOLS
CDBD HANGUL SYLLABLE CWEOLT
CDBE HANGUL SYLLABLE CWEOLP
CDBF HANGUL SYLLABLE CWEOLH
CDC0 HANGUL SYLLABLE CWEOM
CDC1 HANGUL SYLLABLE CWEOB
CDC2 HANGUL SYLLABLE CWEOBS
CDC3 HANGUL SYLLABLE CWEOS
CDC4 HANGUL SYLLABLE CWEOSS
CDC5 HANGUL SYLLABLE CWEONG
CDC6 HANGUL SYLLABLE CWEOJ
CDC7 HANGUL SYLLABLE CWEOC
CDC8 HANGUL SYLLABLE CWEOK
CDC9 HANGUL SYLLABLE CWEOT
CDCA HANGUL SYLLABLE CWEOP
CDCB HANGUL SYLLABLE CWEOH
CDCC HANGUL SYLLABLE CWE
CDCD HANGUL SYLLABLE CWEG
CDCE HANGUL SYLLABLE CWEGG
CDCF HANGUL SYLLABLE CWEGS
CDD0 HANGUL SYLLABLE CWEN
CDD1 HANGUL SYLLABLE CWENJ
CDD2 HANGUL SYLLABLE CWENH
CDD3 HANGUL SYLLABLE CWED
CDD4 HANGUL SYLLABLE CWEL
CDD5 HANGUL SYLLABLE CWELG
CDD6 HANGUL SYLLABLE CWELM
CDD7 HANGUL SYLLABLE CWELB
CDD8 HANGUL SYLLABLE CWELS
CDD9 HANGUL SYLLABLE CWELT
CDDA HANGUL SYLLABLE CWELP
CDDB HANGUL SYLLABLE CWELH
CDDC HANGUL SYLLABLE CWEM
CDDD HANGUL SYLLABLE CWEB
CDDE HANGUL SYLLABLE CWEBS
CDDF HANGUL SYLLABLE CWES
CDE0 HANGUL SYLLABLE CWESS
CDE1 HANGUL SYLLABLE CWENG
CDE2 HANGUL SYLLABLE CWEJ
CDE3 HANGUL SYLLABLE CWEC
CDE4 HANGUL SYLLABLE CWEK
CDE5 HANGUL SYLLABLE CWET
CDE6 HANGUL SYLLABLE CWEP
CDE7 HANGUL SYLLABLE CWEH
CDE8 HANGUL SYLLABLE CWI
CDE9 HANGUL SYLLABLE CWIG
CDEA HANGUL SYLLABLE CWIGG
CDEB HANGUL SYLLABLE CWIGS
CDEC HANGUL SYLLABLE CWIN
CDED HANGUL SYLLABLE CWINJ
CDEE HANGUL SYLLABLE CWINH
CDEF HANGUL SYLLABLE CWID
CDF0 HANGUL SYLLABLE CWIL
CDF1 HANGUL SYLLABLE CWILG
CDF2 HANGUL SYLLABLE CWILM
CDF3 HANGUL SYLLABLE CWILB
CDF4 HANGUL SYLLABLE CWILS
CDF5 HANGUL SYLLABLE CWILT
CDF6 HANGUL SYLLABLE CWILP
CDF7 HANGUL SYLLABLE CWILH
CDF8 HANGUL SYLLABLE CWIM
CDF9 HANGUL SYLLABLE CWIB
CDFA HANGUL SYLLABLE CWIBS
CDFB HANGUL SYLLABLE CWIS
CDFC HANGUL SYLLABLE CWISS
CDFD HANGUL SYLLABLE CWING
CDFE HANGUL SYLLABLE CWIJ
CDFF HANGUL SYLLABLE CWIC
CE00 HANGUL SYLLABLE CWIK
CE01 HANGUL SYLLABLE CWIT
CE02 HANGUL SYLLABLE CWIP
CE03 HANGUL SYLLABLE CWIH
CE04 HANGUL SYLLABLE CYU
CE05 HANGUL SYLLABLE CYUG
CE06 HANGUL SYLLABLE CYUGG
CE07 HANGUL SYLLABLE CYUGS
CE08 HANGUL SYLLABLE CYUN
CE09 HANGUL SYLLABLE CYUNJ
CE0A HANGUL SYLLABLE CYUNH
CE0B HANGUL SYLLABLE CYUD
CE0C HANGUL SYLLABLE CYUL
CE0D HANGUL SYLLABLE CYULG
CE0E HANGUL SYLLABLE CYULM
CE0F HANGUL SYLLABLE CYULB
CE10 HANGUL SYLLABLE CYULS
CE11 HANGUL SYLLABLE CYULT
CE12 HANGUL SYLLABLE CYULP
CE13 HANGUL SYLLABLE CYULH
CE14 HANGUL SYLLABLE CYUM
CE15 HANGUL SYLLABLE CYUB
CE16 HANGUL SYLLABLE CYUBS
CE17 HANGUL SYLLABLE CYUS
CE18 HANGUL SYLLABLE CYUSS
CE19 HANGUL SYLLABLE CYUNG
CE1A HANGUL SYLLABLE CYUJ
CE1B HANGUL SYLLABLE CYUC
CE1C HANGUL SYLLABLE CYUK
CE1D HANGUL SYLLABLE CYUT
CE1E HANGUL SYLLABLE CYUP
CE1F HANGUL SYLLABLE CYUH
CE20 HANGUL SYLLABLE CEU
CE21 HANGUL SYLLABLE CEUG
CE22 HANGUL SYLLABLE CEUGG
CE23 HANGUL SYLLABLE CEUGS
CE24 HANGUL SYLLABLE CEUN
CE25 HANGUL SYLLABLE CEUNJ
CE26 HANGUL SYLLABLE CEUNH
CE27 HANGUL SYLLABLE CEUD
CE28 HANGUL SYLLABLE CEUL
CE29 HANGUL SYLLABLE CEULG
CE2A HANGUL SYLLABLE CEULM
CE2B HANGUL SYLLABLE CEULB
CE2C HANGUL SYLLABLE CEULS
CE2D HANGUL SYLLABLE CEULT
CE2E HANGUL SYLLABLE CEULP
CE2F HANGUL SYLLABLE CEULH
CE30 HANGUL SYLLABLE CEUM
CE31 HANGUL SYLLABLE CEUB
CE32 HANGUL SYLLABLE CEUBS
CE33 HANGUL SYLLABLE CEUS
CE34 HANGUL SYLLABLE CEUSS
CE35 HANGUL SYLLABLE CEUNG
CE36 HANGUL SYLLABLE CEUJ
CE37 HANGUL SYLLABLE CEUC
CE38 HANGUL SYLLABLE CEUK
CE39 HANGUL SYLLABLE CEUT
CE3A HANGUL SYLLABLE CEUP
CE3B HANGUL SYLLABLE CEUH
CE3C HANGUL SYLLABLE CYI
CE3D HANGUL SYLLABLE CYIG
CE3E HANGUL SYLLABLE CYIGG
CE3F HANGUL SYLLABLE CYIGS
CE40 HANGUL SYLLABLE CYIN
CE41 HANGUL SYLLABLE CYINJ
CE42 HANGUL SYLLABLE CYINH
CE43 HANGUL SYLLABLE CYID
CE44 HANGUL SYLLABLE CYIL
CE45 HANGUL SYLLABLE CYILG
CE46 HANGUL SYLLABLE CYILM
CE47 HANGUL SYLLABLE CYILB
CE48 HANGUL SYLLABLE CYILS
CE49 HANGUL SYLLABLE CYILT
CE4A HANGUL SYLLABLE CYILP
CE4B HANGUL SYLLABLE CYILH
CE4C HANGUL SYLLABLE CYIM
CE4D HANGUL SYLLABLE CYIB
CE4E HANGUL SYLLABLE CYIBS
CE4F HANGUL SYLLABLE CYIS
CE50 HANGUL SYLLABLE CYISS
CE51 HANGUL SYLLABLE CYING
CE52 HANGUL SYLLABLE CYIJ
CE53 HANGUL SYLLABLE CYIC
CE54 HANGUL SYLLABLE CYIK
CE55 HANGUL SYLLABLE CYIT
CE56 HANGUL SYLLABLE CYIP
CE57 HANGUL SYLLABLE CYIH
CE58 HANGUL SYLLABLE CI
CE59 HANGUL SYLLABLE CIG
CE5A HANGUL SYLLABLE CIGG
CE5B HANGUL SYLLABLE CIGS
CE5C HANGUL SYLLABLE CIN
CE5D HANGUL SYLLABLE CINJ
CE5E HANGUL SYLLABLE CINH
CE5F HANGUL SYLLABLE CID
CE60 HANGUL SYLLABLE CIL
CE61 HANGUL SYLLABLE CILG
CE62 HANGUL SYLLABLE CILM
CE63 HANGUL SYLLABLE CILB
CE64 HANGUL SYLLABLE CILS
CE65 HANGUL SYLLABLE CILT
CE66 HANGUL SYLLABLE CILP
CE67 HANGUL SYLLABLE CILH
CE68 HANGUL SYLLABLE CIM
CE69 HANGUL SYLLABLE CIB
CE6A HANGUL SYLLABLE CIBS
CE6B HANGUL SYLLABLE CIS
CE6C HANGUL SYLLABLE CISS
CE6D HANGUL SYLLABLE CING
CE6E HANGUL SYLLABLE CIJ
CE6F HANGUL SYLLABLE CIC
CE70 HANGUL SYLLABLE CIK
CE71 HANGUL SYLLABLE CIT
CE72 HANGUL SYLLABLE CIP
CE73 HANGUL SYLLABLE CIH
CE74 HANGUL SYLLABLE KA
CE75 HANGUL SYLLABLE KAG
CE76 HANGUL SYLLABLE KAGG
CE77 HANGUL SYLLABLE KAGS
CE78 HANGUL SYLLABLE KAN
CE79 HANGUL SYLLABLE KANJ
CE7A HANGUL SYLLABLE KANH
CE7B HANGUL SYLLABLE KAD
CE7C HANGUL SYLLABLE KAL
CE7D HANGUL SYLLABLE KALG
CE7E HANGUL SYLLABLE KALM
CE7F HANGUL SYLLABLE KALB
CE80 HANGUL SYLLABLE KALS
CE81 HANGUL SYLLABLE KALT
CE82 HANGUL SYLLABLE KALP
CE83 HANGUL SYLLABLE KALH
CE84 HANGUL SYLLABLE KAM
CE85 HANGUL SYLLABLE KAB
CE86 HANGUL SYLLABLE KABS
CE87 HANGUL SYLLABLE KAS
CE88 HANGUL SYLLABLE KASS
CE89 HANGUL SYLLABLE KANG
CE8A HANGUL SYLLABLE KAJ
CE8B HANGUL SYLLABLE KAC
CE8C HANGUL SYLLABLE KAK
CE8D HANGUL SYLLABLE KAT
CE8E HANGUL SYLLABLE KAP
CE8F HANGUL SYLLABLE KAH
CE90 HANGUL SYLLABLE KAE
CE91 HANGUL SYLLABLE KAEG
CE92 HANGUL SYLLABLE KAEGG
CE93 HANGUL SYLLABLE KAEGS
CE94 HANGUL SYLLABLE KAEN
CE95 HANGUL SYLLABLE KAENJ
CE96 HANGUL SYLLABLE KAENH
CE97 HANGUL SYLLABLE KAED
CE98 HANGUL SYLLABLE KAEL
CE99 HANGUL SYLLABLE KAELG
CE9A HANGUL SYLLABLE KAELM
CE9B HANGUL SYLLABLE KAELB
CE9C HANGUL SYLLABLE KAELS
CE9D HANGUL SYLLABLE KAELT
CE9E HANGUL SYLLABLE KAELP
CE9F HANGUL SYLLABLE KAELH
CEA0 HANGUL SYLLABLE KAEM
CEA1 HANGUL SYLLABLE KAEB
CEA2 HANGUL SYLLABLE KAEBS
CEA3 HANGUL SYLLABLE KAES
CEA4 HANGUL SYLLABLE KAESS
CEA5 HANGUL SYLLABLE KAENG
CEA6 HANGUL SYLLABLE KAEJ
CEA7 HANGUL SYLLABLE KAEC
CEA8 HANGUL SYLLABLE KAEK
CEA9 HANGUL SYLLABLE KAET
CEAA HANGUL SYLLABLE KAEP
CEAB HANGUL SYLLABLE KAEH
CEAC HANGUL SYLLABLE KYA
CEAD HANGUL SYLLABLE KYAG
CEAE HANGUL SYLLABLE KYAGG
CEAF HANGUL SYLLABLE KYAGS
CEB0 HANGUL SYLLABLE KYAN
CEB1 HANGUL SYLLABLE KYANJ
CEB2 HANGUL SYLLABLE KYANH
CEB3 HANGUL SYLLABLE KYAD
CEB4 HANGUL SYLLABLE KYAL
CEB5 HANGUL SYLLABLE KYALG
CEB6 HANGUL SYLLABLE KYALM
CEB7 HANGUL SYLLABLE KYALB
CEB8 HANGUL SYLLABLE KYALS
CEB9 HANGUL SYLLABLE KYALT
CEBA HANGUL SYLLABLE KYALP
CEBB HANGUL SYLLABLE KYALH
CEBC HANGUL SYLLABLE KYAM
CEBD HANGUL SYLLABLE KYAB
CEBE HANGUL SYLLABLE KYABS
CEBF HANGUL SYLLABLE KYAS
CEC0 HANGUL SYLLABLE KYASS
CEC1 HANGUL SYLLABLE KYANG
CEC2 HANGUL SYLLABLE KYAJ
CEC3 HANGUL SYLLABLE KYAC
CEC4 HANGUL SYLLABLE KYAK
CEC5 HANGUL SYLLABLE KYAT
CEC6 HANGUL SYLLABLE KYAP
CEC7 HANGUL SYLLABLE KYAH
CEC8 HANGUL SYLLABLE KYAE
CEC9 HANGUL SYLLABLE KYAEG
CECA HANGUL SYLLABLE KYAEGG
CECB HANGUL SYLLABLE KYAEGS
CECC HANGUL SYLLABLE KYAEN
CECD HANGUL SYLLABLE KYAENJ
CECE HANGUL SYLLABLE KYAENH
CECF HANGUL SYLLABLE KYAED
CED0 HANGUL SYLLABLE KYAEL
CED1 HANGUL SYLLABLE KYAELG
CED2 HANGUL SYLLABLE KYAELM
CED3 HANGUL SYLLABLE KYAELB
CED4 HANGUL SYLLABLE KYAELS
CED5 HANGUL SYLLABLE KYAELT
CED6 HANGUL SYLLABLE KYAELP
CED7 HANGUL SYLLABLE KYAELH
CED8 HANGUL SYLLABLE KYAEM
CED9 HANGUL SYLLABLE KYAEB
CEDA HANGUL SYLLABLE KYAEBS
CEDB HANGUL SYLLABLE KYAES
CEDC HANGUL SYLLABLE KYAESS
CEDD HANGUL SYLLABLE KYAENG
CEDE HANGUL SYLLABLE KYAEJ
CEDF HANGUL SYLLABLE KYAEC
CEE0 HANGUL SYLLABLE KYAEK
CEE1 HANGUL SYLLABLE KYAET
CEE2 HANGUL SYLLABLE KYAEP
CEE3 HANGUL SYLLABLE KYAEH
CEE4 HANGUL SYLLABLE KEO
CEE5 HANGUL SYLLABLE KEOG
CEE6 HANGUL SYLLABLE KEOGG
CEE7 HANGUL SYLLABLE KEOGS
CEE8 HANGUL SYLLABLE KEON
CEE9 HANGUL SYLLABLE KEONJ
CEEA HANGUL SYLLABLE KEONH
CEEB HANGUL SYLLABLE KEOD
CEEC HANGUL SYLLABLE KEOL
CEED HANGUL SYLLABLE KEOLG
CEEE HANGUL SYLLABLE KEOLM
CEEF HANGUL SYLLABLE KEOLB
CEF0 HANGUL SYLLABLE KEOLS
CEF1 HANGUL SYLLABLE KEOLT
CEF2 HANGUL SYLLABLE KEOLP
CEF3 HANGUL SYLLABLE KEOLH
CEF4 HANGUL SYLLABLE KEOM
CEF5 HANGUL SYLLABLE KEOB
CEF6 HANGUL SYLLABLE KEOBS
CEF7 HANGUL SYLLABLE KEOS
CEF8 HANGUL SYLLABLE KEOSS
CEF9 HANGUL SYLLABLE KEONG
CEFA HANGUL SYLLABLE KEOJ
CEFB HANGUL SYLLABLE KEOC
CEFC HANGUL SYLLABLE KEOK
CEFD HANGUL SYLLABLE KEOT
CEFE HANGUL SYLLABLE KEOP
CEFF HANGUL SYLLABLE KEOH
CF00 HANGUL SYLLABLE KE
CF01 HANGUL SYLLABLE KEG
CF02 HANGUL SYLLABLE KEGG
CF03 HANGUL SYLLABLE KEGS
CF04 HANGUL SYLLABLE KEN
CF05 HANGUL SYLLABLE KENJ
CF06 HANGUL SYLLABLE KENH
CF07 HANGUL SYLLABLE KED
CF08 HANGUL SYLLABLE KEL
CF09 HANGUL SYLLABLE KELG
CF0A HANGUL SYLLABLE KELM
CF0B HANGUL SYLLABLE KELB
CF0C HANGUL SYLLABLE KELS
CF0D HANGUL SYLLABLE KELT
CF0E HANGUL SYLLABLE KELP
CF0F HANGUL SYLLABLE KELH
CF10 HANGUL SYLLABLE KEM
CF11 HANGUL SYLLABLE KEB
CF12 HANGUL SYLLABLE KEBS
CF13 HANGUL SYLLABLE KES
CF14 HANGUL SYLLABLE KESS
CF15 HANGUL SYLLABLE KENG
CF16 HANGUL SYLLABLE KEJ
CF17 HANGUL SYLLABLE KEC
CF18 HANGUL SYLLABLE KEK
CF19 HANGUL SYLLABLE KET
CF1A HANGUL SYLLABLE KEP
CF1B HANGUL SYLLABLE KEH
CF1C HANGUL SYLLABLE KYEO
CF1D HANGUL SYLLABLE KYEOG
CF1E HANGUL SYLLABLE KYEOGG
CF1F HANGUL SYLLABLE KYEOGS
CF20 HANGUL SYLLABLE KYEON
CF21 HANGUL SYLLABLE KYEONJ
CF22 HANGUL SYLLABLE KYEONH
CF23 HANGUL SYLLABLE KYEOD
CF24 HANGUL SYLLABLE KYEOL
CF25 HANGUL SYLLABLE KYEOLG
CF26 HANGUL SYLLABLE KYEOLM
CF27 HANGUL SYLLABLE KYEOLB
CF28 HANGUL SYLLABLE KYEOLS
CF29 HANGUL SYLLABLE KYEOLT
CF2A HANGUL SYLLABLE KYEOLP
CF2B HANGUL SYLLABLE KYEOLH
CF2C HANGUL SYLLABLE KYEOM
CF2D HANGUL SYLLABLE KYEOB
CF2E HANGUL SYLLABLE KYEOBS
CF2F HANGUL SYLLABLE KYEOS
CF30 HANGUL SYLLABLE KYEOSS
CF31 HANGUL SYLLABLE KYEONG
CF32 HANGUL SYLLABLE KYEOJ
CF33 HANGUL SYLLABLE KYEOC
CF34 HANGUL SYLLABLE KYEOK
CF35 HANGUL SYLLABLE KYEOT
CF36 HANGUL SYLLABLE KYEOP
CF37 HANGUL SYLLABLE KYEOH
CF38 HANGUL SYLLABLE KYE
CF39 HANGUL SYLLABLE KYEG
CF3A HANGUL SYLLABLE KYEGG
CF3B HANGUL SYLLABLE KYEGS
CF3C HANGUL SYLLABLE KYEN
CF3D HANGUL SYLLABLE KYENJ
CF3E HANGUL SYLLABLE KYENH
CF3F HANGUL SYLLABLE KYED
CF40 HANGUL SYLLABLE KYEL
CF41 HANGUL SYLLABLE KYELG
CF42 HANGUL SYLLABLE KYELM
CF43 HANGUL SYLLABLE KYELB
CF44 HANGUL SYLLABLE KYELS
CF45 HANGUL SYLLABLE KYELT
CF46 HANGUL SYLLABLE KYELP
CF47 HANGUL SYLLABLE KYELH
CF48 HANGUL SYLLABLE KYEM
CF49 HANGUL SYLLABLE KYEB
CF4A HANGUL SYLLABLE KYEBS
CF4B HANGUL SYLLABLE KYES
CF4C HANGUL SYLLABLE KYESS
CF4D HANGUL SYLLABLE KYENG
CF4E HANGUL SYLLABLE KYEJ
CF4F HANGUL SYLLABLE KYEC
CF50 HANGUL SYLLABLE KYEK
CF51 HANGUL SYLLABLE KYET
CF52 HANGUL SYLLABLE KYEP
CF53 HANGUL SYLLABLE KYEH
CF54 HANGUL SYLLABLE KO
CF55 HANGUL SYLLABLE KOG
CF56 HANGUL SYLLABLE KOGG
CF57 HANGUL SYLLABLE KOGS
CF58 HANGUL SYLLABLE KON
CF59 HANGUL SYLLABLE KONJ
CF5A HANGUL SYLLABLE KONH
CF5B HANGUL SYLLABLE KOD
CF5C HANGUL SYLLABLE KOL
CF5D HANGUL SYLLABLE KOLG
CF5E HANGUL SYLLABLE KOLM
CF5F HANGUL SYLLABLE KOLB
CF60 HANGUL SYLLABLE KOLS
CF61 HANGUL SYLLABLE KOLT
CF62 HANGUL SYLLABLE KOLP
CF63 HANGUL SYLLABLE KOLH
CF64 HANGUL SYLLABLE KOM
CF65 HANGUL SYLLABLE KOB
CF66 HANGUL SYLLABLE KOBS
CF67 HANGUL SYLLABLE KOS
CF68 HANGUL SYLLABLE KOSS
CF69 HANGUL SYLLABLE KONG
CF6A HANGUL SYLLABLE KOJ
CF6B HANGUL SYLLABLE KOC
CF6C HANGUL SYLLABLE KOK
CF6D HANGUL SYLLABLE KOT
CF6E HANGUL SYLLABLE KOP
CF6F HANGUL SYLLABLE KOH
CF70 HANGUL SYLLABLE KWA
CF71 HANGUL SYLLABLE KWAG
CF72 HANGUL SYLLABLE KWAGG
CF73 HANGUL SYLLABLE KWAGS
CF74 HANGUL SYLLABLE KWAN
CF75 HANGUL SYLLABLE KWANJ
CF76 HANGUL SYLLABLE KWANH
CF77 HANGUL SYLLABLE KWAD
CF78 HANGUL SYLLABLE KWAL
CF79 HANGUL SYLLABLE KWALG
CF7A HANGUL SYLLABLE KWALM
CF7B HANGUL SYLLABLE KWALB
CF7C HANGUL SYLLABLE KWALS
CF7D HANGUL SYLLABLE KWALT
CF7E HANGUL SYLLABLE KWALP
CF7F HANGUL SYLLABLE KWALH
CF80 HANGUL SYLLABLE KWAM
CF81 HANGUL SYLLABLE KWAB
CF82 HANGUL SYLLABLE KWABS
CF83 HANGUL SYLLABLE KWAS
CF84 HANGUL SYLLABLE KWASS
CF85 HANGUL SYLLABLE KWANG
CF86 HANGUL SYLLABLE KWAJ
CF87 HANGUL SYLLABLE KWAC
CF88 HANGUL SYLLABLE KWAK
CF89 HANGUL SYLLABLE KWAT
CF8A HANGUL SYLLABLE KWAP
CF8B HANGUL SYLLABLE KWAH
CF8C HANGUL SYLLABLE KWAE
CF8D HANGUL SYLLABLE KWAEG
CF8E HANGUL SYLLABLE KWAEGG
CF8F HANGUL SYLLABLE KWAEGS
CF90 HANGUL SYLLABLE KWAEN
CF91 HANGUL SYLLABLE KWAENJ
CF92 HANGUL SYLLABLE KWAENH
CF93 HANGUL SYLLABLE KWAED
CF94 HANGUL SYLLABLE KWAEL
CF95 HANGUL SYLLABLE KWAELG
CF96 HANGUL SYLLABLE KWAELM
CF97 HANGUL SYLLABLE KWAELB
CF98 HANGUL SYLLABLE KWAELS
CF99 HANGUL SYLLABLE KWAELT
CF9A HANGUL SYLLABLE KWAELP
CF9B HANGUL SYLLABLE KWAELH
CF9C HANGUL SYLLABLE KWAEM
CF9D HANGUL SYLLABLE KWAEB
CF9E HANGUL SYLLABLE KWAEBS
CF9F HANGUL SYLLABLE KWAES
CFA0 HANGUL SYLLABLE KWAESS
CFA1 HANGUL SYLLABLE KWAENG
CFA2 HANGUL SYLLABLE KWAEJ
CFA3 HANGUL SYLLABLE KWAEC
CFA4 HANGUL SYLLABLE KWAEK
CFA5 HANGUL SYLLABLE KWAET
CFA6 HANGUL SYLLABLE KWAEP
CFA7 HANGUL SYLLABLE KWAEH
CFA8 HANGUL SYLLABLE KOE
CFA9 HANGUL SYLLABLE KOEG
CFAA HANGUL SYLLABLE KOEGG
CFAB HANGUL SYLLABLE KOEGS
CFAC HANGUL SYLLABLE KOEN
CFAD HANGUL SYLLABLE KOENJ
CFAE HANGUL SYLLABLE KOENH
CFAF HANGUL SYLLABLE KOED
CFB0 HANGUL SYLLABLE KOEL
CFB1 HANGUL SYLLABLE KOELG
CFB2 HANGUL SYLLABLE KOELM
CFB3 HANGUL SYLLABLE KOELB
CFB4 HANGUL SYLLABLE KOELS
CFB5 HANGUL SYLLABLE KOELT
CFB6 HANGUL SYLLABLE KOELP
CFB7 HANGUL SYLLABLE KOELH
CFB8 HANGUL SYLLABLE KOEM
CFB9 HANGUL SYLLABLE KOEB
CFBA HANGUL SYLLABLE KOEBS
CFBB HANGUL SYLLABLE KOES
CFBC HANGUL SYLLABLE KOESS
CFBD HANGUL SYLLABLE KOENG
CFBE HANGUL SYLLABLE KOEJ
CFBF HANGUL SYLLABLE KOEC
CFC0 HANGUL SYLLABLE KOEK
CFC1 HANGUL SYLLABLE KOET
CFC2 HANGUL SYLLABLE KOEP
CFC3 HANGUL SYLLABLE KOEH
CFC4 HANGUL SYLLABLE KYO
CFC5 HANGUL SYLLABLE KYOG
CFC6 HANGUL SYLLABLE KYOGG
CFC7 HANGUL SYLLABLE KYOGS
CFC8 HANGUL SYLLABLE KYON
CFC9 HANGUL SYLLABLE KYONJ
CFCA HANGUL SYLLABLE KYONH
CFCB HANGUL SYLLABLE KYOD
CFCC HANGUL SYLLABLE KYOL
CFCD HANGUL SYLLABLE KYOLG
CFCE HANGUL SYLLABLE KYOLM
CFCF HANGUL SYLLABLE KYOLB
CFD0 HANGUL SYLLABLE KYOLS
CFD1 HANGUL SYLLABLE KYOLT
CFD2 HANGUL SYLLABLE KYOLP
CFD3 HANGUL SYLLABLE KYOLH
CFD4 HANGUL SYLLABLE KYOM
CFD5 HANGUL SYLLABLE KYOB
CFD6 HANGUL SYLLABLE KYOBS
CFD7 HANGUL SYLLABLE KYOS
CFD8 HANGUL SYLLABLE KYOSS
CFD9 HANGUL SYLLABLE KYONG
CFDA HANGUL SYLLABLE KYOJ
CFDB HANGUL SYLLABLE KYOC
CFDC HANGUL SYLLABLE KYOK
CFDD HANGUL SYLLABLE KYOT
CFDE HANGUL SYLLABLE KYOP
CFDF HANGUL SYLLABLE KYOH
CFE0 HANGUL SYLLABLE KU
CFE1 HANGUL SYLLABLE KUG
CFE2 HANGUL SYLLABLE KUGG
CFE3 HANGUL SYLLABLE KUGS
CFE4 HANGUL SYLLABLE KUN
CFE5 HANGUL SYLLABLE KUNJ
CFE6 HANGUL SYLLABLE KUNH
CFE7 HANGUL SYLLABLE KUD
CFE8 HANGUL SYLLABLE KUL
CFE9 HANGUL SYLLABLE KULG
CFEA HANGUL SYLLABLE KULM
CFEB HANGUL SYLLABLE KULB
CFEC HANGUL SYLLABLE KULS
CFED HANGUL SYLLABLE KULT
CFEE HANGUL SYLLABLE KULP
CFEF HANGUL SYLLABLE KULH
CFF0 HANGUL SYLLABLE KUM
CFF1 HANGUL SYLLABLE KUB
CFF2 HANGUL SYLLABLE KUBS
CFF3 HANGUL SYLLABLE KUS
CFF4 HANGUL SYLLABLE KUSS
CFF5 HANGUL SYLLABLE KUNG
CFF6 HANGUL SYLLABLE KUJ
CFF7 HANGUL SYLLABLE KUC
CFF8 HANGUL SYLLABLE KUK
CFF9 HANGUL SYLLABLE KUT
CFFA HANGUL SYLLABLE KUP
CFFB HANGUL SYLLABLE KUH
CFFC HANGUL SYLLABLE KWEO
CFFD HANGUL SYLLABLE KWEOG
CFFE HANGUL SYLLABLE KWEOGG
CFFF HANGUL SYLLABLE KWEOGS
D000 HANGUL SYLLABLE KWEON
D001 HANGUL SYLLABLE KWEONJ
D002 HANGUL SYLLABLE KWEONH
D003 HANGUL SYLLABLE KWEOD
D004 HANGUL SYLLABLE KWEOL
D005 HANGUL SYLLABLE KWEOLG
D006 HANGUL SYLLABLE KWEOLM
D007 HANGUL SYLLABLE KWEOLB
D008 HANGUL SYLLABLE KWEOLS
D009 HANGUL SYLLABLE KWEOLT
D00A HANGUL SYLLABLE KWEOLP
D00B HANGUL SYLLABLE KWEOLH
D00C HANGUL SYLLABLE KWEOM
D00D HANGUL SYLLABLE KWEOB
D00E HANGUL SYLLABLE KWEOBS
D00F HANGUL SYLLABLE KWEOS
D010 HANGUL SYLLABLE KWEOSS
D011 HANGUL SYLLABLE KWEONG
D012 HANGUL SYLLABLE KWEOJ
D013 HANGUL SYLLABLE KWEOC
D014 HANGUL SYLLABLE KWEOK
D015 HANGUL SYLLABLE KWEOT
D016 HANGUL SYLLABLE KWEOP
D017 HANGUL SYLLABLE KWEOH
D018 HANGUL SYLLABLE KWE
D019 HANGUL SYLLABLE KWEG
D01A HANGUL SYLLABLE KWEGG
D01B HANGUL SYLLABLE KWEGS
D01C HANGUL SYLLABLE KWEN
D01D HANGUL SYLLABLE KWENJ
D01E HANGUL SYLLABLE KWENH
D01F HANGUL SYLLABLE KWED
D020 HANGUL SYLLABLE KWEL
D021 HANGUL SYLLABLE KWELG
D022 HANGUL SYLLABLE KWELM
D023 HANGUL SYLLABLE KWELB
D024 HANGUL SYLLABLE KWELS
D025 HANGUL SYLLABLE KWELT
D026 HANGUL SYLLABLE KWELP
D027 HANGUL SYLLABLE KWELH
D028 HANGUL SYLLABLE KWEM
D029 HANGUL SYLLABLE KWEB
D02A HANGUL SYLLABLE KWEBS
D02B HANGUL SYLLABLE KWES
D02C HANGUL SYLLABLE KWESS
D02D HANGUL SYLLABLE KWENG
D02E HANGUL SYLLABLE KWEJ
D02F HANGUL SYLLABLE KWEC
D030 HANGUL SYLLABLE KWEK
D031 HANGUL SYLLABLE KWET
D032 HANGUL SYLLABLE KWEP
D033 HANGUL SYLLABLE KWEH
D034 HANGUL SYLLABLE KWI
D035 HANGUL SYLLABLE KWIG
D036 HANGUL SYLLABLE KWIGG
D037 HANGUL SYLLABLE KWIGS
D038 HANGUL SYLLABLE KWIN
D039 HANGUL SYLLABLE KWINJ
D03A HANGUL SYLLABLE KWINH
D03B HANGUL SYLLABLE KWID
D03C HANGUL SYLLABLE KWIL
D03D HANGUL SYLLABLE KWILG
D03E HANGUL SYLLABLE KWILM
D03F HANGUL SYLLABLE KWILB
D040 HANGUL SYLLABLE KWILS
D041 HANGUL SYLLABLE KWILT
D042 HANGUL SYLLABLE KWILP
D043 HANGUL SYLLABLE KWILH
D044 HANGUL SYLLABLE KWIM
D045 HANGUL SYLLABLE KWIB
D046 HANGUL SYLLABLE KWIBS
D047 HANGUL SYLLABLE KWIS
D048 HANGUL SYLLABLE KWISS
D049 HANGUL SYLLABLE KWING
D04A HANGUL SYLLABLE KWIJ
D04B HANGUL SYLLABLE KWIC
D04C HANGUL SYLLABLE KWIK
D04D HANGUL SYLLABLE KWIT
D04E HANGUL SYLLABLE KWIP
D04F HANGUL SYLLABLE KWIH
D050 HANGUL SYLLABLE KYU
D051 HANGUL SYLLABLE KYUG
D052 HANGUL SYLLABLE KYUGG
D053 HANGUL SYLLABLE KYUGS
D054 HANGUL SYLLABLE KYUN
D055 HANGUL SYLLABLE KYUNJ
D056 HANGUL SYLLABLE KYUNH
D057 HANGUL SYLLABLE KYUD
D058 HANGUL SYLLABLE KYUL
D059 HANGUL SYLLABLE KYULG
D05A HANGUL SYLLABLE KYULM
D05B HANGUL SYLLABLE KYULB
D05C HANGUL SYLLABLE KYULS
D05D HANGUL SYLLABLE KYULT
D05E HANGUL SYLLABLE KYULP
D05F HANGUL SYLLABLE KYULH
D060 HANGUL SYLLABLE KYUM
D061 HANGUL SYLLABLE KYUB
D062 HANGUL SYLLABLE KYUBS
D063 HANGUL SYLLABLE KYUS
D064 HANGUL SYLLABLE KYUSS
D065 HANGUL SYLLABLE KYUNG
D066 HANGUL SYLLABLE KYUJ
D067 HANGUL SYLLABLE KYUC
D068 HANGUL SYLLABLE KYUK
D069 HANGUL SYLLABLE KYUT
D06A HANGUL SYLLABLE KYUP
D06B HANGUL SYLLABLE KYUH
D06C HANGUL SYLLABLE KEU
D06D HANGUL SYLLABLE KEUG
D06E HANGUL SYLLABLE KEUGG
D06F HANGUL SYLLABLE KEUGS
D070 HANGUL SYLLABLE KEUN
D071 HANGUL SYLLABLE KEUNJ
D072 HANGUL SYLLABLE KEUNH
D073 HANGUL SYLLABLE KEUD
D074 HANGUL SYLLABLE KEUL
D075 HANGUL SYLLABLE KEULG
D076 HANGUL SYLLABLE KEULM
D077 HANGUL SYLLABLE KEULB
D078 HANGUL SYLLABLE KEULS
D079 HANGUL SYLLABLE KEULT
D07A HANGUL SYLLABLE KEULP
D07B HANGUL SYLLABLE KEULH
D07C HANGUL SYLLABLE KEUM
D07D HANGUL SYLLABLE KEUB
D07E HANGUL SYLLABLE KEUBS
D07F HANGUL SYLLABLE KEUS
D080 HANGUL SYLLABLE KEUSS
D081 HANGUL SYLLABLE KEUNG
D082 HANGUL SYLLABLE KEUJ
D083 HANGUL SYLLABLE KEUC
D084 HANGUL SYLLABLE KEUK
D085 HANGUL SYLLABLE KEUT
D086 HANGUL SYLLABLE KEUP
D087 HANGUL SYLLABLE KEUH
D088 HANGUL SYLLABLE KYI
D089 HANGUL SYLLABLE KYIG
D08A HANGUL SYLLABLE KYIGG
D08B HANGUL SYLLABLE KYIGS
D08C HANGUL SYLLABLE KYIN
D08D HANGUL SYLLABLE KYINJ
D08E HANGUL SYLLABLE KYINH
D08F HANGUL SYLLABLE KYID
D090 HANGUL SYLLABLE KYIL
D091 HANGUL SYLLABLE KYILG
D092 HANGUL SYLLABLE KYILM
D093 HANGUL SYLLABLE KYILB
D094 HANGUL SYLLABLE KYILS
D095 HANGUL SYLLABLE KYILT
D096 HANGUL SYLLABLE KYILP
D097 HANGUL SYLLABLE KYILH
D098 HANGUL SYLLABLE KYIM
D099 HANGUL SYLLABLE KYIB
D09A HANGUL SYLLABLE KYIBS
D09B HANGUL SYLLABLE KYIS
D09C HANGUL SYLLABLE KYISS
D09D HANGUL SYLLABLE KYING
D09E HANGUL SYLLABLE KYIJ
D09F HANGUL SYLLABLE KYIC
D0A0 HANGUL SYLLABLE KYIK
D0A1 HANGUL SYLLABLE KYIT
D0A2 HANGUL SYLLABLE KYIP
D0A3 HANGUL SYLLABLE KYIH
D0A4 HANGUL SYLLABLE KI
D0A5 HANGUL SYLLABLE KIG
D0A6 HANGUL SYLLABLE KIGG
D0A7 HANGUL SYLLABLE KIGS
D0A8 HANGUL SYLLABLE KIN
D0A9 HANGUL SYLLABLE KINJ
D0AA HANGUL SYLLABLE KINH
D0AB HANGUL SYLLABLE KID
D0AC HANGUL SYLLABLE KIL
D0AD HANGUL SYLLABLE KILG
D0AE HANGUL SYLLABLE KILM
D0AF HANGUL SYLLABLE KILB
D0B0 HANGUL SYLLABLE KILS
D0B1 HANGUL SYLLABLE KILT
D0B2 HANGUL SYLLABLE KILP
D0B3 HANGUL SYLLABLE KILH
D0B4 HANGUL SYLLABLE KIM
D0B5 HANGUL SYLLABLE KIB
D0B6 HANGUL SYLLABLE KIBS
D0B7 HANGUL SYLLABLE KIS
D0B8 HANGUL SYLLABLE KISS
D0B9 HANGUL SYLLABLE KING
D0BA HANGUL SYLLABLE KIJ
D0BB HANGUL SYLLABLE KIC
D0BC HANGUL SYLLABLE KIK
D0BD HANGUL SYLLABLE KIT
D0BE HANGUL SYLLABLE KIP
D0BF HANGUL SYLLABLE KIH
D0C0 HANGUL SYLLABLE TA
D0C1 HANGUL SYLLABLE TAG
D0C2 HANGUL SYLLABLE TAGG
D0C3 HANGUL SYLLABLE TAGS
D0C4 HANGUL SYLLABLE TAN
D0C5 HANGUL SYLLABLE TANJ
D0C6 HANGUL SYLLABLE TANH
D0C7 HANGUL SYLLABLE TAD
D0C8 HANGUL SYLLABLE TAL
D0C9 HANGUL SYLLABLE TALG
D0CA HANGUL SYLLABLE TALM
D0CB HANGUL SYLLABLE TALB
D0CC HANGUL SYLLABLE TALS
D0CD HANGUL SYLLABLE TALT
D0CE HANGUL SYLLABLE TALP
D0CF HANGUL SYLLABLE TALH
D0D0 HANGUL SYLLABLE TAM
D0D1 HANGUL SYLLABLE TAB
D0D2 HANGUL SYLLABLE TABS
D0D3 HANGUL SYLLABLE TAS
D0D4 HANGUL SYLLABLE TASS
D0D5 HANGUL SYLLABLE TANG
D0D6 HANGUL SYLLABLE TAJ
D0D7 HANGUL SYLLABLE TAC
D0D8 HANGUL SYLLABLE TAK
D0D9 HANGUL SYLLABLE TAT
D0DA HANGUL SYLLABLE TAP
D0DB HANGUL SYLLABLE TAH
D0DC HANGUL SYLLABLE TAE
D0DD HANGUL SYLLABLE TAEG
D0DE HANGUL SYLLABLE TAEGG
D0DF HANGUL SYLLABLE TAEGS
D0E0 HANGUL SYLLABLE TAEN
D0E1 HANGUL SYLLABLE TAENJ
D0E2 HANGUL SYLLABLE TAENH
D0E3 HANGUL SYLLABLE TAED
D0E4 HANGUL SYLLABLE TAEL
D0E5 HANGUL SYLLABLE TAELG
D0E6 HANGUL SYLLABLE TAELM
D0E7 HANGUL SYLLABLE TAELB
D0E8 HANGUL SYLLABLE TAELS
D0E9 HANGUL SYLLABLE TAELT
D0EA HANGUL SYLLABLE TAELP
D0EB HANGUL SYLLABLE TAELH
D0EC HANGUL SYLLABLE TAEM
D0ED HANGUL SYLLABLE TAEB
D0EE HANGUL SYLLABLE TAEBS
D0EF HANGUL SYLLABLE TAES
D0F0 HANGUL SYLLABLE TAESS
D0F1 HANGUL SYLLABLE TAENG
D0F2 HANGUL SYLLABLE TAEJ
D0F3 HANGUL SYLLABLE TAEC
D0F4 HANGUL SYLLABLE TAEK
D0F5 HANGUL SYLLABLE TAET
D0F6 HANGUL SYLLABLE TAEP
D0F7 HANGUL SYLLABLE TAEH
D0F8 HANGUL SYLLABLE TYA
D0F9 HANGUL SYLLABLE TYAG
D0FA HANGUL SYLLABLE TYAGG
D0FB HANGUL SYLLABLE TYAGS
D0FC HANGUL SYLLABLE TYAN
D0FD HANGUL SYLLABLE TYANJ
D0FE HANGUL SYLLABLE TYANH
D0FF HANGUL SYLLABLE TYAD
D100 HANGUL SYLLABLE TYAL
D101 HANGUL SYLLABLE TYALG
D102 HANGUL SYLLABLE TYALM
D103 HANGUL SYLLABLE TYALB
D104 HANGUL SYLLABLE TYALS
D105 HANGUL SYLLABLE TYALT
D106 HANGUL SYLLABLE TYALP
D107 HANGUL SYLLABLE TYALH
D108 HANGUL SYLLABLE TYAM
D109 HANGUL SYLLABLE TYAB
D10A HANGUL SYLLABLE TYABS
D10B HANGUL SYLLABLE TYAS
D10C HANGUL SYLLABLE TYASS
D10D HANGUL SYLLABLE TYANG
D10E HANGUL SYLLABLE TYAJ
D10F HANGUL SYLLABLE TYAC
D110 HANGUL SYLLABLE TYAK
D111 HANGUL SYLLABLE TYAT
D112 HANGUL SYLLABLE TYAP
D113 HANGUL SYLLABLE TYAH
D114 HANGUL SYLLABLE TYAE
D115 HANGUL SYLLABLE TYAEG
D116 HANGUL SYLLABLE TYAEGG
D117 HANGUL SYLLABLE TYAEGS
D118 HANGUL SYLLABLE TYAEN
D119 HANGUL SYLLABLE TYAENJ
D11A HANGUL SYLLABLE TYAENH
D11B HANGUL SYLLABLE TYAED
D11C HANGUL SYLLABLE TYAEL
D11D HANGUL SYLLABLE TYAELG
D11E HANGUL SYLLABLE TYAELM
D11F HANGUL SYLLABLE TYAELB
D120 HANGUL SYLLABLE TYAELS
D121 HANGUL SYLLABLE TYAELT
D122 HANGUL SYLLABLE TYAELP
D123 HANGUL SYLLABLE TYAELH
D124 HANGUL SYLLABLE TYAEM
D125 HANGUL SYLLABLE TYAEB
D126 HANGUL SYLLABLE TYAEBS
D127 HANGUL SYLLABLE TYAES
D128 HANGUL SYLLABLE TYAESS
D129 HANGUL SYLLABLE TYAENG
D12A HANGUL SYLLABLE TYAEJ
D12B HANGUL SYLLABLE TYAEC
D12C HANGUL SYLLABLE TYAEK
D12D HANGUL SYLLABLE TYAET
D12E HANGUL SYLLABLE TYAEP
D12F HANGUL SYLLABLE TYAEH
D130 HANGUL SYLLABLE TEO
D131 HANGUL SYLLABLE TEOG
D132 HANGUL SYLLABLE TEOGG
D133 HANGUL SYLLABLE TEOGS
D134 HANGUL SYLLABLE TEON
D135 HANGUL SYLLABLE TEONJ
D136 HANGUL SYLLABLE TEONH
D137 HANGUL SYLLABLE TEOD
D138 HANGUL SYLLABLE TEOL
D139 HANGUL SYLLABLE TEOLG
D13A HANGUL SYLLABLE TEOLM
D13B HANGUL SYLLABLE TEOLB
D13C HANGUL SYLLABLE TEOLS
D13D HANGUL SYLLABLE TEOLT
D13E HANGUL SYLLABLE TEOLP
D13F HANGUL SYLLABLE TEOLH
D140 HANGUL SYLLABLE TEOM
D141 HANGUL SYLLABLE TEOB
D142 HANGUL SYLLABLE TEOBS
D143 HANGUL SYLLABLE TEOS
D144 HANGUL SYLLABLE TEOSS
D145 HANGUL SYLLABLE TEONG
D146 HANGUL SYLLABLE TEOJ
D147 HANGUL SYLLABLE TEOC
D148 HANGUL SYLLABLE TEOK
D149 HANGUL SYLLABLE TEOT
D14A HANGUL SYLLABLE TEOP
D14B HANGUL SYLLABLE TEOH
D14C HANGUL SYLLABLE TE
D14D HANGUL SYLLABLE TEG
D14E HANGUL SYLLABLE TEGG
D14F HANGUL SYLLABLE TEGS
D150 HANGUL SYLLABLE TEN
D151 HANGUL SYLLABLE TENJ
D152 HANGUL SYLLABLE TENH
D153 HANGUL SYLLABLE TED
D154 HANGUL SYLLABLE TEL
D155 HANGUL SYLLABLE TELG
D156 HANGUL SYLLABLE TELM
D157 HANGUL SYLLABLE TELB
D158 HANGUL SYLLABLE TELS
D159 HANGUL SYLLABLE TELT
D15A HANGUL SYLLABLE TELP
D15B HANGUL SYLLABLE TELH
D15C HANGUL SYLLABLE TEM
D15D HANGUL SYLLABLE TEB
D15E HANGUL SYLLABLE TEBS
D15F HANGUL SYLLABLE TES
D160 HANGUL SYLLABLE TESS
D161 HANGUL SYLLABLE TENG
D162 HANGUL SYLLABLE TEJ
D163 HANGUL SYLLABLE TEC
D164 HANGUL SYLLABLE TEK
D165 HANGUL SYLLABLE TET
D166 HANGUL SYLLABLE TEP
D167 HANGUL SYLLABLE TEH
D168 HANGUL SYLLABLE TYEO
D169 HANGUL SYLLABLE TYEOG
D16A HANGUL SYLLABLE TYEOGG
D16B HANGUL SYLLABLE TYEOGS
D16C HANGUL SYLLABLE TYEON
D16D HANGUL SYLLABLE TYEONJ
D16E HANGUL SYLLABLE TYEONH
D16F HANGUL SYLLABLE TYEOD
D170 HANGUL SYLLABLE TYEOL
D171 HANGUL SYLLABLE TYEOLG
D172 HANGUL SYLLABLE TYEOLM
D173 HANGUL SYLLABLE TYEOLB
D174 HANGUL SYLLABLE TYEOLS
D175 HANGUL SYLLABLE TYEOLT
D176 HANGUL SYLLABLE TYEOLP
D177 HANGUL SYLLABLE TYEOLH
D178 HANGUL SYLLABLE TYEOM
D179 HANGUL SYLLABLE TYEOB
D17A HANGUL SYLLABLE TYEOBS
D17B HANGUL SYLLABLE TYEOS
D17C HANGUL SYLLABLE TYEOSS
D17D HANGUL SYLLABLE TYEONG
D17E HANGUL SYLLABLE TYEOJ
D17F HANGUL SYLLABLE TYEOC
D180 HANGUL SYLLABLE TYEOK
D181 HANGUL SYLLABLE TYEOT
D182 HANGUL SYLLABLE TYEOP
D183 HANGUL SYLLABLE TYEOH
D184 HANGUL SYLLABLE TYE
D185 HANGUL SYLLABLE TYEG
D186 HANGUL SYLLABLE TYEGG
D187 HANGUL SYLLABLE TYEGS
D188 HANGUL SYLLABLE TYEN
D189 HANGUL SYLLABLE TYENJ
D18A HANGUL SYLLABLE TYENH
D18B HANGUL SYLLABLE TYED
D18C HANGUL SYLLABLE TYEL
D18D HANGUL SYLLABLE TYELG
D18E HANGUL SYLLABLE TYELM
D18F HANGUL SYLLABLE TYELB
D190 HANGUL SYLLABLE TYELS
D191 HANGUL SYLLABLE TYELT
D192 HANGUL SYLLABLE TYELP
D193 HANGUL SYLLABLE TYELH
D194 HANGUL SYLLABLE TYEM
D195 HANGUL SYLLABLE TYEB
D196 HANGUL SYLLABLE TYEBS
D197 HANGUL SYLLABLE TYES
D198 HANGUL SYLLABLE TYESS
D199 HANGUL SYLLABLE TYENG
D19A HANGUL SYLLABLE TYEJ
D19B HANGUL SYLLABLE TYEC
D19C HANGUL SYLLABLE TYEK
D19D HANGUL SYLLABLE TYET
D19E HANGUL SYLLABLE TYEP
D19F HANGUL SYLLABLE TYEH
D1A0 HANGUL SYLLABLE TO
D1A1 HANGUL SYLLABLE TOG
D1A2 HANGUL SYLLABLE TOGG
D1A3 HANGUL SYLLABLE TOGS
D1A4 HANGUL SYLLABLE TON
D1A5 HANGUL SYLLABLE TONJ
D1A6 HANGUL SYLLABLE TONH
D1A7 HANGUL SYLLABLE TOD
D1A8 HANGUL SYLLABLE TOL
D1A9 HANGUL SYLLABLE TOLG
D1AA HANGUL SYLLABLE TOLM
D1AB HANGUL SYLLABLE TOLB
D1AC HANGUL SYLLABLE TOLS
D1AD HANGUL SYLLABLE TOLT
D1AE HANGUL SYLLABLE TOLP
D1AF HANGUL SYLLABLE TOLH
D1B0 HANGUL SYLLABLE TOM
D1B1 HANGUL SYLLABLE TOB
D1B2 HANGUL SYLLABLE TOBS
D1B3 HANGUL SYLLABLE TOS
D1B4 HANGUL SYLLABLE TOSS
D1B5 HANGUL SYLLABLE TONG
D1B6 HANGUL SYLLABLE TOJ
D1B7 HANGUL SYLLABLE TOC
D1B8 HANGUL SYLLABLE TOK
D1B9 HANGUL SYLLABLE TOT
D1BA HANGUL SYLLABLE TOP
D1BB HANGUL SYLLABLE TOH
D1BC HANGUL SYLLABLE TWA
D1BD HANGUL SYLLABLE TWAG
D1BE HANGUL SYLLABLE TWAGG
D1BF HANGUL SYLLABLE TWAGS
D1C0 HANGUL SYLLABLE TWAN
D1C1 HANGUL SYLLABLE TWANJ
D1C2 HANGUL SYLLABLE TWANH
D1C3 HANGUL SYLLABLE TWAD
D1C4 HANGUL SYLLABLE TWAL
D1C5 HANGUL SYLLABLE TWALG
D1C6 HANGUL SYLLABLE TWALM
D1C7 HANGUL SYLLABLE TWALB
D1C8 HANGUL SYLLABLE TWALS
D1C9 HANGUL SYLLABLE TWALT
D1CA HANGUL SYLLABLE TWALP
D1CB HANGUL SYLLABLE TWALH
D1CC HANGUL SYLLABLE TWAM
D1CD HANGUL SYLLABLE TWAB
D1CE HANGUL SYLLABLE TWABS
D1CF HANGUL SYLLABLE TWAS
D1D0 HANGUL SYLLABLE TWASS
D1D1 HANGUL SYLLABLE TWANG
D1D2 HANGUL SYLLABLE TWAJ
D1D3 HANGUL SYLLABLE TWAC
D1D4 HANGUL SYLLABLE TWAK
D1D5 HANGUL SYLLABLE TWAT
D1D6 HANGUL SYLLABLE TWAP
D1D7 HANGUL SYLLABLE TWAH
D1D8 HANGUL SYLLABLE TWAE
D1D9 HANGUL SYLLABLE TWAEG
D1DA HANGUL SYLLABLE TWAEGG
D1DB HANGUL SYLLABLE TWAEGS
D1DC HANGUL SYLLABLE TWAEN
D1DD HANGUL SYLLABLE TWAENJ
D1DE HANGUL SYLLABLE TWAENH
D1DF HANGUL SYLLABLE TWAED
D1E0 HANGUL SYLLABLE TWAEL
D1E1 HANGUL SYLLABLE TWAELG
D1E2 HANGUL SYLLABLE TWAELM
D1E3 HANGUL SYLLABLE TWAELB
D1E4 HANGUL SYLLABLE TWAELS
D1E5 HANGUL SYLLABLE TWAELT
D1E6 HANGUL SYLLABLE TWAELP
D1E7 HANGUL SYLLABLE TWAELH
D1E8 HANGUL SYLLABLE TWAEM
D1E9 HANGUL SYLLABLE TWAEB
D1EA HANGUL SYLLABLE TWAEBS
D1EB HANGUL SYLLABLE TWAES
D1EC HANGUL SYLLABLE TWAESS
D1ED HANGUL SYLLABLE TWAENG
D1EE HANGUL SYLLABLE TWAEJ
D1EF HANGUL SYLLABLE TWAEC
D1F0 HANGUL SYLLABLE TWAEK
D1F1 HANGUL SYLLABLE TWAET
D1F2 HANGUL SYLLABLE TWAEP
D1F3 HANGUL SYLLABLE TWAEH
D1F4 HANGUL SYLLABLE TOE
D1F5 HANGUL SYLLABLE TOEG
D1F6 HANGUL SYLLABLE TOEGG
D1F7 HANGUL SYLLABLE TOEGS
D1F8 HANGUL SYLLABLE TOEN
D1F9 HANGUL SYLLABLE TOENJ
D1FA HANGUL SYLLABLE TOENH
D1FB HANGUL SYLLABLE TOED
D1FC HANGUL SYLLABLE TOEL
D1FD HANGUL SYLLABLE TOELG
D1FE HANGUL SYLLABLE TOELM
D1FF HANGUL SYLLABLE TOELB
D200 HANGUL SYLLABLE TOELS
D201 HANGUL SYLLABLE TOELT
D202 HANGUL SYLLABLE TOELP
D203 HANGUL SYLLABLE TOELH
D204 HANGUL SYLLABLE TOEM
D205 HANGUL SYLLABLE TOEB
D206 HANGUL SYLLABLE TOEBS
D207 HANGUL SYLLABLE TOES
D208 HANGUL SYLLABLE TOESS
D209 HANGUL SYLLABLE TOENG
D20A HANGUL SYLLABLE TOEJ
D20B HANGUL SYLLABLE TOEC
D20C HANGUL SYLLABLE TOEK
D20D HANGUL SYLLABLE TOET
D20E HANGUL SYLLABLE TOEP
D20F HANGUL SYLLABLE TOEH
D210 HANGUL SYLLABLE TYO
D211 HANGUL SYLLABLE TYOG
D212 HANGUL SYLLABLE TYOGG
D213 HANGUL SYLLABLE TYOGS
D214 HANGUL SYLLABLE TYON
D215 HANGUL SYLLABLE TYONJ
D216 HANGUL SYLLABLE TYONH
D217 HANGUL SYLLABLE TYOD
D218 HANGUL SYLLABLE TYOL
D219 HANGUL SYLLABLE TYOLG
D21A HANGUL SYLLABLE TYOLM
D21B HANGUL SYLLABLE TYOLB
D21C HANGUL SYLLABLE TYOLS
D21D HANGUL SYLLABLE TYOLT
D21E HANGUL SYLLABLE TYOLP
D21F HANGUL SYLLABLE TYOLH
D220 HANGUL SYLLABLE TYOM
D221 HANGUL SYLLABLE TYOB
D222 HANGUL SYLLABLE TYOBS
D223 HANGUL SYLLABLE TYOS
D224 HANGUL SYLLABLE TYOSS
D225 HANGUL SYLLABLE TYONG
D226 HANGUL SYLLABLE TYOJ
D227 HANGUL SYLLABLE TYOC
D228 HANGUL SYLLABLE TYOK
D229 HANGUL SYLLABLE TYOT
D22A HANGUL SYLLABLE TYOP
D22B HANGUL SYLLABLE TYOH
D22C HANGUL SYLLABLE TU
D22D HANGUL SYLLABLE TUG
D22E HANGUL SYLLABLE TUGG
D22F HANGUL SYLLABLE TUGS
D230 HANGUL SYLLABLE TUN
D231 HANGUL SYLLABLE TUNJ
D232 HANGUL SYLLABLE TUNH
D233 HANGUL SYLLABLE TUD
D234 HANGUL SYLLABLE TUL
D235 HANGUL SYLLABLE TULG
D236 HANGUL SYLLABLE TULM
D237 HANGUL SYLLABLE TULB
D238 HANGUL SYLLABLE TULS
D239 HANGUL SYLLABLE TULT
D23A HANGUL SYLLABLE TULP
D23B HANGUL SYLLABLE TULH
D23C HANGUL SYLLABLE TUM
D23D HANGUL SYLLABLE TUB
D23E HANGUL SYLLABLE TUBS
D23F HANGUL SYLLABLE TUS
D240 HANGUL SYLLABLE TUSS
D241 HANGUL SYLLABLE TUNG
D242 HANGUL SYLLABLE TUJ
D243 HANGUL SYLLABLE TUC
D244 HANGUL SYLLABLE TUK
D245 HANGUL SYLLABLE TUT
D246 HANGUL SYLLABLE TUP
D247 HANGUL SYLLABLE TUH
D248 HANGUL SYLLABLE TWEO
D249 HANGUL SYLLABLE TWEOG
D24A HANGUL SYLLABLE TWEOGG
D24B HANGUL SYLLABLE TWEOGS
D24C HANGUL SYLLABLE TWEON
D24D HANGUL SYLLABLE TWEONJ
D24E HANGUL SYLLABLE TWEONH
D24F HANGUL SYLLABLE TWEOD
D250 HANGUL SYLLABLE TWEOL
D251 HANGUL SYLLABLE TWEOLG
D252 HANGUL SYLLABLE TWEOLM
D253 HANGUL SYLLABLE TWEOLB
D254 HANGUL SYLLABLE TWEOLS
D255 HANGUL SYLLABLE TWEOLT
D256 HANGUL SYLLABLE TWEOLP
D257 HANGUL SYLLABLE TWEOLH
D258 HANGUL SYLLABLE TWEOM
D259 HANGUL SYLLABLE TWEOB
D25A HANGUL SYLLABLE TWEOBS
D25B HANGUL SYLLABLE TWEOS
D25C HANGUL SYLLABLE TWEOSS
D25D HANGUL SYLLABLE TWEONG
D25E HANGUL SYLLABLE TWEOJ
D25F HANGUL SYLLABLE TWEOC
D260 HANGUL SYLLABLE TWEOK
D261 HANGUL SYLLABLE TWEOT
D262 HANGUL SYLLABLE TWEOP
D263 HANGUL SYLLABLE TWEOH
D264 HANGUL SYLLABLE TWE
D265 HANGUL SYLLABLE TWEG
D266 HANGUL SYLLABLE TWEGG
D267 HANGUL SYLLABLE TWEGS
D268 HANGUL SYLLABLE TWEN
D269 HANGUL SYLLABLE TWENJ
D26A HANGUL SYLLABLE TWENH
D26B HANGUL SYLLABLE TWED
D26C HANGUL SYLLABLE TWEL
D26D HANGUL SYLLABLE TWELG
D26E HANGUL SYLLABLE TWELM
D26F HANGUL SYLLABLE TWELB
D270 HANGUL SYLLABLE TWELS
D271 HANGUL SYLLABLE TWELT
D272 HANGUL SYLLABLE TWELP
D273 HANGUL SYLLABLE TWELH
D274 HANGUL SYLLABLE TWEM
D275 HANGUL SYLLABLE TWEB
D276 HANGUL SYLLABLE TWEBS
D277 HANGUL SYLLABLE TWES
D278 HANGUL SYLLABLE TWESS
D279 HANGUL SYLLABLE TWENG
D27A HANGUL SYLLABLE TWEJ
D27B HANGUL SYLLABLE TWEC
D27C HANGUL SYLLABLE TWEK
D27D HANGUL SYLLABLE TWET
D27E HANGUL SYLLABLE TWEP
D27F HANGUL SYLLABLE TWEH
D280 HANGUL SYLLABLE TWI
D281 HANGUL SYLLABLE TWIG
D282 HANGUL SYLLABLE TWIGG
D283 HANGUL SYLLABLE TWIGS
D284 HANGUL SYLLABLE TWIN
D285 HANGUL SYLLABLE TWINJ
D286 HANGUL SYLLABLE TWINH
D287 HANGUL SYLLABLE TWID
D288 HANGUL SYLLABLE TWIL
D289 HANGUL SYLLABLE TWILG
D28A HANGUL SYLLABLE TWILM
D28B HANGUL SYLLABLE TWILB
D28C HANGUL SYLLABLE TWILS
D28D HANGUL SYLLABLE TWILT
D28E HANGUL SYLLABLE TWILP
D28F HANGUL SYLLABLE TWILH
D290 HANGUL SYLLABLE TWIM
D291 HANGUL SYLLABLE TWIB
D292 HANGUL SYLLABLE TWIBS
D293 HANGUL SYLLABLE TWIS
D294 HANGUL SYLLABLE TWISS
D295 HANGUL SYLLABLE TWING
D296 HANGUL SYLLABLE TWIJ
D297 HANGUL SYLLABLE TWIC
D298 HANGUL SYLLABLE TWIK
D299 HANGUL SYLLABLE TWIT
D29A HANGUL SYLLABLE TWIP
D29B HANGUL SYLLABLE TWIH
D29C HANGUL SYLLABLE TYU
D29D HANGUL SYLLABLE TYUG
D29E HANGUL SYLLABLE TYUGG
D29F HANGUL SYLLABLE TYUGS
D2A0 HANGUL SYLLABLE TYUN
D2A1 HANGUL SYLLABLE TYUNJ
D2A2 HANGUL SYLLABLE TYUNH
D2A3 HANGUL SYLLABLE TYUD
D2A4 HANGUL SYLLABLE TYUL
D2A5 HANGUL SYLLABLE TYULG
D2A6 HANGUL SYLLABLE TYULM
D2A7 HANGUL SYLLABLE TYULB
D2A8 HANGUL SYLLABLE TYULS
D2A9 HANGUL SYLLABLE TYULT
D2AA HANGUL SYLLABLE TYULP
D2AB HANGUL SYLLABLE TYULH
D2AC HANGUL SYLLABLE TYUM
D2AD HANGUL SYLLABLE TYUB
D2AE HANGUL SYLLABLE TYUBS
D2AF HANGUL SYLLABLE TYUS
D2B0 HANGUL SYLLABLE TYUSS
D2B1 HANGUL SYLLABLE TYUNG
D2B2 HANGUL SYLLABLE TYUJ
D2B3 HANGUL SYLLABLE TYUC
D2B4 HANGUL SYLLABLE TYUK
D2B5 HANGUL SYLLABLE TYUT
D2B6 HANGUL SYLLABLE TYUP
D2B7 HANGUL SYLLABLE TYUH
D2B8 HANGUL SYLLABLE TEU
D2B9 HANGUL SYLLABLE TEUG
D2BA HANGUL SYLLABLE TEUGG
D2BB HANGUL SYLLABLE TEUGS
D2BC HANGUL SYLLABLE TEUN
D2BD HANGUL SYLLABLE TEUNJ
D2BE HANGUL SYLLABLE TEUNH
D2BF HANGUL SYLLABLE TEUD
D2C0 HANGUL SYLLABLE TEUL
D2C1 HANGUL SYLLABLE TEULG
D2C2 HANGUL SYLLABLE TEULM
D2C3 HANGUL SYLLABLE TEULB
D2C4 HANGUL SYLLABLE TEULS
D2C5 HANGUL SYLLABLE TEULT
D2C6 HANGUL SYLLABLE TEULP
D2C7 HANGUL SYLLABLE TEULH
D2C8 HANGUL SYLLABLE TEUM
D2C9 HANGUL SYLLABLE TEUB
D2CA HANGUL SYLLABLE TEUBS
D2CB HANGUL SYLLABLE TEUS
D2CC HANGUL SYLLABLE TEUSS
D2CD HANGUL SYLLABLE TEUNG
D2CE HANGUL SYLLABLE TEUJ
D2CF HANGUL SYLLABLE TEUC
D2D0 HANGUL SYLLABLE TEUK
D2D1 HANGUL SYLLABLE TEUT
D2D2 HANGUL SYLLABLE TEUP
D2D3 HANGUL SYLLABLE TEUH
D2D4 HANGUL SYLLABLE TYI
D2D5 HANGUL SYLLABLE TYIG
D2D6 HANGUL SYLLABLE TYIGG
D2D7 HANGUL SYLLABLE TYIGS
D2D8 HANGUL SYLLABLE TYIN
D2D9 HANGUL SYLLABLE TYINJ
D2DA HANGUL SYLLABLE TYINH
D2DB HANGUL SYLLABLE TYID
D2DC HANGUL SYLLABLE TYIL
D2DD HANGUL SYLLABLE TYILG
D2DE HANGUL SYLLABLE TYILM
D2DF HANGUL SYLLABLE TYILB
D2E0 HANGUL SYLLABLE TYILS
D2E1 HANGUL SYLLABLE TYILT
D2E2 HANGUL SYLLABLE TYILP
D2E3 HANGUL SYLLABLE TYILH
D2E4 HANGUL SYLLABLE TYIM
D2E5 HANGUL SYLLABLE TYIB
D2E6 HANGUL SYLLABLE TYIBS
D2E7 HANGUL SYLLABLE TYIS
D2E8 HANGUL SYLLABLE TYISS
D2E9 HANGUL SYLLABLE TYING
D2EA HANGUL SYLLABLE TYIJ
D2EB HANGUL SYLLABLE TYIC
D2EC HANGUL SYLLABLE TYIK
D2ED HANGUL SYLLABLE TYIT
D2EE HANGUL SYLLABLE TYIP
D2EF HANGUL SYLLABLE TYIH
D2F0 HANGUL SYLLABLE TI
D2F1 HANGUL SYLLABLE TIG
D2F2 HANGUL SYLLABLE TIGG
D2F3 HANGUL SYLLABLE TIGS
D2F4 HANGUL SYLLABLE TIN
D2F5 HANGUL SYLLABLE TINJ
D2F6 HANGUL SYLLABLE TINH
D2F7 HANGUL SYLLABLE TID
D2F8 HANGUL SYLLABLE TIL
D2F9 HANGUL SYLLABLE TILG
D2FA HANGUL SYLLABLE TILM
D2FB HANGUL SYLLABLE TILB
D2FC HANGUL SYLLABLE TILS
D2FD HANGUL SYLLABLE TILT
D2FE HANGUL SYLLABLE TILP
D2FF HANGUL SYLLABLE TILH
D300 HANGUL SYLLABLE TIM
D301 HANGUL SYLLABLE TIB
D302 HANGUL SYLLABLE TIBS
D303 HANGUL SYLLABLE TIS
D304 HANGUL SYLLABLE TISS
D305 HANGUL SYLLABLE TING
D306 HANGUL SYLLABLE TIJ
D307 HANGUL SYLLABLE TIC
D308 HANGUL SYLLABLE TIK
D309 HANGUL SYLLABLE TIT
D30A HANGUL SYLLABLE TIP
D30B HANGUL SYLLABLE TIH
D30C HANGUL SYLLABLE PA
D30D HANGUL SYLLABLE PAG
D30E HANGUL SYLLABLE PAGG
D30F HANGUL SYLLABLE PAGS
D310 HANGUL SYLLABLE PAN
D311 HANGUL SYLLABLE PANJ
D312 HANGUL SYLLABLE PANH
D313 HANGUL SYLLABLE PAD
D314 HANGUL SYLLABLE PAL
D315 HANGUL SYLLABLE PALG
D316 HANGUL SYLLABLE PALM
D317 HANGUL SYLLABLE PALB
D318 HANGUL SYLLABLE PALS
D319 HANGUL SYLLABLE PALT
D31A HANGUL SYLLABLE PALP
D31B HANGUL SYLLABLE PALH
D31C HANGUL SYLLABLE PAM
D31D HANGUL SYLLABLE PAB
D31E HANGUL SYLLABLE PABS
D31F HANGUL SYLLABLE PAS
D320 HANGUL SYLLABLE PASS
D321 HANGUL SYLLABLE PANG
D322 HANGUL SYLLABLE PAJ
D323 HANGUL SYLLABLE PAC
D324 HANGUL SYLLABLE PAK
D325 HANGUL SYLLABLE PAT
D326 HANGUL SYLLABLE PAP
D327 HANGUL SYLLABLE PAH
D328 HANGUL SYLLABLE PAE
D329 HANGUL SYLLABLE PAEG
D32A HANGUL SYLLABLE PAEGG
D32B HANGUL SYLLABLE PAEGS
D32C HANGUL SYLLABLE PAEN
D32D HANGUL SYLLABLE PAENJ
D32E HANGUL SYLLABLE PAENH
D32F HANGUL SYLLABLE PAED
D330 HANGUL SYLLABLE PAEL
D331 HANGUL SYLLABLE PAELG
D332 HANGUL SYLLABLE PAELM
D333 HANGUL SYLLABLE PAELB
D334 HANGUL SYLLABLE PAELS
D335 HANGUL SYLLABLE PAELT
D336 HANGUL SYLLABLE PAELP
D337 HANGUL SYLLABLE PAELH
D338 HANGUL SYLLABLE PAEM
D339 HANGUL SYLLABLE PAEB
D33A HANGUL SYLLABLE PAEBS
D33B HANGUL SYLLABLE PAES
D33C HANGUL SYLLABLE PAESS
D33D HANGUL SYLLABLE PAENG
D33E HANGUL SYLLABLE PAEJ
D33F HANGUL SYLLABLE PAEC
D340 HANGUL SYLLABLE PAEK
D341 HANGUL SYLLABLE PAET
D342 HANGUL SYLLABLE PAEP
D343 HANGUL SYLLABLE PAEH
D344 HANGUL SYLLABLE PYA
D345 HANGUL SYLLABLE PYAG
D346 HANGUL SYLLABLE PYAGG
D347 HANGUL SYLLABLE PYAGS
D348 HANGUL SYLLABLE PYAN
D349 HANGUL SYLLABLE PYANJ
D34A HANGUL SYLLABLE PYANH
D34B HANGUL SYLLABLE PYAD
D34C HANGUL SYLLABLE PYAL
D34D HANGUL SYLLABLE PYALG
D34E HANGUL SYLLABLE PYALM
D34F HANGUL SYLLABLE PYALB
D350 HANGUL SYLLABLE PYALS
D351 HANGUL SYLLABLE PYALT
D352 HANGUL SYLLABLE PYALP
D353 HANGUL SYLLABLE PYALH
D354 HANGUL SYLLABLE PYAM
D355 HANGUL SYLLABLE PYAB
D356 HANGUL SYLLABLE PYABS
D357 HANGUL SYLLABLE PYAS
D358 HANGUL SYLLABLE PYASS
D359 HANGUL SYLLABLE PYANG
D35A HANGUL SYLLABLE PYAJ
D35B HANGUL SYLLABLE PYAC
D35C HANGUL SYLLABLE PYAK
D35D HANGUL SYLLABLE PYAT
D35E HANGUL SYLLABLE PYAP
D35F HANGUL SYLLABLE PYAH
D360 HANGUL SYLLABLE PYAE
D361 HANGUL SYLLABLE PYAEG
D362 HANGUL SYLLABLE PYAEGG
D363 HANGUL SYLLABLE PYAEGS
D364 HANGUL SYLLABLE PYAEN
D365 HANGUL SYLLABLE PYAENJ
D366 HANGUL SYLLABLE PYAENH
D367 HANGUL SYLLABLE PYAED
D368 HANGUL SYLLABLE PYAEL
D369 HANGUL SYLLABLE PYAELG
D36A HANGUL SYLLABLE PYAELM
D36B HANGUL SYLLABLE PYAELB
D36C HANGUL SYLLABLE PYAELS
D36D HANGUL SYLLABLE PYAELT
D36E HANGUL SYLLABLE PYAELP
D36F HANGUL SYLLABLE PYAELH
D370 HANGUL SYLLABLE PYAEM
D371 HANGUL SYLLABLE PYAEB
D372 HANGUL SYLLABLE PYAEBS
D373 HANGUL SYLLABLE PYAES
D374 HANGUL SYLLABLE PYAESS
D375 HANGUL SYLLABLE PYAENG
D376 HANGUL SYLLABLE PYAEJ
D377 HANGUL SYLLABLE PYAEC
D378 HANGUL SYLLABLE PYAEK
D379 HANGUL SYLLABLE PYAET
D37A HANGUL SYLLABLE PYAEP
D37B HANGUL SYLLABLE PYAEH
D37C HANGUL SYLLABLE PEO
D37D HANGUL SYLLABLE PEOG
D37E HANGUL SYLLABLE PEOGG
D37F HANGUL SYLLABLE PEOGS
D380 HANGUL SYLLABLE PEON
D381 HANGUL SYLLABLE PEONJ
D382 HANGUL SYLLABLE PEONH
D383 HANGUL SYLLABLE PEOD
D384 HANGUL SYLLABLE PEOL
D385 HANGUL SYLLABLE PEOLG
D386 HANGUL SYLLABLE PEOLM
D387 HANGUL SYLLABLE PEOLB
D388 HANGUL SYLLABLE PEOLS
D389 HANGUL SYLLABLE PEOLT
D38A HANGUL SYLLABLE PEOLP
D38B HANGUL SYLLABLE PEOLH
D38C HANGUL SYLLABLE PEOM
D38D HANGUL SYLLABLE PEOB
D38E HANGUL SYLLABLE PEOBS
D38F HANGUL SYLLABLE PEOS
D390 HANGUL SYLLABLE PEOSS
D391 HANGUL SYLLABLE PEONG
D392 HANGUL SYLLABLE PEOJ
D393 HANGUL SYLLABLE PEOC
D394 HANGUL SYLLABLE PEOK
D395 HANGUL SYLLABLE PEOT
D396 HANGUL SYLLABLE PEOP
D397 HANGUL SYLLABLE PEOH
D398 HANGUL SYLLABLE PE
D399 HANGUL SYLLABLE PEG
D39A HANGUL SYLLABLE PEGG
D39B HANGUL SYLLABLE PEGS
D39C HANGUL SYLLABLE PEN
D39D HANGUL SYLLABLE PENJ
D39E HANGUL SYLLABLE PENH
D39F HANGUL SYLLABLE PED
D3A0 HANGUL SYLLABLE PEL
D3A1 HANGUL SYLLABLE PELG
D3A2 HANGUL SYLLABLE PELM
D3A3 HANGUL SYLLABLE PELB
D3A4 HANGUL SYLLABLE PELS
D3A5 HANGUL SYLLABLE PELT
D3A6 HANGUL SYLLABLE PELP
D3A7 HANGUL SYLLABLE PELH
D3A8 HANGUL SYLLABLE PEM
D3A9 HANGUL SYLLABLE PEB
D3AA HANGUL SYLLABLE PEBS
D3AB HANGUL SYLLABLE PES
D3AC HANGUL SYLLABLE PESS
D3AD HANGUL SYLLABLE PENG
D3AE HANGUL SYLLABLE PEJ
D3AF HANGUL SYLLABLE PEC
D3B0 HANGUL SYLLABLE PEK
D3B1 HANGUL SYLLABLE PET
D3B2 HANGUL SYLLABLE PEP
D3B3 HANGUL SYLLABLE PEH
D3B4 HANGUL SYLLABLE PYEO
D3B5 HANGUL SYLLABLE PYEOG
D3B6 HANGUL SYLLABLE PYEOGG
D3B7 HANGUL SYLLABLE PYEOGS
D3B8 HANGUL SYLLABLE PYEON
D3B9 HANGUL SYLLABLE PYEONJ
D3BA HANGUL SYLLABLE PYEONH
D3BB HANGUL SYLLABLE PYEOD
D3BC HANGUL SYLLABLE PYEOL
D3BD HANGUL SYLLABLE PYEOLG
D3BE HANGUL SYLLABLE PYEOLM
D3BF HANGUL SYLLABLE PYEOLB
D3C0 HANGUL SYLLABLE PYEOLS
D3C1 HANGUL SYLLABLE PYEOLT
D3C2 HANGUL SYLLABLE PYEOLP
D3C3 HANGUL SYLLABLE PYEOLH
D3C4 HANGUL SYLLABLE PYEOM
D3C5 HANGUL SYLLABLE PYEOB
D3C6 HANGUL SYLLABLE PYEOBS
D3C7 HANGUL SYLLABLE PYEOS
D3C8 HANGUL SYLLABLE PYEOSS
D3C9 HANGUL SYLLABLE PYEONG
D3CA HANGUL SYLLABLE PYEOJ
D3CB HANGUL SYLLABLE PYEOC
D3CC HANGUL SYLLABLE PYEOK
D3CD HANGUL SYLLABLE PYEOT
D3CE HANGUL SYLLABLE PYEOP
D3CF HANGUL SYLLABLE PYEOH
D3D0 HANGUL SYLLABLE PYE
D3D1 HANGUL SYLLABLE PYEG
D3D2 HANGUL SYLLABLE PYEGG
D3D3 HANGUL SYLLABLE PYEGS
D3D4 HANGUL SYLLABLE PYEN
D3D5 HANGUL SYLLABLE PYENJ
D3D6 HANGUL SYLLABLE PYENH
D3D7 HANGUL SYLLABLE PYED
D3D8 HANGUL SYLLABLE PYEL
D3D9 HANGUL SYLLABLE PYELG
D3DA HANGUL SYLLABLE PYELM
D3DB HANGUL SYLLABLE PYELB
D3DC HANGUL SYLLABLE PYELS
D3DD HANGUL SYLLABLE PYELT
D3DE HANGUL SYLLABLE PYELP
D3DF HANGUL SYLLABLE PYELH
D3E0 HANGUL SYLLABLE PYEM
D3E1 HANGUL SYLLABLE PYEB
D3E2 HANGUL SYLLABLE PYEBS
D3E3 HANGUL SYLLABLE PYES
D3E4 HANGUL SYLLABLE PYESS
D3E5 HANGUL SYLLABLE PYENG
D3E6 HANGUL SYLLABLE PYEJ
D3E7 HANGUL SYLLABLE PYEC
D3E8 HANGUL SYLLABLE PYEK
D3E9 HANGUL SYLLABLE PYET
D3EA HANGUL SYLLABLE PYEP
D3EB HANGUL SYLLABLE PYEH
D3EC HANGUL SYLLABLE PO
D3ED HANGUL SYLLABLE POG
D3EE HANGUL SYLLABLE POGG
D3EF HANGUL SYLLABLE POGS
D3F0 HANGUL SYLLABLE PON
D3F1 HANGUL SYLLABLE PONJ
D3F2 HANGUL SYLLABLE PONH
D3F3 HANGUL SYLLABLE POD
D3F4 HANGUL SYLLABLE POL
D3F5 HANGUL SYLLABLE POLG
D3F6 HANGUL SYLLABLE POLM
D3F7 HANGUL SYLLABLE POLB
D3F8 HANGUL SYLLABLE POLS
D3F9 HANGUL SYLLABLE POLT
D3FA HANGUL SYLLABLE POLP
D3FB HANGUL SYLLABLE POLH
D3FC HANGUL SYLLABLE POM
D3FD HANGUL SYLLABLE POB
D3FE HANGUL SYLLABLE POBS
D3FF HANGUL SYLLABLE POS
D400 HANGUL SYLLABLE POSS
D401 HANGUL SYLLABLE PONG
D402 HANGUL SYLLABLE POJ
D403 HANGUL SYLLABLE POC
D404 HANGUL SYLLABLE POK
D405 HANGUL SYLLABLE POT
D406 HANGUL SYLLABLE POP
D407 HANGUL SYLLABLE POH
D408 HANGUL SYLLABLE PWA
D409 HANGUL SYLLABLE PWAG
D40A HANGUL SYLLABLE PWAGG
D40B HANGUL SYLLABLE PWAGS
D40C HANGUL SYLLABLE PWAN
D40D HANGUL SYLLABLE PWANJ
D40E HANGUL SYLLABLE PWANH
D40F HANGUL SYLLABLE PWAD
D410 HANGUL SYLLABLE PWAL
D411 HANGUL SYLLABLE PWALG
D412 HANGUL SYLLABLE PWALM
D413 HANGUL SYLLABLE PWALB
D414 HANGUL SYLLABLE PWALS
D415 HANGUL SYLLABLE PWALT
D416 HANGUL SYLLABLE PWALP
D417 HANGUL SYLLABLE PWALH
D418 HANGUL SYLLABLE PWAM
D419 HANGUL SYLLABLE PWAB
D41A HANGUL SYLLABLE PWABS
D41B HANGUL SYLLABLE PWAS
D41C HANGUL SYLLABLE PWASS
D41D HANGUL SYLLABLE PWANG
D41E HANGUL SYLLABLE PWAJ
D41F HANGUL SYLLABLE PWAC
D420 HANGUL SYLLABLE PWAK
D421 HANGUL SYLLABLE PWAT
D422 HANGUL SYLLABLE PWAP
D423 HANGUL SYLLABLE PWAH
D424 HANGUL SYLLABLE PWAE
D425 HANGUL SYLLABLE PWAEG
D426 HANGUL SYLLABLE PWAEGG
D427 HANGUL SYLLABLE PWAEGS
D428 HANGUL SYLLABLE PWAEN
D429 HANGUL SYLLABLE PWAENJ
D42A HANGUL SYLLABLE PWAENH
D42B HANGUL SYLLABLE PWAED
D42C HANGUL SYLLABLE PWAEL
D42D HANGUL SYLLABLE PWAELG
D42E HANGUL SYLLABLE PWAELM
D42F HANGUL SYLLABLE PWAELB
D430 HANGUL SYLLABLE PWAELS
D431 HANGUL SYLLABLE PWAELT
D432 HANGUL SYLLABLE PWAELP
D433 HANGUL SYLLABLE PWAELH
D434 HANGUL SYLLABLE PWAEM
D435 HANGUL SYLLABLE PWAEB
D436 HANGUL SYLLABLE PWAEBS
D437 HANGUL SYLLABLE PWAES
D438 HANGUL SYLLABLE PWAESS
D439 HANGUL SYLLABLE PWAENG
D43A HANGUL SYLLABLE PWAEJ
D43B HANGUL SYLLABLE PWAEC
D43C HANGUL SYLLABLE PWAEK
D43D HANGUL SYLLABLE PWAET
D43E HANGUL SYLLABLE PWAEP
D43F HANGUL SYLLABLE PWAEH
D440 HANGUL SYLLABLE POE
D441 HANGUL SYLLABLE POEG
D442 HANGUL SYLLABLE POEGG
D443 HANGUL SYLLABLE POEGS
D444 HANGUL SYLLABLE POEN
D445 HANGUL SYLLABLE POENJ
D446 HANGUL SYLLABLE POENH
D447 HANGUL SYLLABLE POED
D448 HANGUL SYLLABLE POEL
D449 HANGUL SYLLABLE POELG
D44A HANGUL SYLLABLE POELM
D44B HANGUL SYLLABLE POELB
D44C HANGUL SYLLABLE POELS
D44D HANGUL SYLLABLE POELT
D44E HANGUL SYLLABLE POELP
D44F HANGUL SYLLABLE POELH
D450 HANGUL SYLLABLE POEM
D451 HANGUL SYLLABLE POEB
D452 HANGUL SYLLABLE POEBS
D453 HANGUL SYLLABLE POES
D454 HANGUL SYLLABLE POESS
D455 HANGUL SYLLABLE POENG
D456 HANGUL SYLLABLE POEJ
D457 HANGUL SYLLABLE POEC
D458 HANGUL SYLLABLE POEK
D459 HANGUL SYLLABLE POET
D45A HANGUL SYLLABLE POEP
D45B HANGUL SYLLABLE POEH
D45C HANGUL SYLLABLE PYO
D45D HANGUL SYLLABLE PYOG
D45E HANGUL SYLLABLE PYOGG
D45F HANGUL SYLLABLE PYOGS
D460 HANGUL SYLLABLE PYON
D461 HANGUL SYLLABLE PYONJ
D462 HANGUL SYLLABLE PYONH
D463 HANGUL SYLLABLE PYOD
D464 HANGUL SYLLABLE PYOL
D465 HANGUL SYLLABLE PYOLG
D466 HANGUL SYLLABLE PYOLM
D467 HANGUL SYLLABLE PYOLB
D468 HANGUL SYLLABLE PYOLS
D469 HANGUL SYLLABLE PYOLT
D46A HANGUL SYLLABLE PYOLP
D46B HANGUL SYLLABLE PYOLH
D46C HANGUL SYLLABLE PYOM
D46D HANGUL SYLLABLE PYOB
D46E HANGUL SYLLABLE PYOBS
D46F HANGUL SYLLABLE PYOS
D470 HANGUL SYLLABLE PYOSS
D471 HANGUL SYLLABLE PYONG
D472 HANGUL SYLLABLE PYOJ
D473 HANGUL SYLLABLE PYOC
D474 HANGUL SYLLABLE PYOK
D475 HANGUL SYLLABLE PYOT
D476 HANGUL SYLLABLE PYOP
D477 HANGUL SYLLABLE PYOH
D478 HANGUL SYLLABLE PU
D479 HANGUL SYLLABLE PUG
D47A HANGUL SYLLABLE PUGG
D47B HANGUL SYLLABLE PUGS
D47C HANGUL SYLLABLE PUN
D47D HANGUL SYLLABLE PUNJ
D47E HANGUL SYLLABLE PUNH
D47F HANGUL SYLLABLE PUD
D480 HANGUL SYLLABLE PUL
D481 HANGUL SYLLABLE PULG
D482 HANGUL SYLLABLE PULM
D483 HANGUL SYLLABLE PULB
D484 HANGUL SYLLABLE PULS
D485 HANGUL SYLLABLE PULT
D486 HANGUL SYLLABLE PULP
D487 HANGUL SYLLABLE PULH
D488 HANGUL SYLLABLE PUM
D489 HANGUL SYLLABLE PUB
D48A HANGUL SYLLABLE PUBS
D48B HANGUL SYLLABLE PUS
D48C HANGUL SYLLABLE PUSS
D48D HANGUL SYLLABLE PUNG
D48E HANGUL SYLLABLE PUJ
D48F HANGUL SYLLABLE PUC
D490 HANGUL SYLLABLE PUK
D491 HANGUL SYLLABLE PUT
D492 HANGUL SYLLABLE PUP
D493 HANGUL SYLLABLE PUH
D494 HANGUL SYLLABLE PWEO
D495 HANGUL SYLLABLE PWEOG
D496 HANGUL SYLLABLE PWEOGG
D497 HANGUL SYLLABLE PWEOGS
D498 HANGUL SYLLABLE PWEON
D499 HANGUL SYLLABLE PWEONJ
D49A HANGUL SYLLABLE PWEONH
D49B HANGUL SYLLABLE PWEOD
D49C HANGUL SYLLABLE PWEOL
D49D HANGUL SYLLABLE PWEOLG
D49E HANGUL SYLLABLE PWEOLM
D49F HANGUL SYLLABLE PWEOLB
D4A0 HANGUL SYLLABLE PWEOLS
D4A1 HANGUL SYLLABLE PWEOLT
D4A2 HANGUL SYLLABLE PWEOLP
D4A3 HANGUL SYLLABLE PWEOLH
D4A4 HANGUL SYLLABLE PWEOM
D4A5 HANGUL SYLLABLE PWEOB
D4A6 HANGUL SYLLABLE PWEOBS
D4A7 HANGUL SYLLABLE PWEOS
D4A8 HANGUL SYLLABLE PWEOSS
D4A9 HANGUL SYLLABLE PWEONG
D4AA HANGUL SYLLABLE PWEOJ
D4AB HANGUL SYLLABLE PWEOC
D4AC HANGUL SYLLABLE PWEOK
D4AD HANGUL SYLLABLE PWEOT
D4AE HANGUL SYLLABLE PWEOP
D4AF HANGUL SYLLABLE PWEOH
D4B0 HANGUL SYLLABLE PWE
D4B1 HANGUL SYLLABLE PWEG
D4B2 HANGUL SYLLABLE PWEGG
D4B3 HANGUL SYLLABLE PWEGS
D4B4 HANGUL SYLLABLE PWEN
D4B5 HANGUL SYLLABLE PWENJ
D4B6 HANGUL SYLLABLE PWENH
D4B7 HANGUL SYLLABLE PWED
D4B8 HANGUL SYLLABLE PWEL
D4B9 HANGUL SYLLABLE PWELG
D4BA HANGUL SYLLABLE PWELM
D4BB HANGUL SYLLABLE PWELB
D4BC HANGUL SYLLABLE PWELS
D4BD HANGUL SYLLABLE PWELT
D4BE HANGUL SYLLABLE PWELP
D4BF HANGUL SYLLABLE PWELH
D4C0 HANGUL SYLLABLE PWEM
D4C1 HANGUL SYLLABLE PWEB
D4C2 HANGUL SYLLABLE PWEBS
D4C3 HANGUL SYLLABLE PWES
D4C4 HANGUL SYLLABLE PWESS
D4C5 HANGUL SYLLABLE PWENG
D4C6 HANGUL SYLLABLE PWEJ
D4C7 HANGUL SYLLABLE PWEC
D4C8 HANGUL SYLLABLE PWEK
D4C9 HANGUL SYLLABLE PWET
D4CA HANGUL SYLLABLE PWEP
D4CB HANGUL SYLLABLE PWEH
D4CC HANGUL SYLLABLE PWI
D4CD HANGUL SYLLABLE PWIG
D4CE HANGUL SYLLABLE PWIGG
D4CF HANGUL SYLLABLE PWIGS
D4D0 HANGUL SYLLABLE PWIN
D4D1 HANGUL SYLLABLE PWINJ
D4D2 HANGUL SYLLABLE PWINH
D4D3 HANGUL SYLLABLE PWID
D4D4 HANGUL SYLLABLE PWIL
D4D5 HANGUL SYLLABLE PWILG
D4D6 HANGUL SYLLABLE PWILM
D4D7 HANGUL SYLLABLE PWILB
D4D8 HANGUL SYLLABLE PWILS
D4D9 HANGUL SYLLABLE PWILT
D4DA HANGUL SYLLABLE PWILP
D4DB HANGUL SYLLABLE PWILH
D4DC HANGUL SYLLABLE PWIM
D4DD HANGUL SYLLABLE PWIB
D4DE HANGUL SYLLABLE PWIBS
D4DF HANGUL SYLLABLE PWIS
D4E0 HANGUL SYLLABLE PWISS
D4E1 HANGUL SYLLABLE PWING
D4E2 HANGUL SYLLABLE PWIJ
D4E3 HANGUL SYLLABLE PWIC
D4E4 HANGUL SYLLABLE PWIK
D4E5 HANGUL SYLLABLE PWIT
D4E6 HANGUL SYLLABLE PWIP
D4E7 HANGUL SYLLABLE PWIH
D4E8 HANGUL SYLLABLE PYU
D4E9 HANGUL SYLLABLE PYUG
D4EA HANGUL SYLLABLE PYUGG
D4EB HANGUL SYLLABLE PYUGS
D4EC HANGUL SYLLABLE PYUN
D4ED HANGUL SYLLABLE PYUNJ
D4EE HANGUL SYLLABLE PYUNH
D4EF HANGUL SYLLABLE PYUD
D4F0 HANGUL SYLLABLE PYUL
D4F1 HANGUL SYLLABLE PYULG
D4F2 HANGUL SYLLABLE PYULM
D4F3 HANGUL SYLLABLE PYULB
D4F4 HANGUL SYLLABLE PYULS
D4F5 HANGUL SYLLABLE PYULT
D4F6 HANGUL SYLLABLE PYULP
D4F7 HANGUL SYLLABLE PYULH
D4F8 HANGUL SYLLABLE PYUM
D4F9 HANGUL SYLLABLE PYUB
D4FA HANGUL SYLLABLE PYUBS
D4FB HANGUL SYLLABLE PYUS
D4FC HANGUL SYLLABLE PYUSS
D4FD HANGUL SYLLABLE PYUNG
D4FE HANGUL SYLLABLE PYUJ
D4FF HANGUL SYLLABLE PYUC
D500 HANGUL SYLLABLE PYUK
D501 HANGUL SYLLABLE PYUT
D502 HANGUL SYLLABLE PYUP
D503 HANGUL SYLLABLE PYUH
D504 HANGUL SYLLABLE PEU
D505 HANGUL SYLLABLE PEUG
D506 HANGUL SYLLABLE PEUGG
D507 HANGUL SYLLABLE PEUGS
D508 HANGUL SYLLABLE PEUN
D509 HANGUL SYLLABLE PEUNJ
D50A HANGUL SYLLABLE PEUNH
D50B HANGUL SYLLABLE PEUD
D50C HANGUL SYLLABLE PEUL
D50D HANGUL SYLLABLE PEULG
D50E HANGUL SYLLABLE PEULM
D50F HANGUL SYLLABLE PEULB
D510 HANGUL SYLLABLE PEULS
D511 HANGUL SYLLABLE PEULT
D512 HANGUL SYLLABLE PEULP
D513 HANGUL SYLLABLE PEULH
D514 HANGUL SYLLABLE PEUM
D515 HANGUL SYLLABLE PEUB
D516 HANGUL SYLLABLE PEUBS
D517 HANGUL SYLLABLE PEUS
D518 HANGUL SYLLABLE PEUSS
D519 HANGUL SYLLABLE PEUNG
D51A HANGUL SYLLABLE PEUJ
D51B HANGUL SYLLABLE PEUC
D51C HANGUL SYLLABLE PEUK
D51D HANGUL SYLLABLE PEUT
D51E HANGUL SYLLABLE PEUP
D51F HANGUL SYLLABLE PEUH
D520 HANGUL SYLLABLE PYI
D521 HANGUL SYLLABLE PYIG
D522 HANGUL SYLLABLE PYIGG
D523 HANGUL SYLLABLE PYIGS
D524 HANGUL SYLLABLE PYIN
D525 HANGUL SYLLABLE PYINJ
D526 HANGUL SYLLABLE PYINH
D527 HANGUL SYLLABLE PYID
D528 HANGUL SYLLABLE PYIL
D529 HANGUL SYLLABLE PYILG
D52A HANGUL SYLLABLE PYILM
D52B HANGUL SYLLABLE PYILB
D52C HANGUL SYLLABLE PYILS
D52D HANGUL SYLLABLE PYILT
D52E HANGUL SYLLABLE PYILP
D52F HANGUL SYLLABLE PYILH
D530 HANGUL SYLLABLE PYIM
D531 HANGUL SYLLABLE PYIB
D532 HANGUL SYLLABLE PYIBS
D533 HANGUL SYLLABLE PYIS
D534 HANGUL SYLLABLE PYISS
D535 HANGUL SYLLABLE PYING
D536 HANGUL SYLLABLE PYIJ
D537 HANGUL SYLLABLE PYIC
D538 HANGUL SYLLABLE PYIK
D539 HANGUL SYLLABLE PYIT
D53A HANGUL SYLLABLE PYIP
D53B HANGUL SYLLABLE PYIH
D53C HANGUL SYLLABLE PI
D53D HANGUL SYLLABLE PIG
D53E HANGUL SYLLABLE PIGG
D53F HANGUL SYLLABLE PIGS
D540 HANGUL SYLLABLE PIN
D541 HANGUL SYLLABLE PINJ
D542 HANGUL SYLLABLE PINH
D543 HANGUL SYLLABLE PID
D544 HANGUL SYLLABLE PIL
D545 HANGUL SYLLABLE PILG
D546 HANGUL SYLLABLE PILM
D547 HANGUL SYLLABLE PILB
D548 HANGUL SYLLABLE PILS
D549 HANGUL SYLLABLE PILT
D54A HANGUL SYLLABLE PILP
D54B HANGUL SYLLABLE PILH
D54C HANGUL SYLLABLE PIM
D54D HANGUL SYLLABLE PIB
D54E HANGUL SYLLABLE PIBS
D54F HANGUL SYLLABLE PIS
D550 HANGUL SYLLABLE PISS
D551 HANGUL SYLLABLE PING
D552 HANGUL SYLLABLE PIJ
D553 HANGUL SYLLABLE PIC
D554 HANGUL SYLLABLE PIK
D555 HANGUL SYLLABLE PIT
D556 HANGUL SYLLABLE PIP
D557 HANGUL SYLLABLE PIH
D558 HANGUL SYLLABLE HA
D559 HANGUL SYLLABLE HAG
D55A HANGUL SYLLABLE HAGG
D55B HANGUL SYLLABLE HAGS
D55C HANGUL SYLLABLE HAN
D55D HANGUL SYLLABLE HANJ
D55E HANGUL SYLLABLE HANH
D55F HANGUL SYLLABLE HAD
D560 HANGUL SYLLABLE HAL
D561 HANGUL SYLLABLE HALG
D562 HANGUL SYLLABLE HALM
D563 HANGUL SYLLABLE HALB
D564 HANGUL SYLLABLE HALS
D565 HANGUL SYLLABLE HALT
D566 HANGUL SYLLABLE HALP
D567 HANGUL SYLLABLE HALH
D568 HANGUL SYLLABLE HAM
D569 HANGUL SYLLABLE HAB
D56A HANGUL SYLLABLE HABS
D56B HANGUL SYLLABLE HAS
D56C HANGUL SYLLABLE HASS
D56D HANGUL SYLLABLE HANG
D56E HANGUL SYLLABLE HAJ
D56F HANGUL SYLLABLE HAC
D570 HANGUL SYLLABLE HAK
D571 HANGUL SYLLABLE HAT
D572 HANGUL SYLLABLE HAP
D573 HANGUL SYLLABLE HAH
D574 HANGUL SYLLABLE HAE
D575 HANGUL SYLLABLE HAEG
D576 HANGUL SYLLABLE HAEGG
D577 HANGUL SYLLABLE HAEGS
D578 HANGUL SYLLABLE HAEN
D579 HANGUL SYLLABLE HAENJ
D57A HANGUL SYLLABLE HAENH
D57B HANGUL SYLLABLE HAED
D57C HANGUL SYLLABLE HAEL
D57D HANGUL SYLLABLE HAELG
D57E HANGUL SYLLABLE HAELM
D57F HANGUL SYLLABLE HAELB
D580 HANGUL SYLLABLE HAELS
D581 HANGUL SYLLABLE HAELT
D582 HANGUL SYLLABLE HAELP
D583 HANGUL SYLLABLE HAELH
D584 HANGUL SYLLABLE HAEM
D585 HANGUL SYLLABLE HAEB
D586 HANGUL SYLLABLE HAEBS
D587 HANGUL SYLLABLE HAES
D588 HANGUL SYLLABLE HAESS
D589 HANGUL SYLLABLE HAENG
D58A HANGUL SYLLABLE HAEJ
D58B HANGUL SYLLABLE HAEC
D58C HANGUL SYLLABLE HAEK
D58D HANGUL SYLLABLE HAET
D58E HANGUL SYLLABLE HAEP
D58F HANGUL SYLLABLE HAEH
D590 HANGUL SYLLABLE HYA
D591 HANGUL SYLLABLE HYAG
D592 HANGUL SYLLABLE HYAGG
D593 HANGUL SYLLABLE HYAGS
D594 HANGUL SYLLABLE HYAN
D595 HANGUL SYLLABLE HYANJ
D596 HANGUL SYLLABLE HYANH
D597 HANGUL SYLLABLE HYAD
D598 HANGUL SYLLABLE HYAL
D599 HANGUL SYLLABLE HYALG
D59A HANGUL SYLLABLE HYALM
D59B HANGUL SYLLABLE HYALB
D59C HANGUL SYLLABLE HYALS
D59D HANGUL SYLLABLE HYALT
D59E HANGUL SYLLABLE HYALP
D59F HANGUL SYLLABLE HYALH
D5A0 HANGUL SYLLABLE HYAM
D5A1 HANGUL SYLLABLE HYAB
D5A2 HANGUL SYLLABLE HYABS
D5A3 HANGUL SYLLABLE HYAS
D5A4 HANGUL SYLLABLE HYASS
D5A5 HANGUL SYLLABLE HYANG
D5A6 HANGUL SYLLABLE HYAJ
D5A7 HANGUL SYLLABLE HYAC
D5A8 HANGUL SYLLABLE HYAK
D5A9 HANGUL SYLLABLE HYAT
D5AA HANGUL SYLLABLE HYAP
D5AB HANGUL SYLLABLE HYAH
D5AC HANGUL SYLLABLE HYAE
D5AD HANGUL SYLLABLE HYAEG
D5AE HANGUL SYLLABLE HYAEGG
D5AF HANGUL SYLLABLE HYAEGS
D5B0 HANGUL SYLLABLE HYAEN
D5B1 HANGUL SYLLABLE HYAENJ
D5B2 HANGUL SYLLABLE HYAENH
D5B3 HANGUL SYLLABLE HYAED
D5B4 HANGUL SYLLABLE HYAEL
D5B5 HANGUL SYLLABLE HYAELG
D5B6 HANGUL SYLLABLE HYAELM
D5B7 HANGUL SYLLABLE HYAELB
D5B8 HANGUL SYLLABLE HYAELS
D5B9 HANGUL SYLLABLE HYAELT
D5BA HANGUL SYLLABLE HYAELP
D5BB HANGUL SYLLABLE HYAELH
D5BC HANGUL SYLLABLE HYAEM
D5BD HANGUL SYLLABLE HYAEB
D5BE HANGUL SYLLABLE HYAEBS
D5BF HANGUL SYLLABLE HYAES
D5C0 HANGUL SYLLABLE HYAESS
D5C1 HANGUL SYLLABLE HYAENG
D5C2 HANGUL SYLLABLE HYAEJ
D5C3 HANGUL SYLLABLE HYAEC
D5C4 HANGUL SYLLABLE HYAEK
D5C5 HANGUL SYLLABLE HYAET
D5C6 HANGUL SYLLABLE HYAEP
D5C7 HANGUL SYLLABLE HYAEH
D5C8 HANGUL SYLLABLE HEO
D5C9 HANGUL SYLLABLE HEOG
D5CA HANGUL SYLLABLE HEOGG
D5CB HANGUL SYLLABLE HEOGS
D5CC HANGUL SYLLABLE HEON
D5CD HANGUL SYLLABLE HEONJ
D5CE HANGUL SYLLABLE HEONH
D5CF HANGUL SYLLABLE HEOD
D5D0 HANGUL SYLLABLE HEOL
D5D1 HANGUL SYLLABLE HEOLG
D5D2 HANGUL SYLLABLE HEOLM
D5D3 HANGUL SYLLABLE HEOLB
D5D4 HANGUL SYLLABLE HEOLS
D5D5 HANGUL SYLLABLE HEOLT
D5D6 HANGUL SYLLABLE HEOLP
D5D7 HANGUL SYLLABLE HEOLH
D5D8 HANGUL SYLLABLE HEOM
D5D9 HANGUL SYLLABLE HEOB
D5DA HANGUL SYLLABLE HEOBS
D5DB HANGUL SYLLABLE HEOS
D5DC HANGUL SYLLABLE HEOSS
D5DD HANGUL SYLLABLE HEONG
D5DE HANGUL SYLLABLE HEOJ
D5DF HANGUL SYLLABLE HEOC
D5E0 HANGUL SYLLABLE HEOK
D5E1 HANGUL SYLLABLE HEOT
D5E2 HANGUL SYLLABLE HEOP
D5E3 HANGUL SYLLABLE HEOH
D5E4 HANGUL SYLLABLE HE
D5E5 HANGUL SYLLABLE HEG
D5E6 HANGUL SYLLABLE HEGG
D5E7 HANGUL SYLLABLE HEGS
D5E8 HANGUL SYLLABLE HEN
D5E9 HANGUL SYLLABLE HENJ
D5EA HANGUL SYLLABLE HENH
D5EB HANGUL SYLLABLE HED
D5EC HANGUL SYLLABLE HEL
D5ED HANGUL SYLLABLE HELG
D5EE HANGUL SYLLABLE HELM
D5EF HANGUL SYLLABLE HELB
D5F0 HANGUL SYLLABLE HELS
D5F1 HANGUL SYLLABLE HELT
D5F2 HANGUL SYLLABLE HELP
D5F3 HANGUL SYLLABLE HELH
D5F4 HANGUL SYLLABLE HEM
D5F5 HANGUL SYLLABLE HEB
D5F6 HANGUL SYLLABLE HEBS
D5F7 HANGUL SYLLABLE HES
D5F8 HANGUL SYLLABLE HESS
D5F9 HANGUL SYLLABLE HENG
D5FA HANGUL SYLLABLE HEJ
D5FB HANGUL SYLLABLE HEC
D5FC HANGUL SYLLABLE HEK
D5FD HANGUL SYLLABLE HET
D5FE HANGUL SYLLABLE HEP
D5FF HANGUL SYLLABLE HEH
D600 HANGUL SYLLABLE HYEO
D601 HANGUL SYLLABLE HYEOG
D602 HANGUL SYLLABLE HYEOGG
D603 HANGUL SYLLABLE HYEOGS
D604 HANGUL SYLLABLE HYEON
D605 HANGUL SYLLABLE HYEONJ
D606 HANGUL SYLLABLE HYEONH
D607 HANGUL SYLLABLE HYEOD
D608 HANGUL SYLLABLE HYEOL
D609 HANGUL SYLLABLE HYEOLG
D60A HANGUL SYLLABLE HYEOLM
D60B HANGUL SYLLABLE HYEOLB
D60C HANGUL SYLLABLE HYEOLS
D60D HANGUL SYLLABLE HYEOLT
D60E HANGUL SYLLABLE HYEOLP
D60F HANGUL SYLLABLE HYEOLH
D610 HANGUL SYLLABLE HYEOM
D611 HANGUL SYLLABLE HYEOB
D612 HANGUL SYLLABLE HYEOBS
D613 HANGUL SYLLABLE HYEOS
D614 HANGUL SYLLABLE HYEOSS
D615 HANGUL SYLLABLE HYEONG
D616 HANGUL SYLLABLE HYEOJ
D617 HANGUL SYLLABLE HYEOC
D618 HANGUL SYLLABLE HYEOK
D619 HANGUL SYLLABLE HYEOT
D61A HANGUL SYLLABLE HYEOP
D61B HANGUL SYLLABLE HYEOH
D61C HANGUL SYLLABLE HYE
D61D HANGUL SYLLABLE HYEG
D61E HANGUL SYLLABLE HYEGG
D61F HANGUL SYLLABLE HYEGS
D620 HANGUL SYLLABLE HYEN
D621 HANGUL SYLLABLE HYENJ
D622 HANGUL SYLLABLE HYENH
D623 HANGUL SYLLABLE HYED
D624 HANGUL SYLLABLE HYEL
D625 HANGUL SYLLABLE HYELG
D626 HANGUL SYLLABLE HYELM
D627 HANGUL SYLLABLE HYELB
D628 HANGUL SYLLABLE HYELS
D629 HANGUL SYLLABLE HYELT
D62A HANGUL SYLLABLE HYELP
D62B HANGUL SYLLABLE HYELH
D62C HANGUL SYLLABLE HYEM
D62D HANGUL SYLLABLE HYEB
D62E HANGUL SYLLABLE HYEBS
D62F HANGUL SYLLABLE HYES
D630 HANGUL SYLLABLE HYESS
D631 HANGUL SYLLABLE HYENG
D632 HANGUL SYLLABLE HYEJ
D633 HANGUL SYLLABLE HYEC
D634 HANGUL SYLLABLE HYEK
D635 HANGUL SYLLABLE HYET
D636 HANGUL SYLLABLE HYEP
D637 HANGUL SYLLABLE HYEH
D638 HANGUL SYLLABLE HO
D639 HANGUL SYLLABLE HOG
D63A HANGUL SYLLABLE HOGG
D63B HANGUL SYLLABLE HOGS
D63C HANGUL SYLLABLE HON
D63D HANGUL SYLLABLE HONJ
D63E HANGUL SYLLABLE HONH
D63F HANGUL SYLLABLE HOD
D640 HANGUL SYLLABLE HOL
D641 HANGUL SYLLABLE HOLG
D642 HANGUL SYLLABLE HOLM
D643 HANGUL SYLLABLE HOLB
D644 HANGUL SYLLABLE HOLS
D645 HANGUL SYLLABLE HOLT
D646 HANGUL SYLLABLE HOLP
D647 HANGUL SYLLABLE HOLH
D648 HANGUL SYLLABLE HOM
D649 HANGUL SYLLABLE HOB
D64A HANGUL SYLLABLE HOBS
D64B HANGUL SYLLABLE HOS
D64C HANGUL SYLLABLE HOSS
D64D HANGUL SYLLABLE HONG
D64E HANGUL SYLLABLE HOJ
D64F HANGUL SYLLABLE HOC
D650 HANGUL SYLLABLE HOK
D651 HANGUL SYLLABLE HOT
D652 HANGUL SYLLABLE HOP
D653 HANGUL SYLLABLE HOH
D654 HANGUL SYLLABLE HWA
D655 HANGUL SYLLABLE HWAG
D656 HANGUL SYLLABLE HWAGG
D657 HANGUL SYLLABLE HWAGS
D658 HANGUL SYLLABLE HWAN
D659 HANGUL SYLLABLE HWANJ
D65A HANGUL SYLLABLE HWANH
D65B HANGUL SYLLABLE HWAD
D65C HANGUL SYLLABLE HWAL
D65D HANGUL SYLLABLE HWALG
D65E HANGUL SYLLABLE HWALM
D65F HANGUL SYLLABLE HWALB
D660 HANGUL SYLLABLE HWALS
D661 HANGUL SYLLABLE HWALT
D662 HANGUL SYLLABLE HWALP
D663 HANGUL SYLLABLE HWALH
D664 HANGUL SYLLABLE HWAM
D665 HANGUL SYLLABLE HWAB
D666 HANGUL SYLLABLE HWABS
D667 HANGUL SYLLABLE HWAS
D668 HANGUL SYLLABLE HWASS
D669 HANGUL SYLLABLE HWANG
D66A HANGUL SYLLABLE HWAJ
D66B HANGUL SYLLABLE HWAC
D66C HANGUL SYLLABLE HWAK
D66D HANGUL SYLLABLE HWAT
D66E HANGUL SYLLABLE HWAP
D66F HANGUL SYLLABLE HWAH
D670 HANGUL SYLLABLE HWAE
D671 HANGUL SYLLABLE HWAEG
D672 HANGUL SYLLABLE HWAEGG
D673 HANGUL SYLLABLE HWAEGS
D674 HANGUL SYLLABLE HWAEN
D675 HANGUL SYLLABLE HWAENJ
D676 HANGUL SYLLABLE HWAENH
D677 HANGUL SYLLABLE HWAED
D678 HANGUL SYLLABLE HWAEL
D679 HANGUL SYLLABLE HWAELG
D67A HANGUL SYLLABLE HWAELM
D67B HANGUL SYLLABLE HWAELB
D67C HANGUL SYLLABLE HWAELS
D67D HANGUL SYLLABLE HWAELT
D67E HANGUL SYLLABLE HWAELP
D67F HANGUL SYLLABLE HWAELH
D680 HANGUL SYLLABLE HWAEM
D681 HANGUL SYLLABLE HWAEB
D682 HANGUL SYLLABLE HWAEBS
D683 HANGUL SYLLABLE HWAES
D684 HANGUL SYLLABLE HWAESS
D685 HANGUL SYLLABLE HWAENG
D686 HANGUL SYLLABLE HWAEJ
D687 HANGUL SYLLABLE HWAEC
D688 HANGUL SYLLABLE HWAEK
D689 HANGUL SYLLABLE HWAET
D68A HANGUL SYLLABLE HWAEP
D68B HANGUL SYLLABLE HWAEH
D68C HANGUL SYLLABLE HOE
D68D HANGUL SYLLABLE HOEG
D68E HANGUL SYLLABLE HOEGG
D68F HANGUL SYLLABLE HOEGS
D690 HANGUL SYLLABLE HOEN
D691 HANGUL SYLLABLE HOENJ
D692 HANGUL SYLLABLE HOENH
D693 HANGUL SYLLABLE HOED
D694 HANGUL SYLLABLE HOEL
D695 HANGUL SYLLABLE HOELG
D696 HANGUL SYLLABLE HOELM
D697 HANGUL SYLLABLE HOELB
D698 HANGUL SYLLABLE HOELS
D699 HANGUL SYLLABLE HOELT
D69A HANGUL SYLLABLE HOELP
D69B HANGUL SYLLABLE HOELH
D69C HANGUL SYLLABLE HOEM
D69D HANGUL SYLLABLE HOEB
D69E HANGUL SYLLABLE HOEBS
D69F HANGUL SYLLABLE HOES
D6A0 HANGUL SYLLABLE HOESS
D6A1 HANGUL SYLLABLE HOENG
D6A2 HANGUL SYLLABLE HOEJ
D6A3 HANGUL SYLLABLE HOEC
D6A4 HANGUL SYLLABLE HOEK
D6A5 HANGUL SYLLABLE HOET
D6A6 HANGUL SYLLABLE HOEP
D6A7 HANGUL SYLLABLE HOEH
D6A8 HANGUL SYLLABLE HYO
D6A9 HANGUL SYLLABLE HYOG
D6AA HANGUL SYLLABLE HYOGG
D6AB HANGUL SYLLABLE HYOGS
D6AC HANGUL SYLLABLE HYON
D6AD HANGUL SYLLABLE HYONJ
D6AE HANGUL SYLLABLE HYONH
D6AF HANGUL SYLLABLE HYOD
D6B0 HANGUL SYLLABLE HYOL
D6B1 HANGUL SYLLABLE HYOLG
D6B2 HANGUL SYLLABLE HYOLM
D6B3 HANGUL SYLLABLE HYOLB
D6B4 HANGUL SYLLABLE HYOLS
D6B5 HANGUL SYLLABLE HYOLT
D6B6 HANGUL SYLLABLE HYOLP
D6B7 HANGUL SYLLABLE HYOLH
D6B8 HANGUL SYLLABLE HYOM
D6B9 HANGUL SYLLABLE HYOB
D6BA HANGUL SYLLABLE HYOBS
D6BB HANGUL SYLLABLE HYOS
D6BC HANGUL SYLLABLE HYOSS
D6BD HANGUL SYLLABLE HYONG
D6BE HANGUL SYLLABLE HYOJ
D6BF HANGUL SYLLABLE HYOC
D6C0 HANGUL SYLLABLE HYOK
D6C1 HANGUL SYLLABLE HYOT
D6C2 HANGUL SYLLABLE HYOP
D6C3 HANGUL SYLLABLE HYOH
D6C4 HANGUL SYLLABLE HU
D6C5 HANGUL SYLLABLE HUG
D6C6 HANGUL SYLLABLE HUGG
D6C7 HANGUL SYLLABLE HUGS
D6C8 HANGUL SYLLABLE HUN
D6C9 HANGUL SYLLABLE HUNJ
D6CA HANGUL SYLLABLE HUNH
D6CB HANGUL SYLLABLE HUD
D6CC HANGUL SYLLABLE HUL
D6CD HANGUL SYLLABLE HULG
D6CE HANGUL SYLLABLE HULM
D6CF HANGUL SYLLABLE HULB
D6D0 HANGUL SYLLABLE HULS
D6D1 HANGUL SYLLABLE HULT
D6D2 HANGUL SYLLABLE HULP
D6D3 HANGUL SYLLABLE HULH
D6D4 HANGUL SYLLABLE HUM
D6D5 HANGUL SYLLABLE HUB
D6D6 HANGUL SYLLABLE HUBS
D6D7 HANGUL SYLLABLE HUS
D6D8 HANGUL SYLLABLE HUSS
D6D9 HANGUL SYLLABLE HUNG
D6DA HANGUL SYLLABLE HUJ
D6DB HANGUL SYLLABLE HUC
D6DC HANGUL SYLLABLE HUK
D6DD HANGUL SYLLABLE HUT
D6DE HANGUL SYLLABLE HUP
D6DF HANGUL SYLLABLE HUH
D6E0 HANGUL SYLLABLE HWEO
D6E1 HANGUL SYLLABLE HWEOG
D6E2 HANGUL SYLLABLE HWEOGG
D6E3 HANGUL SYLLABLE HWEOGS
D6E4 HANGUL SYLLABLE HWEON
D6E5 HANGUL SYLLABLE HWEONJ
D6E6 HANGUL SYLLABLE HWEONH
D6E7 HANGUL SYLLABLE HWEOD
D6E8 HANGUL SYLLABLE HWEOL
D6E9 HANGUL SYLLABLE HWEOLG
D6EA HANGUL SYLLABLE HWEOLM
D6EB HANGUL SYLLABLE HWEOLB
D6EC HANGUL SYLLABLE HWEOLS
D6ED HANGUL SYLLABLE HWEOLT
D6EE HANGUL SYLLABLE HWEOLP
D6EF HANGUL SYLLABLE HWEOLH
D6F0 HANGUL SYLLABLE HWEOM
D6F1 HANGUL SYLLABLE HWEOB
D6F2 HANGUL SYLLABLE HWEOBS
D6F3 HANGUL SYLLABLE HWEOS
D6F4 HANGUL SYLLABLE HWEOSS
D6F5 HANGUL SYLLABLE HWEONG
D6F6 HANGUL SYLLABLE HWEOJ
D6F7 HANGUL SYLLABLE HWEOC
D6F8 HANGUL SYLLABLE HWEOK
D6F9 HANGUL SYLLABLE HWEOT
D6FA HANGUL SYLLABLE HWEOP
D6FB HANGUL SYLLABLE HWEOH
D6FC HANGUL SYLLABLE HWE
D6FD HANGUL SYLLABLE HWEG
D6FE HANGUL SYLLABLE HWEGG
D6FF HANGUL SYLLABLE HWEGS
D700 HANGUL SYLLABLE HWEN
D701 HANGUL SYLLABLE HWENJ
D702 HANGUL SYLLABLE HWENH
D703 HANGUL SYLLABLE HWED
D704 HANGUL SYLLABLE HWEL
D705 HANGUL SYLLABLE HWELG
D706 HANGUL SYLLABLE HWELM
D707 HANGUL SYLLABLE HWELB
D708 HANGUL SYLLABLE HWELS
D709 HANGUL SYLLABLE HWELT
D70A HANGUL SYLLABLE HWELP
D70B HANGUL SYLLABLE HWELH
D70C HANGUL SYLLABLE HWEM
D70D HANGUL SYLLABLE HWEB
D70E HANGUL SYLLABLE HWEBS
D70F HANGUL SYLLABLE HWES
D710 HANGUL SYLLABLE HWESS
D711 HANGUL SYLLABLE HWENG
D712 HANGUL SYLLABLE HWEJ
D713 HANGUL SYLLABLE HWEC
D714 HANGUL SYLLABLE HWEK
D715 HANGUL SYLLABLE HWET
D716 HANGUL SYLLABLE HWEP
D717 HANGUL SYLLABLE HWEH
D718 HANGUL SYLLABLE HWI
D719 HANGUL SYLLABLE HWIG
D71A HANGUL SYLLABLE HWIGG
D71B HANGUL SYLLABLE HWIGS
D71C HANGUL SYLLABLE HWIN
D71D HANGUL SYLLABLE HWINJ
D71E HANGUL SYLLABLE HWINH
D71F HANGUL SYLLABLE HWID
D720 HANGUL SYLLABLE HWIL
D721 HANGUL SYLLABLE HWILG
D722 HANGUL SYLLABLE HWILM
D723 HANGUL SYLLABLE HWILB
D724 HANGUL SYLLABLE HWILS
D725 HANGUL SYLLABLE HWILT
D726 HANGUL SYLLABLE HWILP
D727 HANGUL SYLLABLE HWILH
D728 HANGUL SYLLABLE HWIM
D729 HANGUL SYLLABLE HWIB
D72A HANGUL SYLLABLE HWIBS
D72B HANGUL SYLLABLE HWIS
D72C HANGUL SYLLABLE HWISS
D72D HANGUL SYLLABLE HWING
D72E HANGUL SYLLABLE HWIJ
D72F HANGUL SYLLABLE HWIC
D730 HANGUL SYLLABLE HWIK
D731 HANGUL SYLLABLE HWIT
D732 HANGUL SYLLABLE HWIP
D733 HANGUL SYLLABLE HWIH
D734 HANGUL SYLLABLE HYU
D735 HANGUL SYLLABLE HYUG
D736 HANGUL SYLLABLE HYUGG
D737 HANGUL SYLLABLE HYUGS
D738 HANGUL SYLLABLE HYUN
D739 HANGUL SYLLABLE HYUNJ
D73A HANGUL SYLLABLE HYUNH
D73B HANGUL SYLLABLE HYUD
D73C HANGUL SYLLABLE HYUL
D73D HANGUL SYLLABLE HYULG
D73E HANGUL SYLLABLE HYULM
D73F HANGUL SYLLABLE HYULB
D740 HANGUL SYLLABLE HYULS
D741 HANGUL SYLLABLE HYULT
D742 HANGUL SYLLABLE HYULP
D743 HANGUL SYLLABLE HYULH
D744 HANGUL SYLLABLE HYUM
D745 HANGUL SYLLABLE HYUB
D746 HANGUL SYLLABLE HYUBS
D747 HANGUL SYLLABLE HYUS
D748 HANGUL SYLLABLE HYUSS
D749 HANGUL SYLLABLE HYUNG
D74A HANGUL SYLLABLE HYUJ
D74B HANGUL SYLLABLE HYUC
D74C HANGUL SYLLABLE HYUK
D74D HANGUL SYLLABLE HYUT
D74E HANGUL SYLLABLE HYUP
D74F HANGUL SYLLABLE HYUH
D750 HANGUL SYLLABLE HEU
D751 HANGUL SYLLABLE HEUG
D752 HANGUL SYLLABLE HEUGG
D753 HANGUL SYLLABLE HEUGS
D754 HANGUL SYLLABLE HEUN
D755 HANGUL SYLLABLE HEUNJ
D756 HANGUL SYLLABLE HEUNH
D757 HANGUL SYLLABLE HEUD
D758 HANGUL SYLLABLE HEUL
D759 HANGUL SYLLABLE HEULG
D75A HANGUL SYLLABLE HEULM
D75B HANGUL SYLLABLE HEULB
D75C HANGUL SYLLABLE HEULS
D75D HANGUL SYLLABLE HEULT
D75E HANGUL SYLLABLE HEULP
D75F HANGUL SYLLABLE HEULH
D760 HANGUL SYLLABLE HEUM
D761 HANGUL SYLLABLE HEUB
D762 HANGUL SYLLABLE HEUBS
D763 HANGUL SYLLABLE HEUS
D764 HANGUL SYLLABLE HEUSS
D765 HANGUL SYLLABLE HEUNG
D766 HANGUL SYLLABLE HEUJ
D767 HANGUL SYLLABLE HEUC
D768 HANGUL SYLLABLE HEUK
D769 HANGUL SYLLABLE HEUT
D76A HANGUL SYLLABLE HEUP
D76B HANGUL SYLLABLE HEUH
D76C HANGUL SYLLABLE HYI
D76D HANGUL SYLLABLE HYIG
D76E HANGUL SYLLABLE HYIGG
D76F HANGUL SYLLABLE HYIGS
D770 HANGUL SYLLABLE HYIN
D771 HANGUL SYLLABLE HYINJ
D772 HANGUL SYLLABLE HYINH
D773 HANGUL SYLLABLE HYID
D774 HANGUL SYLLABLE HYIL
D775 HANGUL SYLLABLE HYILG
D776 HANGUL SYLLABLE HYILM
D777 HANGUL SYLLABLE HYILB
D778 HANGUL SYLLABLE HYILS
D779 HANGUL SYLLABLE HYILT
D77A HANGUL SYLLABLE HYILP
D77B HANGUL SYLLABLE HYILH
D77C HANGUL SYLLABLE HYIM
D77D HANGUL SYLLABLE HYIB
D77E HANGUL SYLLABLE HYIBS
D77F HANGUL SYLLABLE HYIS
D780 HANGUL SYLLABLE HYISS
D781 HANGUL SYLLABLE HYING
D782 HANGUL SYLLABLE HYIJ
D783 HANGUL SYLLABLE HYIC
D784 HANGUL SYLLABLE HYIK
D785 HANGUL SYLLABLE HYIT
D786 HANGUL SYLLABLE HYIP
D787 HANGUL SYLLABLE HYIH
D788 HANGUL SYLLABLE HI
D789 HANGUL SYLLABLE HIG
D78A HANGUL SYLLABLE HIGG
D78B HANGUL SYLLABLE HIGS
D78C HANGUL SYLLABLE HIN
D78D HANGUL SYLLABLE HINJ
D78E HANGUL SYLLABLE HINH
D78F HANGUL SYLLABLE HID
D790 HANGUL SYLLABLE HIL
D791 HANGUL SYLLABLE HILG
D792 HANGUL SYLLABLE HILM
D793 HANGUL SYLLABLE HILB
D794 HANGUL SYLLABLE HILS
D795 HANGUL SYLLABLE HILT
D796 HANGUL SYLLABLE HILP
D797 HANGUL SYLLABLE HILH
D798 HANGUL SYLLABLE HIM
D799 HANGUL SYLLABLE HIB
D79A HANGUL SYLLABLE HIBS
D79B HANGUL SYLLABLE HIS
D79C HANGUL SYLLABLE HISS
D79D HANGUL SYLLABLE HING
D79E HANGUL SYLLABLE HIJ
D79F HANGUL SYLLABLE HIC
D7A0 HANGUL SYLLABLE HIK
D7A1 HANGUL SYLLABLE HIT
D7A2 HANGUL SYLLABLE HIP
D7A3 HANGUL SYLLABLE HIH
D7B0 HANGUL JUNGSEONG O-YEO
D7B1 HANGUL JUNGSEONG O-O-I
D7B2 HANGUL JUNGSEONG YO-A
D7B3 HANGUL JUNGSEONG YO-AE
D7B4 HANGUL JUNGSEONG YO-EO
D7B5 HANGUL JUNGSEONG U-YEO
D7B6 HANGUL JUNGSEONG U-I-I
D7B7 HANGUL JUNGSEONG YU-AE
D7B8 HANGUL JUNGSEONG YU-O
D7B9 HANGUL JUNGSEONG EU-A
D7BA HANGUL JUNGSEONG EU-EO
D7BB HANGUL JUNGSEONG EU-E
D7BC HANGUL JUNGSEONG EU-O
D7BD HANGUL JUNGSEONG I-YA-O
D7BE HANGUL JUNGSEONG I-YAE
D7BF HANGUL JUNGSEONG I-YEO
D7C0 HANGUL JUNGSEONG I-YE
D7C1 HANGUL JUNGSEONG I-O-I
D7C2 HANGUL JUNGSEONG I-YO
D7C3 HANGUL JUNGSEONG I-YU
D7C4 HANGUL JUNGSEONG I-I
D7C5 HANGUL JUNGSEONG ARAEA-A
D7C6 HANGUL JUNGSEONG ARAEA-E
D7CB HANGUL JONGSEONG NIEUN-RIEUL
D7CC HANGUL JONGSEONG NIEUN-CHIEUCH
D7CD HANGUL JONGSEONG SSANGTIKEUT
D7CE HANGUL JONGSEONG SSANGTIKEUT-PIEUP
D7CF HANGUL JONGSEONG TIKEUT-PIEUP
D7D0 HANGUL JONGSEONG TIKEUT-SIOS
D7D1 HANGUL JONGSEONG TIKEUT-SIOS-KIYEOK
D7D2 HANGUL JONGSEONG TIKEUT-CIEUC
D7D3 HANGUL JONGSEONG TIKEUT-CHIEUCH
D7D4 HANGUL JONGSEONG TIKEUT-THIEUTH
D7D5 HANGUL JONGSEONG RIEUL-SSANGKIYEOK
D7D6 HANGUL JONGSEONG RIEUL-KIYEOK-HIEUH
D7D7 HANGUL JONGSEONG SSANGRIEUL-KHIEUKH
D7D8 HANGUL JONGSEONG RIEUL-MIEUM-HIEUH
D7D9 HANGUL JONGSEONG RIEUL-PIEUP-TIKEUT
D7DA HANGUL JONGSEONG RIEUL-PIEUP-PHIEUPH
D7DB HANGUL JONGSEONG RIEUL-YESIEUNG
D7DC HANGUL JONGSEONG RIEUL-YEORINHIEUH-HIEUH
D7DD HANGUL JONGSEONG KAPYEOUNRIEUL
D7DE HANGUL JONGSEONG MIEUM-NIEUN
D7DF HANGUL JONGSEONG MIEUM-SSANGNIEUN
D7E0 HANGUL JONGSEONG SSANGMIEUM
D7E1 HANGUL JONGSEONG MIEUM-PIEUP-SIOS
D7E2 HANGUL JONGSEONG MIEUM-CIEUC
D7E3 HANGUL JONGSEONG PIEUP-TIKEUT
D7E4 HANGUL JONGSEONG PIEUP-RIEUL-PHIEUPH
D7E5 HANGUL JONGSEONG PIEUP-MIEUM
D7E6 HANGUL JONGSEONG SSANGPIEUP
D7E7 HANGUL JONGSEONG PIEUP-SIOS-TIKEUT
D7E8 HANGUL JONGSEONG PIEUP-CIEUC
D7E9 HANGUL JONGSEONG PIEUP-CHIEUCH
D7EA HANGUL JONGSEONG SIOS-MIEUM
D7EB HANGUL JONGSEONG SIOS-KAPYEOUNPIEUP
D7EC HANGUL JONGSEONG SSANGSIOS-KIYEOK
D7ED HANGUL JONGSEONG SSANGSIOS-TIKEUT
D7EE HANGUL JONGSEONG SIOS-PANSIOS
D7EF HANGUL JONGSEONG SIOS-CIEUC
D7F0 HANGUL JONGSEONG SIOS-CHIEUCH
D7F1 HANGUL JONGSEONG SIOS-THIEUTH
D7F2 HANGUL JONGSEONG SIOS-HIEUH
D7F3 HANGUL JONGSEONG PANSIOS-PIEUP
D7F4 HANGUL JONGSEONG PANSIOS-KAPYEOUNPIEUP
D7F5 HANGUL JONGSEONG YESIEUNG-MIEUM
D7F6 HANGUL JONGSEONG YESIEUNG-HIEUH
D7F7 HANGUL JONGSEONG CIEUC-PIEUP
D7F8 HANGUL JONGSEONG CIEUC-SSANGPIEUP
D7F9 HANGUL JONGSEONG SSANGCIEUC
D7FA HANGUL JONGSEONG PHIEUPH-SIOS
D7FB HANGUL JONGSEONG PHIEUPH-THIEUTH
F900 CJK COMPATIBILITY IDEOGRAPH-#F900, RSKangXi=151.3, Def{how? what?}
F901 CJK COMPATIBILITY IDEOGRAPH-#F901, RSKangXi=73.3, Def{more, still further, much more}
F902 CJK COMPATIBILITY IDEOGRAPH-#F902, RSKangXi=159.0, Def{cart, vehicle; carry in cart}
F903 CJK COMPATIBILITY IDEOGRAPH-#F903, RSKangXi=154.6, Def{surname; merchant; buy, trade}
F904 CJK COMPATIBILITY IDEOGRAPH-#F904, RSKangXi=85.10, Def{slip, slide; slippery, polished}
F905 CJK COMPATIBILITY IDEOGRAPH-#F905, RSKangXi=2.6, Def{string; relatives; conspire}
F906 CJK COMPATIBILITY IDEOGRAPH-#F906, RSKangXi=30.2, Def{sentence}
F907 CJK COMPATIBILITY IDEOGRAPH-#F907, RSKangXi=213.0, Def{turtle or tortoise; cuckold}
F908 CJK COMPATIBILITY IDEOGRAPH-#F908, RSKangXi=213.0, Def{turtle or tortoise; cuckold}
F909 CJK COMPATIBILITY IDEOGRAPH-#F909, RSKangXi=37.6, Def{deed, contract, bond; engrave}
F90A CJK COMPATIBILITY IDEOGRAPH-#F90A, RSKangXi=167.0, Def{gold; metals in general; money}
F90B CJK COMPATIBILITY IDEOGRAPH-#F90B, RSKangXi=30.9, Def{horn, bugle; lama; final particle}
F90C CJK COMPATIBILITY IDEOGRAPH-#F90C, RSKangXi=37.5, Def{but, how; bear, stand, endure}
F90D CJK COMPATIBILITY IDEOGRAPH-#F90D, RSKangXi=61.16, Def{lazy, languid, listless}
F90E CJK COMPATIBILITY IDEOGRAPH-#F90E, RSKangXi=104.16, Def{leprosy, scabies, mange; shoddy}
F90F CJK COMPATIBILITY IDEOGRAPH-#F90F, RSKangXi=122.14, Def{net for catching birds; gauze}
F910 CJK COMPATIBILITY IDEOGRAPH-#F910, RSKangXi=140.19, Def{type of creeping plant; turnip}
F911 CJK COMPATIBILITY IDEOGRAPH-#F911, RSKangXi=142.11, Def{spiral shell; conch; spiral}
F912 CJK COMPATIBILITY IDEOGRAPH-#F912, RSKangXi=145.8, Def{bare, nude; undress, strip}
F913 CJK COMPATIBILITY IDEOGRAPH-#F913, RSKangXi=162.19, Def{patrol; inspect; watch}
F914 CJK COMPATIBILITY IDEOGRAPH-#F914, RSKangXi=75.11, Def{happy, glad; enjoyable; music}
F915 CJK COMPATIBILITY IDEOGRAPH-#F915, RSKangXi=85.6, Def{river in Shanxi province; city}
F916 CJK COMPATIBILITY IDEOGRAPH-#F916, RSKangXi=86.6, Def{brand, burn; branding iron}
F917 CJK COMPATIBILITY IDEOGRAPH-#F917, RSKangXi=96.6, Def{kind of necklace}
F918 CJK COMPATIBILITY IDEOGRAPH-#F918, RSKangXi=140.9, Def{fall, drop; net income, surplus}
F919 CJK COMPATIBILITY IDEOGRAPH-#F919, RSKangXi=164.6, Def{cream, cheese; koumiss}
F91A CJK COMPATIBILITY IDEOGRAPH-#F91A, RSKangXi=187.6, Def{white horse with black mane; camel}
F91B CJK COMPATIBILITY IDEOGRAPH-#F91B, RSKangXi=5.12, Def{confusion, state of chaos; create chaos, revolt}
F91C CJK COMPATIBILITY IDEOGRAPH-#F91C, RSKangXi=26.5, Def{egg; ovum; roe; spawn}
F91D CJK COMPATIBILITY IDEOGRAPH-#F91D, RSKangXi=75.17, Def{railing, balustrade; animal pan}
F91E CJK COMPATIBILITY IDEOGRAPH-#F91E, RSKangXi=86.17, Def{rotten, spoiled, decayed}
F91F CJK COMPATIBILITY IDEOGRAPH-#F91F, RSKangXi=140.17, Def{orchid; elegant, graceful}
F920 CJK COMPATIBILITY IDEOGRAPH-#F920, RSKangXi=196.19, Def{fabulous bird}
F921 CJK COMPATIBILITY IDEOGRAPH-#F921, RSKangXi=46.9, Def{mountain mist, mountain haze}
F922 CJK COMPATIBILITY IDEOGRAPH-#F922, RSKangXi=85.14, Def{flood, overflow; excessive}
F923 CJK COMPATIBILITY IDEOGRAPH-#F923, RSKangXi=140.14, Def{blue; indigo plant; surname}
F924 CJK COMPATIBILITY IDEOGRAPH-#F924, RSKangXi=145.14, Def{ragged, tattered, threadbare}
F925 CJK COMPATIBILITY IDEOGRAPH-#F925, RSKangXi=64.5, Def{pull, drag; seize, hold; lengthen}
F926 CJK COMPATIBILITY IDEOGRAPH-#F926, RSKangXi=130.15, Def{year end sacrifice; dried meat}
F927 CJK COMPATIBILITY IDEOGRAPH-#F927, RSKangXi=142.15, Def{wax; candle; waxy, glazed}
F928 CJK COMPATIBILITY IDEOGRAPH-#F928, RSKangXi=53.10, Def{corridor, porch, veranda}
F929 CJK COMPATIBILITY IDEOGRAPH-#F929, RSKangXi=74.6, Def{clear, bright; distinct}
F92A CJK COMPATIBILITY IDEOGRAPH-#F92A, RSKangXi=85.7, Def{wave; wasteful, reckless}
F92B CJK COMPATIBILITY IDEOGRAPH-#F92B, RSKangXi=94.7, Def{wolf}
F92C CJK COMPATIBILITY IDEOGRAPH-#F92C, RSKangXi=163.7, Def{gentleman, young man; husband}
F92D CJK COMPATIBILITY IDEOGRAPH-#F92D, RSKangXi=9.6, Def{come, coming; return, returning}
F92E CJK COMPATIBILITY IDEOGRAPH-#F92E, RSKangXi=15.5, Def{cold, cool; lonely}
F92F CJK COMPATIBILITY IDEOGRAPH-#F92F, RSKangXi=19.10, Def{labor, toil, do manual work}
F930 CJK COMPATIBILITY IDEOGRAPH-#F930, RSKangXi=64.13, Def{capture, seize}
F931 CJK COMPATIBILITY IDEOGRAPH-#F931, RSKangXi=75.15, Def{oar, scull; row}
F932 CJK COMPATIBILITY IDEOGRAPH-#F932, RSKangXi=86.16, Def{fireplace, stove, oven, furnace}
F933 CJK COMPATIBILITY IDEOGRAPH-#F933, RSKangXi=108.11, Def{cottage, hut; surname; black}
F934 CJK COMPATIBILITY IDEOGRAPH-#F934, RSKangXi=125.0, Def{old, aged; experienced}
F935 CJK COMPATIBILITY IDEOGRAPH-#F935, RSKangXi=140.16, Def{rushes, reeds}
F936 CJK COMPATIBILITY IDEOGRAPH-#F936, RSKangXi=141.6, Def{capture, imprison, seize; prison}
F937 CJK COMPATIBILITY IDEOGRAPH-#F937, RSKangXi=157.6, Def{road, path, street; journey}
F938 CJK COMPATIBILITY IDEOGRAPH-#F938, RSKangXi=173.12, Def{dew; bare, open, exposed}
F939 CJK COMPATIBILITY IDEOGRAPH-#F939, RSKangXi=195.4, Def{foolish, stupid, rash; vulgar}
F93A CJK COMPATIBILITY IDEOGRAPH-#F93A, RSKangXi=196.12, Def{heron, egret}
F93B CJK COMPATIBILITY IDEOGRAPH-#F93B, RSKangXi=112.8, Def{rough, uneven, rocky; mediocre}
F93C CJK COMPATIBILITY IDEOGRAPH-#F93C, RSKangXi=113.8, Def{blessing, happiness, prosperity}
F93D CJK COMPATIBILITY IDEOGRAPH-#F93D, RSKangXi=120.8, Def{green; chlorine}
F93E CJK COMPATIBILITY IDEOGRAPH-#F93E, RSKangXi=140.8, Def{the green bamboo; greenish bamboo}
F93F CJK COMPATIBILITY IDEOGRAPH-#F93F, RSKangXi=167.8, Def{copy, write down, record}
F940 CJK COMPATIBILITY IDEOGRAPH-#F940, RSKangXi=198.0, Def{deer; surname; KangXi radical 198}
F941 CJK COMPATIBILITY IDEOGRAPH-#F941, RSKangXi=149.8, Def{debate; discuss; discourse}
F942 CJK COMPATIBILITY IDEOGRAPH-#F942, RSKangXi=32.16, Def{grave, mound; ridge in field}
F943 CJK COMPATIBILITY IDEOGRAPH-#F943, RSKangXi=55.4, Def{do, play or fiddle with; alley}
F944 CJK COMPATIBILITY IDEOGRAPH-#F944, RSKangXi=118.16, Def{cage; cage-like basket}
F945 CJK COMPATIBILITY IDEOGRAPH-#F945, RSKangXi=128.16, Def{deaf}
F946 CJK COMPATIBILITY IDEOGRAPH-#F946, RSKangXi=93.3, Def{prison; stable, pen; secure}
F947 CJK COMPATIBILITY IDEOGRAPH-#F947, RSKangXi=112.10, Def{pile of rocks or stones; great}
F948 CJK COMPATIBILITY IDEOGRAPH-#F948, RSKangXi=154.6, Def{bribe; give present}
F949 CJK COMPATIBILITY IDEOGRAPH-#F949, RSKangXi=173.5, Def{thunder}
F94A CJK COMPATIBILITY IDEOGRAPH-#F94A, RSKangXi=32.15, Def{rampart, military wall}
F94B CJK COMPATIBILITY IDEOGRAPH-#F94B, RSKangXi=44.11, Def{frequently, often, again and again}
F94C CJK COMPATIBILITY IDEOGRAPH-#F94C, RSKangXi=75.11, Def{building of two or more stories}
F94D CJK COMPATIBILITY IDEOGRAPH-#F94D, RSKangXi=85.8, Def{tears; weep, cry}
F94E CJK COMPATIBILITY IDEOGRAPH-#F94E, RSKangXi=85.11, Def{leak, drip; funnel; hour glass}
F94F CJK COMPATIBILITY IDEOGRAPH-#F94F, RSKangXi=120.5, Def{tired; implicate, involve; bother}
F950 CJK COMPATIBILITY IDEOGRAPH-#F950, RSKangXi=120.11, Def{thread; detailed, precise}
F951 CJK COMPATIBILITY IDEOGRAPH-#F951, RSKangXi=170.6, Def{narrow; crude, coarse; ugly}
F952 CJK COMPATIBILITY IDEOGRAPH-#F952, RSKangXi=19.9, Def{strangle, tighten}
F953 CJK COMPATIBILITY IDEOGRAPH-#F953, RSKangXi=130.2, Def{ribs; chest}
F954 CJK COMPATIBILITY IDEOGRAPH-#F954, RSKangXi=15.13, Def{shiver with cold or fear, fearful}
F955 CJK COMPATIBILITY IDEOGRAPH-#F955, RSKangXi=15.8, Def{pure; virtuous; insult; maltreat}
F956 CJK COMPATIBILITY IDEOGRAPH-#F956, RSKangXi=115.8, Def{corner, edge, angle; square block}
F957 CJK COMPATIBILITY IDEOGRAPH-#F957, RSKangXi=120.8, Def{thin silk, damask silk}
F958 CJK COMPATIBILITY IDEOGRAPH-#F958, RSKangXi=140.8, Def{water-chestnut, water caltrop}
F959 CJK COMPATIBILITY IDEOGRAPH-#F959, RSKangXi=170.8, Def{hill, mound; mausoleum}
F95A CJK COMPATIBILITY IDEOGRAPH-#F95A, RSKangXi=149.15, Def{read, study; pronounce}
F95B CJK COMPATIBILITY IDEOGRAPH-#F95B, RSKangXi=64.5, Def{take; bring; grasp, hold; arrest}
F95C CJK COMPATIBILITY IDEOGRAPH-#F95C, RSKangXi=75.11, Def{happy, glad; enjoyable; music}
F95D CJK COMPATIBILITY IDEOGRAPH-#F95D, RSKangXi=149.9, Def{promise; assent, approve}
F95E CJK COMPATIBILITY IDEOGRAPH-#F95E, RSKangXi=3.3, Def{cinnabar (native HgS); vermilion (artificial HgS used as pigment)}
F95F CJK COMPATIBILITY IDEOGRAPH-#F95F, RSKangXi=40.11, Def{repose, serenity, peace; peaceful}
F960 CJK COMPATIBILITY IDEOGRAPH-#F960, RSKangXi=61.5, Def{anger, rage, passion; angry}
F961 CJK COMPATIBILITY IDEOGRAPH-#F961, RSKangXi=95.6, Def{to lead; ratio; rate; limit}
F962 CJK COMPATIBILITY IDEOGRAPH-#F962, RSKangXi=102.7, Def{different, unusual, strange}
F963 CJK COMPATIBILITY IDEOGRAPH-#F963, RSKangXi=21.3, Def{north; northern; northward}
F964 CJK COMPATIBILITY IDEOGRAPH-#F964, RSKangXi=112.12, Def{a tributary of the Wei river in Shanxi}
F965 CJK COMPATIBILITY IDEOGRAPH-#F965, RSKangXi=9.7, Def{convenience, ease; expedient}
F966 CJK COMPATIBILITY IDEOGRAPH-#F966, RSKangXi=60.9, Def{return; repeat; repeatedly}
F967 CJK COMPATIBILITY IDEOGRAPH-#F967, RSKangXi=1.3, Def{no, not; un-; negative prefix}
F968 CJK COMPATIBILITY IDEOGRAPH-#F968, RSKangXi=85.5, Def{to seep out, excrete}
F969 CJK COMPATIBILITY IDEOGRAPH-#F969, RSKangXi=66.11, Def{number; several; count; fate}
F96A CJK COMPATIBILITY IDEOGRAPH-#F96A, RSKangXi=120.4, Def{large rope, cable; rules, laws}
F96B CJK COMPATIBILITY IDEOGRAPH-#F96B, RSKangXi=28.9, Def{take part in, intervene}
F96C CJK COMPATIBILITY IDEOGRAPH-#F96C, RSKangXi=32.10, Def{stop up, block. seal, cork}
F96D CJK COMPATIBILITY IDEOGRAPH-#F96D, RSKangXi=109.4, Def{province; save, economize}
F96E CJK COMPATIBILITY IDEOGRAPH-#F96E, RSKangXi=140.9, Def{leaf, petal; page of book; period}
F96F CJK COMPATIBILITY IDEOGRAPH-#F96F, RSKangXi=149.7, Def{speak, say, talk; scold, upbraid}
F970 CJK COMPATIBILITY IDEOGRAPH-#F970, RSKangXi=79.7, Def{kill, slaughter, murder; hurt}
F971 CJK COMPATIBILITY IDEOGRAPH-#F971, RSKangXi=161.0, Def{early morning}
F972 CJK COMPATIBILITY IDEOGRAPH-#F972, RSKangXi=85.4, Def{sink, submerge; addicted to; name}
F973 CJK COMPATIBILITY IDEOGRAPH-#F973, RSKangXi=64.6, Def{pick up, collect, tidy up; ten}
F974 CJK COMPATIBILITY IDEOGRAPH-#F974, RSKangXi=140.5, Def{if, supposing, assuming; similar}
F975 CJK COMPATIBILITY IDEOGRAPH-#F975, RSKangXi=64.8, Def{rob, ransack, plunder; pass by}
F976 CJK COMPATIBILITY IDEOGRAPH-#F976, RSKangXi=102.6, Def{approximately, roughly; outline}
F977 CJK COMPATIBILITY IDEOGRAPH-#F977, RSKangXi=8.7, Def{bright, brilliant, radiant, light}
F978 CJK COMPATIBILITY IDEOGRAPH-#F978, RSKangXi=11.6, Def{two, both, pair, couple; ounce}
F979 CJK COMPATIBILITY IDEOGRAPH-#F979, RSKangXi=15.8, Def{cool, cold; disheartened}
F97A CJK COMPATIBILITY IDEOGRAPH-#F97A, RSKangXi=75.7, Def{bridge; beam; rafters; surname}
F97B CJK COMPATIBILITY IDEOGRAPH-#F97B, RSKangXi=119.12, Def{food, grain, provisions}
F97C CJK COMPATIBILITY IDEOGRAPH-#F97C, RSKangXi=138.1, Def{good, virtuous, respectable}
F97D CJK COMPATIBILITY IDEOGRAPH-#F97D, RSKangXi=149.8, Def{excuse, forgive; guess, presume}
F97E CJK COMPATIBILITY IDEOGRAPH-#F97E, RSKangXi=166.5, Def{measure, quantity, capacity}
F97F CJK COMPATIBILITY IDEOGRAPH-#F97F, RSKangXi=19.15, Def{strive; encourage}
F980 CJK COMPATIBILITY IDEOGRAPH-#F980, RSKangXi=30.4, Def{surname; a musical note}
F981 CJK COMPATIBILITY IDEOGRAPH-#F981, RSKangXi=38.0, Def{woman, girl; feminine; rad. 38}
F982 CJK COMPATIBILITY IDEOGRAPH-#F982, RSKangXi=53.16, Def{hut, cottage; name of a mountain}
F983 CJK COMPATIBILITY IDEOGRAPH-#F983, RSKangXi=70.6, Def{trip, journey; travel; traveler}
F984 CJK COMPATIBILITY IDEOGRAPH-#F984, RSKangXi=85.15, Def{strain out, filter}
F985 CJK COMPATIBILITY IDEOGRAPH-#F985, RSKangXi=112.15, Def{whetstone; sharpen}
F986 CJK COMPATIBILITY IDEOGRAPH-#F986, RSKangXi=169.7, Def{village of twenty-five families}
F987 CJK COMPATIBILITY IDEOGRAPH-#F987, RSKangXi=187.19, Def{a pure black horse; a pair of horses}
F988 CJK COMPATIBILITY IDEOGRAPH-#F988, RSKangXi=198.8, Def{beautiful, magnificent, elegant}
F989 CJK COMPATIBILITY IDEOGRAPH-#F989, RSKangXi=202.3, Def{surname; numerous, many; black}
F98A CJK COMPATIBILITY IDEOGRAPH-#F98A, RSKangXi=19.0, Def{power, capability, influence}
F98B CJK COMPATIBILITY IDEOGRAPH-#F98B, RSKangXi=72.12, Def{calendar, era}
F98C CJK COMPATIBILITY IDEOGRAPH-#F98C, RSKangXi=77.12, Def{take place, past, history}
F98D CJK COMPATIBILITY IDEOGRAPH-#F98D, RSKangXi=159.15, Def{run over something with a vehicle}
F98E CJK COMPATIBILITY IDEOGRAPH-#F98E, RSKangXi=51.3, Def{year; new-years; person's age}
F98F CJK COMPATIBILITY IDEOGRAPH-#F98F, RSKangXi=61.12, Def{pity, sympathize}
F990 CJK COMPATIBILITY IDEOGRAPH-#F990, RSKangXi=61.19, Def{love; long for, yearn for; love}
F991 CJK COMPATIBILITY IDEOGRAPH-#F991, RSKangXi=64.12, Def{twirl in fingers, tease, toy with}
F992 CJK COMPATIBILITY IDEOGRAPH-#F992, RSKangXi=85.11, Def{flowing water; ripples; weeping}
F993 CJK COMPATIBILITY IDEOGRAPH-#F993, RSKangXi=86.9, Def{smelt, refine; distill, condense}
F994 CJK COMPATIBILITY IDEOGRAPH-#F994, RSKangXi=96.11, Def{vessel used to hold grain offerings}
F995 CJK COMPATIBILITY IDEOGRAPH-#F995, RSKangXi=115.3, Def{year; new-years; person's age}
F996 CJK COMPATIBILITY IDEOGRAPH-#F996, RSKangXi=120.9, Def{practice, drill, exercise, train}
F997 CJK COMPATIBILITY IDEOGRAPH-#F997, RSKangXi=128.11, Def{connect, join; associate, ally}
F998 CJK COMPATIBILITY IDEOGRAPH-#F998, RSKangXi=159.8, Def{a hand-cart; to transport by carriage}
F999 CJK COMPATIBILITY IDEOGRAPH-#F999, RSKangXi=140.11, Def{lotus, water lily; paradise}
F99A CJK COMPATIBILITY IDEOGRAPH-#F99A, RSKangXi=162.7, Def{join, connect; continuous; even}
F99B CJK COMPATIBILITY IDEOGRAPH-#F99B, RSKangXi=167.9, Def{smelt metals, forge; refine}
F99C CJK COMPATIBILITY IDEOGRAPH-#F99C, RSKangXi=18.4, Def{a line; to arrange in order, classify}
F99D CJK COMPATIBILITY IDEOGRAPH-#F99D, RSKangXi=19.4, Def{bad, inferior; slightly}
F99E CJK COMPATIBILITY IDEOGRAPH-#F99E, RSKangXi=30.6, Def{throat; pharynx}
F99F CJK COMPATIBILITY IDEOGRAPH-#F99F, RSKangXi=86.6, Def{fiery, violent, vehement, ardent}
F9A0 CJK COMPATIBILITY IDEOGRAPH-#F9A0, RSKangXi=145.6, Def{split, crack, break open; rend}
F9A1 CJK COMPATIBILITY IDEOGRAPH-#F9A1, RSKangXi=149.7, Def{speak, say, talk; scold, upbraid}
F9A2 CJK COMPATIBILITY IDEOGRAPH-#F9A2, RSKangXi=53.10, Def{upright, honorable, honest}
F9A3 CJK COMPATIBILITY IDEOGRAPH-#F9A3, RSKangXi=61.4, Def{think of, recall, study}
F9A4 CJK COMPATIBILITY IDEOGRAPH-#F9A4, RSKangXi=64.8, Def{to twist, nip with the fingers}
F9A5 CJK COMPATIBILITY IDEOGRAPH-#F9A5, RSKangXi=78.13, Def{dress corpse for burial}
F9A6 CJK COMPATIBILITY IDEOGRAPH-#F9A6, RSKangXi=118.13, Def{a blind, screen, curtain}
F9A7 CJK COMPATIBILITY IDEOGRAPH-#F9A7, RSKangXi=94.15, Def{hunt; field sports}
F9A8 CJK COMPATIBILITY IDEOGRAPH-#F9A8, RSKangXi=9.3, Def{command, order; 'commandant', magistrate; allow, cause}
F9A9 CJK COMPATIBILITY IDEOGRAPH-#F9A9, RSKangXi=31.5, Def{prison, enclosure}
F9AA CJK COMPATIBILITY IDEOGRAPH-#F9AA, RSKangXi=40.11, Def{repose, serenity, peace; peaceful}
F9AB CJK COMPATIBILITY IDEOGRAPH-#F9AB, RSKangXi=46.14, Def{mountain ridge, mountain peak}
F9AC CJK COMPATIBILITY IDEOGRAPH-#F9AC, RSKangXi=61.5, Def{pity, sympathize}
F9AD CJK COMPATIBILITY IDEOGRAPH-#F9AD, RSKangXi=96.5, Def{tinkling of jade}
F9AE CJK COMPATIBILITY IDEOGRAPH-#F9AE, RSKangXi=96.10, Def{lustre of gems; bright, lustrous}
F9AF CJK COMPATIBILITY IDEOGRAPH-#F9AF, RSKangXi=123.5, Def{species of antelope}
F9B0 CJK COMPATIBILITY IDEOGRAPH-#F9B0, RSKangXi=128.5, Def{listen, hear}
F9B1 CJK COMPATIBILITY IDEOGRAPH-#F9B1, RSKangXi=167.5, Def{bell}
F9B2 CJK COMPATIBILITY IDEOGRAPH-#F9B2, RSKangXi=173.5, Def{zero; fragment, fraction}
F9B3 CJK COMPATIBILITY IDEOGRAPH-#F9B3, RSKangXi=173.16, Def{spirit, soul; spiritual world}
F9B4 CJK COMPATIBILITY IDEOGRAPH-#F9B4, RSKangXi=181.5, Def{neck; collar; lead, guide}
F9B5 CJK COMPATIBILITY IDEOGRAPH-#F9B5, RSKangXi=9.6, Def{precedent, example; regulation}
F9B6 CJK COMPATIBILITY IDEOGRAPH-#F9B6, RSKangXi=113.13, Def{social custom; manners; courtesy; rites}
F9B7 CJK COMPATIBILITY IDEOGRAPH-#F9B7, RSKangXi=164.13, Def{sweet wine; sweet spring}
F9B8 CJK COMPATIBILITY IDEOGRAPH-#F9B8, RSKangXi=171.8, Def{be subservient to; servant}
F9B9 CJK COMPATIBILITY IDEOGRAPH-#F9B9, RSKangXi=61.8, Def{evil, wicked, bad, foul}
F9BA CJK COMPATIBILITY IDEOGRAPH-#F9BA, RSKangXi=6.1, Def{to finish; particle of completed action}
F9BB CJK COMPATIBILITY IDEOGRAPH-#F9BB, RSKangXi=9.12, Def{officials; bureaucracy}
F9BC CJK COMPATIBILITY IDEOGRAPH-#F9BC, RSKangXi=40.12, Def{shanty, hut, shack}
F9BD CJK COMPATIBILITY IDEOGRAPH-#F9BD, RSKangXi=44.4, Def{urine; urinate}
F9BE CJK COMPATIBILITY IDEOGRAPH-#F9BE, RSKangXi=68.6, Def{consider, conjecture; material}
F9BF CJK COMPATIBILITY IDEOGRAPH-#F9BF, RSKangXi=75.11, Def{happy, glad; enjoyable; music}
F9C0 CJK COMPATIBILITY IDEOGRAPH-#F9C0, RSKangXi=86.12, Def{to burn, set afire; to illuminate; a signal lamp}
F9C1 CJK COMPATIBILITY IDEOGRAPH-#F9C1, RSKangXi=104.12, Def{be healed, cured, recover}
F9C2 CJK COMPATIBILITY IDEOGRAPH-#F9C2, RSKangXi=140.11, Def{smartweed, polygonum}
F9C3 CJK COMPATIBILITY IDEOGRAPH-#F9C3, RSKangXi=162.12, Def{distant, far}
F9C4 CJK COMPATIBILITY IDEOGRAPH-#F9C4, RSKangXi=212.0, Def{dragon; symbolic of emperor}
F9C5 CJK COMPATIBILITY IDEOGRAPH-#F9C5, RSKangXi=72.9, Def{halo in sky; fog; dizzy, faint}
F9C6 CJK COMPATIBILITY IDEOGRAPH-#F9C6, RSKangXi=170.4, Def{ancient musical instrument; surname}
F9C7 CJK COMPATIBILITY IDEOGRAPH-#F9C7, RSKangXi=18.13, Def{surname; kill, destroy}
F9C8 CJK COMPATIBILITY IDEOGRAPH-#F9C8, RSKangXi=75.4, Def{ligustrum sinenese, tree}
F9C9 CJK COMPATIBILITY IDEOGRAPH-#F9C9, RSKangXi=75.5, Def{willow tree; pleasure}
F9CA CJK COMPATIBILITY IDEOGRAPH-#F9CA, RSKangXi=85.7, Def{flow, circulate, drift; class}
F9CB CJK COMPATIBILITY IDEOGRAPH-#F9CB, RSKangXi=85.10, Def{slide, glide, slip; slippery}
F9CC CJK COMPATIBILITY IDEOGRAPH-#F9CC, RSKangXi=96.7, Def{sparkling stone; glazed, opaque}
F9CD CJK COMPATIBILITY IDEOGRAPH-#F9CD, RSKangXi=102.5, Def{stop, halt; stay, detain, keep}
F9CE CJK COMPATIBILITY IDEOGRAPH-#F9CE, RSKangXi=112.7, Def{sulfur}
F9CF CJK COMPATIBILITY IDEOGRAPH-#F9CF, RSKangXi=120.4, Def{knot; button; handle, knob; tie}
F9D0 CJK COMPATIBILITY IDEOGRAPH-#F9D0, RSKangXi=181.10, Def{class, group, kind, category}
F9D1 CJK COMPATIBILITY IDEOGRAPH-#F9D1, RSKangXi=12.2, Def{number six}
F9D2 CJK COMPATIBILITY IDEOGRAPH-#F9D2, RSKangXi=62.11, Def{kill, massacre; oppress}
F9D3 CJK COMPATIBILITY IDEOGRAPH-#F9D3, RSKangXi=170.8, Def{land, continental; army}
F9D4 CJK COMPATIBILITY IDEOGRAPH-#F9D4, RSKangXi=9.8, Def{normal human relationships}
F9D5 CJK COMPATIBILITY IDEOGRAPH-#F9D5, RSKangXi=46.8, Def{Kunlun mountains in Jiangsu}
F9D6 CJK COMPATIBILITY IDEOGRAPH-#F9D6, RSKangXi=85.8, Def{be lost; sink, be submerged}
F9D7 CJK COMPATIBILITY IDEOGRAPH-#F9D7, RSKangXi=159.8, Def{wheel; revolve, turn; recur}
F9D8 CJK COMPATIBILITY IDEOGRAPH-#F9D8, RSKangXi=60.6, Def{statute, principle, regulation}
F9D9 CJK COMPATIBILITY IDEOGRAPH-#F9D9, RSKangXi=61.10, Def{shiver, shudder, tremble; tremble}
F9DA CJK COMPATIBILITY IDEOGRAPH-#F9DA, RSKangXi=75.6, Def{chestnut tree, chestnuts; surname}
F9DB CJK COMPATIBILITY IDEOGRAPH-#F9DB, RSKangXi=95.6, Def{to lead; ratio; rate; limit}
F9DC CJK COMPATIBILITY IDEOGRAPH-#F9DC, RSKangXi=170.9, Def{prosperous, plentiful, abundant}
F9DD CJK COMPATIBILITY IDEOGRAPH-#F9DD, RSKangXi=18.5, Def{gains, advantage, profit, merit}
F9DE CJK COMPATIBILITY IDEOGRAPH-#F9DE, RSKangXi=30.3, Def{government official, magistrate}
F9DF CJK COMPATIBILITY IDEOGRAPH-#F9DF, RSKangXi=44.12, Def{footwear, shoes; walk on, tread}
F9E0 CJK COMPATIBILITY IDEOGRAPH-#F9E0, RSKangXi=72.4, Def{change; easy}
F9E1 CJK COMPATIBILITY IDEOGRAPH-#F9E1, RSKangXi=75.3, Def{plum; judge; surname}
F9E2 CJK COMPATIBILITY IDEOGRAPH-#F9E2, RSKangXi=75.7, Def{pear; opera; cut, slash}
F9E3 CJK COMPATIBILITY IDEOGRAPH-#F9E3, RSKangXi=85.5, Def{mud, mire; earth, clay; plaster}
F9E4 CJK COMPATIBILITY IDEOGRAPH-#F9E4, RSKangXi=96.7, Def{reason, logic; manage}
F9E5 CJK COMPATIBILITY IDEOGRAPH-#F9E5, RSKangXi=104.7, Def{dysentery}
F9E6 CJK COMPATIBILITY IDEOGRAPH-#F9E6, RSKangXi=122.11, Def{sorrow, grief; incur, meet with}
F9E7 CJK COMPATIBILITY IDEOGRAPH-#F9E7, RSKangXi=145.7, Def{inside, interior, within}
F9E8 CJK COMPATIBILITY IDEOGRAPH-#F9E8, RSKangXi=145.7, Def{inside, interior, within}
F9E9 CJK COMPATIBILITY IDEOGRAPH-#F9E9, RSKangXi=166.0, Def{unit of distance; village; lane}
F9EA CJK COMPATIBILITY IDEOGRAPH-#F9EA, RSKangXi=172.11, Def{leave, depart; go away; separate}
F9EB CJK COMPATIBILITY IDEOGRAPH-#F9EB, RSKangXi=23.9, Def{hide; go into hiding}
F9EC CJK COMPATIBILITY IDEOGRAPH-#F9EC, RSKangXi=85.10, Def{drown; submerge in water; indulge}
F9ED CJK COMPATIBILITY IDEOGRAPH-#F9ED, RSKangXi=30.4, Def{stingy, miserly, parsimonious}
F9EE CJK COMPATIBILITY IDEOGRAPH-#F9EE, RSKangXi=86.12, Def{phosphorus}
F9EF CJK COMPATIBILITY IDEOGRAPH-#F9EF, RSKangXi=96.12, Def{luster of jade}
F9F0 CJK COMPATIBILITY IDEOGRAPH-#F9F0, RSKangXi=140.16, Def{rush used in making mats; surname}
F9F1 CJK COMPATIBILITY IDEOGRAPH-#F9F1, RSKangXi=170.12, Def{neighbor; neighboring; adjacent}
F9F2 CJK COMPATIBILITY IDEOGRAPH-#F9F2, RSKangXi=195.12, Def{fish scales}
F9F3 CJK COMPATIBILITY IDEOGRAPH-#F9F3, RSKangXi=198.12, Def{female of Chinese unicorn}
F9F4 CJK COMPATIBILITY IDEOGRAPH-#F9F4, RSKangXi=75.4, Def{forest, grove; surname}
F9F5 CJK COMPATIBILITY IDEOGRAPH-#F9F5, RSKangXi=85.8, Def{drip, soak, drench; perfectly}
F9F6 CJK COMPATIBILITY IDEOGRAPH-#F9F6, RSKangXi=131.11, Def{draw near, approach; descend}
F9F7 CJK COMPATIBILITY IDEOGRAPH-#F9F7, RSKangXi=117.0, Def{stand; let stand; establish, set}
F9F8 CJK COMPATIBILITY IDEOGRAPH-#F9F8, RSKangXi=118.5, Def{bamboo hat; bamboo covering}
F9F9 CJK COMPATIBILITY IDEOGRAPH-#F9F9, RSKangXi=119.5, Def{grain; small particle}
F9FA CJK COMPATIBILITY IDEOGRAPH-#F9FA, RSKangXi=94.4, Def{form; appearance; shape; official}
F9FB CJK COMPATIBILITY IDEOGRAPH-#F9FB, RSKangXi=86.4, Def{roast, broil; toast; cauterize}
F9FC CJK COMPATIBILITY IDEOGRAPH-#F9FC, RSKangXi=149.12, Def{recognize, understand, know}
F9FD CJK COMPATIBILITY IDEOGRAPH-#F9FD, RSKangXi=9.2, Def{file of ten soldiers}
F9FE CJK COMPATIBILITY IDEOGRAPH-#F9FE, RSKangXi=140.6, Def{tea}
F9FF CJK COMPATIBILITY IDEOGRAPH-#F9FF, RSKangXi=18.6, Def{stab; prick, irritate; prod}
FA00 CJK COMPATIBILITY IDEOGRAPH-#FA00, RSKangXi=18.2, Def{cut, mince, slice, carve}
FA01 CJK COMPATIBILITY IDEOGRAPH-#FA01, RSKangXi=53.6, Def{degree, system; manner; to consider}
FA02 CJK COMPATIBILITY IDEOGRAPH-#FA02, RSKangXi=64.5, Def{expand; open up; support or push}
FA03 CJK COMPATIBILITY IDEOGRAPH-#FA03, RSKangXi=119.10, Def{sugar; candy; sweets}
FA04 CJK COMPATIBILITY IDEOGRAPH-#FA04, RSKangXi=40.3, Def{residence, dwelling, home; grave}
FA05 CJK COMPATIBILITY IDEOGRAPH-#FA05, RSKangXi=85.6, Def{cave, grotto; ravine; hole}
FA06 CJK COMPATIBILITY IDEOGRAPH-#FA06, RSKangXi=72.11, Def{violent, brutal, tyrannical}
FA07 CJK COMPATIBILITY IDEOGRAPH-#FA07, RSKangXi=159.9, Def{spokes of wheel}
FA08 CJK COMPATIBILITY IDEOGRAPH-#FA08, RSKangXi=144.0, Def{go; walk; move, travel; circulate}
FA09 CJK COMPATIBILITY IDEOGRAPH-#FA09, RSKangXi=170.6, Def{descend, fall, drop; lower, down}
FA0A CJK COMPATIBILITY IDEOGRAPH-#FA0A, RSKangXi=147.0, Def{see, observe, behold; perceive}
FA0B CJK COMPATIBILITY IDEOGRAPH-#FA0B, RSKangXi=53.11, Def{broad, wide, open, empty; expand}
FA0C CJK COMPATIBILITY IDEOGRAPH-#FA0C, RSKangXi=10.1, Def{duplicate of Big Five A461}
FA0D CJK COMPATIBILITY IDEOGRAPH-#FA0D, RSKangXi=30.10, Def{vomit}
FA0E CJK COMPATIBILITY IDEOGRAPH-#FA0E, IRGKangXi=0167.011, RSKangXi=29.11
FA0F CJK COMPATIBILITY IDEOGRAPH-#FA0F, IRGKangXi=0230.121, RSKangXi=32.7
FA10 CJK COMPATIBILITY IDEOGRAPH-#FA10, RSKangXi=32.10, Def{cemetery; tomb}
FA11 CJK COMPATIBILITY IDEOGRAPH-#FA11, IRGKangXi=0316.381, RSKangXi=46.9
FA12 CJK COMPATIBILITY IDEOGRAPH-#FA12, RSKangXi=72.8, Def{clear weather}
FA13 CJK COMPATIBILITY IDEOGRAPH-#FA13, IRGKangXi=0542.191, RSKangXi=75.9
FA14 CJK COMPATIBILITY IDEOGRAPH-#FA14, IRGKangXi=0546.251, RSKangXi=75.10
FA15 CJK COMPATIBILITY IDEOGRAPH-#FA15, RSKangXi=86.11, Def{bright}
FA16 CJK COMPATIBILITY IDEOGRAPH-#FA16, RSKangXi=94.8, Def{pig}
FA17 CJK COMPATIBILITY IDEOGRAPH-#FA17, RSKangXi=108.5, Def{profit}
FA18 CJK COMPATIBILITY IDEOGRAPH-#FA18, RSKangXi=113.1, Def{social custom; manners; courtesy}
FA19 CJK COMPATIBILITY IDEOGRAPH-#FA19, RSKangXi=113.5, Def{spirit}
FA1A CJK COMPATIBILITY IDEOGRAPH-#FA1A, RSKangXi=113.6, Def{good luck}
FA1B CJK COMPATIBILITY IDEOGRAPH-#FA1B, RSKangXi=113.9, Def{happiness}
FA1C CJK COMPATIBILITY IDEOGRAPH-#FA1C, RSKangXi=174.5, Def{pacify; appease; calm}
FA1D CJK COMPATIBILITY IDEOGRAPH-#FA1D, RSKangXi=119.8, Def{essence; semen; spirit}
FA1E CJK COMPATIBILITY IDEOGRAPH-#FA1E, RSKangXi=124.0, Def{feather}
FA1F CJK COMPATIBILITY IDEOGRAPH-#FA1F, RSKangXi=140.13
FA20 CJK COMPATIBILITY IDEOGRAPH-#FA20
FA21 CJK COMPATIBILITY IDEOGRAPH-#FA21, IRGKangXi=1081.111, RSKangXi=142.5
FA22 CJK COMPATIBILITY IDEOGRAPH-#FA22, RSKangXi=149.9, Def{several}
FA23 CJK COMPATIBILITY IDEOGRAPH-#FA23, RSKangXi=156.4
FA24 CJK COMPATIBILITY IDEOGRAPH-#FA24, IRGKangXi=1254.171, RSKangXi=162.4
FA25 CJK COMPATIBILITY IDEOGRAPH-#FA25, RSKangXi=162.8, Def{flee}
FA26 CJK COMPATIBILITY IDEOGRAPH-#FA26, RSKangXi=163.9, Def{metropolis}
FA27 CJK COMPATIBILITY IDEOGRAPH-#FA27, IRGKangXi=1308.261, RSKangXi=167.7
FA28 CJK COMPATIBILITY IDEOGRAPH-#FA28, IRGKangXi=1313.051, RSKangXi=167.8
FA29 CJK COMPATIBILITY IDEOGRAPH-#FA29, IRGKangXi=1359.101, RSKangXi=170.10
FA2A CJK COMPATIBILITY IDEOGRAPH-#FA2A, RSKangXi=184.4, Def{cooked rice; food; meal}
FA2B CJK COMPATIBILITY IDEOGRAPH-#FA2B, RSKangXi=184.5, Def{raise animals; feed; nourish}
FA2C CJK COMPATIBILITY IDEOGRAPH-#FA2C, RSKangXi=184.8, Def{public building}
FA2D CJK COMPATIBILITY IDEOGRAPH-#FA2D, RSKangXi=196.11, Def{crane}
FA2E CJK COMPATIBILITY IDEOGRAPH-#FA2E
FA2F CJK COMPATIBILITY IDEOGRAPH-#FA2F
FA30 CJK COMPATIBILITY IDEOGRAPH-#FA30
FA31 CJK COMPATIBILITY IDEOGRAPH-#FA31
FA32 CJK COMPATIBILITY IDEOGRAPH-#FA32
FA33 CJK COMPATIBILITY IDEOGRAPH-#FA33
FA34 CJK COMPATIBILITY IDEOGRAPH-#FA34
FA35 CJK COMPATIBILITY IDEOGRAPH-#FA35
FA36 CJK COMPATIBILITY IDEOGRAPH-#FA36
FA37 CJK COMPATIBILITY IDEOGRAPH-#FA37
FA38 CJK COMPATIBILITY IDEOGRAPH-#FA38
FA39 CJK COMPATIBILITY IDEOGRAPH-#FA39
FA3A CJK COMPATIBILITY IDEOGRAPH-#FA3A
FA3B CJK COMPATIBILITY IDEOGRAPH-#FA3B
FA3C CJK COMPATIBILITY IDEOGRAPH-#FA3C
FA3D CJK COMPATIBILITY IDEOGRAPH-#FA3D
FA3E CJK COMPATIBILITY IDEOGRAPH-#FA3E
FA3F CJK COMPATIBILITY IDEOGRAPH-#FA3F
FA40 CJK COMPATIBILITY IDEOGRAPH-#FA40
FA41 CJK COMPATIBILITY IDEOGRAPH-#FA41
FA42 CJK COMPATIBILITY IDEOGRAPH-#FA42
FA43 CJK COMPATIBILITY IDEOGRAPH-#FA43
FA44 CJK COMPATIBILITY IDEOGRAPH-#FA44
FA45 CJK COMPATIBILITY IDEOGRAPH-#FA45
FA46 CJK COMPATIBILITY IDEOGRAPH-#FA46
FA47 CJK COMPATIBILITY IDEOGRAPH-#FA47
FA48 CJK COMPATIBILITY IDEOGRAPH-#FA48
FA49 CJK COMPATIBILITY IDEOGRAPH-#FA49
FA4A CJK COMPATIBILITY IDEOGRAPH-#FA4A
FA4B CJK COMPATIBILITY IDEOGRAPH-#FA4B
FA4C CJK COMPATIBILITY IDEOGRAPH-#FA4C
FA4D CJK COMPATIBILITY IDEOGRAPH-#FA4D
FA4E CJK COMPATIBILITY IDEOGRAPH-#FA4E
FA4F CJK COMPATIBILITY IDEOGRAPH-#FA4F
FA50 CJK COMPATIBILITY IDEOGRAPH-#FA50
FA51 CJK COMPATIBILITY IDEOGRAPH-#FA51
FA52 CJK COMPATIBILITY IDEOGRAPH-#FA52
FA53 CJK COMPATIBILITY IDEOGRAPH-#FA53
FA54 CJK COMPATIBILITY IDEOGRAPH-#FA54
FA55 CJK COMPATIBILITY IDEOGRAPH-#FA55
FA56 CJK COMPATIBILITY IDEOGRAPH-#FA56
FA57 CJK COMPATIBILITY IDEOGRAPH-#FA57
FA58 CJK COMPATIBILITY IDEOGRAPH-#FA58
FA59 CJK COMPATIBILITY IDEOGRAPH-#FA59
FA5A CJK COMPATIBILITY IDEOGRAPH-#FA5A
FA5B CJK COMPATIBILITY IDEOGRAPH-#FA5B
FA5C CJK COMPATIBILITY IDEOGRAPH-#FA5C
FA5D CJK COMPATIBILITY IDEOGRAPH-#FA5D
FA5E CJK COMPATIBILITY IDEOGRAPH-#FA5E
FA5F CJK COMPATIBILITY IDEOGRAPH-#FA5F
FA60 CJK COMPATIBILITY IDEOGRAPH-#FA60
FA61 CJK COMPATIBILITY IDEOGRAPH-#FA61
FA62 CJK COMPATIBILITY IDEOGRAPH-#FA62
FA63 CJK COMPATIBILITY IDEOGRAPH-#FA63
FA64 CJK COMPATIBILITY IDEOGRAPH-#FA64
FA65 CJK COMPATIBILITY IDEOGRAPH-#FA65
FA66 CJK COMPATIBILITY IDEOGRAPH-#FA66
FA67 CJK COMPATIBILITY IDEOGRAPH-#FA67
FA68 CJK COMPATIBILITY IDEOGRAPH-#FA68
FA69 CJK COMPATIBILITY IDEOGRAPH-#FA69
FA6A CJK COMPATIBILITY IDEOGRAPH-#FA6A
FA6B CJK COMPATIBILITY IDEOGRAPH-#FA6B
FA6C CJK COMPATIBILITY IDEOGRAPH-#FA6C
FA6D CJK COMPATIBILITY IDEOGRAPH-#FA6D
FA70 CJK COMPATIBILITY IDEOGRAPH-#FA70
FA71 CJK COMPATIBILITY IDEOGRAPH-#FA71
FA72 CJK COMPATIBILITY IDEOGRAPH-#FA72
FA73 CJK COMPATIBILITY IDEOGRAPH-#FA73
FA74 CJK COMPATIBILITY IDEOGRAPH-#FA74
FA75 CJK COMPATIBILITY IDEOGRAPH-#FA75
FA76 CJK COMPATIBILITY IDEOGRAPH-#FA76
FA77 CJK COMPATIBILITY IDEOGRAPH-#FA77
FA78 CJK COMPATIBILITY IDEOGRAPH-#FA78
FA79 CJK COMPATIBILITY IDEOGRAPH-#FA79
FA7A CJK COMPATIBILITY IDEOGRAPH-#FA7A
FA7B CJK COMPATIBILITY IDEOGRAPH-#FA7B
FA7C CJK COMPATIBILITY IDEOGRAPH-#FA7C
FA7D CJK COMPATIBILITY IDEOGRAPH-#FA7D
FA7E CJK COMPATIBILITY IDEOGRAPH-#FA7E
FA7F CJK COMPATIBILITY IDEOGRAPH-#FA7F
FA80 CJK COMPATIBILITY IDEOGRAPH-#FA80
FA81 CJK COMPATIBILITY IDEOGRAPH-#FA81
FA82 CJK COMPATIBILITY IDEOGRAPH-#FA82
FA83 CJK COMPATIBILITY IDEOGRAPH-#FA83
FA84 CJK COMPATIBILITY IDEOGRAPH-#FA84
FA85 CJK COMPATIBILITY IDEOGRAPH-#FA85
FA86 CJK COMPATIBILITY IDEOGRAPH-#FA86
FA87 CJK COMPATIBILITY IDEOGRAPH-#FA87
FA88 CJK COMPATIBILITY IDEOGRAPH-#FA88
FA89 CJK COMPATIBILITY IDEOGRAPH-#FA89
FA8A CJK COMPATIBILITY IDEOGRAPH-#FA8A
FA8B CJK COMPATIBILITY IDEOGRAPH-#FA8B
FA8C CJK COMPATIBILITY IDEOGRAPH-#FA8C
FA8D CJK COMPATIBILITY IDEOGRAPH-#FA8D
FA8E CJK COMPATIBILITY IDEOGRAPH-#FA8E
FA8F CJK COMPATIBILITY IDEOGRAPH-#FA8F
FA90 CJK COMPATIBILITY IDEOGRAPH-#FA90
FA91 CJK COMPATIBILITY IDEOGRAPH-#FA91
FA92 CJK COMPATIBILITY IDEOGRAPH-#FA92
FA93 CJK COMPATIBILITY IDEOGRAPH-#FA93
FA94 CJK COMPATIBILITY IDEOGRAPH-#FA94
FA95 CJK COMPATIBILITY IDEOGRAPH-#FA95
FA96 CJK COMPATIBILITY IDEOGRAPH-#FA96
FA97 CJK COMPATIBILITY IDEOGRAPH-#FA97
FA98 CJK COMPATIBILITY IDEOGRAPH-#FA98
FA99 CJK COMPATIBILITY IDEOGRAPH-#FA99
FA9A CJK COMPATIBILITY IDEOGRAPH-#FA9A
FA9B CJK COMPATIBILITY IDEOGRAPH-#FA9B
FA9C CJK COMPATIBILITY IDEOGRAPH-#FA9C
FA9D CJK COMPATIBILITY IDEOGRAPH-#FA9D
FA9E CJK COMPATIBILITY IDEOGRAPH-#FA9E
FA9F CJK COMPATIBILITY IDEOGRAPH-#FA9F
FAA0 CJK COMPATIBILITY IDEOGRAPH-#FAA0
FAA1 CJK COMPATIBILITY IDEOGRAPH-#FAA1
FAA2 CJK COMPATIBILITY IDEOGRAPH-#FAA2
FAA3 CJK COMPATIBILITY IDEOGRAPH-#FAA3
FAA4 CJK COMPATIBILITY IDEOGRAPH-#FAA4
FAA5 CJK COMPATIBILITY IDEOGRAPH-#FAA5
FAA6 CJK COMPATIBILITY IDEOGRAPH-#FAA6
FAA7 CJK COMPATIBILITY IDEOGRAPH-#FAA7
FAA8 CJK COMPATIBILITY IDEOGRAPH-#FAA8
FAA9 CJK COMPATIBILITY IDEOGRAPH-#FAA9
FAAA CJK COMPATIBILITY IDEOGRAPH-#FAAA
FAAB CJK COMPATIBILITY IDEOGRAPH-#FAAB
FAAC CJK COMPATIBILITY IDEOGRAPH-#FAAC
FAAD CJK COMPATIBILITY IDEOGRAPH-#FAAD
FAAE CJK COMPATIBILITY IDEOGRAPH-#FAAE
FAAF CJK COMPATIBILITY IDEOGRAPH-#FAAF
FAB0 CJK COMPATIBILITY IDEOGRAPH-#FAB0
FAB1 CJK COMPATIBILITY IDEOGRAPH-#FAB1
FAB2 CJK COMPATIBILITY IDEOGRAPH-#FAB2
FAB3 CJK COMPATIBILITY IDEOGRAPH-#FAB3
FAB4 CJK COMPATIBILITY IDEOGRAPH-#FAB4
FAB5 CJK COMPATIBILITY IDEOGRAPH-#FAB5
FAB6 CJK COMPATIBILITY IDEOGRAPH-#FAB6
FAB7 CJK COMPATIBILITY IDEOGRAPH-#FAB7
FAB8 CJK COMPATIBILITY IDEOGRAPH-#FAB8
FAB9 CJK COMPATIBILITY IDEOGRAPH-#FAB9
FABA CJK COMPATIBILITY IDEOGRAPH-#FABA
FABB CJK COMPATIBILITY IDEOGRAPH-#FABB
FABC CJK COMPATIBILITY IDEOGRAPH-#FABC
FABD CJK COMPATIBILITY IDEOGRAPH-#FABD
FABE CJK COMPATIBILITY IDEOGRAPH-#FABE
FABF CJK COMPATIBILITY IDEOGRAPH-#FABF
FAC0 CJK COMPATIBILITY IDEOGRAPH-#FAC0
FAC1 CJK COMPATIBILITY IDEOGRAPH-#FAC1
FAC2 CJK COMPATIBILITY IDEOGRAPH-#FAC2
FAC3 CJK COMPATIBILITY IDEOGRAPH-#FAC3
FAC4 CJK COMPATIBILITY IDEOGRAPH-#FAC4
FAC5 CJK COMPATIBILITY IDEOGRAPH-#FAC5
FAC6 CJK COMPATIBILITY IDEOGRAPH-#FAC6
FAC7 CJK COMPATIBILITY IDEOGRAPH-#FAC7
FAC8 CJK COMPATIBILITY IDEOGRAPH-#FAC8
FAC9 CJK COMPATIBILITY IDEOGRAPH-#FAC9
FACA CJK COMPATIBILITY IDEOGRAPH-#FACA
FACB CJK COMPATIBILITY IDEOGRAPH-#FACB
FACC CJK COMPATIBILITY IDEOGRAPH-#FACC
FACD CJK COMPATIBILITY IDEOGRAPH-#FACD
FACE CJK COMPATIBILITY IDEOGRAPH-#FACE
FACF CJK COMPATIBILITY IDEOGRAPH-#FACF
FAD0 CJK COMPATIBILITY IDEOGRAPH-#FAD0
FAD1 CJK COMPATIBILITY IDEOGRAPH-#FAD1
FAD2 CJK COMPATIBILITY IDEOGRAPH-#FAD2
FAD3 CJK COMPATIBILITY IDEOGRAPH-#FAD3
FAD4 CJK COMPATIBILITY IDEOGRAPH-#FAD4
FAD5 CJK COMPATIBILITY IDEOGRAPH-#FAD5
FAD6 CJK COMPATIBILITY IDEOGRAPH-#FAD6
FAD7 CJK COMPATIBILITY IDEOGRAPH-#FAD7
FAD8 CJK COMPATIBILITY IDEOGRAPH-#FAD8
FAD9 CJK COMPATIBILITY IDEOGRAPH-#FAD9
FB00 LATIN SMALL LIGATURE FF
FB01 LATIN SMALL LIGATURE FI
FB02 LATIN SMALL LIGATURE FL
FB03 LATIN SMALL LIGATURE FFI
FB04 LATIN SMALL LIGATURE FFL
FB05 LATIN SMALL LIGATURE LONG S T
FB06 LATIN SMALL LIGATURE ST
FB13 ARMENIAN SMALL LIGATURE MEN NOW
FB14 ARMENIAN SMALL LIGATURE MEN ECH
FB15 ARMENIAN SMALL LIGATURE MEN INI
FB16 ARMENIAN SMALL LIGATURE VEW NOW
FB17 ARMENIAN SMALL LIGATURE MEN XEH
FB1D HEBREW LETTER YOD WITH HIRIQ
FB1E HEBREW POINT JUDEO-SPANISH VARIKA
FB1F HEBREW LIGATURE YIDDISH YOD YOD PATAH
FB20 HEBREW LETTER ALTERNATIVE AYIN
FB21 HEBREW LETTER WIDE ALEF
FB22 HEBREW LETTER WIDE DALET
FB23 HEBREW LETTER WIDE HE
FB24 HEBREW LETTER WIDE KAF
FB25 HEBREW LETTER WIDE LAMED
FB26 HEBREW LETTER WIDE FINAL MEM
FB27 HEBREW LETTER WIDE RESH
FB28 HEBREW LETTER WIDE TAV
FB29 HEBREW LETTER ALTERNATIVE PLUS SIGN
FB2A HEBREW LETTER SHIN WITH SHIN DOT
FB2B HEBREW LETTER SHIN WITH SIN DOT
FB2C HEBREW LETTER SHIN WITH DAGESH AND SHIN DOT
FB2D HEBREW LETTER SHIN WITH DAGESH AND SIN DOT
FB2E HEBREW LETTER ALEF WITH PATAH
FB2F HEBREW LETTER ALEF WITH QAMATS
FB30 HEBREW LETTER ALEF WITH MAPIQ
FB31 HEBREW LETTER BET WITH DAGESH
FB32 HEBREW LETTER GIMEL WITH DAGESH
FB33 HEBREW LETTER DALET WITH DAGESH
FB34 HEBREW LETTER HE WITH MAPIQ
FB35 HEBREW LETTER VAV WITH DAGESH
FB36 HEBREW LETTER ZAYIN WITH DAGESH
FB38 HEBREW LETTER TET WITH DAGESH
FB39 HEBREW LETTER YOD WITH DAGESH
FB3A HEBREW LETTER FINAL KAF WITH DAGESH
FB3B HEBREW LETTER KAF WITH DAGESH
FB3C HEBREW LETTER LAMED WITH DAGESH
FB3E HEBREW LETTER MEM WITH DAGESH
FB40 HEBREW LETTER NUN WITH DAGESH
FB41 HEBREW LETTER SAMEKH WITH DAGESH
FB43 HEBREW LETTER FINAL PE WITH DAGESH
FB44 HEBREW LETTER PE WITH DAGESH
FB46 HEBREW LETTER TSADI WITH DAGESH
FB47 HEBREW LETTER QOF WITH DAGESH
FB48 HEBREW LETTER RESH WITH DAGESH
FB49 HEBREW LETTER SHIN WITH DAGESH
FB4A HEBREW LETTER TAV WITH DAGESH
FB4B HEBREW LETTER VAV WITH HOLAM
FB4C HEBREW LETTER BET WITH RAFE
FB4D HEBREW LETTER KAF WITH RAFE
FB4E HEBREW LETTER PE WITH RAFE
FB4F HEBREW LIGATURE ALEF LAMED
FB50 ARABIC LETTER ALEF WASLA ISOLATED FORM
FB51 ARABIC LETTER ALEF WASLA FINAL FORM
FB52 ARABIC LETTER BEEH ISOLATED FORM
FB53 ARABIC LETTER BEEH FINAL FORM
FB54 ARABIC LETTER BEEH INITIAL FORM
FB55 ARABIC LETTER BEEH MEDIAL FORM
FB56 ARABIC LETTER PEH ISOLATED FORM
FB57 ARABIC LETTER PEH FINAL FORM
FB58 ARABIC LETTER PEH INITIAL FORM
FB59 ARABIC LETTER PEH MEDIAL FORM
FB5A ARABIC LETTER BEHEH ISOLATED FORM
FB5B ARABIC LETTER BEHEH FINAL FORM
FB5C ARABIC LETTER BEHEH INITIAL FORM
FB5D ARABIC LETTER BEHEH MEDIAL FORM
FB5E ARABIC LETTER TTEHEH ISOLATED FORM
FB5F ARABIC LETTER TTEHEH FINAL FORM
FB60 ARABIC LETTER TTEHEH INITIAL FORM
FB61 ARABIC LETTER TTEHEH MEDIAL FORM
FB62 ARABIC LETTER TEHEH ISOLATED FORM
FB63 ARABIC LETTER TEHEH FINAL FORM
FB64 ARABIC LETTER TEHEH INITIAL FORM
FB65 ARABIC LETTER TEHEH MEDIAL FORM
FB66 ARABIC LETTER TTEH ISOLATED FORM
FB67 ARABIC LETTER TTEH FINAL FORM
FB68 ARABIC LETTER TTEH INITIAL FORM
FB69 ARABIC LETTER TTEH MEDIAL FORM
FB6A ARABIC LETTER VEH ISOLATED FORM
FB6B ARABIC LETTER VEH FINAL FORM
FB6C ARABIC LETTER VEH INITIAL FORM
FB6D ARABIC LETTER VEH MEDIAL FORM
FB6E ARABIC LETTER PEHEH ISOLATED FORM
FB6F ARABIC LETTER PEHEH FINAL FORM
FB70 ARABIC LETTER PEHEH INITIAL FORM
FB71 ARABIC LETTER PEHEH MEDIAL FORM
FB72 ARABIC LETTER DYEH ISOLATED FORM
FB73 ARABIC LETTER DYEH FINAL FORM
FB74 ARABIC LETTER DYEH INITIAL FORM
FB75 ARABIC LETTER DYEH MEDIAL FORM
FB76 ARABIC LETTER NYEH ISOLATED FORM
FB77 ARABIC LETTER NYEH FINAL FORM
FB78 ARABIC LETTER NYEH INITIAL FORM
FB79 ARABIC LETTER NYEH MEDIAL FORM
FB7A ARABIC LETTER TCHEH ISOLATED FORM
FB7B ARABIC LETTER TCHEH FINAL FORM
FB7C ARABIC LETTER TCHEH INITIAL FORM
FB7D ARABIC LETTER TCHEH MEDIAL FORM
FB7E ARABIC LETTER TCHEHEH ISOLATED FORM
FB7F ARABIC LETTER TCHEHEH FINAL FORM
FB80 ARABIC LETTER TCHEHEH INITIAL FORM
FB81 ARABIC LETTER TCHEHEH MEDIAL FORM
FB82 ARABIC LETTER DDAHAL ISOLATED FORM
FB83 ARABIC LETTER DDAHAL FINAL FORM
FB84 ARABIC LETTER DAHAL ISOLATED FORM
FB85 ARABIC LETTER DAHAL FINAL FORM
FB86 ARABIC LETTER DUL ISOLATED FORM
FB87 ARABIC LETTER DUL FINAL FORM
FB88 ARABIC LETTER DDAL ISOLATED FORM
FB89 ARABIC LETTER DDAL FINAL FORM
FB8A ARABIC LETTER JEH ISOLATED FORM
FB8B ARABIC LETTER JEH FINAL FORM
FB8C ARABIC LETTER RREH ISOLATED FORM
FB8D ARABIC LETTER RREH FINAL FORM
FB8E ARABIC LETTER KEHEH ISOLATED FORM
FB8F ARABIC LETTER KEHEH FINAL FORM
FB90 ARABIC LETTER KEHEH INITIAL FORM
FB91 ARABIC LETTER KEHEH MEDIAL FORM
FB92 ARABIC LETTER GAF ISOLATED FORM
FB93 ARABIC LETTER GAF FINAL FORM
FB94 ARABIC LETTER GAF INITIAL FORM
FB95 ARABIC LETTER GAF MEDIAL FORM
FB96 ARABIC LETTER GUEH ISOLATED FORM
FB97 ARABIC LETTER GUEH FINAL FORM
FB98 ARABIC LETTER GUEH INITIAL FORM
FB99 ARABIC LETTER GUEH MEDIAL FORM
FB9A ARABIC LETTER NGOEH ISOLATED FORM
FB9B ARABIC LETTER NGOEH FINAL FORM
FB9C ARABIC LETTER NGOEH INITIAL FORM
FB9D ARABIC LETTER NGOEH MEDIAL FORM
FB9E ARABIC LETTER NOON GHUNNA ISOLATED FORM
FB9F ARABIC LETTER NOON GHUNNA FINAL FORM
FBA0 ARABIC LETTER RNOON ISOLATED FORM
FBA1 ARABIC LETTER RNOON FINAL FORM
FBA2 ARABIC LETTER RNOON INITIAL FORM
FBA3 ARABIC LETTER RNOON MEDIAL FORM
FBA4 ARABIC LETTER HEH WITH YEH ABOVE ISOLATED FORM
FBA5 ARABIC LETTER HEH WITH YEH ABOVE FINAL FORM
FBA6 ARABIC LETTER HEH GOAL ISOLATED FORM
FBA7 ARABIC LETTER HEH GOAL FINAL FORM
FBA8 ARABIC LETTER HEH GOAL INITIAL FORM
FBA9 ARABIC LETTER HEH GOAL MEDIAL FORM
FBAA ARABIC LETTER HEH DOACHASHMEE ISOLATED FORM
FBAB ARABIC LETTER HEH DOACHASHMEE FINAL FORM
FBAC ARABIC LETTER HEH DOACHASHMEE INITIAL FORM
FBAD ARABIC LETTER HEH DOACHASHMEE MEDIAL FORM
FBAE ARABIC LETTER YEH BARREE ISOLATED FORM
FBAF ARABIC LETTER YEH BARREE FINAL FORM
FBB0 ARABIC LETTER YEH BARREE WITH HAMZA ABOVE ISOLATED FORM
FBB1 ARABIC LETTER YEH BARREE WITH HAMZA ABOVE FINAL FORM
FBB2 ARABIC SYMBOL DOT ABOVE
FBB3 ARABIC SYMBOL DOT BELOW
FBB4 ARABIC SYMBOL TWO DOTS ABOVE
FBB5 ARABIC SYMBOL TWO DOTS BELOW
FBB6 ARABIC SYMBOL THREE DOTS ABOVE
FBB7 ARABIC SYMBOL THREE DOTS BELOW
FBB8 ARABIC SYMBOL THREE DOTS POINTING DOWNWARDS ABOVE
FBB9 ARABIC SYMBOL THREE DOTS POINTING DOWNWARDS BELOW
FBBA ARABIC SYMBOL FOUR DOTS ABOVE
FBBB ARABIC SYMBOL FOUR DOTS BELOW
FBBC ARABIC SYMBOL DOUBLE VERTICAL BAR BELOW
FBBD ARABIC SYMBOL TWO DOTS VERTICALLY ABOVE
FBBE ARABIC SYMBOL TWO DOTS VERTICALLY BELOW
FBBF ARABIC SYMBOL RING
FBC0 ARABIC SYMBOL SMALL TAH ABOVE
FBC1 ARABIC SYMBOL SMALL TAH BELOW
FBD3 ARABIC LETTER NG ISOLATED FORM
FBD4 ARABIC LETTER NG FINAL FORM
FBD5 ARABIC LETTER NG INITIAL FORM
FBD6 ARABIC LETTER NG MEDIAL FORM
FBD7 ARABIC LETTER U ISOLATED FORM
FBD8 ARABIC LETTER U FINAL FORM
FBD9 ARABIC LETTER OE ISOLATED FORM
FBDA ARABIC LETTER OE FINAL FORM
FBDB ARABIC LETTER YU ISOLATED FORM
FBDC ARABIC LETTER YU FINAL FORM
FBDD ARABIC LETTER U WITH HAMZA ABOVE ISOLATED FORM
FBDE ARABIC LETTER VE ISOLATED FORM
FBDF ARABIC LETTER VE FINAL FORM
FBE0 ARABIC LETTER KIRGHIZ OE ISOLATED FORM
FBE1 ARABIC LETTER KIRGHIZ OE FINAL FORM
FBE2 ARABIC LETTER KIRGHIZ YU ISOLATED FORM
FBE3 ARABIC LETTER KIRGHIZ YU FINAL FORM
FBE4 ARABIC LETTER E ISOLATED FORM
FBE5 ARABIC LETTER E FINAL FORM
FBE6 ARABIC LETTER E INITIAL FORM
FBE7 ARABIC LETTER E MEDIAL FORM
FBE8 ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA INITIAL FORM
FBE9 ARABIC LETTER UIGHUR KAZAKH KIRGHIZ ALEF MAKSURA MEDIAL FORM
FBEA ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF ISOLATED FORM
FBEB ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF FINAL FORM
FBEC ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE ISOLATED FORM
FBED ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH AE FINAL FORM
FBEE ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW ISOLATED FORM
FBEF ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH WAW FINAL FORM
FBF0 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U ISOLATED FORM
FBF1 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH U FINAL FORM
FBF2 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE ISOLATED FORM
FBF3 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH OE FINAL FORM
FBF4 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU ISOLATED FORM
FBF5 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YU FINAL FORM
FBF6 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E ISOLATED FORM
FBF7 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E FINAL FORM
FBF8 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH E INITIAL FORM
FBF9 ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM
FBFA ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM
FBFB ARABIC LIGATURE UIGHUR KIRGHIZ YEH WITH HAMZA ABOVE WITH ALEF MAKSURA INITIAL FORM
FBFC ARABIC LETTER FARSI YEH ISOLATED FORM
FBFD ARABIC LETTER FARSI YEH FINAL FORM
FBFE ARABIC LETTER FARSI YEH INITIAL FORM
FBFF ARABIC LETTER FARSI YEH MEDIAL FORM
FC00 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM ISOLATED FORM
FC01 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH ISOLATED FORM
FC02 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM ISOLATED FORM
FC03 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA ISOLATED FORM
FC04 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH ISOLATED FORM
FC05 ARABIC LIGATURE BEH WITH JEEM ISOLATED FORM
FC06 ARABIC LIGATURE BEH WITH HAH ISOLATED FORM
FC07 ARABIC LIGATURE BEH WITH KHAH ISOLATED FORM
FC08 ARABIC LIGATURE BEH WITH MEEM ISOLATED FORM
FC09 ARABIC LIGATURE BEH WITH ALEF MAKSURA ISOLATED FORM
FC0A ARABIC LIGATURE BEH WITH YEH ISOLATED FORM
FC0B ARABIC LIGATURE TEH WITH JEEM ISOLATED FORM
FC0C ARABIC LIGATURE TEH WITH HAH ISOLATED FORM
FC0D ARABIC LIGATURE TEH WITH KHAH ISOLATED FORM
FC0E ARABIC LIGATURE TEH WITH MEEM ISOLATED FORM
FC0F ARABIC LIGATURE TEH WITH ALEF MAKSURA ISOLATED FORM
FC10 ARABIC LIGATURE TEH WITH YEH ISOLATED FORM
FC11 ARABIC LIGATURE THEH WITH JEEM ISOLATED FORM
FC12 ARABIC LIGATURE THEH WITH MEEM ISOLATED FORM
FC13 ARABIC LIGATURE THEH WITH ALEF MAKSURA ISOLATED FORM
FC14 ARABIC LIGATURE THEH WITH YEH ISOLATED FORM
FC15 ARABIC LIGATURE JEEM WITH HAH ISOLATED FORM
FC16 ARABIC LIGATURE JEEM WITH MEEM ISOLATED FORM
FC17 ARABIC LIGATURE HAH WITH JEEM ISOLATED FORM
FC18 ARABIC LIGATURE HAH WITH MEEM ISOLATED FORM
FC19 ARABIC LIGATURE KHAH WITH JEEM ISOLATED FORM
FC1A ARABIC LIGATURE KHAH WITH HAH ISOLATED FORM
FC1B ARABIC LIGATURE KHAH WITH MEEM ISOLATED FORM
FC1C ARABIC LIGATURE SEEN WITH JEEM ISOLATED FORM
FC1D ARABIC LIGATURE SEEN WITH HAH ISOLATED FORM
FC1E ARABIC LIGATURE SEEN WITH KHAH ISOLATED FORM
FC1F ARABIC LIGATURE SEEN WITH MEEM ISOLATED FORM
FC20 ARABIC LIGATURE SAD WITH HAH ISOLATED FORM
FC21 ARABIC LIGATURE SAD WITH MEEM ISOLATED FORM
FC22 ARABIC LIGATURE DAD WITH JEEM ISOLATED FORM
FC23 ARABIC LIGATURE DAD WITH HAH ISOLATED FORM
FC24 ARABIC LIGATURE DAD WITH KHAH ISOLATED FORM
FC25 ARABIC LIGATURE DAD WITH MEEM ISOLATED FORM
FC26 ARABIC LIGATURE TAH WITH HAH ISOLATED FORM
FC27 ARABIC LIGATURE TAH WITH MEEM ISOLATED FORM
FC28 ARABIC LIGATURE ZAH WITH MEEM ISOLATED FORM
FC29 ARABIC LIGATURE AIN WITH JEEM ISOLATED FORM
FC2A ARABIC LIGATURE AIN WITH MEEM ISOLATED FORM
FC2B ARABIC LIGATURE GHAIN WITH JEEM ISOLATED FORM
FC2C ARABIC LIGATURE GHAIN WITH MEEM ISOLATED FORM
FC2D ARABIC LIGATURE FEH WITH JEEM ISOLATED FORM
FC2E ARABIC LIGATURE FEH WITH HAH ISOLATED FORM
FC2F ARABIC LIGATURE FEH WITH KHAH ISOLATED FORM
FC30 ARABIC LIGATURE FEH WITH MEEM ISOLATED FORM
FC31 ARABIC LIGATURE FEH WITH ALEF MAKSURA ISOLATED FORM
FC32 ARABIC LIGATURE FEH WITH YEH ISOLATED FORM
FC33 ARABIC LIGATURE QAF WITH HAH ISOLATED FORM
FC34 ARABIC LIGATURE QAF WITH MEEM ISOLATED FORM
FC35 ARABIC LIGATURE QAF WITH ALEF MAKSURA ISOLATED FORM
FC36 ARABIC LIGATURE QAF WITH YEH ISOLATED FORM
FC37 ARABIC LIGATURE KAF WITH ALEF ISOLATED FORM
FC38 ARABIC LIGATURE KAF WITH JEEM ISOLATED FORM
FC39 ARABIC LIGATURE KAF WITH HAH ISOLATED FORM
FC3A ARABIC LIGATURE KAF WITH KHAH ISOLATED FORM
FC3B ARABIC LIGATURE KAF WITH LAM ISOLATED FORM
FC3C ARABIC LIGATURE KAF WITH MEEM ISOLATED FORM
FC3D ARABIC LIGATURE KAF WITH ALEF MAKSURA ISOLATED FORM
FC3E ARABIC LIGATURE KAF WITH YEH ISOLATED FORM
FC3F ARABIC LIGATURE LAM WITH JEEM ISOLATED FORM
FC40 ARABIC LIGATURE LAM WITH HAH ISOLATED FORM
FC41 ARABIC LIGATURE LAM WITH KHAH ISOLATED FORM
FC42 ARABIC LIGATURE LAM WITH MEEM ISOLATED FORM
FC43 ARABIC LIGATURE LAM WITH ALEF MAKSURA ISOLATED FORM
FC44 ARABIC LIGATURE LAM WITH YEH ISOLATED FORM
FC45 ARABIC LIGATURE MEEM WITH JEEM ISOLATED FORM
FC46 ARABIC LIGATURE MEEM WITH HAH ISOLATED FORM
FC47 ARABIC LIGATURE MEEM WITH KHAH ISOLATED FORM
FC48 ARABIC LIGATURE MEEM WITH MEEM ISOLATED FORM
FC49 ARABIC LIGATURE MEEM WITH ALEF MAKSURA ISOLATED FORM
FC4A ARABIC LIGATURE MEEM WITH YEH ISOLATED FORM
FC4B ARABIC LIGATURE NOON WITH JEEM ISOLATED FORM
FC4C ARABIC LIGATURE NOON WITH HAH ISOLATED FORM
FC4D ARABIC LIGATURE NOON WITH KHAH ISOLATED FORM
FC4E ARABIC LIGATURE NOON WITH MEEM ISOLATED FORM
FC4F ARABIC LIGATURE NOON WITH ALEF MAKSURA ISOLATED FORM
FC50 ARABIC LIGATURE NOON WITH YEH ISOLATED FORM
FC51 ARABIC LIGATURE HEH WITH JEEM ISOLATED FORM
FC52 ARABIC LIGATURE HEH WITH MEEM ISOLATED FORM
FC53 ARABIC LIGATURE HEH WITH ALEF MAKSURA ISOLATED FORM
FC54 ARABIC LIGATURE HEH WITH YEH ISOLATED FORM
FC55 ARABIC LIGATURE YEH WITH JEEM ISOLATED FORM
FC56 ARABIC LIGATURE YEH WITH HAH ISOLATED FORM
FC57 ARABIC LIGATURE YEH WITH KHAH ISOLATED FORM
FC58 ARABIC LIGATURE YEH WITH MEEM ISOLATED FORM
FC59 ARABIC LIGATURE YEH WITH ALEF MAKSURA ISOLATED FORM
FC5A ARABIC LIGATURE YEH WITH YEH ISOLATED FORM
FC5B ARABIC LIGATURE THAL WITH SUPERSCRIPT ALEF ISOLATED FORM
FC5C ARABIC LIGATURE REH WITH SUPERSCRIPT ALEF ISOLATED FORM
FC5D ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF ISOLATED FORM
FC5E ARABIC LIGATURE SHADDA WITH DAMMATAN ISOLATED FORM
FC5F ARABIC LIGATURE SHADDA WITH KASRATAN ISOLATED FORM
FC60 ARABIC LIGATURE SHADDA WITH FATHA ISOLATED FORM
FC61 ARABIC LIGATURE SHADDA WITH DAMMA ISOLATED FORM
FC62 ARABIC LIGATURE SHADDA WITH KASRA ISOLATED FORM
FC63 ARABIC LIGATURE SHADDA WITH SUPERSCRIPT ALEF ISOLATED FORM
FC64 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH REH FINAL FORM
FC65 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ZAIN FINAL FORM
FC66 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM FINAL FORM
FC67 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH NOON FINAL FORM
FC68 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH ALEF MAKSURA FINAL FORM
FC69 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH YEH FINAL FORM
FC6A ARABIC LIGATURE BEH WITH REH FINAL FORM
FC6B ARABIC LIGATURE BEH WITH ZAIN FINAL FORM
FC6C ARABIC LIGATURE BEH WITH MEEM FINAL FORM
FC6D ARABIC LIGATURE BEH WITH NOON FINAL FORM
FC6E ARABIC LIGATURE BEH WITH ALEF MAKSURA FINAL FORM
FC6F ARABIC LIGATURE BEH WITH YEH FINAL FORM
FC70 ARABIC LIGATURE TEH WITH REH FINAL FORM
FC71 ARABIC LIGATURE TEH WITH ZAIN FINAL FORM
FC72 ARABIC LIGATURE TEH WITH MEEM FINAL FORM
FC73 ARABIC LIGATURE TEH WITH NOON FINAL FORM
FC74 ARABIC LIGATURE TEH WITH ALEF MAKSURA FINAL FORM
FC75 ARABIC LIGATURE TEH WITH YEH FINAL FORM
FC76 ARABIC LIGATURE THEH WITH REH FINAL FORM
FC77 ARABIC LIGATURE THEH WITH ZAIN FINAL FORM
FC78 ARABIC LIGATURE THEH WITH MEEM FINAL FORM
FC79 ARABIC LIGATURE THEH WITH NOON FINAL FORM
FC7A ARABIC LIGATURE THEH WITH ALEF MAKSURA FINAL FORM
FC7B ARABIC LIGATURE THEH WITH YEH FINAL FORM
FC7C ARABIC LIGATURE FEH WITH ALEF MAKSURA FINAL FORM
FC7D ARABIC LIGATURE FEH WITH YEH FINAL FORM
FC7E ARABIC LIGATURE QAF WITH ALEF MAKSURA FINAL FORM
FC7F ARABIC LIGATURE QAF WITH YEH FINAL FORM
FC80 ARABIC LIGATURE KAF WITH ALEF FINAL FORM
FC81 ARABIC LIGATURE KAF WITH LAM FINAL FORM
FC82 ARABIC LIGATURE KAF WITH MEEM FINAL FORM
FC83 ARABIC LIGATURE KAF WITH ALEF MAKSURA FINAL FORM
FC84 ARABIC LIGATURE KAF WITH YEH FINAL FORM
FC85 ARABIC LIGATURE LAM WITH MEEM FINAL FORM
FC86 ARABIC LIGATURE LAM WITH ALEF MAKSURA FINAL FORM
FC87 ARABIC LIGATURE LAM WITH YEH FINAL FORM
FC88 ARABIC LIGATURE MEEM WITH ALEF FINAL FORM
FC89 ARABIC LIGATURE MEEM WITH MEEM FINAL FORM
FC8A ARABIC LIGATURE NOON WITH REH FINAL FORM
FC8B ARABIC LIGATURE NOON WITH ZAIN FINAL FORM
FC8C ARABIC LIGATURE NOON WITH MEEM FINAL FORM
FC8D ARABIC LIGATURE NOON WITH NOON FINAL FORM
FC8E ARABIC LIGATURE NOON WITH ALEF MAKSURA FINAL FORM
FC8F ARABIC LIGATURE NOON WITH YEH FINAL FORM
FC90 ARABIC LIGATURE ALEF MAKSURA WITH SUPERSCRIPT ALEF FINAL FORM
FC91 ARABIC LIGATURE YEH WITH REH FINAL FORM
FC92 ARABIC LIGATURE YEH WITH ZAIN FINAL FORM
FC93 ARABIC LIGATURE YEH WITH MEEM FINAL FORM
FC94 ARABIC LIGATURE YEH WITH NOON FINAL FORM
FC95 ARABIC LIGATURE YEH WITH ALEF MAKSURA FINAL FORM
FC96 ARABIC LIGATURE YEH WITH YEH FINAL FORM
FC97 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH JEEM INITIAL FORM
FC98 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HAH INITIAL FORM
FC99 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH KHAH INITIAL FORM
FC9A ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM INITIAL FORM
FC9B ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH INITIAL FORM
FC9C ARABIC LIGATURE BEH WITH JEEM INITIAL FORM
FC9D ARABIC LIGATURE BEH WITH HAH INITIAL FORM
FC9E ARABIC LIGATURE BEH WITH KHAH INITIAL FORM
FC9F ARABIC LIGATURE BEH WITH MEEM INITIAL FORM
FCA0 ARABIC LIGATURE BEH WITH HEH INITIAL FORM
FCA1 ARABIC LIGATURE TEH WITH JEEM INITIAL FORM
FCA2 ARABIC LIGATURE TEH WITH HAH INITIAL FORM
FCA3 ARABIC LIGATURE TEH WITH KHAH INITIAL FORM
FCA4 ARABIC LIGATURE TEH WITH MEEM INITIAL FORM
FCA5 ARABIC LIGATURE TEH WITH HEH INITIAL FORM
FCA6 ARABIC LIGATURE THEH WITH MEEM INITIAL FORM
FCA7 ARABIC LIGATURE JEEM WITH HAH INITIAL FORM
FCA8 ARABIC LIGATURE JEEM WITH MEEM INITIAL FORM
FCA9 ARABIC LIGATURE HAH WITH JEEM INITIAL FORM
FCAA ARABIC LIGATURE HAH WITH MEEM INITIAL FORM
FCAB ARABIC LIGATURE KHAH WITH JEEM INITIAL FORM
FCAC ARABIC LIGATURE KHAH WITH MEEM INITIAL FORM
FCAD ARABIC LIGATURE SEEN WITH JEEM INITIAL FORM
FCAE ARABIC LIGATURE SEEN WITH HAH INITIAL FORM
FCAF ARABIC LIGATURE SEEN WITH KHAH INITIAL FORM
FCB0 ARABIC LIGATURE SEEN WITH MEEM INITIAL FORM
FCB1 ARABIC LIGATURE SAD WITH HAH INITIAL FORM
FCB2 ARABIC LIGATURE SAD WITH KHAH INITIAL FORM
FCB3 ARABIC LIGATURE SAD WITH MEEM INITIAL FORM
FCB4 ARABIC LIGATURE DAD WITH JEEM INITIAL FORM
FCB5 ARABIC LIGATURE DAD WITH HAH INITIAL FORM
FCB6 ARABIC LIGATURE DAD WITH KHAH INITIAL FORM
FCB7 ARABIC LIGATURE DAD WITH MEEM INITIAL FORM
FCB8 ARABIC LIGATURE TAH WITH HAH INITIAL FORM
FCB9 ARABIC LIGATURE ZAH WITH MEEM INITIAL FORM
FCBA ARABIC LIGATURE AIN WITH JEEM INITIAL FORM
FCBB ARABIC LIGATURE AIN WITH MEEM INITIAL FORM
FCBC ARABIC LIGATURE GHAIN WITH JEEM INITIAL FORM
FCBD ARABIC LIGATURE GHAIN WITH MEEM INITIAL FORM
FCBE ARABIC LIGATURE FEH WITH JEEM INITIAL FORM
FCBF ARABIC LIGATURE FEH WITH HAH INITIAL FORM
FCC0 ARABIC LIGATURE FEH WITH KHAH INITIAL FORM
FCC1 ARABIC LIGATURE FEH WITH MEEM INITIAL FORM
FCC2 ARABIC LIGATURE QAF WITH HAH INITIAL FORM
FCC3 ARABIC LIGATURE QAF WITH MEEM INITIAL FORM
FCC4 ARABIC LIGATURE KAF WITH JEEM INITIAL FORM
FCC5 ARABIC LIGATURE KAF WITH HAH INITIAL FORM
FCC6 ARABIC LIGATURE KAF WITH KHAH INITIAL FORM
FCC7 ARABIC LIGATURE KAF WITH LAM INITIAL FORM
FCC8 ARABIC LIGATURE KAF WITH MEEM INITIAL FORM
FCC9 ARABIC LIGATURE LAM WITH JEEM INITIAL FORM
FCCA ARABIC LIGATURE LAM WITH HAH INITIAL FORM
FCCB ARABIC LIGATURE LAM WITH KHAH INITIAL FORM
FCCC ARABIC LIGATURE LAM WITH MEEM INITIAL FORM
FCCD ARABIC LIGATURE LAM WITH HEH INITIAL FORM
FCCE ARABIC LIGATURE MEEM WITH JEEM INITIAL FORM
FCCF ARABIC LIGATURE MEEM WITH HAH INITIAL FORM
FCD0 ARABIC LIGATURE MEEM WITH KHAH INITIAL FORM
FCD1 ARABIC LIGATURE MEEM WITH MEEM INITIAL FORM
FCD2 ARABIC LIGATURE NOON WITH JEEM INITIAL FORM
FCD3 ARABIC LIGATURE NOON WITH HAH INITIAL FORM
FCD4 ARABIC LIGATURE NOON WITH KHAH INITIAL FORM
FCD5 ARABIC LIGATURE NOON WITH MEEM INITIAL FORM
FCD6 ARABIC LIGATURE NOON WITH HEH INITIAL FORM
FCD7 ARABIC LIGATURE HEH WITH JEEM INITIAL FORM
FCD8 ARABIC LIGATURE HEH WITH MEEM INITIAL FORM
FCD9 ARABIC LIGATURE HEH WITH SUPERSCRIPT ALEF INITIAL FORM
FCDA ARABIC LIGATURE YEH WITH JEEM INITIAL FORM
FCDB ARABIC LIGATURE YEH WITH HAH INITIAL FORM
FCDC ARABIC LIGATURE YEH WITH KHAH INITIAL FORM
FCDD ARABIC LIGATURE YEH WITH MEEM INITIAL FORM
FCDE ARABIC LIGATURE YEH WITH HEH INITIAL FORM
FCDF ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH MEEM MEDIAL FORM
FCE0 ARABIC LIGATURE YEH WITH HAMZA ABOVE WITH HEH MEDIAL FORM
FCE1 ARABIC LIGATURE BEH WITH MEEM MEDIAL FORM
FCE2 ARABIC LIGATURE BEH WITH HEH MEDIAL FORM
FCE3 ARABIC LIGATURE TEH WITH MEEM MEDIAL FORM
FCE4 ARABIC LIGATURE TEH WITH HEH MEDIAL FORM
FCE5 ARABIC LIGATURE THEH WITH MEEM MEDIAL FORM
FCE6 ARABIC LIGATURE THEH WITH HEH MEDIAL FORM
FCE7 ARABIC LIGATURE SEEN WITH MEEM MEDIAL FORM
FCE8 ARABIC LIGATURE SEEN WITH HEH MEDIAL FORM
FCE9 ARABIC LIGATURE SHEEN WITH MEEM MEDIAL FORM
FCEA ARABIC LIGATURE SHEEN WITH HEH MEDIAL FORM
FCEB ARABIC LIGATURE KAF WITH LAM MEDIAL FORM
FCEC ARABIC LIGATURE KAF WITH MEEM MEDIAL FORM
FCED ARABIC LIGATURE LAM WITH MEEM MEDIAL FORM
FCEE ARABIC LIGATURE NOON WITH MEEM MEDIAL FORM
FCEF ARABIC LIGATURE NOON WITH HEH MEDIAL FORM
FCF0 ARABIC LIGATURE YEH WITH MEEM MEDIAL FORM
FCF1 ARABIC LIGATURE YEH WITH HEH MEDIAL FORM
FCF2 ARABIC LIGATURE SHADDA WITH FATHA MEDIAL FORM
FCF3 ARABIC LIGATURE SHADDA WITH DAMMA MEDIAL FORM
FCF4 ARABIC LIGATURE SHADDA WITH KASRA MEDIAL FORM
FCF5 ARABIC LIGATURE TAH WITH ALEF MAKSURA ISOLATED FORM
FCF6 ARABIC LIGATURE TAH WITH YEH ISOLATED FORM
FCF7 ARABIC LIGATURE AIN WITH ALEF MAKSURA ISOLATED FORM
FCF8 ARABIC LIGATURE AIN WITH YEH ISOLATED FORM
FCF9 ARABIC LIGATURE GHAIN WITH ALEF MAKSURA ISOLATED FORM
FCFA ARABIC LIGATURE GHAIN WITH YEH ISOLATED FORM
FCFB ARABIC LIGATURE SEEN WITH ALEF MAKSURA ISOLATED FORM
FCFC ARABIC LIGATURE SEEN WITH YEH ISOLATED FORM
FCFD ARABIC LIGATURE SHEEN WITH ALEF MAKSURA ISOLATED FORM
FCFE ARABIC LIGATURE SHEEN WITH YEH ISOLATED FORM
FCFF ARABIC LIGATURE HAH WITH ALEF MAKSURA ISOLATED FORM
FD00 ARABIC LIGATURE HAH WITH YEH ISOLATED FORM
FD01 ARABIC LIGATURE JEEM WITH ALEF MAKSURA ISOLATED FORM
FD02 ARABIC LIGATURE JEEM WITH YEH ISOLATED FORM
FD03 ARABIC LIGATURE KHAH WITH ALEF MAKSURA ISOLATED FORM
FD04 ARABIC LIGATURE KHAH WITH YEH ISOLATED FORM
FD05 ARABIC LIGATURE SAD WITH ALEF MAKSURA ISOLATED FORM
FD06 ARABIC LIGATURE SAD WITH YEH ISOLATED FORM
FD07 ARABIC LIGATURE DAD WITH ALEF MAKSURA ISOLATED FORM
FD08 ARABIC LIGATURE DAD WITH YEH ISOLATED FORM
FD09 ARABIC LIGATURE SHEEN WITH JEEM ISOLATED FORM
FD0A ARABIC LIGATURE SHEEN WITH HAH ISOLATED FORM
FD0B ARABIC LIGATURE SHEEN WITH KHAH ISOLATED FORM
FD0C ARABIC LIGATURE SHEEN WITH MEEM ISOLATED FORM
FD0D ARABIC LIGATURE SHEEN WITH REH ISOLATED FORM
FD0E ARABIC LIGATURE SEEN WITH REH ISOLATED FORM
FD0F ARABIC LIGATURE SAD WITH REH ISOLATED FORM
FD10 ARABIC LIGATURE DAD WITH REH ISOLATED FORM
FD11 ARABIC LIGATURE TAH WITH ALEF MAKSURA FINAL FORM
FD12 ARABIC LIGATURE TAH WITH YEH FINAL FORM
FD13 ARABIC LIGATURE AIN WITH ALEF MAKSURA FINAL FORM
FD14 ARABIC LIGATURE AIN WITH YEH FINAL FORM
FD15 ARABIC LIGATURE GHAIN WITH ALEF MAKSURA FINAL FORM
FD16 ARABIC LIGATURE GHAIN WITH YEH FINAL FORM
FD17 ARABIC LIGATURE SEEN WITH ALEF MAKSURA FINAL FORM
FD18 ARABIC LIGATURE SEEN WITH YEH FINAL FORM
FD19 ARABIC LIGATURE SHEEN WITH ALEF MAKSURA FINAL FORM
FD1A ARABIC LIGATURE SHEEN WITH YEH FINAL FORM
FD1B ARABIC LIGATURE HAH WITH ALEF MAKSURA FINAL FORM
FD1C ARABIC LIGATURE HAH WITH YEH FINAL FORM
FD1D ARABIC LIGATURE JEEM WITH ALEF MAKSURA FINAL FORM
FD1E ARABIC LIGATURE JEEM WITH YEH FINAL FORM
FD1F ARABIC LIGATURE KHAH WITH ALEF MAKSURA FINAL FORM
FD20 ARABIC LIGATURE KHAH WITH YEH FINAL FORM
FD21 ARABIC LIGATURE SAD WITH ALEF MAKSURA FINAL FORM
FD22 ARABIC LIGATURE SAD WITH YEH FINAL FORM
FD23 ARABIC LIGATURE DAD WITH ALEF MAKSURA FINAL FORM
FD24 ARABIC LIGATURE DAD WITH YEH FINAL FORM
FD25 ARABIC LIGATURE SHEEN WITH JEEM FINAL FORM
FD26 ARABIC LIGATURE SHEEN WITH HAH FINAL FORM
FD27 ARABIC LIGATURE SHEEN WITH KHAH FINAL FORM
FD28 ARABIC LIGATURE SHEEN WITH MEEM FINAL FORM
FD29 ARABIC LIGATURE SHEEN WITH REH FINAL FORM
FD2A ARABIC LIGATURE SEEN WITH REH FINAL FORM
FD2B ARABIC LIGATURE SAD WITH REH FINAL FORM
FD2C ARABIC LIGATURE DAD WITH REH FINAL FORM
FD2D ARABIC LIGATURE SHEEN WITH JEEM INITIAL FORM
FD2E ARABIC LIGATURE SHEEN WITH HAH INITIAL FORM
FD2F ARABIC LIGATURE SHEEN WITH KHAH INITIAL FORM
FD30 ARABIC LIGATURE SHEEN WITH MEEM INITIAL FORM
FD31 ARABIC LIGATURE SEEN WITH HEH INITIAL FORM
FD32 ARABIC LIGATURE SHEEN WITH HEH INITIAL FORM
FD33 ARABIC LIGATURE TAH WITH MEEM INITIAL FORM
FD34 ARABIC LIGATURE SEEN WITH JEEM MEDIAL FORM
FD35 ARABIC LIGATURE SEEN WITH HAH MEDIAL FORM
FD36 ARABIC LIGATURE SEEN WITH KHAH MEDIAL FORM
FD37 ARABIC LIGATURE SHEEN WITH JEEM MEDIAL FORM
FD38 ARABIC LIGATURE SHEEN WITH HAH MEDIAL FORM
FD39 ARABIC LIGATURE SHEEN WITH KHAH MEDIAL FORM
FD3A ARABIC LIGATURE TAH WITH MEEM MEDIAL FORM
FD3B ARABIC LIGATURE ZAH WITH MEEM MEDIAL FORM
FD3C ARABIC LIGATURE ALEF WITH FATHATAN FINAL FORM
FD3D ARABIC LIGATURE ALEF WITH FATHATAN ISOLATED FORM
FD3E ORNATE LEFT PARENTHESIS
FD3F ORNATE RIGHT PARENTHESIS
FD50 ARABIC LIGATURE TEH WITH JEEM WITH MEEM INITIAL FORM
FD51 ARABIC LIGATURE TEH WITH HAH WITH JEEM FINAL FORM
FD52 ARABIC LIGATURE TEH WITH HAH WITH JEEM INITIAL FORM
FD53 ARABIC LIGATURE TEH WITH HAH WITH MEEM INITIAL FORM
FD54 ARABIC LIGATURE TEH WITH KHAH WITH MEEM INITIAL FORM
FD55 ARABIC LIGATURE TEH WITH MEEM WITH JEEM INITIAL FORM
FD56 ARABIC LIGATURE TEH WITH MEEM WITH HAH INITIAL FORM
FD57 ARABIC LIGATURE TEH WITH MEEM WITH KHAH INITIAL FORM
FD58 ARABIC LIGATURE JEEM WITH MEEM WITH HAH FINAL FORM
FD59 ARABIC LIGATURE JEEM WITH MEEM WITH HAH INITIAL FORM
FD5A ARABIC LIGATURE HAH WITH MEEM WITH YEH FINAL FORM
FD5B ARABIC LIGATURE HAH WITH MEEM WITH ALEF MAKSURA FINAL FORM
FD5C ARABIC LIGATURE SEEN WITH HAH WITH JEEM INITIAL FORM
FD5D ARABIC LIGATURE SEEN WITH JEEM WITH HAH INITIAL FORM
FD5E ARABIC LIGATURE SEEN WITH JEEM WITH ALEF MAKSURA FINAL FORM
FD5F ARABIC LIGATURE SEEN WITH MEEM WITH HAH FINAL FORM
FD60 ARABIC LIGATURE SEEN WITH MEEM WITH HAH INITIAL FORM
FD61 ARABIC LIGATURE SEEN WITH MEEM WITH JEEM INITIAL FORM
FD62 ARABIC LIGATURE SEEN WITH MEEM WITH MEEM FINAL FORM
FD63 ARABIC LIGATURE SEEN WITH MEEM WITH MEEM INITIAL FORM
FD64 ARABIC LIGATURE SAD WITH HAH WITH HAH FINAL FORM
FD65 ARABIC LIGATURE SAD WITH HAH WITH HAH INITIAL FORM
FD66 ARABIC LIGATURE SAD WITH MEEM WITH MEEM FINAL FORM
FD67 ARABIC LIGATURE SHEEN WITH HAH WITH MEEM FINAL FORM
FD68 ARABIC LIGATURE SHEEN WITH HAH WITH MEEM INITIAL FORM
FD69 ARABIC LIGATURE SHEEN WITH JEEM WITH YEH FINAL FORM
FD6A ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH FINAL FORM
FD6B ARABIC LIGATURE SHEEN WITH MEEM WITH KHAH INITIAL FORM
FD6C ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM FINAL FORM
FD6D ARABIC LIGATURE SHEEN WITH MEEM WITH MEEM INITIAL FORM
FD6E ARABIC LIGATURE DAD WITH HAH WITH ALEF MAKSURA FINAL FORM
FD6F ARABIC LIGATURE DAD WITH KHAH WITH MEEM FINAL FORM
FD70 ARABIC LIGATURE DAD WITH KHAH WITH MEEM INITIAL FORM
FD71 ARABIC LIGATURE TAH WITH MEEM WITH HAH FINAL FORM
FD72 ARABIC LIGATURE TAH WITH MEEM WITH HAH INITIAL FORM
FD73 ARABIC LIGATURE TAH WITH MEEM WITH MEEM INITIAL FORM
FD74 ARABIC LIGATURE TAH WITH MEEM WITH YEH FINAL FORM
FD75 ARABIC LIGATURE AIN WITH JEEM WITH MEEM FINAL FORM
FD76 ARABIC LIGATURE AIN WITH MEEM WITH MEEM FINAL FORM
FD77 ARABIC LIGATURE AIN WITH MEEM WITH MEEM INITIAL FORM
FD78 ARABIC LIGATURE AIN WITH MEEM WITH ALEF MAKSURA FINAL FORM
FD79 ARABIC LIGATURE GHAIN WITH MEEM WITH MEEM FINAL FORM
FD7A ARABIC LIGATURE GHAIN WITH MEEM WITH YEH FINAL FORM
FD7B ARABIC LIGATURE GHAIN WITH MEEM WITH ALEF MAKSURA FINAL FORM
FD7C ARABIC LIGATURE FEH WITH KHAH WITH MEEM FINAL FORM
FD7D ARABIC LIGATURE FEH WITH KHAH WITH MEEM INITIAL FORM
FD7E ARABIC LIGATURE QAF WITH MEEM WITH HAH FINAL FORM
FD7F ARABIC LIGATURE QAF WITH MEEM WITH MEEM FINAL FORM
FD80 ARABIC LIGATURE LAM WITH HAH WITH MEEM FINAL FORM
FD81 ARABIC LIGATURE LAM WITH HAH WITH YEH FINAL FORM
FD82 ARABIC LIGATURE LAM WITH HAH WITH ALEF MAKSURA FINAL FORM
FD83 ARABIC LIGATURE LAM WITH JEEM WITH JEEM INITIAL FORM
FD84 ARABIC LIGATURE LAM WITH JEEM WITH JEEM FINAL FORM
FD85 ARABIC LIGATURE LAM WITH KHAH WITH MEEM FINAL FORM
FD86 ARABIC LIGATURE LAM WITH KHAH WITH MEEM INITIAL FORM
FD87 ARABIC LIGATURE LAM WITH MEEM WITH HAH FINAL FORM
FD88 ARABIC LIGATURE LAM WITH MEEM WITH HAH INITIAL FORM
FD89 ARABIC LIGATURE MEEM WITH HAH WITH JEEM INITIAL FORM
FD8A ARABIC LIGATURE MEEM WITH HAH WITH MEEM INITIAL FORM
FD8B ARABIC LIGATURE MEEM WITH HAH WITH YEH FINAL FORM
FD8C ARABIC LIGATURE MEEM WITH JEEM WITH HAH INITIAL FORM
FD8D ARABIC LIGATURE MEEM WITH JEEM WITH MEEM INITIAL FORM
FD8E ARABIC LIGATURE MEEM WITH KHAH WITH JEEM INITIAL FORM
FD8F ARABIC LIGATURE MEEM WITH KHAH WITH MEEM INITIAL FORM
FD92 ARABIC LIGATURE MEEM WITH JEEM WITH KHAH INITIAL FORM
FD93 ARABIC LIGATURE HEH WITH MEEM WITH JEEM INITIAL FORM
FD94 ARABIC LIGATURE HEH WITH MEEM WITH MEEM INITIAL FORM
FD95 ARABIC LIGATURE NOON WITH HAH WITH MEEM INITIAL FORM
FD96 ARABIC LIGATURE NOON WITH HAH WITH ALEF MAKSURA FINAL FORM
FD97 ARABIC LIGATURE NOON WITH JEEM WITH MEEM FINAL FORM
FD98 ARABIC LIGATURE NOON WITH JEEM WITH MEEM INITIAL FORM
FD99 ARABIC LIGATURE NOON WITH JEEM WITH ALEF MAKSURA FINAL FORM
FD9A ARABIC LIGATURE NOON WITH MEEM WITH YEH FINAL FORM
FD9B ARABIC LIGATURE NOON WITH MEEM WITH ALEF MAKSURA FINAL FORM
FD9C ARABIC LIGATURE YEH WITH MEEM WITH MEEM FINAL FORM
FD9D ARABIC LIGATURE YEH WITH MEEM WITH MEEM INITIAL FORM
FD9E ARABIC LIGATURE BEH WITH KHAH WITH YEH FINAL FORM
FD9F ARABIC LIGATURE TEH WITH JEEM WITH YEH FINAL FORM
FDA0 ARABIC LIGATURE TEH WITH JEEM WITH ALEF MAKSURA FINAL FORM
FDA1 ARABIC LIGATURE TEH WITH KHAH WITH YEH FINAL FORM
FDA2 ARABIC LIGATURE TEH WITH KHAH WITH ALEF MAKSURA FINAL FORM
FDA3 ARABIC LIGATURE TEH WITH MEEM WITH YEH FINAL FORM
FDA4 ARABIC LIGATURE TEH WITH MEEM WITH ALEF MAKSURA FINAL FORM
FDA5 ARABIC LIGATURE JEEM WITH MEEM WITH YEH FINAL FORM
FDA6 ARABIC LIGATURE JEEM WITH HAH WITH ALEF MAKSURA FINAL FORM
FDA7 ARABIC LIGATURE JEEM WITH MEEM WITH ALEF MAKSURA FINAL FORM
FDA8 ARABIC LIGATURE SEEN WITH KHAH WITH ALEF MAKSURA FINAL FORM
FDA9 ARABIC LIGATURE SAD WITH HAH WITH YEH FINAL FORM
FDAA ARABIC LIGATURE SHEEN WITH HAH WITH YEH FINAL FORM
FDAB ARABIC LIGATURE DAD WITH HAH WITH YEH FINAL FORM
FDAC ARABIC LIGATURE LAM WITH JEEM WITH YEH FINAL FORM
FDAD ARABIC LIGATURE LAM WITH MEEM WITH YEH FINAL FORM
FDAE ARABIC LIGATURE YEH WITH HAH WITH YEH FINAL FORM
FDAF ARABIC LIGATURE YEH WITH JEEM WITH YEH FINAL FORM
FDB0 ARABIC LIGATURE YEH WITH MEEM WITH YEH FINAL FORM
FDB1 ARABIC LIGATURE MEEM WITH MEEM WITH YEH FINAL FORM
FDB2 ARABIC LIGATURE QAF WITH MEEM WITH YEH FINAL FORM
FDB3 ARABIC LIGATURE NOON WITH HAH WITH YEH FINAL FORM
FDB4 ARABIC LIGATURE QAF WITH MEEM WITH HAH INITIAL FORM
FDB5 ARABIC LIGATURE LAM WITH HAH WITH MEEM INITIAL FORM
FDB6 ARABIC LIGATURE AIN WITH MEEM WITH YEH FINAL FORM
FDB7 ARABIC LIGATURE KAF WITH MEEM WITH YEH FINAL FORM
FDB8 ARABIC LIGATURE NOON WITH JEEM WITH HAH INITIAL FORM
FDB9 ARABIC LIGATURE MEEM WITH KHAH WITH YEH FINAL FORM
FDBA ARABIC LIGATURE LAM WITH JEEM WITH MEEM INITIAL FORM
FDBB ARABIC LIGATURE KAF WITH MEEM WITH MEEM FINAL FORM
FDBC ARABIC LIGATURE LAM WITH JEEM WITH MEEM FINAL FORM
FDBD ARABIC LIGATURE NOON WITH JEEM WITH HAH FINAL FORM
FDBE ARABIC LIGATURE JEEM WITH HAH WITH YEH FINAL FORM
FDBF ARABIC LIGATURE HAH WITH JEEM WITH YEH FINAL FORM
FDC0 ARABIC LIGATURE MEEM WITH JEEM WITH YEH FINAL FORM
FDC1 ARABIC LIGATURE FEH WITH MEEM WITH YEH FINAL FORM
FDC2 ARABIC LIGATURE BEH WITH HAH WITH YEH FINAL FORM
FDC3 ARABIC LIGATURE KAF WITH MEEM WITH MEEM INITIAL FORM
FDC4 ARABIC LIGATURE AIN WITH JEEM WITH MEEM INITIAL FORM
FDC5 ARABIC LIGATURE SAD WITH MEEM WITH MEEM INITIAL FORM
FDC6 ARABIC LIGATURE SEEN WITH KHAH WITH YEH FINAL FORM
FDC7 ARABIC LIGATURE NOON WITH JEEM WITH YEH FINAL FORM
FDF0 ARABIC LIGATURE SALLA USED AS KORANIC STOP SIGN ISOLATED FORM
FDF1 ARABIC LIGATURE QALA USED AS KORANIC STOP SIGN ISOLATED FORM
FDF2 ARABIC LIGATURE ALLAH ISOLATED FORM
FDF3 ARABIC LIGATURE AKBAR ISOLATED FORM
FDF4 ARABIC LIGATURE MOHAMMAD ISOLATED FORM
FDF5 ARABIC LIGATURE SALAM ISOLATED FORM
FDF6 ARABIC LIGATURE RASOUL ISOLATED FORM
FDF7 ARABIC LIGATURE ALAYHE ISOLATED FORM
FDF8 ARABIC LIGATURE WASALLAM ISOLATED FORM
FDF9 ARABIC LIGATURE SALLA ISOLATED FORM
FDFA ARABIC LIGATURE SALLALLAHOU ALAYHE WASALLAM
FDFB ARABIC LIGATURE JALLAJALALOUHOU
FDFC RIAL SIGN
FDFD ARABIC LIGATURE BISMILLAH AR-RAHMAN AR-RAHEEM
FE00 VARIATION SELECTOR-1, VS1
FE01 VARIATION SELECTOR-2, VS2
FE02 VARIATION SELECTOR-3, VS3
FE03 VARIATION SELECTOR-4, VS4
FE04 VARIATION SELECTOR-5, VS5
FE05 VARIATION SELECTOR-6, VS6
FE06 VARIATION SELECTOR-7, VS7
FE07 VARIATION SELECTOR-8, VS8
FE08 VARIATION SELECTOR-9, VS9
FE09 VARIATION SELECTOR-10, VS10
FE0A VARIATION SELECTOR-11, VS11
FE0B VARIATION SELECTOR-12, VS12
FE0C VARIATION SELECTOR-13, VS13
FE0D VARIATION SELECTOR-14, VS14
FE0E VARIATION SELECTOR-15, VS15
FE0F VARIATION SELECTOR-16, VS16
FE10 PRESENTATION FORM FOR VERTICAL COMMA
FE11 PRESENTATION FORM FOR VERTICAL IDEOGRAPHIC COMMA
FE12 PRESENTATION FORM FOR VERTICAL IDEOGRAPHIC FULL STOP
FE13 PRESENTATION FORM FOR VERTICAL COLON
FE14 PRESENTATION FORM FOR VERTICAL SEMICOLON
FE15 PRESENTATION FORM FOR VERTICAL EXCLAMATION MARK
FE16 PRESENTATION FORM FOR VERTICAL QUESTION MARK
FE17 PRESENTATION FORM FOR VERTICAL LEFT WHITE LENTICULAR BRACKET
FE18 PRESENTATION FORM FOR VERTICAL RIGHT WHITE LENTICULAR BRAKCET
FE19 PRESENTATION FORM FOR VERTICAL HORIZONTAL ELLIPSIS
FE20 COMBINING LIGATURE LEFT HALF
FE21 COMBINING LIGATURE RIGHT HALF
FE22 COMBINING DOUBLE TILDE LEFT HALF
FE23 COMBINING DOUBLE TILDE RIGHT HALF
FE24 COMBINING MACRON LEFT HALF
FE25 COMBINING MACRON RIGHT HALF
FE26 COMBINING CONJOINING MACRON
FE27 COMBINING LIGATURE LEFT HALF BELOW
FE28 COMBINING LIGATURE RIGHT HALF BELOW
FE29 COMBINING TILDE LEFT HALF BELOW
FE2A COMBINING TILDE RIGHT HALF BELOW
FE2B COMBINING MACRON LEFT HALF BELOW
FE2C COMBINING MACRON RIGHT HALF BELOW
FE2D COMBINING CONJOINING MACRON BELOW
FE2E COMBINING CYRILLIC TITLO LEFT HALF
FE2F COMBINING CYRILLIC TITLO RIGHT HALF
FE30 PRESENTATION FORM FOR VERTICAL TWO DOT LEADER
FE31 PRESENTATION FORM FOR VERTICAL EM DASH
FE32 PRESENTATION FORM FOR VERTICAL EN DASH
FE33 PRESENTATION FORM FOR VERTICAL LOW LINE
FE34 PRESENTATION FORM FOR VERTICAL WAVY LOW LINE
FE35 PRESENTATION FORM FOR VERTICAL LEFT PARENTHESIS
FE36 PRESENTATION FORM FOR VERTICAL RIGHT PARENTHESIS
FE37 PRESENTATION FORM FOR VERTICAL LEFT CURLY BRACKET
FE38 PRESENTATION FORM FOR VERTICAL RIGHT CURLY BRACKET
FE39 PRESENTATION FORM FOR VERTICAL LEFT TORTOISE SHELL BRACKET
FE3A PRESENTATION FORM FOR VERTICAL RIGHT TORTOISE SHELL BRACKET
FE3B PRESENTATION FORM FOR VERTICAL LEFT BLACK LENTICULAR BRACKET
FE3C PRESENTATION FORM FOR VERTICAL RIGHT BLACK LENTICULAR BRACKET
FE3D PRESENTATION FORM FOR VERTICAL LEFT DOUBLE ANGLE BRACKET
FE3E PRESENTATION FORM FOR VERTICAL RIGHT DOUBLE ANGLE BRACKET
FE3F PRESENTATION FORM FOR VERTICAL LEFT ANGLE BRACKET
FE40 PRESENTATION FORM FOR VERTICAL RIGHT ANGLE BRACKET
FE41 PRESENTATION FORM FOR VERTICAL LEFT CORNER BRACKET
FE42 PRESENTATION FORM FOR VERTICAL RIGHT CORNER BRACKET
FE43 PRESENTATION FORM FOR VERTICAL LEFT WHITE CORNER BRACKET
FE44 PRESENTATION FORM FOR VERTICAL RIGHT WHITE CORNER BRACKET
FE45 SESAME DOT
FE46 WHITE SESAME DOT
FE47 PRESENTATION FORM FOR VERTICAL LEFT SQUARE BRACKET
FE48 PRESENTATION FORM FOR VERTICAL RIGHT SQUARE BRACKET
FE49 DASHED OVERLINE
FE4A CENTRELINE OVERLINE
FE4B WAVY OVERLINE
FE4C DOUBLE WAVY OVERLINE
FE4D DASHED LOW LINE
FE4E CENTRELINE LOW LINE
FE4F WAVY LOW LINE
FE50 SMALL COMMA
FE51 SMALL IDEOGRAPHIC COMMA
FE52 SMALL FULL STOP
FE54 SMALL SEMICOLON
FE55 SMALL COLON
FE56 SMALL QUESTION MARK
FE57 SMALL EXCLAMATION MARK
FE58 SMALL EM DASH
FE59 SMALL LEFT PARENTHESIS
FE5A SMALL RIGHT PARENTHESIS
FE5B SMALL LEFT CURLY BRACKET
FE5C SMALL RIGHT CURLY BRACKET
FE5D SMALL LEFT TORTOISE SHELL BRACKET
FE5E SMALL RIGHT TORTOISE SHELL BRACKET
FE5F SMALL NUMBER SIGN
FE60 SMALL AMPERSAND
FE61 SMALL ASTERISK
FE62 SMALL PLUS SIGN
FE63 SMALL HYPHEN-MINUS
FE64 SMALL LESS-THAN SIGN
FE65 SMALL GREATER-THAN SIGN
FE66 SMALL EQUALS SIGN
FE68 SMALL REVERSE SOLIDUS
FE69 SMALL DOLLAR SIGN
FE6A SMALL PERCENT SIGN
FE6B SMALL COMMERCIAL AT
FE70 ARABIC FATHATAN ISOLATED FORM
FE71 ARABIC TATWEEL WITH FATHATAN ABOVE
FE72 ARABIC DAMMATAN ISOLATED FORM
FE73 ARABIC TAIL FRAGMENT
FE74 ARABIC KASRATAN ISOLATED FORM
FE76 ARABIC FATHA ISOLATED FORM
FE77 ARABIC FATHA MEDIAL FORM
FE78 ARABIC DAMMA ISOLATED FORM
FE79 ARABIC DAMMA MEDIAL FORM
FE7A ARABIC KASRA ISOLATED FORM
FE7B ARABIC KASRA MEDIAL FORM
FE7C ARABIC SHADDA ISOLATED FORM
FE7D ARABIC SHADDA MEDIAL FORM
FE7E ARABIC SUKUN ISOLATED FORM
FE7F ARABIC SUKUN MEDIAL FORM
FE80 ARABIC LETTER HAMZA ISOLATED FORM
FE81 ARABIC LETTER ALEF WITH MADDA ABOVE ISOLATED FORM
FE82 ARABIC LETTER ALEF WITH MADDA ABOVE FINAL FORM
FE83 ARABIC LETTER ALEF WITH HAMZA ABOVE ISOLATED FORM
FE84 ARABIC LETTER ALEF WITH HAMZA ABOVE FINAL FORM
FE85 ARABIC LETTER WAW WITH HAMZA ABOVE ISOLATED FORM
FE86 ARABIC LETTER WAW WITH HAMZA ABOVE FINAL FORM
FE87 ARABIC LETTER ALEF WITH HAMZA BELOW ISOLATED FORM
FE88 ARABIC LETTER ALEF WITH HAMZA BELOW FINAL FORM
FE89 ARABIC LETTER YEH WITH HAMZA ABOVE ISOLATED FORM
FE8A ARABIC LETTER YEH WITH HAMZA ABOVE FINAL FORM
FE8B ARABIC LETTER YEH WITH HAMZA ABOVE INITIAL FORM
FE8C ARABIC LETTER YEH WITH HAMZA ABOVE MEDIAL FORM
FE8D ARABIC LETTER ALEF ISOLATED FORM
FE8E ARABIC LETTER ALEF FINAL FORM
FE8F ARABIC LETTER BEH ISOLATED FORM
FE90 ARABIC LETTER BEH FINAL FORM
FE91 ARABIC LETTER BEH INITIAL FORM
FE92 ARABIC LETTER BEH MEDIAL FORM
FE93 ARABIC LETTER TEH MARBUTA ISOLATED FORM
FE94 ARABIC LETTER TEH MARBUTA FINAL FORM
FE95 ARABIC LETTER TEH ISOLATED FORM
FE96 ARABIC LETTER TEH FINAL FORM
FE97 ARABIC LETTER TEH INITIAL FORM
FE98 ARABIC LETTER TEH MEDIAL FORM
FE99 ARABIC LETTER THEH ISOLATED FORM
FE9A ARABIC LETTER THEH FINAL FORM
FE9B ARABIC LETTER THEH INITIAL FORM
FE9C ARABIC LETTER THEH MEDIAL FORM
FE9D ARABIC LETTER JEEM ISOLATED FORM
FE9E ARABIC LETTER JEEM FINAL FORM
FE9F ARABIC LETTER JEEM INITIAL FORM
FEA0 ARABIC LETTER JEEM MEDIAL FORM
FEA1 ARABIC LETTER HAH ISOLATED FORM
FEA2 ARABIC LETTER HAH FINAL FORM
FEA3 ARABIC LETTER HAH INITIAL FORM
FEA4 ARABIC LETTER HAH MEDIAL FORM
FEA5 ARABIC LETTER KHAH ISOLATED FORM
FEA6 ARABIC LETTER KHAH FINAL FORM
FEA7 ARABIC LETTER KHAH INITIAL FORM
FEA8 ARABIC LETTER KHAH MEDIAL FORM
FEA9 ARABIC LETTER DAL ISOLATED FORM
FEAA ARABIC LETTER DAL FINAL FORM
FEAB ARABIC LETTER THAL ISOLATED FORM
FEAC ARABIC LETTER THAL FINAL FORM
FEAD ARABIC LETTER REH ISOLATED FORM
FEAE ARABIC LETTER REH FINAL FORM
FEAF ARABIC LETTER ZAIN ISOLATED FORM
FEB0 ARABIC LETTER ZAIN FINAL FORM
FEB1 ARABIC LETTER SEEN ISOLATED FORM
FEB2 ARABIC LETTER SEEN FINAL FORM
FEB3 ARABIC LETTER SEEN INITIAL FORM
FEB4 ARABIC LETTER SEEN MEDIAL FORM
FEB5 ARABIC LETTER SHEEN ISOLATED FORM
FEB6 ARABIC LETTER SHEEN FINAL FORM
FEB7 ARABIC LETTER SHEEN INITIAL FORM
FEB8 ARABIC LETTER SHEEN MEDIAL FORM
FEB9 ARABIC LETTER SAD ISOLATED FORM
FEBA ARABIC LETTER SAD FINAL FORM
FEBB ARABIC LETTER SAD INITIAL FORM
FEBC ARABIC LETTER SAD MEDIAL FORM
FEBD ARABIC LETTER DAD ISOLATED FORM
FEBE ARABIC LETTER DAD FINAL FORM
FEBF ARABIC LETTER DAD INITIAL FORM
FEC0 ARABIC LETTER DAD MEDIAL FORM
FEC1 ARABIC LETTER TAH ISOLATED FORM
FEC2 ARABIC LETTER TAH FINAL FORM
FEC3 ARABIC LETTER TAH INITIAL FORM
FEC4 ARABIC LETTER TAH MEDIAL FORM
FEC5 ARABIC LETTER ZAH ISOLATED FORM
FEC6 ARABIC LETTER ZAH FINAL FORM
FEC7 ARABIC LETTER ZAH INITIAL FORM
FEC8 ARABIC LETTER ZAH MEDIAL FORM
FEC9 ARABIC LETTER AIN ISOLATED FORM
FECA ARABIC LETTER AIN FINAL FORM
FECB ARABIC LETTER AIN INITIAL FORM
FECC ARABIC LETTER AIN MEDIAL FORM
FECD ARABIC LETTER GHAIN ISOLATED FORM
FECE ARABIC LETTER GHAIN FINAL FORM
FECF ARABIC LETTER GHAIN INITIAL FORM
FED0 ARABIC LETTER GHAIN MEDIAL FORM
FED1 ARABIC LETTER FEH ISOLATED FORM
FED2 ARABIC LETTER FEH FINAL FORM
FED3 ARABIC LETTER FEH INITIAL FORM
FED4 ARABIC LETTER FEH MEDIAL FORM
FED5 ARABIC LETTER QAF ISOLATED FORM
FED6 ARABIC LETTER QAF FINAL FORM
FED7 ARABIC LETTER QAF INITIAL FORM
FED8 ARABIC LETTER QAF MEDIAL FORM
FED9 ARABIC LETTER KAF ISOLATED FORM
FEDA ARABIC LETTER KAF FINAL FORM
FEDB ARABIC LETTER KAF INITIAL FORM
FEDC ARABIC LETTER KAF MEDIAL FORM
FEDD ARABIC LETTER LAM ISOLATED FORM
FEDE ARABIC LETTER LAM FINAL FORM
FEDF ARABIC LETTER LAM INITIAL FORM
FEE0 ARABIC LETTER LAM MEDIAL FORM
FEE1 ARABIC LETTER MEEM ISOLATED FORM
FEE2 ARABIC LETTER MEEM FINAL FORM
FEE3 ARABIC LETTER MEEM INITIAL FORM
FEE4 ARABIC LETTER MEEM MEDIAL FORM
FEE5 ARABIC LETTER NOON ISOLATED FORM
FEE6 ARABIC LETTER NOON FINAL FORM
FEE7 ARABIC LETTER NOON INITIAL FORM
FEE8 ARABIC LETTER NOON MEDIAL FORM
FEE9 ARABIC LETTER HEH ISOLATED FORM
FEEA ARABIC LETTER HEH FINAL FORM
FEEB ARABIC LETTER HEH INITIAL FORM
FEEC ARABIC LETTER HEH MEDIAL FORM
FEED ARABIC LETTER WAW ISOLATED FORM
FEEE ARABIC LETTER WAW FINAL FORM
FEEF ARABIC LETTER ALEF MAKSURA ISOLATED FORM
FEF0 ARABIC LETTER ALEF MAKSURA FINAL FORM
FEF1 ARABIC LETTER YEH ISOLATED FORM
FEF2 ARABIC LETTER YEH FINAL FORM
FEF3 ARABIC LETTER YEH INITIAL FORM
FEF4 ARABIC LETTER YEH MEDIAL FORM
FEF5 ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE ISOLATED FORM
FEF6 ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE FINAL FORM
FEF7 ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE ISOLATED FORM
FEF8 ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE FINAL FORM
FEF9 ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW ISOLATED FORM
FEFA ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW FINAL FORM
FEFB ARABIC LIGATURE LAM WITH ALEF ISOLATED FORM
FEFC ARABIC LIGATURE LAM WITH ALEF FINAL FORM
FEFF ZERO WIDTH NO-BREAK SPACE, BOM ZWNBSP, BYTE ORDER MARK
FF01 FULLWIDTH EXCLAMATION MARK
FF02 FULLWIDTH QUOTATION MARK
FF03 FULLWIDTH NUMBER SIGN
FF04 FULLWIDTH DOLLAR SIGN
FF05 FULLWIDTH PERCENT SIGN
FF06 FULLWIDTH AMPERSAND
FF07 FULLWIDTH APOSTROPHE
FF08 FULLWIDTH LEFT PARENTHESIS
FF09 FULLWIDTH RIGHT PARENTHESIS
FF0A FULLWIDTH ASTERISK
FF0B FULLWIDTH PLUS SIGN
FF0C FULLWIDTH COMMA
FF0D FULLWIDTH HYPHEN-MINUS
FF0E FULLWIDTH FULL STOP
FF0F FULLWIDTH SOLIDUS
FF10 FULLWIDTH DIGIT ZERO
FF11 FULLWIDTH DIGIT ONE
FF12 FULLWIDTH DIGIT TWO
FF13 FULLWIDTH DIGIT THREE
FF14 FULLWIDTH DIGIT FOUR
FF15 FULLWIDTH DIGIT FIVE
FF16 FULLWIDTH DIGIT SIX
FF17 FULLWIDTH DIGIT SEVEN
FF18 FULLWIDTH DIGIT EIGHT
FF19 FULLWIDTH DIGIT NINE
FF1A FULLWIDTH COLON
FF1B FULLWIDTH SEMICOLON
FF1C FULLWIDTH LESS-THAN SIGN
FF1D FULLWIDTH EQUALS SIGN
FF1E FULLWIDTH GREATER-THAN SIGN
FF1F FULLWIDTH QUESTION MARK
FF20 FULLWIDTH COMMERCIAL AT
FF21 FULLWIDTH LATIN CAPITAL LETTER A
FF22 FULLWIDTH LATIN CAPITAL LETTER B
FF23 FULLWIDTH LATIN CAPITAL LETTER C
FF24 FULLWIDTH LATIN CAPITAL LETTER D
FF25 FULLWIDTH LATIN CAPITAL LETTER E
FF26 FULLWIDTH LATIN CAPITAL LETTER F
FF27 FULLWIDTH LATIN CAPITAL LETTER G
FF28 FULLWIDTH LATIN CAPITAL LETTER H
FF29 FULLWIDTH LATIN CAPITAL LETTER I
FF2A FULLWIDTH LATIN CAPITAL LETTER J
FF2B FULLWIDTH LATIN CAPITAL LETTER K
FF2C FULLWIDTH LATIN CAPITAL LETTER L
FF2D FULLWIDTH LATIN CAPITAL LETTER M
FF2E FULLWIDTH LATIN CAPITAL LETTER N
FF2F FULLWIDTH LATIN CAPITAL LETTER O
FF30 FULLWIDTH LATIN CAPITAL LETTER P
FF31 FULLWIDTH LATIN CAPITAL LETTER Q
FF32 FULLWIDTH LATIN CAPITAL LETTER R
FF33 FULLWIDTH LATIN CAPITAL LETTER S
FF34 FULLWIDTH LATIN CAPITAL LETTER T
FF35 FULLWIDTH LATIN CAPITAL LETTER U
FF36 FULLWIDTH LATIN CAPITAL LETTER V
FF37 FULLWIDTH LATIN CAPITAL LETTER W
FF38 FULLWIDTH LATIN CAPITAL LETTER X
FF39 FULLWIDTH LATIN CAPITAL LETTER Y
FF3A FULLWIDTH LATIN CAPITAL LETTER Z
FF3B FULLWIDTH LEFT SQUARE BRACKET
FF3C FULLWIDTH REVERSE SOLIDUS
FF3D FULLWIDTH RIGHT SQUARE BRACKET
FF3E FULLWIDTH CIRCUMFLEX ACCENT
FF3F FULLWIDTH LOW LINE
FF40 FULLWIDTH GRAVE ACCENT
FF41 FULLWIDTH LATIN SMALL LETTER A
FF42 FULLWIDTH LATIN SMALL LETTER B
FF43 FULLWIDTH LATIN SMALL LETTER C
FF44 FULLWIDTH LATIN SMALL LETTER D
FF45 FULLWIDTH LATIN SMALL LETTER E
FF46 FULLWIDTH LATIN SMALL LETTER F
FF47 FULLWIDTH LATIN SMALL LETTER G
FF48 FULLWIDTH LATIN SMALL LETTER H
FF49 FULLWIDTH LATIN SMALL LETTER I
FF4A FULLWIDTH LATIN SMALL LETTER J
FF4B FULLWIDTH LATIN SMALL LETTER K
FF4C FULLWIDTH LATIN SMALL LETTER L
FF4D FULLWIDTH LATIN SMALL LETTER M
FF4E FULLWIDTH LATIN SMALL LETTER N
FF4F FULLWIDTH LATIN SMALL LETTER O
FF50 FULLWIDTH LATIN SMALL LETTER P
FF51 FULLWIDTH LATIN SMALL LETTER Q
FF52 FULLWIDTH LATIN SMALL LETTER R
FF53 FULLWIDTH LATIN SMALL LETTER S
FF54 FULLWIDTH LATIN SMALL LETTER T
FF55 FULLWIDTH LATIN SMALL LETTER U
FF56 FULLWIDTH LATIN SMALL LETTER V
FF57 FULLWIDTH LATIN SMALL LETTER W
FF58 FULLWIDTH LATIN SMALL LETTER X
FF59 FULLWIDTH LATIN SMALL LETTER Y
FF5A FULLWIDTH LATIN SMALL LETTER Z
FF5B FULLWIDTH LEFT CURLY BRACKET
FF5C FULLWIDTH VERTICAL LINE
FF5D FULLWIDTH RIGHT CURLY BRACKET
FF5E FULLWIDTH TILDE
FF5F FULLWIDTH LEFT WHITE PARENTHESIS
FF60 FULLWIDTH RIGHT WHITE PARENTHESIS
FF61 HALFWIDTH IDEOGRAPHIC FULL STOP
FF62 HALFWIDTH LEFT CORNER BRACKET
FF63 HALFWIDTH RIGHT CORNER BRACKET
FF64 HALFWIDTH IDEOGRAPHIC COMMA
FF65 HALFWIDTH KATAKANA MIDDLE DOT
FF66 HALFWIDTH KATAKANA LETTER WO
FF67 HALFWIDTH KATAKANA LETTER SMALL A
FF68 HALFWIDTH KATAKANA LETTER SMALL I
FF69 HALFWIDTH KATAKANA LETTER SMALL U
FF6A HALFWIDTH KATAKANA LETTER SMALL E
FF6B HALFWIDTH KATAKANA LETTER SMALL O
FF6C HALFWIDTH KATAKANA LETTER SMALL YA
FF6D HALFWIDTH KATAKANA LETTER SMALL YU
FF6E HALFWIDTH KATAKANA LETTER SMALL YO
FF6F HALFWIDTH KATAKANA LETTER SMALL TU
FF70 HALFWIDTH KATAKANA-HIRAGANA PROLONGED SOUND MARK
FF71 HALFWIDTH KATAKANA LETTER A
FF72 HALFWIDTH KATAKANA LETTER I
FF73 HALFWIDTH KATAKANA LETTER U
FF74 HALFWIDTH KATAKANA LETTER E
FF75 HALFWIDTH KATAKANA LETTER O
FF76 HALFWIDTH KATAKANA LETTER KA
FF77 HALFWIDTH KATAKANA LETTER KI
FF78 HALFWIDTH KATAKANA LETTER KU
FF79 HALFWIDTH KATAKANA LETTER KE
FF7A HALFWIDTH KATAKANA LETTER KO
FF7B HALFWIDTH KATAKANA LETTER SA
FF7C HALFWIDTH KATAKANA LETTER SI
FF7D HALFWIDTH KATAKANA LETTER SU
FF7E HALFWIDTH KATAKANA LETTER SE
FF7F HALFWIDTH KATAKANA LETTER SO
FF80 HALFWIDTH KATAKANA LETTER TA
FF81 HALFWIDTH KATAKANA LETTER TI
FF82 HALFWIDTH KATAKANA LETTER TU
FF83 HALFWIDTH KATAKANA LETTER TE
FF84 HALFWIDTH KATAKANA LETTER TO
FF85 HALFWIDTH KATAKANA LETTER NA
FF86 HALFWIDTH KATAKANA LETTER NI
FF87 HALFWIDTH KATAKANA LETTER NU
FF88 HALFWIDTH KATAKANA LETTER NE
FF89 HALFWIDTH KATAKANA LETTER NO
FF8A HALFWIDTH KATAKANA LETTER HA
FF8B HALFWIDTH KATAKANA LETTER HI
FF8C HALFWIDTH KATAKANA LETTER HU
FF8D HALFWIDTH KATAKANA LETTER HE
FF8E HALFWIDTH KATAKANA LETTER HO
FF8F HALFWIDTH KATAKANA LETTER MA
FF90 HALFWIDTH KATAKANA LETTER MI
FF91 HALFWIDTH KATAKANA LETTER MU
FF92 HALFWIDTH KATAKANA LETTER ME
FF93 HALFWIDTH KATAKANA LETTER MO
FF94 HALFWIDTH KATAKANA LETTER YA
FF95 HALFWIDTH KATAKANA LETTER YU
FF96 HALFWIDTH KATAKANA LETTER YO
FF97 HALFWIDTH KATAKANA LETTER RA
FF98 HALFWIDTH KATAKANA LETTER RI
FF99 HALFWIDTH KATAKANA LETTER RU
FF9A HALFWIDTH KATAKANA LETTER RE
FF9B HALFWIDTH KATAKANA LETTER RO
FF9C HALFWIDTH KATAKANA LETTER WA
FF9D HALFWIDTH KATAKANA LETTER N
FF9E HALFWIDTH KATAKANA VOICED SOUND MARK
FF9F HALFWIDTH KATAKANA SEMI-VOICED SOUND MARK
FFA0 HALFWIDTH HANGUL FILLER
FFA1 HALFWIDTH HANGUL LETTER KIYEOK
FFA2 HALFWIDTH HANGUL LETTER SSANGKIYEOK
FFA3 HALFWIDTH HANGUL LETTER KIYEOK-SIOS
FFA4 HALFWIDTH HANGUL LETTER NIEUN
FFA5 HALFWIDTH HANGUL LETTER NIEUN-CIEUC
FFA6 HALFWIDTH HANGUL LETTER NIEUN-HIEUH
FFA7 HALFWIDTH HANGUL LETTER TIKEUT
FFA8 HALFWIDTH HANGUL LETTER SSANGTIKEUT
FFA9 HALFWIDTH HANGUL LETTER RIEUL
FFAA HALFWIDTH HANGUL LETTER RIEUL-KIYEOK
FFAB HALFWIDTH HANGUL LETTER RIEUL-MIEUM
FFAC HALFWIDTH HANGUL LETTER RIEUL-PIEUP
FFAD HALFWIDTH HANGUL LETTER RIEUL-SIOS
FFAE HALFWIDTH HANGUL LETTER RIEUL-THIEUTH
FFAF HALFWIDTH HANGUL LETTER RIEUL-PHIEUPH
FFB0 HALFWIDTH HANGUL LETTER RIEUL-HIEUH
FFB1 HALFWIDTH HANGUL LETTER MIEUM
FFB2 HALFWIDTH HANGUL LETTER PIEUP
FFB3 HALFWIDTH HANGUL LETTER SSANGPIEUP
FFB4 HALFWIDTH HANGUL LETTER PIEUP-SIOS
FFB5 HALFWIDTH HANGUL LETTER SIOS
FFB6 HALFWIDTH HANGUL LETTER SSANGSIOS
FFB7 HALFWIDTH HANGUL LETTER IEUNG
FFB8 HALFWIDTH HANGUL LETTER CIEUC
FFB9 HALFWIDTH HANGUL LETTER SSANGCIEUC
FFBA HALFWIDTH HANGUL LETTER CHIEUCH
FFBB HALFWIDTH HANGUL LETTER KHIEUKH
FFBC HALFWIDTH HANGUL LETTER THIEUTH
FFBD HALFWIDTH HANGUL LETTER PHIEUPH
FFBE HALFWIDTH HANGUL LETTER HIEUH
FFC2 HALFWIDTH HANGUL LETTER A
FFC3 HALFWIDTH HANGUL LETTER AE
FFC4 HALFWIDTH HANGUL LETTER YA
FFC5 HALFWIDTH HANGUL LETTER YAE
FFC6 HALFWIDTH HANGUL LETTER EO
FFC7 HALFWIDTH HANGUL LETTER E
FFCA HALFWIDTH HANGUL LETTER YEO
FFCB HALFWIDTH HANGUL LETTER YE
FFCC HALFWIDTH HANGUL LETTER O
FFCD HALFWIDTH HANGUL LETTER WA
FFCE HALFWIDTH HANGUL LETTER WAE
FFCF HALFWIDTH HANGUL LETTER OE
FFD2 HALFWIDTH HANGUL LETTER YO
FFD3 HALFWIDTH HANGUL LETTER U
FFD4 HALFWIDTH HANGUL LETTER WEO
FFD5 HALFWIDTH HANGUL LETTER WE
FFD6 HALFWIDTH HANGUL LETTER WI
FFD7 HALFWIDTH HANGUL LETTER YU
FFDA HALFWIDTH HANGUL LETTER EU
FFDB HALFWIDTH HANGUL LETTER YI
FFDC HALFWIDTH HANGUL LETTER I
FFE0 FULLWIDTH CENT SIGN
FFE1 FULLWIDTH POUND SIGN
FFE2 FULLWIDTH NOT SIGN
FFE3 FULLWIDTH MACRON
FFE4 FULLWIDTH BROKEN BAR
FFE5 FULLWIDTH YEN SIGN
FFE6 FULLWIDTH WON SIGN
FFE8 HALFWIDTH FORMS LIGHT VERTICAL
FFE9 HALFWIDTH LEFTWARDS ARROW
FFEA HALFWIDTH UPWARDS ARROW
FFEB HALFWIDTH RIGHTWARDS ARROW
FFEC HALFWIDTH DOWNWARDS ARROW
FFED HALFWIDTH BLACK SQUARE
FFEE HALFWIDTH WHITE CIRCLE
FFF9 INTERLINEAR ANNOTATION ANCHOR
FFFA INTERLINEAR ANNOTATION SEPARATOR
FFFB INTERLINEAR ANNOTATION TERMINATOR
FFFC OBJECT REPLACEMENT CHARACTER
FFFD REPLACEMENT CHARACTER
10000 LINEAR B SYLLABLE B008 A
10001 LINEAR B SYLLABLE B038 E
10002 LINEAR B SYLLABLE B028 I
10003 LINEAR B SYLLABLE B061 O
10004 LINEAR B SYLLABLE B010 U
10005 LINEAR B SYLLABLE B001 DA
10006 LINEAR B SYLLABLE B045 DE
10007 LINEAR B SYLLABLE B007 DI
10008 LINEAR B SYLLABLE B014 DO
10009 LINEAR B SYLLABLE B051 DU
1000A LINEAR B SYLLABLE B057 JA
1000B LINEAR B SYLLABLE B046 JE
1000D LINEAR B SYLLABLE B036 JO
1000E LINEAR B SYLLABLE B065 JU
1000F LINEAR B SYLLABLE B077 KA
10010 LINEAR B SYLLABLE B044 KE
10011 LINEAR B SYLLABLE B067 KI
10012 LINEAR B SYLLABLE B070 KO
10013 LINEAR B SYLLABLE B081 KU
10014 LINEAR B SYLLABLE B080 MA
10015 LINEAR B SYLLABLE B013 ME
10016 LINEAR B SYLLABLE B073 MI
10017 LINEAR B SYLLABLE B015 MO
10018 LINEAR B SYLLABLE B023 MU
10019 LINEAR B SYLLABLE B006 NA
1001A LINEAR B SYLLABLE B024 NE
1001B LINEAR B SYLLABLE B030 NI
1001C LINEAR B SYLLABLE B052 NO
1001D LINEAR B SYLLABLE B055 NU
1001E LINEAR B SYLLABLE B003 PA
1001F LINEAR B SYLLABLE B072 PE
10020 LINEAR B SYLLABLE B039 PI
10021 LINEAR B SYLLABLE B011 PO
10022 LINEAR B SYLLABLE B050 PU
10023 LINEAR B SYLLABLE B016 QA
10024 LINEAR B SYLLABLE B078 QE
10025 LINEAR B SYLLABLE B021 QI
10026 LINEAR B SYLLABLE B032 QO
10028 LINEAR B SYLLABLE B060 RA
10029 LINEAR B SYLLABLE B027 RE
1002A LINEAR B SYLLABLE B053 RI
1002B LINEAR B SYLLABLE B002 RO
1002C LINEAR B SYLLABLE B026 RU
1002D LINEAR B SYLLABLE B031 SA
1002E LINEAR B SYLLABLE B009 SE
1002F LINEAR B SYLLABLE B041 SI
10030 LINEAR B SYLLABLE B012 SO
10031 LINEAR B SYLLABLE B058 SU
10032 LINEAR B SYLLABLE B059 TA
10033 LINEAR B SYLLABLE B004 TE
10034 LINEAR B SYLLABLE B037 TI
10035 LINEAR B SYLLABLE B005 TO
10036 LINEAR B SYLLABLE B069 TU
10037 LINEAR B SYLLABLE B054 WA
10038 LINEAR B SYLLABLE B075 WE
10039 LINEAR B SYLLABLE B040 WI
1003A LINEAR B SYLLABLE B042 WO
1003C LINEAR B SYLLABLE B017 ZA
1003D LINEAR B SYLLABLE B074 ZE
1003F LINEAR B SYLLABLE B020 ZO
10040 LINEAR B SYLLABLE B025 A2
10041 LINEAR B SYLLABLE B043 A3
10042 LINEAR B SYLLABLE B085 AU
10043 LINEAR B SYLLABLE B071 DWE
10044 LINEAR B SYLLABLE B090 DWO
10045 LINEAR B SYLLABLE B048 NWA
10046 LINEAR B SYLLABLE B029 PU2
10047 LINEAR B SYLLABLE B062 PTE
10048 LINEAR B SYLLABLE B076 RA2
10049 LINEAR B SYLLABLE B033 RA3
1004A LINEAR B SYLLABLE B068 RO2
1004B LINEAR B SYLLABLE B066 TA2
1004C LINEAR B SYLLABLE B087 TWE
1004D LINEAR B SYLLABLE B091 TWO
10050 LINEAR B SYMBOL B018
10051 LINEAR B SYMBOL B019
10052 LINEAR B SYMBOL B022
10053 LINEAR B SYMBOL B034
10054 LINEAR B SYMBOL B047
10055 LINEAR B SYMBOL B049
10056 LINEAR B SYMBOL B056
10057 LINEAR B SYMBOL B063
10058 LINEAR B SYMBOL B064
10059 LINEAR B SYMBOL B079
1005A LINEAR B SYMBOL B082
1005B LINEAR B SYMBOL B083
1005C LINEAR B SYMBOL B086
1005D LINEAR B SYMBOL B089
10080 LINEAR B IDEOGRAM B100 MAN
10081 LINEAR B IDEOGRAM B102 WOMAN
10082 LINEAR B IDEOGRAM B104 DEER
10083 LINEAR B IDEOGRAM B105 EQUID
10084 LINEAR B IDEOGRAM B105F MARE
10085 LINEAR B IDEOGRAM B105M STALLION
10086 LINEAR B IDEOGRAM B106F EWE
10087 LINEAR B IDEOGRAM B106M RAM
10088 LINEAR B IDEOGRAM B107F SHE-GOAT
10089 LINEAR B IDEOGRAM B107M HE-GOAT
1008A LINEAR B IDEOGRAM B108F SOW
1008B LINEAR B IDEOGRAM B108M BOAR
1008C LINEAR B IDEOGRAM B109F COW
1008D LINEAR B IDEOGRAM B109M BULL
1008E LINEAR B IDEOGRAM B120 WHEAT
1008F LINEAR B IDEOGRAM B121 BARLEY
10090 LINEAR B IDEOGRAM B122 OLIVE
10091 LINEAR B IDEOGRAM B123 SPICE
10092 LINEAR B IDEOGRAM B125 CYPERUS
10093 LINEAR B MONOGRAM B127 KAPO
10094 LINEAR B MONOGRAM B128 KANAKO
10095 LINEAR B IDEOGRAM B130 OIL
10096 LINEAR B IDEOGRAM B131 WINE
10097 LINEAR B IDEOGRAM B132
10098 LINEAR B MONOGRAM B133 AREPA
10099 LINEAR B MONOGRAM B135 MERI
1009A LINEAR B IDEOGRAM B140 BRONZE
1009B LINEAR B IDEOGRAM B141 GOLD
1009C LINEAR B IDEOGRAM B142
1009D LINEAR B IDEOGRAM B145 WOOL
1009E LINEAR B IDEOGRAM B146
1009F LINEAR B IDEOGRAM B150
100A0 LINEAR B IDEOGRAM B151 HORN
100A1 LINEAR B IDEOGRAM B152
100A2 LINEAR B IDEOGRAM B153
100A3 LINEAR B IDEOGRAM B154
100A4 LINEAR B MONOGRAM B156 TURO2
100A5 LINEAR B IDEOGRAM B157
100A6 LINEAR B IDEOGRAM B158
100A7 LINEAR B IDEOGRAM B159 CLOTH
100A8 LINEAR B IDEOGRAM B160
100A9 LINEAR B IDEOGRAM B161
100AA LINEAR B IDEOGRAM B162 GARMENT
100AB LINEAR B IDEOGRAM B163 ARMOUR
100AC LINEAR B IDEOGRAM B164
100AD LINEAR B IDEOGRAM B165
100AE LINEAR B IDEOGRAM B166
100AF LINEAR B IDEOGRAM B167
100B0 LINEAR B IDEOGRAM B168
100B1 LINEAR B IDEOGRAM B169
100B2 LINEAR B IDEOGRAM B170
100B3 LINEAR B IDEOGRAM B171
100B4 LINEAR B IDEOGRAM B172
100B5 LINEAR B IDEOGRAM B173 MONTH
100B6 LINEAR B IDEOGRAM B174
100B7 LINEAR B IDEOGRAM B176 TREE
100B8 LINEAR B IDEOGRAM B177
100B9 LINEAR B IDEOGRAM B178
100BA LINEAR B IDEOGRAM B179
100BB LINEAR B IDEOGRAM B180
100BC LINEAR B IDEOGRAM B181
100BD LINEAR B IDEOGRAM B182
100BE LINEAR B IDEOGRAM B183
100BF LINEAR B IDEOGRAM B184
100C0 LINEAR B IDEOGRAM B185
100C1 LINEAR B IDEOGRAM B189
100C2 LINEAR B IDEOGRAM B190
100C3 LINEAR B IDEOGRAM B191 HELMET
100C4 LINEAR B IDEOGRAM B220 FOOTSTOOL
100C5 LINEAR B IDEOGRAM B225 BATHTUB
100C6 LINEAR B IDEOGRAM B230 SPEAR
100C7 LINEAR B IDEOGRAM B231 ARROW
100C8 LINEAR B IDEOGRAM B232
100C9 LINEAR B IDEOGRAM B233 SWORD
100CA LINEAR B IDEOGRAM B234
100CB LINEAR B IDEOGRAM B236
100CC LINEAR B IDEOGRAM B240 WHEELED CHARIOT
100CD LINEAR B IDEOGRAM B241 CHARIOT
100CE LINEAR B IDEOGRAM B242 CHARIOT FRAME
100CF LINEAR B IDEOGRAM B243 WHEEL
100D0 LINEAR B IDEOGRAM B245
100D1 LINEAR B IDEOGRAM B246
100D2 LINEAR B MONOGRAM B247 DIPTE
100D3 LINEAR B IDEOGRAM B248
100D4 LINEAR B IDEOGRAM B249
100D5 LINEAR B IDEOGRAM B251
100D6 LINEAR B IDEOGRAM B252
100D7 LINEAR B IDEOGRAM B253
100D8 LINEAR B IDEOGRAM B254 DART
100D9 LINEAR B IDEOGRAM B255
100DA LINEAR B IDEOGRAM B256
100DB LINEAR B IDEOGRAM B257
100DC LINEAR B IDEOGRAM B258
100DD LINEAR B IDEOGRAM B259
100DE LINEAR B IDEOGRAM VESSEL B155
100DF LINEAR B IDEOGRAM VESSEL B200
100E0 LINEAR B IDEOGRAM VESSEL B201
100E1 LINEAR B IDEOGRAM VESSEL B202
100E2 LINEAR B IDEOGRAM VESSEL B203
100E3 LINEAR B IDEOGRAM VESSEL B204
100E4 LINEAR B IDEOGRAM VESSEL B205
100E5 LINEAR B IDEOGRAM VESSEL B206
100E6 LINEAR B IDEOGRAM VESSEL B207
100E7 LINEAR B IDEOGRAM VESSEL B208
100E8 LINEAR B IDEOGRAM VESSEL B209
100E9 LINEAR B IDEOGRAM VESSEL B210
100EA LINEAR B IDEOGRAM VESSEL B211
100EB LINEAR B IDEOGRAM VESSEL B212
100EC LINEAR B IDEOGRAM VESSEL B213
100ED LINEAR B IDEOGRAM VESSEL B214
100EE LINEAR B IDEOGRAM VESSEL B215
100EF LINEAR B IDEOGRAM VESSEL B216
100F0 LINEAR B IDEOGRAM VESSEL B217
100F1 LINEAR B IDEOGRAM VESSEL B218
100F2 LINEAR B IDEOGRAM VESSEL B219
100F3 LINEAR B IDEOGRAM VESSEL B221
100F4 LINEAR B IDEOGRAM VESSEL B222
100F5 LINEAR B IDEOGRAM VESSEL B226
100F6 LINEAR B IDEOGRAM VESSEL B227
100F7 LINEAR B IDEOGRAM VESSEL B228
100F8 LINEAR B IDEOGRAM VESSEL B229
100F9 LINEAR B IDEOGRAM VESSEL B250
100FA LINEAR B IDEOGRAM VESSEL B305
10100 AEGEAN WORD SEPARATOR LINE
10101 AEGEAN WORD SEPARATOR DOT
10102 AEGEAN CHECK MARK
10107 AEGEAN NUMBER ONE
10108 AEGEAN NUMBER TWO
10109 AEGEAN NUMBER THREE
1010A AEGEAN NUMBER FOUR
1010B AEGEAN NUMBER FIVE
1010C AEGEAN NUMBER SIX
1010D AEGEAN NUMBER SEVEN
1010E AEGEAN NUMBER EIGHT
1010F AEGEAN NUMBER NINE
10110 AEGEAN NUMBER TEN
10111 AEGEAN NUMBER TWENTY
10112 AEGEAN NUMBER THIRTY
10113 AEGEAN NUMBER FORTY
10114 AEGEAN NUMBER FIFTY
10115 AEGEAN NUMBER SIXTY
10116 AEGEAN NUMBER SEVENTY
10117 AEGEAN NUMBER EIGHTY
10118 AEGEAN NUMBER NINETY
10119 AEGEAN NUMBER ONE HUNDRED
1011A AEGEAN NUMBER TWO HUNDRED
1011B AEGEAN NUMBER THREE HUNDRED
1011C AEGEAN NUMBER FOUR HUNDRED
1011D AEGEAN NUMBER FIVE HUNDRED
1011E AEGEAN NUMBER SIX HUNDRED
1011F AEGEAN NUMBER SEVEN HUNDRED
10120 AEGEAN NUMBER EIGHT HUNDRED
10121 AEGEAN NUMBER NINE HUNDRED
10122 AEGEAN NUMBER ONE THOUSAND
10123 AEGEAN NUMBER TWO THOUSAND
10124 AEGEAN NUMBER THREE THOUSAND
10125 AEGEAN NUMBER FOUR THOUSAND
10126 AEGEAN NUMBER FIVE THOUSAND
10127 AEGEAN NUMBER SIX THOUSAND
10128 AEGEAN NUMBER SEVEN THOUSAND
10129 AEGEAN NUMBER EIGHT THOUSAND
1012A AEGEAN NUMBER NINE THOUSAND
1012B AEGEAN NUMBER TEN THOUSAND
1012C AEGEAN NUMBER TWENTY THOUSAND
1012D AEGEAN NUMBER THIRTY THOUSAND
1012E AEGEAN NUMBER FORTY THOUSAND
1012F AEGEAN NUMBER FIFTY THOUSAND
10130 AEGEAN NUMBER SIXTY THOUSAND
10131 AEGEAN NUMBER SEVENTY THOUSAND
10132 AEGEAN NUMBER EIGHTY THOUSAND
10133 AEGEAN NUMBER NINETY THOUSAND
10137 AEGEAN WEIGHT BASE UNIT
10138 AEGEAN WEIGHT FIRST SUBUNIT
10139 AEGEAN WEIGHT SECOND SUBUNIT
1013A AEGEAN WEIGHT THIRD SUBUNIT
1013B AEGEAN WEIGHT FOURTH SUBUNIT
1013C AEGEAN DRY MEASURE FIRST SUBUNIT
1013D AEGEAN LIQUID MEASURE FIRST SUBUNIT
1013E AEGEAN MEASURE SECOND SUBUNIT
1013F AEGEAN MEASURE THIRD SUBUNIT
10140 GREEK ACROPHONIC ATTIC ONE QUARTER
10141 GREEK ACROPHONIC ATTIC ONE HALF
10142 GREEK ACROPHONIC ATTIC ONE DRACHMA
10143 GREEK ACROPHONIC ATTIC FIVE
10144 GREEK ACROPHONIC ATTIC FIFTY
10145 GREEK ACROPHONIC ATTIC FIVE HUNDRED
10146 GREEK ACROPHONIC ATTIC FIVE THOUSAND
10147 GREEK ACROPHONIC ATTIC FIFTY THOUSAND
10148 GREEK ACROPHONIC ATTIC FIVE TALENTS
10149 GREEK ACROPHONIC ATTIC TEN TALENTS
1014A GREEK ACROPHONIC ATTIC FIFTY TALENTS
1014B GREEK ACROPHONIC ATTIC ONE HUNDRED TALENTS
1014C GREEK ACROPHONIC ATTIC FIVE HUNDRED TALENTS
1014D GREEK ACROPHONIC ATTIC ONE THOUSAND TALENTS
1014E GREEK ACROPHONIC ATTIC FIVE THOUSAND TALENTS
1014F GREEK ACROPHONIC ATTIC FIVE STATERS
10150 GREEK ACROPHONIC ATTIC TEN STATERS
10151 GREEK ACROPHONIC ATTIC FIFTY STATERS
10152 GREEK ACROPHONIC ATTIC ONE HUNDRED STATERS
10153 GREEK ACROPHONIC ATTIC FIVE HUNDRED STATERS
10154 GREEK ACROPHONIC ATTIC ONE THOUSAND STATERS
10155 GREEK ACROPHONIC ATTIC TEN THOUSAND STATERS
10156 GREEK ACROPHONIC ATTIC FIFTY THOUSAND STATERS
10157 GREEK ACROPHONIC ATTIC TEN MNAS
10158 GREEK ACROPHONIC HERAEUM ONE PLETHRON
10159 GREEK ACROPHONIC THESPIAN ONE
1015A GREEK ACROPHONIC HERMIONIAN ONE
1015B GREEK ACROPHONIC EPIDAUREAN TWO
1015C GREEK ACROPHONIC THESPIAN TWO
1015D GREEK ACROPHONIC CYRENAIC TWO DRACHMAS
1015E GREEK ACROPHONIC EPIDAUREAN TWO DRACHMAS
1015F GREEK ACROPHONIC TROEZENIAN FIVE
10160 GREEK ACROPHONIC TROEZENIAN TEN
10161 GREEK ACROPHONIC TROEZENIAN TEN ALTERNATE FORM
10162 GREEK ACROPHONIC HERMIONIAN TEN
10163 GREEK ACROPHONIC MESSENIAN TEN
10164 GREEK ACROPHONIC THESPIAN TEN
10165 GREEK ACROPHONIC THESPIAN THIRTY
10166 GREEK ACROPHONIC TROEZENIAN FIFTY
10167 GREEK ACROPHONIC TROEZENIAN FIFTY ALTERNATE FORM
10168 GREEK ACROPHONIC HERMIONIAN FIFTY
10169 GREEK ACROPHONIC THESPIAN FIFTY
1016A GREEK ACROPHONIC THESPIAN ONE HUNDRED
1016B GREEK ACROPHONIC THESPIAN THREE HUNDRED
1016C GREEK ACROPHONIC EPIDAUREAN FIVE HUNDRED
1016D GREEK ACROPHONIC TROEZENIAN FIVE HUNDRED
1016E GREEK ACROPHONIC THESPIAN FIVE HUNDRED
1016F GREEK ACROPHONIC CARYSTIAN FIVE HUNDRED
10170 GREEK ACROPHONIC NAXIAN FIVE HUNDRED
10171 GREEK ACROPHONIC THESPIAN ONE THOUSAND
10172 GREEK ACROPHONIC THESPIAN FIVE THOUSAND
10173 GREEK ACROPHONIC DELPHIC FIVE MNAS
10174 GREEK ACROPHONIC STRATIAN FIFTY MNAS
10175 GREEK ONE HALF SIGN
10176 GREEK ONE HALF SIGN ALTERNATE FORM
10177 GREEK TWO THIRDS SIGN
10178 GREEK THREE QUARTERS SIGN
10179 GREEK YEAR SIGN
1017A GREEK TALENT SIGN
1017B GREEK DRACHMA SIGN
1017C GREEK OBOL SIGN
1017D GREEK TWO OBOLS SIGN
1017E GREEK THREE OBOLS SIGN
1017F GREEK FOUR OBOLS SIGN
10180 GREEK FIVE OBOLS SIGN
10181 GREEK METRETES SIGN
10182 GREEK KYATHOS BASE SIGN
10183 GREEK LITRA SIGN
10184 GREEK OUNKIA SIGN
10185 GREEK XESTES SIGN
10186 GREEK ARTABE SIGN
10187 GREEK AROURA SIGN
10188 GREEK GRAMMA SIGN
10189 GREEK TRYBLION BASE SIGN
1018A GREEK ZERO SIGN
1018B GREEK ONE QUARTER SIGN
1018C GREEK SINUSOID SIGN
1018D GREEK INDICTION SIGN
1018E NOMISMA SIGN
10190 ROMAN SEXTANS SIGN
10191 ROMAN UNCIA SIGN
10192 ROMAN SEMUNCIA SIGN
10193 ROMAN SEXTULA SIGN
10194 ROMAN DIMIDIA SEXTULA SIGN
10195 ROMAN SILIQUA SIGN
10196 ROMAN DENARIUS SIGN
10197 ROMAN QUINARIUS SIGN
10198 ROMAN SESTERTIUS SIGN
10199 ROMAN DUPONDIUS SIGN
1019A ROMAN AS SIGN
1019B ROMAN CENTURIAL SIGN
101A0 GREEK SYMBOL TAU RHO
101D0 PHAISTOS DISC SIGN PEDESTRIAN
101D1 PHAISTOS DISC SIGN PLUMED HEAD
101D2 PHAISTOS DISC SIGN TATTOOED HEAD
101D3 PHAISTOS DISC SIGN CAPTIVE
101D4 PHAISTOS DISC SIGN CHILD
101D5 PHAISTOS DISC SIGN WOMAN
101D6 PHAISTOS DISC SIGN HELMET
101D7 PHAISTOS DISC SIGN GAUNTLET
101D8 PHAISTOS DISC SIGN TIARA
101D9 PHAISTOS DISC SIGN ARROW
101DA PHAISTOS DISC SIGN BOW
101DB PHAISTOS DISC SIGN SHIELD
101DC PHAISTOS DISC SIGN CLUB
101DD PHAISTOS DISC SIGN MANACLES
101DE PHAISTOS DISC SIGN MATTOCK
101DF PHAISTOS DISC SIGN SAW
101E0 PHAISTOS DISC SIGN LID
101E1 PHAISTOS DISC SIGN BOOMERANG
101E2 PHAISTOS DISC SIGN CARPENTRY PLANE
101E3 PHAISTOS DISC SIGN DOLIUM
101E4 PHAISTOS DISC SIGN COMB
101E5 PHAISTOS DISC SIGN SLING
101E6 PHAISTOS DISC SIGN COLUMN
101E7 PHAISTOS DISC SIGN BEEHIVE
101E8 PHAISTOS DISC SIGN SHIP
101E9 PHAISTOS DISC SIGN HORN
101EA PHAISTOS DISC SIGN HIDE
101EB PHAISTOS DISC SIGN BULLS LEG
101EC PHAISTOS DISC SIGN CAT
101ED PHAISTOS DISC SIGN RAM
101EE PHAISTOS DISC SIGN EAGLE
101EF PHAISTOS DISC SIGN DOVE
101F0 PHAISTOS DISC SIGN TUNNY
101F1 PHAISTOS DISC SIGN BEE
101F2 PHAISTOS DISC SIGN PLANE TREE
101F3 PHAISTOS DISC SIGN VINE
101F4 PHAISTOS DISC SIGN PAPYRUS
101F5 PHAISTOS DISC SIGN ROSETTE
101F6 PHAISTOS DISC SIGN LILY
101F7 PHAISTOS DISC SIGN OX BACK
101F8 PHAISTOS DISC SIGN FLUTE
101F9 PHAISTOS DISC SIGN GRATER
101FA PHAISTOS DISC SIGN STRAINER
101FB PHAISTOS DISC SIGN SMALL AXE
101FC PHAISTOS DISC SIGN WAVY BAND
101FD PHAISTOS DISC SIGN COMBINING OBLIQUE STROKE
10280 LYCIAN LETTER A
10281 LYCIAN LETTER E
10282 LYCIAN LETTER B
10283 LYCIAN LETTER BH
10284 LYCIAN LETTER G
10285 LYCIAN LETTER D
10286 LYCIAN LETTER I
10287 LYCIAN LETTER W
10288 LYCIAN LETTER Z
10289 LYCIAN LETTER TH
1028A LYCIAN LETTER J
1028B LYCIAN LETTER K
1028C LYCIAN LETTER Q
1028D LYCIAN LETTER L
1028E LYCIAN LETTER M
1028F LYCIAN LETTER N
10290 LYCIAN LETTER MM
10291 LYCIAN LETTER NN
10292 LYCIAN LETTER U
10293 LYCIAN LETTER P
10294 LYCIAN LETTER KK
10295 LYCIAN LETTER R
10296 LYCIAN LETTER S
10297 LYCIAN LETTER T
10298 LYCIAN LETTER TT
10299 LYCIAN LETTER AN
1029A LYCIAN LETTER EN
1029B LYCIAN LETTER H
1029C LYCIAN LETTER X
102A0 CARIAN LETTER A
102A1 CARIAN LETTER P2
102A2 CARIAN LETTER D
102A3 CARIAN LETTER L
102A4 CARIAN LETTER UUU
102A5 CARIAN LETTER R
102A6 CARIAN LETTER LD
102A7 CARIAN LETTER A2
102A8 CARIAN LETTER Q
102A9 CARIAN LETTER B
102AA CARIAN LETTER M
102AB CARIAN LETTER O
102AC CARIAN LETTER D2
102AD CARIAN LETTER T
102AE CARIAN LETTER SH
102AF CARIAN LETTER SH2
102B0 CARIAN LETTER S
102B1 CARIAN LETTER C-18
102B2 CARIAN LETTER U
102B3 CARIAN LETTER NN
102B4 CARIAN LETTER X
102B5 CARIAN LETTER N
102B6 CARIAN LETTER TT2
102B7 CARIAN LETTER P
102B8 CARIAN LETTER SS
102B9 CARIAN LETTER I
102BA CARIAN LETTER E
102BB CARIAN LETTER UUUU
102BC CARIAN LETTER K
102BD CARIAN LETTER K2
102BE CARIAN LETTER ND
102BF CARIAN LETTER UU
102C0 CARIAN LETTER G
102C1 CARIAN LETTER G2
102C2 CARIAN LETTER ST
102C3 CARIAN LETTER ST2
102C4 CARIAN LETTER NG
102C5 CARIAN LETTER II
102C6 CARIAN LETTER C-39
102C7 CARIAN LETTER TT
102C8 CARIAN LETTER UUU2
102C9 CARIAN LETTER RR
102CA CARIAN LETTER MB
102CB CARIAN LETTER MB2
102CC CARIAN LETTER MB3
102CD CARIAN LETTER MB4
102CE CARIAN LETTER LD2
102CF CARIAN LETTER E2
102D0 CARIAN LETTER UUU3
102E0 COPTIC EPACT THOUSANDS MARK
102E1 COPTIC EPACT DIGIT ONE
102E2 COPTIC EPACT DIGIT TWO
102E3 COPTIC EPACT DIGIT THREE
102E4 COPTIC EPACT DIGIT FOUR
102E5 COPTIC EPACT DIGIT FIVE
102E6 COPTIC EPACT DIGIT SIX
102E7 COPTIC EPACT DIGIT SEVEN
102E8 COPTIC EPACT DIGIT EIGHT
102E9 COPTIC EPACT DIGIT NINE
102EA COPTIC EPACT NUMBER TEN
102EB COPTIC EPACT NUMBER TWENTY
102EC COPTIC EPACT NUMBER THIRTY
102ED COPTIC EPACT NUMBER FORTY
102EE COPTIC EPACT NUMBER FIFTY
102EF COPTIC EPACT NUMBER SIXTY
102F0 COPTIC EPACT NUMBER SEVENTY
102F1 COPTIC EPACT NUMBER EIGHTY
102F2 COPTIC EPACT NUMBER NINETY
102F3 COPTIC EPACT NUMBER ONE HUNDRED
102F4 COPTIC EPACT NUMBER TWO HUNDRED
102F5 COPTIC EPACT NUMBER THREE HUNDRED
102F6 COPTIC EPACT NUMBER FOUR HUNDRED
102F7 COPTIC EPACT NUMBER FIVE HUNDRED
102F8 COPTIC EPACT NUMBER SIX HUNDRED
102F9 COPTIC EPACT NUMBER SEVEN HUNDRED
102FA COPTIC EPACT NUMBER EIGHT HUNDRED
102FB COPTIC EPACT NUMBER NINE HUNDRED
10300 OLD ITALIC LETTER A
10301 OLD ITALIC LETTER BE
10302 OLD ITALIC LETTER KE
10303 OLD ITALIC LETTER DE
10304 OLD ITALIC LETTER E
10305 OLD ITALIC LETTER VE
10306 OLD ITALIC LETTER ZE
10307 OLD ITALIC LETTER HE
10308 OLD ITALIC LETTER THE
10309 OLD ITALIC LETTER I
1030A OLD ITALIC LETTER KA
1030B OLD ITALIC LETTER EL
1030C OLD ITALIC LETTER EM
1030D OLD ITALIC LETTER EN
1030E OLD ITALIC LETTER ESH
1030F OLD ITALIC LETTER O
10310 OLD ITALIC LETTER PE
10311 OLD ITALIC LETTER SHE
10312 OLD ITALIC LETTER KU
10313 OLD ITALIC LETTER ER
10314 OLD ITALIC LETTER ES
10315 OLD ITALIC LETTER TE
10316 OLD ITALIC LETTER U
10317 OLD ITALIC LETTER EKS
10318 OLD ITALIC LETTER PHE
10319 OLD ITALIC LETTER KHE
1031A OLD ITALIC LETTER EF
1031B OLD ITALIC LETTER ERS
1031C OLD ITALIC LETTER CHE
1031D OLD ITALIC LETTER II
1031E OLD ITALIC LETTER UU
1031F OLD ITALIC LETTER ESS
10320 OLD ITALIC NUMERAL ONE
10321 OLD ITALIC NUMERAL FIVE
10322 OLD ITALIC NUMERAL TEN
10323 OLD ITALIC NUMERAL FIFTY
1032D OLD ITALIC LETTER YE
1032E OLD ITALIC LETTER NORTHERN TSE
1032F OLD ITALIC LETTER SOUTHERN TSE
10330 GOTHIC LETTER AHSA
10331 GOTHIC LETTER BAIRKAN
10332 GOTHIC LETTER GIBA
10333 GOTHIC LETTER DAGS
10334 GOTHIC LETTER AIHVUS
10335 GOTHIC LETTER QAIRTHRA
10336 GOTHIC LETTER IUJA
10337 GOTHIC LETTER HAGL
10338 GOTHIC LETTER THIUTH
10339 GOTHIC LETTER EIS
1033A GOTHIC LETTER KUSMA
1033B GOTHIC LETTER LAGUS
1033C GOTHIC LETTER MANNA
1033D GOTHIC LETTER NAUTHS
1033E GOTHIC LETTER JER
1033F GOTHIC LETTER URUS
10340 GOTHIC LETTER PAIRTHRA
10341 GOTHIC LETTER NINETY
10342 GOTHIC LETTER RAIDA
10343 GOTHIC LETTER SAUIL
10344 GOTHIC LETTER TEIWS
10345 GOTHIC LETTER WINJA
10346 GOTHIC LETTER FAIHU
10347 GOTHIC LETTER IGGWS
10348 GOTHIC LETTER HWAIR
10349 GOTHIC LETTER OTHAL
1034A GOTHIC LETTER NINE HUNDRED
10350 OLD PERMIC LETTER AN
10351 OLD PERMIC LETTER BUR
10352 OLD PERMIC LETTER GAI
10353 OLD PERMIC LETTER DOI
10354 OLD PERMIC LETTER E
10355 OLD PERMIC LETTER ZHOI
10356 OLD PERMIC LETTER DZHOI
10357 OLD PERMIC LETTER ZATA
10358 OLD PERMIC LETTER DZITA
10359 OLD PERMIC LETTER I
1035A OLD PERMIC LETTER KOKE
1035B OLD PERMIC LETTER LEI
1035C OLD PERMIC LETTER MENOE
1035D OLD PERMIC LETTER NENOE
1035E OLD PERMIC LETTER VOOI
1035F OLD PERMIC LETTER PEEI
10360 OLD PERMIC LETTER REI
10361 OLD PERMIC LETTER SII
10362 OLD PERMIC LETTER TAI
10363 OLD PERMIC LETTER U
10364 OLD PERMIC LETTER CHERY
10365 OLD PERMIC LETTER SHOOI
10366 OLD PERMIC LETTER SHCHOOI
10367 OLD PERMIC LETTER YRY
10368 OLD PERMIC LETTER YERU
10369 OLD PERMIC LETTER O
1036A OLD PERMIC LETTER OO
1036B OLD PERMIC LETTER EF
1036C OLD PERMIC LETTER HA
1036D OLD PERMIC LETTER TSIU
1036E OLD PERMIC LETTER VER
1036F OLD PERMIC LETTER YER
10370 OLD PERMIC LETTER YERI
10371 OLD PERMIC LETTER YAT
10372 OLD PERMIC LETTER IE
10373 OLD PERMIC LETTER YU
10374 OLD PERMIC LETTER YA
10375 OLD PERMIC LETTER IA
10376 COMBINING OLD PERMIC LETTER AN
10377 COMBINING OLD PERMIC LETTER DOI
10378 COMBINING OLD PERMIC LETTER ZATA
10379 COMBINING OLD PERMIC LETTER NENOE
1037A COMBINING OLD PERMIC LETTER SII
10380 UGARITIC LETTER ALPA
10381 UGARITIC LETTER BETA
10382 UGARITIC LETTER GAMLA
10383 UGARITIC LETTER KHA
10384 UGARITIC LETTER DELTA
10385 UGARITIC LETTER HO
10386 UGARITIC LETTER WO
10387 UGARITIC LETTER ZETA
10388 UGARITIC LETTER HOTA
10389 UGARITIC LETTER TET
1038A UGARITIC LETTER YOD
1038B UGARITIC LETTER KAF
1038C UGARITIC LETTER SHIN
1038D UGARITIC LETTER LAMDA
1038E UGARITIC LETTER MEM
1038F UGARITIC LETTER DHAL
10390 UGARITIC LETTER NUN
10391 UGARITIC LETTER ZU
10392 UGARITIC LETTER SAMKA
10393 UGARITIC LETTER AIN
10394 UGARITIC LETTER PU
10395 UGARITIC LETTER SADE
10396 UGARITIC LETTER QOPA
10397 UGARITIC LETTER RASHA
10398 UGARITIC LETTER THANNA
10399 UGARITIC LETTER GHAIN
1039A UGARITIC LETTER TO
1039B UGARITIC LETTER I
1039C UGARITIC LETTER U
1039D UGARITIC LETTER SSU
1039F UGARITIC WORD DIVIDER
103A0 OLD PERSIAN SIGN A
103A1 OLD PERSIAN SIGN I
103A2 OLD PERSIAN SIGN U
103A3 OLD PERSIAN SIGN KA
103A4 OLD PERSIAN SIGN KU
103A5 OLD PERSIAN SIGN GA
103A6 OLD PERSIAN SIGN GU
103A7 OLD PERSIAN SIGN XA
103A8 OLD PERSIAN SIGN CA
103A9 OLD PERSIAN SIGN JA
103AA OLD PERSIAN SIGN JI
103AB OLD PERSIAN SIGN TA
103AC OLD PERSIAN SIGN TU
103AD OLD PERSIAN SIGN DA
103AE OLD PERSIAN SIGN DI
103AF OLD PERSIAN SIGN DU
103B0 OLD PERSIAN SIGN THA
103B1 OLD PERSIAN SIGN PA
103B2 OLD PERSIAN SIGN BA
103B3 OLD PERSIAN SIGN FA
103B4 OLD PERSIAN SIGN NA
103B5 OLD PERSIAN SIGN NU
103B6 OLD PERSIAN SIGN MA
103B7 OLD PERSIAN SIGN MI
103B8 OLD PERSIAN SIGN MU
103B9 OLD PERSIAN SIGN YA
103BA OLD PERSIAN SIGN VA
103BB OLD PERSIAN SIGN VI
103BC OLD PERSIAN SIGN RA
103BD OLD PERSIAN SIGN RU
103BE OLD PERSIAN SIGN LA
103BF OLD PERSIAN SIGN SA
103C0 OLD PERSIAN SIGN ZA
103C1 OLD PERSIAN SIGN SHA
103C2 OLD PERSIAN SIGN SSA
103C3 OLD PERSIAN SIGN HA
103C8 OLD PERSIAN SIGN AURAMAZDAA
103C9 OLD PERSIAN SIGN AURAMAZDAA-2
103CA OLD PERSIAN SIGN AURAMAZDAAHA
103CB OLD PERSIAN SIGN XSHAAYATHIYA
103CC OLD PERSIAN SIGN DAHYAAUSH
103CD OLD PERSIAN SIGN DAHYAAUSH-2
103CE OLD PERSIAN SIGN BAGA
103CF OLD PERSIAN SIGN BUUMISH
103D0 OLD PERSIAN WORD DIVIDER
103D1 OLD PERSIAN NUMBER ONE
103D2 OLD PERSIAN NUMBER TWO
103D3 OLD PERSIAN NUMBER TEN
103D4 OLD PERSIAN NUMBER TWENTY
103D5 OLD PERSIAN NUMBER HUNDRED
10400 DESERET CAPITAL LETTER LONG I
10401 DESERET CAPITAL LETTER LONG E
10402 DESERET CAPITAL LETTER LONG A
10403 DESERET CAPITAL LETTER LONG AH
10404 DESERET CAPITAL LETTER LONG O
10405 DESERET CAPITAL LETTER LONG OO
10406 DESERET CAPITAL LETTER SHORT I
10407 DESERET CAPITAL LETTER SHORT E
10408 DESERET CAPITAL LETTER SHORT A
10409 DESERET CAPITAL LETTER SHORT AH
1040A DESERET CAPITAL LETTER SHORT O
1040B DESERET CAPITAL LETTER SHORT OO
1040C DESERET CAPITAL LETTER AY
1040D DESERET CAPITAL LETTER OW
1040E DESERET CAPITAL LETTER WU
1040F DESERET CAPITAL LETTER YEE
10410 DESERET CAPITAL LETTER H
10411 DESERET CAPITAL LETTER PEE
10412 DESERET CAPITAL LETTER BEE
10413 DESERET CAPITAL LETTER TEE
10414 DESERET CAPITAL LETTER DEE
10415 DESERET CAPITAL LETTER CHEE
10416 DESERET CAPITAL LETTER JEE
10417 DESERET CAPITAL LETTER KAY
10418 DESERET CAPITAL LETTER GAY
10419 DESERET CAPITAL LETTER EF
1041A DESERET CAPITAL LETTER VEE
1041B DESERET CAPITAL LETTER ETH
1041C DESERET CAPITAL LETTER THEE
1041D DESERET CAPITAL LETTER ES
1041E DESERET CAPITAL LETTER ZEE
1041F DESERET CAPITAL LETTER ESH
10420 DESERET CAPITAL LETTER ZHEE
10421 DESERET CAPITAL LETTER ER
10422 DESERET CAPITAL LETTER EL
10423 DESERET CAPITAL LETTER EM
10424 DESERET CAPITAL LETTER EN
10425 DESERET CAPITAL LETTER ENG
10426 DESERET CAPITAL LETTER OI
10427 DESERET CAPITAL LETTER EW
10428 DESERET SMALL LETTER LONG I
10429 DESERET SMALL LETTER LONG E
1042A DESERET SMALL LETTER LONG A
1042B DESERET SMALL LETTER LONG AH
1042C DESERET SMALL LETTER LONG O
1042D DESERET SMALL LETTER LONG OO
1042E DESERET SMALL LETTER SHORT I
1042F DESERET SMALL LETTER SHORT E
10430 DESERET SMALL LETTER SHORT A
10431 DESERET SMALL LETTER SHORT AH
10432 DESERET SMALL LETTER SHORT O
10433 DESERET SMALL LETTER SHORT OO
10434 DESERET SMALL LETTER AY
10435 DESERET SMALL LETTER OW
10436 DESERET SMALL LETTER WU
10437 DESERET SMALL LETTER YEE
10438 DESERET SMALL LETTER H
10439 DESERET SMALL LETTER PEE
1043A DESERET SMALL LETTER BEE
1043B DESERET SMALL LETTER TEE
1043C DESERET SMALL LETTER DEE
1043D DESERET SMALL LETTER CHEE
1043E DESERET SMALL LETTER JEE
1043F DESERET SMALL LETTER KAY
10440 DESERET SMALL LETTER GAY
10441 DESERET SMALL LETTER EF
10442 DESERET SMALL LETTER VEE
10443 DESERET SMALL LETTER ETH
10444 DESERET SMALL LETTER THEE
10445 DESERET SMALL LETTER ES
10446 DESERET SMALL LETTER ZEE
10447 DESERET SMALL LETTER ESH
10448 DESERET SMALL LETTER ZHEE
10449 DESERET SMALL LETTER ER
1044A DESERET SMALL LETTER EL
1044B DESERET SMALL LETTER EM
1044C DESERET SMALL LETTER EN
1044D DESERET SMALL LETTER ENG
1044E DESERET SMALL LETTER OI
1044F DESERET SMALL LETTER EW
10450 SHAVIAN LETTER PEEP
10451 SHAVIAN LETTER TOT
10452 SHAVIAN LETTER KICK
10453 SHAVIAN LETTER FEE
10454 SHAVIAN LETTER THIGH
10455 SHAVIAN LETTER SO
10456 SHAVIAN LETTER SURE
10457 SHAVIAN LETTER CHURCH
10458 SHAVIAN LETTER YEA
10459 SHAVIAN LETTER HUNG
1045A SHAVIAN LETTER BIB
1045B SHAVIAN LETTER DEAD
1045C SHAVIAN LETTER GAG
1045D SHAVIAN LETTER VOW
1045E SHAVIAN LETTER THEY
1045F SHAVIAN LETTER ZOO
10460 SHAVIAN LETTER MEASURE
10461 SHAVIAN LETTER JUDGE
10462 SHAVIAN LETTER WOE
10463 SHAVIAN LETTER HA-HA
10464 SHAVIAN LETTER LOLL
10465 SHAVIAN LETTER MIME
10466 SHAVIAN LETTER IF
10467 SHAVIAN LETTER EGG
10468 SHAVIAN LETTER ASH
10469 SHAVIAN LETTER ADO
1046A SHAVIAN LETTER ON
1046B SHAVIAN LETTER WOOL
1046C SHAVIAN LETTER OUT
1046D SHAVIAN LETTER AH
1046E SHAVIAN LETTER ROAR
1046F SHAVIAN LETTER NUN
10470 SHAVIAN LETTER EAT
10471 SHAVIAN LETTER AGE
10472 SHAVIAN LETTER ICE
10473 SHAVIAN LETTER UP
10474 SHAVIAN LETTER OAK
10475 SHAVIAN LETTER OOZE
10476 SHAVIAN LETTER OIL
10477 SHAVIAN LETTER AWE
10478 SHAVIAN LETTER ARE
10479 SHAVIAN LETTER OR
1047A SHAVIAN LETTER AIR
1047B SHAVIAN LETTER ERR
1047C SHAVIAN LETTER ARRAY
1047D SHAVIAN LETTER EAR
1047E SHAVIAN LETTER IAN
1047F SHAVIAN LETTER YEW
10480 OSMANYA LETTER ALEF
10481 OSMANYA LETTER BA
10482 OSMANYA LETTER TA
10483 OSMANYA LETTER JA
10484 OSMANYA LETTER XA
10485 OSMANYA LETTER KHA
10486 OSMANYA LETTER DEEL
10487 OSMANYA LETTER RA
10488 OSMANYA LETTER SA
10489 OSMANYA LETTER SHIIN
1048A OSMANYA LETTER DHA
1048B OSMANYA LETTER CAYN
1048C OSMANYA LETTER GA
1048D OSMANYA LETTER FA
1048E OSMANYA LETTER QAAF
1048F OSMANYA LETTER KAAF
10490 OSMANYA LETTER LAAN
10491 OSMANYA LETTER MIIN
10492 OSMANYA LETTER NUUN
10493 OSMANYA LETTER WAW
10494 OSMANYA LETTER HA
10495 OSMANYA LETTER YA
10496 OSMANYA LETTER A
10497 OSMANYA LETTER E
10498 OSMANYA LETTER I
10499 OSMANYA LETTER O
1049A OSMANYA LETTER U
1049B OSMANYA LETTER AA
1049C OSMANYA LETTER EE
1049D OSMANYA LETTER OO
104A0 OSMANYA DIGIT ZERO
104A1 OSMANYA DIGIT ONE
104A2 OSMANYA DIGIT TWO
104A3 OSMANYA DIGIT THREE
104A4 OSMANYA DIGIT FOUR
104A5 OSMANYA DIGIT FIVE
104A6 OSMANYA DIGIT SIX
104A7 OSMANYA DIGIT SEVEN
104A8 OSMANYA DIGIT EIGHT
104A9 OSMANYA DIGIT NINE
104B0 OSAGE CAPITAL LETTER A
104B1 OSAGE CAPITAL LETTER AI
104B2 OSAGE CAPITAL LETTER AIN
104B3 OSAGE CAPITAL LETTER AH
104B4 OSAGE CAPITAL LETTER BRA
104B5 OSAGE CAPITAL LETTER CHA
104B6 OSAGE CAPITAL LETTER EHCHA
104B7 OSAGE CAPITAL LETTER E
104B8 OSAGE CAPITAL LETTER EIN
104B9 OSAGE CAPITAL LETTER HA
104BA OSAGE CAPITAL LETTER HYA
104BB OSAGE CAPITAL LETTER I
104BC OSAGE CAPITAL LETTER KA
104BD OSAGE CAPITAL LETTER EHKA
104BE OSAGE CAPITAL LETTER KYA
104BF OSAGE CAPITAL LETTER LA
104C0 OSAGE CAPITAL LETTER MA
104C1 OSAGE CAPITAL LETTER NA
104C2 OSAGE CAPITAL LETTER O
104C3 OSAGE CAPITAL LETTER OIN
104C4 OSAGE CAPITAL LETTER PA
104C5 OSAGE CAPITAL LETTER EHPA
104C6 OSAGE CAPITAL LETTER SA
104C7 OSAGE CAPITAL LETTER SHA
104C8 OSAGE CAPITAL LETTER TA
104C9 OSAGE CAPITAL LETTER EHTA
104CA OSAGE CAPITAL LETTER TSA
104CB OSAGE CAPITAL LETTER EHTSA
104CC OSAGE CAPITAL LETTER TSHA
104CD OSAGE CAPITAL LETTER DHA
104CE OSAGE CAPITAL LETTER U
104CF OSAGE CAPITAL LETTER WA
104D0 OSAGE CAPITAL LETTER KHA
104D1 OSAGE CAPITAL LETTER GHA
104D2 OSAGE CAPITAL LETTER ZA
104D3 OSAGE CAPITAL LETTER ZHA
104D8 OSAGE SMALL LETTER A
104D9 OSAGE SMALL LETTER AI
104DA OSAGE SMALL LETTER AIN
104DB OSAGE SMALL LETTER AH
104DC OSAGE SMALL LETTER BRA
104DD OSAGE SMALL LETTER CHA
104DE OSAGE SMALL LETTER EHCHA
104DF OSAGE SMALL LETTER E
104E0 OSAGE SMALL LETTER EIN
104E1 OSAGE SMALL LETTER HA
104E2 OSAGE SMALL LETTER HYA
104E3 OSAGE SMALL LETTER I
104E4 OSAGE SMALL LETTER KA
104E5 OSAGE SMALL LETTER EHKA
104E6 OSAGE SMALL LETTER KYA
104E7 OSAGE SMALL LETTER LA
104E8 OSAGE SMALL LETTER MA
104E9 OSAGE SMALL LETTER NA
104EA OSAGE SMALL LETTER O
104EB OSAGE SMALL LETTER OIN
104EC OSAGE SMALL LETTER PA
104ED OSAGE SMALL LETTER EHPA
104EE OSAGE SMALL LETTER SA
104EF OSAGE SMALL LETTER SHA
104F0 OSAGE SMALL LETTER TA
104F1 OSAGE SMALL LETTER EHTA
104F2 OSAGE SMALL LETTER TSA
104F3 OSAGE SMALL LETTER EHTSA
104F4 OSAGE SMALL LETTER TSHA
104F5 OSAGE SMALL LETTER DHA
104F6 OSAGE SMALL LETTER U
104F7 OSAGE SMALL LETTER WA
104F8 OSAGE SMALL LETTER KHA
104F9 OSAGE SMALL LETTER GHA
104FA OSAGE SMALL LETTER ZA
104FB OSAGE SMALL LETTER ZHA
10500 ELBASAN LETTER A
10501 ELBASAN LETTER BE
10502 ELBASAN LETTER CE
10503 ELBASAN LETTER CHE
10504 ELBASAN LETTER DE
10505 ELBASAN LETTER NDE
10506 ELBASAN LETTER DHE
10507 ELBASAN LETTER EI
10508 ELBASAN LETTER E
10509 ELBASAN LETTER FE
1050A ELBASAN LETTER GE
1050B ELBASAN LETTER GJE
1050C ELBASAN LETTER HE
1050D ELBASAN LETTER I
1050E ELBASAN LETTER JE
1050F ELBASAN LETTER KE
10510 ELBASAN LETTER LE
10511 ELBASAN LETTER LLE
10512 ELBASAN LETTER ME
10513 ELBASAN LETTER NE
10514 ELBASAN LETTER NA
10515 ELBASAN LETTER NJE
10516 ELBASAN LETTER O
10517 ELBASAN LETTER PE
10518 ELBASAN LETTER QE
10519 ELBASAN LETTER RE
1051A ELBASAN LETTER RRE
1051B ELBASAN LETTER SE
1051C ELBASAN LETTER SHE
1051D ELBASAN LETTER TE
1051E ELBASAN LETTER THE
1051F ELBASAN LETTER U
10520 ELBASAN LETTER VE
10521 ELBASAN LETTER XE
10522 ELBASAN LETTER Y
10523 ELBASAN LETTER ZE
10524 ELBASAN LETTER ZHE
10525 ELBASAN LETTER GHE
10526 ELBASAN LETTER GHAMMA
10527 ELBASAN LETTER KHE
10530 CAUCASIAN ALBANIAN LETTER ALT
10531 CAUCASIAN ALBANIAN LETTER BET
10532 CAUCASIAN ALBANIAN LETTER GIM
10533 CAUCASIAN ALBANIAN LETTER DAT
10534 CAUCASIAN ALBANIAN LETTER EB
10535 CAUCASIAN ALBANIAN LETTER ZARL
10536 CAUCASIAN ALBANIAN LETTER EYN
10537 CAUCASIAN ALBANIAN LETTER ZHIL
10538 CAUCASIAN ALBANIAN LETTER TAS
10539 CAUCASIAN ALBANIAN LETTER CHA
1053A CAUCASIAN ALBANIAN LETTER YOWD
1053B CAUCASIAN ALBANIAN LETTER ZHA
1053C CAUCASIAN ALBANIAN LETTER IRB
1053D CAUCASIAN ALBANIAN LETTER SHA
1053E CAUCASIAN ALBANIAN LETTER LAN
1053F CAUCASIAN ALBANIAN LETTER INYA
10540 CAUCASIAN ALBANIAN LETTER XEYN
10541 CAUCASIAN ALBANIAN LETTER DYAN
10542 CAUCASIAN ALBANIAN LETTER CAR
10543 CAUCASIAN ALBANIAN LETTER JHOX
10544 CAUCASIAN ALBANIAN LETTER KAR
10545 CAUCASIAN ALBANIAN LETTER LYIT
10546 CAUCASIAN ALBANIAN LETTER HEYT
10547 CAUCASIAN ALBANIAN LETTER QAY
10548 CAUCASIAN ALBANIAN LETTER AOR
10549 CAUCASIAN ALBANIAN LETTER CHOY
1054A CAUCASIAN ALBANIAN LETTER CHI
1054B CAUCASIAN ALBANIAN LETTER CYAY
1054C CAUCASIAN ALBANIAN LETTER MAQ
1054D CAUCASIAN ALBANIAN LETTER QAR
1054E CAUCASIAN ALBANIAN LETTER NOWC
1054F CAUCASIAN ALBANIAN LETTER DZYAY
10550 CAUCASIAN ALBANIAN LETTER SHAK
10551 CAUCASIAN ALBANIAN LETTER JAYN
10552 CAUCASIAN ALBANIAN LETTER ON
10553 CAUCASIAN ALBANIAN LETTER TYAY
10554 CAUCASIAN ALBANIAN LETTER FAM
10555 CAUCASIAN ALBANIAN LETTER DZAY
10556 CAUCASIAN ALBANIAN LETTER CHAT
10557 CAUCASIAN ALBANIAN LETTER PEN
10558 CAUCASIAN ALBANIAN LETTER GHEYS
10559 CAUCASIAN ALBANIAN LETTER RAT
1055A CAUCASIAN ALBANIAN LETTER SEYK
1055B CAUCASIAN ALBANIAN LETTER VEYZ
1055C CAUCASIAN ALBANIAN LETTER TIWR
1055D CAUCASIAN ALBANIAN LETTER SHOY
1055E CAUCASIAN ALBANIAN LETTER IWN
1055F CAUCASIAN ALBANIAN LETTER CYAW
10560 CAUCASIAN ALBANIAN LETTER CAYN
10561 CAUCASIAN ALBANIAN LETTER YAYD
10562 CAUCASIAN ALBANIAN LETTER PIWR
10563 CAUCASIAN ALBANIAN LETTER KIW
1056F CAUCASIAN ALBANIAN CITATION MARK
10600 LINEAR A SIGN AB001
10601 LINEAR A SIGN AB002
10602 LINEAR A SIGN AB003
10603 LINEAR A SIGN AB004
10604 LINEAR A SIGN AB005
10605 LINEAR A SIGN AB006
10606 LINEAR A SIGN AB007
10607 LINEAR A SIGN AB008
10608 LINEAR A SIGN AB009
10609 LINEAR A SIGN AB010
1060A LINEAR A SIGN AB011
1060B LINEAR A SIGN AB013
1060C LINEAR A SIGN AB016
1060D LINEAR A SIGN AB017
1060E LINEAR A SIGN AB020
1060F LINEAR A SIGN AB021
10610 LINEAR A SIGN AB021F
10611 LINEAR A SIGN AB021M
10612 LINEAR A SIGN AB022
10613 LINEAR A SIGN AB022F
10614 LINEAR A SIGN AB022M
10615 LINEAR A SIGN AB023
10616 LINEAR A SIGN AB023M
10617 LINEAR A SIGN AB024
10618 LINEAR A SIGN AB026
10619 LINEAR A SIGN AB027
1061A LINEAR A SIGN AB028
1061B LINEAR A SIGN A028B
1061C LINEAR A SIGN AB029
1061D LINEAR A SIGN AB030
1061E LINEAR A SIGN AB031
1061F LINEAR A SIGN AB034
10620 LINEAR A SIGN AB037
10621 LINEAR A SIGN AB038
10622 LINEAR A SIGN AB039
10623 LINEAR A SIGN AB040
10624 LINEAR A SIGN AB041
10625 LINEAR A SIGN AB044
10626 LINEAR A SIGN AB045
10627 LINEAR A SIGN AB046
10628 LINEAR A SIGN AB047
10629 LINEAR A SIGN AB048
1062A LINEAR A SIGN AB049
1062B LINEAR A SIGN AB050
1062C LINEAR A SIGN AB051
1062D LINEAR A SIGN AB053
1062E LINEAR A SIGN AB054
1062F LINEAR A SIGN AB055
10630 LINEAR A SIGN AB056
10631 LINEAR A SIGN AB057
10632 LINEAR A SIGN AB058
10633 LINEAR A SIGN AB059
10634 LINEAR A SIGN AB060
10635 LINEAR A SIGN AB061
10636 LINEAR A SIGN AB065
10637 LINEAR A SIGN AB066
10638 LINEAR A SIGN AB067
10639 LINEAR A SIGN AB069
1063A LINEAR A SIGN AB070
1063B LINEAR A SIGN AB073
1063C LINEAR A SIGN AB074
1063D LINEAR A SIGN AB076
1063E LINEAR A SIGN AB077
1063F LINEAR A SIGN AB078
10640 LINEAR A SIGN AB079
10641 LINEAR A SIGN AB080
10642 LINEAR A SIGN AB081
10643 LINEAR A SIGN AB082
10644 LINEAR A SIGN AB085
10645 LINEAR A SIGN AB086
10646 LINEAR A SIGN AB087
10647 LINEAR A SIGN A100-102
10648 LINEAR A SIGN AB118
10649 LINEAR A SIGN AB120
1064A LINEAR A SIGN A120B
1064B LINEAR A SIGN AB122
1064C LINEAR A SIGN AB123
1064D LINEAR A SIGN AB131A
1064E LINEAR A SIGN AB131B
1064F LINEAR A SIGN A131C
10650 LINEAR A SIGN AB164
10651 LINEAR A SIGN AB171
10652 LINEAR A SIGN AB180
10653 LINEAR A SIGN AB188
10654 LINEAR A SIGN AB191
10655 LINEAR A SIGN A301
10656 LINEAR A SIGN A302
10657 LINEAR A SIGN A303
10658 LINEAR A SIGN A304
10659 LINEAR A SIGN A305
1065A LINEAR A SIGN A306
1065B LINEAR A SIGN A307
1065C LINEAR A SIGN A308
1065D LINEAR A SIGN A309A
1065E LINEAR A SIGN A309B
1065F LINEAR A SIGN A309C
10660 LINEAR A SIGN A310
10661 LINEAR A SIGN A311
10662 LINEAR A SIGN A312
10663 LINEAR A SIGN A313A
10664 LINEAR A SIGN A313B
10665 LINEAR A SIGN A313C
10666 LINEAR A SIGN A314
10667 LINEAR A SIGN A315
10668 LINEAR A SIGN A316
10669 LINEAR A SIGN A317
1066A LINEAR A SIGN A318
1066B LINEAR A SIGN A319
1066C LINEAR A SIGN A320
1066D LINEAR A SIGN A321
1066E LINEAR A SIGN A322
1066F LINEAR A SIGN A323
10670 LINEAR A SIGN A324
10671 LINEAR A SIGN A325
10672 LINEAR A SIGN A326
10673 LINEAR A SIGN A327
10674 LINEAR A SIGN A328
10675 LINEAR A SIGN A329
10676 LINEAR A SIGN A330
10677 LINEAR A SIGN A331
10678 LINEAR A SIGN A332
10679 LINEAR A SIGN A333
1067A LINEAR A SIGN A334
1067B LINEAR A SIGN A335
1067C LINEAR A SIGN A336
1067D LINEAR A SIGN A337
1067E LINEAR A SIGN A338
1067F LINEAR A SIGN A339
10680 LINEAR A SIGN A340
10681 LINEAR A SIGN A341
10682 LINEAR A SIGN A342
10683 LINEAR A SIGN A343
10684 LINEAR A SIGN A344
10685 LINEAR A SIGN A345
10686 LINEAR A SIGN A346
10687 LINEAR A SIGN A347
10688 LINEAR A SIGN A348
10689 LINEAR A SIGN A349
1068A LINEAR A SIGN A350
1068B LINEAR A SIGN A351
1068C LINEAR A SIGN A352
1068D LINEAR A SIGN A353
1068E LINEAR A SIGN A354
1068F LINEAR A SIGN A355
10690 LINEAR A SIGN A356
10691 LINEAR A SIGN A357
10692 LINEAR A SIGN A358
10693 LINEAR A SIGN A359
10694 LINEAR A SIGN A360
10695 LINEAR A SIGN A361
10696 LINEAR A SIGN A362
10697 LINEAR A SIGN A363
10698 LINEAR A SIGN A364
10699 LINEAR A SIGN A365
1069A LINEAR A SIGN A366
1069B LINEAR A SIGN A367
1069C LINEAR A SIGN A368
1069D LINEAR A SIGN A369
1069E LINEAR A SIGN A370
1069F LINEAR A SIGN A371
106A0 LINEAR A SIGN A400-VAS
106A1 LINEAR A SIGN A401-VAS
106A2 LINEAR A SIGN A402-VAS
106A3 LINEAR A SIGN A403-VAS
106A4 LINEAR A SIGN A404-VAS
106A5 LINEAR A SIGN A405-VAS
106A6 LINEAR A SIGN A406-VAS
106A7 LINEAR A SIGN A407-VAS
106A8 LINEAR A SIGN A408-VAS
106A9 LINEAR A SIGN A409-VAS
106AA LINEAR A SIGN A410-VAS
106AB LINEAR A SIGN A411-VAS
106AC LINEAR A SIGN A412-VAS
106AD LINEAR A SIGN A413-VAS
106AE LINEAR A SIGN A414-VAS
106AF LINEAR A SIGN A415-VAS
106B0 LINEAR A SIGN A416-VAS
106B1 LINEAR A SIGN A417-VAS
106B2 LINEAR A SIGN A418-VAS
106B3 LINEAR A SIGN A501
106B4 LINEAR A SIGN A502
106B5 LINEAR A SIGN A503
106B6 LINEAR A SIGN A504
106B7 LINEAR A SIGN A505
106B8 LINEAR A SIGN A506
106B9 LINEAR A SIGN A508
106BA LINEAR A SIGN A509
106BB LINEAR A SIGN A510
106BC LINEAR A SIGN A511
106BD LINEAR A SIGN A512
106BE LINEAR A SIGN A513
106BF LINEAR A SIGN A515
106C0 LINEAR A SIGN A516
106C1 LINEAR A SIGN A520
106C2 LINEAR A SIGN A521
106C3 LINEAR A SIGN A523
106C4 LINEAR A SIGN A524
106C5 LINEAR A SIGN A525
106C6 LINEAR A SIGN A526
106C7 LINEAR A SIGN A527
106C8 LINEAR A SIGN A528
106C9 LINEAR A SIGN A529
106CA LINEAR A SIGN A530
106CB LINEAR A SIGN A531
106CC LINEAR A SIGN A532
106CD LINEAR A SIGN A534
106CE LINEAR A SIGN A535
106CF LINEAR A SIGN A536
106D0 LINEAR A SIGN A537
106D1 LINEAR A SIGN A538
106D2 LINEAR A SIGN A539
106D3 LINEAR A SIGN A540
106D4 LINEAR A SIGN A541
106D5 LINEAR A SIGN A542
106D6 LINEAR A SIGN A545
106D7 LINEAR A SIGN A547
106D8 LINEAR A SIGN A548
106D9 LINEAR A SIGN A549
106DA LINEAR A SIGN A550
106DB LINEAR A SIGN A551
106DC LINEAR A SIGN A552
106DD LINEAR A SIGN A553
106DE LINEAR A SIGN A554
106DF LINEAR A SIGN A555
106E0 LINEAR A SIGN A556
106E1 LINEAR A SIGN A557
106E2 LINEAR A SIGN A559
106E3 LINEAR A SIGN A563
106E4 LINEAR A SIGN A564
106E5 LINEAR A SIGN A565
106E6 LINEAR A SIGN A566
106E7 LINEAR A SIGN A568
106E8 LINEAR A SIGN A569
106E9 LINEAR A SIGN A570
106EA LINEAR A SIGN A571
106EB LINEAR A SIGN A572
106EC LINEAR A SIGN A573
106ED LINEAR A SIGN A574
106EE LINEAR A SIGN A575
106EF LINEAR A SIGN A576
106F0 LINEAR A SIGN A577
106F1 LINEAR A SIGN A578
106F2 LINEAR A SIGN A579
106F3 LINEAR A SIGN A580
106F4 LINEAR A SIGN A581
106F5 LINEAR A SIGN A582
106F6 LINEAR A SIGN A583
106F7 LINEAR A SIGN A584
106F8 LINEAR A SIGN A585
106F9 LINEAR A SIGN A586
106FA LINEAR A SIGN A587
106FB LINEAR A SIGN A588
106FC LINEAR A SIGN A589
106FD LINEAR A SIGN A591
106FE LINEAR A SIGN A592
106FF LINEAR A SIGN A594
10700 LINEAR A SIGN A595
10701 LINEAR A SIGN A596
10702 LINEAR A SIGN A598
10703 LINEAR A SIGN A600
10704 LINEAR A SIGN A601
10705 LINEAR A SIGN A602
10706 LINEAR A SIGN A603
10707 LINEAR A SIGN A604
10708 LINEAR A SIGN A606
10709 LINEAR A SIGN A608
1070A LINEAR A SIGN A609
1070B LINEAR A SIGN A610
1070C LINEAR A SIGN A611
1070D LINEAR A SIGN A612
1070E LINEAR A SIGN A613
1070F LINEAR A SIGN A614
10710 LINEAR A SIGN A615
10711 LINEAR A SIGN A616
10712 LINEAR A SIGN A617
10713 LINEAR A SIGN A618
10714 LINEAR A SIGN A619
10715 LINEAR A SIGN A620
10716 LINEAR A SIGN A621
10717 LINEAR A SIGN A622
10718 LINEAR A SIGN A623
10719 LINEAR A SIGN A624
1071A LINEAR A SIGN A626
1071B LINEAR A SIGN A627
1071C LINEAR A SIGN A628
1071D LINEAR A SIGN A629
1071E LINEAR A SIGN A634
1071F LINEAR A SIGN A637
10720 LINEAR A SIGN A638
10721 LINEAR A SIGN A640
10722 LINEAR A SIGN A642
10723 LINEAR A SIGN A643
10724 LINEAR A SIGN A644
10725 LINEAR A SIGN A645
10726 LINEAR A SIGN A646
10727 LINEAR A SIGN A648
10728 LINEAR A SIGN A649
10729 LINEAR A SIGN A651
1072A LINEAR A SIGN A652
1072B LINEAR A SIGN A653
1072C LINEAR A SIGN A654
1072D LINEAR A SIGN A655
1072E LINEAR A SIGN A656
1072F LINEAR A SIGN A657
10730 LINEAR A SIGN A658
10731 LINEAR A SIGN A659
10732 LINEAR A SIGN A660
10733 LINEAR A SIGN A661
10734 LINEAR A SIGN A662
10735 LINEAR A SIGN A663
10736 LINEAR A SIGN A664
10740 LINEAR A SIGN A701 A
10741 LINEAR A SIGN A702 B
10742 LINEAR A SIGN A703 D
10743 LINEAR A SIGN A704 E
10744 LINEAR A SIGN A705 F
10745 LINEAR A SIGN A706 H
10746 LINEAR A SIGN A707 J
10747 LINEAR A SIGN A708 K
10748 LINEAR A SIGN A709 L
10749 LINEAR A SIGN A709-2 L2
1074A LINEAR A SIGN A709-3 L3
1074B LINEAR A SIGN A709-4 L4
1074C LINEAR A SIGN A709-6 L6
1074D LINEAR A SIGN A710 W
1074E LINEAR A SIGN A711 X
1074F LINEAR A SIGN A712 Y
10750 LINEAR A SIGN A713 OMEGA
10751 LINEAR A SIGN A714 ABB
10752 LINEAR A SIGN A715 BB
10753 LINEAR A SIGN A717 DD
10754 LINEAR A SIGN A726 EYYY
10755 LINEAR A SIGN A732 JE
10760 LINEAR A SIGN A800
10761 LINEAR A SIGN A801
10762 LINEAR A SIGN A802
10763 LINEAR A SIGN A803
10764 LINEAR A SIGN A804
10765 LINEAR A SIGN A805
10766 LINEAR A SIGN A806
10767 LINEAR A SIGN A807
10800 CYPRIOT SYLLABLE A
10801 CYPRIOT SYLLABLE E
10802 CYPRIOT SYLLABLE I
10803 CYPRIOT SYLLABLE O
10804 CYPRIOT SYLLABLE U
10805 CYPRIOT SYLLABLE JA
10808 CYPRIOT SYLLABLE JO
1080A CYPRIOT SYLLABLE KA
1080B CYPRIOT SYLLABLE KE
1080C CYPRIOT SYLLABLE KI
1080D CYPRIOT SYLLABLE KO
1080E CYPRIOT SYLLABLE KU
1080F CYPRIOT SYLLABLE LA
10810 CYPRIOT SYLLABLE LE
10811 CYPRIOT SYLLABLE LI
10812 CYPRIOT SYLLABLE LO
10813 CYPRIOT SYLLABLE LU
10814 CYPRIOT SYLLABLE MA
10815 CYPRIOT SYLLABLE ME
10816 CYPRIOT SYLLABLE MI
10817 CYPRIOT SYLLABLE MO
10818 CYPRIOT SYLLABLE MU
10819 CYPRIOT SYLLABLE NA
1081A CYPRIOT SYLLABLE NE
1081B CYPRIOT SYLLABLE NI
1081C CYPRIOT SYLLABLE NO
1081D CYPRIOT SYLLABLE NU
1081E CYPRIOT SYLLABLE PA
1081F CYPRIOT SYLLABLE PE
10820 CYPRIOT SYLLABLE PI
10821 CYPRIOT SYLLABLE PO
10822 CYPRIOT SYLLABLE PU
10823 CYPRIOT SYLLABLE RA
10824 CYPRIOT SYLLABLE RE
10825 CYPRIOT SYLLABLE RI
10826 CYPRIOT SYLLABLE RO
10827 CYPRIOT SYLLABLE RU
10828 CYPRIOT SYLLABLE SA
10829 CYPRIOT SYLLABLE SE
1082A CYPRIOT SYLLABLE SI
1082B CYPRIOT SYLLABLE SO
1082C CYPRIOT SYLLABLE SU
1082D CYPRIOT SYLLABLE TA
1082E CYPRIOT SYLLABLE TE
1082F CYPRIOT SYLLABLE TI
10830 CYPRIOT SYLLABLE TO
10831 CYPRIOT SYLLABLE TU
10832 CYPRIOT SYLLABLE WA
10833 CYPRIOT SYLLABLE WE
10834 CYPRIOT SYLLABLE WI
10835 CYPRIOT SYLLABLE WO
10837 CYPRIOT SYLLABLE XA
10838 CYPRIOT SYLLABLE XE
1083C CYPRIOT SYLLABLE ZA
1083F CYPRIOT SYLLABLE ZO
10840 IMPERIAL ARAMAIC LETTER ALEPH
10841 IMPERIAL ARAMAIC LETTER BETH
10842 IMPERIAL ARAMAIC LETTER GIMEL
10843 IMPERIAL ARAMAIC LETTER DALETH
10844 IMPERIAL ARAMAIC LETTER HE
10845 IMPERIAL ARAMAIC LETTER WAW
10846 IMPERIAL ARAMAIC LETTER ZAYIN
10847 IMPERIAL ARAMAIC LETTER HETH
10848 IMPERIAL ARAMAIC LETTER TETH
10849 IMPERIAL ARAMAIC LETTER YODH
1084A IMPERIAL ARAMAIC LETTER KAPH
1084B IMPERIAL ARAMAIC LETTER LAMEDH
1084C IMPERIAL ARAMAIC LETTER MEM
1084D IMPERIAL ARAMAIC LETTER NUN
1084E IMPERIAL ARAMAIC LETTER SAMEKH
1084F IMPERIAL ARAMAIC LETTER AYIN
10850 IMPERIAL ARAMAIC LETTER PE
10851 IMPERIAL ARAMAIC LETTER SADHE
10852 IMPERIAL ARAMAIC LETTER QOPH
10853 IMPERIAL ARAMAIC LETTER RESH
10854 IMPERIAL ARAMAIC LETTER SHIN
10855 IMPERIAL ARAMAIC LETTER TAW
10857 IMPERIAL ARAMAIC SECTION SIGN
10858 IMPERIAL ARAMAIC NUMBER ONE
10859 IMPERIAL ARAMAIC NUMBER TWO
1085A IMPERIAL ARAMAIC NUMBER THREE
1085B IMPERIAL ARAMAIC NUMBER TEN
1085C IMPERIAL ARAMAIC NUMBER TWENTY
1085D IMPERIAL ARAMAIC NUMBER ONE HUNDRED
1085E IMPERIAL ARAMAIC NUMBER ONE THOUSAND
1085F IMPERIAL ARAMAIC NUMBER TEN THOUSAND
10860 PALMYRENE LETTER ALEPH
10861 PALMYRENE LETTER BETH
10862 PALMYRENE LETTER GIMEL
10863 PALMYRENE LETTER DALETH
10864 PALMYRENE LETTER HE
10865 PALMYRENE LETTER WAW
10866 PALMYRENE LETTER ZAYIN
10867 PALMYRENE LETTER HETH
10868 PALMYRENE LETTER TETH
10869 PALMYRENE LETTER YODH
1086A PALMYRENE LETTER KAPH
1086B PALMYRENE LETTER LAMEDH
1086C PALMYRENE LETTER MEM
1086D PALMYRENE LETTER FINAL NUN
1086E PALMYRENE LETTER NUN
1086F PALMYRENE LETTER SAMEKH
10870 PALMYRENE LETTER AYIN
10871 PALMYRENE LETTER PE
10872 PALMYRENE LETTER SADHE
10873 PALMYRENE LETTER QOPH
10874 PALMYRENE LETTER RESH
10875 PALMYRENE LETTER SHIN
10876 PALMYRENE LETTER TAW
10877 PALMYRENE LEFT-POINTING FLEURON
10878 PALMYRENE RIGHT-POINTING FLEURON
10879 PALMYRENE NUMBER ONE
1087A PALMYRENE NUMBER TWO
1087B PALMYRENE NUMBER THREE
1087C PALMYRENE NUMBER FOUR
1087D PALMYRENE NUMBER FIVE
1087E PALMYRENE NUMBER TEN
1087F PALMYRENE NUMBER TWENTY
10880 NABATAEAN LETTER FINAL ALEPH
10881 NABATAEAN LETTER ALEPH
10882 NABATAEAN LETTER FINAL BETH
10883 NABATAEAN LETTER BETH
10884 NABATAEAN LETTER GIMEL
10885 NABATAEAN LETTER DALETH
10886 NABATAEAN LETTER FINAL HE
10887 NABATAEAN LETTER HE
10888 NABATAEAN LETTER WAW
10889 NABATAEAN LETTER ZAYIN
1088A NABATAEAN LETTER HETH
1088B NABATAEAN LETTER TETH
1088C NABATAEAN LETTER FINAL YODH
1088D NABATAEAN LETTER YODH
1088E NABATAEAN LETTER FINAL KAPH
1088F NABATAEAN LETTER KAPH
10890 NABATAEAN LETTER FINAL LAMEDH
10891 NABATAEAN LETTER LAMEDH
10892 NABATAEAN LETTER FINAL MEM
10893 NABATAEAN LETTER MEM
10894 NABATAEAN LETTER FINAL NUN
10895 NABATAEAN LETTER NUN
10896 NABATAEAN LETTER SAMEKH
10897 NABATAEAN LETTER AYIN
10898 NABATAEAN LETTER PE
10899 NABATAEAN LETTER SADHE
1089A NABATAEAN LETTER QOPH
1089B NABATAEAN LETTER RESH
1089C NABATAEAN LETTER FINAL SHIN
1089D NABATAEAN LETTER SHIN
1089E NABATAEAN LETTER TAW
108A7 NABATAEAN NUMBER ONE
108A8 NABATAEAN NUMBER TWO
108A9 NABATAEAN NUMBER THREE
108AA NABATAEAN NUMBER FOUR
108AB NABATAEAN CRUCIFORM NUMBER FOUR
108AC NABATAEAN NUMBER FIVE
108AD NABATAEAN NUMBER TEN
108AE NABATAEAN NUMBER TWENTY
108AF NABATAEAN NUMBER ONE HUNDRED
108E0 HATRAN LETTER ALEPH
108E1 HATRAN LETTER BETH
108E2 HATRAN LETTER GIMEL
108E3 HATRAN LETTER DALETH-RESH
108E4 HATRAN LETTER HE
108E5 HATRAN LETTER WAW
108E6 HATRAN LETTER ZAYN
108E7 HATRAN LETTER HETH
108E8 HATRAN LETTER TETH
108E9 HATRAN LETTER YODH
108EA HATRAN LETTER KAPH
108EB HATRAN LETTER LAMEDH
108EC HATRAN LETTER MEM
108ED HATRAN LETTER NUN
108EE HATRAN LETTER SAMEKH
108EF HATRAN LETTER AYN
108F0 HATRAN LETTER PE
108F1 HATRAN LETTER SADHE
108F2 HATRAN LETTER QOPH
108F4 HATRAN LETTER SHIN
108F5 HATRAN LETTER TAW
108FB HATRAN NUMBER ONE
108FC HATRAN NUMBER FIVE
108FD HATRAN NUMBER TEN
108FE HATRAN NUMBER TWENTY
108FF HATRAN NUMBER ONE HUNDRED
10900 PHOENICIAN LETTER ALF
10901 PHOENICIAN LETTER BET
10902 PHOENICIAN LETTER GAML
10903 PHOENICIAN LETTER DELT
10904 PHOENICIAN LETTER HE
10905 PHOENICIAN LETTER WAU
10906 PHOENICIAN LETTER ZAI
10907 PHOENICIAN LETTER HET
10908 PHOENICIAN LETTER TET
10909 PHOENICIAN LETTER YOD
1090A PHOENICIAN LETTER KAF
1090B PHOENICIAN LETTER LAMD
1090C PHOENICIAN LETTER MEM
1090D PHOENICIAN LETTER NUN
1090E PHOENICIAN LETTER SEMK
1090F PHOENICIAN LETTER AIN
10910 PHOENICIAN LETTER PE
10911 PHOENICIAN LETTER SADE
10912 PHOENICIAN LETTER QOF
10913 PHOENICIAN LETTER ROSH
10914 PHOENICIAN LETTER SHIN
10915 PHOENICIAN LETTER TAU
10916 PHOENICIAN NUMBER ONE
10917 PHOENICIAN NUMBER TEN
10918 PHOENICIAN NUMBER TWENTY
10919 PHOENICIAN NUMBER ONE HUNDRED
1091A PHOENICIAN NUMBER TWO
1091B PHOENICIAN NUMBER THREE
1091F PHOENICIAN WORD SEPARATOR
10920 LYDIAN LETTER A
10921 LYDIAN LETTER B
10922 LYDIAN LETTER G
10923 LYDIAN LETTER D
10924 LYDIAN LETTER E
10925 LYDIAN LETTER V
10926 LYDIAN LETTER I
10927 LYDIAN LETTER Y
10928 LYDIAN LETTER K
10929 LYDIAN LETTER L
1092A LYDIAN LETTER M
1092B LYDIAN LETTER N
1092C LYDIAN LETTER O
1092D LYDIAN LETTER R
1092E LYDIAN LETTER SS
1092F LYDIAN LETTER T
10930 LYDIAN LETTER U
10931 LYDIAN LETTER F
10932 LYDIAN LETTER Q
10933 LYDIAN LETTER S
10934 LYDIAN LETTER TT
10935 LYDIAN LETTER AN
10936 LYDIAN LETTER EN
10937 LYDIAN LETTER LY
10938 LYDIAN LETTER NN
10939 LYDIAN LETTER C
1093F LYDIAN TRIANGULAR MARK
10980 MEROITIC HIEROGLYPHIC LETTER A
10981 MEROITIC HIEROGLYPHIC LETTER E
10982 MEROITIC HIEROGLYPHIC LETTER I
10983 MEROITIC HIEROGLYPHIC LETTER O
10984 MEROITIC HIEROGLYPHIC LETTER YA
10985 MEROITIC HIEROGLYPHIC LETTER WA
10986 MEROITIC HIEROGLYPHIC LETTER BA
10987 MEROITIC HIEROGLYPHIC LETTER BA-2
10988 MEROITIC HIEROGLYPHIC LETTER PA
10989 MEROITIC HIEROGLYPHIC LETTER MA
1098A MEROITIC HIEROGLYPHIC LETTER NA
1098B MEROITIC HIEROGLYPHIC LETTER NA-2
1098C MEROITIC HIEROGLYPHIC LETTER NE
1098D MEROITIC HIEROGLYPHIC LETTER NE-2
1098E MEROITIC HIEROGLYPHIC LETTER RA
1098F MEROITIC HIEROGLYPHIC LETTER RA-2
10990 MEROITIC HIEROGLYPHIC LETTER LA
10991 MEROITIC HIEROGLYPHIC LETTER KHA
10992 MEROITIC HIEROGLYPHIC LETTER HHA
10993 MEROITIC HIEROGLYPHIC LETTER SA
10994 MEROITIC HIEROGLYPHIC LETTER SA-2
10995 MEROITIC HIEROGLYPHIC LETTER SE
10996 MEROITIC HIEROGLYPHIC LETTER KA
10997 MEROITIC HIEROGLYPHIC LETTER QA
10998 MEROITIC HIEROGLYPHIC LETTER TA
10999 MEROITIC HIEROGLYPHIC LETTER TA-2
1099A MEROITIC HIEROGLYPHIC LETTER TE
1099B MEROITIC HIEROGLYPHIC LETTER TE-2
1099C MEROITIC HIEROGLYPHIC LETTER TO
1099D MEROITIC HIEROGLYPHIC LETTER DA
1099E MEROITIC HIEROGLYPHIC SYMBOL VIDJ
1099F MEROITIC HIEROGLYPHIC SYMBOL VIDJ-2
109A0 MEROITIC CURSIVE LETTER A
109A1 MEROITIC CURSIVE LETTER E
109A2 MEROITIC CURSIVE LETTER I
109A3 MEROITIC CURSIVE LETTER O
109A4 MEROITIC CURSIVE LETTER YA
109A5 MEROITIC CURSIVE LETTER WA
109A6 MEROITIC CURSIVE LETTER BA
109A7 MEROITIC CURSIVE LETTER PA
109A8 MEROITIC CURSIVE LETTER MA
109A9 MEROITIC CURSIVE LETTER NA
109AA MEROITIC CURSIVE LETTER NE
109AB MEROITIC CURSIVE LETTER RA
109AC MEROITIC CURSIVE LETTER LA
109AD MEROITIC CURSIVE LETTER KHA
109AE MEROITIC CURSIVE LETTER HHA
109AF MEROITIC CURSIVE LETTER SA
109B0 MEROITIC CURSIVE LETTER ARCHAIC SA
109B1 MEROITIC CURSIVE LETTER SE
109B2 MEROITIC CURSIVE LETTER KA
109B3 MEROITIC CURSIVE LETTER QA
109B4 MEROITIC CURSIVE LETTER TA
109B5 MEROITIC CURSIVE LETTER TE
109B6 MEROITIC CURSIVE LETTER TO
109B7 MEROITIC CURSIVE LETTER DA
109BC MEROITIC CURSIVE FRACTION ELEVEN TWELFTHS
109BD MEROITIC CURSIVE FRACTION ONE HALF
109BE MEROITIC CURSIVE LOGOGRAM RMT
109BF MEROITIC CURSIVE LOGOGRAM IMN
109C0 MEROITIC CURSIVE NUMBER ONE
109C1 MEROITIC CURSIVE NUMBER TWO
109C2 MEROITIC CURSIVE NUMBER THREE
109C3 MEROITIC CURSIVE NUMBER FOUR
109C4 MEROITIC CURSIVE NUMBER FIVE
109C5 MEROITIC CURSIVE NUMBER SIX
109C6 MEROITIC CURSIVE NUMBER SEVEN
109C7 MEROITIC CURSIVE NUMBER EIGHT
109C8 MEROITIC CURSIVE NUMBER NINE
109C9 MEROITIC CURSIVE NUMBER TEN
109CA MEROITIC CURSIVE NUMBER TWENTY
109CB MEROITIC CURSIVE NUMBER THIRTY
109CC MEROITIC CURSIVE NUMBER FORTY
109CD MEROITIC CURSIVE NUMBER FIFTY
109CE MEROITIC CURSIVE NUMBER SIXTY
109CF MEROITIC CURSIVE NUMBER SEVENTY
109D2 MEROITIC CURSIVE NUMBER ONE HUNDRED
109D3 MEROITIC CURSIVE NUMBER TWO HUNDRED
109D4 MEROITIC CURSIVE NUMBER THREE HUNDRED
109D5 MEROITIC CURSIVE NUMBER FOUR HUNDRED
109D6 MEROITIC CURSIVE NUMBER FIVE HUNDRED
109D7 MEROITIC CURSIVE NUMBER SIX HUNDRED
109D8 MEROITIC CURSIVE NUMBER SEVEN HUNDRED
109D9 MEROITIC CURSIVE NUMBER EIGHT HUNDRED
109DA MEROITIC CURSIVE NUMBER NINE HUNDRED
109DB MEROITIC CURSIVE NUMBER ONE THOUSAND
109DC MEROITIC CURSIVE NUMBER TWO THOUSAND
109DD MEROITIC CURSIVE NUMBER THREE THOUSAND
109DE MEROITIC CURSIVE NUMBER FOUR THOUSAND
109DF MEROITIC CURSIVE NUMBER FIVE THOUSAND
109E0 MEROITIC CURSIVE NUMBER SIX THOUSAND
109E1 MEROITIC CURSIVE NUMBER SEVEN THOUSAND
109E2 MEROITIC CURSIVE NUMBER EIGHT THOUSAND
109E3 MEROITIC CURSIVE NUMBER NINE THOUSAND
109E4 MEROITIC CURSIVE NUMBER TEN THOUSAND
109E5 MEROITIC CURSIVE NUMBER TWENTY THOUSAND
109E6 MEROITIC CURSIVE NUMBER THIRTY THOUSAND
109E7 MEROITIC CURSIVE NUMBER FORTY THOUSAND
109E8 MEROITIC CURSIVE NUMBER FIFTY THOUSAND
109E9 MEROITIC CURSIVE NUMBER SIXTY THOUSAND
109EA MEROITIC CURSIVE NUMBER SEVENTY THOUSAND
109EB MEROITIC CURSIVE NUMBER EIGHTY THOUSAND
109EC MEROITIC CURSIVE NUMBER NINETY THOUSAND
109ED MEROITIC CURSIVE NUMBER ONE HUNDRED THOUSAND
109EE MEROITIC CURSIVE NUMBER TWO HUNDRED THOUSAND
109EF MEROITIC CURSIVE NUMBER THREE HUNDRED THOUSAND
109F0 MEROITIC CURSIVE NUMBER FOUR HUNDRED THOUSAND
109F1 MEROITIC CURSIVE NUMBER FIVE HUNDRED THOUSAND
109F2 MEROITIC CURSIVE NUMBER SIX HUNDRED THOUSAND
109F3 MEROITIC CURSIVE NUMBER SEVEN HUNDRED THOUSAND
109F4 MEROITIC CURSIVE NUMBER EIGHT HUNDRED THOUSAND
109F5 MEROITIC CURSIVE NUMBER NINE HUNDRED THOUSAND
109F6 MEROITIC CURSIVE FRACTION ONE TWELFTH
109F7 MEROITIC CURSIVE FRACTION TWO TWELFTHS
109F8 MEROITIC CURSIVE FRACTION THREE TWELFTHS
109F9 MEROITIC CURSIVE FRACTION FOUR TWELFTHS
109FA MEROITIC CURSIVE FRACTION FIVE TWELFTHS
109FB MEROITIC CURSIVE FRACTION SIX TWELFTHS
109FC MEROITIC CURSIVE FRACTION SEVEN TWELFTHS
109FD MEROITIC CURSIVE FRACTION EIGHT TWELFTHS
109FE MEROITIC CURSIVE FRACTION NINE TWELFTHS
109FF MEROITIC CURSIVE FRACTION TEN TWELFTHS
10A00 KHAROSHTHI LETTER A
10A01 KHAROSHTHI VOWEL SIGN I
10A02 KHAROSHTHI VOWEL SIGN U
10A03 KHAROSHTHI VOWEL SIGN VOCALIC R
10A05 KHAROSHTHI VOWEL SIGN E
10A06 KHAROSHTHI VOWEL SIGN O
10A0C KHAROSHTHI VOWEL LENGTH MARK
10A0D KHAROSHTHI SIGN DOUBLE RING BELOW
10A0E KHAROSHTHI SIGN ANUSVARA
10A0F KHAROSHTHI SIGN VISARGA
10A10 KHAROSHTHI LETTER KA
10A11 KHAROSHTHI LETTER KHA
10A12 KHAROSHTHI LETTER GA
10A13 KHAROSHTHI LETTER GHA
10A15 KHAROSHTHI LETTER CA
10A16 KHAROSHTHI LETTER CHA
10A17 KHAROSHTHI LETTER JA
10A19 KHAROSHTHI LETTER NYA
10A1A KHAROSHTHI LETTER TTA
10A1B KHAROSHTHI LETTER TTHA
10A1C KHAROSHTHI LETTER DDA
10A1D KHAROSHTHI LETTER DDHA
10A1E KHAROSHTHI LETTER NNA
10A1F KHAROSHTHI LETTER TA
10A20 KHAROSHTHI LETTER THA
10A21 KHAROSHTHI LETTER DA
10A22 KHAROSHTHI LETTER DHA
10A23 KHAROSHTHI LETTER NA
10A24 KHAROSHTHI LETTER PA
10A25 KHAROSHTHI LETTER PHA
10A26 KHAROSHTHI LETTER BA
10A27 KHAROSHTHI LETTER BHA
10A28 KHAROSHTHI LETTER MA
10A29 KHAROSHTHI LETTER YA
10A2A KHAROSHTHI LETTER RA
10A2B KHAROSHTHI LETTER LA
10A2C KHAROSHTHI LETTER VA
10A2D KHAROSHTHI LETTER SHA
10A2E KHAROSHTHI LETTER SSA
10A2F KHAROSHTHI LETTER SA
10A30 KHAROSHTHI LETTER ZA
10A31 KHAROSHTHI LETTER HA
10A32 KHAROSHTHI LETTER KKA
10A33 KHAROSHTHI LETTER TTTHA
10A38 KHAROSHTHI SIGN BAR ABOVE
10A39 KHAROSHTHI SIGN CAUDA
10A3A KHAROSHTHI SIGN DOT BELOW
10A3F KHAROSHTHI VIRAMA
10A40 KHAROSHTHI DIGIT ONE
10A41 KHAROSHTHI DIGIT TWO
10A42 KHAROSHTHI DIGIT THREE
10A43 KHAROSHTHI DIGIT FOUR
10A44 KHAROSHTHI NUMBER TEN
10A45 KHAROSHTHI NUMBER TWENTY
10A46 KHAROSHTHI NUMBER ONE HUNDRED
10A47 KHAROSHTHI NUMBER ONE THOUSAND
10A50 KHAROSHTHI PUNCTUATION DOT
10A51 KHAROSHTHI PUNCTUATION SMALL CIRCLE
10A52 KHAROSHTHI PUNCTUATION CIRCLE
10A53 KHAROSHTHI PUNCTUATION CRESCENT BAR
10A54 KHAROSHTHI PUNCTUATION MANGALAM
10A55 KHAROSHTHI PUNCTUATION LOTUS
10A56 KHAROSHTHI PUNCTUATION DANDA
10A57 KHAROSHTHI PUNCTUATION DOUBLE DANDA
10A58 KHAROSHTHI PUNCTUATION LINES
10A60 OLD SOUTH ARABIAN LETTER HE
10A61 OLD SOUTH ARABIAN LETTER LAMEDH
10A62 OLD SOUTH ARABIAN LETTER HETH
10A63 OLD SOUTH ARABIAN LETTER MEM
10A64 OLD SOUTH ARABIAN LETTER QOPH
10A65 OLD SOUTH ARABIAN LETTER WAW
10A66 OLD SOUTH ARABIAN LETTER SHIN
10A67 OLD SOUTH ARABIAN LETTER RESH
10A68 OLD SOUTH ARABIAN LETTER BETH
10A69 OLD SOUTH ARABIAN LETTER TAW
10A6A OLD SOUTH ARABIAN LETTER SAT
10A6B OLD SOUTH ARABIAN LETTER KAPH
10A6C OLD SOUTH ARABIAN LETTER NUN
10A6D OLD SOUTH ARABIAN LETTER KHETH
10A6E OLD SOUTH ARABIAN LETTER SADHE
10A6F OLD SOUTH ARABIAN LETTER SAMEKH
10A70 OLD SOUTH ARABIAN LETTER FE
10A71 OLD SOUTH ARABIAN LETTER ALEF
10A72 OLD SOUTH ARABIAN LETTER AYN
10A73 OLD SOUTH ARABIAN LETTER DHADHE
10A74 OLD SOUTH ARABIAN LETTER GIMEL
10A75 OLD SOUTH ARABIAN LETTER DALETH
10A76 OLD SOUTH ARABIAN LETTER GHAYN
10A77 OLD SOUTH ARABIAN LETTER TETH
10A78 OLD SOUTH ARABIAN LETTER ZAYN
10A79 OLD SOUTH ARABIAN LETTER DHALETH
10A7A OLD SOUTH ARABIAN LETTER YODH
10A7B OLD SOUTH ARABIAN LETTER THAW
10A7C OLD SOUTH ARABIAN LETTER THETH
10A7D OLD SOUTH ARABIAN NUMBER ONE
10A7E OLD SOUTH ARABIAN NUMBER FIFTY
10A7F OLD SOUTH ARABIAN NUMERIC INDICATOR
10A80 OLD NORTH ARABIAN LETTER HEH
10A81 OLD NORTH ARABIAN LETTER LAM
10A82 OLD NORTH ARABIAN LETTER HAH
10A83 OLD NORTH ARABIAN LETTER MEEM
10A84 OLD NORTH ARABIAN LETTER QAF
10A85 OLD NORTH ARABIAN LETTER WAW
10A86 OLD NORTH ARABIAN LETTER ES-2
10A87 OLD NORTH ARABIAN LETTER REH
10A88 OLD NORTH ARABIAN LETTER BEH
10A89 OLD NORTH ARABIAN LETTER TEH
10A8A OLD NORTH ARABIAN LETTER ES-1
10A8B OLD NORTH ARABIAN LETTER KAF
10A8C OLD NORTH ARABIAN LETTER NOON
10A8D OLD NORTH ARABIAN LETTER KHAH
10A8E OLD NORTH ARABIAN LETTER SAD
10A8F OLD NORTH ARABIAN LETTER ES-3
10A90 OLD NORTH ARABIAN LETTER FEH
10A91 OLD NORTH ARABIAN LETTER ALEF
10A92 OLD NORTH ARABIAN LETTER AIN
10A93 OLD NORTH ARABIAN LETTER DAD
10A94 OLD NORTH ARABIAN LETTER GEEM
10A95 OLD NORTH ARABIAN LETTER DAL
10A96 OLD NORTH ARABIAN LETTER GHAIN
10A97 OLD NORTH ARABIAN LETTER TAH
10A98 OLD NORTH ARABIAN LETTER ZAIN
10A99 OLD NORTH ARABIAN LETTER THAL
10A9A OLD NORTH ARABIAN LETTER YEH
10A9B OLD NORTH ARABIAN LETTER THEH
10A9C OLD NORTH ARABIAN LETTER ZAH
10A9D OLD NORTH ARABIAN NUMBER ONE
10A9E OLD NORTH ARABIAN NUMBER TEN
10A9F OLD NORTH ARABIAN NUMBER TWENTY
10AC0 MANICHAEAN LETTER ALEPH
10AC1 MANICHAEAN LETTER BETH
10AC2 MANICHAEAN LETTER BHETH
10AC3 MANICHAEAN LETTER GIMEL
10AC4 MANICHAEAN LETTER GHIMEL
10AC5 MANICHAEAN LETTER DALETH
10AC6 MANICHAEAN LETTER HE
10AC7 MANICHAEAN LETTER WAW
10AC8 MANICHAEAN SIGN UD
10AC9 MANICHAEAN LETTER ZAYIN
10ACA MANICHAEAN LETTER ZHAYIN
10ACB MANICHAEAN LETTER JAYIN
10ACC MANICHAEAN LETTER JHAYIN
10ACD MANICHAEAN LETTER HETH
10ACE MANICHAEAN LETTER TETH
10ACF MANICHAEAN LETTER YODH
10AD0 MANICHAEAN LETTER KAPH
10AD1 MANICHAEAN LETTER XAPH
10AD2 MANICHAEAN LETTER KHAPH
10AD3 MANICHAEAN LETTER LAMEDH
10AD4 MANICHAEAN LETTER DHAMEDH
10AD5 MANICHAEAN LETTER THAMEDH
10AD6 MANICHAEAN LETTER MEM
10AD7 MANICHAEAN LETTER NUN
10AD8 MANICHAEAN LETTER SAMEKH
10AD9 MANICHAEAN LETTER AYIN
10ADA MANICHAEAN LETTER AAYIN
10ADB MANICHAEAN LETTER PE
10ADC MANICHAEAN LETTER FE
10ADD MANICHAEAN LETTER SADHE
10ADE MANICHAEAN LETTER QOPH
10ADF MANICHAEAN LETTER XOPH
10AE0 MANICHAEAN LETTER QHOPH
10AE1 MANICHAEAN LETTER RESH
10AE2 MANICHAEAN LETTER SHIN
10AE3 MANICHAEAN LETTER SSHIN
10AE4 MANICHAEAN LETTER TAW
10AE5 MANICHAEAN ABBREVIATION MARK ABOVE
10AE6 MANICHAEAN ABBREVIATION MARK BELOW
10AEB MANICHAEAN NUMBER ONE
10AEC MANICHAEAN NUMBER FIVE
10AED MANICHAEAN NUMBER TEN
10AEE MANICHAEAN NUMBER TWENTY
10AEF MANICHAEAN NUMBER ONE HUNDRED
10AF0 MANICHAEAN PUNCTUATION STAR
10AF1 MANICHAEAN PUNCTUATION FLEURON
10AF2 MANICHAEAN PUNCTUATION DOUBLE DOT WITHIN DOT
10AF3 MANICHAEAN PUNCTUATION DOT WITHIN DOT
10AF4 MANICHAEAN PUNCTUATION DOT
10AF5 MANICHAEAN PUNCTUATION TWO DOTS
10AF6 MANICHAEAN PUNCTUATION LINE FILLER
10B00 AVESTAN LETTER A
10B01 AVESTAN LETTER AA
10B02 AVESTAN LETTER AO
10B03 AVESTAN LETTER AAO
10B04 AVESTAN LETTER AN
10B05 AVESTAN LETTER AAN
10B06 AVESTAN LETTER AE
10B07 AVESTAN LETTER AEE
10B08 AVESTAN LETTER E
10B09 AVESTAN LETTER EE
10B0A AVESTAN LETTER O
10B0B AVESTAN LETTER OO
10B0C AVESTAN LETTER I
10B0D AVESTAN LETTER II
10B0E AVESTAN LETTER U
10B0F AVESTAN LETTER UU
10B10 AVESTAN LETTER KE
10B11 AVESTAN LETTER XE
10B12 AVESTAN LETTER XYE
10B13 AVESTAN LETTER XVE
10B14 AVESTAN LETTER GE
10B15 AVESTAN LETTER GGE
10B16 AVESTAN LETTER GHE
10B17 AVESTAN LETTER CE
10B18 AVESTAN LETTER JE
10B19 AVESTAN LETTER TE
10B1A AVESTAN LETTER THE
10B1B AVESTAN LETTER DE
10B1C AVESTAN LETTER DHE
10B1D AVESTAN LETTER TTE
10B1E AVESTAN LETTER PE
10B1F AVESTAN LETTER FE
10B20 AVESTAN LETTER BE
10B21 AVESTAN LETTER BHE
10B22 AVESTAN LETTER NGE
10B23 AVESTAN LETTER NGYE
10B24 AVESTAN LETTER NGVE
10B25 AVESTAN LETTER NE
10B26 AVESTAN LETTER NYE
10B27 AVESTAN LETTER NNE
10B28 AVESTAN LETTER ME
10B29 AVESTAN LETTER HME
10B2A AVESTAN LETTER YYE
10B2B AVESTAN LETTER YE
10B2C AVESTAN LETTER VE
10B2D AVESTAN LETTER RE
10B2E AVESTAN LETTER LE
10B2F AVESTAN LETTER SE
10B30 AVESTAN LETTER ZE
10B31 AVESTAN LETTER SHE
10B32 AVESTAN LETTER ZHE
10B33 AVESTAN LETTER SHYE
10B34 AVESTAN LETTER SSHE
10B35 AVESTAN LETTER HE
10B39 AVESTAN ABBREVIATION MARK
10B3A TINY TWO DOTS OVER ONE DOT PUNCTUATION
10B3B SMALL TWO DOTS OVER ONE DOT PUNCTUATION
10B3C LARGE TWO DOTS OVER ONE DOT PUNCTUATION
10B3D LARGE ONE DOT OVER TWO DOTS PUNCTUATION
10B3E LARGE TWO RINGS OVER ONE RING PUNCTUATION
10B3F LARGE ONE RING OVER TWO RINGS PUNCTUATION
10B40 INSCRIPTIONAL PARTHIAN LETTER ALEPH
10B41 INSCRIPTIONAL PARTHIAN LETTER BETH
10B42 INSCRIPTIONAL PARTHIAN LETTER GIMEL
10B43 INSCRIPTIONAL PARTHIAN LETTER DALETH
10B44 INSCRIPTIONAL PARTHIAN LETTER HE
10B45 INSCRIPTIONAL PARTHIAN LETTER WAW
10B46 INSCRIPTIONAL PARTHIAN LETTER ZAYIN
10B47 INSCRIPTIONAL PARTHIAN LETTER HETH
10B48 INSCRIPTIONAL PARTHIAN LETTER TETH
10B49 INSCRIPTIONAL PARTHIAN LETTER YODH
10B4A INSCRIPTIONAL PARTHIAN LETTER KAPH
10B4B INSCRIPTIONAL PARTHIAN LETTER LAMEDH
10B4C INSCRIPTIONAL PARTHIAN LETTER MEM
10B4D INSCRIPTIONAL PARTHIAN LETTER NUN
10B4E INSCRIPTIONAL PARTHIAN LETTER SAMEKH
10B4F INSCRIPTIONAL PARTHIAN LETTER AYIN
10B50 INSCRIPTIONAL PARTHIAN LETTER PE
10B51 INSCRIPTIONAL PARTHIAN LETTER SADHE
10B52 INSCRIPTIONAL PARTHIAN LETTER QOPH
10B53 INSCRIPTIONAL PARTHIAN LETTER RESH
10B54 INSCRIPTIONAL PARTHIAN LETTER SHIN
10B55 INSCRIPTIONAL PARTHIAN LETTER TAW
10B58 INSCRIPTIONAL PARTHIAN NUMBER ONE
10B59 INSCRIPTIONAL PARTHIAN NUMBER TWO
10B5A INSCRIPTIONAL PARTHIAN NUMBER THREE
10B5B INSCRIPTIONAL PARTHIAN NUMBER FOUR
10B5C INSCRIPTIONAL PARTHIAN NUMBER TEN
10B5D INSCRIPTIONAL PARTHIAN NUMBER TWENTY
10B5E INSCRIPTIONAL PARTHIAN NUMBER ONE HUNDRED
10B5F INSCRIPTIONAL PARTHIAN NUMBER ONE THOUSAND
10B60 INSCRIPTIONAL PAHLAVI LETTER ALEPH
10B61 INSCRIPTIONAL PAHLAVI LETTER BETH
10B62 INSCRIPTIONAL PAHLAVI LETTER GIMEL
10B63 INSCRIPTIONAL PAHLAVI LETTER DALETH
10B64 INSCRIPTIONAL PAHLAVI LETTER HE
10B65 INSCRIPTIONAL PAHLAVI LETTER WAW-AYIN-RESH
10B66 INSCRIPTIONAL PAHLAVI LETTER ZAYIN
10B67 INSCRIPTIONAL PAHLAVI LETTER HETH
10B68 INSCRIPTIONAL PAHLAVI LETTER TETH
10B69 INSCRIPTIONAL PAHLAVI LETTER YODH
10B6A INSCRIPTIONAL PAHLAVI LETTER KAPH
10B6B INSCRIPTIONAL PAHLAVI LETTER LAMEDH
10B6C INSCRIPTIONAL PAHLAVI LETTER MEM-QOPH
10B6D INSCRIPTIONAL PAHLAVI LETTER NUN
10B6E INSCRIPTIONAL PAHLAVI LETTER SAMEKH
10B6F INSCRIPTIONAL PAHLAVI LETTER PE
10B70 INSCRIPTIONAL PAHLAVI LETTER SADHE
10B71 INSCRIPTIONAL PAHLAVI LETTER SHIN
10B72 INSCRIPTIONAL PAHLAVI LETTER TAW
10B78 INSCRIPTIONAL PAHLAVI NUMBER ONE
10B79 INSCRIPTIONAL PAHLAVI NUMBER TWO
10B7A INSCRIPTIONAL PAHLAVI NUMBER THREE
10B7B INSCRIPTIONAL PAHLAVI NUMBER FOUR
10B7C INSCRIPTIONAL PAHLAVI NUMBER TEN
10B7D INSCRIPTIONAL PAHLAVI NUMBER TWENTY
10B7E INSCRIPTIONAL PAHLAVI NUMBER ONE HUNDRED
10B7F INSCRIPTIONAL PAHLAVI NUMBER ONE THOUSAND
10B80 PSALTER PAHLAVI LETTER ALEPH
10B81 PSALTER PAHLAVI LETTER BETH
10B82 PSALTER PAHLAVI LETTER GIMEL
10B83 PSALTER PAHLAVI LETTER DALETH
10B84 PSALTER PAHLAVI LETTER HE
10B85 PSALTER PAHLAVI LETTER WAW-AYIN-RESH
10B86 PSALTER PAHLAVI LETTER ZAYIN
10B87 PSALTER PAHLAVI LETTER HETH
10B88 PSALTER PAHLAVI LETTER YODH
10B89 PSALTER PAHLAVI LETTER KAPH
10B8A PSALTER PAHLAVI LETTER LAMEDH
10B8B PSALTER PAHLAVI LETTER MEM-QOPH
10B8C PSALTER PAHLAVI LETTER NUN
10B8D PSALTER PAHLAVI LETTER SAMEKH
10B8E PSALTER PAHLAVI LETTER PE
10B8F PSALTER PAHLAVI LETTER SADHE
10B90 PSALTER PAHLAVI LETTER SHIN
10B91 PSALTER PAHLAVI LETTER TAW
10B99 PSALTER PAHLAVI SECTION MARK
10B9A PSALTER PAHLAVI TURNED SECTION MARK
10B9B PSALTER PAHLAVI FOUR DOTS WITH CROSS
10B9C PSALTER PAHLAVI FOUR DOTS WITH DOT
10BA9 PSALTER PAHLAVI NUMBER ONE
10BAA PSALTER PAHLAVI NUMBER TWO
10BAB PSALTER PAHLAVI NUMBER THREE
10BAC PSALTER PAHLAVI NUMBER FOUR
10BAD PSALTER PAHLAVI NUMBER TEN
10BAE PSALTER PAHLAVI NUMBER TWENTY
10BAF PSALTER PAHLAVI NUMBER ONE HUNDRED
10C00 OLD TURKIC LETTER ORKHON A
10C01 OLD TURKIC LETTER YENISEI A
10C02 OLD TURKIC LETTER YENISEI AE
10C03 OLD TURKIC LETTER ORKHON I
10C04 OLD TURKIC LETTER YENISEI I
10C05 OLD TURKIC LETTER YENISEI E
10C06 OLD TURKIC LETTER ORKHON O
10C07 OLD TURKIC LETTER ORKHON OE
10C08 OLD TURKIC LETTER YENISEI OE
10C09 OLD TURKIC LETTER ORKHON AB
10C0A OLD TURKIC LETTER YENISEI AB
10C0B OLD TURKIC LETTER ORKHON AEB
10C0C OLD TURKIC LETTER YENISEI AEB
10C0D OLD TURKIC LETTER ORKHON AG
10C0E OLD TURKIC LETTER YENISEI AG
10C0F OLD TURKIC LETTER ORKHON AEG
10C10 OLD TURKIC LETTER YENISEI AEG
10C11 OLD TURKIC LETTER ORKHON AD
10C12 OLD TURKIC LETTER YENISEI AD
10C13 OLD TURKIC LETTER ORKHON AED
10C14 OLD TURKIC LETTER ORKHON EZ
10C15 OLD TURKIC LETTER YENISEI EZ
10C16 OLD TURKIC LETTER ORKHON AY
10C17 OLD TURKIC LETTER YENISEI AY
10C18 OLD TURKIC LETTER ORKHON AEY
10C19 OLD TURKIC LETTER YENISEI AEY
10C1A OLD TURKIC LETTER ORKHON AEK
10C1B OLD TURKIC LETTER YENISEI AEK
10C1C OLD TURKIC LETTER ORKHON OEK
10C1D OLD TURKIC LETTER YENISEI OEK
10C1E OLD TURKIC LETTER ORKHON AL
10C1F OLD TURKIC LETTER YENISEI AL
10C20 OLD TURKIC LETTER ORKHON AEL
10C21 OLD TURKIC LETTER ORKHON ELT
10C22 OLD TURKIC LETTER ORKHON EM
10C23 OLD TURKIC LETTER ORKHON AN
10C24 OLD TURKIC LETTER ORKHON AEN
10C25 OLD TURKIC LETTER YENISEI AEN
10C26 OLD TURKIC LETTER ORKHON ENT
10C27 OLD TURKIC LETTER YENISEI ENT
10C28 OLD TURKIC LETTER ORKHON ENC
10C29 OLD TURKIC LETTER YENISEI ENC
10C2A OLD TURKIC LETTER ORKHON ENY
10C2B OLD TURKIC LETTER YENISEI ENY
10C2C OLD TURKIC LETTER YENISEI ANG
10C2D OLD TURKIC LETTER ORKHON ENG
10C2E OLD TURKIC LETTER YENISEI AENG
10C2F OLD TURKIC LETTER ORKHON EP
10C30 OLD TURKIC LETTER ORKHON OP
10C31 OLD TURKIC LETTER ORKHON IC
10C32 OLD TURKIC LETTER ORKHON EC
10C33 OLD TURKIC LETTER YENISEI EC
10C34 OLD TURKIC LETTER ORKHON AQ
10C35 OLD TURKIC LETTER YENISEI AQ
10C36 OLD TURKIC LETTER ORKHON IQ
10C37 OLD TURKIC LETTER YENISEI IQ
10C38 OLD TURKIC LETTER ORKHON OQ
10C39 OLD TURKIC LETTER YENISEI OQ
10C3A OLD TURKIC LETTER ORKHON AR
10C3B OLD TURKIC LETTER YENISEI AR
10C3C OLD TURKIC LETTER ORKHON AER
10C3D OLD TURKIC LETTER ORKHON AS
10C3E OLD TURKIC LETTER ORKHON AES
10C3F OLD TURKIC LETTER ORKHON ASH
10C40 OLD TURKIC LETTER YENISEI ASH
10C41 OLD TURKIC LETTER ORKHON ESH
10C42 OLD TURKIC LETTER YENISEI ESH
10C43 OLD TURKIC LETTER ORKHON AT
10C44 OLD TURKIC LETTER YENISEI AT
10C45 OLD TURKIC LETTER ORKHON AET
10C46 OLD TURKIC LETTER YENISEI AET
10C47 OLD TURKIC LETTER ORKHON OT
10C48 OLD TURKIC LETTER ORKHON BASH
10C80 OLD HUNGARIAN CAPITAL LETTER A
10C81 OLD HUNGARIAN CAPITAL LETTER AA
10C82 OLD HUNGARIAN CAPITAL LETTER EB
10C83 OLD HUNGARIAN CAPITAL LETTER AMB
10C84 OLD HUNGARIAN CAPITAL LETTER EC
10C85 OLD HUNGARIAN CAPITAL LETTER ENC
10C86 OLD HUNGARIAN CAPITAL LETTER ECS
10C87 OLD HUNGARIAN CAPITAL LETTER ED
10C88 OLD HUNGARIAN CAPITAL LETTER AND
10C89 OLD HUNGARIAN CAPITAL LETTER E
10C8A OLD HUNGARIAN CAPITAL LETTER CLOSE E
10C8B OLD HUNGARIAN CAPITAL LETTER EE
10C8C OLD HUNGARIAN CAPITAL LETTER EF
10C8D OLD HUNGARIAN CAPITAL LETTER EG
10C8E OLD HUNGARIAN CAPITAL LETTER EGY
10C8F OLD HUNGARIAN CAPITAL LETTER EH
10C90 OLD HUNGARIAN CAPITAL LETTER I
10C91 OLD HUNGARIAN CAPITAL LETTER II
10C92 OLD HUNGARIAN CAPITAL LETTER EJ
10C93 OLD HUNGARIAN CAPITAL LETTER EK
10C94 OLD HUNGARIAN CAPITAL LETTER AK
10C95 OLD HUNGARIAN CAPITAL LETTER UNK
10C96 OLD HUNGARIAN CAPITAL LETTER EL
10C97 OLD HUNGARIAN CAPITAL LETTER ELY
10C98 OLD HUNGARIAN CAPITAL LETTER EM
10C99 OLD HUNGARIAN CAPITAL LETTER EN
10C9A OLD HUNGARIAN CAPITAL LETTER ENY
10C9B OLD HUNGARIAN CAPITAL LETTER O
10C9C OLD HUNGARIAN CAPITAL LETTER OO
10C9D OLD HUNGARIAN CAPITAL LETTER NIKOLSBURG OE
10C9E OLD HUNGARIAN CAPITAL LETTER RUDIMENTA OE
10C9F OLD HUNGARIAN CAPITAL LETTER OEE
10CA0 OLD HUNGARIAN CAPITAL LETTER EP
10CA1 OLD HUNGARIAN CAPITAL LETTER EMP
10CA2 OLD HUNGARIAN CAPITAL LETTER ER
10CA3 OLD HUNGARIAN CAPITAL LETTER SHORT ER
10CA4 OLD HUNGARIAN CAPITAL LETTER ES
10CA5 OLD HUNGARIAN CAPITAL LETTER ESZ
10CA6 OLD HUNGARIAN CAPITAL LETTER ET
10CA7 OLD HUNGARIAN CAPITAL LETTER ENT
10CA8 OLD HUNGARIAN CAPITAL LETTER ETY
10CA9 OLD HUNGARIAN CAPITAL LETTER ECH
10CAA OLD HUNGARIAN CAPITAL LETTER U
10CAB OLD HUNGARIAN CAPITAL LETTER UU
10CAC OLD HUNGARIAN CAPITAL LETTER NIKOLSBURG UE
10CAD OLD HUNGARIAN CAPITAL LETTER RUDIMENTA UE
10CAE OLD HUNGARIAN CAPITAL LETTER EV
10CAF OLD HUNGARIAN CAPITAL LETTER EZ
10CB0 OLD HUNGARIAN CAPITAL LETTER EZS
10CB1 OLD HUNGARIAN CAPITAL LETTER ENT-SHAPED SIGN
10CB2 OLD HUNGARIAN CAPITAL LETTER US
10CC0 OLD HUNGARIAN SMALL LETTER A
10CC1 OLD HUNGARIAN SMALL LETTER AA
10CC2 OLD HUNGARIAN SMALL LETTER EB
10CC3 OLD HUNGARIAN SMALL LETTER AMB
10CC4 OLD HUNGARIAN SMALL LETTER EC
10CC5 OLD HUNGARIAN SMALL LETTER ENC
10CC6 OLD HUNGARIAN SMALL LETTER ECS
10CC7 OLD HUNGARIAN SMALL LETTER ED
10CC8 OLD HUNGARIAN SMALL LETTER AND
10CC9 OLD HUNGARIAN SMALL LETTER E
10CCA OLD HUNGARIAN SMALL LETTER CLOSE E
10CCB OLD HUNGARIAN SMALL LETTER EE
10CCC OLD HUNGARIAN SMALL LETTER EF
10CCD OLD HUNGARIAN SMALL LETTER EG
10CCE OLD HUNGARIAN SMALL LETTER EGY
10CCF OLD HUNGARIAN SMALL LETTER EH
10CD0 OLD HUNGARIAN SMALL LETTER I
10CD1 OLD HUNGARIAN SMALL LETTER II
10CD2 OLD HUNGARIAN SMALL LETTER EJ
10CD3 OLD HUNGARIAN SMALL LETTER EK
10CD4 OLD HUNGARIAN SMALL LETTER AK
10CD5 OLD HUNGARIAN SMALL LETTER UNK
10CD6 OLD HUNGARIAN SMALL LETTER EL
10CD7 OLD HUNGARIAN SMALL LETTER ELY
10CD8 OLD HUNGARIAN SMALL LETTER EM
10CD9 OLD HUNGARIAN SMALL LETTER EN
10CDA OLD HUNGARIAN SMALL LETTER ENY
10CDB OLD HUNGARIAN SMALL LETTER O
10CDC OLD HUNGARIAN SMALL LETTER OO
10CDD OLD HUNGARIAN SMALL LETTER NIKOLSBURG OE
10CDE OLD HUNGARIAN SMALL LETTER RUDIMENTA OE
10CDF OLD HUNGARIAN SMALL LETTER OEE
10CE0 OLD HUNGARIAN SMALL LETTER EP
10CE1 OLD HUNGARIAN SMALL LETTER EMP
10CE2 OLD HUNGARIAN SMALL LETTER ER
10CE3 OLD HUNGARIAN SMALL LETTER SHORT ER
10CE4 OLD HUNGARIAN SMALL LETTER ES
10CE5 OLD HUNGARIAN SMALL LETTER ESZ
10CE6 OLD HUNGARIAN SMALL LETTER ET
10CE7 OLD HUNGARIAN SMALL LETTER ENT
10CE8 OLD HUNGARIAN SMALL LETTER ETY
10CE9 OLD HUNGARIAN SMALL LETTER ECH
10CEA OLD HUNGARIAN SMALL LETTER U
10CEB OLD HUNGARIAN SMALL LETTER UU
10CEC OLD HUNGARIAN SMALL LETTER NIKOLSBURG UE
10CED OLD HUNGARIAN SMALL LETTER RUDIMENTA UE
10CEE OLD HUNGARIAN SMALL LETTER EV
10CEF OLD HUNGARIAN SMALL LETTER EZ
10CF0 OLD HUNGARIAN SMALL LETTER EZS
10CF1 OLD HUNGARIAN SMALL LETTER ENT-SHAPED SIGN
10CF2 OLD HUNGARIAN SMALL LETTER US
10CFA OLD HUNGARIAN NUMBER ONE
10CFB OLD HUNGARIAN NUMBER FIVE
10CFC OLD HUNGARIAN NUMBER TEN
10CFD OLD HUNGARIAN NUMBER FIFTY
10CFE OLD HUNGARIAN NUMBER ONE HUNDRED
10CFF OLD HUNGARIAN NUMBER ONE THOUSAND
10E60 RUMI DIGIT ONE
10E61 RUMI DIGIT TWO
10E62 RUMI DIGIT THREE
10E63 RUMI DIGIT FOUR
10E64 RUMI DIGIT FIVE
10E65 RUMI DIGIT SIX
10E66 RUMI DIGIT SEVEN
10E67 RUMI DIGIT EIGHT
10E68 RUMI DIGIT NINE
10E69 RUMI NUMBER TEN
10E6A RUMI NUMBER TWENTY
10E6B RUMI NUMBER THIRTY
10E6C RUMI NUMBER FORTY
10E6D RUMI NUMBER FIFTY
10E6E RUMI NUMBER SIXTY
10E6F RUMI NUMBER SEVENTY
10E70 RUMI NUMBER EIGHTY
10E71 RUMI NUMBER NINETY
10E72 RUMI NUMBER ONE HUNDRED
10E73 RUMI NUMBER TWO HUNDRED
10E74 RUMI NUMBER THREE HUNDRED
10E75 RUMI NUMBER FOUR HUNDRED
10E76 RUMI NUMBER FIVE HUNDRED
10E77 RUMI NUMBER SIX HUNDRED
10E78 RUMI NUMBER SEVEN HUNDRED
10E79 RUMI NUMBER EIGHT HUNDRED
10E7A RUMI NUMBER NINE HUNDRED
10E7B RUMI FRACTION ONE HALF
10E7C RUMI FRACTION ONE QUARTER
10E7D RUMI FRACTION ONE THIRD
10E7E RUMI FRACTION TWO THIRDS
11000 BRAHMI SIGN CANDRABINDU
11001 BRAHMI SIGN ANUSVARA
11002 BRAHMI SIGN VISARGA
11003 BRAHMI SIGN JIHVAMULIYA
11004 BRAHMI SIGN UPADHMANIYA
11005 BRAHMI LETTER A
11006 BRAHMI LETTER AA
11007 BRAHMI LETTER I
11008 BRAHMI LETTER II
11009 BRAHMI LETTER U
1100A BRAHMI LETTER UU
1100B BRAHMI LETTER VOCALIC R
1100C BRAHMI LETTER VOCALIC RR
1100D BRAHMI LETTER VOCALIC L
1100E BRAHMI LETTER VOCALIC LL
1100F BRAHMI LETTER E
11010 BRAHMI LETTER AI
11011 BRAHMI LETTER O
11012 BRAHMI LETTER AU
11013 BRAHMI LETTER KA
11014 BRAHMI LETTER KHA
11015 BRAHMI LETTER GA
11016 BRAHMI LETTER GHA
11017 BRAHMI LETTER NGA
11018 BRAHMI LETTER CA
11019 BRAHMI LETTER CHA
1101A BRAHMI LETTER JA
1101B BRAHMI LETTER JHA
1101C BRAHMI LETTER NYA
1101D BRAHMI LETTER TTA
1101E BRAHMI LETTER TTHA
1101F BRAHMI LETTER DDA
11020 BRAHMI LETTER DDHA
11021 BRAHMI LETTER NNA
11022 BRAHMI LETTER TA
11023 BRAHMI LETTER THA
11024 BRAHMI LETTER DA
11025 BRAHMI LETTER DHA
11026 BRAHMI LETTER NA
11027 BRAHMI LETTER PA
11028 BRAHMI LETTER PHA
11029 BRAHMI LETTER BA
1102A BRAHMI LETTER BHA
1102B BRAHMI LETTER MA
1102C BRAHMI LETTER YA
1102D BRAHMI LETTER RA
1102E BRAHMI LETTER LA
1102F BRAHMI LETTER VA
11030 BRAHMI LETTER SHA
11031 BRAHMI LETTER SSA
11032 BRAHMI LETTER SA
11033 BRAHMI LETTER HA
11034 BRAHMI LETTER LLA
11035 BRAHMI LETTER OLD TAMIL LLLA
11036 BRAHMI LETTER OLD TAMIL RRA
11037 BRAHMI LETTER OLD TAMIL NNNA
11038 BRAHMI VOWEL SIGN AA
11039 BRAHMI VOWEL SIGN BHATTIPROLU AA
1103A BRAHMI VOWEL SIGN I
1103B BRAHMI VOWEL SIGN II
1103C BRAHMI VOWEL SIGN U
1103D BRAHMI VOWEL SIGN UU
1103E BRAHMI VOWEL SIGN VOCALIC R
1103F BRAHMI VOWEL SIGN VOCALIC RR
11040 BRAHMI VOWEL SIGN VOCALIC L
11041 BRAHMI VOWEL SIGN VOCALIC LL
11042 BRAHMI VOWEL SIGN E
11043 BRAHMI VOWEL SIGN AI
11044 BRAHMI VOWEL SIGN O
11045 BRAHMI VOWEL SIGN AU
11046 BRAHMI VIRAMA
11047 BRAHMI DANDA
11048 BRAHMI DOUBLE DANDA
11049 BRAHMI PUNCTUATION DOT
1104A BRAHMI PUNCTUATION DOUBLE DOT
1104B BRAHMI PUNCTUATION LINE
1104C BRAHMI PUNCTUATION CRESCENT BAR
1104D BRAHMI PUNCTUATION LOTUS
11052 BRAHMI NUMBER ONE
11053 BRAHMI NUMBER TWO
11054 BRAHMI NUMBER THREE
11055 BRAHMI NUMBER FOUR
11056 BRAHMI NUMBER FIVE
11057 BRAHMI NUMBER SIX
11058 BRAHMI NUMBER SEVEN
11059 BRAHMI NUMBER EIGHT
1105A BRAHMI NUMBER NINE
1105B BRAHMI NUMBER TEN
1105C BRAHMI NUMBER TWENTY
1105D BRAHMI NUMBER THIRTY
1105E BRAHMI NUMBER FORTY
1105F BRAHMI NUMBER FIFTY
11060 BRAHMI NUMBER SIXTY
11061 BRAHMI NUMBER SEVENTY
11062 BRAHMI NUMBER EIGHTY
11063 BRAHMI NUMBER NINETY
11064 BRAHMI NUMBER ONE HUNDRED
11065 BRAHMI NUMBER ONE THOUSAND
11066 BRAHMI DIGIT ZERO
11067 BRAHMI DIGIT ONE
11068 BRAHMI DIGIT TWO
11069 BRAHMI DIGIT THREE
1106A BRAHMI DIGIT FOUR
1106B BRAHMI DIGIT FIVE
1106C BRAHMI DIGIT SIX
1106D BRAHMI DIGIT SEVEN
1106E BRAHMI DIGIT EIGHT
1106F BRAHMI DIGIT NINE
1107F BRAHMI NUMBER JOINER
11080 KAITHI SIGN CANDRABINDU
11081 KAITHI SIGN ANUSVARA
11082 KAITHI SIGN VISARGA
11083 KAITHI LETTER A
11084 KAITHI LETTER AA
11085 KAITHI LETTER I
11086 KAITHI LETTER II
11087 KAITHI LETTER U
11088 KAITHI LETTER UU
11089 KAITHI LETTER E
1108A KAITHI LETTER AI
1108B KAITHI LETTER O
1108C KAITHI LETTER AU
1108D KAITHI LETTER KA
1108E KAITHI LETTER KHA
1108F KAITHI LETTER GA
11090 KAITHI LETTER GHA
11091 KAITHI LETTER NGA
11092 KAITHI LETTER CA
11093 KAITHI LETTER CHA
11094 KAITHI LETTER JA
11095 KAITHI LETTER JHA
11096 KAITHI LETTER NYA
11097 KAITHI LETTER TTA
11098 KAITHI LETTER TTHA
11099 KAITHI LETTER DDA
1109A KAITHI LETTER DDDHA
1109B KAITHI LETTER DDHA
1109C KAITHI LETTER RHA
1109D KAITHI LETTER NNA
1109E KAITHI LETTER TA
1109F KAITHI LETTER THA
110A0 KAITHI LETTER DA
110A1 KAITHI LETTER DHA
110A2 KAITHI LETTER NA
110A3 KAITHI LETTER PA
110A4 KAITHI LETTER PHA
110A5 KAITHI LETTER BA
110A6 KAITHI LETTER BHA
110A7 KAITHI LETTER MA
110A8 KAITHI LETTER YA
110A9 KAITHI LETTER RA
110AA KAITHI LETTER LA
110AB KAITHI LETTER VA
110AC KAITHI LETTER SHA
110AD KAITHI LETTER SSA
110AE KAITHI LETTER SA
110AF KAITHI LETTER HA
110B0 KAITHI VOWEL SIGN AA
110B1 KAITHI VOWEL SIGN I
110B2 KAITHI VOWEL SIGN II
110B3 KAITHI VOWEL SIGN U
110B4 KAITHI VOWEL SIGN UU
110B5 KAITHI VOWEL SIGN E
110B6 KAITHI VOWEL SIGN AI
110B7 KAITHI VOWEL SIGN O
110B8 KAITHI VOWEL SIGN AU
110B9 KAITHI SIGN VIRAMA
110BA KAITHI SIGN NUKTA
110BB KAITHI ABBREVIATION SIGN
110BC KAITHI ENUMERATION SIGN
110BD KAITHI NUMBER SIGN
110BE KAITHI SECTION MARK
110BF KAITHI DOUBLE SECTION MARK
110C0 KAITHI DANDA
110C1 KAITHI DOUBLE DANDA
110D0 SORA SOMPENG LETTER SAH
110D1 SORA SOMPENG LETTER TAH
110D2 SORA SOMPENG LETTER BAH
110D3 SORA SOMPENG LETTER CAH
110D4 SORA SOMPENG LETTER DAH
110D5 SORA SOMPENG LETTER GAH
110D6 SORA SOMPENG LETTER MAH
110D7 SORA SOMPENG LETTER NGAH
110D8 SORA SOMPENG LETTER LAH
110D9 SORA SOMPENG LETTER NAH
110DA SORA SOMPENG LETTER VAH
110DB SORA SOMPENG LETTER PAH
110DC SORA SOMPENG LETTER YAH
110DD SORA SOMPENG LETTER RAH
110DE SORA SOMPENG LETTER HAH
110DF SORA SOMPENG LETTER KAH
110E0 SORA SOMPENG LETTER JAH
110E1 SORA SOMPENG LETTER NYAH
110E2 SORA SOMPENG LETTER AH
110E3 SORA SOMPENG LETTER EEH
110E4 SORA SOMPENG LETTER IH
110E5 SORA SOMPENG LETTER UH
110E6 SORA SOMPENG LETTER OH
110E7 SORA SOMPENG LETTER EH
110E8 SORA SOMPENG LETTER MAE
110F0 SORA SOMPENG DIGIT ZERO
110F1 SORA SOMPENG DIGIT ONE
110F2 SORA SOMPENG DIGIT TWO
110F3 SORA SOMPENG DIGIT THREE
110F4 SORA SOMPENG DIGIT FOUR
110F5 SORA SOMPENG DIGIT FIVE
110F6 SORA SOMPENG DIGIT SIX
110F7 SORA SOMPENG DIGIT SEVEN
110F8 SORA SOMPENG DIGIT EIGHT
110F9 SORA SOMPENG DIGIT NINE
11100 CHAKMA SIGN CANDRABINDU
11101 CHAKMA SIGN ANUSVARA
11102 CHAKMA SIGN VISARGA
11103 CHAKMA LETTER AA
11104 CHAKMA LETTER I
11105 CHAKMA LETTER U
11106 CHAKMA LETTER E
11107 CHAKMA LETTER KAA
11108 CHAKMA LETTER KHAA
11109 CHAKMA LETTER GAA
1110A CHAKMA LETTER GHAA
1110B CHAKMA LETTER NGAA
1110C CHAKMA LETTER CAA
1110D CHAKMA LETTER CHAA
1110E CHAKMA LETTER JAA
1110F CHAKMA LETTER JHAA
11110 CHAKMA LETTER NYAA
11111 CHAKMA LETTER TTAA
11112 CHAKMA LETTER TTHAA
11113 CHAKMA LETTER DDAA
11114 CHAKMA LETTER DDHAA
11115 CHAKMA LETTER NNAA
11116 CHAKMA LETTER TAA
11117 CHAKMA LETTER THAA
11118 CHAKMA LETTER DAA
11119 CHAKMA LETTER DHAA
1111A CHAKMA LETTER NAA
1111B CHAKMA LETTER PAA
1111C CHAKMA LETTER PHAA
1111D CHAKMA LETTER BAA
1111E CHAKMA LETTER BHAA
1111F CHAKMA LETTER MAA
11120 CHAKMA LETTER YYAA
11121 CHAKMA LETTER YAA
11122 CHAKMA LETTER RAA
11123 CHAKMA LETTER LAA
11124 CHAKMA LETTER WAA
11125 CHAKMA LETTER SAA
11126 CHAKMA LETTER HAA
11127 CHAKMA VOWEL SIGN A
11128 CHAKMA VOWEL SIGN I
11129 CHAKMA VOWEL SIGN II
1112A CHAKMA VOWEL SIGN U
1112B CHAKMA VOWEL SIGN UU
1112C CHAKMA VOWEL SIGN E
1112D CHAKMA VOWEL SIGN AI
1112E CHAKMA VOWEL SIGN O
1112F CHAKMA VOWEL SIGN AU
11130 CHAKMA VOWEL SIGN OI
11131 CHAKMA O MARK
11132 CHAKMA AU MARK
11133 CHAKMA VIRAMA
11134 CHAKMA MAAYYAA
11136 CHAKMA DIGIT ZERO
11137 CHAKMA DIGIT ONE
11138 CHAKMA DIGIT TWO
11139 CHAKMA DIGIT THREE
1113A CHAKMA DIGIT FOUR
1113B CHAKMA DIGIT FIVE
1113C CHAKMA DIGIT SIX
1113D CHAKMA DIGIT SEVEN
1113E CHAKMA DIGIT EIGHT
1113F CHAKMA DIGIT NINE
11140 CHAKMA SECTION MARK
11141 CHAKMA DANDA
11142 CHAKMA DOUBLE DANDA
11143 CHAKMA QUESTION MARK
11150 MAHAJANI LETTER A
11151 MAHAJANI LETTER I
11152 MAHAJANI LETTER U
11153 MAHAJANI LETTER E
11154 MAHAJANI LETTER O
11155 MAHAJANI LETTER KA
11156 MAHAJANI LETTER KHA
11157 MAHAJANI LETTER GA
11158 MAHAJANI LETTER GHA
11159 MAHAJANI LETTER CA
1115A MAHAJANI LETTER CHA
1115B MAHAJANI LETTER JA
1115C MAHAJANI LETTER JHA
1115D MAHAJANI LETTER NYA
1115E MAHAJANI LETTER TTA
1115F MAHAJANI LETTER TTHA
11160 MAHAJANI LETTER DDA
11161 MAHAJANI LETTER DDHA
11162 MAHAJANI LETTER NNA
11163 MAHAJANI LETTER TA
11164 MAHAJANI LETTER THA
11165 MAHAJANI LETTER DA
11166 MAHAJANI LETTER DHA
11167 MAHAJANI LETTER NA
11168 MAHAJANI LETTER PA
11169 MAHAJANI LETTER PHA
1116A MAHAJANI LETTER BA
1116B MAHAJANI LETTER BHA
1116C MAHAJANI LETTER MA
1116D MAHAJANI LETTER RA
1116E MAHAJANI LETTER LA
1116F MAHAJANI LETTER VA
11170 MAHAJANI LETTER SA
11171 MAHAJANI LETTER HA
11172 MAHAJANI LETTER RRA
11173 MAHAJANI SIGN NUKTA
11174 MAHAJANI ABBREVIATION SIGN
11175 MAHAJANI SECTION MARK
11176 MAHAJANI LIGATURE SHRI
11180 SHARADA SIGN CANDRABINDU
11181 SHARADA SIGN ANUSVARA
11182 SHARADA SIGN VISARGA
11183 SHARADA LETTER A
11184 SHARADA LETTER AA
11185 SHARADA LETTER I
11186 SHARADA LETTER II
11187 SHARADA LETTER U
11188 SHARADA LETTER UU
11189 SHARADA LETTER VOCALIC R
1118A SHARADA LETTER VOCALIC RR
1118B SHARADA LETTER VOCALIC L
1118C SHARADA LETTER VOCALIC LL
1118D SHARADA LETTER E
1118E SHARADA LETTER AI
1118F SHARADA LETTER O
11190 SHARADA LETTER AU
11191 SHARADA LETTER KA
11192 SHARADA LETTER KHA
11193 SHARADA LETTER GA
11194 SHARADA LETTER GHA
11195 SHARADA LETTER NGA
11196 SHARADA LETTER CA
11197 SHARADA LETTER CHA
11198 SHARADA LETTER JA
11199 SHARADA LETTER JHA
1119A SHARADA LETTER NYA
1119B SHARADA LETTER TTA
1119C SHARADA LETTER TTHA
1119D SHARADA LETTER DDA
1119E SHARADA LETTER DDHA
1119F SHARADA LETTER NNA
111A0 SHARADA LETTER TA
111A1 SHARADA LETTER THA
111A2 SHARADA LETTER DA
111A3 SHARADA LETTER DHA
111A4 SHARADA LETTER NA
111A5 SHARADA LETTER PA
111A6 SHARADA LETTER PHA
111A7 SHARADA LETTER BA
111A8 SHARADA LETTER BHA
111A9 SHARADA LETTER MA
111AA SHARADA LETTER YA
111AB SHARADA LETTER RA
111AC SHARADA LETTER LA
111AD SHARADA LETTER LLA
111AE SHARADA LETTER VA
111AF SHARADA LETTER SHA
111B0 SHARADA LETTER SSA
111B1 SHARADA LETTER SA
111B2 SHARADA LETTER HA
111B3 SHARADA VOWEL SIGN AA
111B4 SHARADA VOWEL SIGN I
111B5 SHARADA VOWEL SIGN II
111B6 SHARADA VOWEL SIGN U
111B7 SHARADA VOWEL SIGN UU
111B8 SHARADA VOWEL SIGN VOCALIC R
111B9 SHARADA VOWEL SIGN VOCALIC RR
111BA SHARADA VOWEL SIGN VOCALIC L
111BB SHARADA VOWEL SIGN VOCALIC LL
111BC SHARADA VOWEL SIGN E
111BD SHARADA VOWEL SIGN AI
111BE SHARADA VOWEL SIGN O
111BF SHARADA VOWEL SIGN AU
111C0 SHARADA SIGN VIRAMA
111C1 SHARADA SIGN AVAGRAHA
111C2 SHARADA SIGN JIHVAMULIYA
111C3 SHARADA SIGN UPADHMANIYA
111C4 SHARADA OM
111C5 SHARADA DANDA
111C6 SHARADA DOUBLE DANDA
111C7 SHARADA ABBREVIATION SIGN
111C8 SHARADA SEPARATOR
111C9 SHARADA SANDHI MARK
111CA SHARADA SIGN NUKTA
111CB SHARADA VOWEL MODIFIER MARK
111CC SHARADA EXTRA SHORT VOWEL MARK
111CD SHARADA SUTRA MARK
111D0 SHARADA DIGIT ZERO
111D1 SHARADA DIGIT ONE
111D2 SHARADA DIGIT TWO
111D3 SHARADA DIGIT THREE
111D4 SHARADA DIGIT FOUR
111D5 SHARADA DIGIT FIVE
111D6 SHARADA DIGIT SIX
111D7 SHARADA DIGIT SEVEN
111D8 SHARADA DIGIT EIGHT
111D9 SHARADA DIGIT NINE
111DA SHARADA EKAM
111DB SHARADA SIGN SIDDHAM
111DC SHARADA HEADSTROKE
111DD SHARADA CONTINUATION SIGN
111DE SHARADA SECTION MARK-1
111DF SHARADA SECTION MARK-2
111E1 SINHALA ARCHAIC DIGIT ONE
111E2 SINHALA ARCHAIC DIGIT TWO
111E3 SINHALA ARCHAIC DIGIT THREE
111E4 SINHALA ARCHAIC DIGIT FOUR
111E5 SINHALA ARCHAIC DIGIT FIVE
111E6 SINHALA ARCHAIC DIGIT SIX
111E7 SINHALA ARCHAIC DIGIT SEVEN
111E8 SINHALA ARCHAIC DIGIT EIGHT
111E9 SINHALA ARCHAIC DIGIT NINE
111EA SINHALA ARCHAIC NUMBER TEN
111EB SINHALA ARCHAIC NUMBER TWENTY
111EC SINHALA ARCHAIC NUMBER THIRTY
111ED SINHALA ARCHAIC NUMBER FORTY
111EE SINHALA ARCHAIC NUMBER FIFTY
111EF SINHALA ARCHAIC NUMBER SIXTY
111F0 SINHALA ARCHAIC NUMBER SEVENTY
111F1 SINHALA ARCHAIC NUMBER EIGHTY
111F2 SINHALA ARCHAIC NUMBER NINETY
111F3 SINHALA ARCHAIC NUMBER ONE HUNDRED
111F4 SINHALA ARCHAIC NUMBER ONE THOUSAND
11200 KHOJKI LETTER A
11201 KHOJKI LETTER AA
11202 KHOJKI LETTER I
11203 KHOJKI LETTER U
11204 KHOJKI LETTER E
11205 KHOJKI LETTER AI
11206 KHOJKI LETTER O
11207 KHOJKI LETTER AU
11208 KHOJKI LETTER KA
11209 KHOJKI LETTER KHA
1120A KHOJKI LETTER GA
1120B KHOJKI LETTER GGA
1120C KHOJKI LETTER GHA
1120D KHOJKI LETTER NGA
1120E KHOJKI LETTER CA
1120F KHOJKI LETTER CHA
11210 KHOJKI LETTER JA
11211 KHOJKI LETTER JJA
11213 KHOJKI LETTER NYA
11214 KHOJKI LETTER TTA
11215 KHOJKI LETTER TTHA
11216 KHOJKI LETTER DDA
11217 KHOJKI LETTER DDHA
11218 KHOJKI LETTER NNA
11219 KHOJKI LETTER TA
1121A KHOJKI LETTER THA
1121B KHOJKI LETTER DA
1121C KHOJKI LETTER DDDA
1121D KHOJKI LETTER DHA
1121E KHOJKI LETTER NA
1121F KHOJKI LETTER PA
11220 KHOJKI LETTER PHA
11221 KHOJKI LETTER BA
11222 KHOJKI LETTER BBA
11223 KHOJKI LETTER BHA
11224 KHOJKI LETTER MA
11225 KHOJKI LETTER YA
11226 KHOJKI LETTER RA
11227 KHOJKI LETTER LA
11228 KHOJKI LETTER VA
11229 KHOJKI LETTER SA
1122A KHOJKI LETTER HA
1122B KHOJKI LETTER LLA
1122C KHOJKI VOWEL SIGN AA
1122D KHOJKI VOWEL SIGN I
1122E KHOJKI VOWEL SIGN II
1122F KHOJKI VOWEL SIGN U
11230 KHOJKI VOWEL SIGN E
11231 KHOJKI VOWEL SIGN AI
11232 KHOJKI VOWEL SIGN O
11233 KHOJKI VOWEL SIGN AU
11234 KHOJKI SIGN ANUSVARA
11235 KHOJKI SIGN VIRAMA
11236 KHOJKI SIGN NUKTA
11237 KHOJKI SIGN SHADDA
11238 KHOJKI DANDA
11239 KHOJKI DOUBLE DANDA
1123A KHOJKI WORD SEPARATOR
1123B KHOJKI SECTION MARK
1123C KHOJKI DOUBLE SECTION MARK
1123D KHOJKI ABBREVIATION SIGN
1123E KHOJKI SIGN SUKUN
11280 MULTANI LETTER A
11281 MULTANI LETTER I
11282 MULTANI LETTER U
11283 MULTANI LETTER E
11284 MULTANI LETTER KA
11285 MULTANI LETTER KHA
11286 MULTANI LETTER GA
11288 MULTANI LETTER GHA
1128A MULTANI LETTER CA
1128B MULTANI LETTER CHA
1128C MULTANI LETTER JA
1128D MULTANI LETTER JJA
1128F MULTANI LETTER NYA
11290 MULTANI LETTER TTA
11291 MULTANI LETTER TTHA
11292 MULTANI LETTER DDA
11293 MULTANI LETTER DDDA
11294 MULTANI LETTER DDHA
11295 MULTANI LETTER NNA
11296 MULTANI LETTER TA
11297 MULTANI LETTER THA
11298 MULTANI LETTER DA
11299 MULTANI LETTER DHA
1129A MULTANI LETTER NA
1129B MULTANI LETTER PA
1129C MULTANI LETTER PHA
1129D MULTANI LETTER BA
1129F MULTANI LETTER BHA
112A0 MULTANI LETTER MA
112A1 MULTANI LETTER YA
112A2 MULTANI LETTER RA
112A3 MULTANI LETTER LA
112A4 MULTANI LETTER VA
112A5 MULTANI LETTER SA
112A6 MULTANI LETTER HA
112A7 MULTANI LETTER RRA
112A8 MULTANI LETTER RHA
112A9 MULTANI SECTION MARK
112B0 KHUDAWADI LETTER A
112B1 KHUDAWADI LETTER AA
112B2 KHUDAWADI LETTER I
112B3 KHUDAWADI LETTER II
112B4 KHUDAWADI LETTER U
112B5 KHUDAWADI LETTER UU
112B6 KHUDAWADI LETTER E
112B7 KHUDAWADI LETTER AI
112B8 KHUDAWADI LETTER O
112B9 KHUDAWADI LETTER AU
112BA KHUDAWADI LETTER KA
112BB KHUDAWADI LETTER KHA
112BC KHUDAWADI LETTER GA
112BD KHUDAWADI LETTER GGA
112BE KHUDAWADI LETTER GHA
112BF KHUDAWADI LETTER NGA
112C0 KHUDAWADI LETTER CA
112C1 KHUDAWADI LETTER CHA
112C2 KHUDAWADI LETTER JA
112C3 KHUDAWADI LETTER JJA
112C4 KHUDAWADI LETTER JHA
112C5 KHUDAWADI LETTER NYA
112C6 KHUDAWADI LETTER TTA
112C7 KHUDAWADI LETTER TTHA
112C8 KHUDAWADI LETTER DDA
112C9 KHUDAWADI LETTER DDDA
112CA KHUDAWADI LETTER RRA
112CB KHUDAWADI LETTER DDHA
112CC KHUDAWADI LETTER NNA
112CD KHUDAWADI LETTER TA
112CE KHUDAWADI LETTER THA
112CF KHUDAWADI LETTER DA
112D0 KHUDAWADI LETTER DHA
112D1 KHUDAWADI LETTER NA
112D2 KHUDAWADI LETTER PA
112D3 KHUDAWADI LETTER PHA
112D4 KHUDAWADI LETTER BA
112D5 KHUDAWADI LETTER BBA
112D6 KHUDAWADI LETTER BHA
112D7 KHUDAWADI LETTER MA
112D8 KHUDAWADI LETTER YA
112D9 KHUDAWADI LETTER RA
112DA KHUDAWADI LETTER LA
112DB KHUDAWADI LETTER VA
112DC KHUDAWADI LETTER SHA
112DD KHUDAWADI LETTER SA
112DE KHUDAWADI LETTER HA
112DF KHUDAWADI SIGN ANUSVARA
112E0 KHUDAWADI VOWEL SIGN AA
112E1 KHUDAWADI VOWEL SIGN I
112E2 KHUDAWADI VOWEL SIGN II
112E3 KHUDAWADI VOWEL SIGN U
112E4 KHUDAWADI VOWEL SIGN UU
112E5 KHUDAWADI VOWEL SIGN E
112E6 KHUDAWADI VOWEL SIGN AI
112E7 KHUDAWADI VOWEL SIGN O
112E8 KHUDAWADI VOWEL SIGN AU
112E9 KHUDAWADI SIGN NUKTA
112EA KHUDAWADI SIGN VIRAMA
112F0 KHUDAWADI DIGIT ZERO
112F1 KHUDAWADI DIGIT ONE
112F2 KHUDAWADI DIGIT TWO
112F3 KHUDAWADI DIGIT THREE
112F4 KHUDAWADI DIGIT FOUR
112F5 KHUDAWADI DIGIT FIVE
112F6 KHUDAWADI DIGIT SIX
112F7 KHUDAWADI DIGIT SEVEN
112F8 KHUDAWADI DIGIT EIGHT
112F9 KHUDAWADI DIGIT NINE
11300 GRANTHA SIGN COMBINING ANUSVARA ABOVE
11301 GRANTHA SIGN CANDRABINDU
11302 GRANTHA SIGN ANUSVARA
11303 GRANTHA SIGN VISARGA
11305 GRANTHA LETTER A
11306 GRANTHA LETTER AA
11307 GRANTHA LETTER I
11308 GRANTHA LETTER II
11309 GRANTHA LETTER U
1130A GRANTHA LETTER UU
1130B GRANTHA LETTER VOCALIC R
1130C GRANTHA LETTER VOCALIC L
1130F GRANTHA LETTER EE
11310 GRANTHA LETTER AI
11313 GRANTHA LETTER OO
11314 GRANTHA LETTER AU
11315 GRANTHA LETTER KA
11316 GRANTHA LETTER KHA
11317 GRANTHA LETTER GA
11318 GRANTHA LETTER GHA
11319 GRANTHA LETTER NGA
1131A GRANTHA LETTER CA
1131B GRANTHA LETTER CHA
1131C GRANTHA LETTER JA
1131D GRANTHA LETTER JHA
1131E GRANTHA LETTER NYA
1131F GRANTHA LETTER TTA
11320 GRANTHA LETTER TTHA
11321 GRANTHA LETTER DDA
11322 GRANTHA LETTER DDHA
11323 GRANTHA LETTER NNA
11324 GRANTHA LETTER TA
11325 GRANTHA LETTER THA
11326 GRANTHA LETTER DA
11327 GRANTHA LETTER DHA
11328 GRANTHA LETTER NA
1132A GRANTHA LETTER PA
1132B GRANTHA LETTER PHA
1132C GRANTHA LETTER BA
1132D GRANTHA LETTER BHA
1132E GRANTHA LETTER MA
1132F GRANTHA LETTER YA
11330 GRANTHA LETTER RA
11332 GRANTHA LETTER LA
11333 GRANTHA LETTER LLA
11335 GRANTHA LETTER VA
11336 GRANTHA LETTER SHA
11337 GRANTHA LETTER SSA
11338 GRANTHA LETTER SA
11339 GRANTHA LETTER HA
1133C GRANTHA SIGN NUKTA
1133D GRANTHA SIGN AVAGRAHA
1133E GRANTHA VOWEL SIGN AA
1133F GRANTHA VOWEL SIGN I
11340 GRANTHA VOWEL SIGN II
11341 GRANTHA VOWEL SIGN U
11342 GRANTHA VOWEL SIGN UU
11343 GRANTHA VOWEL SIGN VOCALIC R
11344 GRANTHA VOWEL SIGN VOCALIC RR
11347 GRANTHA VOWEL SIGN EE
11348 GRANTHA VOWEL SIGN AI
1134B GRANTHA VOWEL SIGN OO
1134C GRANTHA VOWEL SIGN AU
1134D GRANTHA SIGN VIRAMA
11350 GRANTHA OM
11357 GRANTHA AU LENGTH MARK
1135D GRANTHA SIGN PLUTA
1135E GRANTHA LETTER VEDIC ANUSVARA
1135F GRANTHA LETTER VEDIC DOUBLE ANUSVARA
11360 GRANTHA LETTER VOCALIC RR
11361 GRANTHA LETTER VOCALIC LL
11362 GRANTHA VOWEL SIGN VOCALIC L
11363 GRANTHA VOWEL SIGN VOCALIC LL
11366 COMBINING GRANTHA DIGIT ZERO
11367 COMBINING GRANTHA DIGIT ONE
11368 COMBINING GRANTHA DIGIT TWO
11369 COMBINING GRANTHA DIGIT THREE
1136A COMBINING GRANTHA DIGIT FOUR
1136B COMBINING GRANTHA DIGIT FIVE
1136C COMBINING GRANTHA DIGIT SIX
11370 COMBINING GRANTHA LETTER A
11371 COMBINING GRANTHA LETTER KA
11372 COMBINING GRANTHA LETTER NA
11373 COMBINING GRANTHA LETTER VI
11374 COMBINING GRANTHA LETTER PA
11400 NEWA LETTER A
11401 NEWA LETTER AA
11402 NEWA LETTER I
11403 NEWA LETTER II
11404 NEWA LETTER U
11405 NEWA LETTER UU
11406 NEWA LETTER VOCALIC R
11407 NEWA LETTER VOCALIC RR
11408 NEWA LETTER VOCALIC L
11409 NEWA LETTER VOCALIC LL
1140A NEWA LETTER E
1140B NEWA LETTER AI
1140C NEWA LETTER O
1140D NEWA LETTER AU
1140E NEWA LETTER KA
1140F NEWA LETTER KHA
11410 NEWA LETTER GA
11411 NEWA LETTER GHA
11412 NEWA LETTER NGA
11413 NEWA LETTER NGHA
11414 NEWA LETTER CA
11415 NEWA LETTER CHA
11416 NEWA LETTER JA
11417 NEWA LETTER JHA
11418 NEWA LETTER NYA
11419 NEWA LETTER NYHA
1141A NEWA LETTER TTA
1141B NEWA LETTER TTHA
1141C NEWA LETTER DDA
1141D NEWA LETTER DDHA
1141E NEWA LETTER NNA
1141F NEWA LETTER TA
11420 NEWA LETTER THA
11421 NEWA LETTER DA
11422 NEWA LETTER DHA
11423 NEWA LETTER NA
11424 NEWA LETTER NHA
11425 NEWA LETTER PA
11426 NEWA LETTER PHA
11427 NEWA LETTER BA
11428 NEWA LETTER BHA
11429 NEWA LETTER MA
1142A NEWA LETTER MHA
1142B NEWA LETTER YA
1142C NEWA LETTER RA
1142D NEWA LETTER RHA
1142E NEWA LETTER LA
1142F NEWA LETTER LHA
11430 NEWA LETTER WA
11431 NEWA LETTER SHA
11432 NEWA LETTER SSA
11433 NEWA LETTER SA
11434 NEWA LETTER HA
11435 NEWA VOWEL SIGN AA
11436 NEWA VOWEL SIGN I
11437 NEWA VOWEL SIGN II
11438 NEWA VOWEL SIGN U
11439 NEWA VOWEL SIGN UU
1143A NEWA VOWEL SIGN VOCALIC R
1143B NEWA VOWEL SIGN VOCALIC RR
1143C NEWA VOWEL SIGN VOCALIC L
1143D NEWA VOWEL SIGN VOCALIC LL
1143E NEWA VOWEL SIGN E
1143F NEWA VOWEL SIGN AI
11440 NEWA VOWEL SIGN O
11441 NEWA VOWEL SIGN AU
11442 NEWA SIGN VIRAMA
11443 NEWA SIGN CANDRABINDU
11444 NEWA SIGN ANUSVARA
11445 NEWA SIGN VISARGA
11446 NEWA SIGN NUKTA
11447 NEWA SIGN AVAGRAHA
11448 NEWA SIGN FINAL ANUSVARA
11449 NEWA OM
1144A NEWA SIDDHI
1144B NEWA DANDA
1144C NEWA DOUBLE DANDA
1144D NEWA COMMA
1144E NEWA GAP FILLER
1144F NEWA ABBREVIATION SIGN
11450 NEWA DIGIT ZERO
11451 NEWA DIGIT ONE
11452 NEWA DIGIT TWO
11453 NEWA DIGIT THREE
11454 NEWA DIGIT FOUR
11455 NEWA DIGIT FIVE
11456 NEWA DIGIT SIX
11457 NEWA DIGIT SEVEN
11458 NEWA DIGIT EIGHT
11459 NEWA DIGIT NINE
1145B NEWA PLACEHOLDER MARK
1145D NEWA INSERTION SIGN
11480 TIRHUTA ANJI
11481 TIRHUTA LETTER A
11482 TIRHUTA LETTER AA
11483 TIRHUTA LETTER I
11484 TIRHUTA LETTER II
11485 TIRHUTA LETTER U
11486 TIRHUTA LETTER UU
11487 TIRHUTA LETTER VOCALIC R
11488 TIRHUTA LETTER VOCALIC RR
11489 TIRHUTA LETTER VOCALIC L
1148A TIRHUTA LETTER VOCALIC LL
1148B TIRHUTA LETTER E
1148C TIRHUTA LETTER AI
1148D TIRHUTA LETTER O
1148E TIRHUTA LETTER AU
1148F TIRHUTA LETTER KA
11490 TIRHUTA LETTER KHA
11491 TIRHUTA LETTER GA
11492 TIRHUTA LETTER GHA
11493 TIRHUTA LETTER NGA
11494 TIRHUTA LETTER CA
11495 TIRHUTA LETTER CHA
11496 TIRHUTA LETTER JA
11497 TIRHUTA LETTER JHA
11498 TIRHUTA LETTER NYA
11499 TIRHUTA LETTER TTA
1149A TIRHUTA LETTER TTHA
1149B TIRHUTA LETTER DDA
1149C TIRHUTA LETTER DDHA
1149D TIRHUTA LETTER NNA
1149E TIRHUTA LETTER TA
1149F TIRHUTA LETTER THA
114A0 TIRHUTA LETTER DA
114A1 TIRHUTA LETTER DHA
114A2 TIRHUTA LETTER NA
114A3 TIRHUTA LETTER PA
114A4 TIRHUTA LETTER PHA
114A5 TIRHUTA LETTER BA
114A6 TIRHUTA LETTER BHA
114A7 TIRHUTA LETTER MA
114A8 TIRHUTA LETTER YA
114A9 TIRHUTA LETTER RA
114AA TIRHUTA LETTER LA
114AB TIRHUTA LETTER VA
114AC TIRHUTA LETTER SHA
114AD TIRHUTA LETTER SSA
114AE TIRHUTA LETTER SA
114AF TIRHUTA LETTER HA
114B0 TIRHUTA VOWEL SIGN AA
114B1 TIRHUTA VOWEL SIGN I
114B2 TIRHUTA VOWEL SIGN II
114B3 TIRHUTA VOWEL SIGN U
114B4 TIRHUTA VOWEL SIGN UU
114B5 TIRHUTA VOWEL SIGN VOCALIC R
114B6 TIRHUTA VOWEL SIGN VOCALIC RR
114B7 TIRHUTA VOWEL SIGN VOCALIC L
114B8 TIRHUTA VOWEL SIGN VOCALIC LL
114B9 TIRHUTA VOWEL SIGN E
114BA TIRHUTA VOWEL SIGN SHORT E
114BB TIRHUTA VOWEL SIGN AI
114BC TIRHUTA VOWEL SIGN O
114BD TIRHUTA VOWEL SIGN SHORT O
114BE TIRHUTA VOWEL SIGN AU
114BF TIRHUTA SIGN CANDRABINDU
114C0 TIRHUTA SIGN ANUSVARA
114C1 TIRHUTA SIGN VISARGA
114C2 TIRHUTA SIGN VIRAMA
114C3 TIRHUTA SIGN NUKTA
114C4 TIRHUTA SIGN AVAGRAHA
114C5 TIRHUTA GVANG
114C6 TIRHUTA ABBREVIATION SIGN
114C7 TIRHUTA OM
114D0 TIRHUTA DIGIT ZERO
114D1 TIRHUTA DIGIT ONE
114D2 TIRHUTA DIGIT TWO
114D3 TIRHUTA DIGIT THREE
114D4 TIRHUTA DIGIT FOUR
114D5 TIRHUTA DIGIT FIVE
114D6 TIRHUTA DIGIT SIX
114D7 TIRHUTA DIGIT SEVEN
114D8 TIRHUTA DIGIT EIGHT
114D9 TIRHUTA DIGIT NINE
11580 SIDDHAM LETTER A
11581 SIDDHAM LETTER AA
11582 SIDDHAM LETTER I
11583 SIDDHAM LETTER II
11584 SIDDHAM LETTER U
11585 SIDDHAM LETTER UU
11586 SIDDHAM LETTER VOCALIC R
11587 SIDDHAM LETTER VOCALIC RR
11588 SIDDHAM LETTER VOCALIC L
11589 SIDDHAM LETTER VOCALIC LL
1158A SIDDHAM LETTER E
1158B SIDDHAM LETTER AI
1158C SIDDHAM LETTER O
1158D SIDDHAM LETTER AU
1158E SIDDHAM LETTER KA
1158F SIDDHAM LETTER KHA
11590 SIDDHAM LETTER GA
11591 SIDDHAM LETTER GHA
11592 SIDDHAM LETTER NGA
11593 SIDDHAM LETTER CA
11594 SIDDHAM LETTER CHA
11595 SIDDHAM LETTER JA
11596 SIDDHAM LETTER JHA
11597 SIDDHAM LETTER NYA
11598 SIDDHAM LETTER TTA
11599 SIDDHAM LETTER TTHA
1159A SIDDHAM LETTER DDA
1159B SIDDHAM LETTER DDHA
1159C SIDDHAM LETTER NNA
1159D SIDDHAM LETTER TA
1159E SIDDHAM LETTER THA
1159F SIDDHAM LETTER DA
115A0 SIDDHAM LETTER DHA
115A1 SIDDHAM LETTER NA
115A2 SIDDHAM LETTER PA
115A3 SIDDHAM LETTER PHA
115A4 SIDDHAM LETTER BA
115A5 SIDDHAM LETTER BHA
115A6 SIDDHAM LETTER MA
115A7 SIDDHAM LETTER YA
115A8 SIDDHAM LETTER RA
115A9 SIDDHAM LETTER LA
115AA SIDDHAM LETTER VA
115AB SIDDHAM LETTER SHA
115AC SIDDHAM LETTER SSA
115AD SIDDHAM LETTER SA
115AE SIDDHAM LETTER HA
115AF SIDDHAM VOWEL SIGN AA
115B0 SIDDHAM VOWEL SIGN I
115B1 SIDDHAM VOWEL SIGN II
115B2 SIDDHAM VOWEL SIGN U
115B3 SIDDHAM VOWEL SIGN UU
115B4 SIDDHAM VOWEL SIGN VOCALIC R
115B5 SIDDHAM VOWEL SIGN VOCALIC RR
115B8 SIDDHAM VOWEL SIGN E
115B9 SIDDHAM VOWEL SIGN AI
115BA SIDDHAM VOWEL SIGN O
115BB SIDDHAM VOWEL SIGN AU
115BC SIDDHAM SIGN CANDRABINDU
115BD SIDDHAM SIGN ANUSVARA
115BE SIDDHAM SIGN VISARGA
115BF SIDDHAM SIGN VIRAMA
115C0 SIDDHAM SIGN NUKTA
115C1 SIDDHAM SIGN SIDDHAM
115C2 SIDDHAM DANDA
115C3 SIDDHAM DOUBLE DANDA
115C4 SIDDHAM SEPARATOR DOT
115C5 SIDDHAM SEPARATOR BAR
115C6 SIDDHAM REPETITION MARK-1
115C7 SIDDHAM REPETITION MARK-2
115C8 SIDDHAM REPETITION MARK-3
115C9 SIDDHAM END OF TEXT MARK
115CA SIDDHAM SECTION MARK WITH TRIDENT AND U-SHAPED ORNAMENTS
115CB SIDDHAM SECTION MARK WITH TRIDENT AND DOTTED CRESCENTS
115CC SIDDHAM SECTION MARK WITH RAYS AND DOTTED CRESCENTS
115CD SIDDHAM SECTION MARK WITH RAYS AND DOTTED DOUBLE CRESCENTS
115CE SIDDHAM SECTION MARK WITH RAYS AND DOTTED TRIPLE CRESCENTS
115CF SIDDHAM SECTION MARK DOUBLE RING
115D0 SIDDHAM SECTION MARK DOUBLE RING WITH RAYS
115D1 SIDDHAM SECTION MARK WITH DOUBLE CRESCENTS
115D2 SIDDHAM SECTION MARK WITH TRIPLE CRESCENTS
115D3 SIDDHAM SECTION MARK WITH QUADRUPLE CRESCENTS
115D4 SIDDHAM SECTION MARK WITH SEPTUPLE CRESCENTS
115D5 SIDDHAM SECTION MARK WITH CIRCLES AND RAYS
115D6 SIDDHAM SECTION MARK WITH CIRCLES AND TWO ENCLOSURES
115D7 SIDDHAM SECTION MARK WITH CIRCLES AND FOUR ENCLOSURES
115D8 SIDDHAM LETTER THREE-CIRCLE ALTERNATE I
115D9 SIDDHAM LETTER TWO-CIRCLE ALTERNATE I
115DA SIDDHAM LETTER TWO-CIRCLE ALTERNATE II
115DB SIDDHAM LETTER ALTERNATE U
115DC SIDDHAM VOWEL SIGN ALTERNATE U
115DD SIDDHAM VOWEL SIGN ALTERNATE UU
11600 MODI LETTER A
11601 MODI LETTER AA
11602 MODI LETTER I
11603 MODI LETTER II
11604 MODI LETTER U
11605 MODI LETTER UU
11606 MODI LETTER VOCALIC R
11607 MODI LETTER VOCALIC RR
11608 MODI LETTER VOCALIC L
11609 MODI LETTER VOCALIC LL
1160A MODI LETTER E
1160B MODI LETTER AI
1160C MODI LETTER O
1160D MODI LETTER AU
1160E MODI LETTER KA
1160F MODI LETTER KHA
11610 MODI LETTER GA
11611 MODI LETTER GHA
11612 MODI LETTER NGA
11613 MODI LETTER CA
11614 MODI LETTER CHA
11615 MODI LETTER JA
11616 MODI LETTER JHA
11617 MODI LETTER NYA
11618 MODI LETTER TTA
11619 MODI LETTER TTHA
1161A MODI LETTER DDA
1161B MODI LETTER DDHA
1161C MODI LETTER NNA
1161D MODI LETTER TA
1161E MODI LETTER THA
1161F MODI LETTER DA
11620 MODI LETTER DHA
11621 MODI LETTER NA
11622 MODI LETTER PA
11623 MODI LETTER PHA
11624 MODI LETTER BA
11625 MODI LETTER BHA
11626 MODI LETTER MA
11627 MODI LETTER YA
11628 MODI LETTER RA
11629 MODI LETTER LA
1162A MODI LETTER VA
1162B MODI LETTER SHA
1162C MODI LETTER SSA
1162D MODI LETTER SA
1162E MODI LETTER HA
1162F MODI LETTER LLA
11630 MODI VOWEL SIGN AA
11631 MODI VOWEL SIGN I
11632 MODI VOWEL SIGN II
11633 MODI VOWEL SIGN U
11634 MODI VOWEL SIGN UU
11635 MODI VOWEL SIGN VOCALIC R
11636 MODI VOWEL SIGN VOCALIC RR
11637 MODI VOWEL SIGN VOCALIC L
11638 MODI VOWEL SIGN VOCALIC LL
11639 MODI VOWEL SIGN E
1163A MODI VOWEL SIGN AI
1163B MODI VOWEL SIGN O
1163C MODI VOWEL SIGN AU
1163D MODI SIGN ANUSVARA
1163E MODI SIGN VISARGA
1163F MODI SIGN VIRAMA
11640 MODI SIGN ARDHACANDRA
11641 MODI DANDA
11642 MODI DOUBLE DANDA
11643 MODI ABBREVIATION SIGN
11644 MODI SIGN HUVA
11650 MODI DIGIT ZERO
11651 MODI DIGIT ONE
11652 MODI DIGIT TWO
11653 MODI DIGIT THREE
11654 MODI DIGIT FOUR
11655 MODI DIGIT FIVE
11656 MODI DIGIT SIX
11657 MODI DIGIT SEVEN
11658 MODI DIGIT EIGHT
11659 MODI DIGIT NINE
11660 MONGOLIAN BIRGA WITH ORNAMENT
11661 MONGOLIAN ROTATED BIRGA
11662 MONGOLIAN DOUBLE BIRGA WITH ORNAMENT
11663 MONGOLIAN TRIPLE BIRGA WITH ORNAMENT
11664 MONGOLIAN BIRGA WITH DOUBLE ORNAMENT
11665 MONGOLIAN ROTATED BIRGA WITH ORNAMENT
11666 MONGOLIAN ROTATED BIRGA WITH DOUBLE ORNAMENT
11667 MONGOLIAN INVERTED BIRGA
11668 MONGOLIAN INVERTED BIRGA WITH DOUBLE ORNAMENT
11669 MONGOLIAN SWIRL BIRGA
1166A MONGOLIAN SWIRL BIRGA WITH ORNAMENT
1166B MONGOLIAN SWIRL BIRGA WITH DOUBLE ORNAMENT
1166C MONGOLIAN TURNED SWIRL BIRGA WITH DOUBLE ORNAMENT
11680 TAKRI LETTER A
11681 TAKRI LETTER AA
11682 TAKRI LETTER I
11683 TAKRI LETTER II
11684 TAKRI LETTER U
11685 TAKRI LETTER UU
11686 TAKRI LETTER E
11687 TAKRI LETTER AI
11688 TAKRI LETTER O
11689 TAKRI LETTER AU
1168A TAKRI LETTER KA
1168B TAKRI LETTER KHA
1168C TAKRI LETTER GA
1168D TAKRI LETTER GHA
1168E TAKRI LETTER NGA
1168F TAKRI LETTER CA
11690 TAKRI LETTER CHA
11691 TAKRI LETTER JA
11692 TAKRI LETTER JHA
11693 TAKRI LETTER NYA
11694 TAKRI LETTER TTA
11695 TAKRI LETTER TTHA
11696 TAKRI LETTER DDA
11697 TAKRI LETTER DDHA
11698 TAKRI LETTER NNA
11699 TAKRI LETTER TA
1169A TAKRI LETTER THA
1169B TAKRI LETTER DA
1169C TAKRI LETTER DHA
1169D TAKRI LETTER NA
1169E TAKRI LETTER PA
1169F TAKRI LETTER PHA
116A0 TAKRI LETTER BA
116A1 TAKRI LETTER BHA
116A2 TAKRI LETTER MA
116A3 TAKRI LETTER YA
116A4 TAKRI LETTER RA
116A5 TAKRI LETTER LA
116A6 TAKRI LETTER VA
116A7 TAKRI LETTER SHA
116A8 TAKRI LETTER SA
116A9 TAKRI LETTER HA
116AA TAKRI LETTER RRA
116AB TAKRI SIGN ANUSVARA
116AC TAKRI SIGN VISARGA
116AD TAKRI VOWEL SIGN AA
116AE TAKRI VOWEL SIGN I
116AF TAKRI VOWEL SIGN II
116B0 TAKRI VOWEL SIGN U
116B1 TAKRI VOWEL SIGN UU
116B2 TAKRI VOWEL SIGN E
116B3 TAKRI VOWEL SIGN AI
116B4 TAKRI VOWEL SIGN O
116B5 TAKRI VOWEL SIGN AU
116B6 TAKRI SIGN VIRAMA
116B7 TAKRI SIGN NUKTA
116C0 TAKRI DIGIT ZERO
116C1 TAKRI DIGIT ONE
116C2 TAKRI DIGIT TWO
116C3 TAKRI DIGIT THREE
116C4 TAKRI DIGIT FOUR
116C5 TAKRI DIGIT FIVE
116C6 TAKRI DIGIT SIX
116C7 TAKRI DIGIT SEVEN
116C8 TAKRI DIGIT EIGHT
116C9 TAKRI DIGIT NINE
11700 AHOM LETTER KA
11701 AHOM LETTER KHA
11702 AHOM LETTER NGA
11703 AHOM LETTER NA
11704 AHOM LETTER TA
11705 AHOM LETTER ALTERNATE TA
11706 AHOM LETTER PA
11707 AHOM LETTER PHA
11708 AHOM LETTER BA
11709 AHOM LETTER MA
1170A AHOM LETTER JA
1170B AHOM LETTER CHA
1170C AHOM LETTER THA
1170D AHOM LETTER RA
1170E AHOM LETTER LA
1170F AHOM LETTER SA
11710 AHOM LETTER NYA
11711 AHOM LETTER HA
11712 AHOM LETTER A
11713 AHOM LETTER DA
11714 AHOM LETTER DHA
11715 AHOM LETTER GA
11716 AHOM LETTER ALTERNATE GA
11717 AHOM LETTER GHA
11718 AHOM LETTER BHA
11719 AHOM LETTER JHA
1171D AHOM CONSONANT SIGN MEDIAL LA
1171E AHOM CONSONANT SIGN MEDIAL RA
1171F AHOM CONSONANT SIGN MEDIAL LIGATING RA
11720 AHOM VOWEL SIGN A
11721 AHOM VOWEL SIGN AA
11722 AHOM VOWEL SIGN I
11723 AHOM VOWEL SIGN II
11724 AHOM VOWEL SIGN U
11725 AHOM VOWEL SIGN UU
11726 AHOM VOWEL SIGN E
11727 AHOM VOWEL SIGN AW
11728 AHOM VOWEL SIGN O
11729 AHOM VOWEL SIGN AI
1172A AHOM VOWEL SIGN AM
1172B AHOM SIGN KILLER
11730 AHOM DIGIT ZERO
11731 AHOM DIGIT ONE
11732 AHOM DIGIT TWO
11733 AHOM DIGIT THREE
11734 AHOM DIGIT FOUR
11735 AHOM DIGIT FIVE
11736 AHOM DIGIT SIX
11737 AHOM DIGIT SEVEN
11738 AHOM DIGIT EIGHT
11739 AHOM DIGIT NINE
1173A AHOM NUMBER TEN
1173B AHOM NUMBER TWENTY
1173C AHOM SIGN SMALL SECTION
1173D AHOM SIGN SECTION
1173E AHOM SIGN RULAI
1173F AHOM SYMBOL VI
118A0 WARANG CITI CAPITAL LETTER NGAA
118A1 WARANG CITI CAPITAL LETTER A
118A2 WARANG CITI CAPITAL LETTER WI
118A3 WARANG CITI CAPITAL LETTER YU
118A4 WARANG CITI CAPITAL LETTER YA
118A5 WARANG CITI CAPITAL LETTER YO
118A6 WARANG CITI CAPITAL LETTER II
118A7 WARANG CITI CAPITAL LETTER UU
118A8 WARANG CITI CAPITAL LETTER E
118A9 WARANG CITI CAPITAL LETTER O
118AA WARANG CITI CAPITAL LETTER ANG
118AB WARANG CITI CAPITAL LETTER GA
118AC WARANG CITI CAPITAL LETTER KO
118AD WARANG CITI CAPITAL LETTER ENY
118AE WARANG CITI CAPITAL LETTER YUJ
118AF WARANG CITI CAPITAL LETTER UC
118B0 WARANG CITI CAPITAL LETTER ENN
118B1 WARANG CITI CAPITAL LETTER ODD
118B2 WARANG CITI CAPITAL LETTER TTE
118B3 WARANG CITI CAPITAL LETTER NUNG
118B4 WARANG CITI CAPITAL LETTER DA
118B5 WARANG CITI CAPITAL LETTER AT
118B6 WARANG CITI CAPITAL LETTER AM
118B7 WARANG CITI CAPITAL LETTER BU
118B8 WARANG CITI CAPITAL LETTER PU
118B9 WARANG CITI CAPITAL LETTER HIYO
118BA WARANG CITI CAPITAL LETTER HOLO
118BB WARANG CITI CAPITAL LETTER HORR
118BC WARANG CITI CAPITAL LETTER HAR
118BD WARANG CITI CAPITAL LETTER SSUU
118BE WARANG CITI CAPITAL LETTER SII
118BF WARANG CITI CAPITAL LETTER VIYO
118C0 WARANG CITI SMALL LETTER NGAA
118C1 WARANG CITI SMALL LETTER A
118C2 WARANG CITI SMALL LETTER WI
118C3 WARANG CITI SMALL LETTER YU
118C4 WARANG CITI SMALL LETTER YA
118C5 WARANG CITI SMALL LETTER YO
118C6 WARANG CITI SMALL LETTER II
118C7 WARANG CITI SMALL LETTER UU
118C8 WARANG CITI SMALL LETTER E
118C9 WARANG CITI SMALL LETTER O
118CA WARANG CITI SMALL LETTER ANG
118CB WARANG CITI SMALL LETTER GA
118CC WARANG CITI SMALL LETTER KO
118CD WARANG CITI SMALL LETTER ENY
118CE WARANG CITI SMALL LETTER YUJ
118CF WARANG CITI SMALL LETTER UC
118D0 WARANG CITI SMALL LETTER ENN
118D1 WARANG CITI SMALL LETTER ODD
118D2 WARANG CITI SMALL LETTER TTE
118D3 WARANG CITI SMALL LETTER NUNG
118D4 WARANG CITI SMALL LETTER DA
118D5 WARANG CITI SMALL LETTER AT
118D6 WARANG CITI SMALL LETTER AM
118D7 WARANG CITI SMALL LETTER BU
118D8 WARANG CITI SMALL LETTER PU
118D9 WARANG CITI SMALL LETTER HIYO
118DA WARANG CITI SMALL LETTER HOLO
118DB WARANG CITI SMALL LETTER HORR
118DC WARANG CITI SMALL LETTER HAR
118DD WARANG CITI SMALL LETTER SSUU
118DE WARANG CITI SMALL LETTER SII
118DF WARANG CITI SMALL LETTER VIYO
118E0 WARANG CITI DIGIT ZERO
118E1 WARANG CITI DIGIT ONE
118E2 WARANG CITI DIGIT TWO
118E3 WARANG CITI DIGIT THREE
118E4 WARANG CITI DIGIT FOUR
118E5 WARANG CITI DIGIT FIVE
118E6 WARANG CITI DIGIT SIX
118E7 WARANG CITI DIGIT SEVEN
118E8 WARANG CITI DIGIT EIGHT
118E9 WARANG CITI DIGIT NINE
118EA WARANG CITI NUMBER TEN
118EB WARANG CITI NUMBER TWENTY
118EC WARANG CITI NUMBER THIRTY
118ED WARANG CITI NUMBER FORTY
118EE WARANG CITI NUMBER FIFTY
118EF WARANG CITI NUMBER SIXTY
118F0 WARANG CITI NUMBER SEVENTY
118F1 WARANG CITI NUMBER EIGHTY
118F2 WARANG CITI NUMBER NINETY
118FF WARANG CITI OM
11A00 ZANABAZAR SQUARE LETTER A
11A01 ZANABAZAR SQUARE VOWEL SIGN I
11A02 ZANABAZAR SQUARE VOWEL SIGN UE
11A03 ZANABAZAR SQUARE VOWEL SIGN U
11A04 ZANABAZAR SQUARE VOWEL SIGN E
11A05 ZANABAZAR SQUARE VOWEL SIGN OE
11A06 ZANABAZAR SQUARE VOWEL SIGN O
11A07 ZANABAZAR SQUARE VOWEL SIGN AI
11A08 ZANABAZAR SQUARE VOWEL SIGN AU
11A09 ZANABAZAR SQUARE VOWEL SIGN REVERSED I
11A0A ZANABAZAR SQUARE VOWEL LENGTH MARK
11A0B ZANABAZAR SQUARE LETTER KA
11A0C ZANABAZAR SQUARE LETTER KHA
11A0D ZANABAZAR SQUARE LETTER GA
11A0E ZANABAZAR SQUARE LETTER GHA
11A0F ZANABAZAR SQUARE LETTER NGA
11A10 ZANABAZAR SQUARE LETTER CA
11A11 ZANABAZAR SQUARE LETTER CHA
11A12 ZANABAZAR SQUARE LETTER JA
11A13 ZANABAZAR SQUARE LETTER NYA
11A14 ZANABAZAR SQUARE LETTER TTA
11A15 ZANABAZAR SQUARE LETTER TTHA
11A16 ZANABAZAR SQUARE LETTER DDA
11A17 ZANABAZAR SQUARE LETTER DDHA
11A18 ZANABAZAR SQUARE LETTER NNA
11A19 ZANABAZAR SQUARE LETTER TA
11A1A ZANABAZAR SQUARE LETTER THA
11A1B ZANABAZAR SQUARE LETTER DA
11A1C ZANABAZAR SQUARE LETTER DHA
11A1D ZANABAZAR SQUARE LETTER NA
11A1E ZANABAZAR SQUARE LETTER PA
11A1F ZANABAZAR SQUARE LETTER PHA
11A20 ZANABAZAR SQUARE LETTER BA
11A21 ZANABAZAR SQUARE LETTER BHA
11A22 ZANABAZAR SQUARE LETTER MA
11A23 ZANABAZAR SQUARE LETTER TSA
11A24 ZANABAZAR SQUARE LETTER TSHA
11A25 ZANABAZAR SQUARE LETTER DZA
11A26 ZANABAZAR SQUARE LETTER DZHA
11A27 ZANABAZAR SQUARE LETTER ZHA
11A28 ZANABAZAR SQUARE LETTER ZA
11A29 ZANABAZAR SQUARE LETTER -A
11A2A ZANABAZAR SQUARE LETTER YA
11A2B ZANABAZAR SQUARE LETTER RA
11A2C ZANABAZAR SQUARE LETTER LA
11A2D ZANABAZAR SQUARE LETTER VA
11A2E ZANABAZAR SQUARE LETTER SHA
11A2F ZANABAZAR SQUARE LETTER SSA
11A30 ZANABAZAR SQUARE LETTER SA
11A31 ZANABAZAR SQUARE LETTER HA
11A32 ZANABAZAR SQUARE LETTER KSSA
11A33 ZANABAZAR SQUARE FINAL CONSONANT MARK
11A34 ZANABAZAR SQUARE SIGN VIRAMA
11A35 ZANABAZAR SQUARE SIGN CANDRABINDU
11A36 ZANABAZAR SQUARE SIGN CANDRABINDU WITH ORNAMENT
11A37 ZANABAZAR SQUARE SIGN CANDRA WITH ORNAMENT
11A38 ZANABAZAR SQUARE SIGN ANUSVARA
11A39 ZANABAZAR SQUARE SIGN VISARGA
11A3A ZANABAZAR SQUARE CLUSTER-INITIAL LETTER RA
11A3B ZANABAZAR SQUARE CLUSTER-FINAL LETTER YA
11A3C ZANABAZAR SQUARE CLUSTER-FINAL LETTER RA
11A3D ZANABAZAR SQUARE CLUSTER-FINAL LETTER LA
11A3E ZANABAZAR SQUARE CLUSTER-FINAL LETTER VA
11A3F ZANABAZAR SQUARE INITIAL HEAD MARK
11A40 ZANABAZAR SQUARE CLOSING HEAD MARK
11A41 ZANABAZAR SQUARE MARK TSHEG
11A42 ZANABAZAR SQUARE MARK SHAD
11A43 ZANABAZAR SQUARE MARK DOUBLE SHAD
11A44 ZANABAZAR SQUARE MARK LONG TSHEG
11A45 ZANABAZAR SQUARE INITIAL DOUBLE-LINED HEAD MARK
11A46 ZANABAZAR SQUARE CLOSING DOUBLE-LINED HEAD MARK
11A47 ZANABAZAR SQUARE SUBJOINER
11A50 SOYOMBO LETTER A
11A51 SOYOMBO VOWEL SIGN I
11A52 SOYOMBO VOWEL SIGN UE
11A53 SOYOMBO VOWEL SIGN U
11A54 SOYOMBO VOWEL SIGN E
11A55 SOYOMBO VOWEL SIGN O
11A56 SOYOMBO VOWEL SIGN OE
11A57 SOYOMBO VOWEL SIGN AI
11A58 SOYOMBO VOWEL SIGN AU
11A59 SOYOMBO VOWEL SIGN VOCALIC R
11A5A SOYOMBO VOWEL SIGN VOCALIC L
11A5B SOYOMBO VOWEL LENGTH MARK
11A5C SOYOMBO LETTER KA
11A5D SOYOMBO LETTER KHA
11A5E SOYOMBO LETTER GA
11A5F SOYOMBO LETTER GHA
11A60 SOYOMBO LETTER NGA
11A61 SOYOMBO LETTER CA
11A62 SOYOMBO LETTER CHA
11A63 SOYOMBO LETTER JA
11A64 SOYOMBO LETTER JHA
11A65 SOYOMBO LETTER NYA
11A66 SOYOMBO LETTER TTA
11A67 SOYOMBO LETTER TTHA
11A68 SOYOMBO LETTER DDA
11A69 SOYOMBO LETTER DDHA
11A6A SOYOMBO LETTER NNA
11A6B SOYOMBO LETTER TA
11A6C SOYOMBO LETTER THA
11A6D SOYOMBO LETTER DA
11A6E SOYOMBO LETTER DHA
11A6F SOYOMBO LETTER NA
11A70 SOYOMBO LETTER PA
11A71 SOYOMBO LETTER PHA
11A72 SOYOMBO LETTER BA
11A73 SOYOMBO LETTER BHA
11A74 SOYOMBO LETTER MA
11A75 SOYOMBO LETTER TSA
11A76 SOYOMBO LETTER TSHA
11A77 SOYOMBO LETTER DZA
11A78 SOYOMBO LETTER ZHA
11A79 SOYOMBO LETTER ZA
11A7A SOYOMBO LETTER -A
11A7B SOYOMBO LETTER YA
11A7C SOYOMBO LETTER RA
11A7D SOYOMBO LETTER LA
11A7E SOYOMBO LETTER VA
11A7F SOYOMBO LETTER SHA
11A80 SOYOMBO LETTER SSA
11A81 SOYOMBO LETTER SA
11A82 SOYOMBO LETTER HA
11A83 SOYOMBO LETTER KSSA
11A86 SOYOMBO CLUSTER-INITIAL LETTER RA
11A87 SOYOMBO CLUSTER-INITIAL LETTER LA
11A88 SOYOMBO CLUSTER-INITIAL LETTER SHA
11A89 SOYOMBO CLUSTER-INITIAL LETTER SA
11A8A SOYOMBO FINAL CONSONANT SIGN G
11A8B SOYOMBO FINAL CONSONANT SIGN K
11A8C SOYOMBO FINAL CONSONANT SIGN NG
11A8D SOYOMBO FINAL CONSONANT SIGN D
11A8E SOYOMBO FINAL CONSONANT SIGN N
11A8F SOYOMBO FINAL CONSONANT SIGN B
11A90 SOYOMBO FINAL CONSONANT SIGN M
11A91 SOYOMBO FINAL CONSONANT SIGN R
11A92 SOYOMBO FINAL CONSONANT SIGN L
11A93 SOYOMBO FINAL CONSONANT SIGN SH
11A94 SOYOMBO FINAL CONSONANT SIGN S
11A95 SOYOMBO FINAL CONSONANT SIGN -A
11A96 SOYOMBO SIGN ANUSVARA
11A97 SOYOMBO SIGN VISARGA
11A98 SOYOMBO GEMINATION MARK
11A99 SOYOMBO SUBJOINER
11A9A SOYOMBO MARK TSHEG
11A9B SOYOMBO MARK SHAD
11A9C SOYOMBO MARK DOUBLE SHAD
11A9E SOYOMBO HEAD MARK WITH MOON AND SUN AND TRIPLE FLAME
11A9F SOYOMBO HEAD MARK WITH MOON AND SUN AND FLAME
11AA0 SOYOMBO HEAD MARK WITH MOON AND SUN
11AA1 SOYOMBO TERMINAL MARK-1
11AA2 SOYOMBO TERMINAL MARK-2
11AC0 PAU CIN HAU LETTER PA
11AC1 PAU CIN HAU LETTER KA
11AC2 PAU CIN HAU LETTER LA
11AC3 PAU CIN HAU LETTER MA
11AC4 PAU CIN HAU LETTER DA
11AC5 PAU CIN HAU LETTER ZA
11AC6 PAU CIN HAU LETTER VA
11AC7 PAU CIN HAU LETTER NGA
11AC8 PAU CIN HAU LETTER HA
11AC9 PAU CIN HAU LETTER GA
11ACA PAU CIN HAU LETTER KHA
11ACB PAU CIN HAU LETTER SA
11ACC PAU CIN HAU LETTER BA
11ACD PAU CIN HAU LETTER CA
11ACE PAU CIN HAU LETTER TA
11ACF PAU CIN HAU LETTER THA
11AD0 PAU CIN HAU LETTER NA
11AD1 PAU CIN HAU LETTER PHA
11AD2 PAU CIN HAU LETTER RA
11AD3 PAU CIN HAU LETTER FA
11AD4 PAU CIN HAU LETTER CHA
11AD5 PAU CIN HAU LETTER A
11AD6 PAU CIN HAU LETTER E
11AD7 PAU CIN HAU LETTER I
11AD8 PAU CIN HAU LETTER O
11AD9 PAU CIN HAU LETTER U
11ADA PAU CIN HAU LETTER UA
11ADB PAU CIN HAU LETTER IA
11ADC PAU CIN HAU LETTER FINAL P
11ADD PAU CIN HAU LETTER FINAL K
11ADE PAU CIN HAU LETTER FINAL T
11ADF PAU CIN HAU LETTER FINAL M
11AE0 PAU CIN HAU LETTER FINAL N
11AE1 PAU CIN HAU LETTER FINAL L
11AE2 PAU CIN HAU LETTER FINAL W
11AE3 PAU CIN HAU LETTER FINAL NG
11AE4 PAU CIN HAU LETTER FINAL Y
11AE5 PAU CIN HAU RISING TONE LONG
11AE6 PAU CIN HAU RISING TONE
11AE7 PAU CIN HAU SANDHI GLOTTAL STOP
11AE8 PAU CIN HAU RISING TONE LONG FINAL
11AE9 PAU CIN HAU RISING TONE FINAL
11AEA PAU CIN HAU SANDHI GLOTTAL STOP FINAL
11AEB PAU CIN HAU SANDHI TONE LONG
11AEC PAU CIN HAU SANDHI TONE
11AED PAU CIN HAU SANDHI TONE LONG FINAL
11AEE PAU CIN HAU SANDHI TONE FINAL
11AEF PAU CIN HAU MID-LEVEL TONE
11AF0 PAU CIN HAU GLOTTAL STOP VARIANT
11AF1 PAU CIN HAU MID-LEVEL TONE LONG FINAL
11AF2 PAU CIN HAU MID-LEVEL TONE FINAL
11AF3 PAU CIN HAU LOW-FALLING TONE LONG
11AF4 PAU CIN HAU LOW-FALLING TONE
11AF5 PAU CIN HAU GLOTTAL STOP
11AF6 PAU CIN HAU LOW-FALLING TONE LONG FINAL
11AF7 PAU CIN HAU LOW-FALLING TONE FINAL
11AF8 PAU CIN HAU GLOTTAL STOP FINAL
11C00 BHAIKSUKI LETTER A
11C01 BHAIKSUKI LETTER AA
11C02 BHAIKSUKI LETTER I
11C03 BHAIKSUKI LETTER II
11C04 BHAIKSUKI LETTER U
11C05 BHAIKSUKI LETTER UU
11C06 BHAIKSUKI LETTER VOCALIC R
11C07 BHAIKSUKI LETTER VOCALIC RR
11C08 BHAIKSUKI LETTER VOCALIC L
11C0A BHAIKSUKI LETTER E
11C0B BHAIKSUKI LETTER AI
11C0C BHAIKSUKI LETTER O
11C0D BHAIKSUKI LETTER AU
11C0E BHAIKSUKI LETTER KA
11C0F BHAIKSUKI LETTER KHA
11C10 BHAIKSUKI LETTER GA
11C11 BHAIKSUKI LETTER GHA
11C12 BHAIKSUKI LETTER NGA
11C13 BHAIKSUKI LETTER CA
11C14 BHAIKSUKI LETTER CHA
11C15 BHAIKSUKI LETTER JA
11C16 BHAIKSUKI LETTER JHA
11C17 BHAIKSUKI LETTER NYA
11C18 BHAIKSUKI LETTER TTA
11C19 BHAIKSUKI LETTER TTHA
11C1A BHAIKSUKI LETTER DDA
11C1B BHAIKSUKI LETTER DDHA
11C1C BHAIKSUKI LETTER NNA
11C1D BHAIKSUKI LETTER TA
11C1E BHAIKSUKI LETTER THA
11C1F BHAIKSUKI LETTER DA
11C20 BHAIKSUKI LETTER DHA
11C21 BHAIKSUKI LETTER NA
11C22 BHAIKSUKI LETTER PA
11C23 BHAIKSUKI LETTER PHA
11C24 BHAIKSUKI LETTER BA
11C25 BHAIKSUKI LETTER BHA
11C26 BHAIKSUKI LETTER MA
11C27 BHAIKSUKI LETTER YA
11C28 BHAIKSUKI LETTER RA
11C29 BHAIKSUKI LETTER LA
11C2A BHAIKSUKI LETTER VA
11C2B BHAIKSUKI LETTER SHA
11C2C BHAIKSUKI LETTER SSA
11C2D BHAIKSUKI LETTER SA
11C2E BHAIKSUKI LETTER HA
11C2F BHAIKSUKI VOWEL SIGN AA
11C30 BHAIKSUKI VOWEL SIGN I
11C31 BHAIKSUKI VOWEL SIGN II
11C32 BHAIKSUKI VOWEL SIGN U
11C33 BHAIKSUKI VOWEL SIGN UU
11C34 BHAIKSUKI VOWEL SIGN VOCALIC R
11C35 BHAIKSUKI VOWEL SIGN VOCALIC RR
11C36 BHAIKSUKI VOWEL SIGN VOCALIC L
11C38 BHAIKSUKI VOWEL SIGN E
11C39 BHAIKSUKI VOWEL SIGN AI
11C3A BHAIKSUKI VOWEL SIGN O
11C3B BHAIKSUKI VOWEL SIGN AU
11C3C BHAIKSUKI SIGN CANDRABINDU
11C3D BHAIKSUKI SIGN ANUSVARA
11C3E BHAIKSUKI SIGN VISARGA
11C3F BHAIKSUKI SIGN VIRAMA
11C40 BHAIKSUKI SIGN AVAGRAHA
11C41 BHAIKSUKI DANDA
11C42 BHAIKSUKI DOUBLE DANDA
11C43 BHAIKSUKI WORD SEPARATOR
11C44 BHAIKSUKI GAP FILLER-1
11C45 BHAIKSUKI GAP FILLER-2
11C50 BHAIKSUKI DIGIT ZERO
11C51 BHAIKSUKI DIGIT ONE
11C52 BHAIKSUKI DIGIT TWO
11C53 BHAIKSUKI DIGIT THREE
11C54 BHAIKSUKI DIGIT FOUR
11C55 BHAIKSUKI DIGIT FIVE
11C56 BHAIKSUKI DIGIT SIX
11C57 BHAIKSUKI DIGIT SEVEN
11C58 BHAIKSUKI DIGIT EIGHT
11C59 BHAIKSUKI DIGIT NINE
11C5A BHAIKSUKI NUMBER ONE
11C5B BHAIKSUKI NUMBER TWO
11C5C BHAIKSUKI NUMBER THREE
11C5D BHAIKSUKI NUMBER FOUR
11C5E BHAIKSUKI NUMBER FIVE
11C5F BHAIKSUKI NUMBER SIX
11C60 BHAIKSUKI NUMBER SEVEN
11C61 BHAIKSUKI NUMBER EIGHT
11C62 BHAIKSUKI NUMBER NINE
11C63 BHAIKSUKI NUMBER TEN
11C64 BHAIKSUKI NUMBER TWENTY
11C65 BHAIKSUKI NUMBER THIRTY
11C66 BHAIKSUKI NUMBER FORTY
11C67 BHAIKSUKI NUMBER FIFTY
11C68 BHAIKSUKI NUMBER SIXTY
11C69 BHAIKSUKI NUMBER SEVENTY
11C6A BHAIKSUKI NUMBER EIGHTY
11C6B BHAIKSUKI NUMBER NINETY
11C6C BHAIKSUKI HUNDREDS UNIT MARK
11C70 MARCHEN HEAD MARK
11C71 MARCHEN MARK SHAD
11C72 MARCHEN LETTER KA
11C73 MARCHEN LETTER KHA
11C74 MARCHEN LETTER GA
11C75 MARCHEN LETTER NGA
11C76 MARCHEN LETTER CA
11C77 MARCHEN LETTER CHA
11C78 MARCHEN LETTER JA
11C79 MARCHEN LETTER NYA
11C7A MARCHEN LETTER TA
11C7B MARCHEN LETTER THA
11C7C MARCHEN LETTER DA
11C7D MARCHEN LETTER NA
11C7E MARCHEN LETTER PA
11C7F MARCHEN LETTER PHA
11C80 MARCHEN LETTER BA
11C81 MARCHEN LETTER MA
11C82 MARCHEN LETTER TSA
11C83 MARCHEN LETTER TSHA
11C84 MARCHEN LETTER DZA
11C85 MARCHEN LETTER WA
11C86 MARCHEN LETTER ZHA
11C87 MARCHEN LETTER ZA
11C88 MARCHEN LETTER -A
11C89 MARCHEN LETTER YA
11C8A MARCHEN LETTER RA
11C8B MARCHEN LETTER LA
11C8C MARCHEN LETTER SHA
11C8D MARCHEN LETTER SA
11C8E MARCHEN LETTER HA
11C8F MARCHEN LETTER A
11C92 MARCHEN SUBJOINED LETTER KA
11C93 MARCHEN SUBJOINED LETTER KHA
11C94 MARCHEN SUBJOINED LETTER GA
11C95 MARCHEN SUBJOINED LETTER NGA
11C96 MARCHEN SUBJOINED LETTER CA
11C97 MARCHEN SUBJOINED LETTER CHA
11C98 MARCHEN SUBJOINED LETTER JA
11C99 MARCHEN SUBJOINED LETTER NYA
11C9A MARCHEN SUBJOINED LETTER TA
11C9B MARCHEN SUBJOINED LETTER THA
11C9C MARCHEN SUBJOINED LETTER DA
11C9D MARCHEN SUBJOINED LETTER NA
11C9E MARCHEN SUBJOINED LETTER PA
11C9F MARCHEN SUBJOINED LETTER PHA
11CA0 MARCHEN SUBJOINED LETTER BA
11CA1 MARCHEN SUBJOINED LETTER MA
11CA2 MARCHEN SUBJOINED LETTER TSA
11CA3 MARCHEN SUBJOINED LETTER TSHA
11CA4 MARCHEN SUBJOINED LETTER DZA
11CA5 MARCHEN SUBJOINED LETTER WA
11CA6 MARCHEN SUBJOINED LETTER ZHA
11CA7 MARCHEN SUBJOINED LETTER ZA
11CA9 MARCHEN SUBJOINED LETTER YA
11CAA MARCHEN SUBJOINED LETTER RA
11CAB MARCHEN SUBJOINED LETTER LA
11CAC MARCHEN SUBJOINED LETTER SHA
11CAD MARCHEN SUBJOINED LETTER SA
11CAE MARCHEN SUBJOINED LETTER HA
11CAF MARCHEN SUBJOINED LETTER A
11CB0 MARCHEN VOWEL SIGN AA
11CB1 MARCHEN VOWEL SIGN I
11CB2 MARCHEN VOWEL SIGN U
11CB3 MARCHEN VOWEL SIGN E
11CB4 MARCHEN VOWEL SIGN O
11CB5 MARCHEN SIGN ANUSVARA
11CB6 MARCHEN SIGN CANDRABINDU
11D00 MASARAM GONDI LETTER A
11D01 MASARAM GONDI LETTER AA
11D02 MASARAM GONDI LETTER I
11D03 MASARAM GONDI LETTER II
11D04 MASARAM GONDI LETTER U
11D05 MASARAM GONDI LETTER UU
11D06 MASARAM GONDI LETTER E
11D08 MASARAM GONDI LETTER AI
11D09 MASARAM GONDI LETTER O
11D0B MASARAM GONDI LETTER AU
11D0C MASARAM GONDI LETTER KA
11D0D MASARAM GONDI LETTER KHA
11D0E MASARAM GONDI LETTER GA
11D0F MASARAM GONDI LETTER GHA
11D10 MASARAM GONDI LETTER NGA
11D11 MASARAM GONDI LETTER CA
11D12 MASARAM GONDI LETTER CHA
11D13 MASARAM GONDI LETTER JA
11D14 MASARAM GONDI LETTER JHA
11D15 MASARAM GONDI LETTER NYA
11D16 MASARAM GONDI LETTER TTA
11D17 MASARAM GONDI LETTER TTHA
11D18 MASARAM GONDI LETTER DDA
11D19 MASARAM GONDI LETTER DDHA
11D1A MASARAM GONDI LETTER NNA
11D1B MASARAM GONDI LETTER TA
11D1C MASARAM GONDI LETTER THA
11D1D MASARAM GONDI LETTER DA
11D1E MASARAM GONDI LETTER DHA
11D1F MASARAM GONDI LETTER NA
11D20 MASARAM GONDI LETTER PA
11D21 MASARAM GONDI LETTER PHA
11D22 MASARAM GONDI LETTER BA
11D23 MASARAM GONDI LETTER BHA
11D24 MASARAM GONDI LETTER MA
11D25 MASARAM GONDI LETTER YA
11D26 MASARAM GONDI LETTER RA
11D27 MASARAM GONDI LETTER LA
11D28 MASARAM GONDI LETTER VA
11D29 MASARAM GONDI LETTER SHA
11D2A MASARAM GONDI LETTER SSA
11D2B MASARAM GONDI LETTER SA
11D2C MASARAM GONDI LETTER HA
11D2D MASARAM GONDI LETTER LLA
11D2E MASARAM GONDI LETTER KSSA
11D2F MASARAM GONDI LETTER JNYA
11D30 MASARAM GONDI LETTER TRA
11D31 MASARAM GONDI VOWEL SIGN AA
11D32 MASARAM GONDI VOWEL SIGN I
11D33 MASARAM GONDI VOWEL SIGN II
11D34 MASARAM GONDI VOWEL SIGN U
11D35 MASARAM GONDI VOWEL SIGN UU
11D36 MASARAM GONDI VOWEL SIGN VOCALIC R
11D3A MASARAM GONDI VOWEL SIGN E
11D3C MASARAM GONDI VOWEL SIGN AI
11D3D MASARAM GONDI VOWEL SIGN O
11D3F MASARAM GONDI VOWEL SIGN AU
11D40 MASARAM GONDI SIGN ANUSVARA
11D41 MASARAM GONDI SIGN VISARGA
11D42 MASARAM GONDI SIGN NUKTA
11D43 MASARAM GONDI SIGN CANDRA
11D44 MASARAM GONDI SIGN HALANTA
11D45 MASARAM GONDI VIRAMA
11D46 MASARAM GONDI REPHA
11D47 MASARAM GONDI RA-KARA
11D50 MASARAM GONDI DIGIT ZERO
11D51 MASARAM GONDI DIGIT ONE
11D52 MASARAM GONDI DIGIT TWO
11D53 MASARAM GONDI DIGIT THREE
11D54 MASARAM GONDI DIGIT FOUR
11D55 MASARAM GONDI DIGIT FIVE
11D56 MASARAM GONDI DIGIT SIX
11D57 MASARAM GONDI DIGIT SEVEN
11D58 MASARAM GONDI DIGIT EIGHT
11D59 MASARAM GONDI DIGIT NINE
12000 CUNEIFORM SIGN A
12001 CUNEIFORM SIGN A TIMES A
12002 CUNEIFORM SIGN A TIMES BAD
12003 CUNEIFORM SIGN A TIMES GAN2 TENU
12004 CUNEIFORM SIGN A TIMES HA
12005 CUNEIFORM SIGN A TIMES IGI
12006 CUNEIFORM SIGN A TIMES LAGAR GUNU
12007 CUNEIFORM SIGN A TIMES MUSH
12008 CUNEIFORM SIGN A TIMES SAG
12009 CUNEIFORM SIGN A2
1200A CUNEIFORM SIGN AB
1200B CUNEIFORM SIGN AB TIMES ASH2
1200C CUNEIFORM SIGN AB TIMES DUN3 GUNU
1200D CUNEIFORM SIGN AB TIMES GAL
1200E CUNEIFORM SIGN AB TIMES GAN2 TENU
1200F CUNEIFORM SIGN AB TIMES HA
12010 CUNEIFORM SIGN AB TIMES IGI GUNU
12011 CUNEIFORM SIGN AB TIMES IMIN
12012 CUNEIFORM SIGN AB TIMES LAGAB
12013 CUNEIFORM SIGN AB TIMES SHESH
12014 CUNEIFORM SIGN AB TIMES U PLUS U PLUS U
12015 CUNEIFORM SIGN AB GUNU
12016 CUNEIFORM SIGN AB2
12017 CUNEIFORM SIGN AB2 TIMES BALAG
12018 CUNEIFORM SIGN AB2 TIMES GAN2 TENU
12019 CUNEIFORM SIGN AB2 TIMES ME PLUS EN
1201A CUNEIFORM SIGN AB2 TIMES SHA3
1201B CUNEIFORM SIGN AB2 TIMES TAK4
1201C CUNEIFORM SIGN AD
1201D CUNEIFORM SIGN AK
1201E CUNEIFORM SIGN AK TIMES ERIN2
1201F CUNEIFORM SIGN AK TIMES SHITA PLUS GISH
12020 CUNEIFORM SIGN AL
12021 CUNEIFORM SIGN AL TIMES AL
12022 CUNEIFORM SIGN AL TIMES DIM2
12023 CUNEIFORM SIGN AL TIMES GISH
12024 CUNEIFORM SIGN AL TIMES HA
12025 CUNEIFORM SIGN AL TIMES KAD3
12026 CUNEIFORM SIGN AL TIMES KI
12027 CUNEIFORM SIGN AL TIMES SHE
12028 CUNEIFORM SIGN AL TIMES USH
12029 CUNEIFORM SIGN ALAN
1202A CUNEIFORM SIGN ALEPH
1202B CUNEIFORM SIGN AMAR
1202C CUNEIFORM SIGN AMAR TIMES SHE
1202D CUNEIFORM SIGN AN
1202E CUNEIFORM SIGN AN OVER AN
1202F CUNEIFORM SIGN AN THREE TIMES
12030 CUNEIFORM SIGN AN PLUS NAGA OPPOSING AN PLUS NAGA
12031 CUNEIFORM SIGN AN PLUS NAGA SQUARED
12032 CUNEIFORM SIGN ANSHE
12033 CUNEIFORM SIGN APIN
12034 CUNEIFORM SIGN ARAD
12035 CUNEIFORM SIGN ARAD TIMES KUR
12036 CUNEIFORM SIGN ARKAB
12037 CUNEIFORM SIGN ASAL2
12038 CUNEIFORM SIGN ASH
12039 CUNEIFORM SIGN ASH ZIDA TENU
1203A CUNEIFORM SIGN ASH KABA TENU
1203B CUNEIFORM SIGN ASH OVER ASH TUG2 OVER TUG2 TUG2 OVER TUG2 PAP
1203C CUNEIFORM SIGN ASH OVER ASH OVER ASH
1203D CUNEIFORM SIGN ASH OVER ASH OVER ASH CROSSING ASH OVER ASH OVER ASH
1203E CUNEIFORM SIGN ASH2
1203F CUNEIFORM SIGN ASHGAB
12040 CUNEIFORM SIGN BA
12041 CUNEIFORM SIGN BAD
12042 CUNEIFORM SIGN BAG3
12043 CUNEIFORM SIGN BAHAR2
12044 CUNEIFORM SIGN BAL
12045 CUNEIFORM SIGN BAL OVER BAL
12046 CUNEIFORM SIGN BALAG
12047 CUNEIFORM SIGN BAR
12048 CUNEIFORM SIGN BARA2
12049 CUNEIFORM SIGN BI
1204A CUNEIFORM SIGN BI TIMES A
1204B CUNEIFORM SIGN BI TIMES GAR
1204C CUNEIFORM SIGN BI TIMES IGI GUNU
1204D CUNEIFORM SIGN BU
1204E CUNEIFORM SIGN BU OVER BU AB
1204F CUNEIFORM SIGN BU OVER BU UN
12050 CUNEIFORM SIGN BU CROSSING BU
12051 CUNEIFORM SIGN BULUG
12052 CUNEIFORM SIGN BULUG OVER BULUG
12053 CUNEIFORM SIGN BUR
12054 CUNEIFORM SIGN BUR2
12055 CUNEIFORM SIGN DA
12056 CUNEIFORM SIGN DAG
12057 CUNEIFORM SIGN DAG KISIM5 TIMES A PLUS MASH
12058 CUNEIFORM SIGN DAG KISIM5 TIMES AMAR
12059 CUNEIFORM SIGN DAG KISIM5 TIMES BALAG
1205A CUNEIFORM SIGN DAG KISIM5 TIMES BI
1205B CUNEIFORM SIGN DAG KISIM5 TIMES GA
1205C CUNEIFORM SIGN DAG KISIM5 TIMES GA PLUS MASH
1205D CUNEIFORM SIGN DAG KISIM5 TIMES GI
1205E CUNEIFORM SIGN DAG KISIM5 TIMES GIR2
1205F CUNEIFORM SIGN DAG KISIM5 TIMES GUD
12060 CUNEIFORM SIGN DAG KISIM5 TIMES HA
12061 CUNEIFORM SIGN DAG KISIM5 TIMES IR
12062 CUNEIFORM SIGN DAG KISIM5 TIMES IR PLUS LU
12063 CUNEIFORM SIGN DAG KISIM5 TIMES KAK
12064 CUNEIFORM SIGN DAG KISIM5 TIMES LA
12065 CUNEIFORM SIGN DAG KISIM5 TIMES LU
12066 CUNEIFORM SIGN DAG KISIM5 TIMES LU PLUS MASH2
12067 CUNEIFORM SIGN DAG KISIM5 TIMES LUM
12068 CUNEIFORM SIGN DAG KISIM5 TIMES NE
12069 CUNEIFORM SIGN DAG KISIM5 TIMES PAP PLUS PAP
1206A CUNEIFORM SIGN DAG KISIM5 TIMES SI
1206B CUNEIFORM SIGN DAG KISIM5 TIMES TAK4
1206C CUNEIFORM SIGN DAG KISIM5 TIMES U2 PLUS GIR2
1206D CUNEIFORM SIGN DAG KISIM5 TIMES USH
1206E CUNEIFORM SIGN DAM
1206F CUNEIFORM SIGN DAR
12070 CUNEIFORM SIGN DARA3
12071 CUNEIFORM SIGN DARA4
12072 CUNEIFORM SIGN DI
12073 CUNEIFORM SIGN DIB
12074 CUNEIFORM SIGN DIM
12075 CUNEIFORM SIGN DIM TIMES SHE
12076 CUNEIFORM SIGN DIM2
12077 CUNEIFORM SIGN DIN
12078 CUNEIFORM SIGN DIN KASKAL U GUNU DISH
12079 CUNEIFORM SIGN DISH
1207A CUNEIFORM SIGN DU
1207B CUNEIFORM SIGN DU OVER DU
1207C CUNEIFORM SIGN DU GUNU
1207D CUNEIFORM SIGN DU SHESHIG
1207E CUNEIFORM SIGN DUB
1207F CUNEIFORM SIGN DUB TIMES ESH2
12080 CUNEIFORM SIGN DUB2
12081 CUNEIFORM SIGN DUG
12082 CUNEIFORM SIGN DUGUD
12083 CUNEIFORM SIGN DUH
12084 CUNEIFORM SIGN DUN
12085 CUNEIFORM SIGN DUN3
12086 CUNEIFORM SIGN DUN3 GUNU
12087 CUNEIFORM SIGN DUN3 GUNU GUNU
12088 CUNEIFORM SIGN DUN4
12089 CUNEIFORM SIGN DUR2
1208A CUNEIFORM SIGN E
1208B CUNEIFORM SIGN E TIMES PAP
1208C CUNEIFORM SIGN E OVER E NUN OVER NUN
1208D CUNEIFORM SIGN E2
1208E CUNEIFORM SIGN E2 TIMES A PLUS HA PLUS DA
1208F CUNEIFORM SIGN E2 TIMES GAR
12090 CUNEIFORM SIGN E2 TIMES MI
12091 CUNEIFORM SIGN E2 TIMES SAL
12092 CUNEIFORM SIGN E2 TIMES SHE
12093 CUNEIFORM SIGN E2 TIMES U
12094 CUNEIFORM SIGN EDIN
12095 CUNEIFORM SIGN EGIR
12096 CUNEIFORM SIGN EL
12097 CUNEIFORM SIGN EN
12098 CUNEIFORM SIGN EN TIMES GAN2
12099 CUNEIFORM SIGN EN TIMES GAN2 TENU
1209A CUNEIFORM SIGN EN TIMES ME
1209B CUNEIFORM SIGN EN CROSSING EN
1209C CUNEIFORM SIGN EN OPPOSING EN
1209D CUNEIFORM SIGN EN SQUARED
1209E CUNEIFORM SIGN EREN
1209F CUNEIFORM SIGN ERIN2
120A0 CUNEIFORM SIGN ESH2
120A1 CUNEIFORM SIGN EZEN
120A2 CUNEIFORM SIGN EZEN TIMES A
120A3 CUNEIFORM SIGN EZEN TIMES A PLUS LAL
120A4 CUNEIFORM SIGN EZEN TIMES A PLUS LAL TIMES LAL
120A5 CUNEIFORM SIGN EZEN TIMES AN
120A6 CUNEIFORM SIGN EZEN TIMES BAD
120A7 CUNEIFORM SIGN EZEN TIMES DUN3 GUNU
120A8 CUNEIFORM SIGN EZEN TIMES DUN3 GUNU GUNU
120A9 CUNEIFORM SIGN EZEN TIMES HA
120AA CUNEIFORM SIGN EZEN TIMES HA GUNU
120AB CUNEIFORM SIGN EZEN TIMES IGI GUNU
120AC CUNEIFORM SIGN EZEN TIMES KASKAL
120AD CUNEIFORM SIGN EZEN TIMES KASKAL SQUARED
120AE CUNEIFORM SIGN EZEN TIMES KU3
120AF CUNEIFORM SIGN EZEN TIMES LA
120B0 CUNEIFORM SIGN EZEN TIMES LAL TIMES LAL
120B1 CUNEIFORM SIGN EZEN TIMES LI
120B2 CUNEIFORM SIGN EZEN TIMES LU
120B3 CUNEIFORM SIGN EZEN TIMES U2
120B4 CUNEIFORM SIGN EZEN TIMES UD
120B5 CUNEIFORM SIGN GA
120B6 CUNEIFORM SIGN GA GUNU
120B7 CUNEIFORM SIGN GA2
120B8 CUNEIFORM SIGN GA2 TIMES A PLUS DA PLUS HA
120B9 CUNEIFORM SIGN GA2 TIMES A PLUS HA
120BA CUNEIFORM SIGN GA2 TIMES A PLUS IGI
120BB CUNEIFORM SIGN GA2 TIMES AB2 TENU PLUS TAB
120BC CUNEIFORM SIGN GA2 TIMES AN
120BD CUNEIFORM SIGN GA2 TIMES ASH
120BE CUNEIFORM SIGN GA2 TIMES ASH2 PLUS GAL
120BF CUNEIFORM SIGN GA2 TIMES BAD
120C0 CUNEIFORM SIGN GA2 TIMES BAR PLUS RA
120C1 CUNEIFORM SIGN GA2 TIMES BUR
120C2 CUNEIFORM SIGN GA2 TIMES BUR PLUS RA
120C3 CUNEIFORM SIGN GA2 TIMES DA
120C4 CUNEIFORM SIGN GA2 TIMES DI
120C5 CUNEIFORM SIGN GA2 TIMES DIM TIMES SHE
120C6 CUNEIFORM SIGN GA2 TIMES DUB
120C7 CUNEIFORM SIGN GA2 TIMES EL
120C8 CUNEIFORM SIGN GA2 TIMES EL PLUS LA
120C9 CUNEIFORM SIGN GA2 TIMES EN
120CA CUNEIFORM SIGN GA2 TIMES EN TIMES GAN2 TENU
120CB CUNEIFORM SIGN GA2 TIMES GAN2 TENU
120CC CUNEIFORM SIGN GA2 TIMES GAR
120CD CUNEIFORM SIGN GA2 TIMES GI
120CE CUNEIFORM SIGN GA2 TIMES GI4
120CF CUNEIFORM SIGN GA2 TIMES GI4 PLUS A
120D0 CUNEIFORM SIGN GA2 TIMES GIR2 PLUS SU
120D1 CUNEIFORM SIGN GA2 TIMES HA PLUS LU PLUS ESH2
120D2 CUNEIFORM SIGN GA2 TIMES HAL
120D3 CUNEIFORM SIGN GA2 TIMES HAL PLUS LA
120D4 CUNEIFORM SIGN GA2 TIMES HI PLUS LI
120D5 CUNEIFORM SIGN GA2 TIMES HUB2
120D6 CUNEIFORM SIGN GA2 TIMES IGI GUNU
120D7 CUNEIFORM SIGN GA2 TIMES ISH PLUS HU PLUS ASH
120D8 CUNEIFORM SIGN GA2 TIMES KAK
120D9 CUNEIFORM SIGN GA2 TIMES KASKAL
120DA CUNEIFORM SIGN GA2 TIMES KID
120DB CUNEIFORM SIGN GA2 TIMES KID PLUS LAL
120DC CUNEIFORM SIGN GA2 TIMES KU3 PLUS AN
120DD CUNEIFORM SIGN GA2 TIMES LA
120DE CUNEIFORM SIGN GA2 TIMES ME PLUS EN
120DF CUNEIFORM SIGN GA2 TIMES MI
120E0 CUNEIFORM SIGN GA2 TIMES NUN
120E1 CUNEIFORM SIGN GA2 TIMES NUN OVER NUN
120E2 CUNEIFORM SIGN GA2 TIMES PA
120E3 CUNEIFORM SIGN GA2 TIMES SAL
120E4 CUNEIFORM SIGN GA2 TIMES SAR
120E5 CUNEIFORM SIGN GA2 TIMES SHE
120E6 CUNEIFORM SIGN GA2 TIMES SHE PLUS TUR
120E7 CUNEIFORM SIGN GA2 TIMES SHID
120E8 CUNEIFORM SIGN GA2 TIMES SUM
120E9 CUNEIFORM SIGN GA2 TIMES TAK4
120EA CUNEIFORM SIGN GA2 TIMES U
120EB CUNEIFORM SIGN GA2 TIMES UD
120EC CUNEIFORM SIGN GA2 TIMES UD PLUS DU
120ED CUNEIFORM SIGN GA2 OVER GA2
120EE CUNEIFORM SIGN GABA
120EF CUNEIFORM SIGN GABA CROSSING GABA
120F0 CUNEIFORM SIGN GAD
120F1 CUNEIFORM SIGN GAD OVER GAD GAR OVER GAR
120F2 CUNEIFORM SIGN GAL
120F3 CUNEIFORM SIGN GAL GAD OVER GAD GAR OVER GAR
120F4 CUNEIFORM SIGN GALAM
120F5 CUNEIFORM SIGN GAM
120F6 CUNEIFORM SIGN GAN
120F7 CUNEIFORM SIGN GAN2
120F8 CUNEIFORM SIGN GAN2 TENU
120F9 CUNEIFORM SIGN GAN2 OVER GAN2
120FA CUNEIFORM SIGN GAN2 CROSSING GAN2
120FB CUNEIFORM SIGN GAR
120FC CUNEIFORM SIGN GAR3
120FD CUNEIFORM SIGN GASHAN
120FE CUNEIFORM SIGN GESHTIN
120FF CUNEIFORM SIGN GESHTIN TIMES KUR
12100 CUNEIFORM SIGN GI
12101 CUNEIFORM SIGN GI TIMES E
12102 CUNEIFORM SIGN GI TIMES U
12103 CUNEIFORM SIGN GI CROSSING GI
12104 CUNEIFORM SIGN GI4
12105 CUNEIFORM SIGN GI4 OVER GI4
12106 CUNEIFORM SIGN GI4 CROSSING GI4
12107 CUNEIFORM SIGN GIDIM
12108 CUNEIFORM SIGN GIR2
12109 CUNEIFORM SIGN GIR2 GUNU
1210A CUNEIFORM SIGN GIR3
1210B CUNEIFORM SIGN GIR3 TIMES A PLUS IGI
1210C CUNEIFORM SIGN GIR3 TIMES GAN2 TENU
1210D CUNEIFORM SIGN GIR3 TIMES IGI
1210E CUNEIFORM SIGN GIR3 TIMES LU PLUS IGI
1210F CUNEIFORM SIGN GIR3 TIMES PA
12110 CUNEIFORM SIGN GISAL
12111 CUNEIFORM SIGN GISH
12112 CUNEIFORM SIGN GISH CROSSING GISH
12113 CUNEIFORM SIGN GISH TIMES BAD
12114 CUNEIFORM SIGN GISH TIMES TAK4
12115 CUNEIFORM SIGN GISH TENU
12116 CUNEIFORM SIGN GU
12117 CUNEIFORM SIGN GU CROSSING GU
12118 CUNEIFORM SIGN GU2
12119 CUNEIFORM SIGN GU2 TIMES KAK
1211A CUNEIFORM SIGN GU2 TIMES KAK TIMES IGI GUNU
1211B CUNEIFORM SIGN GU2 TIMES NUN
1211C CUNEIFORM SIGN GU2 TIMES SAL PLUS TUG2
1211D CUNEIFORM SIGN GU2 GUNU
1211E CUNEIFORM SIGN GUD
1211F CUNEIFORM SIGN GUD TIMES A PLUS KUR
12120 CUNEIFORM SIGN GUD TIMES KUR
12121 CUNEIFORM SIGN GUD OVER GUD LUGAL
12122 CUNEIFORM SIGN GUL
12123 CUNEIFORM SIGN GUM
12124 CUNEIFORM SIGN GUM TIMES SHE
12125 CUNEIFORM SIGN GUR
12126 CUNEIFORM SIGN GUR7
12127 CUNEIFORM SIGN GURUN
12128 CUNEIFORM SIGN GURUSH
12129 CUNEIFORM SIGN HA
1212A CUNEIFORM SIGN HA TENU
1212B CUNEIFORM SIGN HA GUNU
1212C CUNEIFORM SIGN HAL
1212D CUNEIFORM SIGN HI
1212E CUNEIFORM SIGN HI TIMES ASH
1212F CUNEIFORM SIGN HI TIMES ASH2
12130 CUNEIFORM SIGN HI TIMES BAD
12131 CUNEIFORM SIGN HI TIMES DISH
12132 CUNEIFORM SIGN HI TIMES GAD
12133 CUNEIFORM SIGN HI TIMES KIN
12134 CUNEIFORM SIGN HI TIMES NUN
12135 CUNEIFORM SIGN HI TIMES SHE
12136 CUNEIFORM SIGN HI TIMES U
12137 CUNEIFORM SIGN HU
12138 CUNEIFORM SIGN HUB2
12139 CUNEIFORM SIGN HUB2 TIMES AN
1213A CUNEIFORM SIGN HUB2 TIMES HAL
1213B CUNEIFORM SIGN HUB2 TIMES KASKAL
1213C CUNEIFORM SIGN HUB2 TIMES LISH
1213D CUNEIFORM SIGN HUB2 TIMES UD
1213E CUNEIFORM SIGN HUL2
1213F CUNEIFORM SIGN I
12140 CUNEIFORM SIGN I A
12141 CUNEIFORM SIGN IB
12142 CUNEIFORM SIGN IDIM
12143 CUNEIFORM SIGN IDIM OVER IDIM BUR
12144 CUNEIFORM SIGN IDIM OVER IDIM SQUARED
12145 CUNEIFORM SIGN IG
12146 CUNEIFORM SIGN IGI
12147 CUNEIFORM SIGN IGI DIB
12148 CUNEIFORM SIGN IGI RI
12149 CUNEIFORM SIGN IGI OVER IGI SHIR OVER SHIR UD OVER UD
1214A CUNEIFORM SIGN IGI GUNU
1214B CUNEIFORM SIGN IL
1214C CUNEIFORM SIGN IL TIMES GAN2 TENU
1214D CUNEIFORM SIGN IL2
1214E CUNEIFORM SIGN IM
1214F CUNEIFORM SIGN IM TIMES TAK4
12150 CUNEIFORM SIGN IM CROSSING IM
12151 CUNEIFORM SIGN IM OPPOSING IM
12152 CUNEIFORM SIGN IM SQUARED
12153 CUNEIFORM SIGN IMIN
12154 CUNEIFORM SIGN IN
12155 CUNEIFORM SIGN IR
12156 CUNEIFORM SIGN ISH
12157 CUNEIFORM SIGN KA
12158 CUNEIFORM SIGN KA TIMES A
12159 CUNEIFORM SIGN KA TIMES AD
1215A CUNEIFORM SIGN KA TIMES AD PLUS KU3
1215B CUNEIFORM SIGN KA TIMES ASH2
1215C CUNEIFORM SIGN KA TIMES BAD
1215D CUNEIFORM SIGN KA TIMES BALAG
1215E CUNEIFORM SIGN KA TIMES BAR
1215F CUNEIFORM SIGN KA TIMES BI
12160 CUNEIFORM SIGN KA TIMES ERIN2
12161 CUNEIFORM SIGN KA TIMES ESH2
12162 CUNEIFORM SIGN KA TIMES GA
12163 CUNEIFORM SIGN KA TIMES GAL
12164 CUNEIFORM SIGN KA TIMES GAN2 TENU
12165 CUNEIFORM SIGN KA TIMES GAR
12166 CUNEIFORM SIGN KA TIMES GAR PLUS SHA3 PLUS A
12167 CUNEIFORM SIGN KA TIMES GI
12168 CUNEIFORM SIGN KA TIMES GIR2
12169 CUNEIFORM SIGN KA TIMES GISH PLUS SAR
1216A CUNEIFORM SIGN KA TIMES GISH CROSSING GISH
1216B CUNEIFORM SIGN KA TIMES GU
1216C CUNEIFORM SIGN KA TIMES GUR7
1216D CUNEIFORM SIGN KA TIMES IGI
1216E CUNEIFORM SIGN KA TIMES IM
1216F CUNEIFORM SIGN KA TIMES KAK
12170 CUNEIFORM SIGN KA TIMES KI
12171 CUNEIFORM SIGN KA TIMES KID
12172 CUNEIFORM SIGN KA TIMES LI
12173 CUNEIFORM SIGN KA TIMES LU
12174 CUNEIFORM SIGN KA TIMES ME
12175 CUNEIFORM SIGN KA TIMES ME PLUS DU
12176 CUNEIFORM SIGN KA TIMES ME PLUS GI
12177 CUNEIFORM SIGN KA TIMES ME PLUS TE
12178 CUNEIFORM SIGN KA TIMES MI
12179 CUNEIFORM SIGN KA TIMES MI PLUS NUNUZ
1217A CUNEIFORM SIGN KA TIMES NE
1217B CUNEIFORM SIGN KA TIMES NUN
1217C CUNEIFORM SIGN KA TIMES PI
1217D CUNEIFORM SIGN KA TIMES RU
1217E CUNEIFORM SIGN KA TIMES SA
1217F CUNEIFORM SIGN KA TIMES SAR
12180 CUNEIFORM SIGN KA TIMES SHA
12181 CUNEIFORM SIGN KA TIMES SHE
12182 CUNEIFORM SIGN KA TIMES SHID
12183 CUNEIFORM SIGN KA TIMES SHU
12184 CUNEIFORM SIGN KA TIMES SIG
12185 CUNEIFORM SIGN KA TIMES SUHUR
12186 CUNEIFORM SIGN KA TIMES TAR
12187 CUNEIFORM SIGN KA TIMES U
12188 CUNEIFORM SIGN KA TIMES U2
12189 CUNEIFORM SIGN KA TIMES UD
1218A CUNEIFORM SIGN KA TIMES UMUM TIMES PA
1218B CUNEIFORM SIGN KA TIMES USH
1218C CUNEIFORM SIGN KA TIMES ZI
1218D CUNEIFORM SIGN KA2
1218E CUNEIFORM SIGN KA2 CROSSING KA2
1218F CUNEIFORM SIGN KAB
12190 CUNEIFORM SIGN KAD2
12191 CUNEIFORM SIGN KAD3
12192 CUNEIFORM SIGN KAD4
12193 CUNEIFORM SIGN KAD5
12194 CUNEIFORM SIGN KAD5 OVER KAD5
12195 CUNEIFORM SIGN KAK
12196 CUNEIFORM SIGN KAK TIMES IGI GUNU
12197 CUNEIFORM SIGN KAL
12198 CUNEIFORM SIGN KAL TIMES BAD
12199 CUNEIFORM SIGN KAL CROSSING KAL
1219A CUNEIFORM SIGN KAM2
1219B CUNEIFORM SIGN KAM4
1219C CUNEIFORM SIGN KASKAL
1219D CUNEIFORM SIGN KASKAL LAGAB TIMES U OVER LAGAB TIMES U
1219E CUNEIFORM SIGN KASKAL OVER KASKAL LAGAB TIMES U OVER LAGAB TIMES U
1219F CUNEIFORM SIGN KESH2
121A0 CUNEIFORM SIGN KI
121A1 CUNEIFORM SIGN KI TIMES BAD
121A2 CUNEIFORM SIGN KI TIMES U
121A3 CUNEIFORM SIGN KI TIMES UD
121A4 CUNEIFORM SIGN KID
121A5 CUNEIFORM SIGN KIN
121A6 CUNEIFORM SIGN KISAL
121A7 CUNEIFORM SIGN KISH
121A8 CUNEIFORM SIGN KISIM5
121A9 CUNEIFORM SIGN KISIM5 OVER KISIM5
121AA CUNEIFORM SIGN KU
121AB CUNEIFORM SIGN KU OVER HI TIMES ASH2 KU OVER HI TIMES ASH2
121AC CUNEIFORM SIGN KU3
121AD CUNEIFORM SIGN KU4
121AE CUNEIFORM SIGN KU4 VARIANT FORM
121AF CUNEIFORM SIGN KU7
121B0 CUNEIFORM SIGN KUL
121B1 CUNEIFORM SIGN KUL GUNU
121B2 CUNEIFORM SIGN KUN
121B3 CUNEIFORM SIGN KUR
121B4 CUNEIFORM SIGN KUR OPPOSING KUR
121B5 CUNEIFORM SIGN KUSHU2
121B6 CUNEIFORM SIGN KWU318
121B7 CUNEIFORM SIGN LA
121B8 CUNEIFORM SIGN LAGAB
121B9 CUNEIFORM SIGN LAGAB TIMES A
121BA CUNEIFORM SIGN LAGAB TIMES A PLUS DA PLUS HA
121BB CUNEIFORM SIGN LAGAB TIMES A PLUS GAR
121BC CUNEIFORM SIGN LAGAB TIMES A PLUS LAL
121BD CUNEIFORM SIGN LAGAB TIMES AL
121BE CUNEIFORM SIGN LAGAB TIMES AN
121BF CUNEIFORM SIGN LAGAB TIMES ASH ZIDA TENU
121C0 CUNEIFORM SIGN LAGAB TIMES BAD
121C1 CUNEIFORM SIGN LAGAB TIMES BI
121C2 CUNEIFORM SIGN LAGAB TIMES DAR
121C3 CUNEIFORM SIGN LAGAB TIMES EN
121C4 CUNEIFORM SIGN LAGAB TIMES GA
121C5 CUNEIFORM SIGN LAGAB TIMES GAR
121C6 CUNEIFORM SIGN LAGAB TIMES GUD
121C7 CUNEIFORM SIGN LAGAB TIMES GUD PLUS GUD
121C8 CUNEIFORM SIGN LAGAB TIMES HA
121C9 CUNEIFORM SIGN LAGAB TIMES HAL
121CA CUNEIFORM SIGN LAGAB TIMES HI TIMES NUN
121CB CUNEIFORM SIGN LAGAB TIMES IGI GUNU
121CC CUNEIFORM SIGN LAGAB TIMES IM
121CD CUNEIFORM SIGN LAGAB TIMES IM PLUS HA
121CE CUNEIFORM SIGN LAGAB TIMES IM PLUS LU
121CF CUNEIFORM SIGN LAGAB TIMES KI
121D0 CUNEIFORM SIGN LAGAB TIMES KIN
121D1 CUNEIFORM SIGN LAGAB TIMES KU3
121D2 CUNEIFORM SIGN LAGAB TIMES KUL
121D3 CUNEIFORM SIGN LAGAB TIMES KUL PLUS HI PLUS A
121D4 CUNEIFORM SIGN LAGAB TIMES LAGAB
121D5 CUNEIFORM SIGN LAGAB TIMES LISH
121D6 CUNEIFORM SIGN LAGAB TIMES LU
121D7 CUNEIFORM SIGN LAGAB TIMES LUL
121D8 CUNEIFORM SIGN LAGAB TIMES ME
121D9 CUNEIFORM SIGN LAGAB TIMES ME PLUS EN
121DA CUNEIFORM SIGN LAGAB TIMES MUSH
121DB CUNEIFORM SIGN LAGAB TIMES NE
121DC CUNEIFORM SIGN LAGAB TIMES SHE PLUS SUM
121DD CUNEIFORM SIGN LAGAB TIMES SHITA PLUS GISH PLUS ERIN2
121DE CUNEIFORM SIGN LAGAB TIMES SHITA PLUS GISH TENU
121DF CUNEIFORM SIGN LAGAB TIMES SHU2
121E0 CUNEIFORM SIGN LAGAB TIMES SHU2 PLUS SHU2
121E1 CUNEIFORM SIGN LAGAB TIMES SUM
121E2 CUNEIFORM SIGN LAGAB TIMES TAG
121E3 CUNEIFORM SIGN LAGAB TIMES TAK4
121E4 CUNEIFORM SIGN LAGAB TIMES TE PLUS A PLUS SU PLUS NA
121E5 CUNEIFORM SIGN LAGAB TIMES U
121E6 CUNEIFORM SIGN LAGAB TIMES U PLUS A
121E7 CUNEIFORM SIGN LAGAB TIMES U PLUS U PLUS U
121E8 CUNEIFORM SIGN LAGAB TIMES U2 PLUS ASH
121E9 CUNEIFORM SIGN LAGAB TIMES UD
121EA CUNEIFORM SIGN LAGAB TIMES USH
121EB CUNEIFORM SIGN LAGAB SQUARED
121EC CUNEIFORM SIGN LAGAR
121ED CUNEIFORM SIGN LAGAR TIMES SHE
121EE CUNEIFORM SIGN LAGAR TIMES SHE PLUS SUM
121EF CUNEIFORM SIGN LAGAR GUNU
121F0 CUNEIFORM SIGN LAGAR GUNU OVER LAGAR GUNU SHE
121F1 CUNEIFORM SIGN LAHSHU
121F2 CUNEIFORM SIGN LAL
121F3 CUNEIFORM SIGN LAL TIMES LAL
121F4 CUNEIFORM SIGN LAM
121F5 CUNEIFORM SIGN LAM TIMES KUR
121F6 CUNEIFORM SIGN LAM TIMES KUR PLUS RU
121F7 CUNEIFORM SIGN LI
121F8 CUNEIFORM SIGN LIL
121F9 CUNEIFORM SIGN LIMMU2
121FA CUNEIFORM SIGN LISH
121FB CUNEIFORM SIGN LU
121FC CUNEIFORM SIGN LU TIMES BAD
121FD CUNEIFORM SIGN LU2
121FE CUNEIFORM SIGN LU2 TIMES AL
121FF CUNEIFORM SIGN LU2 TIMES BAD
12200 CUNEIFORM SIGN LU2 TIMES ESH2
12201 CUNEIFORM SIGN LU2 TIMES ESH2 TENU
12202 CUNEIFORM SIGN LU2 TIMES GAN2 TENU
12203 CUNEIFORM SIGN LU2 TIMES HI TIMES BAD
12204 CUNEIFORM SIGN LU2 TIMES IM
12205 CUNEIFORM SIGN LU2 TIMES KAD2
12206 CUNEIFORM SIGN LU2 TIMES KAD3
12207 CUNEIFORM SIGN LU2 TIMES KAD3 PLUS ASH
12208 CUNEIFORM SIGN LU2 TIMES KI
12209 CUNEIFORM SIGN LU2 TIMES LA PLUS ASH
1220A CUNEIFORM SIGN LU2 TIMES LAGAB
1220B CUNEIFORM SIGN LU2 TIMES ME PLUS EN
1220C CUNEIFORM SIGN LU2 TIMES NE
1220D CUNEIFORM SIGN LU2 TIMES NU
1220E CUNEIFORM SIGN LU2 TIMES SI PLUS ASH
1220F CUNEIFORM SIGN LU2 TIMES SIK2 PLUS BU
12210 CUNEIFORM SIGN LU2 TIMES TUG2
12211 CUNEIFORM SIGN LU2 TENU
12212 CUNEIFORM SIGN LU2 CROSSING LU2
12213 CUNEIFORM SIGN LU2 OPPOSING LU2
12214 CUNEIFORM SIGN LU2 SQUARED
12215 CUNEIFORM SIGN LU2 SHESHIG
12216 CUNEIFORM SIGN LU3
12217 CUNEIFORM SIGN LUGAL
12218 CUNEIFORM SIGN LUGAL OVER LUGAL
12219 CUNEIFORM SIGN LUGAL OPPOSING LUGAL
1221A CUNEIFORM SIGN LUGAL SHESHIG
1221B CUNEIFORM SIGN LUH
1221C CUNEIFORM SIGN LUL
1221D CUNEIFORM SIGN LUM
1221E CUNEIFORM SIGN LUM OVER LUM
1221F CUNEIFORM SIGN LUM OVER LUM GAR OVER GAR
12220 CUNEIFORM SIGN MA
12221 CUNEIFORM SIGN MA TIMES TAK4
12222 CUNEIFORM SIGN MA GUNU
12223 CUNEIFORM SIGN MA2
12224 CUNEIFORM SIGN MAH
12225 CUNEIFORM SIGN MAR
12226 CUNEIFORM SIGN MASH
12227 CUNEIFORM SIGN MASH2
12228 CUNEIFORM SIGN ME
12229 CUNEIFORM SIGN MES
1222A CUNEIFORM SIGN MI
1222B CUNEIFORM SIGN MIN
1222C CUNEIFORM SIGN MU
1222D CUNEIFORM SIGN MU OVER MU
1222E CUNEIFORM SIGN MUG
1222F CUNEIFORM SIGN MUG GUNU
12230 CUNEIFORM SIGN MUNSUB
12231 CUNEIFORM SIGN MURGU2
12232 CUNEIFORM SIGN MUSH
12233 CUNEIFORM SIGN MUSH TIMES A
12234 CUNEIFORM SIGN MUSH TIMES KUR
12235 CUNEIFORM SIGN MUSH TIMES ZA
12236 CUNEIFORM SIGN MUSH OVER MUSH
12237 CUNEIFORM SIGN MUSH OVER MUSH TIMES A PLUS NA
12238 CUNEIFORM SIGN MUSH CROSSING MUSH
12239 CUNEIFORM SIGN MUSH3
1223A CUNEIFORM SIGN MUSH3 TIMES A
1223B CUNEIFORM SIGN MUSH3 TIMES A PLUS DI
1223C CUNEIFORM SIGN MUSH3 TIMES DI
1223D CUNEIFORM SIGN MUSH3 GUNU
1223E CUNEIFORM SIGN NA
1223F CUNEIFORM SIGN NA2
12240 CUNEIFORM SIGN NAGA
12241 CUNEIFORM SIGN NAGA INVERTED
12242 CUNEIFORM SIGN NAGA TIMES SHU TENU
12243 CUNEIFORM SIGN NAGA OPPOSING NAGA
12244 CUNEIFORM SIGN NAGAR
12245 CUNEIFORM SIGN NAM NUTILLU
12246 CUNEIFORM SIGN NAM
12247 CUNEIFORM SIGN NAM2
12248 CUNEIFORM SIGN NE
12249 CUNEIFORM SIGN NE TIMES A
1224A CUNEIFORM SIGN NE TIMES UD
1224B CUNEIFORM SIGN NE SHESHIG
1224C CUNEIFORM SIGN NI
1224D CUNEIFORM SIGN NI TIMES E
1224E CUNEIFORM SIGN NI2
1224F CUNEIFORM SIGN NIM
12250 CUNEIFORM SIGN NIM TIMES GAN2 TENU
12251 CUNEIFORM SIGN NIM TIMES GAR PLUS GAN2 TENU
12252 CUNEIFORM SIGN NINDA2
12253 CUNEIFORM SIGN NINDA2 TIMES AN
12254 CUNEIFORM SIGN NINDA2 TIMES ASH
12255 CUNEIFORM SIGN NINDA2 TIMES ASH PLUS ASH
12256 CUNEIFORM SIGN NINDA2 TIMES GUD
12257 CUNEIFORM SIGN NINDA2 TIMES ME PLUS GAN2 TENU
12258 CUNEIFORM SIGN NINDA2 TIMES NE
12259 CUNEIFORM SIGN NINDA2 TIMES NUN
1225A CUNEIFORM SIGN NINDA2 TIMES SHE
1225B CUNEIFORM SIGN NINDA2 TIMES SHE PLUS A AN
1225C CUNEIFORM SIGN NINDA2 TIMES SHE PLUS ASH
1225D CUNEIFORM SIGN NINDA2 TIMES SHE PLUS ASH PLUS ASH
1225E CUNEIFORM SIGN NINDA2 TIMES U2 PLUS ASH
1225F CUNEIFORM SIGN NINDA2 TIMES USH
12260 CUNEIFORM SIGN NISAG
12261 CUNEIFORM SIGN NU
12262 CUNEIFORM SIGN NU11
12263 CUNEIFORM SIGN NUN
12264 CUNEIFORM SIGN NUN LAGAR TIMES GAR
12265 CUNEIFORM SIGN NUN LAGAR TIMES MASH
12266 CUNEIFORM SIGN NUN LAGAR TIMES SAL
12267 CUNEIFORM SIGN NUN LAGAR TIMES SAL OVER NUN LAGAR TIMES SAL
12268 CUNEIFORM SIGN NUN LAGAR TIMES USH
12269 CUNEIFORM SIGN NUN TENU
1226A CUNEIFORM SIGN NUN OVER NUN
1226B CUNEIFORM SIGN NUN CROSSING NUN
1226C CUNEIFORM SIGN NUN CROSSING NUN LAGAR OVER LAGAR
1226D CUNEIFORM SIGN NUNUZ
1226E CUNEIFORM SIGN NUNUZ AB2 TIMES ASHGAB
1226F CUNEIFORM SIGN NUNUZ AB2 TIMES BI
12270 CUNEIFORM SIGN NUNUZ AB2 TIMES DUG
12271 CUNEIFORM SIGN NUNUZ AB2 TIMES GUD
12272 CUNEIFORM SIGN NUNUZ AB2 TIMES IGI GUNU
12273 CUNEIFORM SIGN NUNUZ AB2 TIMES KAD3
12274 CUNEIFORM SIGN NUNUZ AB2 TIMES LA
12275 CUNEIFORM SIGN NUNUZ AB2 TIMES NE
12276 CUNEIFORM SIGN NUNUZ AB2 TIMES SILA3
12277 CUNEIFORM SIGN NUNUZ AB2 TIMES U2
12278 CUNEIFORM SIGN NUNUZ KISIM5 TIMES BI
12279 CUNEIFORM SIGN NUNUZ KISIM5 TIMES BI U
1227A CUNEIFORM SIGN PA
1227B CUNEIFORM SIGN PAD
1227C CUNEIFORM SIGN PAN
1227D CUNEIFORM SIGN PAP
1227E CUNEIFORM SIGN PESH2
1227F CUNEIFORM SIGN PI
12280 CUNEIFORM SIGN PI TIMES A
12281 CUNEIFORM SIGN PI TIMES AB
12282 CUNEIFORM SIGN PI TIMES BI
12283 CUNEIFORM SIGN PI TIMES BU
12284 CUNEIFORM SIGN PI TIMES E
12285 CUNEIFORM SIGN PI TIMES I
12286 CUNEIFORM SIGN PI TIMES IB
12287 CUNEIFORM SIGN PI TIMES U
12288 CUNEIFORM SIGN PI TIMES U2
12289 CUNEIFORM SIGN PI CROSSING PI
1228A CUNEIFORM SIGN PIRIG
1228B CUNEIFORM SIGN PIRIG TIMES KAL
1228C CUNEIFORM SIGN PIRIG TIMES UD
1228D CUNEIFORM SIGN PIRIG TIMES ZA
1228E CUNEIFORM SIGN PIRIG OPPOSING PIRIG
1228F CUNEIFORM SIGN RA
12290 CUNEIFORM SIGN RAB
12291 CUNEIFORM SIGN RI
12292 CUNEIFORM SIGN RU
12293 CUNEIFORM SIGN SA
12294 CUNEIFORM SIGN SAG NUTILLU
12295 CUNEIFORM SIGN SAG
12296 CUNEIFORM SIGN SAG TIMES A
12297 CUNEIFORM SIGN SAG TIMES DU
12298 CUNEIFORM SIGN SAG TIMES DUB
12299 CUNEIFORM SIGN SAG TIMES HA
1229A CUNEIFORM SIGN SAG TIMES KAK
1229B CUNEIFORM SIGN SAG TIMES KUR
1229C CUNEIFORM SIGN SAG TIMES LUM
1229D CUNEIFORM SIGN SAG TIMES MI
1229E CUNEIFORM SIGN SAG TIMES NUN
1229F CUNEIFORM SIGN SAG TIMES SAL
122A0 CUNEIFORM SIGN SAG TIMES SHID
122A1 CUNEIFORM SIGN SAG TIMES TAB
122A2 CUNEIFORM SIGN SAG TIMES U2
122A3 CUNEIFORM SIGN SAG TIMES UB
122A4 CUNEIFORM SIGN SAG TIMES UM
122A5 CUNEIFORM SIGN SAG TIMES UR
122A6 CUNEIFORM SIGN SAG TIMES USH
122A7 CUNEIFORM SIGN SAG OVER SAG
122A8 CUNEIFORM SIGN SAG GUNU
122A9 CUNEIFORM SIGN SAL
122AA CUNEIFORM SIGN SAL LAGAB TIMES ASH2
122AB CUNEIFORM SIGN SANGA2
122AC CUNEIFORM SIGN SAR
122AD CUNEIFORM SIGN SHA
122AE CUNEIFORM SIGN SHA3
122AF CUNEIFORM SIGN SHA3 TIMES A
122B0 CUNEIFORM SIGN SHA3 TIMES BAD
122B1 CUNEIFORM SIGN SHA3 TIMES GISH
122B2 CUNEIFORM SIGN SHA3 TIMES NE
122B3 CUNEIFORM SIGN SHA3 TIMES SHU2
122B4 CUNEIFORM SIGN SHA3 TIMES TUR
122B5 CUNEIFORM SIGN SHA3 TIMES U
122B6 CUNEIFORM SIGN SHA3 TIMES U PLUS A
122B7 CUNEIFORM SIGN SHA6
122B8 CUNEIFORM SIGN SHAB6
122B9 CUNEIFORM SIGN SHAR2
122BA CUNEIFORM SIGN SHE
122BB CUNEIFORM SIGN SHE HU
122BC CUNEIFORM SIGN SHE OVER SHE GAD OVER GAD GAR OVER GAR
122BD CUNEIFORM SIGN SHE OVER SHE TAB OVER TAB GAR OVER GAR
122BE CUNEIFORM SIGN SHEG9
122BF CUNEIFORM SIGN SHEN
122C0 CUNEIFORM SIGN SHESH
122C1 CUNEIFORM SIGN SHESH2
122C2 CUNEIFORM SIGN SHESHLAM
122C3 CUNEIFORM SIGN SHID
122C4 CUNEIFORM SIGN SHID TIMES A
122C5 CUNEIFORM SIGN SHID TIMES IM
122C6 CUNEIFORM SIGN SHIM
122C7 CUNEIFORM SIGN SHIM TIMES A
122C8 CUNEIFORM SIGN SHIM TIMES BAL
122C9 CUNEIFORM SIGN SHIM TIMES BULUG
122CA CUNEIFORM SIGN SHIM TIMES DIN
122CB CUNEIFORM SIGN SHIM TIMES GAR
122CC CUNEIFORM SIGN SHIM TIMES IGI
122CD CUNEIFORM SIGN SHIM TIMES IGI GUNU
122CE CUNEIFORM SIGN SHIM TIMES KUSHU2
122CF CUNEIFORM SIGN SHIM TIMES LUL
122D0 CUNEIFORM SIGN SHIM TIMES MUG
122D1 CUNEIFORM SIGN SHIM TIMES SAL
122D2 CUNEIFORM SIGN SHINIG
122D3 CUNEIFORM SIGN SHIR
122D4 CUNEIFORM SIGN SHIR TENU
122D5 CUNEIFORM SIGN SHIR OVER SHIR BUR OVER BUR
122D6 CUNEIFORM SIGN SHITA
122D7 CUNEIFORM SIGN SHU
122D8 CUNEIFORM SIGN SHU OVER INVERTED SHU
122D9 CUNEIFORM SIGN SHU2
122DA CUNEIFORM SIGN SHUBUR
122DB CUNEIFORM SIGN SI
122DC CUNEIFORM SIGN SI GUNU
122DD CUNEIFORM SIGN SIG
122DE CUNEIFORM SIGN SIG4
122DF CUNEIFORM SIGN SIG4 OVER SIG4 SHU2
122E0 CUNEIFORM SIGN SIK2
122E1 CUNEIFORM SIGN SILA3
122E2 CUNEIFORM SIGN SU
122E3 CUNEIFORM SIGN SU OVER SU
122E4 CUNEIFORM SIGN SUD
122E5 CUNEIFORM SIGN SUD2
122E6 CUNEIFORM SIGN SUHUR
122E7 CUNEIFORM SIGN SUM
122E8 CUNEIFORM SIGN SUMASH
122E9 CUNEIFORM SIGN SUR
122EA CUNEIFORM SIGN SUR9
122EB CUNEIFORM SIGN TA
122EC CUNEIFORM SIGN TA ASTERISK
122ED CUNEIFORM SIGN TA TIMES HI
122EE CUNEIFORM SIGN TA TIMES MI
122EF CUNEIFORM SIGN TA GUNU
122F0 CUNEIFORM SIGN TAB
122F1 CUNEIFORM SIGN TAB OVER TAB NI OVER NI DISH OVER DISH
122F2 CUNEIFORM SIGN TAB SQUARED
122F3 CUNEIFORM SIGN TAG
122F4 CUNEIFORM SIGN TAG TIMES BI
122F5 CUNEIFORM SIGN TAG TIMES GUD
122F6 CUNEIFORM SIGN TAG TIMES SHE
122F7 CUNEIFORM SIGN TAG TIMES SHU
122F8 CUNEIFORM SIGN TAG TIMES TUG2
122F9 CUNEIFORM SIGN TAG TIMES UD
122FA CUNEIFORM SIGN TAK4
122FB CUNEIFORM SIGN TAR
122FC CUNEIFORM SIGN TE
122FD CUNEIFORM SIGN TE GUNU
122FE CUNEIFORM SIGN TI
122FF CUNEIFORM SIGN TI TENU
12300 CUNEIFORM SIGN TIL
12301 CUNEIFORM SIGN TIR
12302 CUNEIFORM SIGN TIR TIMES TAK4
12303 CUNEIFORM SIGN TIR OVER TIR
12304 CUNEIFORM SIGN TIR OVER TIR GAD OVER GAD GAR OVER GAR
12305 CUNEIFORM SIGN TU
12306 CUNEIFORM SIGN TUG2
12307 CUNEIFORM SIGN TUK
12308 CUNEIFORM SIGN TUM
12309 CUNEIFORM SIGN TUR
1230A CUNEIFORM SIGN TUR OVER TUR ZA OVER ZA
1230B CUNEIFORM SIGN U
1230C CUNEIFORM SIGN U GUD
1230D CUNEIFORM SIGN U U U
1230E CUNEIFORM SIGN U OVER U PA OVER PA GAR OVER GAR
1230F CUNEIFORM SIGN U OVER U SUR OVER SUR
12310 CUNEIFORM SIGN U OVER U U REVERSED OVER U REVERSED
12311 CUNEIFORM SIGN U2
12312 CUNEIFORM SIGN UB
12313 CUNEIFORM SIGN UD
12314 CUNEIFORM SIGN UD KUSHU2
12315 CUNEIFORM SIGN UD TIMES BAD
12316 CUNEIFORM SIGN UD TIMES MI
12317 CUNEIFORM SIGN UD TIMES U PLUS U PLUS U
12318 CUNEIFORM SIGN UD TIMES U PLUS U PLUS U GUNU
12319 CUNEIFORM SIGN UD GUNU
1231A CUNEIFORM SIGN UD SHESHIG
1231B CUNEIFORM SIGN UD SHESHIG TIMES BAD
1231C CUNEIFORM SIGN UDUG
1231D CUNEIFORM SIGN UM
1231E CUNEIFORM SIGN UM TIMES LAGAB
1231F CUNEIFORM SIGN UM TIMES ME PLUS DA
12320 CUNEIFORM SIGN UM TIMES SHA3
12321 CUNEIFORM SIGN UM TIMES U
12322 CUNEIFORM SIGN UMBIN
12323 CUNEIFORM SIGN UMUM
12324 CUNEIFORM SIGN UMUM TIMES KASKAL
12325 CUNEIFORM SIGN UMUM TIMES PA
12326 CUNEIFORM SIGN UN
12327 CUNEIFORM SIGN UN GUNU
12328 CUNEIFORM SIGN UR
12329 CUNEIFORM SIGN UR CROSSING UR
1232A CUNEIFORM SIGN UR SHESHIG
1232B CUNEIFORM SIGN UR2
1232C CUNEIFORM SIGN UR2 TIMES A PLUS HA
1232D CUNEIFORM SIGN UR2 TIMES A PLUS NA
1232E CUNEIFORM SIGN UR2 TIMES AL
1232F CUNEIFORM SIGN UR2 TIMES HA
12330 CUNEIFORM SIGN UR2 TIMES NUN
12331 CUNEIFORM SIGN UR2 TIMES U2
12332 CUNEIFORM SIGN UR2 TIMES U2 PLUS ASH
12333 CUNEIFORM SIGN UR2 TIMES U2 PLUS BI
12334 CUNEIFORM SIGN UR4
12335 CUNEIFORM SIGN URI
12336 CUNEIFORM SIGN URI3
12337 CUNEIFORM SIGN URU
12338 CUNEIFORM SIGN URU TIMES A
12339 CUNEIFORM SIGN URU TIMES ASHGAB
1233A CUNEIFORM SIGN URU TIMES BAR
1233B CUNEIFORM SIGN URU TIMES DUN
1233C CUNEIFORM SIGN URU TIMES GA
1233D CUNEIFORM SIGN URU TIMES GAL
1233E CUNEIFORM SIGN URU TIMES GAN2 TENU
1233F CUNEIFORM SIGN URU TIMES GAR
12340 CUNEIFORM SIGN URU TIMES GU
12341 CUNEIFORM SIGN URU TIMES HA
12342 CUNEIFORM SIGN URU TIMES IGI
12343 CUNEIFORM SIGN URU TIMES IM
12344 CUNEIFORM SIGN URU TIMES ISH
12345 CUNEIFORM SIGN URU TIMES KI
12346 CUNEIFORM SIGN URU TIMES LUM
12347 CUNEIFORM SIGN URU TIMES MIN
12348 CUNEIFORM SIGN URU TIMES PA
12349 CUNEIFORM SIGN URU TIMES SHE
1234A CUNEIFORM SIGN URU TIMES SIG4
1234B CUNEIFORM SIGN URU TIMES TU
1234C CUNEIFORM SIGN URU TIMES U PLUS GUD
1234D CUNEIFORM SIGN URU TIMES UD
1234E CUNEIFORM SIGN URU TIMES URUDA
1234F CUNEIFORM SIGN URUDA
12350 CUNEIFORM SIGN URUDA TIMES U
12351 CUNEIFORM SIGN USH
12352 CUNEIFORM SIGN USH TIMES A
12353 CUNEIFORM SIGN USH TIMES KU
12354 CUNEIFORM SIGN USH TIMES KUR
12355 CUNEIFORM SIGN USH TIMES TAK4
12356 CUNEIFORM SIGN USHX
12357 CUNEIFORM SIGN USH2
12358 CUNEIFORM SIGN USHUMX
12359 CUNEIFORM SIGN UTUKI
1235A CUNEIFORM SIGN UZ3
1235B CUNEIFORM SIGN UZ3 TIMES KASKAL
1235C CUNEIFORM SIGN UZU
1235D CUNEIFORM SIGN ZA
1235E CUNEIFORM SIGN ZA TENU
1235F CUNEIFORM SIGN ZA SQUARED TIMES KUR
12360 CUNEIFORM SIGN ZAG
12361 CUNEIFORM SIGN ZAMX
12362 CUNEIFORM SIGN ZE2
12363 CUNEIFORM SIGN ZI
12364 CUNEIFORM SIGN ZI OVER ZI
12365 CUNEIFORM SIGN ZI3
12366 CUNEIFORM SIGN ZIB
12367 CUNEIFORM SIGN ZIB KABA TENU
12368 CUNEIFORM SIGN ZIG
12369 CUNEIFORM SIGN ZIZ2
1236A CUNEIFORM SIGN ZU
1236B CUNEIFORM SIGN ZU5
1236C CUNEIFORM SIGN ZU5 TIMES A
1236D CUNEIFORM SIGN ZUBUR
1236E CUNEIFORM SIGN ZUM
1236F CUNEIFORM SIGN KAP ELAMITE
12370 CUNEIFORM SIGN AB TIMES NUN
12371 CUNEIFORM SIGN AB2 TIMES A
12372 CUNEIFORM SIGN AMAR TIMES KUG
12373 CUNEIFORM SIGN DAG KISIM5 TIMES U2 PLUS MASH
12374 CUNEIFORM SIGN DAG3
12375 CUNEIFORM SIGN DISH PLUS SHU
12376 CUNEIFORM SIGN DUB TIMES SHE
12377 CUNEIFORM SIGN EZEN TIMES GUD
12378 CUNEIFORM SIGN EZEN TIMES SHE
12379 CUNEIFORM SIGN GA2 TIMES AN PLUS KAK PLUS A
1237A CUNEIFORM SIGN GA2 TIMES ASH2
1237B CUNEIFORM SIGN GE22
1237C CUNEIFORM SIGN GIG
1237D CUNEIFORM SIGN HUSH
1237E CUNEIFORM SIGN KA TIMES ANSHE
1237F CUNEIFORM SIGN KA TIMES ASH3
12380 CUNEIFORM SIGN KA TIMES GISH
12381 CUNEIFORM SIGN KA TIMES GUD
12382 CUNEIFORM SIGN KA TIMES HI TIMES ASH2
12383 CUNEIFORM SIGN KA TIMES LUM
12384 CUNEIFORM SIGN KA TIMES PA
12385 CUNEIFORM SIGN KA TIMES SHUL
12386 CUNEIFORM SIGN KA TIMES TU
12387 CUNEIFORM SIGN KA TIMES UR2
12388 CUNEIFORM SIGN LAGAB TIMES GI
12389 CUNEIFORM SIGN LU2 SHESHIG TIMES BAD
1238A CUNEIFORM SIGN LU2 TIMES ESH2 PLUS LAL
1238B CUNEIFORM SIGN LU2 TIMES SHU
1238C CUNEIFORM SIGN MESH
1238D CUNEIFORM SIGN MUSH3 TIMES ZA
1238E CUNEIFORM SIGN NA4
1238F CUNEIFORM SIGN NIN
12390 CUNEIFORM SIGN NIN9
12391 CUNEIFORM SIGN NINDA2 TIMES BAL
12392 CUNEIFORM SIGN NINDA2 TIMES GI
12393 CUNEIFORM SIGN NU11 ROTATED NINETY DEGREES
12394 CUNEIFORM SIGN PESH2 ASTERISK
12395 CUNEIFORM SIGN PIR2
12396 CUNEIFORM SIGN SAG TIMES IGI GUNU
12397 CUNEIFORM SIGN TI2
12398 CUNEIFORM SIGN UM TIMES ME
12399 CUNEIFORM SIGN U U
12400 CUNEIFORM NUMERIC SIGN TWO ASH
12401 CUNEIFORM NUMERIC SIGN THREE ASH
12402 CUNEIFORM NUMERIC SIGN FOUR ASH
12403 CUNEIFORM NUMERIC SIGN FIVE ASH
12404 CUNEIFORM NUMERIC SIGN SIX ASH
12405 CUNEIFORM NUMERIC SIGN SEVEN ASH
12406 CUNEIFORM NUMERIC SIGN EIGHT ASH
12407 CUNEIFORM NUMERIC SIGN NINE ASH
12408 CUNEIFORM NUMERIC SIGN THREE DISH
12409 CUNEIFORM NUMERIC SIGN FOUR DISH
1240A CUNEIFORM NUMERIC SIGN FIVE DISH
1240B CUNEIFORM NUMERIC SIGN SIX DISH
1240C CUNEIFORM NUMERIC SIGN SEVEN DISH
1240D CUNEIFORM NUMERIC SIGN EIGHT DISH
1240E CUNEIFORM NUMERIC SIGN NINE DISH
1240F CUNEIFORM NUMERIC SIGN FOUR U
12410 CUNEIFORM NUMERIC SIGN FIVE U
12411 CUNEIFORM NUMERIC SIGN SIX U
12412 CUNEIFORM NUMERIC SIGN SEVEN U
12413 CUNEIFORM NUMERIC SIGN EIGHT U
12414 CUNEIFORM NUMERIC SIGN NINE U
12415 CUNEIFORM NUMERIC SIGN ONE GESH2
12416 CUNEIFORM NUMERIC SIGN TWO GESH2
12417 CUNEIFORM NUMERIC SIGN THREE GESH2
12418 CUNEIFORM NUMERIC SIGN FOUR GESH2
12419 CUNEIFORM NUMERIC SIGN FIVE GESH2
1241A CUNEIFORM NUMERIC SIGN SIX GESH2
1241B CUNEIFORM NUMERIC SIGN SEVEN GESH2
1241C CUNEIFORM NUMERIC SIGN EIGHT GESH2
1241D CUNEIFORM NUMERIC SIGN NINE GESH2
1241E CUNEIFORM NUMERIC SIGN ONE GESHU
1241F CUNEIFORM NUMERIC SIGN TWO GESHU
12420 CUNEIFORM NUMERIC SIGN THREE GESHU
12421 CUNEIFORM NUMERIC SIGN FOUR GESHU
12422 CUNEIFORM NUMERIC SIGN FIVE GESHU
12423 CUNEIFORM NUMERIC SIGN TWO SHAR2
12424 CUNEIFORM NUMERIC SIGN THREE SHAR2
12425 CUNEIFORM NUMERIC SIGN THREE SHAR2 VARIANT FORM
12426 CUNEIFORM NUMERIC SIGN FOUR SHAR2
12427 CUNEIFORM NUMERIC SIGN FIVE SHAR2
12428 CUNEIFORM NUMERIC SIGN SIX SHAR2
12429 CUNEIFORM NUMERIC SIGN SEVEN SHAR2
1242A CUNEIFORM NUMERIC SIGN EIGHT SHAR2
1242B CUNEIFORM NUMERIC SIGN NINE SHAR2
1242C CUNEIFORM NUMERIC SIGN ONE SHARU
1242D CUNEIFORM NUMERIC SIGN TWO SHARU
1242E CUNEIFORM NUMERIC SIGN THREE SHARU
1242F CUNEIFORM NUMERIC SIGN THREE SHARU VARIANT FORM
12430 CUNEIFORM NUMERIC SIGN FOUR SHARU
12431 CUNEIFORM NUMERIC SIGN FIVE SHARU
12432 CUNEIFORM NUMERIC SIGN SHAR2 TIMES GAL PLUS DISH
12433 CUNEIFORM NUMERIC SIGN SHAR2 TIMES GAL PLUS MIN
12434 CUNEIFORM NUMERIC SIGN ONE BURU
12435 CUNEIFORM NUMERIC SIGN TWO BURU
12436 CUNEIFORM NUMERIC SIGN THREE BURU
12437 CUNEIFORM NUMERIC SIGN THREE BURU VARIANT FORM
12438 CUNEIFORM NUMERIC SIGN FOUR BURU
12439 CUNEIFORM NUMERIC SIGN FIVE BURU
1243A CUNEIFORM NUMERIC SIGN THREE VARIANT FORM ESH16
1243B CUNEIFORM NUMERIC SIGN THREE VARIANT FORM ESH21
1243C CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU
1243D CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU4
1243E CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU A
1243F CUNEIFORM NUMERIC SIGN FOUR VARIANT FORM LIMMU B
12440 CUNEIFORM NUMERIC SIGN SIX VARIANT FORM ASH9
12441 CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN3
12442 CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN A
12443 CUNEIFORM NUMERIC SIGN SEVEN VARIANT FORM IMIN B
12444 CUNEIFORM NUMERIC SIGN EIGHT VARIANT FORM USSU
12445 CUNEIFORM NUMERIC SIGN EIGHT VARIANT FORM USSU3
12446 CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU
12447 CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU3
12448 CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU4
12449 CUNEIFORM NUMERIC SIGN NINE VARIANT FORM ILIMMU A
1244A CUNEIFORM NUMERIC SIGN TWO ASH TENU
1244B CUNEIFORM NUMERIC SIGN THREE ASH TENU
1244C CUNEIFORM NUMERIC SIGN FOUR ASH TENU
1244D CUNEIFORM NUMERIC SIGN FIVE ASH TENU
1244E CUNEIFORM NUMERIC SIGN SIX ASH TENU
1244F CUNEIFORM NUMERIC SIGN ONE BAN2
12450 CUNEIFORM NUMERIC SIGN TWO BAN2
12451 CUNEIFORM NUMERIC SIGN THREE BAN2
12452 CUNEIFORM NUMERIC SIGN FOUR BAN2
12453 CUNEIFORM NUMERIC SIGN FOUR BAN2 VARIANT FORM
12454 CUNEIFORM NUMERIC SIGN FIVE BAN2
12455 CUNEIFORM NUMERIC SIGN FIVE BAN2 VARIANT FORM
12456 CUNEIFORM NUMERIC SIGN NIGIDAMIN
12457 CUNEIFORM NUMERIC SIGN NIGIDAESH
12458 CUNEIFORM NUMERIC SIGN ONE ESHE3
12459 CUNEIFORM NUMERIC SIGN TWO ESHE3
1245A CUNEIFORM NUMERIC SIGN ONE THIRD DISH
1245B CUNEIFORM NUMERIC SIGN TWO THIRDS DISH
1245C CUNEIFORM NUMERIC SIGN FIVE SIXTHS DISH
1245D CUNEIFORM NUMERIC SIGN ONE THIRD VARIANT FORM A
1245E CUNEIFORM NUMERIC SIGN TWO THIRDS VARIANT FORM A
1245F CUNEIFORM NUMERIC SIGN ONE EIGHTH ASH
12460 CUNEIFORM NUMERIC SIGN ONE QUARTER ASH
12461 CUNEIFORM NUMERIC SIGN OLD ASSYRIAN ONE SIXTH
12462 CUNEIFORM NUMERIC SIGN OLD ASSYRIAN ONE QUARTER
12463 CUNEIFORM NUMERIC SIGN ONE QUARTER GUR
12464 CUNEIFORM NUMERIC SIGN ONE HALF GUR
12465 CUNEIFORM NUMERIC SIGN ELAMITE ONE THIRD
12466 CUNEIFORM NUMERIC SIGN ELAMITE TWO THIRDS
12467 CUNEIFORM NUMERIC SIGN ELAMITE FORTY
12468 CUNEIFORM NUMERIC SIGN ELAMITE FIFTY
12469 CUNEIFORM NUMERIC SIGN FOUR U VARIANT FORM
1246A CUNEIFORM NUMERIC SIGN FIVE U VARIANT FORM
1246B CUNEIFORM NUMERIC SIGN SIX U VARIANT FORM
1246C CUNEIFORM NUMERIC SIGN SEVEN U VARIANT FORM
1246D CUNEIFORM NUMERIC SIGN EIGHT U VARIANT FORM
1246E CUNEIFORM NUMERIC SIGN NINE U VARIANT FORM
12470 CUNEIFORM PUNCTUATION SIGN OLD ASSYRIAN WORD DIVIDER
12471 CUNEIFORM PUNCTUATION SIGN VERTICAL COLON
12472 CUNEIFORM PUNCTUATION SIGN DIAGONAL COLON
12473 CUNEIFORM PUNCTUATION SIGN DIAGONAL TRICOLON
12474 CUNEIFORM PUNCTUATION SIGN DIAGONAL QUADCOLON
12480 CUNEIFORM SIGN AB TIMES NUN TENU
12481 CUNEIFORM SIGN AB TIMES SHU2
12482 CUNEIFORM SIGN AD TIMES ESH2
12483 CUNEIFORM SIGN BAD TIMES DISH TENU
12484 CUNEIFORM SIGN BAHAR2 TIMES AB2
12485 CUNEIFORM SIGN BAHAR2 TIMES NI
12486 CUNEIFORM SIGN BAHAR2 TIMES ZA
12487 CUNEIFORM SIGN BU OVER BU TIMES NA2
12488 CUNEIFORM SIGN DA TIMES TAK4
12489 CUNEIFORM SIGN DAG TIMES KUR
1248A CUNEIFORM SIGN DIM TIMES IGI
1248B CUNEIFORM SIGN DIM TIMES U U U
1248C CUNEIFORM SIGN DIM2 TIMES UD
1248D CUNEIFORM SIGN DUG TIMES ANSHE
1248E CUNEIFORM SIGN DUG TIMES ASH
1248F CUNEIFORM SIGN DUG TIMES ASH AT LEFT
12490 CUNEIFORM SIGN DUG TIMES DIN
12491 CUNEIFORM SIGN DUG TIMES DUN
12492 CUNEIFORM SIGN DUG TIMES ERIN2
12493 CUNEIFORM SIGN DUG TIMES GA
12494 CUNEIFORM SIGN DUG TIMES GI
12495 CUNEIFORM SIGN DUG TIMES GIR2 GUNU
12496 CUNEIFORM SIGN DUG TIMES GISH
12497 CUNEIFORM SIGN DUG TIMES HA
12498 CUNEIFORM SIGN DUG TIMES HI
12499 CUNEIFORM SIGN DUG TIMES IGI GUNU
1249A CUNEIFORM SIGN DUG TIMES KASKAL
1249B CUNEIFORM SIGN DUG TIMES KUR
1249C CUNEIFORM SIGN DUG TIMES KUSHU2
1249D CUNEIFORM SIGN DUG TIMES KUSHU2 PLUS KASKAL
1249E CUNEIFORM SIGN DUG TIMES LAK-020
1249F CUNEIFORM SIGN DUG TIMES LAM
124A0 CUNEIFORM SIGN DUG TIMES LAM TIMES KUR
124A1 CUNEIFORM SIGN DUG TIMES LUH PLUS GISH
124A2 CUNEIFORM SIGN DUG TIMES MASH
124A3 CUNEIFORM SIGN DUG TIMES MES
124A4 CUNEIFORM SIGN DUG TIMES MI
124A5 CUNEIFORM SIGN DUG TIMES NI
124A6 CUNEIFORM SIGN DUG TIMES PI
124A7 CUNEIFORM SIGN DUG TIMES SHE
124A8 CUNEIFORM SIGN DUG TIMES SI GUNU
124A9 CUNEIFORM SIGN E2 TIMES KUR
124AA CUNEIFORM SIGN E2 TIMES PAP
124AB CUNEIFORM SIGN ERIN2 X
124AC CUNEIFORM SIGN ESH2 CROSSING ESH2
124AD CUNEIFORM SIGN EZEN SHESHIG TIMES ASH
124AE CUNEIFORM SIGN EZEN SHESHIG TIMES HI
124AF CUNEIFORM SIGN EZEN SHESHIG TIMES IGI GUNU
124B0 CUNEIFORM SIGN EZEN SHESHIG TIMES LA
124B1 CUNEIFORM SIGN EZEN SHESHIG TIMES LAL
124B2 CUNEIFORM SIGN EZEN SHESHIG TIMES ME
124B3 CUNEIFORM SIGN EZEN SHESHIG TIMES MES
124B4 CUNEIFORM SIGN EZEN SHESHIG TIMES SU
124B5 CUNEIFORM SIGN EZEN TIMES SU
124B6 CUNEIFORM SIGN GA2 TIMES BAHAR2
124B7 CUNEIFORM SIGN GA2 TIMES DIM GUNU
124B8 CUNEIFORM SIGN GA2 TIMES DUG TIMES IGI GUNU
124B9 CUNEIFORM SIGN GA2 TIMES DUG TIMES KASKAL
124BA CUNEIFORM SIGN GA2 TIMES EREN
124BB CUNEIFORM SIGN GA2 TIMES GA
124BC CUNEIFORM SIGN GA2 TIMES GAR PLUS DI
124BD CUNEIFORM SIGN GA2 TIMES GAR PLUS NE
124BE CUNEIFORM SIGN GA2 TIMES HA PLUS A
124BF CUNEIFORM SIGN GA2 TIMES KUSHU2 PLUS KASKAL
124C0 CUNEIFORM SIGN GA2 TIMES LAM
124C1 CUNEIFORM SIGN GA2 TIMES LAM TIMES KUR
124C2 CUNEIFORM SIGN GA2 TIMES LUH
124C3 CUNEIFORM SIGN GA2 TIMES MUSH
124C4 CUNEIFORM SIGN GA2 TIMES NE
124C5 CUNEIFORM SIGN GA2 TIMES NE PLUS E2
124C6 CUNEIFORM SIGN GA2 TIMES NE PLUS GI
124C7 CUNEIFORM SIGN GA2 TIMES SHIM
124C8 CUNEIFORM SIGN GA2 TIMES ZIZ2
124C9 CUNEIFORM SIGN GABA ROTATED NINETY DEGREES
124CA CUNEIFORM SIGN GESHTIN TIMES U
124CB CUNEIFORM SIGN GISH TIMES GISH CROSSING GISH
124CC CUNEIFORM SIGN GU2 TIMES IGI GUNU
124CD CUNEIFORM SIGN GUD PLUS GISH TIMES TAK4
124CE CUNEIFORM SIGN HA TENU GUNU
124CF CUNEIFORM SIGN HI TIMES ASH OVER HI TIMES ASH
124D0 CUNEIFORM SIGN KA TIMES BU
124D1 CUNEIFORM SIGN KA TIMES KA
124D2 CUNEIFORM SIGN KA TIMES U U U
124D3 CUNEIFORM SIGN KA TIMES UR
124D4 CUNEIFORM SIGN LAGAB TIMES ZU OVER ZU
124D5 CUNEIFORM SIGN LAK-003
124D6 CUNEIFORM SIGN LAK-021
124D7 CUNEIFORM SIGN LAK-025
124D8 CUNEIFORM SIGN LAK-030
124D9 CUNEIFORM SIGN LAK-050
124DA CUNEIFORM SIGN LAK-051
124DB CUNEIFORM SIGN LAK-062
124DC CUNEIFORM SIGN LAK-079 OVER LAK-079 GUNU
124DD CUNEIFORM SIGN LAK-080
124DE CUNEIFORM SIGN LAK-081 OVER LAK-081
124DF CUNEIFORM SIGN LAK-092
124E0 CUNEIFORM SIGN LAK-130
124E1 CUNEIFORM SIGN LAK-142
124E2 CUNEIFORM SIGN LAK-210
124E3 CUNEIFORM SIGN LAK-219
124E4 CUNEIFORM SIGN LAK-220
124E5 CUNEIFORM SIGN LAK-225
124E6 CUNEIFORM SIGN LAK-228
124E7 CUNEIFORM SIGN LAK-238
124E8 CUNEIFORM SIGN LAK-265
124E9 CUNEIFORM SIGN LAK-266
124EA CUNEIFORM SIGN LAK-343
124EB CUNEIFORM SIGN LAK-347
124EC CUNEIFORM SIGN LAK-348
124ED CUNEIFORM SIGN LAK-383
124EE CUNEIFORM SIGN LAK-384
124EF CUNEIFORM SIGN LAK-390
124F0 CUNEIFORM SIGN LAK-441
124F1 CUNEIFORM SIGN LAK-449
124F2 CUNEIFORM SIGN LAK-449 TIMES GU
124F3 CUNEIFORM SIGN LAK-449 TIMES IGI
124F4 CUNEIFORM SIGN LAK-449 TIMES PAP PLUS LU3
124F5 CUNEIFORM SIGN LAK-449 TIMES PAP PLUS PAP PLUS LU3
124F6 CUNEIFORM SIGN LAK-449 TIMES U2 PLUS BA
124F7 CUNEIFORM SIGN LAK-450
124F8 CUNEIFORM SIGN LAK-457
124F9 CUNEIFORM SIGN LAK-470
124FA CUNEIFORM SIGN LAK-483
124FB CUNEIFORM SIGN LAK-490
124FC CUNEIFORM SIGN LAK-492
124FD CUNEIFORM SIGN LAK-493
124FE CUNEIFORM SIGN LAK-495
124FF CUNEIFORM SIGN LAK-550
12500 CUNEIFORM SIGN LAK-608
12501 CUNEIFORM SIGN LAK-617
12502 CUNEIFORM SIGN LAK-617 TIMES ASH
12503 CUNEIFORM SIGN LAK-617 TIMES BAD
12504 CUNEIFORM SIGN LAK-617 TIMES DUN3 GUNU GUNU
12505 CUNEIFORM SIGN LAK-617 TIMES KU3
12506 CUNEIFORM SIGN LAK-617 TIMES LA
12507 CUNEIFORM SIGN LAK-617 TIMES TAR
12508 CUNEIFORM SIGN LAK-617 TIMES TE
12509 CUNEIFORM SIGN LAK-617 TIMES U2
1250A CUNEIFORM SIGN LAK-617 TIMES UD
1250B CUNEIFORM SIGN LAK-617 TIMES URUDA
1250C CUNEIFORM SIGN LAK-636
1250D CUNEIFORM SIGN LAK-648
1250E CUNEIFORM SIGN LAK-648 TIMES DUB
1250F CUNEIFORM SIGN LAK-648 TIMES GA
12510 CUNEIFORM SIGN LAK-648 TIMES IGI
12511 CUNEIFORM SIGN LAK-648 TIMES IGI GUNU
12512 CUNEIFORM SIGN LAK-648 TIMES NI
12513 CUNEIFORM SIGN LAK-648 TIMES PAP PLUS PAP PLUS LU3
12514 CUNEIFORM SIGN LAK-648 TIMES SHESH PLUS KI
12515 CUNEIFORM SIGN LAK-648 TIMES UD
12516 CUNEIFORM SIGN LAK-648 TIMES URUDA
12517 CUNEIFORM SIGN LAK-724
12518 CUNEIFORM SIGN LAK-749
12519 CUNEIFORM SIGN LU2 GUNU TIMES ASH
1251A CUNEIFORM SIGN LU2 TIMES DISH
1251B CUNEIFORM SIGN LU2 TIMES HAL
1251C CUNEIFORM SIGN LU2 TIMES PAP
1251D CUNEIFORM SIGN LU2 TIMES PAP PLUS PAP PLUS LU3
1251E CUNEIFORM SIGN LU2 TIMES TAK4
1251F CUNEIFORM SIGN MI PLUS ZA7
12520 CUNEIFORM SIGN MUSH OVER MUSH TIMES GA
12521 CUNEIFORM SIGN MUSH OVER MUSH TIMES KAK
12522 CUNEIFORM SIGN NINDA2 TIMES DIM GUNU
12523 CUNEIFORM SIGN NINDA2 TIMES GISH
12524 CUNEIFORM SIGN NINDA2 TIMES GUL
12525 CUNEIFORM SIGN NINDA2 TIMES HI
12526 CUNEIFORM SIGN NINDA2 TIMES KESH2
12527 CUNEIFORM SIGN NINDA2 TIMES LAK-050
12528 CUNEIFORM SIGN NINDA2 TIMES MASH
12529 CUNEIFORM SIGN NINDA2 TIMES PAP PLUS PAP
1252A CUNEIFORM SIGN NINDA2 TIMES U
1252B CUNEIFORM SIGN NINDA2 TIMES U PLUS U
1252C CUNEIFORM SIGN NINDA2 TIMES URUDA
1252D CUNEIFORM SIGN SAG GUNU TIMES HA
1252E CUNEIFORM SIGN SAG TIMES EN
1252F CUNEIFORM SIGN SAG TIMES SHE AT LEFT
12530 CUNEIFORM SIGN SAG TIMES TAK4
12531 CUNEIFORM SIGN SHA6 TENU
12532 CUNEIFORM SIGN SHE OVER SHE
12533 CUNEIFORM SIGN SHE PLUS HUB2
12534 CUNEIFORM SIGN SHE PLUS NAM2
12535 CUNEIFORM SIGN SHE PLUS SAR
12536 CUNEIFORM SIGN SHU2 PLUS DUG TIMES NI
12537 CUNEIFORM SIGN SHU2 PLUS E2 TIMES AN
12538 CUNEIFORM SIGN SI TIMES TAK4
12539 CUNEIFORM SIGN TAK4 PLUS SAG
1253A CUNEIFORM SIGN TUM TIMES GAN2 TENU
1253B CUNEIFORM SIGN TUM TIMES THREE DISH
1253C CUNEIFORM SIGN UR2 INVERTED
1253D CUNEIFORM SIGN UR2 TIMES UD
1253E CUNEIFORM SIGN URU TIMES DARA3
1253F CUNEIFORM SIGN URU TIMES LAK-668
12540 CUNEIFORM SIGN URU TIMES LU3
12541 CUNEIFORM SIGN ZA7
12542 CUNEIFORM SIGN ZU OVER ZU PLUS SAR
12543 CUNEIFORM SIGN ZU5 TIMES THREE DISH TENU
13000 EGYPTIAN HIEROGLYPH A001
13001 EGYPTIAN HIEROGLYPH A002
13002 EGYPTIAN HIEROGLYPH A003
13003 EGYPTIAN HIEROGLYPH A004
13004 EGYPTIAN HIEROGLYPH A005
13005 EGYPTIAN HIEROGLYPH A005A
13006 EGYPTIAN HIEROGLYPH A006
13007 EGYPTIAN HIEROGLYPH A006A
13008 EGYPTIAN HIEROGLYPH A006B
13009 EGYPTIAN HIEROGLYPH A007
1300A EGYPTIAN HIEROGLYPH A008
1300B EGYPTIAN HIEROGLYPH A009
1300C EGYPTIAN HIEROGLYPH A010
1300D EGYPTIAN HIEROGLYPH A011
1300E EGYPTIAN HIEROGLYPH A012
1300F EGYPTIAN HIEROGLYPH A013
13010 EGYPTIAN HIEROGLYPH A014
13011 EGYPTIAN HIEROGLYPH A014A
13012 EGYPTIAN HIEROGLYPH A015
13013 EGYPTIAN HIEROGLYPH A016
13014 EGYPTIAN HIEROGLYPH A017
13015 EGYPTIAN HIEROGLYPH A017A
13016 EGYPTIAN HIEROGLYPH A018
13017 EGYPTIAN HIEROGLYPH A019
13018 EGYPTIAN HIEROGLYPH A020
13019 EGYPTIAN HIEROGLYPH A021
1301A EGYPTIAN HIEROGLYPH A022
1301B EGYPTIAN HIEROGLYPH A023
1301C EGYPTIAN HIEROGLYPH A024
1301D EGYPTIAN HIEROGLYPH A025
1301E EGYPTIAN HIEROGLYPH A026
1301F EGYPTIAN HIEROGLYPH A027
13020 EGYPTIAN HIEROGLYPH A028
13021 EGYPTIAN HIEROGLYPH A029
13022 EGYPTIAN HIEROGLYPH A030
13023 EGYPTIAN HIEROGLYPH A031
13024 EGYPTIAN HIEROGLYPH A032
13025 EGYPTIAN HIEROGLYPH A032A
13026 EGYPTIAN HIEROGLYPH A033
13027 EGYPTIAN HIEROGLYPH A034
13028 EGYPTIAN HIEROGLYPH A035
13029 EGYPTIAN HIEROGLYPH A036
1302A EGYPTIAN HIEROGLYPH A037
1302B EGYPTIAN HIEROGLYPH A038
1302C EGYPTIAN HIEROGLYPH A039
1302D EGYPTIAN HIEROGLYPH A040
1302E EGYPTIAN HIEROGLYPH A040A
1302F EGYPTIAN HIEROGLYPH A041
13030 EGYPTIAN HIEROGLYPH A042
13031 EGYPTIAN HIEROGLYPH A042A
13032 EGYPTIAN HIEROGLYPH A043
13033 EGYPTIAN HIEROGLYPH A043A
13034 EGYPTIAN HIEROGLYPH A044
13035 EGYPTIAN HIEROGLYPH A045
13036 EGYPTIAN HIEROGLYPH A045A
13037 EGYPTIAN HIEROGLYPH A046
13038 EGYPTIAN HIEROGLYPH A047
13039 EGYPTIAN HIEROGLYPH A048
1303A EGYPTIAN HIEROGLYPH A049
1303B EGYPTIAN HIEROGLYPH A050
1303C EGYPTIAN HIEROGLYPH A051
1303D EGYPTIAN HIEROGLYPH A052
1303E EGYPTIAN HIEROGLYPH A053
1303F EGYPTIAN HIEROGLYPH A054
13040 EGYPTIAN HIEROGLYPH A055
13041 EGYPTIAN HIEROGLYPH A056
13042 EGYPTIAN HIEROGLYPH A057
13043 EGYPTIAN HIEROGLYPH A058
13044 EGYPTIAN HIEROGLYPH A059
13045 EGYPTIAN HIEROGLYPH A060
13046 EGYPTIAN HIEROGLYPH A061
13047 EGYPTIAN HIEROGLYPH A062
13048 EGYPTIAN HIEROGLYPH A063
13049 EGYPTIAN HIEROGLYPH A064
1304A EGYPTIAN HIEROGLYPH A065
1304B EGYPTIAN HIEROGLYPH A066
1304C EGYPTIAN HIEROGLYPH A067
1304D EGYPTIAN HIEROGLYPH A068
1304E EGYPTIAN HIEROGLYPH A069
1304F EGYPTIAN HIEROGLYPH A070
13050 EGYPTIAN HIEROGLYPH B001
13051 EGYPTIAN HIEROGLYPH B002
13052 EGYPTIAN HIEROGLYPH B003
13053 EGYPTIAN HIEROGLYPH B004
13054 EGYPTIAN HIEROGLYPH B005
13055 EGYPTIAN HIEROGLYPH B005A
13056 EGYPTIAN HIEROGLYPH B006
13057 EGYPTIAN HIEROGLYPH B007
13058 EGYPTIAN HIEROGLYPH B008
13059 EGYPTIAN HIEROGLYPH B009
1305A EGYPTIAN HIEROGLYPH C001
1305B EGYPTIAN HIEROGLYPH C002
1305C EGYPTIAN HIEROGLYPH C002A
1305D EGYPTIAN HIEROGLYPH C002B
1305E EGYPTIAN HIEROGLYPH C002C
1305F EGYPTIAN HIEROGLYPH C003
13060 EGYPTIAN HIEROGLYPH C004
13061 EGYPTIAN HIEROGLYPH C005
13062 EGYPTIAN HIEROGLYPH C006
13063 EGYPTIAN HIEROGLYPH C007
13064 EGYPTIAN HIEROGLYPH C008
13065 EGYPTIAN HIEROGLYPH C009
13066 EGYPTIAN HIEROGLYPH C010
13067 EGYPTIAN HIEROGLYPH C010A
13068 EGYPTIAN HIEROGLYPH C011
13069 EGYPTIAN HIEROGLYPH C012
1306A EGYPTIAN HIEROGLYPH C013
1306B EGYPTIAN HIEROGLYPH C014
1306C EGYPTIAN HIEROGLYPH C015
1306D EGYPTIAN HIEROGLYPH C016
1306E EGYPTIAN HIEROGLYPH C017
1306F EGYPTIAN HIEROGLYPH C018
13070 EGYPTIAN HIEROGLYPH C019
13071 EGYPTIAN HIEROGLYPH C020
13072 EGYPTIAN HIEROGLYPH C021
13073 EGYPTIAN HIEROGLYPH C022
13074 EGYPTIAN HIEROGLYPH C023
13075 EGYPTIAN HIEROGLYPH C024
13076 EGYPTIAN HIEROGLYPH D001
13077 EGYPTIAN HIEROGLYPH D002
13078 EGYPTIAN HIEROGLYPH D003
13079 EGYPTIAN HIEROGLYPH D004
1307A EGYPTIAN HIEROGLYPH D005
1307B EGYPTIAN HIEROGLYPH D006
1307C EGYPTIAN HIEROGLYPH D007
1307D EGYPTIAN HIEROGLYPH D008
1307E EGYPTIAN HIEROGLYPH D008A
1307F EGYPTIAN HIEROGLYPH D009
13080 EGYPTIAN HIEROGLYPH D010
13081 EGYPTIAN HIEROGLYPH D011
13082 EGYPTIAN HIEROGLYPH D012
13083 EGYPTIAN HIEROGLYPH D013
13084 EGYPTIAN HIEROGLYPH D014
13085 EGYPTIAN HIEROGLYPH D015
13086 EGYPTIAN HIEROGLYPH D016
13087 EGYPTIAN HIEROGLYPH D017
13088 EGYPTIAN HIEROGLYPH D018
13089 EGYPTIAN HIEROGLYPH D019
1308A EGYPTIAN HIEROGLYPH D020
1308B EGYPTIAN HIEROGLYPH D021
1308C EGYPTIAN HIEROGLYPH D022
1308D EGYPTIAN HIEROGLYPH D023
1308E EGYPTIAN HIEROGLYPH D024
1308F EGYPTIAN HIEROGLYPH D025
13090 EGYPTIAN HIEROGLYPH D026
13091 EGYPTIAN HIEROGLYPH D027
13092 EGYPTIAN HIEROGLYPH D027A
13093 EGYPTIAN HIEROGLYPH D028
13094 EGYPTIAN HIEROGLYPH D029
13095 EGYPTIAN HIEROGLYPH D030
13096 EGYPTIAN HIEROGLYPH D031
13097 EGYPTIAN HIEROGLYPH D031A
13098 EGYPTIAN HIEROGLYPH D032
13099 EGYPTIAN HIEROGLYPH D033
1309A EGYPTIAN HIEROGLYPH D034
1309B EGYPTIAN HIEROGLYPH D034A
1309C EGYPTIAN HIEROGLYPH D035
1309D EGYPTIAN HIEROGLYPH D036
1309E EGYPTIAN HIEROGLYPH D037
1309F EGYPTIAN HIEROGLYPH D038
130A0 EGYPTIAN HIEROGLYPH D039
130A1 EGYPTIAN HIEROGLYPH D040
130A2 EGYPTIAN HIEROGLYPH D041
130A3 EGYPTIAN HIEROGLYPH D042
130A4 EGYPTIAN HIEROGLYPH D043
130A5 EGYPTIAN HIEROGLYPH D044
130A6 EGYPTIAN HIEROGLYPH D045
130A7 EGYPTIAN HIEROGLYPH D046
130A8 EGYPTIAN HIEROGLYPH D046A
130A9 EGYPTIAN HIEROGLYPH D047
130AA EGYPTIAN HIEROGLYPH D048
130AB EGYPTIAN HIEROGLYPH D048A
130AC EGYPTIAN HIEROGLYPH D049
130AD EGYPTIAN HIEROGLYPH D050
130AE EGYPTIAN HIEROGLYPH D050A
130AF EGYPTIAN HIEROGLYPH D050B
130B0 EGYPTIAN HIEROGLYPH D050C
130B1 EGYPTIAN HIEROGLYPH D050D
130B2 EGYPTIAN HIEROGLYPH D050E
130B3 EGYPTIAN HIEROGLYPH D050F
130B4 EGYPTIAN HIEROGLYPH D050G
130B5 EGYPTIAN HIEROGLYPH D050H
130B6 EGYPTIAN HIEROGLYPH D050I
130B7 EGYPTIAN HIEROGLYPH D051
130B8 EGYPTIAN HIEROGLYPH D052
130B9 EGYPTIAN HIEROGLYPH D052A
130BA EGYPTIAN HIEROGLYPH D053
130BB EGYPTIAN HIEROGLYPH D054
130BC EGYPTIAN HIEROGLYPH D054A
130BD EGYPTIAN HIEROGLYPH D055
130BE EGYPTIAN HIEROGLYPH D056
130BF EGYPTIAN HIEROGLYPH D057
130C0 EGYPTIAN HIEROGLYPH D058
130C1 EGYPTIAN HIEROGLYPH D059
130C2 EGYPTIAN HIEROGLYPH D060
130C3 EGYPTIAN HIEROGLYPH D061
130C4 EGYPTIAN HIEROGLYPH D062
130C5 EGYPTIAN HIEROGLYPH D063
130C6 EGYPTIAN HIEROGLYPH D064
130C7 EGYPTIAN HIEROGLYPH D065
130C8 EGYPTIAN HIEROGLYPH D066
130C9 EGYPTIAN HIEROGLYPH D067
130CA EGYPTIAN HIEROGLYPH D067A
130CB EGYPTIAN HIEROGLYPH D067B
130CC EGYPTIAN HIEROGLYPH D067C
130CD EGYPTIAN HIEROGLYPH D067D
130CE EGYPTIAN HIEROGLYPH D067E
130CF EGYPTIAN HIEROGLYPH D067F
130D0 EGYPTIAN HIEROGLYPH D067G
130D1 EGYPTIAN HIEROGLYPH D067H
130D2 EGYPTIAN HIEROGLYPH E001
130D3 EGYPTIAN HIEROGLYPH E002
130D4 EGYPTIAN HIEROGLYPH E003
130D5 EGYPTIAN HIEROGLYPH E004
130D6 EGYPTIAN HIEROGLYPH E005
130D7 EGYPTIAN HIEROGLYPH E006
130D8 EGYPTIAN HIEROGLYPH E007
130D9 EGYPTIAN HIEROGLYPH E008
130DA EGYPTIAN HIEROGLYPH E008A
130DB EGYPTIAN HIEROGLYPH E009
130DC EGYPTIAN HIEROGLYPH E009A
130DD EGYPTIAN HIEROGLYPH E010
130DE EGYPTIAN HIEROGLYPH E011
130DF EGYPTIAN HIEROGLYPH E012
130E0 EGYPTIAN HIEROGLYPH E013
130E1 EGYPTIAN HIEROGLYPH E014
130E2 EGYPTIAN HIEROGLYPH E015
130E3 EGYPTIAN HIEROGLYPH E016
130E4 EGYPTIAN HIEROGLYPH E016A
130E5 EGYPTIAN HIEROGLYPH E017
130E6 EGYPTIAN HIEROGLYPH E017A
130E7 EGYPTIAN HIEROGLYPH E018
130E8 EGYPTIAN HIEROGLYPH E019
130E9 EGYPTIAN HIEROGLYPH E020
130EA EGYPTIAN HIEROGLYPH E020A
130EB EGYPTIAN HIEROGLYPH E021
130EC EGYPTIAN HIEROGLYPH E022
130ED EGYPTIAN HIEROGLYPH E023
130EE EGYPTIAN HIEROGLYPH E024
130EF EGYPTIAN HIEROGLYPH E025
130F0 EGYPTIAN HIEROGLYPH E026
130F1 EGYPTIAN HIEROGLYPH E027
130F2 EGYPTIAN HIEROGLYPH E028
130F3 EGYPTIAN HIEROGLYPH E028A
130F4 EGYPTIAN HIEROGLYPH E029
130F5 EGYPTIAN HIEROGLYPH E030
130F6 EGYPTIAN HIEROGLYPH E031
130F7 EGYPTIAN HIEROGLYPH E032
130F8 EGYPTIAN HIEROGLYPH E033
130F9 EGYPTIAN HIEROGLYPH E034
130FA EGYPTIAN HIEROGLYPH E034A
130FB EGYPTIAN HIEROGLYPH E036
130FC EGYPTIAN HIEROGLYPH E037
130FD EGYPTIAN HIEROGLYPH E038
130FE EGYPTIAN HIEROGLYPH F001
130FF EGYPTIAN HIEROGLYPH F001A
13100 EGYPTIAN HIEROGLYPH F002
13101 EGYPTIAN HIEROGLYPH F003
13102 EGYPTIAN HIEROGLYPH F004
13103 EGYPTIAN HIEROGLYPH F005
13104 EGYPTIAN HIEROGLYPH F006
13105 EGYPTIAN HIEROGLYPH F007
13106 EGYPTIAN HIEROGLYPH F008
13107 EGYPTIAN HIEROGLYPH F009
13108 EGYPTIAN HIEROGLYPH F010
13109 EGYPTIAN HIEROGLYPH F011
1310A EGYPTIAN HIEROGLYPH F012
1310B EGYPTIAN HIEROGLYPH F013
1310C EGYPTIAN HIEROGLYPH F013A
1310D EGYPTIAN HIEROGLYPH F014
1310E EGYPTIAN HIEROGLYPH F015
1310F EGYPTIAN HIEROGLYPH F016
13110 EGYPTIAN HIEROGLYPH F017
13111 EGYPTIAN HIEROGLYPH F018
13112 EGYPTIAN HIEROGLYPH F019
13113 EGYPTIAN HIEROGLYPH F020
13114 EGYPTIAN HIEROGLYPH F021
13115 EGYPTIAN HIEROGLYPH F021A
13116 EGYPTIAN HIEROGLYPH F022
13117 EGYPTIAN HIEROGLYPH F023
13118 EGYPTIAN HIEROGLYPH F024
13119 EGYPTIAN HIEROGLYPH F025
1311A EGYPTIAN HIEROGLYPH F026
1311B EGYPTIAN HIEROGLYPH F027
1311C EGYPTIAN HIEROGLYPH F028
1311D EGYPTIAN HIEROGLYPH F029
1311E EGYPTIAN HIEROGLYPH F030
1311F EGYPTIAN HIEROGLYPH F031
13120 EGYPTIAN HIEROGLYPH F031A
13121 EGYPTIAN HIEROGLYPH F032
13122 EGYPTIAN HIEROGLYPH F033
13123 EGYPTIAN HIEROGLYPH F034
13124 EGYPTIAN HIEROGLYPH F035
13125 EGYPTIAN HIEROGLYPH F036
13126 EGYPTIAN HIEROGLYPH F037
13127 EGYPTIAN HIEROGLYPH F037A
13128 EGYPTIAN HIEROGLYPH F038
13129 EGYPTIAN HIEROGLYPH F038A
1312A EGYPTIAN HIEROGLYPH F039
1312B EGYPTIAN HIEROGLYPH F040
1312C EGYPTIAN HIEROGLYPH F041
1312D EGYPTIAN HIEROGLYPH F042
1312E EGYPTIAN HIEROGLYPH F043
1312F EGYPTIAN HIEROGLYPH F044
13130 EGYPTIAN HIEROGLYPH F045
13131 EGYPTIAN HIEROGLYPH F045A
13132 EGYPTIAN HIEROGLYPH F046
13133 EGYPTIAN HIEROGLYPH F046A
13134 EGYPTIAN HIEROGLYPH F047
13135 EGYPTIAN HIEROGLYPH F047A
13136 EGYPTIAN HIEROGLYPH F048
13137 EGYPTIAN HIEROGLYPH F049
13138 EGYPTIAN HIEROGLYPH F050
13139 EGYPTIAN HIEROGLYPH F051
1313A EGYPTIAN HIEROGLYPH F051A
1313B EGYPTIAN HIEROGLYPH F051B
1313C EGYPTIAN HIEROGLYPH F051C
1313D EGYPTIAN HIEROGLYPH F052
1313E EGYPTIAN HIEROGLYPH F053
1313F EGYPTIAN HIEROGLYPH G001
13140 EGYPTIAN HIEROGLYPH G002
13141 EGYPTIAN HIEROGLYPH G003
13142 EGYPTIAN HIEROGLYPH G004
13143 EGYPTIAN HIEROGLYPH G005
13144 EGYPTIAN HIEROGLYPH G006
13145 EGYPTIAN HIEROGLYPH G006A
13146 EGYPTIAN HIEROGLYPH G007
13147 EGYPTIAN HIEROGLYPH G007A
13148 EGYPTIAN HIEROGLYPH G007B
13149 EGYPTIAN HIEROGLYPH G008
1314A EGYPTIAN HIEROGLYPH G009
1314B EGYPTIAN HIEROGLYPH G010
1314C EGYPTIAN HIEROGLYPH G011
1314D EGYPTIAN HIEROGLYPH G011A
1314E EGYPTIAN HIEROGLYPH G012
1314F EGYPTIAN HIEROGLYPH G013
13150 EGYPTIAN HIEROGLYPH G014
13151 EGYPTIAN HIEROGLYPH G015
13152 EGYPTIAN HIEROGLYPH G016
13153 EGYPTIAN HIEROGLYPH G017
13154 EGYPTIAN HIEROGLYPH G018
13155 EGYPTIAN HIEROGLYPH G019
13156 EGYPTIAN HIEROGLYPH G020
13157 EGYPTIAN HIEROGLYPH G020A
13158 EGYPTIAN HIEROGLYPH G021
13159 EGYPTIAN HIEROGLYPH G022
1315A EGYPTIAN HIEROGLYPH G023
1315B EGYPTIAN HIEROGLYPH G024
1315C EGYPTIAN HIEROGLYPH G025
1315D EGYPTIAN HIEROGLYPH G026
1315E EGYPTIAN HIEROGLYPH G026A
1315F EGYPTIAN HIEROGLYPH G027
13160 EGYPTIAN HIEROGLYPH G028
13161 EGYPTIAN HIEROGLYPH G029
13162 EGYPTIAN HIEROGLYPH G030
13163 EGYPTIAN HIEROGLYPH G031
13164 EGYPTIAN HIEROGLYPH G032
13165 EGYPTIAN HIEROGLYPH G033
13166 EGYPTIAN HIEROGLYPH G034
13167 EGYPTIAN HIEROGLYPH G035
13168 EGYPTIAN HIEROGLYPH G036
13169 EGYPTIAN HIEROGLYPH G036A
1316A EGYPTIAN HIEROGLYPH G037
1316B EGYPTIAN HIEROGLYPH G037A
1316C EGYPTIAN HIEROGLYPH G038
1316D EGYPTIAN HIEROGLYPH G039
1316E EGYPTIAN HIEROGLYPH G040
1316F EGYPTIAN HIEROGLYPH G041
13170 EGYPTIAN HIEROGLYPH G042
13171 EGYPTIAN HIEROGLYPH G043
13172 EGYPTIAN HIEROGLYPH G043A
13173 EGYPTIAN HIEROGLYPH G044
13174 EGYPTIAN HIEROGLYPH G045
13175 EGYPTIAN HIEROGLYPH G045A
13176 EGYPTIAN HIEROGLYPH G046
13177 EGYPTIAN HIEROGLYPH G047
13178 EGYPTIAN HIEROGLYPH G048
13179 EGYPTIAN HIEROGLYPH G049
1317A EGYPTIAN HIEROGLYPH G050
1317B EGYPTIAN HIEROGLYPH G051
1317C EGYPTIAN HIEROGLYPH G052
1317D EGYPTIAN HIEROGLYPH G053
1317E EGYPTIAN HIEROGLYPH G054
1317F EGYPTIAN HIEROGLYPH H001
13180 EGYPTIAN HIEROGLYPH H002
13181 EGYPTIAN HIEROGLYPH H003
13182 EGYPTIAN HIEROGLYPH H004
13183 EGYPTIAN HIEROGLYPH H005
13184 EGYPTIAN HIEROGLYPH H006
13185 EGYPTIAN HIEROGLYPH H006A
13186 EGYPTIAN HIEROGLYPH H007
13187 EGYPTIAN HIEROGLYPH H008
13188 EGYPTIAN HIEROGLYPH I001
13189 EGYPTIAN HIEROGLYPH I002
1318A EGYPTIAN HIEROGLYPH I003
1318B EGYPTIAN HIEROGLYPH I004
1318C EGYPTIAN HIEROGLYPH I005
1318D EGYPTIAN HIEROGLYPH I005A
1318E EGYPTIAN HIEROGLYPH I006
1318F EGYPTIAN HIEROGLYPH I007
13190 EGYPTIAN HIEROGLYPH I008
13191 EGYPTIAN HIEROGLYPH I009
13192 EGYPTIAN HIEROGLYPH I009A
13193 EGYPTIAN HIEROGLYPH I010
13194 EGYPTIAN HIEROGLYPH I010A
13195 EGYPTIAN HIEROGLYPH I011
13196 EGYPTIAN HIEROGLYPH I011A
13197 EGYPTIAN HIEROGLYPH I012
13198 EGYPTIAN HIEROGLYPH I013
13199 EGYPTIAN HIEROGLYPH I014
1319A EGYPTIAN HIEROGLYPH I015
1319B EGYPTIAN HIEROGLYPH K001
1319C EGYPTIAN HIEROGLYPH K002
1319D EGYPTIAN HIEROGLYPH K003
1319E EGYPTIAN HIEROGLYPH K004
1319F EGYPTIAN HIEROGLYPH K005
131A0 EGYPTIAN HIEROGLYPH K006
131A1 EGYPTIAN HIEROGLYPH K007
131A2 EGYPTIAN HIEROGLYPH K008
131A3 EGYPTIAN HIEROGLYPH L001
131A4 EGYPTIAN HIEROGLYPH L002
131A5 EGYPTIAN HIEROGLYPH L002A
131A6 EGYPTIAN HIEROGLYPH L003
131A7 EGYPTIAN HIEROGLYPH L004
131A8 EGYPTIAN HIEROGLYPH L005
131A9 EGYPTIAN HIEROGLYPH L006
131AA EGYPTIAN HIEROGLYPH L006A
131AB EGYPTIAN HIEROGLYPH L007
131AC EGYPTIAN HIEROGLYPH L008
131AD EGYPTIAN HIEROGLYPH M001
131AE EGYPTIAN HIEROGLYPH M001A
131AF EGYPTIAN HIEROGLYPH M001B
131B0 EGYPTIAN HIEROGLYPH M002
131B1 EGYPTIAN HIEROGLYPH M003
131B2 EGYPTIAN HIEROGLYPH M003A
131B3 EGYPTIAN HIEROGLYPH M004
131B4 EGYPTIAN HIEROGLYPH M005
131B5 EGYPTIAN HIEROGLYPH M006
131B6 EGYPTIAN HIEROGLYPH M007
131B7 EGYPTIAN HIEROGLYPH M008
131B8 EGYPTIAN HIEROGLYPH M009
131B9 EGYPTIAN HIEROGLYPH M010
131BA EGYPTIAN HIEROGLYPH M010A
131BB EGYPTIAN HIEROGLYPH M011
131BC EGYPTIAN HIEROGLYPH M012
131BD EGYPTIAN HIEROGLYPH M012A
131BE EGYPTIAN HIEROGLYPH M012B
131BF EGYPTIAN HIEROGLYPH M012C
131C0 EGYPTIAN HIEROGLYPH M012D
131C1 EGYPTIAN HIEROGLYPH M012E
131C2 EGYPTIAN HIEROGLYPH M012F
131C3 EGYPTIAN HIEROGLYPH M012G
131C4 EGYPTIAN HIEROGLYPH M012H
131C5 EGYPTIAN HIEROGLYPH M013
131C6 EGYPTIAN HIEROGLYPH M014
131C7 EGYPTIAN HIEROGLYPH M015
131C8 EGYPTIAN HIEROGLYPH M015A
131C9 EGYPTIAN HIEROGLYPH M016
131CA EGYPTIAN HIEROGLYPH M016A
131CB EGYPTIAN HIEROGLYPH M017
131CC EGYPTIAN HIEROGLYPH M017A
131CD EGYPTIAN HIEROGLYPH M018
131CE EGYPTIAN HIEROGLYPH M019
131CF EGYPTIAN HIEROGLYPH M020
131D0 EGYPTIAN HIEROGLYPH M021
131D1 EGYPTIAN HIEROGLYPH M022
131D2 EGYPTIAN HIEROGLYPH M022A
131D3 EGYPTIAN HIEROGLYPH M023
131D4 EGYPTIAN HIEROGLYPH M024
131D5 EGYPTIAN HIEROGLYPH M024A
131D6 EGYPTIAN HIEROGLYPH M025
131D7 EGYPTIAN HIEROGLYPH M026
131D8 EGYPTIAN HIEROGLYPH M027
131D9 EGYPTIAN HIEROGLYPH M028
131DA EGYPTIAN HIEROGLYPH M028A
131DB EGYPTIAN HIEROGLYPH M029
131DC EGYPTIAN HIEROGLYPH M030
131DD EGYPTIAN HIEROGLYPH M031
131DE EGYPTIAN HIEROGLYPH M031A
131DF EGYPTIAN HIEROGLYPH M032
131E0 EGYPTIAN HIEROGLYPH M033
131E1 EGYPTIAN HIEROGLYPH M033A
131E2 EGYPTIAN HIEROGLYPH M033B
131E3 EGYPTIAN HIEROGLYPH M034
131E4 EGYPTIAN HIEROGLYPH M035
131E5 EGYPTIAN HIEROGLYPH M036
131E6 EGYPTIAN HIEROGLYPH M037
131E7 EGYPTIAN HIEROGLYPH M038
131E8 EGYPTIAN HIEROGLYPH M039
131E9 EGYPTIAN HIEROGLYPH M040
131EA EGYPTIAN HIEROGLYPH M040A
131EB EGYPTIAN HIEROGLYPH M041
131EC EGYPTIAN HIEROGLYPH M042
131ED EGYPTIAN HIEROGLYPH M043
131EE EGYPTIAN HIEROGLYPH M044
131EF EGYPTIAN HIEROGLYPH N001
131F0 EGYPTIAN HIEROGLYPH N002
131F1 EGYPTIAN HIEROGLYPH N003
131F2 EGYPTIAN HIEROGLYPH N004
131F3 EGYPTIAN HIEROGLYPH N005
131F4 EGYPTIAN HIEROGLYPH N006
131F5 EGYPTIAN HIEROGLYPH N007
131F6 EGYPTIAN HIEROGLYPH N008
131F7 EGYPTIAN HIEROGLYPH N009
131F8 EGYPTIAN HIEROGLYPH N010
131F9 EGYPTIAN HIEROGLYPH N011
131FA EGYPTIAN HIEROGLYPH N012
131FB EGYPTIAN HIEROGLYPH N013
131FC EGYPTIAN HIEROGLYPH N014
131FD EGYPTIAN HIEROGLYPH N015
131FE EGYPTIAN HIEROGLYPH N016
131FF EGYPTIAN HIEROGLYPH N017
13200 EGYPTIAN HIEROGLYPH N018
13201 EGYPTIAN HIEROGLYPH N018A
13202 EGYPTIAN HIEROGLYPH N018B
13203 EGYPTIAN HIEROGLYPH N019
13204 EGYPTIAN HIEROGLYPH N020
13205 EGYPTIAN HIEROGLYPH N021
13206 EGYPTIAN HIEROGLYPH N022
13207 EGYPTIAN HIEROGLYPH N023
13208 EGYPTIAN HIEROGLYPH N024
13209 EGYPTIAN HIEROGLYPH N025
1320A EGYPTIAN HIEROGLYPH N025A
1320B EGYPTIAN HIEROGLYPH N026
1320C EGYPTIAN HIEROGLYPH N027
1320D EGYPTIAN HIEROGLYPH N028
1320E EGYPTIAN HIEROGLYPH N029
1320F EGYPTIAN HIEROGLYPH N030
13210 EGYPTIAN HIEROGLYPH N031
13211 EGYPTIAN HIEROGLYPH N032
13212 EGYPTIAN HIEROGLYPH N033
13213 EGYPTIAN HIEROGLYPH N033A
13214 EGYPTIAN HIEROGLYPH N034
13215 EGYPTIAN HIEROGLYPH N034A
13216 EGYPTIAN HIEROGLYPH N035
13217 EGYPTIAN HIEROGLYPH N035A
13218 EGYPTIAN HIEROGLYPH N036
13219 EGYPTIAN HIEROGLYPH N037
1321A EGYPTIAN HIEROGLYPH N037A
1321B EGYPTIAN HIEROGLYPH N038
1321C EGYPTIAN HIEROGLYPH N039
1321D EGYPTIAN HIEROGLYPH N040
1321E EGYPTIAN HIEROGLYPH N041
1321F EGYPTIAN HIEROGLYPH N042
13220 EGYPTIAN HIEROGLYPH NL001
13221 EGYPTIAN HIEROGLYPH NL002
13222 EGYPTIAN HIEROGLYPH NL003
13223 EGYPTIAN HIEROGLYPH NL004
13224 EGYPTIAN HIEROGLYPH NL005
13225 EGYPTIAN HIEROGLYPH NL005A
13226 EGYPTIAN HIEROGLYPH NL006
13227 EGYPTIAN HIEROGLYPH NL007
13228 EGYPTIAN HIEROGLYPH NL008
13229 EGYPTIAN HIEROGLYPH NL009
1322A EGYPTIAN HIEROGLYPH NL010
1322B EGYPTIAN HIEROGLYPH NL011
1322C EGYPTIAN HIEROGLYPH NL012
1322D EGYPTIAN HIEROGLYPH NL013
1322E EGYPTIAN HIEROGLYPH NL014
1322F EGYPTIAN HIEROGLYPH NL015
13230 EGYPTIAN HIEROGLYPH NL016
13231 EGYPTIAN HIEROGLYPH NL017
13232 EGYPTIAN HIEROGLYPH NL017A
13233 EGYPTIAN HIEROGLYPH NL018
13234 EGYPTIAN HIEROGLYPH NL019
13235 EGYPTIAN HIEROGLYPH NL020
13236 EGYPTIAN HIEROGLYPH NU001
13237 EGYPTIAN HIEROGLYPH NU002
13238 EGYPTIAN HIEROGLYPH NU003
13239 EGYPTIAN HIEROGLYPH NU004
1323A EGYPTIAN HIEROGLYPH NU005
1323B EGYPTIAN HIEROGLYPH NU006
1323C EGYPTIAN HIEROGLYPH NU007
1323D EGYPTIAN HIEROGLYPH NU008
1323E EGYPTIAN HIEROGLYPH NU009
1323F EGYPTIAN HIEROGLYPH NU010
13240 EGYPTIAN HIEROGLYPH NU010A
13241 EGYPTIAN HIEROGLYPH NU011
13242 EGYPTIAN HIEROGLYPH NU011A
13243 EGYPTIAN HIEROGLYPH NU012
13244 EGYPTIAN HIEROGLYPH NU013
13245 EGYPTIAN HIEROGLYPH NU014
13246 EGYPTIAN HIEROGLYPH NU015
13247 EGYPTIAN HIEROGLYPH NU016
13248 EGYPTIAN HIEROGLYPH NU017
13249 EGYPTIAN HIEROGLYPH NU018
1324A EGYPTIAN HIEROGLYPH NU018A
1324B EGYPTIAN HIEROGLYPH NU019
1324C EGYPTIAN HIEROGLYPH NU020
1324D EGYPTIAN HIEROGLYPH NU021
1324E EGYPTIAN HIEROGLYPH NU022
1324F EGYPTIAN HIEROGLYPH NU022A
13250 EGYPTIAN HIEROGLYPH O001
13251 EGYPTIAN HIEROGLYPH O001A
13252 EGYPTIAN HIEROGLYPH O002
13253 EGYPTIAN HIEROGLYPH O003
13254 EGYPTIAN HIEROGLYPH O004
13255 EGYPTIAN HIEROGLYPH O005
13256 EGYPTIAN HIEROGLYPH O005A
13257 EGYPTIAN HIEROGLYPH O006
13258 EGYPTIAN HIEROGLYPH O006A
13259 EGYPTIAN HIEROGLYPH O006B
1325A EGYPTIAN HIEROGLYPH O006C
1325B EGYPTIAN HIEROGLYPH O006D
1325C EGYPTIAN HIEROGLYPH O006E
1325D EGYPTIAN HIEROGLYPH O006F
1325E EGYPTIAN HIEROGLYPH O007
1325F EGYPTIAN HIEROGLYPH O008
13260 EGYPTIAN HIEROGLYPH O009
13261 EGYPTIAN HIEROGLYPH O010
13262 EGYPTIAN HIEROGLYPH O010A
13263 EGYPTIAN HIEROGLYPH O010B
13264 EGYPTIAN HIEROGLYPH O010C
13265 EGYPTIAN HIEROGLYPH O011
13266 EGYPTIAN HIEROGLYPH O012
13267 EGYPTIAN HIEROGLYPH O013
13268 EGYPTIAN HIEROGLYPH O014
13269 EGYPTIAN HIEROGLYPH O015
1326A EGYPTIAN HIEROGLYPH O016
1326B EGYPTIAN HIEROGLYPH O017
1326C EGYPTIAN HIEROGLYPH O018
1326D EGYPTIAN HIEROGLYPH O019
1326E EGYPTIAN HIEROGLYPH O019A
1326F EGYPTIAN HIEROGLYPH O020
13270 EGYPTIAN HIEROGLYPH O020A
13271 EGYPTIAN HIEROGLYPH O021
13272 EGYPTIAN HIEROGLYPH O022
13273 EGYPTIAN HIEROGLYPH O023
13274 EGYPTIAN HIEROGLYPH O024
13275 EGYPTIAN HIEROGLYPH O024A
13276 EGYPTIAN HIEROGLYPH O025
13277 EGYPTIAN HIEROGLYPH O025A
13278 EGYPTIAN HIEROGLYPH O026
13279 EGYPTIAN HIEROGLYPH O027
1327A EGYPTIAN HIEROGLYPH O028
1327B EGYPTIAN HIEROGLYPH O029
1327C EGYPTIAN HIEROGLYPH O029A
1327D EGYPTIAN HIEROGLYPH O030
1327E EGYPTIAN HIEROGLYPH O030A
1327F EGYPTIAN HIEROGLYPH O031
13280 EGYPTIAN HIEROGLYPH O032
13281 EGYPTIAN HIEROGLYPH O033
13282 EGYPTIAN HIEROGLYPH O033A
13283 EGYPTIAN HIEROGLYPH O034
13284 EGYPTIAN HIEROGLYPH O035
13285 EGYPTIAN HIEROGLYPH O036
13286 EGYPTIAN HIEROGLYPH O036A
13287 EGYPTIAN HIEROGLYPH O036B
13288 EGYPTIAN HIEROGLYPH O036C
13289 EGYPTIAN HIEROGLYPH O036D
1328A EGYPTIAN HIEROGLYPH O037
1328B EGYPTIAN HIEROGLYPH O038
1328C EGYPTIAN HIEROGLYPH O039
1328D EGYPTIAN HIEROGLYPH O040
1328E EGYPTIAN HIEROGLYPH O041
1328F EGYPTIAN HIEROGLYPH O042
13290 EGYPTIAN HIEROGLYPH O043
13291 EGYPTIAN HIEROGLYPH O044
13292 EGYPTIAN HIEROGLYPH O045
13293 EGYPTIAN HIEROGLYPH O046
13294 EGYPTIAN HIEROGLYPH O047
13295 EGYPTIAN HIEROGLYPH O048
13296 EGYPTIAN HIEROGLYPH O049
13297 EGYPTIAN HIEROGLYPH O050
13298 EGYPTIAN HIEROGLYPH O050A
13299 EGYPTIAN HIEROGLYPH O050B
1329A EGYPTIAN HIEROGLYPH O051
1329B EGYPTIAN HIEROGLYPH P001
1329C EGYPTIAN HIEROGLYPH P001A
1329D EGYPTIAN HIEROGLYPH P002
1329E EGYPTIAN HIEROGLYPH P003
1329F EGYPTIAN HIEROGLYPH P003A
132A0 EGYPTIAN HIEROGLYPH P004
132A1 EGYPTIAN HIEROGLYPH P005
132A2 EGYPTIAN HIEROGLYPH P006
132A3 EGYPTIAN HIEROGLYPH P007
132A4 EGYPTIAN HIEROGLYPH P008
132A5 EGYPTIAN HIEROGLYPH P009
132A6 EGYPTIAN HIEROGLYPH P010
132A7 EGYPTIAN HIEROGLYPH P011
132A8 EGYPTIAN HIEROGLYPH Q001
132A9 EGYPTIAN HIEROGLYPH Q002
132AA EGYPTIAN HIEROGLYPH Q003
132AB EGYPTIAN HIEROGLYPH Q004
132AC EGYPTIAN HIEROGLYPH Q005
132AD EGYPTIAN HIEROGLYPH Q006
132AE EGYPTIAN HIEROGLYPH Q007
132AF EGYPTIAN HIEROGLYPH R001
132B0 EGYPTIAN HIEROGLYPH R002
132B1 EGYPTIAN HIEROGLYPH R002A
132B2 EGYPTIAN HIEROGLYPH R003
132B3 EGYPTIAN HIEROGLYPH R003A
132B4 EGYPTIAN HIEROGLYPH R003B
132B5 EGYPTIAN HIEROGLYPH R004
132B6 EGYPTIAN HIEROGLYPH R005
132B7 EGYPTIAN HIEROGLYPH R006
132B8 EGYPTIAN HIEROGLYPH R007
132B9 EGYPTIAN HIEROGLYPH R008
132BA EGYPTIAN HIEROGLYPH R009
132BB EGYPTIAN HIEROGLYPH R010
132BC EGYPTIAN HIEROGLYPH R010A
132BD EGYPTIAN HIEROGLYPH R011
132BE EGYPTIAN HIEROGLYPH R012
132BF EGYPTIAN HIEROGLYPH R013
132C0 EGYPTIAN HIEROGLYPH R014
132C1 EGYPTIAN HIEROGLYPH R015
132C2 EGYPTIAN HIEROGLYPH R016
132C3 EGYPTIAN HIEROGLYPH R016A
132C4 EGYPTIAN HIEROGLYPH R017
132C5 EGYPTIAN HIEROGLYPH R018
132C6 EGYPTIAN HIEROGLYPH R019
132C7 EGYPTIAN HIEROGLYPH R020
132C8 EGYPTIAN HIEROGLYPH R021
132C9 EGYPTIAN HIEROGLYPH R022
132CA EGYPTIAN HIEROGLYPH R023
132CB EGYPTIAN HIEROGLYPH R024
132CC EGYPTIAN HIEROGLYPH R025
132CD EGYPTIAN HIEROGLYPH R026
132CE EGYPTIAN HIEROGLYPH R027
132CF EGYPTIAN HIEROGLYPH R028
132D0 EGYPTIAN HIEROGLYPH R029
132D1 EGYPTIAN HIEROGLYPH S001
132D2 EGYPTIAN HIEROGLYPH S002
132D3 EGYPTIAN HIEROGLYPH S002A
132D4 EGYPTIAN HIEROGLYPH S003
132D5 EGYPTIAN HIEROGLYPH S004
132D6 EGYPTIAN HIEROGLYPH S005
132D7 EGYPTIAN HIEROGLYPH S006
132D8 EGYPTIAN HIEROGLYPH S006A
132D9 EGYPTIAN HIEROGLYPH S007
132DA EGYPTIAN HIEROGLYPH S008
132DB EGYPTIAN HIEROGLYPH S009
132DC EGYPTIAN HIEROGLYPH S010
132DD EGYPTIAN HIEROGLYPH S011
132DE EGYPTIAN HIEROGLYPH S012
132DF EGYPTIAN HIEROGLYPH S013
132E0 EGYPTIAN HIEROGLYPH S014
132E1 EGYPTIAN HIEROGLYPH S014A
132E2 EGYPTIAN HIEROGLYPH S014B
132E3 EGYPTIAN HIEROGLYPH S015
132E4 EGYPTIAN HIEROGLYPH S016
132E5 EGYPTIAN HIEROGLYPH S017
132E6 EGYPTIAN HIEROGLYPH S017A
132E7 EGYPTIAN HIEROGLYPH S018
132E8 EGYPTIAN HIEROGLYPH S019
132E9 EGYPTIAN HIEROGLYPH S020
132EA EGYPTIAN HIEROGLYPH S021
132EB EGYPTIAN HIEROGLYPH S022
132EC EGYPTIAN HIEROGLYPH S023
132ED EGYPTIAN HIEROGLYPH S024
132EE EGYPTIAN HIEROGLYPH S025
132EF EGYPTIAN HIEROGLYPH S026
132F0 EGYPTIAN HIEROGLYPH S026A
132F1 EGYPTIAN HIEROGLYPH S026B
132F2 EGYPTIAN HIEROGLYPH S027
132F3 EGYPTIAN HIEROGLYPH S028
132F4 EGYPTIAN HIEROGLYPH S029
132F5 EGYPTIAN HIEROGLYPH S030
132F6 EGYPTIAN HIEROGLYPH S031
132F7 EGYPTIAN HIEROGLYPH S032
132F8 EGYPTIAN HIEROGLYPH S033
132F9 EGYPTIAN HIEROGLYPH S034
132FA EGYPTIAN HIEROGLYPH S035
132FB EGYPTIAN HIEROGLYPH S035A
132FC EGYPTIAN HIEROGLYPH S036
132FD EGYPTIAN HIEROGLYPH S037
132FE EGYPTIAN HIEROGLYPH S038
132FF EGYPTIAN HIEROGLYPH S039
13300 EGYPTIAN HIEROGLYPH S040
13301 EGYPTIAN HIEROGLYPH S041
13302 EGYPTIAN HIEROGLYPH S042
13303 EGYPTIAN HIEROGLYPH S043
13304 EGYPTIAN HIEROGLYPH S044
13305 EGYPTIAN HIEROGLYPH S045
13306 EGYPTIAN HIEROGLYPH S046
13307 EGYPTIAN HIEROGLYPH T001
13308 EGYPTIAN HIEROGLYPH T002
13309 EGYPTIAN HIEROGLYPH T003
1330A EGYPTIAN HIEROGLYPH T003A
1330B EGYPTIAN HIEROGLYPH T004
1330C EGYPTIAN HIEROGLYPH T005
1330D EGYPTIAN HIEROGLYPH T006
1330E EGYPTIAN HIEROGLYPH T007
1330F EGYPTIAN HIEROGLYPH T007A
13310 EGYPTIAN HIEROGLYPH T008
13311 EGYPTIAN HIEROGLYPH T008A
13312 EGYPTIAN HIEROGLYPH T009
13313 EGYPTIAN HIEROGLYPH T009A
13314 EGYPTIAN HIEROGLYPH T010
13315 EGYPTIAN HIEROGLYPH T011
13316 EGYPTIAN HIEROGLYPH T011A
13317 EGYPTIAN HIEROGLYPH T012
13318 EGYPTIAN HIEROGLYPH T013
13319 EGYPTIAN HIEROGLYPH T014
1331A EGYPTIAN HIEROGLYPH T015
1331B EGYPTIAN HIEROGLYPH T016
1331C EGYPTIAN HIEROGLYPH T016A
1331D EGYPTIAN HIEROGLYPH T017
1331E EGYPTIAN HIEROGLYPH T018
1331F EGYPTIAN HIEROGLYPH T019
13320 EGYPTIAN HIEROGLYPH T020
13321 EGYPTIAN HIEROGLYPH T021
13322 EGYPTIAN HIEROGLYPH T022
13323 EGYPTIAN HIEROGLYPH T023
13324 EGYPTIAN HIEROGLYPH T024
13325 EGYPTIAN HIEROGLYPH T025
13326 EGYPTIAN HIEROGLYPH T026
13327 EGYPTIAN HIEROGLYPH T027
13328 EGYPTIAN HIEROGLYPH T028
13329 EGYPTIAN HIEROGLYPH T029
1332A EGYPTIAN HIEROGLYPH T030
1332B EGYPTIAN HIEROGLYPH T031
1332C EGYPTIAN HIEROGLYPH T032
1332D EGYPTIAN HIEROGLYPH T032A
1332E EGYPTIAN HIEROGLYPH T033
1332F EGYPTIAN HIEROGLYPH T033A
13330 EGYPTIAN HIEROGLYPH T034
13331 EGYPTIAN HIEROGLYPH T035
13332 EGYPTIAN HIEROGLYPH T036
13333 EGYPTIAN HIEROGLYPH U001
13334 EGYPTIAN HIEROGLYPH U002
13335 EGYPTIAN HIEROGLYPH U003
13336 EGYPTIAN HIEROGLYPH U004
13337 EGYPTIAN HIEROGLYPH U005
13338 EGYPTIAN HIEROGLYPH U006
13339 EGYPTIAN HIEROGLYPH U006A
1333A EGYPTIAN HIEROGLYPH U006B
1333B EGYPTIAN HIEROGLYPH U007
1333C EGYPTIAN HIEROGLYPH U008
1333D EGYPTIAN HIEROGLYPH U009
1333E EGYPTIAN HIEROGLYPH U010
1333F EGYPTIAN HIEROGLYPH U011
13340 EGYPTIAN HIEROGLYPH U012
13341 EGYPTIAN HIEROGLYPH U013
13342 EGYPTIAN HIEROGLYPH U014
13343 EGYPTIAN HIEROGLYPH U015
13344 EGYPTIAN HIEROGLYPH U016
13345 EGYPTIAN HIEROGLYPH U017
13346 EGYPTIAN HIEROGLYPH U018
13347 EGYPTIAN HIEROGLYPH U019
13348 EGYPTIAN HIEROGLYPH U020
13349 EGYPTIAN HIEROGLYPH U021
1334A EGYPTIAN HIEROGLYPH U022
1334B EGYPTIAN HIEROGLYPH U023
1334C EGYPTIAN HIEROGLYPH U023A
1334D EGYPTIAN HIEROGLYPH U024
1334E EGYPTIAN HIEROGLYPH U025
1334F EGYPTIAN HIEROGLYPH U026
13350 EGYPTIAN HIEROGLYPH U027
13351 EGYPTIAN HIEROGLYPH U028
13352 EGYPTIAN HIEROGLYPH U029
13353 EGYPTIAN HIEROGLYPH U029A
13354 EGYPTIAN HIEROGLYPH U030
13355 EGYPTIAN HIEROGLYPH U031
13356 EGYPTIAN HIEROGLYPH U032
13357 EGYPTIAN HIEROGLYPH U032A
13358 EGYPTIAN HIEROGLYPH U033
13359 EGYPTIAN HIEROGLYPH U034
1335A EGYPTIAN HIEROGLYPH U035
1335B EGYPTIAN HIEROGLYPH U036
1335C EGYPTIAN HIEROGLYPH U037
1335D EGYPTIAN HIEROGLYPH U038
1335E EGYPTIAN HIEROGLYPH U039
1335F EGYPTIAN HIEROGLYPH U040
13360 EGYPTIAN HIEROGLYPH U041
13361 EGYPTIAN HIEROGLYPH U042
13362 EGYPTIAN HIEROGLYPH V001
13363 EGYPTIAN HIEROGLYPH V001A
13364 EGYPTIAN HIEROGLYPH V001B
13365 EGYPTIAN HIEROGLYPH V001C
13366 EGYPTIAN HIEROGLYPH V001D
13367 EGYPTIAN HIEROGLYPH V001E
13368 EGYPTIAN HIEROGLYPH V001F
13369 EGYPTIAN HIEROGLYPH V001G
1336A EGYPTIAN HIEROGLYPH V001H
1336B EGYPTIAN HIEROGLYPH V001I
1336C EGYPTIAN HIEROGLYPH V002
1336D EGYPTIAN HIEROGLYPH V002A
1336E EGYPTIAN HIEROGLYPH V003
1336F EGYPTIAN HIEROGLYPH V004
13370 EGYPTIAN HIEROGLYPH V005
13371 EGYPTIAN HIEROGLYPH V006
13372 EGYPTIAN HIEROGLYPH V007
13373 EGYPTIAN HIEROGLYPH V007A
13374 EGYPTIAN HIEROGLYPH V007B
13375 EGYPTIAN HIEROGLYPH V008
13376 EGYPTIAN HIEROGLYPH V009
13377 EGYPTIAN HIEROGLYPH V010
13378 EGYPTIAN HIEROGLYPH V011
13379 EGYPTIAN HIEROGLYPH V011A
1337A EGYPTIAN HIEROGLYPH V011B
1337B EGYPTIAN HIEROGLYPH V011C
1337C EGYPTIAN HIEROGLYPH V012
1337D EGYPTIAN HIEROGLYPH V012A
1337E EGYPTIAN HIEROGLYPH V012B
1337F EGYPTIAN HIEROGLYPH V013
13380 EGYPTIAN HIEROGLYPH V014
13381 EGYPTIAN HIEROGLYPH V015
13382 EGYPTIAN HIEROGLYPH V016
13383 EGYPTIAN HIEROGLYPH V017
13384 EGYPTIAN HIEROGLYPH V018
13385 EGYPTIAN HIEROGLYPH V019
13386 EGYPTIAN HIEROGLYPH V020
13387 EGYPTIAN HIEROGLYPH V020A
13388 EGYPTIAN HIEROGLYPH V020B
13389 EGYPTIAN HIEROGLYPH V020C
1338A EGYPTIAN HIEROGLYPH V020D
1338B EGYPTIAN HIEROGLYPH V020E
1338C EGYPTIAN HIEROGLYPH V020F
1338D EGYPTIAN HIEROGLYPH V020G
1338E EGYPTIAN HIEROGLYPH V020H
1338F EGYPTIAN HIEROGLYPH V020I
13390 EGYPTIAN HIEROGLYPH V020J
13391 EGYPTIAN HIEROGLYPH V020K
13392 EGYPTIAN HIEROGLYPH V020L
13393 EGYPTIAN HIEROGLYPH V021
13394 EGYPTIAN HIEROGLYPH V022
13395 EGYPTIAN HIEROGLYPH V023
13396 EGYPTIAN HIEROGLYPH V023A
13397 EGYPTIAN HIEROGLYPH V024
13398 EGYPTIAN HIEROGLYPH V025
13399 EGYPTIAN HIEROGLYPH V026
1339A EGYPTIAN HIEROGLYPH V027
1339B EGYPTIAN HIEROGLYPH V028
1339C EGYPTIAN HIEROGLYPH V028A
1339D EGYPTIAN HIEROGLYPH V029
1339E EGYPTIAN HIEROGLYPH V029A
1339F EGYPTIAN HIEROGLYPH V030
133A0 EGYPTIAN HIEROGLYPH V030A
133A1 EGYPTIAN HIEROGLYPH V031
133A2 EGYPTIAN HIEROGLYPH V031A
133A3 EGYPTIAN HIEROGLYPH V032
133A4 EGYPTIAN HIEROGLYPH V033
133A5 EGYPTIAN HIEROGLYPH V033A
133A6 EGYPTIAN HIEROGLYPH V034
133A7 EGYPTIAN HIEROGLYPH V035
133A8 EGYPTIAN HIEROGLYPH V036
133A9 EGYPTIAN HIEROGLYPH V037
133AA EGYPTIAN HIEROGLYPH V037A
133AB EGYPTIAN HIEROGLYPH V038
133AC EGYPTIAN HIEROGLYPH V039
133AD EGYPTIAN HIEROGLYPH V040
133AE EGYPTIAN HIEROGLYPH V040A
133AF EGYPTIAN HIEROGLYPH W001
133B0 EGYPTIAN HIEROGLYPH W002
133B1 EGYPTIAN HIEROGLYPH W003
133B2 EGYPTIAN HIEROGLYPH W003A
133B3 EGYPTIAN HIEROGLYPH W004
133B4 EGYPTIAN HIEROGLYPH W005
133B5 EGYPTIAN HIEROGLYPH W006
133B6 EGYPTIAN HIEROGLYPH W007
133B7 EGYPTIAN HIEROGLYPH W008
133B8 EGYPTIAN HIEROGLYPH W009
133B9 EGYPTIAN HIEROGLYPH W009A
133BA EGYPTIAN HIEROGLYPH W010
133BB EGYPTIAN HIEROGLYPH W010A
133BC EGYPTIAN HIEROGLYPH W011
133BD EGYPTIAN HIEROGLYPH W012
133BE EGYPTIAN HIEROGLYPH W013
133BF EGYPTIAN HIEROGLYPH W014
133C0 EGYPTIAN HIEROGLYPH W014A
133C1 EGYPTIAN HIEROGLYPH W015
133C2 EGYPTIAN HIEROGLYPH W016
133C3 EGYPTIAN HIEROGLYPH W017
133C4 EGYPTIAN HIEROGLYPH W017A
133C5 EGYPTIAN HIEROGLYPH W018
133C6 EGYPTIAN HIEROGLYPH W018A
133C7 EGYPTIAN HIEROGLYPH W019
133C8 EGYPTIAN HIEROGLYPH W020
133C9 EGYPTIAN HIEROGLYPH W021
133CA EGYPTIAN HIEROGLYPH W022
133CB EGYPTIAN HIEROGLYPH W023
133CC EGYPTIAN HIEROGLYPH W024
133CD EGYPTIAN HIEROGLYPH W024A
133CE EGYPTIAN HIEROGLYPH W025
133CF EGYPTIAN HIEROGLYPH X001
133D0 EGYPTIAN HIEROGLYPH X002
133D1 EGYPTIAN HIEROGLYPH X003
133D2 EGYPTIAN HIEROGLYPH X004
133D3 EGYPTIAN HIEROGLYPH X004A
133D4 EGYPTIAN HIEROGLYPH X004B
133D5 EGYPTIAN HIEROGLYPH X005
133D6 EGYPTIAN HIEROGLYPH X006
133D7 EGYPTIAN HIEROGLYPH X006A
133D8 EGYPTIAN HIEROGLYPH X007
133D9 EGYPTIAN HIEROGLYPH X008
133DA EGYPTIAN HIEROGLYPH X008A
133DB EGYPTIAN HIEROGLYPH Y001
133DC EGYPTIAN HIEROGLYPH Y001A
133DD EGYPTIAN HIEROGLYPH Y002
133DE EGYPTIAN HIEROGLYPH Y003
133DF EGYPTIAN HIEROGLYPH Y004
133E0 EGYPTIAN HIEROGLYPH Y005
133E1 EGYPTIAN HIEROGLYPH Y006
133E2 EGYPTIAN HIEROGLYPH Y007
133E3 EGYPTIAN HIEROGLYPH Y008
133E4 EGYPTIAN HIEROGLYPH Z001
133E5 EGYPTIAN HIEROGLYPH Z002
133E6 EGYPTIAN HIEROGLYPH Z002A
133E7 EGYPTIAN HIEROGLYPH Z002B
133E8 EGYPTIAN HIEROGLYPH Z002C
133E9 EGYPTIAN HIEROGLYPH Z002D
133EA EGYPTIAN HIEROGLYPH Z003
133EB EGYPTIAN HIEROGLYPH Z003A
133EC EGYPTIAN HIEROGLYPH Z003B
133ED EGYPTIAN HIEROGLYPH Z004
133EE EGYPTIAN HIEROGLYPH Z004A
133EF EGYPTIAN HIEROGLYPH Z005
133F0 EGYPTIAN HIEROGLYPH Z005A
133F1 EGYPTIAN HIEROGLYPH Z006
133F2 EGYPTIAN HIEROGLYPH Z007
133F3 EGYPTIAN HIEROGLYPH Z008
133F4 EGYPTIAN HIEROGLYPH Z009
133F5 EGYPTIAN HIEROGLYPH Z010
133F6 EGYPTIAN HIEROGLYPH Z011
133F7 EGYPTIAN HIEROGLYPH Z012
133F8 EGYPTIAN HIEROGLYPH Z013
133F9 EGYPTIAN HIEROGLYPH Z014
133FA EGYPTIAN HIEROGLYPH Z015
133FB EGYPTIAN HIEROGLYPH Z015A
133FC EGYPTIAN HIEROGLYPH Z015B
133FD EGYPTIAN HIEROGLYPH Z015C
133FE EGYPTIAN HIEROGLYPH Z015D
133FF EGYPTIAN HIEROGLYPH Z015E
13400 EGYPTIAN HIEROGLYPH Z015F
13401 EGYPTIAN HIEROGLYPH Z015G
13402 EGYPTIAN HIEROGLYPH Z015H
13403 EGYPTIAN HIEROGLYPH Z015I
13404 EGYPTIAN HIEROGLYPH Z016
13405 EGYPTIAN HIEROGLYPH Z016A
13406 EGYPTIAN HIEROGLYPH Z016B
13407 EGYPTIAN HIEROGLYPH Z016C
13408 EGYPTIAN HIEROGLYPH Z016D
13409 EGYPTIAN HIEROGLYPH Z016E
1340A EGYPTIAN HIEROGLYPH Z016F
1340B EGYPTIAN HIEROGLYPH Z016G
1340C EGYPTIAN HIEROGLYPH Z016H
1340D EGYPTIAN HIEROGLYPH AA001
1340E EGYPTIAN HIEROGLYPH AA002
1340F EGYPTIAN HIEROGLYPH AA003
13410 EGYPTIAN HIEROGLYPH AA004
13411 EGYPTIAN HIEROGLYPH AA005
13412 EGYPTIAN HIEROGLYPH AA006
13413 EGYPTIAN HIEROGLYPH AA007
13414 EGYPTIAN HIEROGLYPH AA007A
13415 EGYPTIAN HIEROGLYPH AA007B
13416 EGYPTIAN HIEROGLYPH AA008
13417 EGYPTIAN HIEROGLYPH AA009
13418 EGYPTIAN HIEROGLYPH AA010
13419 EGYPTIAN HIEROGLYPH AA011
1341A EGYPTIAN HIEROGLYPH AA012
1341B EGYPTIAN HIEROGLYPH AA013
1341C EGYPTIAN HIEROGLYPH AA014
1341D EGYPTIAN HIEROGLYPH AA015
1341E EGYPTIAN HIEROGLYPH AA016
1341F EGYPTIAN HIEROGLYPH AA017
13420 EGYPTIAN HIEROGLYPH AA018
13421 EGYPTIAN HIEROGLYPH AA019
13422 EGYPTIAN HIEROGLYPH AA020
13423 EGYPTIAN HIEROGLYPH AA021
13424 EGYPTIAN HIEROGLYPH AA022
13425 EGYPTIAN HIEROGLYPH AA023
13426 EGYPTIAN HIEROGLYPH AA024
13427 EGYPTIAN HIEROGLYPH AA025
13428 EGYPTIAN HIEROGLYPH AA026
13429 EGYPTIAN HIEROGLYPH AA027
1342A EGYPTIAN HIEROGLYPH AA028
1342B EGYPTIAN HIEROGLYPH AA029
1342C EGYPTIAN HIEROGLYPH AA030
1342D EGYPTIAN HIEROGLYPH AA031
1342E EGYPTIAN HIEROGLYPH AA032
14400 ANATOLIAN HIEROGLYPH A001
14401 ANATOLIAN HIEROGLYPH A002
14402 ANATOLIAN HIEROGLYPH A003
14403 ANATOLIAN HIEROGLYPH A004
14404 ANATOLIAN HIEROGLYPH A005
14405 ANATOLIAN HIEROGLYPH A006
14406 ANATOLIAN HIEROGLYPH A007
14407 ANATOLIAN HIEROGLYPH A008
14408 ANATOLIAN HIEROGLYPH A009
14409 ANATOLIAN HIEROGLYPH A010
1440A ANATOLIAN HIEROGLYPH A010A
1440B ANATOLIAN HIEROGLYPH A011
1440C ANATOLIAN HIEROGLYPH A012
1440D ANATOLIAN HIEROGLYPH A013
1440E ANATOLIAN HIEROGLYPH A014
1440F ANATOLIAN HIEROGLYPH A015
14410 ANATOLIAN HIEROGLYPH A016
14411 ANATOLIAN HIEROGLYPH A017
14412 ANATOLIAN HIEROGLYPH A018
14413 ANATOLIAN HIEROGLYPH A019
14414 ANATOLIAN HIEROGLYPH A020
14415 ANATOLIAN HIEROGLYPH A021
14416 ANATOLIAN HIEROGLYPH A022
14417 ANATOLIAN HIEROGLYPH A023
14418 ANATOLIAN HIEROGLYPH A024
14419 ANATOLIAN HIEROGLYPH A025
1441A ANATOLIAN HIEROGLYPH A026
1441B ANATOLIAN HIEROGLYPH A026A
1441C ANATOLIAN HIEROGLYPH A027
1441D ANATOLIAN HIEROGLYPH A028
1441E ANATOLIAN HIEROGLYPH A029
1441F ANATOLIAN HIEROGLYPH A030
14420 ANATOLIAN HIEROGLYPH A031
14421 ANATOLIAN HIEROGLYPH A032
14422 ANATOLIAN HIEROGLYPH A033
14423 ANATOLIAN HIEROGLYPH A034
14424 ANATOLIAN HIEROGLYPH A035
14425 ANATOLIAN HIEROGLYPH A036
14426 ANATOLIAN HIEROGLYPH A037
14427 ANATOLIAN HIEROGLYPH A038
14428 ANATOLIAN HIEROGLYPH A039
14429 ANATOLIAN HIEROGLYPH A039A
1442A ANATOLIAN HIEROGLYPH A040
1442B ANATOLIAN HIEROGLYPH A041
1442C ANATOLIAN HIEROGLYPH A041A
1442D ANATOLIAN HIEROGLYPH A042
1442E ANATOLIAN HIEROGLYPH A043
1442F ANATOLIAN HIEROGLYPH A044
14430 ANATOLIAN HIEROGLYPH A045
14431 ANATOLIAN HIEROGLYPH A045A
14432 ANATOLIAN HIEROGLYPH A046
14433 ANATOLIAN HIEROGLYPH A046A
14434 ANATOLIAN HIEROGLYPH A046B
14435 ANATOLIAN HIEROGLYPH A047
14436 ANATOLIAN HIEROGLYPH A048
14437 ANATOLIAN HIEROGLYPH A049
14438 ANATOLIAN HIEROGLYPH A050
14439 ANATOLIAN HIEROGLYPH A051
1443A ANATOLIAN HIEROGLYPH A052
1443B ANATOLIAN HIEROGLYPH A053
1443C ANATOLIAN HIEROGLYPH A054
1443D ANATOLIAN HIEROGLYPH A055
1443E ANATOLIAN HIEROGLYPH A056
1443F ANATOLIAN HIEROGLYPH A057
14440 ANATOLIAN HIEROGLYPH A058
14441 ANATOLIAN HIEROGLYPH A059
14442 ANATOLIAN HIEROGLYPH A060
14443 ANATOLIAN HIEROGLYPH A061
14444 ANATOLIAN HIEROGLYPH A062
14445 ANATOLIAN HIEROGLYPH A063
14446 ANATOLIAN HIEROGLYPH A064
14447 ANATOLIAN HIEROGLYPH A065
14448 ANATOLIAN HIEROGLYPH A066
14449 ANATOLIAN HIEROGLYPH A066A
1444A ANATOLIAN HIEROGLYPH A066B
1444B ANATOLIAN HIEROGLYPH A066C
1444C ANATOLIAN HIEROGLYPH A067
1444D ANATOLIAN HIEROGLYPH A068
1444E ANATOLIAN HIEROGLYPH A069
1444F ANATOLIAN HIEROGLYPH A070
14450 ANATOLIAN HIEROGLYPH A071
14451 ANATOLIAN HIEROGLYPH A072
14452 ANATOLIAN HIEROGLYPH A073
14453 ANATOLIAN HIEROGLYPH A074
14454 ANATOLIAN HIEROGLYPH A075
14455 ANATOLIAN HIEROGLYPH A076
14456 ANATOLIAN HIEROGLYPH A077
14457 ANATOLIAN HIEROGLYPH A078
14458 ANATOLIAN HIEROGLYPH A079
14459 ANATOLIAN HIEROGLYPH A080
1445A ANATOLIAN HIEROGLYPH A081
1445B ANATOLIAN HIEROGLYPH A082
1445C ANATOLIAN HIEROGLYPH A083
1445D ANATOLIAN HIEROGLYPH A084
1445E ANATOLIAN HIEROGLYPH A085
1445F ANATOLIAN HIEROGLYPH A086
14460 ANATOLIAN HIEROGLYPH A087
14461 ANATOLIAN HIEROGLYPH A088
14462 ANATOLIAN HIEROGLYPH A089
14463 ANATOLIAN HIEROGLYPH A090
14464 ANATOLIAN HIEROGLYPH A091
14465 ANATOLIAN HIEROGLYPH A092
14466 ANATOLIAN HIEROGLYPH A093
14467 ANATOLIAN HIEROGLYPH A094
14468 ANATOLIAN HIEROGLYPH A095
14469 ANATOLIAN HIEROGLYPH A096
1446A ANATOLIAN HIEROGLYPH A097
1446B ANATOLIAN HIEROGLYPH A097A
1446C ANATOLIAN HIEROGLYPH A098
1446D ANATOLIAN HIEROGLYPH A098A
1446E ANATOLIAN HIEROGLYPH A099
1446F ANATOLIAN HIEROGLYPH A100
14470 ANATOLIAN HIEROGLYPH A100A
14471 ANATOLIAN HIEROGLYPH A101
14472 ANATOLIAN HIEROGLYPH A101A
14473 ANATOLIAN HIEROGLYPH A102
14474 ANATOLIAN HIEROGLYPH A102A
14475 ANATOLIAN HIEROGLYPH A103
14476 ANATOLIAN HIEROGLYPH A104
14477 ANATOLIAN HIEROGLYPH A104A
14478 ANATOLIAN HIEROGLYPH A104B
14479 ANATOLIAN HIEROGLYPH A104C
1447A ANATOLIAN HIEROGLYPH A105
1447B ANATOLIAN HIEROGLYPH A105A
1447C ANATOLIAN HIEROGLYPH A105B
1447D ANATOLIAN HIEROGLYPH A106
1447E ANATOLIAN HIEROGLYPH A107
1447F ANATOLIAN HIEROGLYPH A107A
14480 ANATOLIAN HIEROGLYPH A107B
14481 ANATOLIAN HIEROGLYPH A107C
14482 ANATOLIAN HIEROGLYPH A108
14483 ANATOLIAN HIEROGLYPH A109
14484 ANATOLIAN HIEROGLYPH A110
14485 ANATOLIAN HIEROGLYPH A110A
14486 ANATOLIAN HIEROGLYPH A110B
14487 ANATOLIAN HIEROGLYPH A111
14488 ANATOLIAN HIEROGLYPH A112
14489 ANATOLIAN HIEROGLYPH A113
1448A ANATOLIAN HIEROGLYPH A114
1448B ANATOLIAN HIEROGLYPH A115
1448C ANATOLIAN HIEROGLYPH A115A
1448D ANATOLIAN HIEROGLYPH A116
1448E ANATOLIAN HIEROGLYPH A117
1448F ANATOLIAN HIEROGLYPH A118
14490 ANATOLIAN HIEROGLYPH A119
14491 ANATOLIAN HIEROGLYPH A120
14492 ANATOLIAN HIEROGLYPH A121
14493 ANATOLIAN HIEROGLYPH A122
14494 ANATOLIAN HIEROGLYPH A123
14495 ANATOLIAN HIEROGLYPH A124
14496 ANATOLIAN HIEROGLYPH A125
14497 ANATOLIAN HIEROGLYPH A125A
14498 ANATOLIAN HIEROGLYPH A126
14499 ANATOLIAN HIEROGLYPH A127
1449A ANATOLIAN HIEROGLYPH A128
1449B ANATOLIAN HIEROGLYPH A129
1449C ANATOLIAN HIEROGLYPH A130
1449D ANATOLIAN HIEROGLYPH A131
1449E ANATOLIAN HIEROGLYPH A132
1449F ANATOLIAN HIEROGLYPH A133
144A0 ANATOLIAN HIEROGLYPH A134
144A1 ANATOLIAN HIEROGLYPH A135
144A2 ANATOLIAN HIEROGLYPH A135A
144A3 ANATOLIAN HIEROGLYPH A136
144A4 ANATOLIAN HIEROGLYPH A137
144A5 ANATOLIAN HIEROGLYPH A138
144A6 ANATOLIAN HIEROGLYPH A139
144A7 ANATOLIAN HIEROGLYPH A140
144A8 ANATOLIAN HIEROGLYPH A141
144A9 ANATOLIAN HIEROGLYPH A142
144AA ANATOLIAN HIEROGLYPH A143
144AB ANATOLIAN HIEROGLYPH A144
144AC ANATOLIAN HIEROGLYPH A145
144AD ANATOLIAN HIEROGLYPH A146
144AE ANATOLIAN HIEROGLYPH A147
144AF ANATOLIAN HIEROGLYPH A148
144B0 ANATOLIAN HIEROGLYPH A149
144B1 ANATOLIAN HIEROGLYPH A150
144B2 ANATOLIAN HIEROGLYPH A151
144B3 ANATOLIAN HIEROGLYPH A152
144B4 ANATOLIAN HIEROGLYPH A153
144B5 ANATOLIAN HIEROGLYPH A154
144B6 ANATOLIAN HIEROGLYPH A155
144B7 ANATOLIAN HIEROGLYPH A156
144B8 ANATOLIAN HIEROGLYPH A157
144B9 ANATOLIAN HIEROGLYPH A158
144BA ANATOLIAN HIEROGLYPH A159
144BB ANATOLIAN HIEROGLYPH A160
144BC ANATOLIAN HIEROGLYPH A161
144BD ANATOLIAN HIEROGLYPH A162
144BE ANATOLIAN HIEROGLYPH A163
144BF ANATOLIAN HIEROGLYPH A164
144C0 ANATOLIAN HIEROGLYPH A165
144C1 ANATOLIAN HIEROGLYPH A166
144C2 ANATOLIAN HIEROGLYPH A167
144C3 ANATOLIAN HIEROGLYPH A168
144C4 ANATOLIAN HIEROGLYPH A169
144C5 ANATOLIAN HIEROGLYPH A170
144C6 ANATOLIAN HIEROGLYPH A171
144C7 ANATOLIAN HIEROGLYPH A172
144C8 ANATOLIAN HIEROGLYPH A173
144C9 ANATOLIAN HIEROGLYPH A174
144CA ANATOLIAN HIEROGLYPH A175
144CB ANATOLIAN HIEROGLYPH A176
144CC ANATOLIAN HIEROGLYPH A177
144CD ANATOLIAN HIEROGLYPH A178
144CE ANATOLIAN HIEROGLYPH A179
144CF ANATOLIAN HIEROGLYPH A180
144D0 ANATOLIAN HIEROGLYPH A181
144D1 ANATOLIAN HIEROGLYPH A182
144D2 ANATOLIAN HIEROGLYPH A183
144D3 ANATOLIAN HIEROGLYPH A184
144D4 ANATOLIAN HIEROGLYPH A185
144D5 ANATOLIAN HIEROGLYPH A186
144D6 ANATOLIAN HIEROGLYPH A187
144D7 ANATOLIAN HIEROGLYPH A188
144D8 ANATOLIAN HIEROGLYPH A189
144D9 ANATOLIAN HIEROGLYPH A190
144DA ANATOLIAN HIEROGLYPH A191
144DB ANATOLIAN HIEROGLYPH A192
144DC ANATOLIAN HIEROGLYPH A193
144DD ANATOLIAN HIEROGLYPH A194
144DE ANATOLIAN HIEROGLYPH A195
144DF ANATOLIAN HIEROGLYPH A196
144E0 ANATOLIAN HIEROGLYPH A197
144E1 ANATOLIAN HIEROGLYPH A198
144E2 ANATOLIAN HIEROGLYPH A199
144E3 ANATOLIAN HIEROGLYPH A200
144E4 ANATOLIAN HIEROGLYPH A201
144E5 ANATOLIAN HIEROGLYPH A202
144E6 ANATOLIAN HIEROGLYPH A202A
144E7 ANATOLIAN HIEROGLYPH A202B
144E8 ANATOLIAN HIEROGLYPH A203
144E9 ANATOLIAN HIEROGLYPH A204
144EA ANATOLIAN HIEROGLYPH A205
144EB ANATOLIAN HIEROGLYPH A206
144EC ANATOLIAN HIEROGLYPH A207
144ED ANATOLIAN HIEROGLYPH A207A
144EE ANATOLIAN HIEROGLYPH A208
144EF ANATOLIAN HIEROGLYPH A209
144F0 ANATOLIAN HIEROGLYPH A209A
144F1 ANATOLIAN HIEROGLYPH A210
144F2 ANATOLIAN HIEROGLYPH A211
144F3 ANATOLIAN HIEROGLYPH A212
144F4 ANATOLIAN HIEROGLYPH A213
144F5 ANATOLIAN HIEROGLYPH A214
144F6 ANATOLIAN HIEROGLYPH A215
144F7 ANATOLIAN HIEROGLYPH A215A
144F8 ANATOLIAN HIEROGLYPH A216
144F9 ANATOLIAN HIEROGLYPH A216A
144FA ANATOLIAN HIEROGLYPH A217
144FB ANATOLIAN HIEROGLYPH A218
144FC ANATOLIAN HIEROGLYPH A219
144FD ANATOLIAN HIEROGLYPH A220
144FE ANATOLIAN HIEROGLYPH A221
144FF ANATOLIAN HIEROGLYPH A222
14500 ANATOLIAN HIEROGLYPH A223
14501 ANATOLIAN HIEROGLYPH A224
14502 ANATOLIAN HIEROGLYPH A225
14503 ANATOLIAN HIEROGLYPH A226
14504 ANATOLIAN HIEROGLYPH A227
14505 ANATOLIAN HIEROGLYPH A227A
14506 ANATOLIAN HIEROGLYPH A228
14507 ANATOLIAN HIEROGLYPH A229
14508 ANATOLIAN HIEROGLYPH A230
14509 ANATOLIAN HIEROGLYPH A231
1450A ANATOLIAN HIEROGLYPH A232
1450B ANATOLIAN HIEROGLYPH A233
1450C ANATOLIAN HIEROGLYPH A234
1450D ANATOLIAN HIEROGLYPH A235
1450E ANATOLIAN HIEROGLYPH A236
1450F ANATOLIAN HIEROGLYPH A237
14510 ANATOLIAN HIEROGLYPH A238
14511 ANATOLIAN HIEROGLYPH A239
14512 ANATOLIAN HIEROGLYPH A240
14513 ANATOLIAN HIEROGLYPH A241
14514 ANATOLIAN HIEROGLYPH A242
14515 ANATOLIAN HIEROGLYPH A243
14516 ANATOLIAN HIEROGLYPH A244
14517 ANATOLIAN HIEROGLYPH A245
14518 ANATOLIAN HIEROGLYPH A246
14519 ANATOLIAN HIEROGLYPH A247
1451A ANATOLIAN HIEROGLYPH A248
1451B ANATOLIAN HIEROGLYPH A249
1451C ANATOLIAN HIEROGLYPH A250
1451D ANATOLIAN HIEROGLYPH A251
1451E ANATOLIAN HIEROGLYPH A252
1451F ANATOLIAN HIEROGLYPH A253
14520 ANATOLIAN HIEROGLYPH A254
14521 ANATOLIAN HIEROGLYPH A255
14522 ANATOLIAN HIEROGLYPH A256
14523 ANATOLIAN HIEROGLYPH A257
14524 ANATOLIAN HIEROGLYPH A258
14525 ANATOLIAN HIEROGLYPH A259
14526 ANATOLIAN HIEROGLYPH A260
14527 ANATOLIAN HIEROGLYPH A261
14528 ANATOLIAN HIEROGLYPH A262
14529 ANATOLIAN HIEROGLYPH A263
1452A ANATOLIAN HIEROGLYPH A264
1452B ANATOLIAN HIEROGLYPH A265
1452C ANATOLIAN HIEROGLYPH A266
1452D ANATOLIAN HIEROGLYPH A267
1452E ANATOLIAN HIEROGLYPH A267A
1452F ANATOLIAN HIEROGLYPH A268
14530 ANATOLIAN HIEROGLYPH A269
14531 ANATOLIAN HIEROGLYPH A270
14532 ANATOLIAN HIEROGLYPH A271
14533 ANATOLIAN HIEROGLYPH A272
14534 ANATOLIAN HIEROGLYPH A273
14535 ANATOLIAN HIEROGLYPH A274
14536 ANATOLIAN HIEROGLYPH A275
14537 ANATOLIAN HIEROGLYPH A276
14538 ANATOLIAN HIEROGLYPH A277
14539 ANATOLIAN HIEROGLYPH A278
1453A ANATOLIAN HIEROGLYPH A279
1453B ANATOLIAN HIEROGLYPH A280
1453C ANATOLIAN HIEROGLYPH A281
1453D ANATOLIAN HIEROGLYPH A282
1453E ANATOLIAN HIEROGLYPH A283
1453F ANATOLIAN HIEROGLYPH A284
14540 ANATOLIAN HIEROGLYPH A285
14541 ANATOLIAN HIEROGLYPH A286
14542 ANATOLIAN HIEROGLYPH A287
14543 ANATOLIAN HIEROGLYPH A288
14544 ANATOLIAN HIEROGLYPH A289
14545 ANATOLIAN HIEROGLYPH A289A
14546 ANATOLIAN HIEROGLYPH A290
14547 ANATOLIAN HIEROGLYPH A291
14548 ANATOLIAN HIEROGLYPH A292
14549 ANATOLIAN HIEROGLYPH A293
1454A ANATOLIAN HIEROGLYPH A294
1454B ANATOLIAN HIEROGLYPH A294A
1454C ANATOLIAN HIEROGLYPH A295
1454D ANATOLIAN HIEROGLYPH A296
1454E ANATOLIAN HIEROGLYPH A297
1454F ANATOLIAN HIEROGLYPH A298
14550 ANATOLIAN HIEROGLYPH A299
14551 ANATOLIAN HIEROGLYPH A299A
14552 ANATOLIAN HIEROGLYPH A300
14553 ANATOLIAN HIEROGLYPH A301
14554 ANATOLIAN HIEROGLYPH A302
14555 ANATOLIAN HIEROGLYPH A303
14556 ANATOLIAN HIEROGLYPH A304
14557 ANATOLIAN HIEROGLYPH A305
14558 ANATOLIAN HIEROGLYPH A306
14559 ANATOLIAN HIEROGLYPH A307
1455A ANATOLIAN HIEROGLYPH A308
1455B ANATOLIAN HIEROGLYPH A309
1455C ANATOLIAN HIEROGLYPH A309A
1455D ANATOLIAN HIEROGLYPH A310
1455E ANATOLIAN HIEROGLYPH A311
1455F ANATOLIAN HIEROGLYPH A312
14560 ANATOLIAN HIEROGLYPH A313
14561 ANATOLIAN HIEROGLYPH A314
14562 ANATOLIAN HIEROGLYPH A315
14563 ANATOLIAN HIEROGLYPH A316
14564 ANATOLIAN HIEROGLYPH A317
14565 ANATOLIAN HIEROGLYPH A318
14566 ANATOLIAN HIEROGLYPH A319
14567 ANATOLIAN HIEROGLYPH A320
14568 ANATOLIAN HIEROGLYPH A321
14569 ANATOLIAN HIEROGLYPH A322
1456A ANATOLIAN HIEROGLYPH A323
1456B ANATOLIAN HIEROGLYPH A324
1456C ANATOLIAN HIEROGLYPH A325
1456D ANATOLIAN HIEROGLYPH A326
1456E ANATOLIAN HIEROGLYPH A327
1456F ANATOLIAN HIEROGLYPH A328
14570 ANATOLIAN HIEROGLYPH A329
14571 ANATOLIAN HIEROGLYPH A329A
14572 ANATOLIAN HIEROGLYPH A330
14573 ANATOLIAN HIEROGLYPH A331
14574 ANATOLIAN HIEROGLYPH A332A
14575 ANATOLIAN HIEROGLYPH A332B
14576 ANATOLIAN HIEROGLYPH A332C
14577 ANATOLIAN HIEROGLYPH A333
14578 ANATOLIAN HIEROGLYPH A334
14579 ANATOLIAN HIEROGLYPH A335
1457A ANATOLIAN HIEROGLYPH A336
1457B ANATOLIAN HIEROGLYPH A336A
1457C ANATOLIAN HIEROGLYPH A336B
1457D ANATOLIAN HIEROGLYPH A336C
1457E ANATOLIAN HIEROGLYPH A337
1457F ANATOLIAN HIEROGLYPH A338
14580 ANATOLIAN HIEROGLYPH A339
14581 ANATOLIAN HIEROGLYPH A340
14582 ANATOLIAN HIEROGLYPH A341
14583 ANATOLIAN HIEROGLYPH A342
14584 ANATOLIAN HIEROGLYPH A343
14585 ANATOLIAN HIEROGLYPH A344
14586 ANATOLIAN HIEROGLYPH A345
14587 ANATOLIAN HIEROGLYPH A346
14588 ANATOLIAN HIEROGLYPH A347
14589 ANATOLIAN HIEROGLYPH A348
1458A ANATOLIAN HIEROGLYPH A349
1458B ANATOLIAN HIEROGLYPH A350
1458C ANATOLIAN HIEROGLYPH A351
1458D ANATOLIAN HIEROGLYPH A352
1458E ANATOLIAN HIEROGLYPH A353
1458F ANATOLIAN HIEROGLYPH A354
14590 ANATOLIAN HIEROGLYPH A355
14591 ANATOLIAN HIEROGLYPH A356
14592 ANATOLIAN HIEROGLYPH A357
14593 ANATOLIAN HIEROGLYPH A358
14594 ANATOLIAN HIEROGLYPH A359
14595 ANATOLIAN HIEROGLYPH A359A
14596 ANATOLIAN HIEROGLYPH A360
14597 ANATOLIAN HIEROGLYPH A361
14598 ANATOLIAN HIEROGLYPH A362
14599 ANATOLIAN HIEROGLYPH A363
1459A ANATOLIAN HIEROGLYPH A364
1459B ANATOLIAN HIEROGLYPH A364A
1459C ANATOLIAN HIEROGLYPH A365
1459D ANATOLIAN HIEROGLYPH A366
1459E ANATOLIAN HIEROGLYPH A367
1459F ANATOLIAN HIEROGLYPH A368
145A0 ANATOLIAN HIEROGLYPH A368A
145A1 ANATOLIAN HIEROGLYPH A369
145A2 ANATOLIAN HIEROGLYPH A370
145A3 ANATOLIAN HIEROGLYPH A371
145A4 ANATOLIAN HIEROGLYPH A371A
145A5 ANATOLIAN HIEROGLYPH A372
145A6 ANATOLIAN HIEROGLYPH A373
145A7 ANATOLIAN HIEROGLYPH A374
145A8 ANATOLIAN HIEROGLYPH A375
145A9 ANATOLIAN HIEROGLYPH A376
145AA ANATOLIAN HIEROGLYPH A377
145AB ANATOLIAN HIEROGLYPH A378
145AC ANATOLIAN HIEROGLYPH A379
145AD ANATOLIAN HIEROGLYPH A380
145AE ANATOLIAN HIEROGLYPH A381
145AF ANATOLIAN HIEROGLYPH A381A
145B0 ANATOLIAN HIEROGLYPH A382
145B1 ANATOLIAN HIEROGLYPH A383 RA OR RI
145B2 ANATOLIAN HIEROGLYPH A383A
145B3 ANATOLIAN HIEROGLYPH A384
145B4 ANATOLIAN HIEROGLYPH A385
145B5 ANATOLIAN HIEROGLYPH A386
145B6 ANATOLIAN HIEROGLYPH A386A
145B7 ANATOLIAN HIEROGLYPH A387
145B8 ANATOLIAN HIEROGLYPH A388
145B9 ANATOLIAN HIEROGLYPH A389
145BA ANATOLIAN HIEROGLYPH A390
145BB ANATOLIAN HIEROGLYPH A391
145BC ANATOLIAN HIEROGLYPH A392
145BD ANATOLIAN HIEROGLYPH A393 EIGHT
145BE ANATOLIAN HIEROGLYPH A394
145BF ANATOLIAN HIEROGLYPH A395
145C0 ANATOLIAN HIEROGLYPH A396
145C1 ANATOLIAN HIEROGLYPH A397
145C2 ANATOLIAN HIEROGLYPH A398
145C3 ANATOLIAN HIEROGLYPH A399
145C4 ANATOLIAN HIEROGLYPH A400
145C5 ANATOLIAN HIEROGLYPH A401
145C6 ANATOLIAN HIEROGLYPH A402
145C7 ANATOLIAN HIEROGLYPH A403
145C8 ANATOLIAN HIEROGLYPH A404
145C9 ANATOLIAN HIEROGLYPH A405
145CA ANATOLIAN HIEROGLYPH A406
145CB ANATOLIAN HIEROGLYPH A407
145CC ANATOLIAN HIEROGLYPH A408
145CD ANATOLIAN HIEROGLYPH A409
145CE ANATOLIAN HIEROGLYPH A410 BEGIN LOGOGRAM MARK
145CF ANATOLIAN HIEROGLYPH A410A END LOGOGRAM MARK
145D0 ANATOLIAN HIEROGLYPH A411
145D1 ANATOLIAN HIEROGLYPH A412
145D2 ANATOLIAN HIEROGLYPH A413
145D3 ANATOLIAN HIEROGLYPH A414
145D4 ANATOLIAN HIEROGLYPH A415
145D5 ANATOLIAN HIEROGLYPH A416
145D6 ANATOLIAN HIEROGLYPH A417
145D7 ANATOLIAN HIEROGLYPH A418
145D8 ANATOLIAN HIEROGLYPH A419
145D9 ANATOLIAN HIEROGLYPH A420
145DA ANATOLIAN HIEROGLYPH A421
145DB ANATOLIAN HIEROGLYPH A422
145DC ANATOLIAN HIEROGLYPH A423
145DD ANATOLIAN HIEROGLYPH A424
145DE ANATOLIAN HIEROGLYPH A425
145DF ANATOLIAN HIEROGLYPH A426
145E0 ANATOLIAN HIEROGLYPH A427
145E1 ANATOLIAN HIEROGLYPH A428
145E2 ANATOLIAN HIEROGLYPH A429
145E3 ANATOLIAN HIEROGLYPH A430
145E4 ANATOLIAN HIEROGLYPH A431
145E5 ANATOLIAN HIEROGLYPH A432
145E6 ANATOLIAN HIEROGLYPH A433
145E7 ANATOLIAN HIEROGLYPH A434
145E8 ANATOLIAN HIEROGLYPH A435
145E9 ANATOLIAN HIEROGLYPH A436
145EA ANATOLIAN HIEROGLYPH A437
145EB ANATOLIAN HIEROGLYPH A438
145EC ANATOLIAN HIEROGLYPH A439
145ED ANATOLIAN HIEROGLYPH A440
145EE ANATOLIAN HIEROGLYPH A441
145EF ANATOLIAN HIEROGLYPH A442
145F0 ANATOLIAN HIEROGLYPH A443
145F1 ANATOLIAN HIEROGLYPH A444
145F2 ANATOLIAN HIEROGLYPH A445
145F3 ANATOLIAN HIEROGLYPH A446
145F4 ANATOLIAN HIEROGLYPH A447
145F5 ANATOLIAN HIEROGLYPH A448
145F6 ANATOLIAN HIEROGLYPH A449
145F7 ANATOLIAN HIEROGLYPH A450
145F8 ANATOLIAN HIEROGLYPH A450A
145F9 ANATOLIAN HIEROGLYPH A451
145FA ANATOLIAN HIEROGLYPH A452
145FB ANATOLIAN HIEROGLYPH A453
145FC ANATOLIAN HIEROGLYPH A454
145FD ANATOLIAN HIEROGLYPH A455
145FE ANATOLIAN HIEROGLYPH A456
145FF ANATOLIAN HIEROGLYPH A457
14600 ANATOLIAN HIEROGLYPH A457A
14601 ANATOLIAN HIEROGLYPH A458
14602 ANATOLIAN HIEROGLYPH A459
14603 ANATOLIAN HIEROGLYPH A460
14604 ANATOLIAN HIEROGLYPH A461
14605 ANATOLIAN HIEROGLYPH A462
14606 ANATOLIAN HIEROGLYPH A463
14607 ANATOLIAN HIEROGLYPH A464
14608 ANATOLIAN HIEROGLYPH A465
14609 ANATOLIAN HIEROGLYPH A466
1460A ANATOLIAN HIEROGLYPH A467
1460B ANATOLIAN HIEROGLYPH A468
1460C ANATOLIAN HIEROGLYPH A469
1460D ANATOLIAN HIEROGLYPH A470
1460E ANATOLIAN HIEROGLYPH A471
1460F ANATOLIAN HIEROGLYPH A472
14610 ANATOLIAN HIEROGLYPH A473
14611 ANATOLIAN HIEROGLYPH A474
14612 ANATOLIAN HIEROGLYPH A475
14613 ANATOLIAN HIEROGLYPH A476
14614 ANATOLIAN HIEROGLYPH A477
14615 ANATOLIAN HIEROGLYPH A478
14616 ANATOLIAN HIEROGLYPH A479
14617 ANATOLIAN HIEROGLYPH A480
14618 ANATOLIAN HIEROGLYPH A481
14619 ANATOLIAN HIEROGLYPH A482
1461A ANATOLIAN HIEROGLYPH A483
1461B ANATOLIAN HIEROGLYPH A484
1461C ANATOLIAN HIEROGLYPH A485
1461D ANATOLIAN HIEROGLYPH A486
1461E ANATOLIAN HIEROGLYPH A487
1461F ANATOLIAN HIEROGLYPH A488
14620 ANATOLIAN HIEROGLYPH A489
14621 ANATOLIAN HIEROGLYPH A490
14622 ANATOLIAN HIEROGLYPH A491
14623 ANATOLIAN HIEROGLYPH A492
14624 ANATOLIAN HIEROGLYPH A493
14625 ANATOLIAN HIEROGLYPH A494
14626 ANATOLIAN HIEROGLYPH A495
14627 ANATOLIAN HIEROGLYPH A496
14628 ANATOLIAN HIEROGLYPH A497
14629 ANATOLIAN HIEROGLYPH A501
1462A ANATOLIAN HIEROGLYPH A502
1462B ANATOLIAN HIEROGLYPH A503
1462C ANATOLIAN HIEROGLYPH A504
1462D ANATOLIAN HIEROGLYPH A505
1462E ANATOLIAN HIEROGLYPH A506
1462F ANATOLIAN HIEROGLYPH A507
14630 ANATOLIAN HIEROGLYPH A508
14631 ANATOLIAN HIEROGLYPH A509
14632 ANATOLIAN HIEROGLYPH A510
14633 ANATOLIAN HIEROGLYPH A511
14634 ANATOLIAN HIEROGLYPH A512
14635 ANATOLIAN HIEROGLYPH A513
14636 ANATOLIAN HIEROGLYPH A514
14637 ANATOLIAN HIEROGLYPH A515
14638 ANATOLIAN HIEROGLYPH A516
14639 ANATOLIAN HIEROGLYPH A517
1463A ANATOLIAN HIEROGLYPH A518
1463B ANATOLIAN HIEROGLYPH A519
1463C ANATOLIAN HIEROGLYPH A520
1463D ANATOLIAN HIEROGLYPH A521
1463E ANATOLIAN HIEROGLYPH A522
1463F ANATOLIAN HIEROGLYPH A523
14640 ANATOLIAN HIEROGLYPH A524
14641 ANATOLIAN HIEROGLYPH A525
14642 ANATOLIAN HIEROGLYPH A526
14643 ANATOLIAN HIEROGLYPH A527
14644 ANATOLIAN HIEROGLYPH A528
14645 ANATOLIAN HIEROGLYPH A529
14646 ANATOLIAN HIEROGLYPH A530
16800 BAMUM LETTER PHASE-A NGKUE MFON
16801 BAMUM LETTER PHASE-A GBIEE FON
16802 BAMUM LETTER PHASE-A PON MFON PIPAEMGBIEE
16803 BAMUM LETTER PHASE-A PON MFON PIPAEMBA
16804 BAMUM LETTER PHASE-A NAA MFON
16805 BAMUM LETTER PHASE-A SHUENSHUET
16806 BAMUM LETTER PHASE-A TITA MFON
16807 BAMUM LETTER PHASE-A NZA MFON
16808 BAMUM LETTER PHASE-A SHINDA PA NJI
16809 BAMUM LETTER PHASE-A PON PA NJI PIPAEMGBIEE
1680A BAMUM LETTER PHASE-A PON PA NJI PIPAEMBA
1680B BAMUM LETTER PHASE-A MAEMBGBIEE
1680C BAMUM LETTER PHASE-A TU MAEMBA
1680D BAMUM LETTER PHASE-A NGANGU
1680E BAMUM LETTER PHASE-A MAEMVEUX
1680F BAMUM LETTER PHASE-A MANSUAE
16810 BAMUM LETTER PHASE-A MVEUAENGAM
16811 BAMUM LETTER PHASE-A SEUNYAM
16812 BAMUM LETTER PHASE-A NTOQPEN
16813 BAMUM LETTER PHASE-A KEUKEUTNDA
16814 BAMUM LETTER PHASE-A NKINDI
16815 BAMUM LETTER PHASE-A SUU
16816 BAMUM LETTER PHASE-A NGKUENZEUM
16817 BAMUM LETTER PHASE-A LAPAQ
16818 BAMUM LETTER PHASE-A LET KUT
16819 BAMUM LETTER PHASE-A NTAP MFAA
1681A BAMUM LETTER PHASE-A MAEKEUP
1681B BAMUM LETTER PHASE-A PASHAE
1681C BAMUM LETTER PHASE-A GHEUAERAE
1681D BAMUM LETTER PHASE-A PAMSHAE
1681E BAMUM LETTER PHASE-A MON NGGEUAET
1681F BAMUM LETTER PHASE-A NZUN MEUT
16820 BAMUM LETTER PHASE-A U YUQ NAE
16821 BAMUM LETTER PHASE-A GHEUAEGHEUAE
16822 BAMUM LETTER PHASE-A NTAP NTAA
16823 BAMUM LETTER PHASE-A SISA
16824 BAMUM LETTER PHASE-A MGBASA
16825 BAMUM LETTER PHASE-A MEUNJOMNDEUQ
16826 BAMUM LETTER PHASE-A MOOMPUQ
16827 BAMUM LETTER PHASE-A KAFA
16828 BAMUM LETTER PHASE-A PA LEERAEWA
16829 BAMUM LETTER PHASE-A NDA LEERAEWA
1682A BAMUM LETTER PHASE-A PET
1682B BAMUM LETTER PHASE-A MAEMKPEN
1682C BAMUM LETTER PHASE-A NIKA
1682D BAMUM LETTER PHASE-A PUP
1682E BAMUM LETTER PHASE-A TUAEP
1682F BAMUM LETTER PHASE-A LUAEP
16830 BAMUM LETTER PHASE-A SONJAM
16831 BAMUM LETTER PHASE-A TEUTEUWEN
16832 BAMUM LETTER PHASE-A MAENYI
16833 BAMUM LETTER PHASE-A KET
16834 BAMUM LETTER PHASE-A NDAANGGEUAET
16835 BAMUM LETTER PHASE-A KUOQ
16836 BAMUM LETTER PHASE-A MOOMEUT
16837 BAMUM LETTER PHASE-A SHUM
16838 BAMUM LETTER PHASE-A LOMMAE
16839 BAMUM LETTER PHASE-A FIRI
1683A BAMUM LETTER PHASE-A ROM
1683B BAMUM LETTER PHASE-A KPOQ
1683C BAMUM LETTER PHASE-A SOQ
1683D BAMUM LETTER PHASE-A MAP PIEET
1683E BAMUM LETTER PHASE-A SHIRAE
1683F BAMUM LETTER PHASE-A NTAP
16840 BAMUM LETTER PHASE-A SHOQ NSHUT YUM
16841 BAMUM LETTER PHASE-A NYIT MONGKEUAEQ
16842 BAMUM LETTER PHASE-A PAARAE
16843 BAMUM LETTER PHASE-A NKAARAE
16844 BAMUM LETTER PHASE-A UNKNOWN
16845 BAMUM LETTER PHASE-A NGGEN
16846 BAMUM LETTER PHASE-A MAESI
16847 BAMUM LETTER PHASE-A NJAM
16848 BAMUM LETTER PHASE-A MBANYI
16849 BAMUM LETTER PHASE-A NYET
1684A BAMUM LETTER PHASE-A TEUAEN
1684B BAMUM LETTER PHASE-A SOT
1684C BAMUM LETTER PHASE-A PAAM
1684D BAMUM LETTER PHASE-A NSHIEE
1684E BAMUM LETTER PHASE-A MAEM
1684F BAMUM LETTER PHASE-A NYI
16850 BAMUM LETTER PHASE-A KAQ
16851 BAMUM LETTER PHASE-A NSHA
16852 BAMUM LETTER PHASE-A VEE
16853 BAMUM LETTER PHASE-A LU
16854 BAMUM LETTER PHASE-A NEN
16855 BAMUM LETTER PHASE-A NAQ
16856 BAMUM LETTER PHASE-A MBAQ
16857 BAMUM LETTER PHASE-B NSHUET
16858 BAMUM LETTER PHASE-B TU MAEMGBIEE
16859 BAMUM LETTER PHASE-B SIEE
1685A BAMUM LETTER PHASE-B SET TU
1685B BAMUM LETTER PHASE-B LOM NTEUM
1685C BAMUM LETTER PHASE-B MBA MAELEE
1685D BAMUM LETTER PHASE-B KIEEM
1685E BAMUM LETTER PHASE-B YEURAE
1685F BAMUM LETTER PHASE-B MBAARAE
16860 BAMUM LETTER PHASE-B KAM
16861 BAMUM LETTER PHASE-B PEESHI
16862 BAMUM LETTER PHASE-B YAFU LEERAEWA
16863 BAMUM LETTER PHASE-B LAM NSHUT NYAM
16864 BAMUM LETTER PHASE-B NTIEE SHEUOQ
16865 BAMUM LETTER PHASE-B NDU NJAA
16866 BAMUM LETTER PHASE-B GHEUGHEUAEM
16867 BAMUM LETTER PHASE-B PIT
16868 BAMUM LETTER PHASE-B TU NSIEE
16869 BAMUM LETTER PHASE-B SHET NJAQ
1686A BAMUM LETTER PHASE-B SHEUAEQTU
1686B BAMUM LETTER PHASE-B MFON TEUAEQ
1686C BAMUM LETTER PHASE-B MBIT MBAAKET
1686D BAMUM LETTER PHASE-B NYI NTEUM
1686E BAMUM LETTER PHASE-B KEUPUQ
1686F BAMUM LETTER PHASE-B GHEUGHEN
16870 BAMUM LETTER PHASE-B KEUYEUX
16871 BAMUM LETTER PHASE-B LAANAE
16872 BAMUM LETTER PHASE-B PARUM
16873 BAMUM LETTER PHASE-B VEUM
16874 BAMUM LETTER PHASE-B NGKINDI MVOP
16875 BAMUM LETTER PHASE-B NGGEU MBU
16876 BAMUM LETTER PHASE-B WUAET
16877 BAMUM LETTER PHASE-B SAKEUAE
16878 BAMUM LETTER PHASE-B TAAM
16879 BAMUM LETTER PHASE-B MEUQ
1687A BAMUM LETTER PHASE-B NGGUOQ
1687B BAMUM LETTER PHASE-B NGGUOQ LARGE
1687C BAMUM LETTER PHASE-B MFIYAQ
1687D BAMUM LETTER PHASE-B SUE
1687E BAMUM LETTER PHASE-B MBEURI
1687F BAMUM LETTER PHASE-B MONTIEEN
16880 BAMUM LETTER PHASE-B NYAEMAE
16881 BAMUM LETTER PHASE-B PUNGAAM
16882 BAMUM LETTER PHASE-B MEUT NGGEET
16883 BAMUM LETTER PHASE-B FEUX
16884 BAMUM LETTER PHASE-B MBUOQ
16885 BAMUM LETTER PHASE-B FEE
16886 BAMUM LETTER PHASE-B KEUAEM
16887 BAMUM LETTER PHASE-B MA NJEUAENA
16888 BAMUM LETTER PHASE-B MA NJUQA
16889 BAMUM LETTER PHASE-B LET
1688A BAMUM LETTER PHASE-B NGGAAM
1688B BAMUM LETTER PHASE-B NSEN
1688C BAMUM LETTER PHASE-B MA
1688D BAMUM LETTER PHASE-B KIQ
1688E BAMUM LETTER PHASE-B NGOM
1688F BAMUM LETTER PHASE-C NGKUE MAEMBA
16890 BAMUM LETTER PHASE-C NZA
16891 BAMUM LETTER PHASE-C YUM
16892 BAMUM LETTER PHASE-C WANGKUOQ
16893 BAMUM LETTER PHASE-C NGGEN
16894 BAMUM LETTER PHASE-C NDEUAEREE
16895 BAMUM LETTER PHASE-C NGKAQ
16896 BAMUM LETTER PHASE-C GHARAE
16897 BAMUM LETTER PHASE-C MBEEKEET
16898 BAMUM LETTER PHASE-C GBAYI
16899 BAMUM LETTER PHASE-C NYIR MKPARAQ MEUN
1689A BAMUM LETTER PHASE-C NTU MBIT
1689B BAMUM LETTER PHASE-C MBEUM
1689C BAMUM LETTER PHASE-C PIRIEEN
1689D BAMUM LETTER PHASE-C NDOMBU
1689E BAMUM LETTER PHASE-C MBAA CABBAGE-TREE
1689F BAMUM LETTER PHASE-C KEUSHEUAEP
168A0 BAMUM LETTER PHASE-C GHAP
168A1 BAMUM LETTER PHASE-C KEUKAQ
168A2 BAMUM LETTER PHASE-C YU MUOMAE
168A3 BAMUM LETTER PHASE-C NZEUM
168A4 BAMUM LETTER PHASE-C MBUE
168A5 BAMUM LETTER PHASE-C NSEUAEN
168A6 BAMUM LETTER PHASE-C MBIT
168A7 BAMUM LETTER PHASE-C YEUQ
168A8 BAMUM LETTER PHASE-C KPARAQ
168A9 BAMUM LETTER PHASE-C KAA
168AA BAMUM LETTER PHASE-C SEUX
168AB BAMUM LETTER PHASE-C NDIDA
168AC BAMUM LETTER PHASE-C TAASHAE
168AD BAMUM LETTER PHASE-C NJUEQ
168AE BAMUM LETTER PHASE-C TITA YUE
168AF BAMUM LETTER PHASE-C SUAET
168B0 BAMUM LETTER PHASE-C NGGUAEN NYAM
168B1 BAMUM LETTER PHASE-C VEUX
168B2 BAMUM LETTER PHASE-C NANSANAQ
168B3 BAMUM LETTER PHASE-C MA KEUAERI
168B4 BAMUM LETTER PHASE-C NTAA
168B5 BAMUM LETTER PHASE-C NGGUON
168B6 BAMUM LETTER PHASE-C LAP
168B7 BAMUM LETTER PHASE-C MBIRIEEN
168B8 BAMUM LETTER PHASE-C MGBASAQ
168B9 BAMUM LETTER PHASE-C NTEUNGBA
168BA BAMUM LETTER PHASE-C TEUTEUX
168BB BAMUM LETTER PHASE-C NGGUM
168BC BAMUM LETTER PHASE-C FUE
168BD BAMUM LETTER PHASE-C NDEUT
168BE BAMUM LETTER PHASE-C NSA
168BF BAMUM LETTER PHASE-C NSHAQ
168C0 BAMUM LETTER PHASE-C BUNG
168C1 BAMUM LETTER PHASE-C VEUAEPEN
168C2 BAMUM LETTER PHASE-C MBERAE
168C3 BAMUM LETTER PHASE-C RU
168C4 BAMUM LETTER PHASE-C NJAEM
168C5 BAMUM LETTER PHASE-C LAM
168C6 BAMUM LETTER PHASE-C TITUAEP
168C7 BAMUM LETTER PHASE-C NSUOT NGOM
168C8 BAMUM LETTER PHASE-C NJEEEE
168C9 BAMUM LETTER PHASE-C KET
168CA BAMUM LETTER PHASE-C NGGU
168CB BAMUM LETTER PHASE-C MAESI
168CC BAMUM LETTER PHASE-C MBUAEM
168CD BAMUM LETTER PHASE-C LU
168CE BAMUM LETTER PHASE-C KUT
168CF BAMUM LETTER PHASE-C NJAM
168D0 BAMUM LETTER PHASE-C NGOM
168D1 BAMUM LETTER PHASE-C WUP
168D2 BAMUM LETTER PHASE-C NGGUEET
168D3 BAMUM LETTER PHASE-C NSOM
168D4 BAMUM LETTER PHASE-C NTEN
168D5 BAMUM LETTER PHASE-C KUOP NKAARAE
168D6 BAMUM LETTER PHASE-C NSUN
168D7 BAMUM LETTER PHASE-C NDAM
168D8 BAMUM LETTER PHASE-C MA NSIEE
168D9 BAMUM LETTER PHASE-C YAA
168DA BAMUM LETTER PHASE-C NDAP
168DB BAMUM LETTER PHASE-C SHUEQ
168DC BAMUM LETTER PHASE-C SETFON
168DD BAMUM LETTER PHASE-C MBI
168DE BAMUM LETTER PHASE-C MAEMBA
168DF BAMUM LETTER PHASE-C MBANYI
168E0 BAMUM LETTER PHASE-C KEUSEUX
168E1 BAMUM LETTER PHASE-C MBEUX
168E2 BAMUM LETTER PHASE-C KEUM
168E3 BAMUM LETTER PHASE-C MBAA PICKET
168E4 BAMUM LETTER PHASE-C YUWOQ
168E5 BAMUM LETTER PHASE-C NJEUX
168E6 BAMUM LETTER PHASE-C MIEE
168E7 BAMUM LETTER PHASE-C MUAE
168E8 BAMUM LETTER PHASE-C SHIQ
168E9 BAMUM LETTER PHASE-C KEN LAW
168EA BAMUM LETTER PHASE-C KEN FATIGUE
168EB BAMUM LETTER PHASE-C NGAQ
168EC BAMUM LETTER PHASE-C NAQ
168ED BAMUM LETTER PHASE-C LIQ
168EE BAMUM LETTER PHASE-C PIN
168EF BAMUM LETTER PHASE-C PEN
168F0 BAMUM LETTER PHASE-C TET
168F1 BAMUM LETTER PHASE-D MBUO
168F2 BAMUM LETTER PHASE-D WAP
168F3 BAMUM LETTER PHASE-D NJI
168F4 BAMUM LETTER PHASE-D MFON
168F5 BAMUM LETTER PHASE-D NJIEE
168F6 BAMUM LETTER PHASE-D LIEE
168F7 BAMUM LETTER PHASE-D NJEUT
168F8 BAMUM LETTER PHASE-D NSHEE
168F9 BAMUM LETTER PHASE-D NGGAAMAE
168FA BAMUM LETTER PHASE-D NYAM
168FB BAMUM LETTER PHASE-D WUAEN
168FC BAMUM LETTER PHASE-D NGKUN
168FD BAMUM LETTER PHASE-D SHEE
168FE BAMUM LETTER PHASE-D NGKAP
168FF BAMUM LETTER PHASE-D KEUAETMEUN
16900 BAMUM LETTER PHASE-D TEUT
16901 BAMUM LETTER PHASE-D SHEUAE
16902 BAMUM LETTER PHASE-D NJAP
16903 BAMUM LETTER PHASE-D SUE
16904 BAMUM LETTER PHASE-D KET
16905 BAMUM LETTER PHASE-D YAEMMAE
16906 BAMUM LETTER PHASE-D KUOM
16907 BAMUM LETTER PHASE-D SAP
16908 BAMUM LETTER PHASE-D MFEUT
16909 BAMUM LETTER PHASE-D NDEUX
1690A BAMUM LETTER PHASE-D MALEERI
1690B BAMUM LETTER PHASE-D MEUT
1690C BAMUM LETTER PHASE-D SEUAEQ
1690D BAMUM LETTER PHASE-D YEN
1690E BAMUM LETTER PHASE-D NJEUAEM
1690F BAMUM LETTER PHASE-D KEUOT MBUAE
16910 BAMUM LETTER PHASE-D NGKEURI
16911 BAMUM LETTER PHASE-D TU
16912 BAMUM LETTER PHASE-D GHAA
16913 BAMUM LETTER PHASE-D NGKYEE
16914 BAMUM LETTER PHASE-D FEUFEUAET
16915 BAMUM LETTER PHASE-D NDEE
16916 BAMUM LETTER PHASE-D MGBOFUM
16917 BAMUM LETTER PHASE-D LEUAEP
16918 BAMUM LETTER PHASE-D NDON
16919 BAMUM LETTER PHASE-D MONI
1691A BAMUM LETTER PHASE-D MGBEUN
1691B BAMUM LETTER PHASE-D PUUT
1691C BAMUM LETTER PHASE-D MGBIEE
1691D BAMUM LETTER PHASE-D MFO
1691E BAMUM LETTER PHASE-D LUM
1691F BAMUM LETTER PHASE-D NSIEEP
16920 BAMUM LETTER PHASE-D MBAA
16921 BAMUM LETTER PHASE-D KWAET
16922 BAMUM LETTER PHASE-D NYET
16923 BAMUM LETTER PHASE-D TEUAEN
16924 BAMUM LETTER PHASE-D SOT
16925 BAMUM LETTER PHASE-D YUWOQ
16926 BAMUM LETTER PHASE-D KEUM
16927 BAMUM LETTER PHASE-D RAEM
16928 BAMUM LETTER PHASE-D TEEEE
16929 BAMUM LETTER PHASE-D NGKEUAEQ
1692A BAMUM LETTER PHASE-D MFEUAE
1692B BAMUM LETTER PHASE-D NSIEET
1692C BAMUM LETTER PHASE-D KEUP
1692D BAMUM LETTER PHASE-D PIP
1692E BAMUM LETTER PHASE-D PEUTAE
1692F BAMUM LETTER PHASE-D NYUE
16930 BAMUM LETTER PHASE-D LET
16931 BAMUM LETTER PHASE-D NGGAAM
16932 BAMUM LETTER PHASE-D MFIEE
16933 BAMUM LETTER PHASE-D NGGWAEN
16934 BAMUM LETTER PHASE-D YUOM
16935 BAMUM LETTER PHASE-D PAP
16936 BAMUM LETTER PHASE-D YUOP
16937 BAMUM LETTER PHASE-D NDAM
16938 BAMUM LETTER PHASE-D NTEUM
16939 BAMUM LETTER PHASE-D SUAE
1693A BAMUM LETTER PHASE-D KUN
1693B BAMUM LETTER PHASE-D NGGEUX
1693C BAMUM LETTER PHASE-D NGKIEE
1693D BAMUM LETTER PHASE-D TUOT
1693E BAMUM LETTER PHASE-D MEUN
1693F BAMUM LETTER PHASE-D KUQ
16940 BAMUM LETTER PHASE-D NSUM
16941 BAMUM LETTER PHASE-D TEUN
16942 BAMUM LETTER PHASE-D MAENJET
16943 BAMUM LETTER PHASE-D NGGAP
16944 BAMUM LETTER PHASE-D LEUM
16945 BAMUM LETTER PHASE-D NGGUOM
16946 BAMUM LETTER PHASE-D NSHUT
16947 BAMUM LETTER PHASE-D NJUEQ
16948 BAMUM LETTER PHASE-D GHEUAE
16949 BAMUM LETTER PHASE-D KU
1694A BAMUM LETTER PHASE-D REN OLD
1694B BAMUM LETTER PHASE-D TAE
1694C BAMUM LETTER PHASE-D TOQ
1694D BAMUM LETTER PHASE-D NYI
1694E BAMUM LETTER PHASE-D RII
1694F BAMUM LETTER PHASE-D LEEEE
16950 BAMUM LETTER PHASE-D MEEEE
16951 BAMUM LETTER PHASE-D M
16952 BAMUM LETTER PHASE-D SUU
16953 BAMUM LETTER PHASE-D MU
16954 BAMUM LETTER PHASE-D SHII
16955 BAMUM LETTER PHASE-D SHEUX
16956 BAMUM LETTER PHASE-D KYEE
16957 BAMUM LETTER PHASE-D NU
16958 BAMUM LETTER PHASE-D SHU
16959 BAMUM LETTER PHASE-D NTEE
1695A BAMUM LETTER PHASE-D PEE
1695B BAMUM LETTER PHASE-D NI
1695C BAMUM LETTER PHASE-D SHOQ
1695D BAMUM LETTER PHASE-D PUQ
1695E BAMUM LETTER PHASE-D MVOP
1695F BAMUM LETTER PHASE-D LOQ
16960 BAMUM LETTER PHASE-D REN MUCH
16961 BAMUM LETTER PHASE-D TI
16962 BAMUM LETTER PHASE-D NTUU
16963 BAMUM LETTER PHASE-D MBAA SEVEN
16964 BAMUM LETTER PHASE-D SAQ
16965 BAMUM LETTER PHASE-D FAA
16966 BAMUM LETTER PHASE-E NDAP
16967 BAMUM LETTER PHASE-E TOON
16968 BAMUM LETTER PHASE-E MBEUM
16969 BAMUM LETTER PHASE-E LAP
1696A BAMUM LETTER PHASE-E VOM
1696B BAMUM LETTER PHASE-E LOON
1696C BAMUM LETTER PHASE-E PAA
1696D BAMUM LETTER PHASE-E SOM
1696E BAMUM LETTER PHASE-E RAQ
1696F BAMUM LETTER PHASE-E NSHUOP
16970 BAMUM LETTER PHASE-E NDUN
16971 BAMUM LETTER PHASE-E PUAE
16972 BAMUM LETTER PHASE-E TAM
16973 BAMUM LETTER PHASE-E NGKA
16974 BAMUM LETTER PHASE-E KPEUX
16975 BAMUM LETTER PHASE-E WUO
16976 BAMUM LETTER PHASE-E SEE
16977 BAMUM LETTER PHASE-E NGGEUAET
16978 BAMUM LETTER PHASE-E PAAM
16979 BAMUM LETTER PHASE-E TOO
1697A BAMUM LETTER PHASE-E KUOP
1697B BAMUM LETTER PHASE-E LOM
1697C BAMUM LETTER PHASE-E NSHIEE
1697D BAMUM LETTER PHASE-E NGOP
1697E BAMUM LETTER PHASE-E MAEM
1697F BAMUM LETTER PHASE-E NGKEUX
16980 BAMUM LETTER PHASE-E NGOQ
16981 BAMUM LETTER PHASE-E NSHUE
16982 BAMUM LETTER PHASE-E RIMGBA
16983 BAMUM LETTER PHASE-E NJEUX
16984 BAMUM LETTER PHASE-E PEEM
16985 BAMUM LETTER PHASE-E SAA
16986 BAMUM LETTER PHASE-E NGGURAE
16987 BAMUM LETTER PHASE-E MGBA
16988 BAMUM LETTER PHASE-E GHEUX
16989 BAMUM LETTER PHASE-E NGKEUAEM
1698A BAMUM LETTER PHASE-E NJAEMLI
1698B BAMUM LETTER PHASE-E MAP
1698C BAMUM LETTER PHASE-E LOOT
1698D BAMUM LETTER PHASE-E NGGEEEE
1698E BAMUM LETTER PHASE-E NDIQ
1698F BAMUM LETTER PHASE-E TAEN NTEUM
16990 BAMUM LETTER PHASE-E SET
16991 BAMUM LETTER PHASE-E PUM
16992 BAMUM LETTER PHASE-E NDAA SOFTNESS
16993 BAMUM LETTER PHASE-E NGGUAESHAE NYAM
16994 BAMUM LETTER PHASE-E YIEE
16995 BAMUM LETTER PHASE-E GHEUN
16996 BAMUM LETTER PHASE-E TUAE
16997 BAMUM LETTER PHASE-E YEUAE
16998 BAMUM LETTER PHASE-E PO
16999 BAMUM LETTER PHASE-E TUMAE
1699A BAMUM LETTER PHASE-E KEUAE
1699B BAMUM LETTER PHASE-E SUAEN
1699C BAMUM LETTER PHASE-E TEUAEQ
1699D BAMUM LETTER PHASE-E VEUAE
1699E BAMUM LETTER PHASE-E WEUX
1699F BAMUM LETTER PHASE-E LAAM
169A0 BAMUM LETTER PHASE-E PU
169A1 BAMUM LETTER PHASE-E TAAQ
169A2 BAMUM LETTER PHASE-E GHAAMAE
169A3 BAMUM LETTER PHASE-E NGEUREUT
169A4 BAMUM LETTER PHASE-E SHEUAEQ
169A5 BAMUM LETTER PHASE-E MGBEN
169A6 BAMUM LETTER PHASE-E MBEE
169A7 BAMUM LETTER PHASE-E NZAQ
169A8 BAMUM LETTER PHASE-E NKOM
169A9 BAMUM LETTER PHASE-E GBET
169AA BAMUM LETTER PHASE-E TUM
169AB BAMUM LETTER PHASE-E KUET
169AC BAMUM LETTER PHASE-E YAP
169AD BAMUM LETTER PHASE-E NYI CLEAVER
169AE BAMUM LETTER PHASE-E YIT
169AF BAMUM LETTER PHASE-E MFEUQ
169B0 BAMUM LETTER PHASE-E NDIAQ
169B1 BAMUM LETTER PHASE-E PIEEQ
169B2 BAMUM LETTER PHASE-E YUEQ
169B3 BAMUM LETTER PHASE-E LEUAEM
169B4 BAMUM LETTER PHASE-E FUE
169B5 BAMUM LETTER PHASE-E GBEUX
169B6 BAMUM LETTER PHASE-E NGKUP
169B7 BAMUM LETTER PHASE-E KET
169B8 BAMUM LETTER PHASE-E MAE
169B9 BAMUM LETTER PHASE-E NGKAAMI
169BA BAMUM LETTER PHASE-E GHET
169BB BAMUM LETTER PHASE-E FA
169BC BAMUM LETTER PHASE-E NTUM
169BD BAMUM LETTER PHASE-E PEUT
169BE BAMUM LETTER PHASE-E YEUM
169BF BAMUM LETTER PHASE-E NGGEUAE
169C0 BAMUM LETTER PHASE-E NYI BETWEEN
169C1 BAMUM LETTER PHASE-E NZUQ
169C2 BAMUM LETTER PHASE-E POON
169C3 BAMUM LETTER PHASE-E MIEE
169C4 BAMUM LETTER PHASE-E FUET
169C5 BAMUM LETTER PHASE-E NAE
169C6 BAMUM LETTER PHASE-E MUAE
169C7 BAMUM LETTER PHASE-E GHEUAE
169C8 BAMUM LETTER PHASE-E FU I
169C9 BAMUM LETTER PHASE-E MVI
169CA BAMUM LETTER PHASE-E PUAQ
169CB BAMUM LETTER PHASE-E NGKUM
169CC BAMUM LETTER PHASE-E KUT
169CD BAMUM LETTER PHASE-E PIET
169CE BAMUM LETTER PHASE-E NTAP
169CF BAMUM LETTER PHASE-E YEUAET
169D0 BAMUM LETTER PHASE-E NGGUP
169D1 BAMUM LETTER PHASE-E PA PEOPLE
169D2 BAMUM LETTER PHASE-E FU CALL
169D3 BAMUM LETTER PHASE-E FOM
169D4 BAMUM LETTER PHASE-E NJEE
169D5 BAMUM LETTER PHASE-E A
169D6 BAMUM LETTER PHASE-E TOQ
169D7 BAMUM LETTER PHASE-E O
169D8 BAMUM LETTER PHASE-E I
169D9 BAMUM LETTER PHASE-E LAQ
169DA BAMUM LETTER PHASE-E PA PLURAL
169DB BAMUM LETTER PHASE-E TAA
169DC BAMUM LETTER PHASE-E TAQ
169DD BAMUM LETTER PHASE-E NDAA MY HOUSE
169DE BAMUM LETTER PHASE-E SHIQ
169DF BAMUM LETTER PHASE-E YEUX
169E0 BAMUM LETTER PHASE-E NGUAE
169E1 BAMUM LETTER PHASE-E YUAEN
169E2 BAMUM LETTER PHASE-E YOQ SWIMMING
169E3 BAMUM LETTER PHASE-E YOQ COVER
169E4 BAMUM LETTER PHASE-E YUQ
169E5 BAMUM LETTER PHASE-E YUN
169E6 BAMUM LETTER PHASE-E KEUX
169E7 BAMUM LETTER PHASE-E PEUX
169E8 BAMUM LETTER PHASE-E NJEE EPOCH
169E9 BAMUM LETTER PHASE-E PUE
169EA BAMUM LETTER PHASE-E WUE
169EB BAMUM LETTER PHASE-E FEE
169EC BAMUM LETTER PHASE-E VEE
169ED BAMUM LETTER PHASE-E LU
169EE BAMUM LETTER PHASE-E MI
169EF BAMUM LETTER PHASE-E REUX
169F0 BAMUM LETTER PHASE-E RAE
169F1 BAMUM LETTER PHASE-E NGUAET
169F2 BAMUM LETTER PHASE-E NGA
169F3 BAMUM LETTER PHASE-E SHO
169F4 BAMUM LETTER PHASE-E SHOQ
169F5 BAMUM LETTER PHASE-E FU REMEDY
169F6 BAMUM LETTER PHASE-E NA
169F7 BAMUM LETTER PHASE-E PI
169F8 BAMUM LETTER PHASE-E LOQ
169F9 BAMUM LETTER PHASE-E KO
169FA BAMUM LETTER PHASE-E MEN
169FB BAMUM LETTER PHASE-E MA
169FC BAMUM LETTER PHASE-E MAQ
169FD BAMUM LETTER PHASE-E TEU
169FE BAMUM LETTER PHASE-E KI
169FF BAMUM LETTER PHASE-E MON
16A00 BAMUM LETTER PHASE-E TEN
16A01 BAMUM LETTER PHASE-E FAQ
16A02 BAMUM LETTER PHASE-E GHOM
16A03 BAMUM LETTER PHASE-F KA
16A04 BAMUM LETTER PHASE-F U
16A05 BAMUM LETTER PHASE-F KU
16A06 BAMUM LETTER PHASE-F EE
16A07 BAMUM LETTER PHASE-F REE
16A08 BAMUM LETTER PHASE-F TAE
16A09 BAMUM LETTER PHASE-F NYI
16A0A BAMUM LETTER PHASE-F LA
16A0B BAMUM LETTER PHASE-F RII
16A0C BAMUM LETTER PHASE-F RIEE
16A0D BAMUM LETTER PHASE-F MEEEE
16A0E BAMUM LETTER PHASE-F TAA
16A0F BAMUM LETTER PHASE-F NDAA
16A10 BAMUM LETTER PHASE-F NJAEM
16A11 BAMUM LETTER PHASE-F M
16A12 BAMUM LETTER PHASE-F SUU
16A13 BAMUM LETTER PHASE-F SHII
16A14 BAMUM LETTER PHASE-F SI
16A15 BAMUM LETTER PHASE-F SEUX
16A16 BAMUM LETTER PHASE-F KYEE
16A17 BAMUM LETTER PHASE-F KET
16A18 BAMUM LETTER PHASE-F NUAE
16A19 BAMUM LETTER PHASE-F NU
16A1A BAMUM LETTER PHASE-F NJUAE
16A1B BAMUM LETTER PHASE-F YOQ
16A1C BAMUM LETTER PHASE-F SHU
16A1D BAMUM LETTER PHASE-F YA
16A1E BAMUM LETTER PHASE-F NSHA
16A1F BAMUM LETTER PHASE-F PEUX
16A20 BAMUM LETTER PHASE-F NTEE
16A21 BAMUM LETTER PHASE-F WUE
16A22 BAMUM LETTER PHASE-F PEE
16A23 BAMUM LETTER PHASE-F RU
16A24 BAMUM LETTER PHASE-F NI
16A25 BAMUM LETTER PHASE-F REUX
16A26 BAMUM LETTER PHASE-F KEN
16A27 BAMUM LETTER PHASE-F NGKWAEN
16A28 BAMUM LETTER PHASE-F NGGA
16A29 BAMUM LETTER PHASE-F SHO
16A2A BAMUM LETTER PHASE-F PUAE
16A2B BAMUM LETTER PHASE-F FOM
16A2C BAMUM LETTER PHASE-F WA
16A2D BAMUM LETTER PHASE-F LI
16A2E BAMUM LETTER PHASE-F LOQ
16A2F BAMUM LETTER PHASE-F KO
16A30 BAMUM LETTER PHASE-F MBEN
16A31 BAMUM LETTER PHASE-F REN
16A32 BAMUM LETTER PHASE-F MA
16A33 BAMUM LETTER PHASE-F MO
16A34 BAMUM LETTER PHASE-F MBAA
16A35 BAMUM LETTER PHASE-F TET
16A36 BAMUM LETTER PHASE-F KPA
16A37 BAMUM LETTER PHASE-F SAMBA
16A38 BAMUM LETTER PHASE-F VUEQ
16A40 MRO LETTER TA
16A41 MRO LETTER NGI
16A42 MRO LETTER YO
16A43 MRO LETTER MIM
16A44 MRO LETTER BA
16A45 MRO LETTER DA
16A46 MRO LETTER A
16A47 MRO LETTER PHI
16A48 MRO LETTER KHAI
16A49 MRO LETTER HAO
16A4A MRO LETTER DAI
16A4B MRO LETTER CHU
16A4C MRO LETTER KEAAE
16A4D MRO LETTER OL
16A4E MRO LETTER MAEM
16A4F MRO LETTER NIN
16A50 MRO LETTER PA
16A51 MRO LETTER OO
16A52 MRO LETTER O
16A53 MRO LETTER RO
16A54 MRO LETTER SHI
16A55 MRO LETTER THEA
16A56 MRO LETTER EA
16A57 MRO LETTER WA
16A58 MRO LETTER E
16A59 MRO LETTER KO
16A5A MRO LETTER LAN
16A5B MRO LETTER LA
16A5C MRO LETTER HAI
16A5D MRO LETTER RI
16A5E MRO LETTER TEK
16A60 MRO DIGIT ZERO
16A61 MRO DIGIT ONE
16A62 MRO DIGIT TWO
16A63 MRO DIGIT THREE
16A64 MRO DIGIT FOUR
16A65 MRO DIGIT FIVE
16A66 MRO DIGIT SIX
16A67 MRO DIGIT SEVEN
16A68 MRO DIGIT EIGHT
16A69 MRO DIGIT NINE
16A6E MRO DANDA
16A6F MRO DOUBLE DANDA
16AD0 BASSA VAH LETTER ENNI
16AD1 BASSA VAH LETTER KA
16AD2 BASSA VAH LETTER SE
16AD3 BASSA VAH LETTER FA
16AD4 BASSA VAH LETTER MBE
16AD5 BASSA VAH LETTER YIE
16AD6 BASSA VAH LETTER GAH
16AD7 BASSA VAH LETTER DHII
16AD8 BASSA VAH LETTER KPAH
16AD9 BASSA VAH LETTER JO
16ADA BASSA VAH LETTER HWAH
16ADB BASSA VAH LETTER WA
16ADC BASSA VAH LETTER ZO
16ADD BASSA VAH LETTER GBU
16ADE BASSA VAH LETTER DO
16ADF BASSA VAH LETTER CE
16AE0 BASSA VAH LETTER UWU
16AE1 BASSA VAH LETTER TO
16AE2 BASSA VAH LETTER BA
16AE3 BASSA VAH LETTER VU
16AE4 BASSA VAH LETTER YEIN
16AE5 BASSA VAH LETTER PA
16AE6 BASSA VAH LETTER WADDA
16AE7 BASSA VAH LETTER A
16AE8 BASSA VAH LETTER O
16AE9 BASSA VAH LETTER OO
16AEA BASSA VAH LETTER U
16AEB BASSA VAH LETTER EE
16AEC BASSA VAH LETTER E
16AED BASSA VAH LETTER I
16AF0 BASSA VAH COMBINING HIGH TONE
16AF1 BASSA VAH COMBINING LOW TONE
16AF2 BASSA VAH COMBINING MID TONE
16AF3 BASSA VAH COMBINING LOW-MID TONE
16AF4 BASSA VAH COMBINING HIGH-LOW TONE
16AF5 BASSA VAH FULL STOP
16B00 PAHAWH HMONG VOWEL KEEB
16B01 PAHAWH HMONG VOWEL KEEV
16B02 PAHAWH HMONG VOWEL KIB
16B03 PAHAWH HMONG VOWEL KIV
16B04 PAHAWH HMONG VOWEL KAUB
16B05 PAHAWH HMONG VOWEL KAUV
16B06 PAHAWH HMONG VOWEL KUB
16B07 PAHAWH HMONG VOWEL KUV
16B08 PAHAWH HMONG VOWEL KEB
16B09 PAHAWH HMONG VOWEL KEV
16B0A PAHAWH HMONG VOWEL KAIB
16B0B PAHAWH HMONG VOWEL KAIV
16B0C PAHAWH HMONG VOWEL KOOB
16B0D PAHAWH HMONG VOWEL KOOV
16B0E PAHAWH HMONG VOWEL KAWB
16B0F PAHAWH HMONG VOWEL KAWV
16B10 PAHAWH HMONG VOWEL KUAB
16B11 PAHAWH HMONG VOWEL KUAV
16B12 PAHAWH HMONG VOWEL KOB
16B13 PAHAWH HMONG VOWEL KOV
16B14 PAHAWH HMONG VOWEL KIAB
16B15 PAHAWH HMONG VOWEL KIAV
16B16 PAHAWH HMONG VOWEL KAB
16B17 PAHAWH HMONG VOWEL KAV
16B18 PAHAWH HMONG VOWEL KWB
16B19 PAHAWH HMONG VOWEL KWV
16B1A PAHAWH HMONG VOWEL KAAB
16B1B PAHAWH HMONG VOWEL KAAV
16B1C PAHAWH HMONG CONSONANT VAU
16B1D PAHAWH HMONG CONSONANT NTSAU
16B1E PAHAWH HMONG CONSONANT LAU
16B1F PAHAWH HMONG CONSONANT HAU
16B20 PAHAWH HMONG CONSONANT NLAU
16B21 PAHAWH HMONG CONSONANT RAU
16B22 PAHAWH HMONG CONSONANT NKAU
16B23 PAHAWH HMONG CONSONANT QHAU
16B24 PAHAWH HMONG CONSONANT YAU
16B25 PAHAWH HMONG CONSONANT HLAU
16B26 PAHAWH HMONG CONSONANT MAU
16B27 PAHAWH HMONG CONSONANT CHAU
16B28 PAHAWH HMONG CONSONANT NCHAU
16B29 PAHAWH HMONG CONSONANT HNAU
16B2A PAHAWH HMONG CONSONANT PLHAU
16B2B PAHAWH HMONG CONSONANT NTHAU
16B2C PAHAWH HMONG CONSONANT NAU
16B2D PAHAWH HMONG CONSONANT AU
16B2E PAHAWH HMONG CONSONANT XAU
16B2F PAHAWH HMONG CONSONANT CAU
16B30 PAHAWH HMONG MARK CIM TUB
16B31 PAHAWH HMONG MARK CIM SO
16B32 PAHAWH HMONG MARK CIM KES
16B33 PAHAWH HMONG MARK CIM KHAV
16B34 PAHAWH HMONG MARK CIM SUAM
16B35 PAHAWH HMONG MARK CIM HOM
16B36 PAHAWH HMONG MARK CIM TAUM
16B37 PAHAWH HMONG SIGN VOS THOM
16B38 PAHAWH HMONG SIGN VOS TSHAB CEEB
16B39 PAHAWH HMONG SIGN CIM CHEEM
16B3A PAHAWH HMONG SIGN VOS THIAB
16B3B PAHAWH HMONG SIGN VOS FEEM
16B3C PAHAWH HMONG SIGN XYEEM NTXIV
16B3D PAHAWH HMONG SIGN XYEEM RHO
16B3E PAHAWH HMONG SIGN XYEEM TOV
16B3F PAHAWH HMONG SIGN XYEEM FAIB
16B40 PAHAWH HMONG SIGN VOS SEEV
16B41 PAHAWH HMONG SIGN MEEJ SUAB
16B42 PAHAWH HMONG SIGN VOS NRUA
16B43 PAHAWH HMONG SIGN IB YAM
16B44 PAHAWH HMONG SIGN XAUS
16B45 PAHAWH HMONG SIGN CIM TSOV ROG
16B50 PAHAWH HMONG DIGIT ZERO
16B51 PAHAWH HMONG DIGIT ONE
16B52 PAHAWH HMONG DIGIT TWO
16B53 PAHAWH HMONG DIGIT THREE
16B54 PAHAWH HMONG DIGIT FOUR
16B55 PAHAWH HMONG DIGIT FIVE
16B56 PAHAWH HMONG DIGIT SIX
16B57 PAHAWH HMONG DIGIT SEVEN
16B58 PAHAWH HMONG DIGIT EIGHT
16B59 PAHAWH HMONG DIGIT NINE
16B5B PAHAWH HMONG NUMBER TENS
16B5C PAHAWH HMONG NUMBER HUNDREDS
16B5D PAHAWH HMONG NUMBER TEN THOUSANDS
16B5E PAHAWH HMONG NUMBER MILLIONS
16B5F PAHAWH HMONG NUMBER HUNDRED MILLIONS
16B60 PAHAWH HMONG NUMBER TEN BILLIONS
16B61 PAHAWH HMONG NUMBER TRILLIONS
16B63 PAHAWH HMONG SIGN VOS LUB
16B64 PAHAWH HMONG SIGN XYOO
16B65 PAHAWH HMONG SIGN HLI
16B66 PAHAWH HMONG SIGN THIRD-STAGE HLI
16B67 PAHAWH HMONG SIGN ZWJ THAJ
16B68 PAHAWH HMONG SIGN HNUB
16B69 PAHAWH HMONG SIGN NQIG
16B6A PAHAWH HMONG SIGN XIAB
16B6B PAHAWH HMONG SIGN NTUJ
16B6C PAHAWH HMONG SIGN AV
16B6D PAHAWH HMONG SIGN TXHEEJ CEEV
16B6E PAHAWH HMONG SIGN MEEJ TSEEB
16B6F PAHAWH HMONG SIGN TAU
16B70 PAHAWH HMONG SIGN LOS
16B71 PAHAWH HMONG SIGN MUS
16B72 PAHAWH HMONG SIGN CIM HAIS LUS NTOG NTOG
16B73 PAHAWH HMONG SIGN CIM CUAM TSHOOJ
16B74 PAHAWH HMONG SIGN CIM TXWV
16B75 PAHAWH HMONG SIGN CIM TXWV CHWV
16B76 PAHAWH HMONG SIGN CIM PUB DAWB
16B77 PAHAWH HMONG SIGN CIM NRES TOS
16B7D PAHAWH HMONG CLAN SIGN TSHEEJ
16B7E PAHAWH HMONG CLAN SIGN YEEG
16B7F PAHAWH HMONG CLAN SIGN LIS
16B80 PAHAWH HMONG CLAN SIGN LAUJ
16B81 PAHAWH HMONG CLAN SIGN XYOOJ
16B82 PAHAWH HMONG CLAN SIGN KOO
16B83 PAHAWH HMONG CLAN SIGN HAWJ
16B84 PAHAWH HMONG CLAN SIGN MUAS
16B85 PAHAWH HMONG CLAN SIGN THOJ
16B86 PAHAWH HMONG CLAN SIGN TSAB
16B87 PAHAWH HMONG CLAN SIGN PHAB
16B88 PAHAWH HMONG CLAN SIGN KHAB
16B89 PAHAWH HMONG CLAN SIGN HAM
16B8A PAHAWH HMONG CLAN SIGN VAJ
16B8B PAHAWH HMONG CLAN SIGN FAJ
16B8C PAHAWH HMONG CLAN SIGN YAJ
16B8D PAHAWH HMONG CLAN SIGN TSWB
16B8E PAHAWH HMONG CLAN SIGN KWM
16B8F PAHAWH HMONG CLAN SIGN VWJ
16F00 MIAO LETTER PA
16F01 MIAO LETTER BA
16F02 MIAO LETTER YI PA
16F03 MIAO LETTER PLA
16F04 MIAO LETTER MA
16F05 MIAO LETTER MHA
16F06 MIAO LETTER ARCHAIC MA
16F07 MIAO LETTER FA
16F08 MIAO LETTER VA
16F09 MIAO LETTER VFA
16F0A MIAO LETTER TA
16F0B MIAO LETTER DA
16F0C MIAO LETTER YI TTA
16F0D MIAO LETTER YI TA
16F0E MIAO LETTER TTA
16F0F MIAO LETTER DDA
16F10 MIAO LETTER NA
16F11 MIAO LETTER NHA
16F12 MIAO LETTER YI NNA
16F13 MIAO LETTER ARCHAIC NA
16F14 MIAO LETTER NNA
16F15 MIAO LETTER NNHA
16F16 MIAO LETTER LA
16F17 MIAO LETTER LYA
16F18 MIAO LETTER LHA
16F19 MIAO LETTER LHYA
16F1A MIAO LETTER TLHA
16F1B MIAO LETTER DLHA
16F1C MIAO LETTER TLHYA
16F1D MIAO LETTER DLHYA
16F1E MIAO LETTER KA
16F1F MIAO LETTER GA
16F20 MIAO LETTER YI KA
16F21 MIAO LETTER QA
16F22 MIAO LETTER QGA
16F23 MIAO LETTER NGA
16F24 MIAO LETTER NGHA
16F25 MIAO LETTER ARCHAIC NGA
16F26 MIAO LETTER HA
16F27 MIAO LETTER XA
16F28 MIAO LETTER GHA
16F29 MIAO LETTER GHHA
16F2A MIAO LETTER TSSA
16F2B MIAO LETTER DZZA
16F2C MIAO LETTER NYA
16F2D MIAO LETTER NYHA
16F2E MIAO LETTER TSHA
16F2F MIAO LETTER DZHA
16F30 MIAO LETTER YI TSHA
16F31 MIAO LETTER YI DZHA
16F32 MIAO LETTER REFORMED TSHA
16F33 MIAO LETTER SHA
16F34 MIAO LETTER SSA
16F35 MIAO LETTER ZHA
16F36 MIAO LETTER ZSHA
16F37 MIAO LETTER TSA
16F38 MIAO LETTER DZA
16F39 MIAO LETTER YI TSA
16F3A MIAO LETTER SA
16F3B MIAO LETTER ZA
16F3C MIAO LETTER ZSA
16F3D MIAO LETTER ZZA
16F3E MIAO LETTER ZZSA
16F3F MIAO LETTER ARCHAIC ZZA
16F40 MIAO LETTER ZZYA
16F41 MIAO LETTER ZZSYA
16F42 MIAO LETTER WA
16F43 MIAO LETTER AH
16F44 MIAO LETTER HHA
16F50 MIAO LETTER NASALIZATION
16F51 MIAO SIGN ASPIRATION
16F52 MIAO SIGN REFORMED VOICING
16F53 MIAO SIGN REFORMED ASPIRATION
16F54 MIAO VOWEL SIGN A
16F55 MIAO VOWEL SIGN AA
16F56 MIAO VOWEL SIGN AHH
16F57 MIAO VOWEL SIGN AN
16F58 MIAO VOWEL SIGN ANG
16F59 MIAO VOWEL SIGN O
16F5A MIAO VOWEL SIGN OO
16F5B MIAO VOWEL SIGN WO
16F5C MIAO VOWEL SIGN W
16F5D MIAO VOWEL SIGN E
16F5E MIAO VOWEL SIGN EN
16F5F MIAO VOWEL SIGN ENG
16F60 MIAO VOWEL SIGN OEY
16F61 MIAO VOWEL SIGN I
16F62 MIAO VOWEL SIGN IA
16F63 MIAO VOWEL SIGN IAN
16F64 MIAO VOWEL SIGN IANG
16F65 MIAO VOWEL SIGN IO
16F66 MIAO VOWEL SIGN IE
16F67 MIAO VOWEL SIGN II
16F68 MIAO VOWEL SIGN IU
16F69 MIAO VOWEL SIGN ING
16F6A MIAO VOWEL SIGN U
16F6B MIAO VOWEL SIGN UA
16F6C MIAO VOWEL SIGN UAN
16F6D MIAO VOWEL SIGN UANG
16F6E MIAO VOWEL SIGN UU
16F6F MIAO VOWEL SIGN UEI
16F70 MIAO VOWEL SIGN UNG
16F71 MIAO VOWEL SIGN Y
16F72 MIAO VOWEL SIGN YI
16F73 MIAO VOWEL SIGN AE
16F74 MIAO VOWEL SIGN AEE
16F75 MIAO VOWEL SIGN ERR
16F76 MIAO VOWEL SIGN ROUNDED ERR
16F77 MIAO VOWEL SIGN ER
16F78 MIAO VOWEL SIGN ROUNDED ER
16F79 MIAO VOWEL SIGN AI
16F7A MIAO VOWEL SIGN EI
16F7B MIAO VOWEL SIGN AU
16F7C MIAO VOWEL SIGN OU
16F7D MIAO VOWEL SIGN N
16F7E MIAO VOWEL SIGN NG
16F8F MIAO TONE RIGHT
16F90 MIAO TONE TOP RIGHT
16F91 MIAO TONE ABOVE
16F92 MIAO TONE BELOW
16F93 MIAO LETTER TONE-2
16F94 MIAO LETTER TONE-3
16F95 MIAO LETTER TONE-4
16F96 MIAO LETTER TONE-5
16F97 MIAO LETTER TONE-6
16F98 MIAO LETTER TONE-7
16F99 MIAO LETTER TONE-8
16F9A MIAO LETTER REFORMED TONE-1
16F9B MIAO LETTER REFORMED TONE-2
16F9C MIAO LETTER REFORMED TONE-4
16F9D MIAO LETTER REFORMED TONE-5
16F9E MIAO LETTER REFORMED TONE-6
16F9F MIAO LETTER REFORMED TONE-8
16FE0 TANGUT ITERATION MARK
16FE1 NUSHU ITERATION MARK
17000 TANGUT IDEOGRAPH-#17000, TGT_MergedSrc=L2008-0008
17001 TANGUT IDEOGRAPH-#17001, TGT_MergedSrc=L2008-0030
17002 TANGUT IDEOGRAPH-#17002, TGT_MergedSrc=L2008-0101
17003 TANGUT IDEOGRAPH-#17003, TGT_MergedSrc=L2008-0038
17004 TANGUT IDEOGRAPH-#17004, TGT_MergedSrc=L2008-0026
17005 TANGUT IDEOGRAPH-#17005, TGT_MergedSrc=L2008-0013
17006 TANGUT IDEOGRAPH-#17006, TGT_MergedSrc=L2008-0065
17007 TANGUT IDEOGRAPH-#17007, TGT_MergedSrc=L2008-0005
17008 TANGUT IDEOGRAPH-#17008, TGT_MergedSrc=L2008-0087
17009 TANGUT IDEOGRAPH-#17009, TGT_MergedSrc=L2008-0066
1700A TANGUT IDEOGRAPH-#1700A, TGT_MergedSrc=L2008-0104
1700B TANGUT IDEOGRAPH-#1700B, TGT_MergedSrc=L2008-0080
1700C TANGUT IDEOGRAPH-#1700C, TGT_MergedSrc=L2008-0116
1700D TANGUT IDEOGRAPH-#1700D, TGT_MergedSrc=L2008-0025
1700E TANGUT IDEOGRAPH-#1700E, TGT_MergedSrc=L2008-0056
1700F TANGUT IDEOGRAPH-#1700F, TGT_MergedSrc=L2008-0017
17010 TANGUT IDEOGRAPH-#17010, TGT_MergedSrc=L2008-0143
17011 TANGUT IDEOGRAPH-#17011, TGT_MergedSrc=L2008-0067
17012 TANGUT IDEOGRAPH-#17012, TGT_MergedSrc=L2008-0068
17013 TANGUT IDEOGRAPH-#17013, TGT_MergedSrc=L2008-0147
17014 TANGUT IDEOGRAPH-#17014, TGT_MergedSrc=L2008-0089
17015 TANGUT IDEOGRAPH-#17015, TGT_MergedSrc=L2008-0035
17016 TANGUT IDEOGRAPH-#17016, TGT_MergedSrc=L2008-0069
17017 TANGUT IDEOGRAPH-#17017, TGT_MergedSrc=L2008-0145
17018 TANGUT IDEOGRAPH-#17018, TGT_MergedSrc=L2008-0070
17019 TANGUT IDEOGRAPH-#17019, TGT_MergedSrc=L2008-0082
1701A TANGUT IDEOGRAPH-#1701A, TGT_MergedSrc=L2008-4507
1701B TANGUT IDEOGRAPH-#1701B, TGT_MergedSrc=L2008-0042-4537
1701C TANGUT IDEOGRAPH-#1701C, TGT_MergedSrc=L2008-0043
1701D TANGUT IDEOGRAPH-#1701D, TGT_MergedSrc=L2008-0090
1701E TANGUT IDEOGRAPH-#1701E, TGT_MergedSrc=L2008-0148
1701F TANGUT IDEOGRAPH-#1701F, TGT_MergedSrc=L2008-0050
17020 TANGUT IDEOGRAPH-#17020, TGT_MergedSrc=L2008-0084
17021 TANGUT IDEOGRAPH-#17021, TGT_MergedSrc=L2008-0095
17022 TANGUT IDEOGRAPH-#17022, TGT_MergedSrc=L2008-4516
17023 TANGUT IDEOGRAPH-#17023, TGT_MergedSrc=L2008-0057-4548
17024 TANGUT IDEOGRAPH-#17024, TGT_MergedSrc=L2008-0044
17025 TANGUT IDEOGRAPH-#17025, TGT_MergedSrc=L2008-0088
17026 TANGUT IDEOGRAPH-#17026, TGT_MergedSrc=S1968-0077
17027 TANGUT IDEOGRAPH-#17027, TGT_MergedSrc=L2008-0097
17028 TANGUT IDEOGRAPH-#17028, TGT_MergedSrc=L2008-0018
17029 TANGUT IDEOGRAPH-#17029, TGT_MergedSrc=L2008-0077
1702A TANGUT IDEOGRAPH-#1702A, TGT_MergedSrc=L2008-0085
1702B TANGUT IDEOGRAPH-#1702B, TGT_MergedSrc=L2008-0014
1702C TANGUT IDEOGRAPH-#1702C, TGT_MergedSrc=L2008-0117
1702D TANGUT IDEOGRAPH-#1702D, TGT_MergedSrc=L2008-0048
1702E TANGUT IDEOGRAPH-#1702E, TGT_MergedSrc=L2008-0091
1702F TANGUT IDEOGRAPH-#1702F, TGT_MergedSrc=L2008-0099
17030 TANGUT IDEOGRAPH-#17030, TGT_MergedSrc=L2008-1939
17031 TANGUT IDEOGRAPH-#17031, TGT_MergedSrc=L2008-1961
17032 TANGUT IDEOGRAPH-#17032, TGT_MergedSrc=L2008-1952
17033 TANGUT IDEOGRAPH-#17033, TGT_MergedSrc=L2008-3483
17034 TANGUT IDEOGRAPH-#17034, TGT_MergedSrc=L2008-2955
17035 TANGUT IDEOGRAPH-#17035, TGT_MergedSrc=L2008-2380
17036 TANGUT IDEOGRAPH-#17036, TGT_MergedSrc=L2008-2954
17037 TANGUT IDEOGRAPH-#17037, TGT_MergedSrc=L2008-2561
17038 TANGUT IDEOGRAPH-#17038, TGT_MergedSrc=L2008-3472
17039 TANGUT IDEOGRAPH-#17039, TGT_MergedSrc=L2008-3766
1703A TANGUT IDEOGRAPH-#1703A, TGT_MergedSrc=L2008-3484
1703B TANGUT IDEOGRAPH-#1703B, TGT_MergedSrc=L2008-2979
1703C TANGUT IDEOGRAPH-#1703C, TGT_MergedSrc=L2008-2907
1703D TANGUT IDEOGRAPH-#1703D, TGT_MergedSrc=L2008-2948
1703E TANGUT IDEOGRAPH-#1703E, TGT_MergedSrc=L2008-2991
1703F TANGUT IDEOGRAPH-#1703F, TGT_MergedSrc=L2008-1895
17040 TANGUT IDEOGRAPH-#17040, TGT_MergedSrc=L2008-2946
17041 TANGUT IDEOGRAPH-#17041, TGT_MergedSrc=L2008-2562
17042 TANGUT IDEOGRAPH-#17042, TGT_MergedSrc=L2008-3757
17043 TANGUT IDEOGRAPH-#17043, TGT_MergedSrc=L2008-3486
17044 TANGUT IDEOGRAPH-#17044, TGT_MergedSrc=L2008-3449
17045 TANGUT IDEOGRAPH-#17045, TGT_MergedSrc=L2008-3485
17046 TANGUT IDEOGRAPH-#17046, TGT_MergedSrc=L2008-2381
17047 TANGUT IDEOGRAPH-#17047, TGT_MergedSrc=L2008-1984
17048 TANGUT IDEOGRAPH-#17048, TGT_MergedSrc=L2008-1919
17049 TANGUT IDEOGRAPH-#17049, TGT_MergedSrc=L2008-3759
1704A TANGUT IDEOGRAPH-#1704A, TGT_MergedSrc=L2008-3487
1704B TANGUT IDEOGRAPH-#1704B, TGT_MergedSrc=L2008-2936
1704C TANGUT IDEOGRAPH-#1704C, TGT_MergedSrc=L2008-2710
1704D TANGUT IDEOGRAPH-#1704D, TGT_MergedSrc=L2008-1925
1704E TANGUT IDEOGRAPH-#1704E, TGT_MergedSrc=L2008-2959
1704F TANGUT IDEOGRAPH-#1704F, TGT_MergedSrc=L2008-2930
17050 TANGUT IDEOGRAPH-#17050, TGT_MergedSrc=L2008-1940
17051 TANGUT IDEOGRAPH-#17051, TGT_MergedSrc=L2008-2386
17052 TANGUT IDEOGRAPH-#17052, TGT_MergedSrc=L2008-1972
17053 TANGUT IDEOGRAPH-#17053, TGT_MergedSrc=L2008-2553
17054 TANGUT IDEOGRAPH-#17054, TGT_MergedSrc=L2008-1975
17055 TANGUT IDEOGRAPH-#17055, TGT_MergedSrc=L2008-1960
17056 TANGUT IDEOGRAPH-#17056, TGT_MergedSrc=L2008-2956
17057 TANGUT IDEOGRAPH-#17057, TGT_MergedSrc=L2008-2919
17058 TANGUT IDEOGRAPH-#17058, TGT_MergedSrc=L2008-2971
17059 TANGUT IDEOGRAPH-#17059, TGT_MergedSrc=L2008-2941A
1705A TANGUT IDEOGRAPH-#1705A, TGT_MergedSrc=L2008-2941B
1705B TANGUT IDEOGRAPH-#1705B, TGT_MergedSrc=L2008-3466
1705C TANGUT IDEOGRAPH-#1705C, TGT_MergedSrc=L2008-2713
1705D TANGUT IDEOGRAPH-#1705D, TGT_MergedSrc=L2008-1920
1705E TANGUT IDEOGRAPH-#1705E, TGT_MergedSrc=L2008-2973
1705F TANGUT IDEOGRAPH-#1705F, TGT_MergedSrc=L2008-2564
17060 TANGUT IDEOGRAPH-#17060, TGT_MergedSrc=L2008-2389
17061 TANGUT IDEOGRAPH-#17061, TGT_MergedSrc=L2008-2923
17062 TANGUT IDEOGRAPH-#17062, TGT_MergedSrc=L2008-2942
17063 TANGUT IDEOGRAPH-#17063, TGT_MergedSrc=L2008-2394
17064 TANGUT IDEOGRAPH-#17064, TGT_MergedSrc=L2008-2990
17065 TANGUT IDEOGRAPH-#17065, TGT_MergedSrc=L2008-2985
17066 TANGUT IDEOGRAPH-#17066, TGT_MergedSrc=L2008-3506
17067 TANGUT IDEOGRAPH-#17067, TGT_MergedSrc=L2008-1929
17068 TANGUT IDEOGRAPH-#17068, TGT_MergedSrc=L2008-1973
17069 TANGUT IDEOGRAPH-#17069, TGT_MergedSrc=L2008-2988
1706A TANGUT IDEOGRAPH-#1706A, TGT_MergedSrc=L2008-1982
1706B TANGUT IDEOGRAPH-#1706B, TGT_MergedSrc=L2008-2382
1706C TANGUT IDEOGRAPH-#1706C, TGT_MergedSrc=L2008-2559
1706D TANGUT IDEOGRAPH-#1706D, TGT_MergedSrc=L2008-1955
1706E TANGUT IDEOGRAPH-#1706E, TGT_MergedSrc=L2008-3465
1706F TANGUT IDEOGRAPH-#1706F, TGT_MergedSrc=L2008-1953
17070 TANGUT IDEOGRAPH-#17070, TGT_MergedSrc=N1966-039-096
17071 TANGUT IDEOGRAPH-#17071, TGT_MergedSrc=L2008-2372
17072 TANGUT IDEOGRAPH-#17072, TGT_MergedSrc=L2008-2563
17073 TANGUT IDEOGRAPH-#17073, TGT_MergedSrc=L2008-2822
17074 TANGUT IDEOGRAPH-#17074, TGT_MergedSrc=L2008-2980
17075 TANGUT IDEOGRAPH-#17075, TGT_MergedSrc=L2008-2958
17076 TANGUT IDEOGRAPH-#17076, TGT_MergedSrc=L2008-1956
17077 TANGUT IDEOGRAPH-#17077, TGT_MergedSrc=L2008-1922
17078 TANGUT IDEOGRAPH-#17078, TGT_MergedSrc=L2008-1921
17079 TANGUT IDEOGRAPH-#17079, TGT_MergedSrc=L2008-2977
1707A TANGUT IDEOGRAPH-#1707A, TGT_MergedSrc=L2008-2908
1707B TANGUT IDEOGRAPH-#1707B, TGT_MergedSrc=L2008-2704
1707C TANGUT IDEOGRAPH-#1707C, TGT_MergedSrc=L2008-1976
1707D TANGUT IDEOGRAPH-#1707D, TGT_MergedSrc=L2008-2832
1707E TANGUT IDEOGRAPH-#1707E, TGT_MergedSrc=L2008-2940
1707F TANGUT IDEOGRAPH-#1707F, TGT_MergedSrc=L2008-2957
17080 TANGUT IDEOGRAPH-#17080, TGT_MergedSrc=L2008-2839
17081 TANGUT IDEOGRAPH-#17081, TGT_MergedSrc=L2008-1974
17082 TANGUT IDEOGRAPH-#17082, TGT_MergedSrc=L2008-2385
17083 TANGUT IDEOGRAPH-#17083, TGT_MergedSrc=L2008-3461
17084 TANGUT IDEOGRAPH-#17084, TGT_MergedSrc=L2008-1923
17085 TANGUT IDEOGRAPH-#17085, TGT_MergedSrc=L2008-2384
17086 TANGUT IDEOGRAPH-#17086, TGT_MergedSrc=L2008-2939
17087 TANGUT IDEOGRAPH-#17087, TGT_MergedSrc=L2008-2554
17088 TANGUT IDEOGRAPH-#17088, TGT_MergedSrc=L2008-2920
17089 TANGUT IDEOGRAPH-#17089, TGT_MergedSrc=L2008-2970
1708A TANGUT IDEOGRAPH-#1708A, TGT_MergedSrc=L2008-1927
1708B TANGUT IDEOGRAPH-#1708B, TGT_MergedSrc=L2008-2944
1708C TANGUT IDEOGRAPH-#1708C, TGT_MergedSrc=L2008-2947
1708D TANGUT IDEOGRAPH-#1708D, TGT_MergedSrc=L2008-1893
1708E TANGUT IDEOGRAPH-#1708E, TGT_MergedSrc=L2008-2387
1708F TANGUT IDEOGRAPH-#1708F, TGT_MergedSrc=L2008-3519
17090 TANGUT IDEOGRAPH-#17090, TGT_MergedSrc=L2008-2831
17091 TANGUT IDEOGRAPH-#17091, TGT_MergedSrc=L2008-3496
17092 TANGUT IDEOGRAPH-#17092, TGT_MergedSrc=L2008-3462
17093 TANGUT IDEOGRAPH-#17093, TGT_MergedSrc=L2008-2838
17094 TANGUT IDEOGRAPH-#17094, TGT_MergedSrc=L2008-2572
17095 TANGUT IDEOGRAPH-#17095, TGT_MergedSrc=L2008-3518
17096 TANGUT IDEOGRAPH-#17096, TGT_MergedSrc=L2008-2383
17097 TANGUT IDEOGRAPH-#17097, TGT_MergedSrc=L2008-1970
17098 TANGUT IDEOGRAPH-#17098, TGT_MergedSrc=L2008-3509
17099 TANGUT IDEOGRAPH-#17099, TGT_MergedSrc=L2008-2365
1709A TANGUT IDEOGRAPH-#1709A, TGT_MergedSrc=L2008-1905
1709B TANGUT IDEOGRAPH-#1709B, TGT_MergedSrc=L2008-2828
1709C TANGUT IDEOGRAPH-#1709C, TGT_MergedSrc=L2008-1900
1709D TANGUT IDEOGRAPH-#1709D, TGT_MergedSrc=L2008-2711
1709E TANGUT IDEOGRAPH-#1709E, TGT_MergedSrc=L2008-1966
1709F TANGUT IDEOGRAPH-#1709F, TGT_MergedSrc=L2008-1954
170A0 TANGUT IDEOGRAPH-#170A0, TGT_MergedSrc=L2008-2567
170A1 TANGUT IDEOGRAPH-#170A1, TGT_MergedSrc=L2008-2555
170A2 TANGUT IDEOGRAPH-#170A2, TGT_MergedSrc=L2008-2566
170A3 TANGUT IDEOGRAPH-#170A3, TGT_MergedSrc=L2008-2712
170A4 TANGUT IDEOGRAPH-#170A4, TGT_MergedSrc=L2008-1971
170A5 TANGUT IDEOGRAPH-#170A5, TGT_MergedSrc=L2008-1926
170A6 TANGUT IDEOGRAPH-#170A6, TGT_MergedSrc=L2008-3764
170A7 TANGUT IDEOGRAPH-#170A7, TGT_MergedSrc=L2008-2937
170A8 TANGUT IDEOGRAPH-#170A8, TGT_MergedSrc=L2008-2943
170A9 TANGUT IDEOGRAPH-#170A9, TGT_MergedSrc=L2008-2714
170AA TANGUT IDEOGRAPH-#170AA, TGT_MergedSrc=L2008-2969
170AB TANGUT IDEOGRAPH-#170AB, TGT_MergedSrc=L2008-2986
170AC TANGUT IDEOGRAPH-#170AC, TGT_MergedSrc=L2008-2904
170AD TANGUT IDEOGRAPH-#170AD, TGT_MergedSrc=L2008-1897
170AE TANGUT IDEOGRAPH-#170AE, TGT_MergedSrc=L2008-1898
170AF TANGUT IDEOGRAPH-#170AF, TGT_MergedSrc=L2008-3473
170B0 TANGUT IDEOGRAPH-#170B0, TGT_MergedSrc=L2008-2945
170B1 TANGUT IDEOGRAPH-#170B1, TGT_MergedSrc=L2008-3467
170B2 TANGUT IDEOGRAPH-#170B2, TGT_MergedSrc=L2008-2556
170B3 TANGUT IDEOGRAPH-#170B3, TGT_MergedSrc=L2008-3471
170B4 TANGUT IDEOGRAPH-#170B4, TGT_MergedSrc=L2008-3482
170B5 TANGUT IDEOGRAPH-#170B5, TGT_MergedSrc=L2008-1924
170B6 TANGUT IDEOGRAPH-#170B6, TGT_MergedSrc=L2008-2568
170B7 TANGUT IDEOGRAPH-#170B7, TGT_MergedSrc=L2008-3758
170B8 TANGUT IDEOGRAPH-#170B8, TGT_MergedSrc=L2008-3508
170B9 TANGUT IDEOGRAPH-#170B9, TGT_MergedSrc=L2008-2987
170BA TANGUT IDEOGRAPH-#170BA, TGT_MergedSrc=L2008-2922
170BB TANGUT IDEOGRAPH-#170BB, TGT_MergedSrc=L2008-1983
170BC TANGUT IDEOGRAPH-#170BC, TGT_MergedSrc=L2008-2550
170BD TANGUT IDEOGRAPH-#170BD, TGT_MergedSrc=L2008-3452
170BE TANGUT IDEOGRAPH-#170BE, TGT_MergedSrc=L2008-2918
170BF TANGUT IDEOGRAPH-#170BF, TGT_MergedSrc=L2008-1930
170C0 TANGUT IDEOGRAPH-#170C0, TGT_MergedSrc=L2008-1933
170C1 TANGUT IDEOGRAPH-#170C1, TGT_MergedSrc=L2008-3515
170C2 TANGUT IDEOGRAPH-#170C2, TGT_MergedSrc=L2008-2818
170C3 TANGUT IDEOGRAPH-#170C3, TGT_MergedSrc=L2008-1928
170C4 TANGUT IDEOGRAPH-#170C4, TGT_MergedSrc=L2008-2989
170C5 TANGUT IDEOGRAPH-#170C5, TGT_MergedSrc=L2008-3468
170C6 TANGUT IDEOGRAPH-#170C6, TGT_MergedSrc=L2008-1894
170C7 TANGUT IDEOGRAPH-#170C7, TGT_MergedSrc=L2008-2551
170C8 TANGUT IDEOGRAPH-#170C8, TGT_MergedSrc=L2008-3460
170C9 TANGUT IDEOGRAPH-#170C9, TGT_MergedSrc=L2008-3451
170CA TANGUT IDEOGRAPH-#170CA, TGT_MergedSrc=L2008-3507
170CB TANGUT IDEOGRAPH-#170CB, TGT_MergedSrc=L2008-2921
170CC TANGUT IDEOGRAPH-#170CC, TGT_MergedSrc=L2008-2953
170CD TANGUT IDEOGRAPH-#170CD, TGT_MergedSrc=L2008-2972
170CE TANGUT IDEOGRAPH-#170CE, TGT_MergedSrc=L2008-3510
170CF TANGUT IDEOGRAPH-#170CF, TGT_MergedSrc=L2008-3511
170D0 TANGUT IDEOGRAPH-#170D0, TGT_MergedSrc=L2008-1885
170D1 TANGUT IDEOGRAPH-#170D1, TGT_MergedSrc=L2008-1627
170D2 TANGUT IDEOGRAPH-#170D2, TGT_MergedSrc=L2008-0181
170D3 TANGUT IDEOGRAPH-#170D3, TGT_MergedSrc=L2008-1584
170D4 TANGUT IDEOGRAPH-#170D4, TGT_MergedSrc=L2008-0853
170D5 TANGUT IDEOGRAPH-#170D5, TGT_MergedSrc=L2008-3402
170D6 TANGUT IDEOGRAPH-#170D6, TGT_MergedSrc=L2008-3409
170D7 TANGUT IDEOGRAPH-#170D7, TGT_MergedSrc=L2008-2327
170D8 TANGUT IDEOGRAPH-#170D8, TGT_MergedSrc=L2008-3736
170D9 TANGUT IDEOGRAPH-#170D9, TGT_MergedSrc=L2008-3414
170DA TANGUT IDEOGRAPH-#170DA, TGT_MergedSrc=L2008-3729
170DB TANGUT IDEOGRAPH-#170DB, TGT_MergedSrc=L2008-3554
170DC TANGUT IDEOGRAPH-#170DC, TGT_MergedSrc=L2008-3410
170DD TANGUT IDEOGRAPH-#170DD, TGT_MergedSrc=L2008-2334
170DE TANGUT IDEOGRAPH-#170DE, TGT_MergedSrc=L2008-3732
170DF TANGUT IDEOGRAPH-#170DF, TGT_MergedSrc=L2008-3730
170E0 TANGUT IDEOGRAPH-#170E0, TGT_MergedSrc=L2008-2527
170E1 TANGUT IDEOGRAPH-#170E1, TGT_MergedSrc=L2008-2529
170E2 TANGUT IDEOGRAPH-#170E2, TGT_MergedSrc=L2008-3404
170E3 TANGUT IDEOGRAPH-#170E3, TGT_MergedSrc=L2008-2537
170E4 TANGUT IDEOGRAPH-#170E4, TGT_MergedSrc=L2008-3416
170E5 TANGUT IDEOGRAPH-#170E5, TGT_MergedSrc=L2008-3739
170E6 TANGUT IDEOGRAPH-#170E6, TGT_MergedSrc=L2008-3422
170E7 TANGUT IDEOGRAPH-#170E7, TGT_MergedSrc=L2008-2309
170E8 TANGUT IDEOGRAPH-#170E8, TGT_MergedSrc=L2008-2538
170E9 TANGUT IDEOGRAPH-#170E9, TGT_MergedSrc=L2008-2319
170EA TANGUT IDEOGRAPH-#170EA, TGT_MergedSrc=L2008-2693
170EB TANGUT IDEOGRAPH-#170EB, TGT_MergedSrc=L2008-2313
170EC TANGUT IDEOGRAPH-#170EC, TGT_MergedSrc=L2008-3424
170ED TANGUT IDEOGRAPH-#170ED, TGT_MergedSrc=L2008-2314
170EE TANGUT IDEOGRAPH-#170EE, TGT_MergedSrc=L2008-3407
170EF TANGUT IDEOGRAPH-#170EF, TGT_MergedSrc=L2008-2898
170F0 TANGUT IDEOGRAPH-#170F0, TGT_MergedSrc=L2008-3397
170F1 TANGUT IDEOGRAPH-#170F1, TGT_MergedSrc=L2008-2310
170F2 TANGUT IDEOGRAPH-#170F2, TGT_MergedSrc=L2008-2311
170F3 TANGUT IDEOGRAPH-#170F3, TGT_MergedSrc=L2008-3428
170F4 TANGUT IDEOGRAPH-#170F4, TGT_MergedSrc=L2008-3731
170F5 TANGUT IDEOGRAPH-#170F5, TGT_MergedSrc=L2008-3406
170F6 TANGUT IDEOGRAPH-#170F6, TGT_MergedSrc=L2008-2332
170F7 TANGUT IDEOGRAPH-#170F7, TGT_MergedSrc=L2008-2534
170F8 TANGUT IDEOGRAPH-#170F8, TGT_MergedSrc=L2008-3413
170F9 TANGUT IDEOGRAPH-#170F9, TGT_MergedSrc=L2008-2695
170FA TANGUT IDEOGRAPH-#170FA, TGT_MergedSrc=L2008-2691
170FB TANGUT IDEOGRAPH-#170FB, TGT_MergedSrc=L2008-3734
170FC TANGUT IDEOGRAPH-#170FC, TGT_MergedSrc=L2008-2535
170FD TANGUT IDEOGRAPH-#170FD, TGT_MergedSrc=L2008-3811
170FE TANGUT IDEOGRAPH-#170FE, TGT_MergedSrc=L2008-3733
170FF TANGUT IDEOGRAPH-#170FF, TGT_MergedSrc=L2008-0032
17100 TANGUT IDEOGRAPH-#17100, TGT_MergedSrc=L2008-0061
17101 TANGUT IDEOGRAPH-#17101, TGT_MergedSrc=L2008-0076
17102 TANGUT IDEOGRAPH-#17102, TGT_MergedSrc=L2008-6000
17103 TANGUT IDEOGRAPH-#17103, TGT_MergedSrc=L2008-6002
17104 TANGUT IDEOGRAPH-#17104, TGT_MergedSrc=L2008-0064
17105 TANGUT IDEOGRAPH-#17105, TGT_MergedSrc=L2008-6004
17106 TANGUT IDEOGRAPH-#17106, TGT_MergedSrc=L2008-6003
17107 TANGUT IDEOGRAPH-#17107, TGT_MergedSrc=L2006-6027
17108 TANGUT IDEOGRAPH-#17108, TGT_MergedSrc=L2008-0009
17109 TANGUT IDEOGRAPH-#17109, TGT_MergedSrc=L2008-0049
1710A TANGUT IDEOGRAPH-#1710A, TGT_MergedSrc=L2008-0010
1710B TANGUT IDEOGRAPH-#1710B, TGT_MergedSrc=L2008-0052
1710C TANGUT IDEOGRAPH-#1710C, TGT_MergedSrc=L2008-5995
1710D TANGUT IDEOGRAPH-#1710D, TGT_MergedSrc=L2008-6001
1710E TANGUT IDEOGRAPH-#1710E, TGT_MergedSrc=L2008-0142
1710F TANGUT IDEOGRAPH-#1710F, TGT_MergedSrc=L2008-5997
17110 TANGUT IDEOGRAPH-#17110, TGT_MergedSrc=L2008-0081
17111 TANGUT IDEOGRAPH-#17111, TGT_MergedSrc=L2008-0027
17112 TANGUT IDEOGRAPH-#17112, TGT_MergedSrc=L2008-0094
17113 TANGUT IDEOGRAPH-#17113, TGT_MergedSrc=L2008-0108
17114 TANGUT IDEOGRAPH-#17114, TGT_MergedSrc=L2008-0086
17115 TANGUT IDEOGRAPH-#17115, TGT_MergedSrc=L2008-0132
17116 TANGUT IDEOGRAPH-#17116, TGT_MergedSrc=L2008-0123
17117 TANGUT IDEOGRAPH-#17117, TGT_MergedSrc=L2008-6005
17118 TANGUT IDEOGRAPH-#17118, TGT_MergedSrc=L2008-5996
17119 TANGUT IDEOGRAPH-#17119, TGT_MergedSrc=L2008-5998
1711A TANGUT IDEOGRAPH-#1711A, TGT_MergedSrc=L2008-6006
1711B TANGUT IDEOGRAPH-#1711B, TGT_MergedSrc=L2008-0019
1711C TANGUT IDEOGRAPH-#1711C, TGT_MergedSrc=L2008-0079
1711D TANGUT IDEOGRAPH-#1711D, TGT_MergedSrc=L2008-4505
1711E TANGUT IDEOGRAPH-#1711E, TGT_MergedSrc=L2008-4539
1711F TANGUT IDEOGRAPH-#1711F, TGT_MergedSrc=L2008-4528
17120 TANGUT IDEOGRAPH-#17120, TGT_MergedSrc=L2008-4524
17121 TANGUT IDEOGRAPH-#17121, TGT_MergedSrc=L2008-4529
17122 TANGUT IDEOGRAPH-#17122, TGT_MergedSrc=L2008-4544
17123 TANGUT IDEOGRAPH-#17123, TGT_MergedSrc=L2008-4538
17124 TANGUT IDEOGRAPH-#17124, TGT_MergedSrc=L2008-4536
17125 TANGUT IDEOGRAPH-#17125, TGT_MergedSrc=L2008-4550
17126 TANGUT IDEOGRAPH-#17126, TGT_MergedSrc=L2008-4527
17127 TANGUT IDEOGRAPH-#17127, TGT_MergedSrc=L2008-4549
17128 TANGUT IDEOGRAPH-#17128, TGT_MergedSrc=L2008-4506
17129 TANGUT IDEOGRAPH-#17129, TGT_MergedSrc=L2008-1948
1712A TANGUT IDEOGRAPH-#1712A, TGT_MergedSrc=L2008-2361
1712B TANGUT IDEOGRAPH-#1712B, TGT_MergedSrc=L2008-2927
1712C TANGUT IDEOGRAPH-#1712C, TGT_MergedSrc=L2008-1965
1712D TANGUT IDEOGRAPH-#1712D, TGT_MergedSrc=L2008-1941
1712E TANGUT IDEOGRAPH-#1712E, TGT_MergedSrc=L2008-1985
1712F TANGUT IDEOGRAPH-#1712F, TGT_MergedSrc=L2008-2701
17130 TANGUT IDEOGRAPH-#17130, TGT_MergedSrc=L2008-2981
17131 TANGUT IDEOGRAPH-#17131, TGT_MergedSrc=L2008-2354
17132 TANGUT IDEOGRAPH-#17132, TGT_MergedSrc=H2004-B-0284
17133 TANGUT IDEOGRAPH-#17133, TGT_MergedSrc=L2008-3762
17134 TANGUT IDEOGRAPH-#17134, TGT_MergedSrc=L2008-3488-3489
17135 TANGUT IDEOGRAPH-#17135, TGT_MergedSrc=L2008-3477
17136 TANGUT IDEOGRAPH-#17136, TGT_MergedSrc=L2008-3474
17137 TANGUT IDEOGRAPH-#17137, TGT_MergedSrc=L2008-2823
17138 TANGUT IDEOGRAPH-#17138, TGT_MergedSrc=L2008-1942
17139 TANGUT IDEOGRAPH-#17139, TGT_MergedSrc=L2008-1947
1713A TANGUT IDEOGRAPH-#1713A, TGT_MergedSrc=L2008-2362
1713B TANGUT IDEOGRAPH-#1713B, TGT_MergedSrc=L2008-2699
1713C TANGUT IDEOGRAPH-#1713C, TGT_MergedSrc=L2008-3456
1713D TANGUT IDEOGRAPH-#1713D, TGT_MergedSrc=L2008-3763
1713E TANGUT IDEOGRAPH-#1713E, TGT_MergedSrc=L2008-2931
1713F TANGUT IDEOGRAPH-#1713F, TGT_MergedSrc=L2008-3497
17140 TANGUT IDEOGRAPH-#17140, TGT_MergedSrc=L2008-3491
17141 TANGUT IDEOGRAPH-#17141, TGT_MergedSrc=L2008-2983
17142 TANGUT IDEOGRAPH-#17142, TGT_MergedSrc=L2008-2708
17143 TANGUT IDEOGRAPH-#17143, TGT_MergedSrc=L2008-2709
17144 TANGUT IDEOGRAPH-#17144, TGT_MergedSrc=L2008-2700
17145 TANGUT IDEOGRAPH-#17145, TGT_MergedSrc=L2008-2938
17146 TANGUT IDEOGRAPH-#17146, TGT_MergedSrc=L2008-2833
17147 TANGUT IDEOGRAPH-#17147, TGT_MergedSrc=L2008-1962
17148 TANGUT IDEOGRAPH-#17148, TGT_MergedSrc=L2008-0016
17149 TANGUT IDEOGRAPH-#17149, TGT_MergedSrc=L2008-1906
1714A TANGUT IDEOGRAPH-#1714A, TGT_MergedSrc=L2008-1963
1714B TANGUT IDEOGRAPH-#1714B, TGT_MergedSrc=L2008-1918
1714C TANGUT IDEOGRAPH-#1714C, TGT_MergedSrc=L2008-3498
1714D TANGUT IDEOGRAPH-#1714D, TGT_MergedSrc=L2008-2702
1714E TANGUT IDEOGRAPH-#1714E, TGT_MergedSrc=L2008-3490
1714F TANGUT IDEOGRAPH-#1714F, TGT_MergedSrc=L2008-2913
17150 TANGUT IDEOGRAPH-#17150, TGT_MergedSrc=L2008-2909
17151 TANGUT IDEOGRAPH-#17151, TGT_MergedSrc=L2008-2911
17152 TANGUT IDEOGRAPH-#17152, TGT_MergedSrc=L2008-2982
17153 TANGUT IDEOGRAPH-#17153, TGT_MergedSrc=L2008-2917
17154 TANGUT IDEOGRAPH-#17154, TGT_MergedSrc=L2008-1943
17155 TANGUT IDEOGRAPH-#17155, TGT_MergedSrc=L2008-1949
17156 TANGUT IDEOGRAPH-#17156, TGT_MergedSrc=L2008-1944
17157 TANGUT IDEOGRAPH-#17157, TGT_MergedSrc=L2008-2960
17158 TANGUT IDEOGRAPH-#17158, TGT_MergedSrc=L2008-1914
17159 TANGUT IDEOGRAPH-#17159, TGT_MergedSrc=L2008-2363
1715A TANGUT IDEOGRAPH-#1715A, TGT_MergedSrc=L2008-1950
1715B TANGUT IDEOGRAPH-#1715B, TGT_MergedSrc=L2008-2826
1715C TANGUT IDEOGRAPH-#1715C, TGT_MergedSrc=L2008-2353
1715D TANGUT IDEOGRAPH-#1715D, TGT_MergedSrc=L2008-2914
1715E TANGUT IDEOGRAPH-#1715E, TGT_MergedSrc=L2008-1964
1715F TANGUT IDEOGRAPH-#1715F, TGT_MergedSrc=L2008-3767
17160 TANGUT IDEOGRAPH-#17160, TGT_MergedSrc=L2008-1909
17161 TANGUT IDEOGRAPH-#17161, TGT_MergedSrc=L2008-1981-3517
17162 TANGUT IDEOGRAPH-#17162, TGT_MergedSrc=L2008-2364
17163 TANGUT IDEOGRAPH-#17163, TGT_MergedSrc=L2008-3493
17164 TANGUT IDEOGRAPH-#17164, TGT_MergedSrc=L2008-3475
17165 TANGUT IDEOGRAPH-#17165, TGT_MergedSrc=L2008-1899
17166 TANGUT IDEOGRAPH-#17166, TGT_MergedSrc=L2008-2707
17167 TANGUT IDEOGRAPH-#17167, TGT_MergedSrc=L2008-1907
17168 TANGUT IDEOGRAPH-#17168, TGT_MergedSrc=L2008-2376
17169 TANGUT IDEOGRAPH-#17169, TGT_MergedSrc=L2008-2952
1716A TANGUT IDEOGRAPH-#1716A, TGT_MergedSrc=L2008-2929
1716B TANGUT IDEOGRAPH-#1716B, TGT_MergedSrc=L2008-2369
1716C TANGUT IDEOGRAPH-#1716C, TGT_MergedSrc=L2008-1969
1716D TANGUT IDEOGRAPH-#1716D, TGT_MergedSrc=L2008-3505
1716E TANGUT IDEOGRAPH-#1716E, TGT_MergedSrc=L2008-2830
1716F TANGUT IDEOGRAPH-#1716F, TGT_MergedSrc=L2008-2377
17170 TANGUT IDEOGRAPH-#17170, TGT_MergedSrc=L2008-3463
17171 TANGUT IDEOGRAPH-#17171, TGT_MergedSrc=L2008-1904
17172 TANGUT IDEOGRAPH-#17172, TGT_MergedSrc=L2008-1910
17173 TANGUT IDEOGRAPH-#17173, TGT_MergedSrc=L2008-2933
17174 TANGUT IDEOGRAPH-#17174, TGT_MergedSrc=L2008-2932
17175 TANGUT IDEOGRAPH-#17175, TGT_MergedSrc=L2008-2370
17176 TANGUT IDEOGRAPH-#17176, TGT_MergedSrc=L2008-2565
17177 TANGUT IDEOGRAPH-#17177, TGT_MergedSrc=L2008-2962
17178 TANGUT IDEOGRAPH-#17178, TGT_MergedSrc=L2008-1967
17179 TANGUT IDEOGRAPH-#17179, TGT_MergedSrc=L2008-2375
1717A TANGUT IDEOGRAPH-#1717A, TGT_MergedSrc=L2008-2367
1717B TANGUT IDEOGRAPH-#1717B, TGT_MergedSrc=L2008-2910
1717C TANGUT IDEOGRAPH-#1717C, TGT_MergedSrc=L2008-3492
1717D TANGUT IDEOGRAPH-#1717D, TGT_MergedSrc=L2008-2817
1717E TANGUT IDEOGRAPH-#1717E, TGT_MergedSrc=L2008-2915
1717F TANGUT IDEOGRAPH-#1717F, TGT_MergedSrc=L2008-3494
17180 TANGUT IDEOGRAPH-#17180, TGT_MergedSrc=L2008-1915
17181 TANGUT IDEOGRAPH-#17181, TGT_MergedSrc=L2008-2355
17182 TANGUT IDEOGRAPH-#17182, TGT_MergedSrc=L2008-2827
17183 TANGUT IDEOGRAPH-#17183, TGT_MergedSrc=L2008-2374
17184 TANGUT IDEOGRAPH-#17184, TGT_MergedSrc=L2008-2984
17185 TANGUT IDEOGRAPH-#17185, TGT_MergedSrc=L2008-1911
17186 TANGUT IDEOGRAPH-#17186, TGT_MergedSrc=L2008-2903
17187 TANGUT IDEOGRAPH-#17187, TGT_MergedSrc=L2008-2825
17188 TANGUT IDEOGRAPH-#17188, TGT_MergedSrc=L2008-2357
17189 TANGUT IDEOGRAPH-#17189, TGT_MergedSrc=L2008-3459
1718A TANGUT IDEOGRAPH-#1718A, TGT_MergedSrc=L2008-3458
1718B TANGUT IDEOGRAPH-#1718B, TGT_MergedSrc=L2008-2902
1718C TANGUT IDEOGRAPH-#1718C, TGT_MergedSrc=L2008-2837
1718D TANGUT IDEOGRAPH-#1718D, TGT_MergedSrc=L2008-2368
1718E TANGUT IDEOGRAPH-#1718E, TGT_MergedSrc=L2008-3454
1718F TANGUT IDEOGRAPH-#1718F, TGT_MergedSrc=L2008-3768
17190 TANGUT IDEOGRAPH-#17190, TGT_MergedSrc=L2008-2373
17191 TANGUT IDEOGRAPH-#17191, TGT_MergedSrc=L2008-2964
17192 TANGUT IDEOGRAPH-#17192, TGT_MergedSrc=L2008-1901
17193 TANGUT IDEOGRAPH-#17193, TGT_MergedSrc=L2008-1908
17194 TANGUT IDEOGRAPH-#17194, TGT_MergedSrc=L2008-2819
17195 TANGUT IDEOGRAPH-#17195, TGT_MergedSrc=L2008-2378
17196 TANGUT IDEOGRAPH-#17196, TGT_MergedSrc=L2008-3760
17197 TANGUT IDEOGRAPH-#17197, TGT_MergedSrc=L2008-2966
17198 TANGUT IDEOGRAPH-#17198, TGT_MergedSrc=L2008-1916
17199 TANGUT IDEOGRAPH-#17199, TGT_MergedSrc=L2008-2706
1719A TANGUT IDEOGRAPH-#1719A, TGT_MergedSrc=L2008-1968
1719B TANGUT IDEOGRAPH-#1719B, TGT_MergedSrc=L2008-1951
1719C TANGUT IDEOGRAPH-#1719C, TGT_MergedSrc=L2008-3761
1719D TANGUT IDEOGRAPH-#1719D, TGT_MergedSrc=L2008-2934
1719E TANGUT IDEOGRAPH-#1719E, TGT_MergedSrc=L2008-1945
1719F TANGUT IDEOGRAPH-#1719F, TGT_MergedSrc=L2008-1903
171A0 TANGUT IDEOGRAPH-#171A0, TGT_MergedSrc=L2008-2366
171A1 TANGUT IDEOGRAPH-#171A1, TGT_MergedSrc=L2008-2379
171A2 TANGUT IDEOGRAPH-#171A2, TGT_MergedSrc=L2008-3478
171A3 TANGUT IDEOGRAPH-#171A3, TGT_MergedSrc=L2008-2558
171A4 TANGUT IDEOGRAPH-#171A4, TGT_MergedSrc=L2008-1913
171A5 TANGUT IDEOGRAPH-#171A5, TGT_MergedSrc=L2008-1917
171A6 TANGUT IDEOGRAPH-#171A6, TGT_MergedSrc=L2008-2395
171A7 TANGUT IDEOGRAPH-#171A7, TGT_MergedSrc=L2008-3457
171A8 TANGUT IDEOGRAPH-#171A8, TGT_MergedSrc=L2008-2968
171A9 TANGUT IDEOGRAPH-#171A9, TGT_MergedSrc=L2008-2703
171AA TANGUT IDEOGRAPH-#171AA, TGT_MergedSrc=L2008-3769
171AB TANGUT IDEOGRAPH-#171AB, TGT_MergedSrc=L2008-1946
171AC TANGUT IDEOGRAPH-#171AC, TGT_MergedSrc=L2008-1902
171AD TANGUT IDEOGRAPH-#171AD, TGT_MergedSrc=L2008-2356
171AE TANGUT IDEOGRAPH-#171AE, TGT_MergedSrc=L2008-2912
171AF TANGUT IDEOGRAPH-#171AF, TGT_MergedSrc=L2008-3479
171B0 TANGUT IDEOGRAPH-#171B0, TGT_MergedSrc=L2008-3502
171B1 TANGUT IDEOGRAPH-#171B1, TGT_MergedSrc=L2008-3503
171B2 TANGUT IDEOGRAPH-#171B2, TGT_MergedSrc=L2008-1912
171B3 TANGUT IDEOGRAPH-#171B3, TGT_MergedSrc=L2008-1896
171B4 TANGUT IDEOGRAPH-#171B4, TGT_MergedSrc=L2008-3476
171B5 TANGUT IDEOGRAPH-#171B5, TGT_MergedSrc=L2008-3464
171B6 TANGUT IDEOGRAPH-#171B6, TGT_MergedSrc=L2008-3480
171B7 TANGUT IDEOGRAPH-#171B7, TGT_MergedSrc=L2008-2935
171B8 TANGUT IDEOGRAPH-#171B8, TGT_MergedSrc=L2008-2371
171B9 TANGUT IDEOGRAPH-#171B9, TGT_MergedSrc=L2008-3500
171BA TANGUT IDEOGRAPH-#171BA, TGT_MergedSrc=L2008-2965
171BB TANGUT IDEOGRAPH-#171BB, TGT_MergedSrc=L2008-3455
171BC TANGUT IDEOGRAPH-#171BC, TGT_MergedSrc=L2008-3501
171BD TANGUT IDEOGRAPH-#171BD, TGT_MergedSrc=L2008-2552
171BE TANGUT IDEOGRAPH-#171BE, TGT_MergedSrc=L2008-2557
171BF TANGUT IDEOGRAPH-#171BF, TGT_MergedSrc=L2008-2916
171C0 TANGUT IDEOGRAPH-#171C0, TGT_MergedSrc=L2008-2719
171C1 TANGUT IDEOGRAPH-#171C1, TGT_MergedSrc=L2008-3504
171C2 TANGUT IDEOGRAPH-#171C2, TGT_MergedSrc=L2008-2967
171C3 TANGUT IDEOGRAPH-#171C3, TGT_MergedSrc=L2008-4648
171C4 TANGUT IDEOGRAPH-#171C4, TGT_MergedSrc=L2008-4559
171C5 TANGUT IDEOGRAPH-#171C5, TGT_MergedSrc=L2008-4560
171C6 TANGUT IDEOGRAPH-#171C6, TGT_MergedSrc=L2008-2017
171C7 TANGUT IDEOGRAPH-#171C7, TGT_MergedSrc=L2008-3538
171C8 TANGUT IDEOGRAPH-#171C8, TGT_MergedSrc=L2008-2730
171C9 TANGUT IDEOGRAPH-#171C9, TGT_MergedSrc=L2008-2431
171CA TANGUT IDEOGRAPH-#171CA, TGT_MergedSrc=L2008-3836
171CB TANGUT IDEOGRAPH-#171CB, TGT_MergedSrc=L2008-3818
171CC TANGUT IDEOGRAPH-#171CC, TGT_MergedSrc=L2008-3812
171CD TANGUT IDEOGRAPH-#171CD, TGT_MergedSrc=L2008-3834
171CE TANGUT IDEOGRAPH-#171CE, TGT_MergedSrc=L2008-3815
171CF TANGUT IDEOGRAPH-#171CF, TGT_MergedSrc=L2008-3831
171D0 TANGUT IDEOGRAPH-#171D0, TGT_MergedSrc=L2008-3832
171D1 TANGUT IDEOGRAPH-#171D1, TGT_MergedSrc=L2008-3839
171D2 TANGUT IDEOGRAPH-#171D2, TGT_MergedSrc=L2008-3841
171D3 TANGUT IDEOGRAPH-#171D3, TGT_MergedSrc=L2008-3837
171D4 TANGUT IDEOGRAPH-#171D4, TGT_MergedSrc=L2008-3827
171D5 TANGUT IDEOGRAPH-#171D5, TGT_MergedSrc=L2008-3840
171D6 TANGUT IDEOGRAPH-#171D6, TGT_MergedSrc=L2008-3826
171D7 TANGUT IDEOGRAPH-#171D7, TGT_MergedSrc=L2008-3838
171D8 TANGUT IDEOGRAPH-#171D8, TGT_MergedSrc=L2008-3835
171D9 TANGUT IDEOGRAPH-#171D9, TGT_MergedSrc=L2008-3833
171DA TANGUT IDEOGRAPH-#171DA, TGT_MergedSrc=L2008-4947
171DB TANGUT IDEOGRAPH-#171DB, TGT_MergedSrc=L2008-4856
171DC TANGUT IDEOGRAPH-#171DC, TGT_MergedSrc=L2008-5014
171DD TANGUT IDEOGRAPH-#171DD, TGT_MergedSrc=L2008-4689
171DE TANGUT IDEOGRAPH-#171DE, TGT_MergedSrc=L2008-1501
171DF TANGUT IDEOGRAPH-#171DF, TGT_MergedSrc=L2008-1335
171E0 TANGUT IDEOGRAPH-#171E0, TGT_MergedSrc=L2008-1020
171E1 TANGUT IDEOGRAPH-#171E1, TGT_MergedSrc=L2008-1158
171E2 TANGUT IDEOGRAPH-#171E2, TGT_MergedSrc=L2008-0911
171E3 TANGUT IDEOGRAPH-#171E3, TGT_MergedSrc=L2008-1524
171E4 TANGUT IDEOGRAPH-#171E4, TGT_MergedSrc=L2008-1143
171E5 TANGUT IDEOGRAPH-#171E5, TGT_MergedSrc=L2008-1159
171E6 TANGUT IDEOGRAPH-#171E6, TGT_MergedSrc=L2008-1000
171E7 TANGUT IDEOGRAPH-#171E7, TGT_MergedSrc=L2008-1179
171E8 TANGUT IDEOGRAPH-#171E8, TGT_MergedSrc=L2008-1178
171E9 TANGUT IDEOGRAPH-#171E9, TGT_MergedSrc=L2008-1549
171EA TANGUT IDEOGRAPH-#171EA, TGT_MergedSrc=L2008-1144
171EB TANGUT IDEOGRAPH-#171EB, TGT_MergedSrc=L2008-1147
171EC TANGUT IDEOGRAPH-#171EC, TGT_MergedSrc=L2008-0928
171ED TANGUT IDEOGRAPH-#171ED, TGT_MergedSrc=L2008-1559
171EE TANGUT IDEOGRAPH-#171EE, TGT_MergedSrc=L2008-1067
171EF TANGUT IDEOGRAPH-#171EF, TGT_MergedSrc=L2008-0978
171F0 TANGUT IDEOGRAPH-#171F0, TGT_MergedSrc=L2008-1215
171F1 TANGUT IDEOGRAPH-#171F1, TGT_MergedSrc=L2008-1188
171F2 TANGUT IDEOGRAPH-#171F2, TGT_MergedSrc=L2008-1488
171F3 TANGUT IDEOGRAPH-#171F3, TGT_MergedSrc=L2008-1525
171F4 TANGUT IDEOGRAPH-#171F4, TGT_MergedSrc=L2008-1206
171F5 TANGUT IDEOGRAPH-#171F5, TGT_MergedSrc=L2008-1145
171F6 TANGUT IDEOGRAPH-#171F6, TGT_MergedSrc=L2008-6018
171F7 TANGUT IDEOGRAPH-#171F7, TGT_MergedSrc=L2008-1146
171F8 TANGUT IDEOGRAPH-#171F8, TGT_MergedSrc=L2008-1421
171F9 TANGUT IDEOGRAPH-#171F9, TGT_MergedSrc=L2008-0965
171FA TANGUT IDEOGRAPH-#171FA, TGT_MergedSrc=L2008-1044
171FB TANGUT IDEOGRAPH-#171FB, TGT_MergedSrc=L2008-0901
171FC TANGUT IDEOGRAPH-#171FC, TGT_MergedSrc=L2008-1189
171FD TANGUT IDEOGRAPH-#171FD, TGT_MergedSrc=L2008-0992
171FE TANGUT IDEOGRAPH-#171FE, TGT_MergedSrc=L2008-1069
171FF TANGUT IDEOGRAPH-#171FF, TGT_MergedSrc=L2008-1432
17200 TANGUT IDEOGRAPH-#17200, TGT_MergedSrc=L2008-1068
17201 TANGUT IDEOGRAPH-#17201, TGT_MergedSrc=L2008-1225
17202 TANGUT IDEOGRAPH-#17202, TGT_MergedSrc=L2008-1297
17203 TANGUT IDEOGRAPH-#17203, TGT_MergedSrc=L2008-1422
17204 TANGUT IDEOGRAPH-#17204, TGT_MergedSrc=L2008-1517
17205 TANGUT IDEOGRAPH-#17205, TGT_MergedSrc=L2008-1455
17206 TANGUT IDEOGRAPH-#17206, TGT_MergedSrc=L2008-1047
17207 TANGUT IDEOGRAPH-#17207, TGT_MergedSrc=L2008-0942
17208 TANGUT IDEOGRAPH-#17208, TGT_MergedSrc=L2008-1210
17209 TANGUT IDEOGRAPH-#17209, TGT_MergedSrc=L2008-1470
1720A TANGUT IDEOGRAPH-#1720A, TGT_MergedSrc=L2008-1267B
1720B TANGUT IDEOGRAPH-#1720B, TGT_MergedSrc=L2008-1490
1720C TANGUT IDEOGRAPH-#1720C, TGT_MergedSrc=L2008-1469
1720D TANGUT IDEOGRAPH-#1720D, TGT_MergedSrc=L2008-0919
1720E TANGUT IDEOGRAPH-#1720E, TGT_MergedSrc=L2008-1187
1720F TANGUT IDEOGRAPH-#1720F, TGT_MergedSrc=L2008-1177
17210 TANGUT IDEOGRAPH-#17210, TGT_MergedSrc=L2008-0944
17211 TANGUT IDEOGRAPH-#17211, TGT_MergedSrc=L2008-1110
17212 TANGUT IDEOGRAPH-#17212, TGT_MergedSrc=L2008-1298
17213 TANGUT IDEOGRAPH-#17213, TGT_MergedSrc=L2008-1445
17214 TANGUT IDEOGRAPH-#17214, TGT_MergedSrc=L2008-1550
17215 TANGUT IDEOGRAPH-#17215, TGT_MergedSrc=L2008-1267A
17216 TANGUT IDEOGRAPH-#17216, TGT_MergedSrc=L2008-1555
17217 TANGUT IDEOGRAPH-#17217, TGT_MergedSrc=L2008-1001
17218 TANGUT IDEOGRAPH-#17218, TGT_MergedSrc=L2008-1202
17219 TANGUT IDEOGRAPH-#17219, TGT_MergedSrc=L2008-1399
1721A TANGUT IDEOGRAPH-#1721A, TGT_MergedSrc=L2008-1460
1721B TANGUT IDEOGRAPH-#1721B, TGT_MergedSrc=L2008-1459
1721C TANGUT IDEOGRAPH-#1721C, TGT_MergedSrc=L2008-1160
1721D TANGUT IDEOGRAPH-#1721D, TGT_MergedSrc=L2008-1486
1721E TANGUT IDEOGRAPH-#1721E, TGT_MergedSrc=L2008-1207
1721F TANGUT IDEOGRAPH-#1721F, TGT_MergedSrc=L2008-1104
17220 TANGUT IDEOGRAPH-#17220, TGT_MergedSrc=L2008-0943
17221 TANGUT IDEOGRAPH-#17221, TGT_MergedSrc=L2008-0990
17222 TANGUT IDEOGRAPH-#17222, TGT_MergedSrc=L2008-0916
17223 TANGUT IDEOGRAPH-#17223, TGT_MergedSrc=L2008-1377
17224 TANGUT IDEOGRAPH-#17224, TGT_MergedSrc=L2008-1181
17225 TANGUT IDEOGRAPH-#17225, TGT_MergedSrc=L2008-1396
17226 TANGUT IDEOGRAPH-#17226, TGT_MergedSrc=L2008-1336
17227 TANGUT IDEOGRAPH-#17227, TGT_MergedSrc=L2008-1161
17228 TANGUT IDEOGRAPH-#17228, TGT_MergedSrc=L2008-1180
17229 TANGUT IDEOGRAPH-#17229, TGT_MergedSrc=L2008-5955
1722A TANGUT IDEOGRAPH-#1722A, TGT_MergedSrc=L2008-5981
1722B TANGUT IDEOGRAPH-#1722B, TGT_MergedSrc=L2008-5948
1722C TANGUT IDEOGRAPH-#1722C, TGT_MergedSrc=L2008-5951
1722D TANGUT IDEOGRAPH-#1722D, TGT_MergedSrc=L2008-5835
1722E TANGUT IDEOGRAPH-#1722E, TGT_MergedSrc=L2008-5846
1722F TANGUT IDEOGRAPH-#1722F, TGT_MergedSrc=L2008-5837
17230 TANGUT IDEOGRAPH-#17230, TGT_MergedSrc=L2008-5982
17231 TANGUT IDEOGRAPH-#17231, TGT_MergedSrc=L2008-5913
17232 TANGUT IDEOGRAPH-#17232, TGT_MergedSrc=L2008-5911
17233 TANGUT IDEOGRAPH-#17233, TGT_MergedSrc=L2008-5958
17234 TANGUT IDEOGRAPH-#17234, TGT_MergedSrc=L2008-5992
17235 TANGUT IDEOGRAPH-#17235, TGT_MergedSrc=L2008-5838
17236 TANGUT IDEOGRAPH-#17236, TGT_MergedSrc=L2008-5918
17237 TANGUT IDEOGRAPH-#17237, TGT_MergedSrc=L2008-5956
17238 TANGUT IDEOGRAPH-#17238, TGT_MergedSrc=L2008-5896
17239 TANGUT IDEOGRAPH-#17239, TGT_MergedSrc=L2008-5985
1723A TANGUT IDEOGRAPH-#1723A, TGT_MergedSrc=L2008-5952
1723B TANGUT IDEOGRAPH-#1723B, TGT_MergedSrc=L2008-0426
1723C TANGUT IDEOGRAPH-#1723C, TGT_MergedSrc=L2008-0625
1723D TANGUT IDEOGRAPH-#1723D, TGT_MergedSrc=L2008-1506
1723E TANGUT IDEOGRAPH-#1723E, TGT_MergedSrc=L2008-0732
1723F TANGUT IDEOGRAPH-#1723F, TGT_MergedSrc=L2008-1829
17240 TANGUT IDEOGRAPH-#17240, TGT_MergedSrc=L2008-1825
17241 TANGUT IDEOGRAPH-#17241, TGT_MergedSrc=L2008-0439
17242 TANGUT IDEOGRAPH-#17242, TGT_MergedSrc=L2008-0440
17243 TANGUT IDEOGRAPH-#17243, TGT_MergedSrc=L2008-1826
17244 TANGUT IDEOGRAPH-#17244, TGT_MergedSrc=L2008-1497
17245 TANGUT IDEOGRAPH-#17245, TGT_MergedSrc=L2008-0618
17246 TANGUT IDEOGRAPH-#17246, TGT_MergedSrc=L2008-6009
17247 TANGUT IDEOGRAPH-#17247, TGT_MergedSrc=L2008-0431
17248 TANGUT IDEOGRAPH-#17248, TGT_MergedSrc=L2008-0453
17249 TANGUT IDEOGRAPH-#17249, TGT_MergedSrc=L2008-0735
1724A TANGUT IDEOGRAPH-#1724A, TGT_MergedSrc=L2008-1521
1724B TANGUT IDEOGRAPH-#1724B, TGT_MergedSrc=L2008-1259
1724C TANGUT IDEOGRAPH-#1724C, TGT_MergedSrc=L2008-1168
1724D TANGUT IDEOGRAPH-#1724D, TGT_MergedSrc=L2008-0372
1724E TANGUT IDEOGRAPH-#1724E, TGT_MergedSrc=L2008-0684
1724F TANGUT IDEOGRAPH-#1724F, TGT_MergedSrc=L2008-0365
17250 TANGUT IDEOGRAPH-#17250, TGT_MergedSrc=L2008-0862
17251 TANGUT IDEOGRAPH-#17251, TGT_MergedSrc=L2008-0571
17252 TANGUT IDEOGRAPH-#17252, TGT_MergedSrc=N1966-185-065
17253 TANGUT IDEOGRAPH-#17253, TGT_MergedSrc=L2008-1250
17254 TANGUT IDEOGRAPH-#17254, TGT_MergedSrc=L2008-0707
17255 TANGUT IDEOGRAPH-#17255, TGT_MergedSrc=L2008-1349
17256 TANGUT IDEOGRAPH-#17256, TGT_MergedSrc=L2008-1861
17257 TANGUT IDEOGRAPH-#17257, TGT_MergedSrc=L2008-1714
17258 TANGUT IDEOGRAPH-#17258, TGT_MergedSrc=L2008-1374
17259 TANGUT IDEOGRAPH-#17259, TGT_MergedSrc=L2008-1261
1725A TANGUT IDEOGRAPH-#1725A, TGT_MergedSrc=L2008-1424
1725B TANGUT IDEOGRAPH-#1725B, TGT_MergedSrc=L2008-1262
1725C TANGUT IDEOGRAPH-#1725C, TGT_MergedSrc=L2008-0800
1725D TANGUT IDEOGRAPH-#1725D, TGT_MergedSrc=L2008-0585
1725E TANGUT IDEOGRAPH-#1725E, TGT_MergedSrc=L2008-1862
1725F TANGUT IDEOGRAPH-#1725F, TGT_MergedSrc=L2008-1767
17260 TANGUT IDEOGRAPH-#17260, TGT_MergedSrc=L2008-1260
17261 TANGUT IDEOGRAPH-#17261, TGT_MergedSrc=L2008-1750
17262 TANGUT IDEOGRAPH-#17262, TGT_MergedSrc=L2008-1751
17263 TANGUT IDEOGRAPH-#17263, TGT_MergedSrc=L2008-0797
17264 TANGUT IDEOGRAPH-#17264, TGT_MergedSrc=L2008-0530
17265 TANGUT IDEOGRAPH-#17265, TGT_MergedSrc=L2008-0896
17266 TANGUT IDEOGRAPH-#17266, TGT_MergedSrc=S1968-5520
17267 TANGUT IDEOGRAPH-#17267, TGT_MergedSrc=L2008-1777
17268 TANGUT IDEOGRAPH-#17268, TGT_MergedSrc=L2008-1783
17269 TANGUT IDEOGRAPH-#17269, TGT_MergedSrc=L2008-1249
1726A TANGUT IDEOGRAPH-#1726A, TGT_MergedSrc=L2008-1409
1726B TANGUT IDEOGRAPH-#1726B, TGT_MergedSrc=L2008-1263
1726C TANGUT IDEOGRAPH-#1726C, TGT_MergedSrc=L2008-1682
1726D TANGUT IDEOGRAPH-#1726D, TGT_MergedSrc=L2008-0572
1726E TANGUT IDEOGRAPH-#1726E, TGT_MergedSrc=L2008-0824
1726F TANGUT IDEOGRAPH-#1726F, TGT_MergedSrc=L2008-1689
17270 TANGUT IDEOGRAPH-#17270, TGT_MergedSrc=L2008-0879
17271 TANGUT IDEOGRAPH-#17271, TGT_MergedSrc=L2008-0677
17272 TANGUT IDEOGRAPH-#17272, TGT_MergedSrc=L2008-0282
17273 TANGUT IDEOGRAPH-#17273, TGT_MergedSrc=L2008-1752
17274 TANGUT IDEOGRAPH-#17274, TGT_MergedSrc=L2008-1687
17275 TANGUT IDEOGRAPH-#17275, TGT_MergedSrc=L2008-1686
17276 TANGUT IDEOGRAPH-#17276, TGT_MergedSrc=L2008-0327
17277 TANGUT IDEOGRAPH-#17277, TGT_MergedSrc=L2008-0366
17278 TANGUT IDEOGRAPH-#17278, TGT_MergedSrc=L2008-3026
17279 TANGUT IDEOGRAPH-#17279, TGT_MergedSrc=L2008-2030
1727A TANGUT IDEOGRAPH-#1727A, TGT_MergedSrc=L2008-1987
1727B TANGUT IDEOGRAPH-#1727B, TGT_MergedSrc=L2008-3019
1727C TANGUT IDEOGRAPH-#1727C, TGT_MergedSrc=L2008-3023
1727D TANGUT IDEOGRAPH-#1727D, TGT_MergedSrc=L2008-2031
1727E TANGUT IDEOGRAPH-#1727E, TGT_MergedSrc=L2008-1988
1727F TANGUT IDEOGRAPH-#1727F, TGT_MergedSrc=L2008-2044
17280 TANGUT IDEOGRAPH-#17280, TGT_MergedSrc=L2008-3000
17281 TANGUT IDEOGRAPH-#17281, TGT_MergedSrc=L2008-2582
17282 TANGUT IDEOGRAPH-#17282, TGT_MergedSrc=L2008-3070
17283 TANGUT IDEOGRAPH-#17283, TGT_MergedSrc=L2008-2041
17284 TANGUT IDEOGRAPH-#17284, TGT_MergedSrc=L2008-3046
17285 TANGUT IDEOGRAPH-#17285, TGT_MergedSrc=L2008-2404
17286 TANGUT IDEOGRAPH-#17286, TGT_MergedSrc=L2008-2022
17287 TANGUT IDEOGRAPH-#17287, TGT_MergedSrc=L2008-2023
17288 TANGUT IDEOGRAPH-#17288, TGT_MergedSrc=L2008-2733
17289 TANGUT IDEOGRAPH-#17289, TGT_MergedSrc=L2008-3073
1728A TANGUT IDEOGRAPH-#1728A, TGT_MergedSrc=L2008-2422
1728B TANGUT IDEOGRAPH-#1728B, TGT_MergedSrc=L2008-3031
1728C TANGUT IDEOGRAPH-#1728C, TGT_MergedSrc=L2008-3040
1728D TANGUT IDEOGRAPH-#1728D, TGT_MergedSrc=L2008-2575
1728E TANGUT IDEOGRAPH-#1728E, TGT_MergedSrc=L2008-2577
1728F TANGUT IDEOGRAPH-#1728F, TGT_MergedSrc=L2008-2583
17290 TANGUT IDEOGRAPH-#17290, TGT_MergedSrc=L2008-3539
17291 TANGUT IDEOGRAPH-#17291, TGT_MergedSrc=L2008-3039
17292 TANGUT IDEOGRAPH-#17292, TGT_MergedSrc=L2008-3084
17293 TANGUT IDEOGRAPH-#17293, TGT_MergedSrc=L2008-3011
17294 TANGUT IDEOGRAPH-#17294, TGT_MergedSrc=L2008-3071
17295 TANGUT IDEOGRAPH-#17295, TGT_MergedSrc=L2008-2032
17296 TANGUT IDEOGRAPH-#17296, TGT_MergedSrc=L2008-2045
17297 TANGUT IDEOGRAPH-#17297, TGT_MergedSrc=L2008-2024
17298 TANGUT IDEOGRAPH-#17298, TGT_MergedSrc=L2008-3536
17299 TANGUT IDEOGRAPH-#17299, TGT_MergedSrc=L2008-2419
1729A TANGUT IDEOGRAPH-#1729A, TGT_MergedSrc=L2008-2410
1729B TANGUT IDEOGRAPH-#1729B, TGT_MergedSrc=L2008-3045
1729C TANGUT IDEOGRAPH-#1729C, TGT_MergedSrc=L2008-3773
1729D TANGUT IDEOGRAPH-#1729D, TGT_MergedSrc=L2008-3544
1729E TANGUT IDEOGRAPH-#1729E, TGT_MergedSrc=L2008-3541
1729F TANGUT IDEOGRAPH-#1729F, TGT_MergedSrc=L2008-2731
172A0 TANGUT IDEOGRAPH-#172A0, TGT_MergedSrc=L2008-3534
172A1 TANGUT IDEOGRAPH-#172A1, TGT_MergedSrc=L2008-3540
172A2 TANGUT IDEOGRAPH-#172A2, TGT_MergedSrc=L2008-2737
172A3 TANGUT IDEOGRAPH-#172A3, TGT_MergedSrc=L2008-3085
172A4 TANGUT IDEOGRAPH-#172A4, TGT_MergedSrc=L2008-6031
172A5 TANGUT IDEOGRAPH-#172A5, TGT_MergedSrc=L2008-2851
172A6 TANGUT IDEOGRAPH-#172A6, TGT_MergedSrc=L2008-2018
172A7 TANGUT IDEOGRAPH-#172A7, TGT_MergedSrc=L2008-1990
172A8 TANGUT IDEOGRAPH-#172A8, TGT_MergedSrc=L2008-2054
172A9 TANGUT IDEOGRAPH-#172A9, TGT_MergedSrc=L2008-2581
172AA TANGUT IDEOGRAPH-#172AA, TGT_MergedSrc=L2008-2029
172AB TANGUT IDEOGRAPH-#172AB, TGT_MergedSrc=L2008-2040
172AC TANGUT IDEOGRAPH-#172AC, TGT_MergedSrc=L2008-3027
172AD TANGUT IDEOGRAPH-#172AD, TGT_MergedSrc=L2008-2845
172AE TANGUT IDEOGRAPH-#172AE, TGT_MergedSrc=L2008-3547
172AF TANGUT IDEOGRAPH-#172AF, TGT_MergedSrc=L2008-2004
172B0 TANGUT IDEOGRAPH-#172B0, TGT_MergedSrc=L2008-3047
172B1 TANGUT IDEOGRAPH-#172B1, TGT_MergedSrc=L2008-2412
172B2 TANGUT IDEOGRAPH-#172B2, TGT_MergedSrc=S1968-4313
172B3 TANGUT IDEOGRAPH-#172B3, TGT_MergedSrc=L2008-6036
172B4 TANGUT IDEOGRAPH-#172B4, TGT_MergedSrc=L2008-2734
172B5 TANGUT IDEOGRAPH-#172B5, TGT_MergedSrc=L2008-3048
172B6 TANGUT IDEOGRAPH-#172B6, TGT_MergedSrc=L2008-3041
172B7 TANGUT IDEOGRAPH-#172B7, TGT_MergedSrc=L2008-2720
172B8 TANGUT IDEOGRAPH-#172B8, TGT_MergedSrc=L2008-1991
172B9 TANGUT IDEOGRAPH-#172B9, TGT_MergedSrc=L2008-2732
172BA TANGUT IDEOGRAPH-#172BA, TGT_MergedSrc=L2008-3024
172BB TANGUT IDEOGRAPH-#172BB, TGT_MergedSrc=L2008-3772
172BC TANGUT IDEOGRAPH-#172BC, TGT_MergedSrc=L2008-2843
172BD TANGUT IDEOGRAPH-#172BD, TGT_MergedSrc=L2008-3004
172BE TANGUT IDEOGRAPH-#172BE, TGT_MergedSrc=L2008-1994
172BF TANGUT IDEOGRAPH-#172BF, TGT_MergedSrc=L2008-2020
172C0 TANGUT IDEOGRAPH-#172C0, TGT_MergedSrc=L2008-2413
172C1 TANGUT IDEOGRAPH-#172C1, TGT_MergedSrc=L2008-1996
172C2 TANGUT IDEOGRAPH-#172C2, TGT_MergedSrc=L2008-2417
172C3 TANGUT IDEOGRAPH-#172C3, TGT_MergedSrc=L2008-3075
172C4 TANGUT IDEOGRAPH-#172C4, TGT_MergedSrc=L2008-2588
172C5 TANGUT IDEOGRAPH-#172C5, TGT_MergedSrc=L2008-3078
172C6 TANGUT IDEOGRAPH-#172C6, TGT_MergedSrc=L2008-3010
172C7 TANGUT IDEOGRAPH-#172C7, TGT_MergedSrc=L2008-3077
172C8 TANGUT IDEOGRAPH-#172C8, TGT_MergedSrc=L2008-3055
172C9 TANGUT IDEOGRAPH-#172C9, TGT_MergedSrc=L2008-2013
172CA TANGUT IDEOGRAPH-#172CA, TGT_MergedSrc=L2008-3013
172CB TANGUT IDEOGRAPH-#172CB, TGT_MergedSrc=L2008-2005
172CC TANGUT IDEOGRAPH-#172CC, TGT_MergedSrc=L2008-2401
172CD TANGUT IDEOGRAPH-#172CD, TGT_MergedSrc=L2008-3776
172CE TANGUT IDEOGRAPH-#172CE, TGT_MergedSrc=L2008-2034
172CF TANGUT IDEOGRAPH-#172CF, TGT_MergedSrc=L2008-3035
172D0 TANGUT IDEOGRAPH-#172D0, TGT_MergedSrc=L2008-2724
172D1 TANGUT IDEOGRAPH-#172D1, TGT_MergedSrc=L2008-2738
172D2 TANGUT IDEOGRAPH-#172D2, TGT_MergedSrc=L2008-2414
172D3 TANGUT IDEOGRAPH-#172D3, TGT_MergedSrc=L2008-2579
172D4 TANGUT IDEOGRAPH-#172D4, TGT_MergedSrc=L2008-3051
172D5 TANGUT IDEOGRAPH-#172D5, TGT_MergedSrc=L2008-2019
172D6 TANGUT IDEOGRAPH-#172D6, TGT_MergedSrc=L2008-2042
172D7 TANGUT IDEOGRAPH-#172D7, TGT_MergedSrc=L2008-2025
172D8 TANGUT IDEOGRAPH-#172D8, TGT_MergedSrc=L2008-2053
172D9 TANGUT IDEOGRAPH-#172D9, TGT_MergedSrc=L2008-1989
172DA TANGUT IDEOGRAPH-#172DA, TGT_MergedSrc=L2008-2590
172DB TANGUT IDEOGRAPH-#172DB, TGT_MergedSrc=L2008-3080
172DC TANGUT IDEOGRAPH-#172DC, TGT_MergedSrc=L2008-3550
172DD TANGUT IDEOGRAPH-#172DD, TGT_MergedSrc=L2008-3067
172DE TANGUT IDEOGRAPH-#172DE, TGT_MergedSrc=L2008-2587
172DF TANGUT IDEOGRAPH-#172DF, TGT_MergedSrc=L2008-2415
172E0 TANGUT IDEOGRAPH-#172E0, TGT_MergedSrc=L2008-1992
172E1 TANGUT IDEOGRAPH-#172E1, TGT_MergedSrc=L2008-2726
172E2 TANGUT IDEOGRAPH-#172E2, TGT_MergedSrc=L2008-1993
172E3 TANGUT IDEOGRAPH-#172E3, TGT_MergedSrc=L2008-2429
172E4 TANGUT IDEOGRAPH-#172E4, TGT_MergedSrc=L2008-3542
172E5 TANGUT IDEOGRAPH-#172E5, TGT_MergedSrc=L2008-3033
172E6 TANGUT IDEOGRAPH-#172E6, TGT_MergedSrc=L2008-3069
172E7 TANGUT IDEOGRAPH-#172E7, TGT_MergedSrc=S1968-4266
172E8 TANGUT IDEOGRAPH-#172E8, TGT_MergedSrc=L2008-2400
172E9 TANGUT IDEOGRAPH-#172E9, TGT_MergedSrc=L2008-3012
172EA TANGUT IDEOGRAPH-#172EA, TGT_MergedSrc=L2008-2725
172EB TANGUT IDEOGRAPH-#172EB, TGT_MergedSrc=L2008-3074
172EC TANGUT IDEOGRAPH-#172EC, TGT_MergedSrc=L2008-3056
172ED TANGUT IDEOGRAPH-#172ED, TGT_MergedSrc=L2008-2997
172EE TANGUT IDEOGRAPH-#172EE, TGT_MergedSrc=L2008-2416
172EF TANGUT IDEOGRAPH-#172EF, TGT_MergedSrc=L2008-2011
172F0 TANGUT IDEOGRAPH-#172F0, TGT_MergedSrc=L2008-2432
172F1 TANGUT IDEOGRAPH-#172F1, TGT_MergedSrc=L2008-3533
172F2 TANGUT IDEOGRAPH-#172F2, TGT_MergedSrc=L2008-2849
172F3 TANGUT IDEOGRAPH-#172F3, TGT_MergedSrc=L2008-3553
172F4 TANGUT IDEOGRAPH-#172F4, TGT_MergedSrc=L2008-3548
172F5 TANGUT IDEOGRAPH-#172F5, TGT_MergedSrc=L2008-2589
172F6 TANGUT IDEOGRAPH-#172F6, TGT_MergedSrc=L2008-6026
172F7 TANGUT IDEOGRAPH-#172F7, TGT_MergedSrc=L2008-2423
172F8 TANGUT IDEOGRAPH-#172F8, TGT_MergedSrc=L2008-3527
172F9 TANGUT IDEOGRAPH-#172F9, TGT_MergedSrc=L2008-3529
172FA TANGUT IDEOGRAPH-#172FA, TGT_MergedSrc=L2008-2058
172FB TANGUT IDEOGRAPH-#172FB, TGT_MergedSrc=L2008-2584
172FC TANGUT IDEOGRAPH-#172FC, TGT_MergedSrc=L2008-2408
172FD TANGUT IDEOGRAPH-#172FD, TGT_MergedSrc=L2008-3058
172FE TANGUT IDEOGRAPH-#172FE, TGT_MergedSrc=L2008-3057
172FF TANGUT IDEOGRAPH-#172FF, TGT_MergedSrc=L2008-3042
17300 TANGUT IDEOGRAPH-#17300, TGT_MergedSrc=L2008-3025
17301 TANGUT IDEOGRAPH-#17301, TGT_MergedSrc=L2008-3001
17302 TANGUT IDEOGRAPH-#17302, TGT_MergedSrc=L2008-6024
17303 TANGUT IDEOGRAPH-#17303, TGT_MergedSrc=L2008-2012
17304 TANGUT IDEOGRAPH-#17304, TGT_MergedSrc=L2008-2418
17305 TANGUT IDEOGRAPH-#17305, TGT_MergedSrc=L2008-2049
17306 TANGUT IDEOGRAPH-#17306, TGT_MergedSrc=L2008-3555
17307 TANGUT IDEOGRAPH-#17307, TGT_MergedSrc=L2008-3549
17308 TANGUT IDEOGRAPH-#17308, TGT_MergedSrc=L2008-2727
17309 TANGUT IDEOGRAPH-#17309, TGT_MergedSrc=L2008-2399
1730A TANGUT IDEOGRAPH-#1730A, TGT_MergedSrc=L2008-2405
1730B TANGUT IDEOGRAPH-#1730B, TGT_MergedSrc=L2008-3060
1730C TANGUT IDEOGRAPH-#1730C, TGT_MergedSrc=L2008-1997
1730D TANGUT IDEOGRAPH-#1730D, TGT_MergedSrc=L2008-3049
1730E TANGUT IDEOGRAPH-#1730E, TGT_MergedSrc=L2008-3050
1730F TANGUT IDEOGRAPH-#1730F, TGT_MergedSrc=L2008-3028
17310 TANGUT IDEOGRAPH-#17310, TGT_MergedSrc=L2008-6039
17311 TANGUT IDEOGRAPH-#17311, TGT_MergedSrc=L2008-6025
17312 TANGUT IDEOGRAPH-#17312, TGT_MergedSrc=L2008-3061
17313 TANGUT IDEOGRAPH-#17313, TGT_MergedSrc=L2008-2729
17314 TANGUT IDEOGRAPH-#17314, TGT_MergedSrc=L2008-3537
17315 TANGUT IDEOGRAPH-#17315, TGT_MergedSrc=L2008-3007A
17316 TANGUT IDEOGRAPH-#17316, TGT_MergedSrc=L2008-3007B
17317 TANGUT IDEOGRAPH-#17317, TGT_MergedSrc=L2008-3053
17318 TANGUT IDEOGRAPH-#17318, TGT_MergedSrc=L2008-2009
17319 TANGUT IDEOGRAPH-#17319, TGT_MergedSrc=L2008-3065
1731A TANGUT IDEOGRAPH-#1731A, TGT_MergedSrc=L2008-3068
1731B TANGUT IDEOGRAPH-#1731B, TGT_MergedSrc=L2008-3059
1731C TANGUT IDEOGRAPH-#1731C, TGT_MergedSrc=L2008-3052
1731D TANGUT IDEOGRAPH-#1731D, TGT_MergedSrc=L2008-2007
1731E TANGUT IDEOGRAPH-#1731E, TGT_MergedSrc=L2008-2846
1731F TANGUT IDEOGRAPH-#1731F, TGT_MergedSrc=L2008-6043
17320 TANGUT IDEOGRAPH-#17320, TGT_MergedSrc=L2008-3556
17321 TANGUT IDEOGRAPH-#17321, TGT_MergedSrc=L2008-2014
17322 TANGUT IDEOGRAPH-#17322, TGT_MergedSrc=L2008-3002
17323 TANGUT IDEOGRAPH-#17323, TGT_MergedSrc=L2008-3524
17324 TANGUT IDEOGRAPH-#17324, TGT_MergedSrc=L2008-3034
17325 TANGUT IDEOGRAPH-#17325, TGT_MergedSrc=L2008-2998
17326 TANGUT IDEOGRAPH-#17326, TGT_MergedSrc=L2008-1998
17327 TANGUT IDEOGRAPH-#17327, TGT_MergedSrc=L2008-2006
17328 TANGUT IDEOGRAPH-#17328, TGT_MergedSrc=L2008-2050
17329 TANGUT IDEOGRAPH-#17329, TGT_MergedSrc=L2008-3557
1732A TANGUT IDEOGRAPH-#1732A, TGT_MergedSrc=L2008-3082
1732B TANGUT IDEOGRAPH-#1732B, TGT_MergedSrc=L2008-6038
1732C TANGUT IDEOGRAPH-#1732C, TGT_MergedSrc=L2008-3066
1732D TANGUT IDEOGRAPH-#1732D, TGT_MergedSrc=L2008-1542
1732E TANGUT IDEOGRAPH-#1732E, TGT_MergedSrc=L2008-1543
1732F TANGUT IDEOGRAPH-#1732F, TGT_MergedSrc=L2008-1628
17330 TANGUT IDEOGRAPH-#17330, TGT_MergedSrc=L2008-1633
17331 TANGUT IDEOGRAPH-#17331, TGT_MergedSrc=L2008-1664
17332 TANGUT IDEOGRAPH-#17332, TGT_MergedSrc=L2008-1063
17333 TANGUT IDEOGRAPH-#17333, TGT_MergedSrc=L2008-1096
17334 TANGUT IDEOGRAPH-#17334, TGT_MergedSrc=L2008-1230
17335 TANGUT IDEOGRAPH-#17335, TGT_MergedSrc=L2008-1306
17336 TANGUT IDEOGRAPH-#17336, TGT_MergedSrc=L2008-0784
17337 TANGUT IDEOGRAPH-#17337, TGT_MergedSrc=L2008-1869
17338 TANGUT IDEOGRAPH-#17338, TGT_MergedSrc=L2008-1732
17339 TANGUT IDEOGRAPH-#17339, TGT_MergedSrc=L2008-0558
1733A TANGUT IDEOGRAPH-#1733A, TGT_MergedSrc=L2008-1748
1733B TANGUT IDEOGRAPH-#1733B, TGT_MergedSrc=L2008-1346
1733C TANGUT IDEOGRAPH-#1733C, TGT_MergedSrc=L2008-0338
1733D TANGUT IDEOGRAPH-#1733D, TGT_MergedSrc=L2008-0804
1733E TANGUT IDEOGRAPH-#1733E, TGT_MergedSrc=L2008-1269
1733F TANGUT IDEOGRAPH-#1733F, TGT_MergedSrc=L2008-0687
17340 TANGUT IDEOGRAPH-#17340, TGT_MergedSrc=L2008-0789
17341 TANGUT IDEOGRAPH-#17341, TGT_MergedSrc=L2008-0289
17342 TANGUT IDEOGRAPH-#17342, TGT_MergedSrc=L2008-0377
17343 TANGUT IDEOGRAPH-#17343, TGT_MergedSrc=L2008-0805
17344 TANGUT IDEOGRAPH-#17344, TGT_MergedSrc=L2008-0806
17345 TANGUT IDEOGRAPH-#17345, TGT_MergedSrc=L2008-0270
17346 TANGUT IDEOGRAPH-#17346, TGT_MergedSrc=L2008-0358
17347 TANGUT IDEOGRAPH-#17347, TGT_MergedSrc=L2008-1706
17348 TANGUT IDEOGRAPH-#17348, TGT_MergedSrc=L2008-1201
17349 TANGUT IDEOGRAPH-#17349, TGT_MergedSrc=L2008-0599
1734A TANGUT IDEOGRAPH-#1734A, TGT_MergedSrc=L2008-0290
1734B TANGUT IDEOGRAPH-#1734B, TGT_MergedSrc=L2008-0269
1734C TANGUT IDEOGRAPH-#1734C, TGT_MergedSrc=L2008-0280
1734D TANGUT IDEOGRAPH-#1734D, TGT_MergedSrc=L2008-0281
1734E TANGUT IDEOGRAPH-#1734E, TGT_MergedSrc=L2008-0537
1734F TANGUT IDEOGRAPH-#1734F, TGT_MergedSrc=L2008-0586
17350 TANGUT IDEOGRAPH-#17350, TGT_MergedSrc=L2008-0326
17351 TANGUT IDEOGRAPH-#17351, TGT_MergedSrc=L2008-0823
17352 TANGUT IDEOGRAPH-#17352, TGT_MergedSrc=L2008-1307
17353 TANGUT IDEOGRAPH-#17353, TGT_MergedSrc=L2008-0313
17354 TANGUT IDEOGRAPH-#17354, TGT_MergedSrc=L2008-0325
17355 TANGUT IDEOGRAPH-#17355, TGT_MergedSrc=L2008-0266
17356 TANGUT IDEOGRAPH-#17356, TGT_MergedSrc=L2008-0291
17357 TANGUT IDEOGRAPH-#17357, TGT_MergedSrc=L2008-1768
17358 TANGUT IDEOGRAPH-#17358, TGT_MergedSrc=L2008-0538
17359 TANGUT IDEOGRAPH-#17359, TGT_MergedSrc=L2008-1381
1735A TANGUT IDEOGRAPH-#1735A, TGT_MergedSrc=L2008-1193
1735B TANGUT IDEOGRAPH-#1735B, TGT_MergedSrc=L2008-1412
1735C TANGUT IDEOGRAPH-#1735C, TGT_MergedSrc=L2008-1272
1735D TANGUT IDEOGRAPH-#1735D, TGT_MergedSrc=L2008-0371
1735E TANGUT IDEOGRAPH-#1735E, TGT_MergedSrc=L2008-0885
1735F TANGUT IDEOGRAPH-#1735F, TGT_MergedSrc=L2008-1769
17360 TANGUT IDEOGRAPH-#17360, TGT_MergedSrc=L2008-1685
17361 TANGUT IDEOGRAPH-#17361, TGT_MergedSrc=L2008-0309
17362 TANGUT IDEOGRAPH-#17362, TGT_MergedSrc=L2008-1775
17363 TANGUT IDEOGRAPH-#17363, TGT_MergedSrc=L2008-4459
17364 TANGUT IDEOGRAPH-#17364, TGT_MergedSrc=L2008-0620
17365 TANGUT IDEOGRAPH-#17365, TGT_MergedSrc=L2008-0015
17366 TANGUT IDEOGRAPH-#17366, TGT_MergedSrc=L2008-0028
17367 TANGUT IDEOGRAPH-#17367, TGT_MergedSrc=L2008-0112
17368 TANGUT IDEOGRAPH-#17368, TGT_MergedSrc=L2008-4050
17369 TANGUT IDEOGRAPH-#17369, TGT_MergedSrc=L2008-4049
1736A TANGUT IDEOGRAPH-#1736A, TGT_MergedSrc=L2008-4029
1736B TANGUT IDEOGRAPH-#1736B, TGT_MergedSrc=L2008-4027
1736C TANGUT IDEOGRAPH-#1736C, TGT_MergedSrc=L2008-4048
1736D TANGUT IDEOGRAPH-#1736D, TGT_MergedSrc=L2008-4088
1736E TANGUT IDEOGRAPH-#1736E, TGT_MergedSrc=L2008-4087
1736F TANGUT IDEOGRAPH-#1736F, TGT_MergedSrc=L2008-4086
17370 TANGUT IDEOGRAPH-#17370, TGT_MergedSrc=L2008-4039
17371 TANGUT IDEOGRAPH-#17371, TGT_MergedSrc=L2008-4024
17372 TANGUT IDEOGRAPH-#17372, TGT_MergedSrc=L2008-4026
17373 TANGUT IDEOGRAPH-#17373, TGT_MergedSrc=L2008-4028
17374 TANGUT IDEOGRAPH-#17374, TGT_MergedSrc=L2008-4055
17375 TANGUT IDEOGRAPH-#17375, TGT_MergedSrc=L2008-1026
17376 TANGUT IDEOGRAPH-#17376, TGT_MergedSrc=L2008-1630
17377 TANGUT IDEOGRAPH-#17377, TGT_MergedSrc=L2008-0760
17378 TANGUT IDEOGRAPH-#17378, TGT_MergedSrc=L2008-0486
17379 TANGUT IDEOGRAPH-#17379, TGT_MergedSrc=L2008-0219
1737A TANGUT IDEOGRAPH-#1737A, TGT_MergedSrc=L2008-0752
1737B TANGUT IDEOGRAPH-#1737B, TGT_MergedSrc=L2008-1641
1737C TANGUT IDEOGRAPH-#1737C, TGT_MergedSrc=L2008-0753
1737D TANGUT IDEOGRAPH-#1737D, TGT_MergedSrc=L2008-1651
1737E TANGUT IDEOGRAPH-#1737E, TGT_MergedSrc=L2008-0745
1737F TANGUT IDEOGRAPH-#1737F, TGT_MergedSrc=L2008-1003
17380 TANGUT IDEOGRAPH-#17380, TGT_MergedSrc=L2008-0503
17381 TANGUT IDEOGRAPH-#17381, TGT_MergedSrc=L2008-1082
17382 TANGUT IDEOGRAPH-#17382, TGT_MergedSrc=L2008-1588
17383 TANGUT IDEOGRAPH-#17383, TGT_MergedSrc=L2008-4041
17384 TANGUT IDEOGRAPH-#17384, TGT_MergedSrc=L2008-4078
17385 TANGUT IDEOGRAPH-#17385, TGT_MergedSrc=L2008-4081
17386 TANGUT IDEOGRAPH-#17386, TGT_MergedSrc=L2008-4091
17387 TANGUT IDEOGRAPH-#17387, TGT_MergedSrc=L2008-4079
17388 TANGUT IDEOGRAPH-#17388, TGT_MergedSrc=L2008-4053
17389 TANGUT IDEOGRAPH-#17389, TGT_MergedSrc=L2008-4042
1738A TANGUT IDEOGRAPH-#1738A, TGT_MergedSrc=L2008-4082
1738B TANGUT IDEOGRAPH-#1738B, TGT_MergedSrc=L2008-4080
1738C TANGUT IDEOGRAPH-#1738C, TGT_MergedSrc=L2008-4089
1738D TANGUT IDEOGRAPH-#1738D, TGT_MergedSrc=L2008-4092
1738E TANGUT IDEOGRAPH-#1738E, TGT_MergedSrc=L2008-4090
1738F TANGUT IDEOGRAPH-#1738F, TGT_MergedSrc=L2008-4077
17390 TANGUT IDEOGRAPH-#17390, TGT_MergedSrc=L2008-4043
17391 TANGUT IDEOGRAPH-#17391, TGT_MergedSrc=L2008-4032
17392 TANGUT IDEOGRAPH-#17392, TGT_MergedSrc=L2008-4052
17393 TANGUT IDEOGRAPH-#17393, TGT_MergedSrc=L2008-4051
17394 TANGUT IDEOGRAPH-#17394, TGT_MergedSrc=L2008-4033
17395 TANGUT IDEOGRAPH-#17395, TGT_MergedSrc=L2008-6047
17396 TANGUT IDEOGRAPH-#17396, TGT_MergedSrc=L2008-4046
17397 TANGUT IDEOGRAPH-#17397, TGT_MergedSrc=L2008-4034
17398 TANGUT IDEOGRAPH-#17398, TGT_MergedSrc=L2008-0785
17399 TANGUT IDEOGRAPH-#17399, TGT_MergedSrc=L2008-0335
1739A TANGUT IDEOGRAPH-#1739A, TGT_MergedSrc=L2008-0708
1739B TANGUT IDEOGRAPH-#1739B, TGT_MergedSrc=L2008-0328
1739C TANGUT IDEOGRAPH-#1739C, TGT_MergedSrc=L2008-0566
1739D TANGUT IDEOGRAPH-#1739D, TGT_MergedSrc=L2008-1753
1739E TANGUT IDEOGRAPH-#1739E, TGT_MergedSrc=L2008-1754
1739F TANGUT IDEOGRAPH-#1739F, TGT_MergedSrc=L2008-1350
173A0 TANGUT IDEOGRAPH-#173A0, TGT_MergedSrc=L2008-1407
173A1 TANGUT IDEOGRAPH-#173A1, TGT_MergedSrc=L2008-0798
173A2 TANGUT IDEOGRAPH-#173A2, TGT_MergedSrc=L2008-1755
173A3 TANGUT IDEOGRAPH-#173A3, TGT_MergedSrc=L2008-1376
173A4 TANGUT IDEOGRAPH-#173A4, TGT_MergedSrc=L2008-0367
173A5 TANGUT IDEOGRAPH-#173A5, TGT_MergedSrc=L2008-2360
173A6 TANGUT IDEOGRAPH-#173A6, TGT_MergedSrc=L2008-1937
173A7 TANGUT IDEOGRAPH-#173A7, TGT_MergedSrc=L2008-2359
173A8 TANGUT IDEOGRAPH-#173A8, TGT_MergedSrc=L2008-2926
173A9 TANGUT IDEOGRAPH-#173A9, TGT_MergedSrc=L2008-3516
173AA TANGUT IDEOGRAPH-#173AA, TGT_MergedSrc=H2004-A-5829
173AB TANGUT IDEOGRAPH-#173AB, TGT_MergedSrc=L2008-2698
173AC TANGUT IDEOGRAPH-#173AC, TGT_MergedSrc=L2008-1938
173AD TANGUT IDEOGRAPH-#173AD, TGT_MergedSrc=L2008-1892
173AE TANGUT IDEOGRAPH-#173AE, TGT_MergedSrc=L2008-2820
173AF TANGUT IDEOGRAPH-#173AF, TGT_MergedSrc=L2008-2835
173B0 TANGUT IDEOGRAPH-#173B0, TGT_MergedSrc=L2008-1891
173B1 TANGUT IDEOGRAPH-#173B1, TGT_MergedSrc=L2008-2836
173B2 TANGUT IDEOGRAPH-#173B2, TGT_MergedSrc=L2008-2821
173B3 TANGUT IDEOGRAPH-#173B3, TGT_MergedSrc=L2008-2841
173B4 TANGUT IDEOGRAPH-#173B4, TGT_MergedSrc=L2008-3450
173B5 TANGUT IDEOGRAPH-#173B5, TGT_MergedSrc=L2008-4025
173B6 TANGUT IDEOGRAPH-#173B6, TGT_MergedSrc=L2008-4023
173B7 TANGUT IDEOGRAPH-#173B7, TGT_MergedSrc=L2008-4085
173B8 TANGUT IDEOGRAPH-#173B8, TGT_MergedSrc=L2008-4054
173B9 TANGUT IDEOGRAPH-#173B9, TGT_MergedSrc=L2008-4060
173BA TANGUT IDEOGRAPH-#173BA, TGT_MergedSrc=L2008-4038
173BB TANGUT IDEOGRAPH-#173BB, TGT_MergedSrc=L2008-2080
173BC TANGUT IDEOGRAPH-#173BC, TGT_MergedSrc=L2008-2028
173BD TANGUT IDEOGRAPH-#173BD, TGT_MergedSrc=L2008-2586
173BE TANGUT IDEOGRAPH-#173BE, TGT_MergedSrc=L2008-2411
173BF TANGUT IDEOGRAPH-#173BF, TGT_MergedSrc=L2008-3771
173C0 TANGUT IDEOGRAPH-#173C0, TGT_MergedSrc=L2008-2723
173C1 TANGUT IDEOGRAPH-#173C1, TGT_MergedSrc=L2008-1999
173C2 TANGUT IDEOGRAPH-#173C2, TGT_MergedSrc=L2008-1995
173C3 TANGUT IDEOGRAPH-#173C3, TGT_MergedSrc=L2008-2722
173C4 TANGUT IDEOGRAPH-#173C4, TGT_MergedSrc=L2008-2000
173C5 TANGUT IDEOGRAPH-#173C5, TGT_MergedSrc=L2008-3546
173C6 TANGUT IDEOGRAPH-#173C6, TGT_MergedSrc=L2008-2052
173C7 TANGUT IDEOGRAPH-#173C7, TGT_MergedSrc=L2008-2403
173C8 TANGUT IDEOGRAPH-#173C8, TGT_MergedSrc=L2008-3535
173C9 TANGUT IDEOGRAPH-#173C9, TGT_MergedSrc=L2008-2283
173CA TANGUT IDEOGRAPH-#173CA, TGT_MergedSrc=L2008-3225
173CB TANGUT IDEOGRAPH-#173CB, TGT_MergedSrc=L2008-3363
173CC TANGUT IDEOGRAPH-#173CC, TGT_MergedSrc=S1968-5596
173CD TANGUT IDEOGRAPH-#173CD, TGT_MergedSrc=N1966-202-051
173CE TANGUT IDEOGRAPH-#173CE, TGT_MergedSrc=L2008-2471
173CF TANGUT IDEOGRAPH-#173CF, TGT_MergedSrc=L2008-2441
173D0 TANGUT IDEOGRAPH-#173D0, TGT_MergedSrc=L2008-3790
173D1 TANGUT IDEOGRAPH-#173D1, TGT_MergedSrc=L2008-2442
173D2 TANGUT IDEOGRAPH-#173D2, TGT_MergedSrc=L2008-2744
173D3 TANGUT IDEOGRAPH-#173D3, TGT_MergedSrc=L2008-3655
173D4 TANGUT IDEOGRAPH-#173D4, TGT_MergedSrc=L2008-3350
173D5 TANGUT IDEOGRAPH-#173D5, TGT_MergedSrc=L2008-2774
173D6 TANGUT IDEOGRAPH-#173D6, TGT_MergedSrc=L2008-2796
173D7 TANGUT IDEOGRAPH-#173D7, TGT_MergedSrc=L2008-3104
173D8 TANGUT IDEOGRAPH-#173D8, TGT_MergedSrc=L2008-3273
173D9 TANGUT IDEOGRAPH-#173D9, TGT_MergedSrc=L2008-3340
173DA TANGUT IDEOGRAPH-#173DA, TGT_MergedSrc=L2008-3233
173DB TANGUT IDEOGRAPH-#173DB, TGT_MergedSrc=L2008-2072
173DC TANGUT IDEOGRAPH-#173DC, TGT_MergedSrc=L2008-2081
173DD TANGUT IDEOGRAPH-#173DD, TGT_MergedSrc=L2008-3325
173DE TANGUT IDEOGRAPH-#173DE, TGT_MergedSrc=L2008-3112
173DF TANGUT IDEOGRAPH-#173DF, TGT_MergedSrc=L2008-3573
173E0 TANGUT IDEOGRAPH-#173E0, TGT_MergedSrc=L2008-3303
173E1 TANGUT IDEOGRAPH-#173E1, TGT_MergedSrc=L2008-2503
173E2 TANGUT IDEOGRAPH-#173E2, TGT_MergedSrc=L2008-3720
173E3 TANGUT IDEOGRAPH-#173E3, TGT_MergedSrc=L2008-3349
173E4 TANGUT IDEOGRAPH-#173E4, TGT_MergedSrc=L2008-2171
173E5 TANGUT IDEOGRAPH-#173E5, TGT_MergedSrc=L2008-2488
173E6 TANGUT IDEOGRAPH-#173E6, TGT_MergedSrc=L2008-2863
173E7 TANGUT IDEOGRAPH-#173E7, TGT_MergedSrc=S1968-5574
173E8 TANGUT IDEOGRAPH-#173E8, TGT_MergedSrc=L2008-2681
173E9 TANGUT IDEOGRAPH-#173E9, TGT_MergedSrc=L2008-2671
173EA TANGUT IDEOGRAPH-#173EA, TGT_MergedSrc=L2008-2608
173EB TANGUT IDEOGRAPH-#173EB, TGT_MergedSrc=L2008-2273
173EC TANGUT IDEOGRAPH-#173EC, TGT_MergedSrc=L2008-2287
173ED TANGUT IDEOGRAPH-#173ED, TGT_MergedSrc=L2008-2648
173EE TANGUT IDEOGRAPH-#173EE, TGT_MergedSrc=L2008-3314
173EF TANGUT IDEOGRAPH-#173EF, TGT_MergedSrc=L2008-3658
173F0 TANGUT IDEOGRAPH-#173F0, TGT_MergedSrc=L2008-3155
173F1 TANGUT IDEOGRAPH-#173F1, TGT_MergedSrc=L2008-3313
173F2 TANGUT IDEOGRAPH-#173F2, TGT_MergedSrc=L2008-2489
173F3 TANGUT IDEOGRAPH-#173F3, TGT_MergedSrc=L2008-2220
173F4 TANGUT IDEOGRAPH-#173F4, TGT_MergedSrc=L2008-2149
173F5 TANGUT IDEOGRAPH-#173F5, TGT_MergedSrc=L2008-3369
173F6 TANGUT IDEOGRAPH-#173F6, TGT_MergedSrc=L2008-2769
173F7 TANGUT IDEOGRAPH-#173F7, TGT_MergedSrc=L2008-3352
173F8 TANGUT IDEOGRAPH-#173F8, TGT_MergedSrc=L2008-3718
173F9 TANGUT IDEOGRAPH-#173F9, TGT_MergedSrc=L2008-2513
173FA TANGUT IDEOGRAPH-#173FA, TGT_MergedSrc=L2008-3706
173FB TANGUT IDEOGRAPH-#173FB, TGT_MergedSrc=L2008-2274
173FC TANGUT IDEOGRAPH-#173FC, TGT_MergedSrc=L2008-2143
173FD TANGUT IDEOGRAPH-#173FD, TGT_MergedSrc=L2008-2223
173FE TANGUT IDEOGRAPH-#173FE, TGT_MergedSrc=L2008-2659
173FF TANGUT IDEOGRAPH-#173FF, TGT_MergedSrc=L2008-3377
17400 TANGUT IDEOGRAPH-#17400, TGT_MergedSrc=L2008-3707
17401 TANGUT IDEOGRAPH-#17401, TGT_MergedSrc=L2008-3156
17402 TANGUT IDEOGRAPH-#17402, TGT_MergedSrc=L2008-3271
17403 TANGUT IDEOGRAPH-#17403, TGT_MergedSrc=L2008-3253
17404 TANGUT IDEOGRAPH-#17404, TGT_MergedSrc=L2008-2061
17405 TANGUT IDEOGRAPH-#17405, TGT_MergedSrc=L2008-2434
17406 TANGUT IDEOGRAPH-#17406, TGT_MergedSrc=L2008-3089
17407 TANGUT IDEOGRAPH-#17407, TGT_MergedSrc=L2008-3090
17408 TANGUT IDEOGRAPH-#17408, TGT_MergedSrc=L2008-3088
17409 TANGUT IDEOGRAPH-#17409, TGT_MergedSrc=L2008-2600
1740A TANGUT IDEOGRAPH-#1740A, TGT_MergedSrc=L2008-3558
1740B TANGUT IDEOGRAPH-#1740B, TGT_MergedSrc=L2008-3401
1740C TANGUT IDEOGRAPH-#1740C, TGT_MergedSrc=L2008-3432
1740D TANGUT IDEOGRAPH-#1740D, TGT_MergedSrc=L2008-3018
1740E TANGUT IDEOGRAPH-#1740E, TGT_MergedSrc=L2008-3391
1740F TANGUT IDEOGRAPH-#1740F, TGT_MergedSrc=L2008-3036
17410 TANGUT IDEOGRAPH-#17410, TGT_MergedSrc=L2008-3423
17411 TANGUT IDEOGRAPH-#17411, TGT_MergedSrc=L2008-3398
17412 TANGUT IDEOGRAPH-#17412, TGT_MergedSrc=L2008-3005
17413 TANGUT IDEOGRAPH-#17413, TGT_MergedSrc=L2008-3038
17414 TANGUT IDEOGRAPH-#17414, TGT_MergedSrc=L2008-3083
17415 TANGUT IDEOGRAPH-#17415, TGT_MergedSrc=L2008-3448
17416 TANGUT IDEOGRAPH-#17416, TGT_MergedSrc=L2008-3392
17417 TANGUT IDEOGRAPH-#17417, TGT_MergedSrc=L2008-3015
17418 TANGUT IDEOGRAPH-#17418, TGT_MergedSrc=L2008-3043
17419 TANGUT IDEOGRAPH-#17419, TGT_MergedSrc=L2008-3016
1741A TANGUT IDEOGRAPH-#1741A, TGT_MergedSrc=L2008-3188
1741B TANGUT IDEOGRAPH-#1741B, TGT_MergedSrc=L2008-2994
1741C TANGUT IDEOGRAPH-#1741C, TGT_MergedSrc=L2008-3008
1741D TANGUT IDEOGRAPH-#1741D, TGT_MergedSrc=L2008-3822
1741E TANGUT IDEOGRAPH-#1741E, TGT_MergedSrc=L2008-3825
1741F TANGUT IDEOGRAPH-#1741F, TGT_MergedSrc=L2008-3816
17420 TANGUT IDEOGRAPH-#17420, TGT_MergedSrc=L2008-3828
17421 TANGUT IDEOGRAPH-#17421, TGT_MergedSrc=L2008-3820
17422 TANGUT IDEOGRAPH-#17422, TGT_MergedSrc=L2008-3814
17423 TANGUT IDEOGRAPH-#17423, TGT_MergedSrc=L2008-3821
17424 TANGUT IDEOGRAPH-#17424, TGT_MergedSrc=L2008-3813
17425 TANGUT IDEOGRAPH-#17425, TGT_MergedSrc=L2008-3829
17426 TANGUT IDEOGRAPH-#17426, TGT_MergedSrc=L2008-3824
17427 TANGUT IDEOGRAPH-#17427, TGT_MergedSrc=L2008-3817
17428 TANGUT IDEOGRAPH-#17428, TGT_MergedSrc=L2008-3893
17429 TANGUT IDEOGRAPH-#17429, TGT_MergedSrc=L2008-3938
1742A TANGUT IDEOGRAPH-#1742A, TGT_MergedSrc=L2008-4775
1742B TANGUT IDEOGRAPH-#1742B, TGT_MergedSrc=L2008-4795
1742C TANGUT IDEOGRAPH-#1742C, TGT_MergedSrc=L2008-4933
1742D TANGUT IDEOGRAPH-#1742D, TGT_MergedSrc=L2008-4761
1742E TANGUT IDEOGRAPH-#1742E, TGT_MergedSrc=L2008-4676
1742F TANGUT IDEOGRAPH-#1742F, TGT_MergedSrc=L2008-4719
17430 TANGUT IDEOGRAPH-#17430, TGT_MergedSrc=L2008-4842
17431 TANGUT IDEOGRAPH-#17431, TGT_MergedSrc=L2008-4884
17432 TANGUT IDEOGRAPH-#17432, TGT_MergedSrc=L2008-5042
17433 TANGUT IDEOGRAPH-#17433, TGT_MergedSrc=L2008-4865
17434 TANGUT IDEOGRAPH-#17434, TGT_MergedSrc=L2008-4681
17435 TANGUT IDEOGRAPH-#17435, TGT_MergedSrc=L2008-4803
17436 TANGUT IDEOGRAPH-#17436, TGT_MergedSrc=L2008-4720
17437 TANGUT IDEOGRAPH-#17437, TGT_MergedSrc=L2008-4843
17438 TANGUT IDEOGRAPH-#17438, TGT_MergedSrc=L2008-4804
17439 TANGUT IDEOGRAPH-#17439, TGT_MergedSrc=L2008-4760
1743A TANGUT IDEOGRAPH-#1743A, TGT_MergedSrc=L2008-4794
1743B TANGUT IDEOGRAPH-#1743B, TGT_MergedSrc=L2008-4857
1743C TANGUT IDEOGRAPH-#1743C, TGT_MergedSrc=L2008-4858
1743D TANGUT IDEOGRAPH-#1743D, TGT_MergedSrc=L2008-5034
1743E TANGUT IDEOGRAPH-#1743E, TGT_MergedSrc=L2008-4921
1743F TANGUT IDEOGRAPH-#1743F, TGT_MergedSrc=L2008-4939
17440 TANGUT IDEOGRAPH-#17440, TGT_MergedSrc=L2008-4931
17441 TANGUT IDEOGRAPH-#17441, TGT_MergedSrc=L2008-4744
17442 TANGUT IDEOGRAPH-#17442, TGT_MergedSrc=L2008-5038
17443 TANGUT IDEOGRAPH-#17443, TGT_MergedSrc=L2008-5055
17444 TANGUT IDEOGRAPH-#17444, TGT_MergedSrc=L2008-5054
17445 TANGUT IDEOGRAPH-#17445, TGT_MergedSrc=L2008-4728
17446 TANGUT IDEOGRAPH-#17446, TGT_MergedSrc=L2008-4819
17447 TANGUT IDEOGRAPH-#17447, TGT_MergedSrc=L2008-4820
17448 TANGUT IDEOGRAPH-#17448, TGT_MergedSrc=L2008-4750
17449 TANGUT IDEOGRAPH-#17449, TGT_MergedSrc=L2008-4684
1744A TANGUT IDEOGRAPH-#1744A, TGT_MergedSrc=L2008-4759
1744B TANGUT IDEOGRAPH-#1744B, TGT_MergedSrc=L2008-4721
1744C TANGUT IDEOGRAPH-#1744C, TGT_MergedSrc=L2008-4866
1744D TANGUT IDEOGRAPH-#1744D, TGT_MergedSrc=L2008-5001
1744E TANGUT IDEOGRAPH-#1744E, TGT_MergedSrc=L2008-4942
1744F TANGUT IDEOGRAPH-#1744F, TGT_MergedSrc=L2008-4985
17450 TANGUT IDEOGRAPH-#17450, TGT_MergedSrc=L2008-4788
17451 TANGUT IDEOGRAPH-#17451, TGT_MergedSrc=L2008-4798
17452 TANGUT IDEOGRAPH-#17452, TGT_MergedSrc=L2008-4768
17453 TANGUT IDEOGRAPH-#17453, TGT_MergedSrc=L2008-4723
17454 TANGUT IDEOGRAPH-#17454, TGT_MergedSrc=L2008-4831
17455 TANGUT IDEOGRAPH-#17455, TGT_MergedSrc=L2008-4954
17456 TANGUT IDEOGRAPH-#17456, TGT_MergedSrc=L2008-4818
17457 TANGUT IDEOGRAPH-#17457, TGT_MergedSrc=L2008-4751
17458 TANGUT IDEOGRAPH-#17458, TGT_MergedSrc=L2008-4694
17459 TANGUT IDEOGRAPH-#17459, TGT_MergedSrc=L2008-4848
1745A TANGUT IDEOGRAPH-#1745A, TGT_MergedSrc=L2008-4853
1745B TANGUT IDEOGRAPH-#1745B, TGT_MergedSrc=L2008-4796
1745C TANGUT IDEOGRAPH-#1745C, TGT_MergedSrc=L2008-4690
1745D TANGUT IDEOGRAPH-#1745D, TGT_MergedSrc=L2008-4739
1745E TANGUT IDEOGRAPH-#1745E, TGT_MergedSrc=L2008-4678
1745F TANGUT IDEOGRAPH-#1745F, TGT_MergedSrc=L2008-4989
17460 TANGUT IDEOGRAPH-#17460, TGT_MergedSrc=L2008-4950
17461 TANGUT IDEOGRAPH-#17461, TGT_MergedSrc=L2008-5002
17462 TANGUT IDEOGRAPH-#17462, TGT_MergedSrc=H2004-A-1015
17463 TANGUT IDEOGRAPH-#17463, TGT_MergedSrc=L2008-4943
17464 TANGUT IDEOGRAPH-#17464, TGT_MergedSrc=L2008-4863
17465 TANGUT IDEOGRAPH-#17465, TGT_MergedSrc=L2008-4886
17466 TANGUT IDEOGRAPH-#17466, TGT_MergedSrc=L2008-4753
17467 TANGUT IDEOGRAPH-#17467, TGT_MergedSrc=L2008-4941
17468 TANGUT IDEOGRAPH-#17468, TGT_MergedSrc=L2008-4926
17469 TANGUT IDEOGRAPH-#17469, TGT_MergedSrc=L2008-4868
1746A TANGUT IDEOGRAPH-#1746A, TGT_MergedSrc=L2008-5045
1746B TANGUT IDEOGRAPH-#1746B, TGT_MergedSrc=L2008-5031
1746C TANGUT IDEOGRAPH-#1746C, TGT_MergedSrc=L2008-4799
1746D TANGUT IDEOGRAPH-#1746D, TGT_MergedSrc=L2008-4854
1746E TANGUT IDEOGRAPH-#1746E, TGT_MergedSrc=L2008-4901
1746F TANGUT IDEOGRAPH-#1746F, TGT_MergedSrc=L2008-5007
17470 TANGUT IDEOGRAPH-#17470, TGT_MergedSrc=L2008-4769
17471 TANGUT IDEOGRAPH-#17471, TGT_MergedSrc=L2008-4740
17472 TANGUT IDEOGRAPH-#17472, TGT_MergedSrc=L2008-4980
17473 TANGUT IDEOGRAPH-#17473, TGT_MergedSrc=L2008-4974
17474 TANGUT IDEOGRAPH-#17474, TGT_MergedSrc=L2008-5059
17475 TANGUT IDEOGRAPH-#17475, TGT_MergedSrc=L2008-4758
17476 TANGUT IDEOGRAPH-#17476, TGT_MergedSrc=L2008-4805
17477 TANGUT IDEOGRAPH-#17477, TGT_MergedSrc=L2008-4683
17478 TANGUT IDEOGRAPH-#17478, TGT_MergedSrc=L2008-4767
17479 TANGUT IDEOGRAPH-#17479, TGT_MergedSrc=L2008-4685
1747A TANGUT IDEOGRAPH-#1747A, TGT_MergedSrc=L2008-4789
1747B TANGUT IDEOGRAPH-#1747B, TGT_MergedSrc=L2008-4725
1747C TANGUT IDEOGRAPH-#1747C, TGT_MergedSrc=L2008-4709
1747D TANGUT IDEOGRAPH-#1747D, TGT_MergedSrc=L2008-4806
1747E TANGUT IDEOGRAPH-#1747E, TGT_MergedSrc=L2008-4902
1747F TANGUT IDEOGRAPH-#1747F, TGT_MergedSrc=L2008-4924
17480 TANGUT IDEOGRAPH-#17480, TGT_MergedSrc=L2008-4887
17481 TANGUT IDEOGRAPH-#17481, TGT_MergedSrc=L2008-4973
17482 TANGUT IDEOGRAPH-#17482, TGT_MergedSrc=L2008-5051
17483 TANGUT IDEOGRAPH-#17483, TGT_MergedSrc=L2008-4951
17484 TANGUT IDEOGRAPH-#17484, TGT_MergedSrc=L2008-4862
17485 TANGUT IDEOGRAPH-#17485, TGT_MergedSrc=L2008-4867
17486 TANGUT IDEOGRAPH-#17486, TGT_MergedSrc=L2008-5003
17487 TANGUT IDEOGRAPH-#17487, TGT_MergedSrc=L2008-4925
17488 TANGUT IDEOGRAPH-#17488, TGT_MergedSrc=L2008-4707
17489 TANGUT IDEOGRAPH-#17489, TGT_MergedSrc=L2008-5044
1748A TANGUT IDEOGRAPH-#1748A, TGT_MergedSrc=L2008-4673
1748B TANGUT IDEOGRAPH-#1748B, TGT_MergedSrc=L2008-4763
1748C TANGUT IDEOGRAPH-#1748C, TGT_MergedSrc=L2008-4955
1748D TANGUT IDEOGRAPH-#1748D, TGT_MergedSrc=L2008-5043
1748E TANGUT IDEOGRAPH-#1748E, TGT_MergedSrc=L2008-5048
1748F TANGUT IDEOGRAPH-#1748F, TGT_MergedSrc=L2008-6055
17490 TANGUT IDEOGRAPH-#17490, TGT_MergedSrc=L2008-5030
17491 TANGUT IDEOGRAPH-#17491, TGT_MergedSrc=L2008-4940
17492 TANGUT IDEOGRAPH-#17492, TGT_MergedSrc=L2008-4870
17493 TANGUT IDEOGRAPH-#17493, TGT_MergedSrc=L2008-4837
17494 TANGUT IDEOGRAPH-#17494, TGT_MergedSrc=L2008-4828
17495 TANGUT IDEOGRAPH-#17495, TGT_MergedSrc=L2008-4895
17496 TANGUT IDEOGRAPH-#17496, TGT_MergedSrc=L2008-4885
17497 TANGUT IDEOGRAPH-#17497, TGT_MergedSrc=L2008-5056
17498 TANGUT IDEOGRAPH-#17498, TGT_MergedSrc=L2008-5057
17499 TANGUT IDEOGRAPH-#17499, TGT_MergedSrc=L2008-5058
1749A TANGUT IDEOGRAPH-#1749A, TGT_MergedSrc=L2008-5035
1749B TANGUT IDEOGRAPH-#1749B, TGT_MergedSrc=L2008-4811
1749C TANGUT IDEOGRAPH-#1749C, TGT_MergedSrc=L2008-4970
1749D TANGUT IDEOGRAPH-#1749D, TGT_MergedSrc=L2008-4844
1749E TANGUT IDEOGRAPH-#1749E, TGT_MergedSrc=L2008-5018
1749F TANGUT IDEOGRAPH-#1749F, TGT_MergedSrc=L2008-4992
174A0 TANGUT IDEOGRAPH-#174A0, TGT_MergedSrc=L2008-4724
174A1 TANGUT IDEOGRAPH-#174A1, TGT_MergedSrc=L2008-4822
174A2 TANGUT IDEOGRAPH-#174A2, TGT_MergedSrc=L2008-4708
174A3 TANGUT IDEOGRAPH-#174A3, TGT_MergedSrc=L2008-4727
174A4 TANGUT IDEOGRAPH-#174A4, TGT_MergedSrc=L2008-5004
174A5 TANGUT IDEOGRAPH-#174A5, TGT_MergedSrc=L2008-4923
174A6 TANGUT IDEOGRAPH-#174A6, TGT_MergedSrc=L2008-4975
174A7 TANGUT IDEOGRAPH-#174A7, TGT_MergedSrc=L2008-4836
174A8 TANGUT IDEOGRAPH-#174A8, TGT_MergedSrc=L2008-4696
174A9 TANGUT IDEOGRAPH-#174A9, TGT_MergedSrc=L2008-4849
174AA TANGUT IDEOGRAPH-#174AA, TGT_MergedSrc=L2008-4752
174AB TANGUT IDEOGRAPH-#174AB, TGT_MergedSrc=L2008-4695
174AC TANGUT IDEOGRAPH-#174AC, TGT_MergedSrc=L2008-4722
174AD TANGUT IDEOGRAPH-#174AD, TGT_MergedSrc=L2008-4731
174AE TANGUT IDEOGRAPH-#174AE, TGT_MergedSrc=L2008-4823
174AF TANGUT IDEOGRAPH-#174AF, TGT_MergedSrc=L2008-4807
174B0 TANGUT IDEOGRAPH-#174B0, TGT_MergedSrc=L2008-4932
174B1 TANGUT IDEOGRAPH-#174B1, TGT_MergedSrc=L2008-4971
174B2 TANGUT IDEOGRAPH-#174B2, TGT_MergedSrc=L2008-4972
174B3 TANGUT IDEOGRAPH-#174B3, TGT_MergedSrc=L2008-4903
174B4 TANGUT IDEOGRAPH-#174B4, TGT_MergedSrc=L2008-4988
174B5 TANGUT IDEOGRAPH-#174B5, TGT_MergedSrc=L2008-4920
174B6 TANGUT IDEOGRAPH-#174B6, TGT_MergedSrc=L2008-4969
174B7 TANGUT IDEOGRAPH-#174B7, TGT_MergedSrc=L2008-4905
174B8 TANGUT IDEOGRAPH-#174B8, TGT_MergedSrc=L2008-4949
174B9 TANGUT IDEOGRAPH-#174B9, TGT_MergedSrc=L2008-4778
174BA TANGUT IDEOGRAPH-#174BA, TGT_MergedSrc=L2008-4801
174BB TANGUT IDEOGRAPH-#174BB, TGT_MergedSrc=L2008-4791
174BC TANGUT IDEOGRAPH-#174BC, TGT_MergedSrc=L2008-4808
174BD TANGUT IDEOGRAPH-#174BD, TGT_MergedSrc=L2008-5005
174BE TANGUT IDEOGRAPH-#174BE, TGT_MergedSrc=L2008-4825
174BF TANGUT IDEOGRAPH-#174BF, TGT_MergedSrc=L2008-4845
174C0 TANGUT IDEOGRAPH-#174C0, TGT_MergedSrc=L2008-4746
174C1 TANGUT IDEOGRAPH-#174C1, TGT_MergedSrc=L2008-5026
174C2 TANGUT IDEOGRAPH-#174C2, TGT_MergedSrc=L2008-4993
174C3 TANGUT IDEOGRAPH-#174C3, TGT_MergedSrc=L2008-4692
174C4 TANGUT IDEOGRAPH-#174C4, TGT_MergedSrc=L2008-5039
174C5 TANGUT IDEOGRAPH-#174C5, TGT_MergedSrc=L2008-5040
174C6 TANGUT IDEOGRAPH-#174C6, TGT_MergedSrc=L2008-5024
174C7 TANGUT IDEOGRAPH-#174C7, TGT_MergedSrc=L2008-4968
174C8 TANGUT IDEOGRAPH-#174C8, TGT_MergedSrc=L2008-4729
174C9 TANGUT IDEOGRAPH-#174C9, TGT_MergedSrc=L2008-4869
174CA TANGUT IDEOGRAPH-#174CA, TGT_MergedSrc=L2008-5011
174CB TANGUT IDEOGRAPH-#174CB, TGT_MergedSrc=L2008-5060
174CC TANGUT IDEOGRAPH-#174CC, TGT_MergedSrc=L2008-5032
174CD TANGUT IDEOGRAPH-#174CD, TGT_MergedSrc=L2008-4826
174CE TANGUT IDEOGRAPH-#174CE, TGT_MergedSrc=L2008-4850
174CF TANGUT IDEOGRAPH-#174CF, TGT_MergedSrc=L2008-4810
174D0 TANGUT IDEOGRAPH-#174D0, TGT_MergedSrc=L2008-4691
174D1 TANGUT IDEOGRAPH-#174D1, TGT_MergedSrc=L2008-4976
174D2 TANGUT IDEOGRAPH-#174D2, TGT_MergedSrc=L2008-4977
174D3 TANGUT IDEOGRAPH-#174D3, TGT_MergedSrc=L2008-4762
174D4 TANGUT IDEOGRAPH-#174D4, TGT_MergedSrc=L2008-4832
174D5 TANGUT IDEOGRAPH-#174D5, TGT_MergedSrc=L2008-4987
174D6 TANGUT IDEOGRAPH-#174D6, TGT_MergedSrc=L2008-4733
174D7 TANGUT IDEOGRAPH-#174D7, TGT_MergedSrc=L2008-4706
174D8 TANGUT IDEOGRAPH-#174D8, TGT_MergedSrc=L2008-4784
174D9 TANGUT IDEOGRAPH-#174D9, TGT_MergedSrc=L2008-4776
174DA TANGUT IDEOGRAPH-#174DA, TGT_MergedSrc=L2008-4737
174DB TANGUT IDEOGRAPH-#174DB, TGT_MergedSrc=L2008-4718
174DC TANGUT IDEOGRAPH-#174DC, TGT_MergedSrc=L2008-4754
174DD TANGUT IDEOGRAPH-#174DD, TGT_MergedSrc=L2008-4910
174DE TANGUT IDEOGRAPH-#174DE, TGT_MergedSrc=L2008-5012
174DF TANGUT IDEOGRAPH-#174DF, TGT_MergedSrc=L2008-4934
174E0 TANGUT IDEOGRAPH-#174E0, TGT_MergedSrc=L2008-5052
174E1 TANGUT IDEOGRAPH-#174E1, TGT_MergedSrc=L2008-5050
174E2 TANGUT IDEOGRAPH-#174E2, TGT_MergedSrc=L2008-4893
174E3 TANGUT IDEOGRAPH-#174E3, TGT_MergedSrc=L2008-4944
174E4 TANGUT IDEOGRAPH-#174E4, TGT_MergedSrc=L2008-4864
174E5 TANGUT IDEOGRAPH-#174E5, TGT_MergedSrc=L2008-4937
174E6 TANGUT IDEOGRAPH-#174E6, TGT_MergedSrc=L2008-4922
174E7 TANGUT IDEOGRAPH-#174E7, TGT_MergedSrc=L2008-4938
174E8 TANGUT IDEOGRAPH-#174E8, TGT_MergedSrc=L2008-5028
174E9 TANGUT IDEOGRAPH-#174E9, TGT_MergedSrc=L2008-4809
174EA TANGUT IDEOGRAPH-#174EA, TGT_MergedSrc=L2008-4792
174EB TANGUT IDEOGRAPH-#174EB, TGT_MergedSrc=L2008-4960
174EC TANGUT IDEOGRAPH-#174EC, TGT_MergedSrc=L2008-4982
174ED TANGUT IDEOGRAPH-#174ED, TGT_MergedSrc=L2008-4824
174EE TANGUT IDEOGRAPH-#174EE, TGT_MergedSrc=L2008-5025
174EF TANGUT IDEOGRAPH-#174EF, TGT_MergedSrc=L2008-5027
174F0 TANGUT IDEOGRAPH-#174F0, TGT_MergedSrc=L2008-4693
174F1 TANGUT IDEOGRAPH-#174F1, TGT_MergedSrc=L2008-4978
174F2 TANGUT IDEOGRAPH-#174F2, TGT_MergedSrc=L2008-4790
174F3 TANGUT IDEOGRAPH-#174F3, TGT_MergedSrc=L2008-4736
174F4 TANGUT IDEOGRAPH-#174F4, TGT_MergedSrc=L2008-4838
174F5 TANGUT IDEOGRAPH-#174F5, TGT_MergedSrc=L2008-4927
174F6 TANGUT IDEOGRAPH-#174F6, TGT_MergedSrc=L2008-5006
174F7 TANGUT IDEOGRAPH-#174F7, TGT_MergedSrc=L2008-4686
174F8 TANGUT IDEOGRAPH-#174F8, TGT_MergedSrc=L2008-5016
174F9 TANGUT IDEOGRAPH-#174F9, TGT_MergedSrc=L2008-4914
174FA TANGUT IDEOGRAPH-#174FA, TGT_MergedSrc=L2008-4957
174FB TANGUT IDEOGRAPH-#174FB, TGT_MergedSrc=L2008-4687
174FC TANGUT IDEOGRAPH-#174FC, TGT_MergedSrc=L2008-4847
174FD TANGUT IDEOGRAPH-#174FD, TGT_MergedSrc=L2008-4710
174FE TANGUT IDEOGRAPH-#174FE, TGT_MergedSrc=L2008-4990
174FF TANGUT IDEOGRAPH-#174FF, TGT_MergedSrc=L2008-4913
17500 TANGUT IDEOGRAPH-#17500, TGT_MergedSrc=L2008-5049
17501 TANGUT IDEOGRAPH-#17501, TGT_MergedSrc=L2008-4953
17502 TANGUT IDEOGRAPH-#17502, TGT_MergedSrc=L2008-4888
17503 TANGUT IDEOGRAPH-#17503, TGT_MergedSrc=L2008-4959
17504 TANGUT IDEOGRAPH-#17504, TGT_MergedSrc=L2008-4851
17505 TANGUT IDEOGRAPH-#17505, TGT_MergedSrc=L2008-5021
17506 TANGUT IDEOGRAPH-#17506, TGT_MergedSrc=L2008-4839
17507 TANGUT IDEOGRAPH-#17507, TGT_MergedSrc=L2008-4730
17508 TANGUT IDEOGRAPH-#17508, TGT_MergedSrc=L2008-4936
17509 TANGUT IDEOGRAPH-#17509, TGT_MergedSrc=L2008-4981
1750A TANGUT IDEOGRAPH-#1750A, TGT_MergedSrc=L2008-5029
1750B TANGUT IDEOGRAPH-#1750B, TGT_MergedSrc=L2008-4979
1750C TANGUT IDEOGRAPH-#1750C, TGT_MergedSrc=L2008-4956
1750D TANGUT IDEOGRAPH-#1750D, TGT_MergedSrc=L2008-4986
1750E TANGUT IDEOGRAPH-#1750E, TGT_MergedSrc=L2008-5061
1750F TANGUT IDEOGRAPH-#1750F, TGT_MergedSrc=L2008-4786
17510 TANGUT IDEOGRAPH-#17510, TGT_MergedSrc=L2008-4785
17511 TANGUT IDEOGRAPH-#17511, TGT_MergedSrc=L2008-4800
17512 TANGUT IDEOGRAPH-#17512, TGT_MergedSrc=L2008-4945
17513 TANGUT IDEOGRAPH-#17513, TGT_MergedSrc=L2008-4961
17514 TANGUT IDEOGRAPH-#17514, TGT_MergedSrc=L2008-4726
17515 TANGUT IDEOGRAPH-#17515, TGT_MergedSrc=L2008-4783
17516 TANGUT IDEOGRAPH-#17516, TGT_MergedSrc=L2008-4711
17517 TANGUT IDEOGRAPH-#17517, TGT_MergedSrc=L2008-4830
17518 TANGUT IDEOGRAPH-#17518, TGT_MergedSrc=L2008-4894
17519 TANGUT IDEOGRAPH-#17519, TGT_MergedSrc=L2008-4952
1751A TANGUT IDEOGRAPH-#1751A, TGT_MergedSrc=L2008-4833
1751B TANGUT IDEOGRAPH-#1751B, TGT_MergedSrc=L2008-4906
1751C TANGUT IDEOGRAPH-#1751C, TGT_MergedSrc=L2008-4821
1751D TANGUT IDEOGRAPH-#1751D, TGT_MergedSrc=L2008-5020
1751E TANGUT IDEOGRAPH-#1751E, TGT_MergedSrc=L2008-4918
1751F TANGUT IDEOGRAPH-#1751F, TGT_MergedSrc=L2008-4701
17520 TANGUT IDEOGRAPH-#17520, TGT_MergedSrc=L2008-4732
17521 TANGUT IDEOGRAPH-#17521, TGT_MergedSrc=L2008-4915
17522 TANGUT IDEOGRAPH-#17522, TGT_MergedSrc=L2008-4907
17523 TANGUT IDEOGRAPH-#17523, TGT_MergedSrc=L2008-4698
17524 TANGUT IDEOGRAPH-#17524, TGT_MergedSrc=L2008-4899
17525 TANGUT IDEOGRAPH-#17525, TGT_MergedSrc=L2008-4697
17526 TANGUT IDEOGRAPH-#17526, TGT_MergedSrc=L2008-4904
17527 TANGUT IDEOGRAPH-#17527, TGT_MergedSrc=L2008-4840
17528 TANGUT IDEOGRAPH-#17528, TGT_MergedSrc=L2008-4896
17529 TANGUT IDEOGRAPH-#17529, TGT_MergedSrc=L2008-4900
1752A TANGUT IDEOGRAPH-#1752A, TGT_MergedSrc=L2008-4892
1752B TANGUT IDEOGRAPH-#1752B, TGT_MergedSrc=L2008-4700
1752C TANGUT IDEOGRAPH-#1752C, TGT_MergedSrc=L2008-4962
1752D TANGUT IDEOGRAPH-#1752D, TGT_MergedSrc=L2008-4703
1752E TANGUT IDEOGRAPH-#1752E, TGT_MergedSrc=L2008-4958
1752F TANGUT IDEOGRAPH-#1752F, TGT_MergedSrc=L2008-4829
17530 TANGUT IDEOGRAPH-#17530, TGT_MergedSrc=L2008-4834
17531 TANGUT IDEOGRAPH-#17531, TGT_MergedSrc=L2008-5022
17532 TANGUT IDEOGRAPH-#17532, TGT_MergedSrc=L2008-4984
17533 TANGUT IDEOGRAPH-#17533, TGT_MergedSrc=L2008-4702
17534 TANGUT IDEOGRAPH-#17534, TGT_MergedSrc=L2008-4712
17535 TANGUT IDEOGRAPH-#17535, TGT_MergedSrc=L2008-4963
17536 TANGUT IDEOGRAPH-#17536, TGT_MergedSrc=L2008-4998
17537 TANGUT IDEOGRAPH-#17537, TGT_MergedSrc=L2008-4994
17538 TANGUT IDEOGRAPH-#17538, TGT_MergedSrc=L2008-4699
17539 TANGUT IDEOGRAPH-#17539, TGT_MergedSrc=L2008-4835
1753A TANGUT IDEOGRAPH-#1753A, TGT_MergedSrc=L2008-4991
1753B TANGUT IDEOGRAPH-#1753B, TGT_MergedSrc=L2008-4883
1753C TANGUT IDEOGRAPH-#1753C, TGT_MergedSrc=L2008-4916
1753D TANGUT IDEOGRAPH-#1753D, TGT_MergedSrc=L2008-5153
1753E TANGUT IDEOGRAPH-#1753E, TGT_MergedSrc=L2008-4852
1753F TANGUT IDEOGRAPH-#1753F, TGT_MergedSrc=L2008-5412
17540 TANGUT IDEOGRAPH-#17540, TGT_MergedSrc=L2008-5294
17541 TANGUT IDEOGRAPH-#17541, TGT_MergedSrc=L2008-5068
17542 TANGUT IDEOGRAPH-#17542, TGT_MergedSrc=L2008-5501
17543 TANGUT IDEOGRAPH-#17543, TGT_MergedSrc=L2008-5813
17544 TANGUT IDEOGRAPH-#17544, TGT_MergedSrc=L2008-5811
17545 TANGUT IDEOGRAPH-#17545, TGT_MergedSrc=L2008-5812
17546 TANGUT IDEOGRAPH-#17546, TGT_MergedSrc=L2008-5809
17547 TANGUT IDEOGRAPH-#17547, TGT_MergedSrc=L2008-5808
17548 TANGUT IDEOGRAPH-#17548, TGT_MergedSrc=L2008-5804
17549 TANGUT IDEOGRAPH-#17549, TGT_MergedSrc=L2008-5816
1754A TANGUT IDEOGRAPH-#1754A, TGT_MergedSrc=S1968-2868
1754B TANGUT IDEOGRAPH-#1754B, TGT_MergedSrc=L2008-1425
1754C TANGUT IDEOGRAPH-#1754C, TGT_MergedSrc=L2008-1148
1754D TANGUT IDEOGRAPH-#1754D, TGT_MergedSrc=L2008-0912
1754E TANGUT IDEOGRAPH-#1754E, TGT_MergedSrc=L2008-1444
1754F TANGUT IDEOGRAPH-#1754F, TGT_MergedSrc=L2008-1359
17550 TANGUT IDEOGRAPH-#17550, TGT_MergedSrc=L2008-1252
17551 TANGUT IDEOGRAPH-#17551, TGT_MergedSrc=L2008-0966
17552 TANGUT IDEOGRAPH-#17552, TGT_MergedSrc=L2008-1089
17553 TANGUT IDEOGRAPH-#17553, TGT_MergedSrc=L2008-1244
17554 TANGUT IDEOGRAPH-#17554, TGT_MergedSrc=L2008-0959
17555 TANGUT IDEOGRAPH-#17555, TGT_MergedSrc=L2008-0974
17556 TANGUT IDEOGRAPH-#17556, TGT_MergedSrc=L2008-1150
17557 TANGUT IDEOGRAPH-#17557, TGT_MergedSrc=L2008-1182
17558 TANGUT IDEOGRAPH-#17558, TGT_MergedSrc=L2008-1247
17559 TANGUT IDEOGRAPH-#17559, TGT_MergedSrc=L2008-1246
1755A TANGUT IDEOGRAPH-#1755A, TGT_MergedSrc=L2008-1216
1755B TANGUT IDEOGRAPH-#1755B, TGT_MergedSrc=L2008-1413
1755C TANGUT IDEOGRAPH-#1755C, TGT_MergedSrc=L2008-1360
1755D TANGUT IDEOGRAPH-#1755D, TGT_MergedSrc=L2008-1194
1755E TANGUT IDEOGRAPH-#1755E, TGT_MergedSrc=L2008-1198
1755F TANGUT IDEOGRAPH-#1755F, TGT_MergedSrc=L2008-1436
17560 TANGUT IDEOGRAPH-#17560, TGT_MergedSrc=L2008-0967
17561 TANGUT IDEOGRAPH-#17561, TGT_MergedSrc=L2008-1337
17562 TANGUT IDEOGRAPH-#17562, TGT_MergedSrc=L2008-1062
17563 TANGUT IDEOGRAPH-#17563, TGT_MergedSrc=L2008-0945
17564 TANGUT IDEOGRAPH-#17564, TGT_MergedSrc=L2008-1268
17565 TANGUT IDEOGRAPH-#17565, TGT_MergedSrc=L2008-1339
17566 TANGUT IDEOGRAPH-#17566, TGT_MergedSrc=L2008-1400
17567 TANGUT IDEOGRAPH-#17567, TGT_MergedSrc=L2008-0920
17568 TANGUT IDEOGRAPH-#17568, TGT_MergedSrc=L2008-1373
17569 TANGUT IDEOGRAPH-#17569, TGT_MergedSrc=L2008-1127
1756A TANGUT IDEOGRAPH-#1756A, TGT_MergedSrc=L2008-0960
1756B TANGUT IDEOGRAPH-#1756B, TGT_MergedSrc=L2008-1190
1756C TANGUT IDEOGRAPH-#1756C, TGT_MergedSrc=L2008-1418
1756D TANGUT IDEOGRAPH-#1756D, TGT_MergedSrc=L2008-0946
1756E TANGUT IDEOGRAPH-#1756E, TGT_MergedSrc=L2008-1361
1756F TANGUT IDEOGRAPH-#1756F, TGT_MergedSrc=L2008-0903
17570 TANGUT IDEOGRAPH-#17570, TGT_MergedSrc=L2008-0921
17571 TANGUT IDEOGRAPH-#17571, TGT_MergedSrc=L2008-1378
17572 TANGUT IDEOGRAPH-#17572, TGT_MergedSrc=L2008-1090
17573 TANGUT IDEOGRAPH-#17573, TGT_MergedSrc=L2008-1191
17574 TANGUT IDEOGRAPH-#17574, TGT_MergedSrc=L2008-1362
17575 TANGUT IDEOGRAPH-#17575, TGT_MergedSrc=L2008-1291
17576 TANGUT IDEOGRAPH-#17576, TGT_MergedSrc=L2008-1504
17577 TANGUT IDEOGRAPH-#17577, TGT_MergedSrc=L2008-1492
17578 TANGUT IDEOGRAPH-#17578, TGT_MergedSrc=L2008-0444
17579 TANGUT IDEOGRAPH-#17579, TGT_MergedSrc=L2008-0456
1757A TANGUT IDEOGRAPH-#1757A, TGT_MergedSrc=L2008-0445
1757B TANGUT IDEOGRAPH-#1757B, TGT_MergedSrc=L2008-1485
1757C TANGUT IDEOGRAPH-#1757C, TGT_MergedSrc=L2008-0731
1757D TANGUT IDEOGRAPH-#1757D, TGT_MergedSrc=L2008-1817
1757E TANGUT IDEOGRAPH-#1757E, TGT_MergedSrc=L2008-1484
1757F TANGUT IDEOGRAPH-#1757F, TGT_MergedSrc=L2008-1483
17580 TANGUT IDEOGRAPH-#17580, TGT_MergedSrc=L2008-0455
17581 TANGUT IDEOGRAPH-#17581, TGT_MergedSrc=L2008-0428
17582 TANGUT IDEOGRAPH-#17582, TGT_MergedSrc=L2008-0447
17583 TANGUT IDEOGRAPH-#17583, TGT_MergedSrc=L2008-0627
17584 TANGUT IDEOGRAPH-#17584, TGT_MergedSrc=L2008-0619
17585 TANGUT IDEOGRAPH-#17585, TGT_MergedSrc=L2008-1516
17586 TANGUT IDEOGRAPH-#17586, TGT_MergedSrc=L2008-1819
17587 TANGUT IDEOGRAPH-#17587, TGT_MergedSrc=L2008-1818
17588 TANGUT IDEOGRAPH-#17588, TGT_MergedSrc=L2008-1527
17589 TANGUT IDEOGRAPH-#17589, TGT_MergedSrc=L2008-1509
1758A TANGUT IDEOGRAPH-#1758A, TGT_MergedSrc=L2008-0457
1758B TANGUT IDEOGRAPH-#1758B, TGT_MergedSrc=L2008-0432
1758C TANGUT IDEOGRAPH-#1758C, TGT_MergedSrc=L2008-0448
1758D TANGUT IDEOGRAPH-#1758D, TGT_MergedSrc=L2008-0837
1758E TANGUT IDEOGRAPH-#1758E, TGT_MergedSrc=L2008-0454
1758F TANGUT IDEOGRAPH-#1758F, TGT_MergedSrc=L2008-0429
17590 TANGUT IDEOGRAPH-#17590, TGT_MergedSrc=L2008-0461
17591 TANGUT IDEOGRAPH-#17591, TGT_MergedSrc=L2008-0727
17592 TANGUT IDEOGRAPH-#17592, TGT_MergedSrc=L2008-0628
17593 TANGUT IDEOGRAPH-#17593, TGT_MergedSrc=L2008-0729
17594 TANGUT IDEOGRAPH-#17594, TGT_MergedSrc=L2008-0728
17595 TANGUT IDEOGRAPH-#17595, TGT_MergedSrc=L2008-0626
17596 TANGUT IDEOGRAPH-#17596, TGT_MergedSrc=L2008-0733
17597 TANGUT IDEOGRAPH-#17597, TGT_MergedSrc=L2008-1813
17598 TANGUT IDEOGRAPH-#17598, TGT_MergedSrc=L2008-1824
17599 TANGUT IDEOGRAPH-#17599, TGT_MergedSrc=L2008-1499
1759A TANGUT IDEOGRAPH-#1759A, TGT_MergedSrc=L2008-0835
1759B TANGUT IDEOGRAPH-#1759B, TGT_MergedSrc=L2008-0434
1759C TANGUT IDEOGRAPH-#1759C, TGT_MergedSrc=L2008-0462
1759D TANGUT IDEOGRAPH-#1759D, TGT_MergedSrc=L2008-1809
1759E TANGUT IDEOGRAPH-#1759E, TGT_MergedSrc=L2008-1828
1759F TANGUT IDEOGRAPH-#1759F, TGT_MergedSrc=L2008-0435
175A0 TANGUT IDEOGRAPH-#175A0, TGT_MergedSrc=L2008-1507
175A1 TANGUT IDEOGRAPH-#175A1, TGT_MergedSrc=L2008-1820
175A2 TANGUT IDEOGRAPH-#175A2, TGT_MergedSrc=L2008-1810
175A3 TANGUT IDEOGRAPH-#175A3, TGT_MergedSrc=L2008-1827
175A4 TANGUT IDEOGRAPH-#175A4, TGT_MergedSrc=L2008-1831
175A5 TANGUT IDEOGRAPH-#175A5, TGT_MergedSrc=L2008-1487
175A6 TANGUT IDEOGRAPH-#175A6, TGT_MergedSrc=L2008-1536
175A7 TANGUT IDEOGRAPH-#175A7, TGT_MergedSrc=L2008-1544
175A8 TANGUT IDEOGRAPH-#175A8, TGT_MergedSrc=L2008-1511
175A9 TANGUT IDEOGRAPH-#175A9, TGT_MergedSrc=L2008-0897
175AA TANGUT IDEOGRAPH-#175AA, TGT_MergedSrc=L2008-1523
175AB TANGUT IDEOGRAPH-#175AB, TGT_MergedSrc=L2008-0838
175AC TANGUT IDEOGRAPH-#175AC, TGT_MergedSrc=L2008-0836
175AD TANGUT IDEOGRAPH-#175AD, TGT_MergedSrc=L2008-1821
175AE TANGUT IDEOGRAPH-#175AE, TGT_MergedSrc=L2008-0888
175AF TANGUT IDEOGRAPH-#175AF, TGT_MergedSrc=L2008-0898
175B0 TANGUT IDEOGRAPH-#175B0, TGT_MergedSrc=L2008-0437
175B1 TANGUT IDEOGRAPH-#175B1, TGT_MergedSrc=L2008-1520
175B2 TANGUT IDEOGRAPH-#175B2, TGT_MergedSrc=L2008-1538
175B3 TANGUT IDEOGRAPH-#175B3, TGT_MergedSrc=L2008-0630
175B4 TANGUT IDEOGRAPH-#175B4, TGT_MergedSrc=L2008-0436
175B5 TANGUT IDEOGRAPH-#175B5, TGT_MergedSrc=L2008-0433
175B6 TANGUT IDEOGRAPH-#175B6, TGT_MergedSrc=L2008-0441
175B7 TANGUT IDEOGRAPH-#175B7, TGT_MergedSrc=L2008-0629
175B8 TANGUT IDEOGRAPH-#175B8, TGT_MergedSrc=L2008-1822
175B9 TANGUT IDEOGRAPH-#175B9, TGT_MergedSrc=L2008-6008
175BA TANGUT IDEOGRAPH-#175BA, TGT_MergedSrc=L2008-1811
175BB TANGUT IDEOGRAPH-#175BB, TGT_MergedSrc=L2008-1830
175BC TANGUT IDEOGRAPH-#175BC, TGT_MergedSrc=L2008-1491
175BD TANGUT IDEOGRAPH-#175BD, TGT_MergedSrc=L2008-0427
175BE TANGUT IDEOGRAPH-#175BE, TGT_MergedSrc=L2008-0430
175BF TANGUT IDEOGRAPH-#175BF, TGT_MergedSrc=L2008-0452
175C0 TANGUT IDEOGRAPH-#175C0, TGT_MergedSrc=L2008-0450
175C1 TANGUT IDEOGRAPH-#175C1, TGT_MergedSrc=L2008-1534
175C2 TANGUT IDEOGRAPH-#175C2, TGT_MergedSrc=L2008-0734
175C3 TANGUT IDEOGRAPH-#175C3, TGT_MergedSrc=L2008-1540
175C4 TANGUT IDEOGRAPH-#175C4, TGT_MergedSrc=L2008-0438
175C5 TANGUT IDEOGRAPH-#175C5, TGT_MergedSrc=L2008-0446
175C6 TANGUT IDEOGRAPH-#175C6, TGT_MergedSrc=L2008-1489
175C7 TANGUT IDEOGRAPH-#175C7, TGT_MergedSrc=L2008-1522
175C8 TANGUT IDEOGRAPH-#175C8, TGT_MergedSrc=L2008-1814
175C9 TANGUT IDEOGRAPH-#175C9, TGT_MergedSrc=L2008-1532
175CA TANGUT IDEOGRAPH-#175CA, TGT_MergedSrc=L2008-1812
175CB TANGUT IDEOGRAPH-#175CB, TGT_MergedSrc=L2008-6023
175CC TANGUT IDEOGRAPH-#175CC, TGT_MergedSrc=L2008-1537
175CD TANGUT IDEOGRAPH-#175CD, TGT_MergedSrc=L2008-0634
175CE TANGUT IDEOGRAPH-#175CE, TGT_MergedSrc=L2008-4069
175CF TANGUT IDEOGRAPH-#175CF, TGT_MergedSrc=L2008-4066
175D0 TANGUT IDEOGRAPH-#175D0, TGT_MergedSrc=L2008-4073
175D1 TANGUT IDEOGRAPH-#175D1, TGT_MergedSrc=L2008-4065
175D2 TANGUT IDEOGRAPH-#175D2, TGT_MergedSrc=L2008-4072
175D3 TANGUT IDEOGRAPH-#175D3, TGT_MergedSrc=L2008-0229
175D4 TANGUT IDEOGRAPH-#175D4, TGT_MergedSrc=L2008-0218
175D5 TANGUT IDEOGRAPH-#175D5, TGT_MergedSrc=L2008-0207
175D6 TANGUT IDEOGRAPH-#175D6, TGT_MergedSrc=L2008-0504
175D7 TANGUT IDEOGRAPH-#175D7, TGT_MergedSrc=L2008-1612
175D8 TANGUT IDEOGRAPH-#175D8, TGT_MergedSrc=L2008-1079
175D9 TANGUT IDEOGRAPH-#175D9, TGT_MergedSrc=L2008-1139
175DA TANGUT IDEOGRAPH-#175DA, TGT_MergedSrc=L2008-0661
175DB TANGUT IDEOGRAPH-#175DB, TGT_MergedSrc=L2008-0173
175DC TANGUT IDEOGRAPH-#175DC, TGT_MergedSrc=L2008-0509
175DD TANGUT IDEOGRAPH-#175DD, TGT_MergedSrc=L2008-1619
175DE TANGUT IDEOGRAPH-#175DE, TGT_MergedSrc=L2008-0663
175DF TANGUT IDEOGRAPH-#175DF, TGT_MergedSrc=L2008-1101
175E0 TANGUT IDEOGRAPH-#175E0, TGT_MergedSrc=L2008-0956
175E1 TANGUT IDEOGRAPH-#175E1, TGT_MergedSrc=L2008-0955
175E2 TANGUT IDEOGRAPH-#175E2, TGT_MergedSrc=L2008-1593
175E3 TANGUT IDEOGRAPH-#175E3, TGT_MergedSrc=L2008-5845
175E4 TANGUT IDEOGRAPH-#175E4, TGT_MergedSrc=L2008-5836
175E5 TANGUT IDEOGRAPH-#175E5, TGT_MergedSrc=L2008-5875
175E6 TANGUT IDEOGRAPH-#175E6, TGT_MergedSrc=L2008-5950
175E7 TANGUT IDEOGRAPH-#175E7, TGT_MergedSrc=L2008-5910
175E8 TANGUT IDEOGRAPH-#175E8, TGT_MergedSrc=L2008-5839
175E9 TANGUT IDEOGRAPH-#175E9, TGT_MergedSrc=L2008-5847
175EA TANGUT IDEOGRAPH-#175EA, TGT_MergedSrc=L2008-5840
175EB TANGUT IDEOGRAPH-#175EB, TGT_MergedSrc=L2008-5957
175EC TANGUT IDEOGRAPH-#175EC, TGT_MergedSrc=L2008-5949
175ED TANGUT IDEOGRAPH-#175ED, TGT_MergedSrc=L2008-5984
175EE TANGUT IDEOGRAPH-#175EE, TGT_MergedSrc=L2008-5953
175EF TANGUT IDEOGRAPH-#175EF, TGT_MergedSrc=L2008-1170
175F0 TANGUT IDEOGRAPH-#175F0, TGT_MergedSrc=L2008-0591
175F1 TANGUT IDEOGRAPH-#175F1, TGT_MergedSrc=L2008-1870
175F2 TANGUT IDEOGRAPH-#175F2, TGT_MergedSrc=L2008-1707
175F3 TANGUT IDEOGRAPH-#175F3, TGT_MergedSrc=L2008-1397
175F4 TANGUT IDEOGRAPH-#175F4, TGT_MergedSrc=L2008-0311
175F5 TANGUT IDEOGRAPH-#175F5, TGT_MergedSrc=L2008-1195
175F6 TANGUT IDEOGRAPH-#175F6, TGT_MergedSrc=L2008-1666-1667
175F7 TANGUT IDEOGRAPH-#175F7, TGT_MergedSrc=L2008-1691
175F8 TANGUT IDEOGRAPH-#175F8, TGT_MergedSrc=L2008-1276
175F9 TANGUT IDEOGRAPH-#175F9, TGT_MergedSrc=L2008-1311
175FA TANGUT IDEOGRAPH-#175FA, TGT_MergedSrc=L2008-1310
175FB TANGUT IDEOGRAPH-#175FB, TGT_MergedSrc=L2008-0573
175FC TANGUT IDEOGRAPH-#175FC, TGT_MergedSrc=L2008-0584
175FD TANGUT IDEOGRAPH-#175FD, TGT_MergedSrc=L2008-0602
175FE TANGUT IDEOGRAPH-#175FE, TGT_MergedSrc=L2008-0294
175FF TANGUT IDEOGRAPH-#175FF, TGT_MergedSrc=L2008-1312
17600 TANGUT IDEOGRAPH-#17600, TGT_MergedSrc=L2008-1203
17601 TANGUT IDEOGRAPH-#17601, TGT_MergedSrc=L2008-0285
17602 TANGUT IDEOGRAPH-#17602, TGT_MergedSrc=L2008-1200
17603 TANGUT IDEOGRAPH-#17603, TGT_MergedSrc=L2008-0286
17604 TANGUT IDEOGRAPH-#17604, TGT_MergedSrc=L2008-1313
17605 TANGUT IDEOGRAPH-#17605, TGT_MergedSrc=L2008-1375
17606 TANGUT IDEOGRAPH-#17606, TGT_MergedSrc=L2008-1314
17607 TANGUT IDEOGRAPH-#17607, TGT_MergedSrc=L2008-6013
17608 TANGUT IDEOGRAPH-#17608, TGT_MergedSrc=L2008-1219
17609 TANGUT IDEOGRAPH-#17609, TGT_MergedSrc=L2008-0379
1760A TANGUT IDEOGRAPH-#1760A, TGT_MergedSrc=L2008-0318
1760B TANGUT IDEOGRAPH-#1760B, TGT_MergedSrc=L2008-1347
1760C TANGUT IDEOGRAPH-#1760C, TGT_MergedSrc=L2008-0559
1760D TANGUT IDEOGRAPH-#1760D, TGT_MergedSrc=L2008-0257
1760E TANGUT IDEOGRAPH-#1760E, TGT_MergedSrc=L2008-0332
1760F TANGUT IDEOGRAPH-#1760F, TGT_MergedSrc=L2008-0267
17610 TANGUT IDEOGRAPH-#17610, TGT_MergedSrc=L2008-0560
17611 TANGUT IDEOGRAPH-#17611, TGT_MergedSrc=L2008-1765
17612 TANGUT IDEOGRAPH-#17612, TGT_MergedSrc=L2008-1749
17613 TANGUT IDEOGRAPH-#17613, TGT_MergedSrc=L2008-1703
17614 TANGUT IDEOGRAPH-#17614, TGT_MergedSrc=L2008-1169
17615 TANGUT IDEOGRAPH-#17615, TGT_MergedSrc=L2008-0292
17616 TANGUT IDEOGRAPH-#17616, TGT_MergedSrc=L2008-1766
17617 TANGUT IDEOGRAPH-#17617, TGT_MergedSrc=L2008-0319
17618 TANGUT IDEOGRAPH-#17618, TGT_MergedSrc=L2008-1717
17619 TANGUT IDEOGRAPH-#17619, TGT_MergedSrc=L2008-0587
1761A TANGUT IDEOGRAPH-#1761A, TGT_MergedSrc=L2008-1702
1761B TANGUT IDEOGRAPH-#1761B, TGT_MergedSrc=L2008-1367
1761C TANGUT IDEOGRAPH-#1761C, TGT_MergedSrc=L2008-0870
1761D TANGUT IDEOGRAPH-#1761D, TGT_MergedSrc=L2008-1615
1761E TANGUT IDEOGRAPH-#1761E, TGT_MergedSrc=L2008-0480
1761F TANGUT IDEOGRAPH-#1761F, TGT_MergedSrc=L2008-1080
17620 TANGUT IDEOGRAPH-#17620, TGT_MergedSrc=L2008-0158
17621 TANGUT IDEOGRAPH-#17621, TGT_MergedSrc=L2008-0737
17622 TANGUT IDEOGRAPH-#17622, TGT_MergedSrc=L2008-1004
17623 TANGUT IDEOGRAPH-#17623, TGT_MergedSrc=L2008-1589
17624 TANGUT IDEOGRAPH-#17624, TGT_MergedSrc=L2008-1070
17625 TANGUT IDEOGRAPH-#17625, TGT_MergedSrc=L2008-1021
17626 TANGUT IDEOGRAPH-#17626, TGT_MergedSrc=L2008-1058
17627 TANGUT IDEOGRAPH-#17627, TGT_MergedSrc=L2008-0969
17628 TANGUT IDEOGRAPH-#17628, TGT_MergedSrc=L2008-0970
17629 TANGUT IDEOGRAPH-#17629, TGT_MergedSrc=L2008-1103
1762A TANGUT IDEOGRAPH-#1762A, TGT_MergedSrc=L2008-1137
1762B TANGUT IDEOGRAPH-#1762B, TGT_MergedSrc=L2008-1192
1762C TANGUT IDEOGRAPH-#1762C, TGT_MergedSrc=L2008-1363
1762D TANGUT IDEOGRAPH-#1762D, TGT_MergedSrc=L2008-1299
1762E TANGUT IDEOGRAPH-#1762E, TGT_MergedSrc=L2008-1545
1762F TANGUT IDEOGRAPH-#1762F, TGT_MergedSrc=L2008-2536
17630 TANGUT IDEOGRAPH-#17630, TGT_MergedSrc=L2008-3022
17631 TANGUT IDEOGRAPH-#17631, TGT_MergedSrc=L2008-3086
17632 TANGUT IDEOGRAPH-#17632, TGT_MergedSrc=L2008-4440
17633 TANGUT IDEOGRAPH-#17633, TGT_MergedSrc=L2008-4460
17634 TANGUT IDEOGRAPH-#17634, TGT_MergedSrc=L2008-4450
17635 TANGUT IDEOGRAPH-#17635, TGT_MergedSrc=L2008-4458
17636 TANGUT IDEOGRAPH-#17636, TGT_MergedSrc=L2008-0936
17637 TANGUT IDEOGRAPH-#17637, TGT_MergedSrc=L2008-0222
17638 TANGUT IDEOGRAPH-#17638, TGT_MergedSrc=L2008-0202
17639 TANGUT IDEOGRAPH-#17639, TGT_MergedSrc=L2008-0162
1763A TANGUT IDEOGRAPH-#1763A, TGT_MergedSrc=L2008-0201
1763B TANGUT IDEOGRAPH-#1763B, TGT_MergedSrc=L2008-1124
1763C TANGUT IDEOGRAPH-#1763C, TGT_MergedSrc=L2008-0775
1763D TANGUT IDEOGRAPH-#1763D, TGT_MergedSrc=L2008-1631
1763E TANGUT IDEOGRAPH-#1763E, TGT_MergedSrc=L2008-1128
1763F TANGUT IDEOGRAPH-#1763F, TGT_MergedSrc=L2008-1140
17640 TANGUT IDEOGRAPH-#17640, TGT_MergedSrc=L2008-0773
17641 TANGUT IDEOGRAPH-#17641, TGT_MergedSrc=L2008-1849
17642 TANGUT IDEOGRAPH-#17642, TGT_MergedSrc=L2008-1027
17643 TANGUT IDEOGRAPH-#17643, TGT_MergedSrc=L2008-1661
17644 TANGUT IDEOGRAPH-#17644, TGT_MergedSrc=L2008-0751
17645 TANGUT IDEOGRAPH-#17645, TGT_MergedSrc=L2008-1594
17646 TANGUT IDEOGRAPH-#17646, TGT_MergedSrc=L2008-1081
17647 TANGUT IDEOGRAPH-#17647, TGT_MergedSrc=L2008-1008
17648 TANGUT IDEOGRAPH-#17648, TGT_MergedSrc=L2008-0182
17649 TANGUT IDEOGRAPH-#17649, TGT_MergedSrc=L2008-1129
1764A TANGUT IDEOGRAPH-#1764A, TGT_MergedSrc=L2008-0205
1764B TANGUT IDEOGRAPH-#1764B, TGT_MergedSrc=L2008-1028
1764C TANGUT IDEOGRAPH-#1764C, TGT_MergedSrc=L2008-0223
1764D TANGUT IDEOGRAPH-#1764D, TGT_MergedSrc=L2008-1642
1764E TANGUT IDEOGRAPH-#1764E, TGT_MergedSrc=L2008-1632
1764F TANGUT IDEOGRAPH-#1764F, TGT_MergedSrc=L2008-1586
17650 TANGUT IDEOGRAPH-#17650, TGT_MergedSrc=L2008-1007
17651 TANGUT IDEOGRAPH-#17651, TGT_MergedSrc=L2008-1010
17652 TANGUT IDEOGRAPH-#17652, TGT_MergedSrc=L2008-0498
17653 TANGUT IDEOGRAPH-#17653, TGT_MergedSrc=L2008-0209
17654 TANGUT IDEOGRAPH-#17654, TGT_MergedSrc=L2008-1643
17655 TANGUT IDEOGRAPH-#17655, TGT_MergedSrc=L2008-0165
17656 TANGUT IDEOGRAPH-#17656, TGT_MergedSrc=L2008-0659
17657 TANGUT IDEOGRAPH-#17657, TGT_MergedSrc=L2008-0164
17658 TANGUT IDEOGRAPH-#17658, TGT_MergedSrc=L2008-0178
17659 TANGUT IDEOGRAPH-#17659, TGT_MergedSrc=L2008-1006
1765A TANGUT IDEOGRAPH-#1765A, TGT_MergedSrc=L2008-0962
1765B TANGUT IDEOGRAPH-#1765B, TGT_MergedSrc=L2008-1005
1765C TANGUT IDEOGRAPH-#1765C, TGT_MergedSrc=L2008-0777
1765D TANGUT IDEOGRAPH-#1765D, TGT_MergedSrc=L2008-1845
1765E TANGUT IDEOGRAPH-#1765E, TGT_MergedSrc=L2008-0203
1765F TANGUT IDEOGRAPH-#1765F, TGT_MergedSrc=L2008-1009
17660 TANGUT IDEOGRAPH-#17660, TGT_MergedSrc=L2008-0855
17661 TANGUT IDEOGRAPH-#17661, TGT_MergedSrc=L2008-1029
17662 TANGUT IDEOGRAPH-#17662, TGT_MergedSrc=L2008-0653
17663 TANGUT IDEOGRAPH-#17663, TGT_MergedSrc=L2008-1644
17664 TANGUT IDEOGRAPH-#17664, TGT_MergedSrc=L2008-1123
17665 TANGUT IDEOGRAPH-#17665, TGT_MergedSrc=L2008-0161
17666 TANGUT IDEOGRAPH-#17666, TGT_MergedSrc=L2008-1613
17667 TANGUT IDEOGRAPH-#17667, TGT_MergedSrc=L2008-0937
17668 TANGUT IDEOGRAPH-#17668, TGT_MergedSrc=L2008-1650
17669 TANGUT IDEOGRAPH-#17669, TGT_MergedSrc=L2008-0846
1766A TANGUT IDEOGRAPH-#1766A, TGT_MergedSrc=L2008-1102
1766B TANGUT IDEOGRAPH-#1766B, TGT_MergedSrc=L2008-0774
1766C TANGUT IDEOGRAPH-#1766C, TGT_MergedSrc=L2008-0075
1766D TANGUT IDEOGRAPH-#1766D, TGT_MergedSrc=L2008-0224
1766E TANGUT IDEOGRAPH-#1766E, TGT_MergedSrc=L2008-1083
1766F TANGUT IDEOGRAPH-#1766F, TGT_MergedSrc=L2008-0845
17670 TANGUT IDEOGRAPH-#17670, TGT_MergedSrc=L2008-0492
17671 TANGUT IDEOGRAPH-#17671, TGT_MergedSrc=L2008-1590
17672 TANGUT IDEOGRAPH-#17672, TGT_MergedSrc=L2008-1634
17673 TANGUT IDEOGRAPH-#17673, TGT_MergedSrc=L2008-0754
17674 TANGUT IDEOGRAPH-#17674, TGT_MergedSrc=L2008-0177
17675 TANGUT IDEOGRAPH-#17675, TGT_MergedSrc=L2008-0279
17676 TANGUT IDEOGRAPH-#17676, TGT_MergedSrc=L2008-0364
17677 TANGUT IDEOGRAPH-#17677, TGT_MergedSrc=L2008-0567
17678 TANGUT IDEOGRAPH-#17678, TGT_MergedSrc=L2008-0329
17679 TANGUT IDEOGRAPH-#17679, TGT_MergedSrc=L2008-1369
1767A TANGUT IDEOGRAPH-#1767A, TGT_MergedSrc=L2008-0709
1767B TANGUT IDEOGRAPH-#1767B, TGT_MergedSrc=L2008-1675
1767C TANGUT IDEOGRAPH-#1767C, TGT_MergedSrc=L2008-1778
1767D TANGUT IDEOGRAPH-#1767D, TGT_MergedSrc=L2008-0799
1767E TANGUT IDEOGRAPH-#1767E, TGT_MergedSrc=L2008-0283
1767F TANGUT IDEOGRAPH-#1767F, TGT_MergedSrc=L2008-1756
17680 TANGUT IDEOGRAPH-#17680, TGT_MergedSrc=L2008-1351
17681 TANGUT IDEOGRAPH-#17681, TGT_MergedSrc=L2008-0368
17682 TANGUT IDEOGRAPH-#17682, TGT_MergedSrc=L2008-1683
17683 TANGUT IDEOGRAPH-#17683, TGT_MergedSrc=L2008-4143
17684 TANGUT IDEOGRAPH-#17684, TGT_MergedSrc=L2008-4144
17685 TANGUT IDEOGRAPH-#17685, TGT_MergedSrc=L2008-4383
17686 TANGUT IDEOGRAPH-#17686, TGT_MergedSrc=L2008-4206
17687 TANGUT IDEOGRAPH-#17687, TGT_MergedSrc=L2008-4146
17688 TANGUT IDEOGRAPH-#17688, TGT_MergedSrc=L2008-4276
17689 TANGUT IDEOGRAPH-#17689, TGT_MergedSrc=L2008-4172
1768A TANGUT IDEOGRAPH-#1768A, TGT_MergedSrc=L2008-4278
1768B TANGUT IDEOGRAPH-#1768B, TGT_MergedSrc=L2008-4207
1768C TANGUT IDEOGRAPH-#1768C, TGT_MergedSrc=L2008-4095
1768D TANGUT IDEOGRAPH-#1768D, TGT_MergedSrc=L2008-4411
1768E TANGUT IDEOGRAPH-#1768E, TGT_MergedSrc=L2008-4149
1768F TANGUT IDEOGRAPH-#1768F, TGT_MergedSrc=L2008-4096
17690 TANGUT IDEOGRAPH-#17690, TGT_MergedSrc=L2008-4315
17691 TANGUT IDEOGRAPH-#17691, TGT_MergedSrc=L2008-4099
17692 TANGUT IDEOGRAPH-#17692, TGT_MergedSrc=L2008-4163
17693 TANGUT IDEOGRAPH-#17693, TGT_MergedSrc=L2008-4175
17694 TANGUT IDEOGRAPH-#17694, TGT_MergedSrc=L2008-4173
17695 TANGUT IDEOGRAPH-#17695, TGT_MergedSrc=L2008-4281
17696 TANGUT IDEOGRAPH-#17696, TGT_MergedSrc=L2008-4247
17697 TANGUT IDEOGRAPH-#17697, TGT_MergedSrc=L2008-4277
17698 TANGUT IDEOGRAPH-#17698, TGT_MergedSrc=L2008-4275
17699 TANGUT IDEOGRAPH-#17699, TGT_MergedSrc=L2008-4145
1769A TANGUT IDEOGRAPH-#1769A, TGT_MergedSrc=L2008-4209
1769B TANGUT IDEOGRAPH-#1769B, TGT_MergedSrc=L2008-4174
1769C TANGUT IDEOGRAPH-#1769C, TGT_MergedSrc=L2008-4413
1769D TANGUT IDEOGRAPH-#1769D, TGT_MergedSrc=L2008-4350
1769E TANGUT IDEOGRAPH-#1769E, TGT_MergedSrc=L2008-4421
1769F TANGUT IDEOGRAPH-#1769F, TGT_MergedSrc=L2008-4192
176A0 TANGUT IDEOGRAPH-#176A0, TGT_MergedSrc=L2008-4098
176A1 TANGUT IDEOGRAPH-#176A1, TGT_MergedSrc=L2008-4148
176A2 TANGUT IDEOGRAPH-#176A2, TGT_MergedSrc=L2008-4125
176A3 TANGUT IDEOGRAPH-#176A3, TGT_MergedSrc=L2008-4297
176A4 TANGUT IDEOGRAPH-#176A4, TGT_MergedSrc=L2008-4162
176A5 TANGUT IDEOGRAPH-#176A5, TGT_MergedSrc=L2008-4157
176A6 TANGUT IDEOGRAPH-#176A6, TGT_MergedSrc=L2008-4176
176A7 TANGUT IDEOGRAPH-#176A7, TGT_MergedSrc=L2008-4205
176A8 TANGUT IDEOGRAPH-#176A8, TGT_MergedSrc=L2008-4215
176A9 TANGUT IDEOGRAPH-#176A9, TGT_MergedSrc=L2008-4343
176AA TANGUT IDEOGRAPH-#176AA, TGT_MergedSrc=L2008-4302
176AB TANGUT IDEOGRAPH-#176AB, TGT_MergedSrc=L2008-4165
176AC TANGUT IDEOGRAPH-#176AC, TGT_MergedSrc=L2008-4164
176AD TANGUT IDEOGRAPH-#176AD, TGT_MergedSrc=L2008-4142
176AE TANGUT IDEOGRAPH-#176AE, TGT_MergedSrc=L2008-4409
176AF TANGUT IDEOGRAPH-#176AF, TGT_MergedSrc=L2008-4384
176B0 TANGUT IDEOGRAPH-#176B0, TGT_MergedSrc=L2008-4224
176B1 TANGUT IDEOGRAPH-#176B1, TGT_MergedSrc=L2008-4229
176B2 TANGUT IDEOGRAPH-#176B2, TGT_MergedSrc=L2008-4426
176B3 TANGUT IDEOGRAPH-#176B3, TGT_MergedSrc=L2008-4219
176B4 TANGUT IDEOGRAPH-#176B4, TGT_MergedSrc=L2008-4208
176B5 TANGUT IDEOGRAPH-#176B5, TGT_MergedSrc=L2008-4252
176B6 TANGUT IDEOGRAPH-#176B6, TGT_MergedSrc=L2008-4296
176B7 TANGUT IDEOGRAPH-#176B7, TGT_MergedSrc=L2008-4361
176B8 TANGUT IDEOGRAPH-#176B8, TGT_MergedSrc=L2008-4412
176B9 TANGUT IDEOGRAPH-#176B9, TGT_MergedSrc=L2008-4180
176BA TANGUT IDEOGRAPH-#176BA, TGT_MergedSrc=L2008-4155
176BB TANGUT IDEOGRAPH-#176BB, TGT_MergedSrc=L2008-4100
176BC TANGUT IDEOGRAPH-#176BC, TGT_MergedSrc=L2008-4310
176BD TANGUT IDEOGRAPH-#176BD, TGT_MergedSrc=L2008-4171
176BE TANGUT IDEOGRAPH-#176BE, TGT_MergedSrc=L2008-4199
176BF TANGUT IDEOGRAPH-#176BF, TGT_MergedSrc=L2008-4153
176C0 TANGUT IDEOGRAPH-#176C0, TGT_MergedSrc=L2008-4160
176C1 TANGUT IDEOGRAPH-#176C1, TGT_MergedSrc=L2008-4334
176C2 TANGUT IDEOGRAPH-#176C2, TGT_MergedSrc=L2008-4333
176C3 TANGUT IDEOGRAPH-#176C3, TGT_MergedSrc=L2008-4106
176C4 TANGUT IDEOGRAPH-#176C4, TGT_MergedSrc=L2008-4122
176C5 TANGUT IDEOGRAPH-#176C5, TGT_MergedSrc=L2008-4177
176C6 TANGUT IDEOGRAPH-#176C6, TGT_MergedSrc=L2008-4109
176C7 TANGUT IDEOGRAPH-#176C7, TGT_MergedSrc=L2008-4159
176C8 TANGUT IDEOGRAPH-#176C8, TGT_MergedSrc=L2008-4216
176C9 TANGUT IDEOGRAPH-#176C9, TGT_MergedSrc=L2008-4213
176CA TANGUT IDEOGRAPH-#176CA, TGT_MergedSrc=L2008-4318
176CB TANGUT IDEOGRAPH-#176CB, TGT_MergedSrc=L2008-4212
176CC TANGUT IDEOGRAPH-#176CC, TGT_MergedSrc=L2008-4280
176CD TANGUT IDEOGRAPH-#176CD, TGT_MergedSrc=L2008-4376
176CE TANGUT IDEOGRAPH-#176CE, TGT_MergedSrc=L2008-4357
176CF TANGUT IDEOGRAPH-#176CF, TGT_MergedSrc=L2008-4307
176D0 TANGUT IDEOGRAPH-#176D0, TGT_MergedSrc=L2008-4156
176D1 TANGUT IDEOGRAPH-#176D1, TGT_MergedSrc=L2008-4152
176D2 TANGUT IDEOGRAPH-#176D2, TGT_MergedSrc=L2008-4400
176D3 TANGUT IDEOGRAPH-#176D3, TGT_MergedSrc=L2008-4414
176D4 TANGUT IDEOGRAPH-#176D4, TGT_MergedSrc=L2008-4351
176D5 TANGUT IDEOGRAPH-#176D5, TGT_MergedSrc=L2008-4211
176D6 TANGUT IDEOGRAPH-#176D6, TGT_MergedSrc=L2008-4406
176D7 TANGUT IDEOGRAPH-#176D7, TGT_MergedSrc=L2008-4138
176D8 TANGUT IDEOGRAPH-#176D8, TGT_MergedSrc=L2008-4181
176D9 TANGUT IDEOGRAPH-#176D9, TGT_MergedSrc=L2008-4167
176DA TANGUT IDEOGRAPH-#176DA, TGT_MergedSrc=L2008-4179
176DB TANGUT IDEOGRAPH-#176DB, TGT_MergedSrc=L2008-4204
176DC TANGUT IDEOGRAPH-#176DC, TGT_MergedSrc=L2008-4103
176DD TANGUT IDEOGRAPH-#176DD, TGT_MergedSrc=L2008-4246
176DE TANGUT IDEOGRAPH-#176DE, TGT_MergedSrc=L2008-4245
176DF TANGUT IDEOGRAPH-#176DF, TGT_MergedSrc=L2008-4234
176E0 TANGUT IDEOGRAPH-#176E0, TGT_MergedSrc=L2008-4235
176E1 TANGUT IDEOGRAPH-#176E1, TGT_MergedSrc=L2008-4188
176E2 TANGUT IDEOGRAPH-#176E2, TGT_MergedSrc=L2008-4332
176E3 TANGUT IDEOGRAPH-#176E3, TGT_MergedSrc=L2008-4341
176E4 TANGUT IDEOGRAPH-#176E4, TGT_MergedSrc=L2008-4110
176E5 TANGUT IDEOGRAPH-#176E5, TGT_MergedSrc=L2008-4170
176E6 TANGUT IDEOGRAPH-#176E6, TGT_MergedSrc=L2008-4416
176E7 TANGUT IDEOGRAPH-#176E7, TGT_MergedSrc=L2008-4161
176E8 TANGUT IDEOGRAPH-#176E8, TGT_MergedSrc=L2008-4123
176E9 TANGUT IDEOGRAPH-#176E9, TGT_MergedSrc=L2008-4136
176EA TANGUT IDEOGRAPH-#176EA, TGT_MergedSrc=L2008-4124
176EB TANGUT IDEOGRAPH-#176EB, TGT_MergedSrc=L2008-4404
176EC TANGUT IDEOGRAPH-#176EC, TGT_MergedSrc=L2008-4373
176ED TANGUT IDEOGRAPH-#176ED, TGT_MergedSrc=L2008-4345
176EE TANGUT IDEOGRAPH-#176EE, TGT_MergedSrc=L2008-4279
176EF TANGUT IDEOGRAPH-#176EF, TGT_MergedSrc=L2008-4217
176F0 TANGUT IDEOGRAPH-#176F0, TGT_MergedSrc=L2008-4344
176F1 TANGUT IDEOGRAPH-#176F1, TGT_MergedSrc=L2008-4424
176F2 TANGUT IDEOGRAPH-#176F2, TGT_MergedSrc=L2008-4319
176F3 TANGUT IDEOGRAPH-#176F3, TGT_MergedSrc=N1966-017-09K
176F4 TANGUT IDEOGRAPH-#176F4, TGT_MergedSrc=L2008-4301
176F5 TANGUT IDEOGRAPH-#176F5, TGT_MergedSrc=L2008-4312
176F6 TANGUT IDEOGRAPH-#176F6, TGT_MergedSrc=L2008-4218
176F7 TANGUT IDEOGRAPH-#176F7, TGT_MergedSrc=L2008-4374
176F8 TANGUT IDEOGRAPH-#176F8, TGT_MergedSrc=L2008-4311
176F9 TANGUT IDEOGRAPH-#176F9, TGT_MergedSrc=L2008-4169
176FA TANGUT IDEOGRAPH-#176FA, TGT_MergedSrc=L2008-4291
176FB TANGUT IDEOGRAPH-#176FB, TGT_MergedSrc=L2008-4316
176FC TANGUT IDEOGRAPH-#176FC, TGT_MergedSrc=L2008-4405
176FD TANGUT IDEOGRAPH-#176FD, TGT_MergedSrc=N1966-017-10D
176FE TANGUT IDEOGRAPH-#176FE, TGT_MergedSrc=L2008-4256
176FF TANGUT IDEOGRAPH-#176FF, TGT_MergedSrc=L2008-4282
17700 TANGUT IDEOGRAPH-#17700, TGT_MergedSrc=L2008-4324
17701 TANGUT IDEOGRAPH-#17701, TGT_MergedSrc=L2008-4178
17702 TANGUT IDEOGRAPH-#17702, TGT_MergedSrc=L2008-4102
17703 TANGUT IDEOGRAPH-#17703, TGT_MergedSrc=L2008-4372
17704 TANGUT IDEOGRAPH-#17704, TGT_MergedSrc=L2008-4210
17705 TANGUT IDEOGRAPH-#17705, TGT_MergedSrc=L2008-4227
17706 TANGUT IDEOGRAPH-#17706, TGT_MergedSrc=L2008-4154
17707 TANGUT IDEOGRAPH-#17707, TGT_MergedSrc=L2008-4242
17708 TANGUT IDEOGRAPH-#17708, TGT_MergedSrc=L2008-4401
17709 TANGUT IDEOGRAPH-#17709, TGT_MergedSrc=L2008-4304
1770A TANGUT IDEOGRAPH-#1770A, TGT_MergedSrc=L2008-4428
1770B TANGUT IDEOGRAPH-#1770B, TGT_MergedSrc=L2008-4187
1770C TANGUT IDEOGRAPH-#1770C, TGT_MergedSrc=L2008-4386
1770D TANGUT IDEOGRAPH-#1770D, TGT_MergedSrc=L2008-4225
1770E TANGUT IDEOGRAPH-#1770E, TGT_MergedSrc=L2008-4393
1770F TANGUT IDEOGRAPH-#1770F, TGT_MergedSrc=L2008-4415
17710 TANGUT IDEOGRAPH-#17710, TGT_MergedSrc=L2008-4408
17711 TANGUT IDEOGRAPH-#17711, TGT_MergedSrc=L2008-4166
17712 TANGUT IDEOGRAPH-#17712, TGT_MergedSrc=L2008-4201
17713 TANGUT IDEOGRAPH-#17713, TGT_MergedSrc=L2008-4184
17714 TANGUT IDEOGRAPH-#17714, TGT_MergedSrc=L2008-4395
17715 TANGUT IDEOGRAPH-#17715, TGT_MergedSrc=L2008-4244
17716 TANGUT IDEOGRAPH-#17716, TGT_MergedSrc=L2008-4230
17717 TANGUT IDEOGRAPH-#17717, TGT_MergedSrc=L2008-4203
17718 TANGUT IDEOGRAPH-#17718, TGT_MergedSrc=L2008-4262
17719 TANGUT IDEOGRAPH-#17719, TGT_MergedSrc=L2008-4365
1771A TANGUT IDEOGRAPH-#1771A, TGT_MergedSrc=L2008-4126
1771B TANGUT IDEOGRAPH-#1771B, TGT_MergedSrc=L2008-4285
1771C TANGUT IDEOGRAPH-#1771C, TGT_MergedSrc=L2008-4349
1771D TANGUT IDEOGRAPH-#1771D, TGT_MergedSrc=L2008-4220
1771E TANGUT IDEOGRAPH-#1771E, TGT_MergedSrc=L2008-4191
1771F TANGUT IDEOGRAPH-#1771F, TGT_MergedSrc=L2008-4107
17720 TANGUT IDEOGRAPH-#17720, TGT_MergedSrc=L2008-4150
17721 TANGUT IDEOGRAPH-#17721, TGT_MergedSrc=L2008-4134
17722 TANGUT IDEOGRAPH-#17722, TGT_MergedSrc=L2008-4429
17723 TANGUT IDEOGRAPH-#17723, TGT_MergedSrc=L2008-4292
17724 TANGUT IDEOGRAPH-#17724, TGT_MergedSrc=L2008-4346
17725 TANGUT IDEOGRAPH-#17725, TGT_MergedSrc=L2008-4303
17726 TANGUT IDEOGRAPH-#17726, TGT_MergedSrc=L2008-4226
17727 TANGUT IDEOGRAPH-#17727, TGT_MergedSrc=L2008-4295
17728 TANGUT IDEOGRAPH-#17728, TGT_MergedSrc=L2008-4380
17729 TANGUT IDEOGRAPH-#17729, TGT_MergedSrc=L2008-4320
1772A TANGUT IDEOGRAPH-#1772A, TGT_MergedSrc=L2008-4348
1772B TANGUT IDEOGRAPH-#1772B, TGT_MergedSrc=L2008-4293
1772C TANGUT IDEOGRAPH-#1772C, TGT_MergedSrc=L2008-4248
1772D TANGUT IDEOGRAPH-#1772D, TGT_MergedSrc=L2008-4371
1772E TANGUT IDEOGRAPH-#1772E, TGT_MergedSrc=L2008-4370
1772F TANGUT IDEOGRAPH-#1772F, TGT_MergedSrc=L2008-4190
17730 TANGUT IDEOGRAPH-#17730, TGT_MergedSrc=L2008-4305
17731 TANGUT IDEOGRAPH-#17731, TGT_MergedSrc=L2008-4151
17732 TANGUT IDEOGRAPH-#17732, TGT_MergedSrc=L2008-4308
17733 TANGUT IDEOGRAPH-#17733, TGT_MergedSrc=L2008-4419
17734 TANGUT IDEOGRAPH-#17734, TGT_MergedSrc=L2008-4417
17735 TANGUT IDEOGRAPH-#17735, TGT_MergedSrc=L2008-4392
17736 TANGUT IDEOGRAPH-#17736, TGT_MergedSrc=L2008-4375
17737 TANGUT IDEOGRAPH-#17737, TGT_MergedSrc=L2008-4325
17738 TANGUT IDEOGRAPH-#17738, TGT_MergedSrc=L2008-4326
17739 TANGUT IDEOGRAPH-#17739, TGT_MergedSrc=L2008-4101
1773A TANGUT IDEOGRAPH-#1773A, TGT_MergedSrc=L2008-4221
1773B TANGUT IDEOGRAPH-#1773B, TGT_MergedSrc=L2008-4368
1773C TANGUT IDEOGRAPH-#1773C, TGT_MergedSrc=L2008-4354
1773D TANGUT IDEOGRAPH-#1773D, TGT_MergedSrc=L2008-4283
1773E TANGUT IDEOGRAPH-#1773E, TGT_MergedSrc=L2008-4330
1773F TANGUT IDEOGRAPH-#1773F, TGT_MergedSrc=L2008-4254
17740 TANGUT IDEOGRAPH-#17740, TGT_MergedSrc=L2008-4313
17741 TANGUT IDEOGRAPH-#17741, TGT_MergedSrc=L2008-4182
17742 TANGUT IDEOGRAPH-#17742, TGT_MergedSrc=L2008-4396
17743 TANGUT IDEOGRAPH-#17743, TGT_MergedSrc=L2008-4147
17744 TANGUT IDEOGRAPH-#17744, TGT_MergedSrc=L2008-4112
17745 TANGUT IDEOGRAPH-#17745, TGT_MergedSrc=L2006-6051
17746 TANGUT IDEOGRAPH-#17746, TGT_MergedSrc=L2008-4407
17747 TANGUT IDEOGRAPH-#17747, TGT_MergedSrc=L2008-4403
17748 TANGUT IDEOGRAPH-#17748, TGT_MergedSrc=L2008-4356
17749 TANGUT IDEOGRAPH-#17749, TGT_MergedSrc=L2008-4111
1774A TANGUT IDEOGRAPH-#1774A, TGT_MergedSrc=L2008-4427
1774B TANGUT IDEOGRAPH-#1774B, TGT_MergedSrc=L2008-4410
1774C TANGUT IDEOGRAPH-#1774C, TGT_MergedSrc=L2008-4185
1774D TANGUT IDEOGRAPH-#1774D, TGT_MergedSrc=L2008-4202
1774E TANGUT IDEOGRAPH-#1774E, TGT_MergedSrc=L2008-4189
1774F TANGUT IDEOGRAPH-#1774F, TGT_MergedSrc=L2008-4237
17750 TANGUT IDEOGRAPH-#17750, TGT_MergedSrc=L2008-4236
17751 TANGUT IDEOGRAPH-#17751, TGT_MergedSrc=L2008-4390
17752 TANGUT IDEOGRAPH-#17752, TGT_MergedSrc=L2008-4113
17753 TANGUT IDEOGRAPH-#17753, TGT_MergedSrc=L2008-4114
17754 TANGUT IDEOGRAPH-#17754, TGT_MergedSrc=L2008-4158
17755 TANGUT IDEOGRAPH-#17755, TGT_MergedSrc=L2008-4194
17756 TANGUT IDEOGRAPH-#17756, TGT_MergedSrc=L2008-4186
17757 TANGUT IDEOGRAPH-#17757, TGT_MergedSrc=L2008-4108
17758 TANGUT IDEOGRAPH-#17758, TGT_MergedSrc=L2008-4131
17759 TANGUT IDEOGRAPH-#17759, TGT_MergedSrc=L2008-4257
1775A TANGUT IDEOGRAPH-#1775A, TGT_MergedSrc=L2008-4379
1775B TANGUT IDEOGRAPH-#1775B, TGT_MergedSrc=L2008-4366
1775C TANGUT IDEOGRAPH-#1775C, TGT_MergedSrc=L2008-4133
1775D TANGUT IDEOGRAPH-#1775D, TGT_MergedSrc=L2008-4362
1775E TANGUT IDEOGRAPH-#1775E, TGT_MergedSrc=L2008-4238
1775F TANGUT IDEOGRAPH-#1775F, TGT_MergedSrc=L2008-4382
17760 TANGUT IDEOGRAPH-#17760, TGT_MergedSrc=L2008-4250
17761 TANGUT IDEOGRAPH-#17761, TGT_MergedSrc=L2008-4321
17762 TANGUT IDEOGRAPH-#17762, TGT_MergedSrc=L2008-4299
17763 TANGUT IDEOGRAPH-#17763, TGT_MergedSrc=L2008-4309
17764 TANGUT IDEOGRAPH-#17764, TGT_MergedSrc=L2008-4286
17765 TANGUT IDEOGRAPH-#17765, TGT_MergedSrc=L2008-4117
17766 TANGUT IDEOGRAPH-#17766, TGT_MergedSrc=L2008-4249
17767 TANGUT IDEOGRAPH-#17767, TGT_MergedSrc=L2008-4132
17768 TANGUT IDEOGRAPH-#17768, TGT_MergedSrc=L2008-4193
17769 TANGUT IDEOGRAPH-#17769, TGT_MergedSrc=L2008-4200
1776A TANGUT IDEOGRAPH-#1776A, TGT_MergedSrc=L2008-4418
1776B TANGUT IDEOGRAPH-#1776B, TGT_MergedSrc=L2008-4306
1776C TANGUT IDEOGRAPH-#1776C, TGT_MergedSrc=L2008-4266
1776D TANGUT IDEOGRAPH-#1776D, TGT_MergedSrc=L2008-4369
1776E TANGUT IDEOGRAPH-#1776E, TGT_MergedSrc=L2008-4287
1776F TANGUT IDEOGRAPH-#1776F, TGT_MergedSrc=L2008-4328
17770 TANGUT IDEOGRAPH-#17770, TGT_MergedSrc=L2008-4378
17771 TANGUT IDEOGRAPH-#17771, TGT_MergedSrc=L2008-4352
17772 TANGUT IDEOGRAPH-#17772, TGT_MergedSrc=L2008-4338
17773 TANGUT IDEOGRAPH-#17773, TGT_MergedSrc=L2008-4116
17774 TANGUT IDEOGRAPH-#17774, TGT_MergedSrc=L2008-6049
17775 TANGUT IDEOGRAPH-#17775, TGT_MergedSrc=L2008-4367
17776 TANGUT IDEOGRAPH-#17776, TGT_MergedSrc=L2008-4397
17777 TANGUT IDEOGRAPH-#17777, TGT_MergedSrc=L2008-4331
17778 TANGUT IDEOGRAPH-#17778, TGT_MergedSrc=L2008-4402
17779 TANGUT IDEOGRAPH-#17779, TGT_MergedSrc=L2008-4139
1777A TANGUT IDEOGRAPH-#1777A, TGT_MergedSrc=L2008-4121
1777B TANGUT IDEOGRAPH-#1777B, TGT_MergedSrc=L2008-4104
1777C TANGUT IDEOGRAPH-#1777C, TGT_MergedSrc=L2008-4097
1777D TANGUT IDEOGRAPH-#1777D, TGT_MergedSrc=L2008-4284
1777E TANGUT IDEOGRAPH-#1777E, TGT_MergedSrc=L2008-4398
1777F TANGUT IDEOGRAPH-#1777F, TGT_MergedSrc=L2008-4269
17780 TANGUT IDEOGRAPH-#17780, TGT_MergedSrc=L2008-4335
17781 TANGUT IDEOGRAPH-#17781, TGT_MergedSrc=L2008-4399
17782 TANGUT IDEOGRAPH-#17782, TGT_MergedSrc=L2008-4258
17783 TANGUT IDEOGRAPH-#17783, TGT_MergedSrc=L2008-4259
17784 TANGUT IDEOGRAPH-#17784, TGT_MergedSrc=L2008-4270
17785 TANGUT IDEOGRAPH-#17785, TGT_MergedSrc=L2008-4294
17786 TANGUT IDEOGRAPH-#17786, TGT_MergedSrc=L2008-4377
17787 TANGUT IDEOGRAPH-#17787, TGT_MergedSrc=L2008-4347
17788 TANGUT IDEOGRAPH-#17788, TGT_MergedSrc=L2008-4267
17789 TANGUT IDEOGRAPH-#17789, TGT_MergedSrc=L2008-4232
1778A TANGUT IDEOGRAPH-#1778A, TGT_MergedSrc=L2008-4381
1778B TANGUT IDEOGRAPH-#1778B, TGT_MergedSrc=L2008-4317
1778C TANGUT IDEOGRAPH-#1778C, TGT_MergedSrc=L2008-4118
1778D TANGUT IDEOGRAPH-#1778D, TGT_MergedSrc=L2008-4127
1778E TANGUT IDEOGRAPH-#1778E, TGT_MergedSrc=L2008-4243
1778F TANGUT IDEOGRAPH-#1778F, TGT_MergedSrc=L2008-4360
17790 TANGUT IDEOGRAPH-#17790, TGT_MergedSrc=L2008-4228
17791 TANGUT IDEOGRAPH-#17791, TGT_MergedSrc=L2008-4241
17792 TANGUT IDEOGRAPH-#17792, TGT_MergedSrc=L2008-4387
17793 TANGUT IDEOGRAPH-#17793, TGT_MergedSrc=L2008-4263
17794 TANGUT IDEOGRAPH-#17794, TGT_MergedSrc=L2008-4135
17795 TANGUT IDEOGRAPH-#17795, TGT_MergedSrc=L2008-4222
17796 TANGUT IDEOGRAPH-#17796, TGT_MergedSrc=L2008-4329
17797 TANGUT IDEOGRAPH-#17797, TGT_MergedSrc=L2008-6050
17798 TANGUT IDEOGRAPH-#17798, TGT_MergedSrc=L2008-4394
17799 TANGUT IDEOGRAPH-#17799, TGT_MergedSrc=L2008-4231
1779A TANGUT IDEOGRAPH-#1779A, TGT_MergedSrc=L2008-4264
1779B TANGUT IDEOGRAPH-#1779B, TGT_MergedSrc=L2008-4422
1779C TANGUT IDEOGRAPH-#1779C, TGT_MergedSrc=L2008-4168
1779D TANGUT IDEOGRAPH-#1779D, TGT_MergedSrc=L2008-4115
1779E TANGUT IDEOGRAPH-#1779E, TGT_MergedSrc=L2008-4342
1779F TANGUT IDEOGRAPH-#1779F, TGT_MergedSrc=L2008-4300
177A0 TANGUT IDEOGRAPH-#177A0, TGT_MergedSrc=L2008-4141
177A1 TANGUT IDEOGRAPH-#177A1, TGT_MergedSrc=L2008-4196
177A2 TANGUT IDEOGRAPH-#177A2, TGT_MergedSrc=L2008-4322
177A3 TANGUT IDEOGRAPH-#177A3, TGT_MergedSrc=L2008-4253
177A4 TANGUT IDEOGRAPH-#177A4, TGT_MergedSrc=L2008-4268
177A5 TANGUT IDEOGRAPH-#177A5, TGT_MergedSrc=L2008-4298
177A6 TANGUT IDEOGRAPH-#177A6, TGT_MergedSrc=L2008-4323
177A7 TANGUT IDEOGRAPH-#177A7, TGT_MergedSrc=L2008-4358
177A8 TANGUT IDEOGRAPH-#177A8, TGT_MergedSrc=L2008-4195
177A9 TANGUT IDEOGRAPH-#177A9, TGT_MergedSrc=L2008-4353
177AA TANGUT IDEOGRAPH-#177AA, TGT_MergedSrc=L2008-4140
177AB TANGUT IDEOGRAPH-#177AB, TGT_MergedSrc=L2008-4129
177AC TANGUT IDEOGRAPH-#177AC, TGT_MergedSrc=L2008-4271
177AD TANGUT IDEOGRAPH-#177AD, TGT_MergedSrc=L2008-4120
177AE TANGUT IDEOGRAPH-#177AE, TGT_MergedSrc=L2008-4355
177AF TANGUT IDEOGRAPH-#177AF, TGT_MergedSrc=L2008-4093
177B0 TANGUT IDEOGRAPH-#177B0, TGT_MergedSrc=L2008-4420
177B1 TANGUT IDEOGRAPH-#177B1, TGT_MergedSrc=L2008-4137
177B2 TANGUT IDEOGRAPH-#177B2, TGT_MergedSrc=L2008-4105
177B3 TANGUT IDEOGRAPH-#177B3, TGT_MergedSrc=L2008-4094
177B4 TANGUT IDEOGRAPH-#177B4, TGT_MergedSrc=L2008-4251
177B5 TANGUT IDEOGRAPH-#177B5, TGT_MergedSrc=L2008-4364
177B6 TANGUT IDEOGRAPH-#177B6, TGT_MergedSrc=L2008-4363
177B7 TANGUT IDEOGRAPH-#177B7, TGT_MergedSrc=L2008-4240
177B8 TANGUT IDEOGRAPH-#177B8, TGT_MergedSrc=L2008-4359
177B9 TANGUT IDEOGRAPH-#177B9, TGT_MergedSrc=H2004-A-1805
177BA TANGUT IDEOGRAPH-#177BA, TGT_MergedSrc=L2008-4260
177BB TANGUT IDEOGRAPH-#177BB, TGT_MergedSrc=L2008-4128
177BC TANGUT IDEOGRAPH-#177BC, TGT_MergedSrc=L2008-4197
177BD TANGUT IDEOGRAPH-#177BD, TGT_MergedSrc=L2008-4314
177BE TANGUT IDEOGRAPH-#177BE, TGT_MergedSrc=L2008-4265
177BF TANGUT IDEOGRAPH-#177BF, TGT_MergedSrc=L2008-4288
177C0 TANGUT IDEOGRAPH-#177C0, TGT_MergedSrc=L2008-4385
177C1 TANGUT IDEOGRAPH-#177C1, TGT_MergedSrc=L2008-4337
177C2 TANGUT IDEOGRAPH-#177C2, TGT_MergedSrc=L2008-4255
177C3 TANGUT IDEOGRAPH-#177C3, TGT_MergedSrc=L2008-4339
177C4 TANGUT IDEOGRAPH-#177C4, TGT_MergedSrc=L2008-4391
177C5 TANGUT IDEOGRAPH-#177C5, TGT_MergedSrc=L2008-4340
177C6 TANGUT IDEOGRAPH-#177C6, TGT_MergedSrc=L2008-4261
177C7 TANGUT IDEOGRAPH-#177C7, TGT_MergedSrc=L2008-4273
177C8 TANGUT IDEOGRAPH-#177C8, TGT_MergedSrc=L2008-4272
177C9 TANGUT IDEOGRAPH-#177C9, TGT_MergedSrc=L2008-4388
177CA TANGUT IDEOGRAPH-#177CA, TGT_MergedSrc=L2008-4327
177CB TANGUT IDEOGRAPH-#177CB, TGT_MergedSrc=L2008-4183
177CC TANGUT IDEOGRAPH-#177CC, TGT_MergedSrc=L2008-4290
177CD TANGUT IDEOGRAPH-#177CD, TGT_MergedSrc=L2008-4130
177CE TANGUT IDEOGRAPH-#177CE, TGT_MergedSrc=L2008-4289
177CF TANGUT IDEOGRAPH-#177CF, TGT_MergedSrc=L2008-4223
177D0 TANGUT IDEOGRAPH-#177D0, TGT_MergedSrc=L2008-4336
177D1 TANGUT IDEOGRAPH-#177D1, TGT_MergedSrc=L2008-4239
177D2 TANGUT IDEOGRAPH-#177D2, TGT_MergedSrc=L2008-4119
177D3 TANGUT IDEOGRAPH-#177D3, TGT_MergedSrc=L2008-4389
177D4 TANGUT IDEOGRAPH-#177D4, TGT_MergedSrc=L2008-4233
177D5 TANGUT IDEOGRAPH-#177D5, TGT_MergedSrc=L2008-6048
177D6 TANGUT IDEOGRAPH-#177D6, TGT_MergedSrc=L2008-4198
177D7 TANGUT IDEOGRAPH-#177D7, TGT_MergedSrc=L2008-4558
177D8 TANGUT IDEOGRAPH-#177D8, TGT_MergedSrc=L2008-0604
177D9 TANGUT IDEOGRAPH-#177D9, TGT_MergedSrc=L2008-4633
177DA TANGUT IDEOGRAPH-#177DA, TGT_MergedSrc=L2008-5944
177DB TANGUT IDEOGRAPH-#177DB, TGT_MergedSrc=L2008-4567
177DC TANGUT IDEOGRAPH-#177DC, TGT_MergedSrc=L2008-2520
177DD TANGUT IDEOGRAPH-#177DD, TGT_MergedSrc=L2008-2297
177DE TANGUT IDEOGRAPH-#177DE, TGT_MergedSrc=L2008-4664
177DF TANGUT IDEOGRAPH-#177DF, TGT_MergedSrc=L2008-3722
177E0 TANGUT IDEOGRAPH-#177E0, TGT_MergedSrc=L2008-1285
177E1 TANGUT IDEOGRAPH-#177E1, TGT_MergedSrc=L2008-1875
177E2 TANGUT IDEOGRAPH-#177E2, TGT_MergedSrc=L2008-1727
177E3 TANGUT IDEOGRAPH-#177E3, TGT_MergedSrc=L2008-1382
177E4 TANGUT IDEOGRAPH-#177E4, TGT_MergedSrc=L2008-0714
177E5 TANGUT IDEOGRAPH-#177E5, TGT_MergedSrc=L2008-1868
177E6 TANGUT IDEOGRAPH-#177E6, TGT_MergedSrc=L2008-0598
177E7 TANGUT IDEOGRAPH-#177E7, TGT_MergedSrc=L2008-1700
177E8 TANGUT IDEOGRAPH-#177E8, TGT_MergedSrc=L2008-1770
177E9 TANGUT IDEOGRAPH-#177E9, TGT_MergedSrc=L2008-1393
177EA TANGUT IDEOGRAPH-#177EA, TGT_MergedSrc=L2008-0815
177EB TANGUT IDEOGRAPH-#177EB, TGT_MergedSrc=L2008-0306
177EC TANGUT IDEOGRAPH-#177EC, TGT_MergedSrc=L2008-0816
177ED TANGUT IDEOGRAPH-#177ED, TGT_MergedSrc=L2008-1274
177EE TANGUT IDEOGRAPH-#177EE, TGT_MergedSrc=L2008-1855
177EF TANGUT IDEOGRAPH-#177EF, TGT_MergedSrc=L2008-0876
177F0 TANGUT IDEOGRAPH-#177F0, TGT_MergedSrc=L2008-1701
177F1 TANGUT IDEOGRAPH-#177F1, TGT_MergedSrc=L2008-0748
177F2 TANGUT IDEOGRAPH-#177F2, TGT_MergedSrc=L2008-1014
177F3 TANGUT IDEOGRAPH-#177F3, TGT_MergedSrc=L2008-0226
177F4 TANGUT IDEOGRAPH-#177F4, TGT_MergedSrc=L2008-0652
177F5 TANGUT IDEOGRAPH-#177F5, TGT_MergedSrc=L2008-0167
177F6 TANGUT IDEOGRAPH-#177F6, TGT_MergedSrc=L2008-0481
177F7 TANGUT IDEOGRAPH-#177F7, TGT_MergedSrc=L2008-0168
177F8 TANGUT IDEOGRAPH-#177F8, TGT_MergedSrc=L2008-1847
177F9 TANGUT IDEOGRAPH-#177F9, TGT_MergedSrc=L2008-1591
177FA TANGUT IDEOGRAPH-#177FA, TGT_MergedSrc=L2008-1645
177FB TANGUT IDEOGRAPH-#177FB, TGT_MergedSrc=L2008-0749
177FC TANGUT IDEOGRAPH-#177FC, TGT_MergedSrc=L2008-0180
177FD TANGUT IDEOGRAPH-#177FD, TGT_MergedSrc=L2008-0227
177FE TANGUT IDEOGRAPH-#177FE, TGT_MergedSrc=L2008-1138
177FF TANGUT IDEOGRAPH-#177FF, TGT_MergedSrc=L2008-0850
17800 TANGUT IDEOGRAPH-#17800, TGT_MergedSrc=L2008-0506
17801 TANGUT IDEOGRAPH-#17801, TGT_MergedSrc=L2008-0206
17802 TANGUT IDEOGRAPH-#17802, TGT_MergedSrc=L2008-1614
17803 TANGUT IDEOGRAPH-#17803, TGT_MergedSrc=L2008-4603
17804 TANGUT IDEOGRAPH-#17804, TGT_MergedSrc=L2008-4586
17805 TANGUT IDEOGRAPH-#17805, TGT_MergedSrc=L2008-4596
17806 TANGUT IDEOGRAPH-#17806, TGT_MergedSrc=L2008-4530
17807 TANGUT IDEOGRAPH-#17807, TGT_MergedSrc=L2008-4508
17808 TANGUT IDEOGRAPH-#17808, TGT_MergedSrc=L2008-4547
17809 TANGUT IDEOGRAPH-#17809, TGT_MergedSrc=L2008-4543
1780A TANGUT IDEOGRAPH-#1780A, TGT_MergedSrc=L2008-4642
1780B TANGUT IDEOGRAPH-#1780B, TGT_MergedSrc=L2008-4621
1780C TANGUT IDEOGRAPH-#1780C, TGT_MergedSrc=L2008-4585
1780D TANGUT IDEOGRAPH-#1780D, TGT_MergedSrc=L2008-4580
1780E TANGUT IDEOGRAPH-#1780E, TGT_MergedSrc=L2008-4509
1780F TANGUT IDEOGRAPH-#1780F, TGT_MergedSrc=L2008-4608
17810 TANGUT IDEOGRAPH-#17810, TGT_MergedSrc=L2008-4551
17811 TANGUT IDEOGRAPH-#17811, TGT_MergedSrc=L2008-4552
17812 TANGUT IDEOGRAPH-#17812, TGT_MergedSrc=L2008-4511
17813 TANGUT IDEOGRAPH-#17813, TGT_MergedSrc=L2008-4563
17814 TANGUT IDEOGRAPH-#17814, TGT_MergedSrc=L2008-4568
17815 TANGUT IDEOGRAPH-#17815, TGT_MergedSrc=L2008-4649
17816 TANGUT IDEOGRAPH-#17816, TGT_MergedSrc=L2008-4643
17817 TANGUT IDEOGRAPH-#17817, TGT_MergedSrc=L2008-4635
17818 TANGUT IDEOGRAPH-#17818, TGT_MergedSrc=L2008-4668
17819 TANGUT IDEOGRAPH-#17819, TGT_MergedSrc=L2008-4650
1781A TANGUT IDEOGRAPH-#1781A, TGT_MergedSrc=L2008-4604
1781B TANGUT IDEOGRAPH-#1781B, TGT_MergedSrc=L2008-4617
1781C TANGUT IDEOGRAPH-#1781C, TGT_MergedSrc=L2008-4519
1781D TANGUT IDEOGRAPH-#1781D, TGT_MergedSrc=L2008-4541
1781E TANGUT IDEOGRAPH-#1781E, TGT_MergedSrc=L2008-4572
1781F TANGUT IDEOGRAPH-#1781F, TGT_MergedSrc=L2008-4571
17820 TANGUT IDEOGRAPH-#17820, TGT_MergedSrc=L2008-4644
17821 TANGUT IDEOGRAPH-#17821, TGT_MergedSrc=L2008-4669
17822 TANGUT IDEOGRAPH-#17822, TGT_MergedSrc=L2008-4636
17823 TANGUT IDEOGRAPH-#17823, TGT_MergedSrc=L2008-4667
17824 TANGUT IDEOGRAPH-#17824, TGT_MergedSrc=L2008-4581
17825 TANGUT IDEOGRAPH-#17825, TGT_MergedSrc=L2008-4651
17826 TANGUT IDEOGRAPH-#17826, TGT_MergedSrc=L2008-4582
17827 TANGUT IDEOGRAPH-#17827, TGT_MergedSrc=L2008-4589
17828 TANGUT IDEOGRAPH-#17828, TGT_MergedSrc=L2008-4545
17829 TANGUT IDEOGRAPH-#17829, TGT_MergedSrc=L2008-4542
1782A TANGUT IDEOGRAPH-#1782A, TGT_MergedSrc=L2008-4520
1782B TANGUT IDEOGRAPH-#1782B, TGT_MergedSrc=L2008-4534
1782C TANGUT IDEOGRAPH-#1782C, TGT_MergedSrc=L2008-4514
1782D TANGUT IDEOGRAPH-#1782D, TGT_MergedSrc=L2008-4533
1782E TANGUT IDEOGRAPH-#1782E, TGT_MergedSrc=L2008-4611
1782F TANGUT IDEOGRAPH-#1782F, TGT_MergedSrc=L2008-4653
17830 TANGUT IDEOGRAPH-#17830, TGT_MergedSrc=L2008-4658
17831 TANGUT IDEOGRAPH-#17831, TGT_MergedSrc=L2008-4657
17832 TANGUT IDEOGRAPH-#17832, TGT_MergedSrc=L2008-4583
17833 TANGUT IDEOGRAPH-#17833, TGT_MergedSrc=L2008-4606
17834 TANGUT IDEOGRAPH-#17834, TGT_MergedSrc=L2008-4623
17835 TANGUT IDEOGRAPH-#17835, TGT_MergedSrc=L2008-4532
17836 TANGUT IDEOGRAPH-#17836, TGT_MergedSrc=L2008-4638
17837 TANGUT IDEOGRAPH-#17837, TGT_MergedSrc=L2008-4592
17838 TANGUT IDEOGRAPH-#17838, TGT_MergedSrc=L2008-4612
17839 TANGUT IDEOGRAPH-#17839, TGT_MergedSrc=L2008-4584
1783A TANGUT IDEOGRAPH-#1783A, TGT_MergedSrc=L2008-4605
1783B TANGUT IDEOGRAPH-#1783B, TGT_MergedSrc=L2008-4597
1783C TANGUT IDEOGRAPH-#1783C, TGT_MergedSrc=L2008-4616
1783D TANGUT IDEOGRAPH-#1783D, TGT_MergedSrc=L2008-4613
1783E TANGUT IDEOGRAPH-#1783E, TGT_MergedSrc=L2008-4615
1783F TANGUT IDEOGRAPH-#1783F, TGT_MergedSrc=L2008-4564
17840 TANGUT IDEOGRAPH-#17840, TGT_MergedSrc=L2008-4553
17841 TANGUT IDEOGRAPH-#17841, TGT_MergedSrc=L2008-4619
17842 TANGUT IDEOGRAPH-#17842, TGT_MergedSrc=L2008-4618
17843 TANGUT IDEOGRAPH-#17843, TGT_MergedSrc=L2008-4523
17844 TANGUT IDEOGRAPH-#17844, TGT_MergedSrc=L2008-4513
17845 TANGUT IDEOGRAPH-#17845, TGT_MergedSrc=L2008-4517
17846 TANGUT IDEOGRAPH-#17846, TGT_MergedSrc=L2008-4652
17847 TANGUT IDEOGRAPH-#17847, TGT_MergedSrc=L2008-4610
17848 TANGUT IDEOGRAPH-#17848, TGT_MergedSrc=L2008-4521
17849 TANGUT IDEOGRAPH-#17849, TGT_MergedSrc=L2008-4535
1784A TANGUT IDEOGRAPH-#1784A, TGT_MergedSrc=L2008-4540
1784B TANGUT IDEOGRAPH-#1784B, TGT_MergedSrc=L2008-4593
1784C TANGUT IDEOGRAPH-#1784C, TGT_MergedSrc=N1966-255-107
1784D TANGUT IDEOGRAPH-#1784D, TGT_MergedSrc=L2008-4622
1784E TANGUT IDEOGRAPH-#1784E, TGT_MergedSrc=L2008-4518
1784F TANGUT IDEOGRAPH-#1784F, TGT_MergedSrc=L2008-4576
17850 TANGUT IDEOGRAPH-#17850, TGT_MergedSrc=L2008-4512
17851 TANGUT IDEOGRAPH-#17851, TGT_MergedSrc=L2008-4577
17852 TANGUT IDEOGRAPH-#17852, TGT_MergedSrc=L2008-4598
17853 TANGUT IDEOGRAPH-#17853, TGT_MergedSrc=L2008-4656
17854 TANGUT IDEOGRAPH-#17854, TGT_MergedSrc=L2008-4600
17855 TANGUT IDEOGRAPH-#17855, TGT_MergedSrc=L2008-4614
17856 TANGUT IDEOGRAPH-#17856, TGT_MergedSrc=L2008-4599
17857 TANGUT IDEOGRAPH-#17857, TGT_MergedSrc=L2008-4546
17858 TANGUT IDEOGRAPH-#17858, TGT_MergedSrc=L2008-4639
17859 TANGUT IDEOGRAPH-#17859, TGT_MergedSrc=L2008-4531
1785A TANGUT IDEOGRAPH-#1785A, TGT_MergedSrc=L2008-4569
1785B TANGUT IDEOGRAPH-#1785B, TGT_MergedSrc=L2008-4647
1785C TANGUT IDEOGRAPH-#1785C, TGT_MergedSrc=L2008-4637
1785D TANGUT IDEOGRAPH-#1785D, TGT_MergedSrc=L2008-4620
1785E TANGUT IDEOGRAPH-#1785E, TGT_MergedSrc=L2008-0359
1785F TANGUT IDEOGRAPH-#1785F, TGT_MergedSrc=L2008-0534
17860 TANGUT IDEOGRAPH-#17860, TGT_MergedSrc=L2008-0271
17861 TANGUT IDEOGRAPH-#17861, TGT_MergedSrc=L2008-0320
17862 TANGUT IDEOGRAPH-#17862, TGT_MergedSrc=L2008-0702
17863 TANGUT IDEOGRAPH-#17863, TGT_MergedSrc=L2008-0293
17864 TANGUT IDEOGRAPH-#17864, TGT_MergedSrc=L2008-1780
17865 TANGUT IDEOGRAPH-#17865, TGT_MergedSrc=L2008-1877
17866 TANGUT IDEOGRAPH-#17866, TGT_MergedSrc=L2008-0592
17867 TANGUT IDEOGRAPH-#17867, TGT_MergedSrc=L2008-0703
17868 TANGUT IDEOGRAPH-#17868, TGT_MergedSrc=L2008-0561
17869 TANGUT IDEOGRAPH-#17869, TGT_MergedSrc=L2008-1353
1786A TANGUT IDEOGRAPH-#1786A, TGT_MergedSrc=L2008-1290
1786B TANGUT IDEOGRAPH-#1786B, TGT_MergedSrc=L2008-0778
1786C TANGUT IDEOGRAPH-#1786C, TGT_MergedSrc=L2008-0340
1786D TANGUT IDEOGRAPH-#1786D, TGT_MergedSrc=L2008-0347
1786E TANGUT IDEOGRAPH-#1786E, TGT_MergedSrc=L2008-0541
1786F TANGUT IDEOGRAPH-#1786F, TGT_MergedSrc=L2008-0302
17870 TANGUT IDEOGRAPH-#17870, TGT_MergedSrc=L2008-0357
17871 TANGUT IDEOGRAPH-#17871, TGT_MergedSrc=L2008-1871
17872 TANGUT IDEOGRAPH-#17872, TGT_MergedSrc=L1997-5996
17873 TANGUT IDEOGRAPH-#17873, TGT_MergedSrc=L2008-0272
17874 TANGUT IDEOGRAPH-#17874, TGT_MergedSrc=L2008-0807
17875 TANGUT IDEOGRAPH-#17875, TGT_MergedSrc=L2008-1316
17876 TANGUT IDEOGRAPH-#17876, TGT_MergedSrc=L2008-0535
17877 TANGUT IDEOGRAPH-#17877, TGT_MergedSrc=L2008-1214
17878 TANGUT IDEOGRAPH-#17878, TGT_MergedSrc=L2008-0243
17879 TANGUT IDEOGRAPH-#17879, TGT_MergedSrc=L2008-1392
1787A TANGUT IDEOGRAPH-#1787A, TGT_MergedSrc=L2008-2928
1787B TANGUT IDEOGRAPH-#1787B, TGT_MergedSrc=L2008-3499
1787C TANGUT IDEOGRAPH-#1787C, TGT_MergedSrc=L2008-2705
1787D TANGUT IDEOGRAPH-#1787D, TGT_MergedSrc=L2008-3495
1787E TANGUT IDEOGRAPH-#1787E, TGT_MergedSrc=L2008-2963
1787F TANGUT IDEOGRAPH-#1787F, TGT_MergedSrc=L2008-4021
17880 TANGUT IDEOGRAPH-#17880, TGT_MergedSrc=L2008-4045
17881 TANGUT IDEOGRAPH-#17881, TGT_MergedSrc=L2008-3453
17882 TANGUT IDEOGRAPH-#17882, TGT_MergedSrc=L2008-2824
17883 TANGUT IDEOGRAPH-#17883, TGT_MergedSrc=L2008-2961
17884 TANGUT IDEOGRAPH-#17884, TGT_MergedSrc=L2008-4609
17885 TANGUT IDEOGRAPH-#17885, TGT_MergedSrc=L2008-4525
17886 TANGUT IDEOGRAPH-#17886, TGT_MergedSrc=L2008-2840-4591
17887 TANGUT IDEOGRAPH-#17887, TGT_MergedSrc=L2008-4594
17888 TANGUT IDEOGRAPH-#17888, TGT_MergedSrc=L2008-4037
17889 TANGUT IDEOGRAPH-#17889, TGT_MergedSrc=L2008-4084
1788A TANGUT IDEOGRAPH-#1788A, TGT_MergedSrc=L2008-4044
1788B TANGUT IDEOGRAPH-#1788B, TGT_MergedSrc=L2008-4057
1788C TANGUT IDEOGRAPH-#1788C, TGT_MergedSrc=L2008-4019
1788D TANGUT IDEOGRAPH-#1788D, TGT_MergedSrc=L2008-4020
1788E TANGUT IDEOGRAPH-#1788E, TGT_MergedSrc=L2008-3029
1788F TANGUT IDEOGRAPH-#1788F, TGT_MergedSrc=L2008-3072
17890 TANGUT IDEOGRAPH-#17890, TGT_MergedSrc=L2008-3044
17891 TANGUT IDEOGRAPH-#17891, TGT_MergedSrc=L2008-2844
17892 TANGUT IDEOGRAPH-#17892, TGT_MergedSrc=L2008-3076
17893 TANGUT IDEOGRAPH-#17893, TGT_MergedSrc=L2008-2026
17894 TANGUT IDEOGRAPH-#17894, TGT_MergedSrc=L2008-2051
17895 TANGUT IDEOGRAPH-#17895, TGT_MergedSrc=L2008-3545
17896 TANGUT IDEOGRAPH-#17896, TGT_MergedSrc=L2008-2721
17897 TANGUT IDEOGRAPH-#17897, TGT_MergedSrc=L2008-2420
17898 TANGUT IDEOGRAPH-#17898, TGT_MergedSrc=L2008-2048
17899 TANGUT IDEOGRAPH-#17899, TGT_MergedSrc=L2008-3778
1789A TANGUT IDEOGRAPH-#1789A, TGT_MergedSrc=L2008-3054
1789B TANGUT IDEOGRAPH-#1789B, TGT_MergedSrc=L2008-3003
1789C TANGUT IDEOGRAPH-#1789C, TGT_MergedSrc=L2008-2728
1789D TANGUT IDEOGRAPH-#1789D, TGT_MergedSrc=L2008-3446
1789E TANGUT IDEOGRAPH-#1789E, TGT_MergedSrc=L2008-2398
1789F TANGUT IDEOGRAPH-#1789F, TGT_MergedSrc=L2008-2001
178A0 TANGUT IDEOGRAPH-#178A0, TGT_MergedSrc=L2008-2002
178A1 TANGUT IDEOGRAPH-#178A1, TGT_MergedSrc=L2008-2578
178A2 TANGUT IDEOGRAPH-#178A2, TGT_MergedSrc=L2008-2848
178A3 TANGUT IDEOGRAPH-#178A3, TGT_MergedSrc=L2008-2003
178A4 TANGUT IDEOGRAPH-#178A4, TGT_MergedSrc=L2008-2592
178A5 TANGUT IDEOGRAPH-#178A5, TGT_MergedSrc=L2008-2406
178A6 TANGUT IDEOGRAPH-#178A6, TGT_MergedSrc=L2008-3526
178A7 TANGUT IDEOGRAPH-#178A7, TGT_MergedSrc=L2008-2057
178A8 TANGUT IDEOGRAPH-#178A8, TGT_MergedSrc=L2008-1886
178A9 TANGUT IDEOGRAPH-#178A9, TGT_MergedSrc=L2008-3179
178AA TANGUT IDEOGRAPH-#178AA, TGT_MergedSrc=L2008-2228
178AB TANGUT IDEOGRAPH-#178AB, TGT_MergedSrc=L2008-2185
178AC TANGUT IDEOGRAPH-#178AC, TGT_MergedSrc=L2008-2063
178AD TANGUT IDEOGRAPH-#178AD, TGT_MergedSrc=L2008-3113
178AE TANGUT IDEOGRAPH-#178AE, TGT_MergedSrc=L2008-3178
178AF TANGUT IDEOGRAPH-#178AF, TGT_MergedSrc=L2008-3190
178B0 TANGUT IDEOGRAPH-#178B0, TGT_MergedSrc=L2008-3274
178B1 TANGUT IDEOGRAPH-#178B1, TGT_MergedSrc=L2008-3237
178B2 TANGUT IDEOGRAPH-#178B2, TGT_MergedSrc=L2008-3261
178B3 TANGUT IDEOGRAPH-#178B3, TGT_MergedSrc=L2008-2852
178B4 TANGUT IDEOGRAPH-#178B4, TGT_MergedSrc=L2008-2187
178B5 TANGUT IDEOGRAPH-#178B5, TGT_MergedSrc=L2008-2064
178B6 TANGUT IDEOGRAPH-#178B6, TGT_MergedSrc=L2008-2263
178B7 TANGUT IDEOGRAPH-#178B7, TGT_MergedSrc=L2008-2193
178B8 TANGUT IDEOGRAPH-#178B8, TGT_MergedSrc=L2008-2246
178B9 TANGUT IDEOGRAPH-#178B9, TGT_MergedSrc=L2008-3167
178BA TANGUT IDEOGRAPH-#178BA, TGT_MergedSrc=L2008-2458
178BB TANGUT IDEOGRAPH-#178BB, TGT_MergedSrc=L2008-2641
178BC TANGUT IDEOGRAPH-#178BC, TGT_MergedSrc=L2008-3180
178BD TANGUT IDEOGRAPH-#178BD, TGT_MergedSrc=L2008-3181
178BE TANGUT IDEOGRAPH-#178BE, TGT_MergedSrc=L2008-2602
178BF TANGUT IDEOGRAPH-#178BF, TGT_MergedSrc=L2008-3619
178C0 TANGUT IDEOGRAPH-#178C0, TGT_MergedSrc=L2008-3639
178C1 TANGUT IDEOGRAPH-#178C1, TGT_MergedSrc=L2008-3191
178C2 TANGUT IDEOGRAPH-#178C2, TGT_MergedSrc=L2008-3114
178C3 TANGUT IDEOGRAPH-#178C3, TGT_MergedSrc=L2008-3195
178C4 TANGUT IDEOGRAPH-#178C4, TGT_MergedSrc=L2008-3275
178C5 TANGUT IDEOGRAPH-#178C5, TGT_MergedSrc=L2008-3797
178C6 TANGUT IDEOGRAPH-#178C6, TGT_MergedSrc=L2008-3277
178C7 TANGUT IDEOGRAPH-#178C7, TGT_MergedSrc=L2008-3389
178C8 TANGUT IDEOGRAPH-#178C8, TGT_MergedSrc=L2008-2797
178C9 TANGUT IDEOGRAPH-#178C9, TGT_MergedSrc=L2008-3192
178CA TANGUT IDEOGRAPH-#178CA, TGT_MergedSrc=L2008-2065
178CB TANGUT IDEOGRAPH-#178CB, TGT_MergedSrc=L2008-2178
178CC TANGUT IDEOGRAPH-#178CC, TGT_MergedSrc=L2008-3174
178CD TANGUT IDEOGRAPH-#178CD, TGT_MergedSrc=L2008-2211
178CE TANGUT IDEOGRAPH-#178CE, TGT_MergedSrc=L2008-3217
178CF TANGUT IDEOGRAPH-#178CF, TGT_MergedSrc=L2008-2229
178D0 TANGUT IDEOGRAPH-#178D0, TGT_MergedSrc=L2008-2746
178D1 TANGUT IDEOGRAPH-#178D1, TGT_MergedSrc=L2008-2284
178D2 TANGUT IDEOGRAPH-#178D2, TGT_MergedSrc=L2008-2290
178D3 TANGUT IDEOGRAPH-#178D3, TGT_MergedSrc=L2008-2144
178D4 TANGUT IDEOGRAPH-#178D4, TGT_MergedSrc=L2008-2247
178D5 TANGUT IDEOGRAPH-#178D5, TGT_MergedSrc=L2008-2230
178D6 TANGUT IDEOGRAPH-#178D6, TGT_MergedSrc=L2008-2183
178D7 TANGUT IDEOGRAPH-#178D7, TGT_MergedSrc=L2008-2184
178D8 TANGUT IDEOGRAPH-#178D8, TGT_MergedSrc=L2008-2188
178D9 TANGUT IDEOGRAPH-#178D9, TGT_MergedSrc=L2008-2294
178DA TANGUT IDEOGRAPH-#178DA, TGT_MergedSrc=L2008-2066
178DB TANGUT IDEOGRAPH-#178DB, TGT_MergedSrc=L2008-2074
178DC TANGUT IDEOGRAPH-#178DC, TGT_MergedSrc=L2008-2173
178DD TANGUT IDEOGRAPH-#178DD, TGT_MergedSrc=L2008-2206
178DE TANGUT IDEOGRAPH-#178DE, TGT_MergedSrc=L2008-2464
178DF TANGUT IDEOGRAPH-#178DF, TGT_MergedSrc=L2008-3630
178E0 TANGUT IDEOGRAPH-#178E0, TGT_MergedSrc=L2008-2073
178E1 TANGUT IDEOGRAPH-#178E1, TGT_MergedSrc=L2008-3115
178E2 TANGUT IDEOGRAPH-#178E2, TGT_MergedSrc=L2008-2490
178E3 TANGUT IDEOGRAPH-#178E3, TGT_MergedSrc=L2008-3278
178E4 TANGUT IDEOGRAPH-#178E4, TGT_MergedSrc=L2008-2642
178E5 TANGUT IDEOGRAPH-#178E5, TGT_MergedSrc=L2008-2616
178E6 TANGUT IDEOGRAPH-#178E6, TGT_MergedSrc=L2008-2603
178E7 TANGUT IDEOGRAPH-#178E7, TGT_MergedSrc=L2008-2640
178E8 TANGUT IDEOGRAPH-#178E8, TGT_MergedSrc=L2008-3620
178E9 TANGUT IDEOGRAPH-#178E9, TGT_MergedSrc=L2008-3640
178EA TANGUT IDEOGRAPH-#178EA, TGT_MergedSrc=L2008-3142
178EB TANGUT IDEOGRAPH-#178EB, TGT_MergedSrc=L2008-3798
178EC TANGUT IDEOGRAPH-#178EC, TGT_MergedSrc=L2008-3621
178ED TANGUT IDEOGRAPH-#178ED, TGT_MergedSrc=L2008-3193
178EE TANGUT IDEOGRAPH-#178EE, TGT_MergedSrc=L2008-3238
178EF TANGUT IDEOGRAPH-#178EF, TGT_MergedSrc=L2008-3208
178F0 TANGUT IDEOGRAPH-#178F0, TGT_MergedSrc=L2008-3276
178F1 TANGUT IDEOGRAPH-#178F1, TGT_MergedSrc=L2008-2854
178F2 TANGUT IDEOGRAPH-#178F2, TGT_MergedSrc=L2008-3784
178F3 TANGUT IDEOGRAPH-#178F3, TGT_MergedSrc=L2008-3365
178F4 TANGUT IDEOGRAPH-#178F4, TGT_MergedSrc=L2008-3804
178F5 TANGUT IDEOGRAPH-#178F5, TGT_MergedSrc=L2008-3366
178F6 TANGUT IDEOGRAPH-#178F6, TGT_MergedSrc=L2008-3279
178F7 TANGUT IDEOGRAPH-#178F7, TGT_MergedSrc=L2008-3194
178F8 TANGUT IDEOGRAPH-#178F8, TGT_MergedSrc=L2008-2448
178F9 TANGUT IDEOGRAPH-#178F9, TGT_MergedSrc=L2008-3120
178FA TANGUT IDEOGRAPH-#178FA, TGT_MergedSrc=L2008-2088
178FB TANGUT IDEOGRAPH-#178FB, TGT_MergedSrc=L2008-2190
178FC TANGUT IDEOGRAPH-#178FC, TGT_MergedSrc=L2008-2748
178FD TANGUT IDEOGRAPH-#178FD, TGT_MergedSrc=L2008-2089
178FE TANGUT IDEOGRAPH-#178FE, TGT_MergedSrc=L2008-2215
178FF TANGUT IDEOGRAPH-#178FF, TGT_MergedSrc=L2008-2783
17900 TANGUT IDEOGRAPH-#17900, TGT_MergedSrc=L2008-3139
17901 TANGUT IDEOGRAPH-#17901, TGT_MergedSrc=L2008-3200
17902 TANGUT IDEOGRAPH-#17902, TGT_MergedSrc=L2008-3201
17903 TANGUT IDEOGRAPH-#17903, TGT_MergedSrc=L2008-2189
17904 TANGUT IDEOGRAPH-#17904, TGT_MergedSrc=L2008-2082
17905 TANGUT IDEOGRAPH-#17905, TGT_MergedSrc=L2008-2201
17906 TANGUT IDEOGRAPH-#17906, TGT_MergedSrc=L2008-2214
17907 TANGUT IDEOGRAPH-#17907, TGT_MergedSrc=L2008-2775
17908 TANGUT IDEOGRAPH-#17908, TGT_MergedSrc=L2008-2295
17909 TANGUT IDEOGRAPH-#17909, TGT_MergedSrc=L2008-2075
1790A TANGUT IDEOGRAPH-#1790A, TGT_MergedSrc=L2008-2629
1790B TANGUT IDEOGRAPH-#1790B, TGT_MergedSrc=L2008-2194
1790C TANGUT IDEOGRAPH-#1790C, TGT_MergedSrc=L2008-2196
1790D TANGUT IDEOGRAPH-#1790D, TGT_MergedSrc=L2008-2473
1790E TANGUT IDEOGRAPH-#1790E, TGT_MergedSrc=L2008-2661
1790F TANGUT IDEOGRAPH-#1790F, TGT_MergedSrc=L2008-2609
17910 TANGUT IDEOGRAPH-#17910, TGT_MergedSrc=L2008-2650
17911 TANGUT IDEOGRAPH-#17911, TGT_MergedSrc=L2008-3210
17912 TANGUT IDEOGRAPH-#17912, TGT_MergedSrc=L2008-3305
17913 TANGUT IDEOGRAPH-#17913, TGT_MergedSrc=L2008-3228
17914 TANGUT IDEOGRAPH-#17914, TGT_MergedSrc=L2008-3306
17915 TANGUT IDEOGRAPH-#17915, TGT_MergedSrc=L2008-2469
17916 TANGUT IDEOGRAPH-#17916, TGT_MergedSrc=L2008-2216
17917 TANGUT IDEOGRAPH-#17917, TGT_MergedSrc=L1997-5998
17918 TANGUT IDEOGRAPH-#17918, TGT_MergedSrc=L2008-3182
17919 TANGUT IDEOGRAPH-#17919, TGT_MergedSrc=L2008-2645
1791A TANGUT IDEOGRAPH-#1791A, TGT_MergedSrc=L2008-3241
1791B TANGUT IDEOGRAPH-#1791B, TGT_MergedSrc=L2008-2649
1791C TANGUT IDEOGRAPH-#1791C, TGT_MergedSrc=L2008-2688
1791D TANGUT IDEOGRAPH-#1791D, TGT_MergedSrc=L2008-2749
1791E TANGUT IDEOGRAPH-#1791E, TGT_MergedSrc=L2008-2643
1791F TANGUT IDEOGRAPH-#1791F, TGT_MergedSrc=L2008-3641
17920 TANGUT IDEOGRAPH-#17920, TGT_MergedSrc=L2008-3691
17921 TANGUT IDEOGRAPH-#17921, TGT_MergedSrc=L2008-3590
17922 TANGUT IDEOGRAPH-#17922, TGT_MergedSrc=L2008-3791
17923 TANGUT IDEOGRAPH-#17923, TGT_MergedSrc=L2008-3569
17924 TANGUT IDEOGRAPH-#17924, TGT_MergedSrc=L2008-3565
17925 TANGUT IDEOGRAPH-#17925, TGT_MergedSrc=L2008-3787
17926 TANGUT IDEOGRAPH-#17926, TGT_MergedSrc=L2008-3676
17927 TANGUT IDEOGRAPH-#17927, TGT_MergedSrc=L2008-3805
17928 TANGUT IDEOGRAPH-#17928, TGT_MergedSrc=L2008-3570
17929 TANGUT IDEOGRAPH-#17929, TGT_MergedSrc=L2008-3628
1792A TANGUT IDEOGRAPH-#1792A, TGT_MergedSrc=L2008-2777
1792B TANGUT IDEOGRAPH-#1792B, TGT_MergedSrc=L2008-3622
1792C TANGUT IDEOGRAPH-#1792C, TGT_MergedSrc=L2008-3591
1792D TANGUT IDEOGRAPH-#1792D, TGT_MergedSrc=L2008-3128
1792E TANGUT IDEOGRAPH-#1792E, TGT_MergedSrc=L2008-3360
1792F TANGUT IDEOGRAPH-#1792F, TGT_MergedSrc=L2008-3173
17930 TANGUT IDEOGRAPH-#17930, TGT_MergedSrc=L2008-2739
17931 TANGUT IDEOGRAPH-#17931, TGT_MergedSrc=L2008-3248
17932 TANGUT IDEOGRAPH-#17932, TGT_MergedSrc=L2008-3250
17933 TANGUT IDEOGRAPH-#17933, TGT_MergedSrc=L2008-2888
17934 TANGUT IDEOGRAPH-#17934, TGT_MergedSrc=L2008-3207
17935 TANGUT IDEOGRAPH-#17935, TGT_MergedSrc=L2008-2176
17936 TANGUT IDEOGRAPH-#17936, TGT_MergedSrc=L2008-2518
17937 TANGUT IDEOGRAPH-#17937, TGT_MergedSrc=L2008-3614
17938 TANGUT IDEOGRAPH-#17938, TGT_MergedSrc=L2008-2197
17939 TANGUT IDEOGRAPH-#17939, TGT_MergedSrc=L2008-3121
1793A TANGUT IDEOGRAPH-#1793A, TGT_MergedSrc=L2008-2466
1793B TANGUT IDEOGRAPH-#1793B, TGT_MergedSrc=L2008-2467
1793C TANGUT IDEOGRAPH-#1793C, TGT_MergedSrc=L2008-2491
1793D TANGUT IDEOGRAPH-#1793D, TGT_MergedSrc=L2008-2617
1793E TANGUT IDEOGRAPH-#1793E, TGT_MergedSrc=L2008-2447
1793F TANGUT IDEOGRAPH-#1793F, TGT_MergedSrc=L2008-2127
17940 TANGUT IDEOGRAPH-#17940, TGT_MergedSrc=L2008-2225
17941 TANGUT IDEOGRAPH-#17941, TGT_MergedSrc=L2008-2118
17942 TANGUT IDEOGRAPH-#17942, TGT_MergedSrc=L2008-3215
17943 TANGUT IDEOGRAPH-#17943, TGT_MergedSrc=L2008-2205
17944 TANGUT IDEOGRAPH-#17944, TGT_MergedSrc=L2008-2630
17945 TANGUT IDEOGRAPH-#17945, TGT_MergedSrc=L2008-2610
17946 TANGUT IDEOGRAPH-#17946, TGT_MergedSrc=L2008-3631
17947 TANGUT IDEOGRAPH-#17947, TGT_MergedSrc=L2008-3212
17948 TANGUT IDEOGRAPH-#17948, TGT_MergedSrc=L2008-3258
17949 TANGUT IDEOGRAPH-#17949, TGT_MergedSrc=L2008-2747
1794A TANGUT IDEOGRAPH-#1794A, TGT_MergedSrc=L2008-2203
1794B TANGUT IDEOGRAPH-#1794B, TGT_MergedSrc=L2008-2128
1794C TANGUT IDEOGRAPH-#1794C, TGT_MergedSrc=L2008-2231
1794D TANGUT IDEOGRAPH-#1794D, TGT_MergedSrc=L2008-2296
1794E TANGUT IDEOGRAPH-#1794E, TGT_MergedSrc=L2008-2212
1794F TANGUT IDEOGRAPH-#1794F, TGT_MergedSrc=L2008-2250
17950 TANGUT IDEOGRAPH-#17950, TGT_MergedSrc=L2008-2611
17951 TANGUT IDEOGRAPH-#17951, TGT_MergedSrc=L2008-3118
17952 TANGUT IDEOGRAPH-#17952, TGT_MergedSrc=L2008-2195
17953 TANGUT IDEOGRAPH-#17953, TGT_MergedSrc=L2008-2857
17954 TANGUT IDEOGRAPH-#17954, TGT_MergedSrc=L2008-2753
17955 TANGUT IDEOGRAPH-#17955, TGT_MergedSrc=L2008-3782
17956 TANGUT IDEOGRAPH-#17956, TGT_MergedSrc=L2008-3679
17957 TANGUT IDEOGRAPH-#17957, TGT_MergedSrc=L2008-3234
17958 TANGUT IDEOGRAPH-#17958, TGT_MergedSrc=L2008-3222
17959 TANGUT IDEOGRAPH-#17959, TGT_MergedSrc=L2008-3214
1795A TANGUT IDEOGRAPH-#1795A, TGT_MergedSrc=L2008-3281
1795B TANGUT IDEOGRAPH-#1795B, TGT_MergedSrc=L2008-2778
1795C TANGUT IDEOGRAPH-#1795C, TGT_MergedSrc=L2008-2606
1795D TANGUT IDEOGRAPH-#1795D, TGT_MergedSrc=L2008-2637
1795E TANGUT IDEOGRAPH-#1795E, TGT_MergedSrc=L2008-2776
1795F TANGUT IDEOGRAPH-#1795F, TGT_MergedSrc=L2008-2604
17960 TANGUT IDEOGRAPH-#17960, TGT_MergedSrc=L2008-2638
17961 TANGUT IDEOGRAPH-#17961, TGT_MergedSrc=L2008-3566
17962 TANGUT IDEOGRAPH-#17962, TGT_MergedSrc=L2008-3636
17963 TANGUT IDEOGRAPH-#17963, TGT_MergedSrc=L2008-3788
17964 TANGUT IDEOGRAPH-#17964, TGT_MergedSrc=L2008-3574
17965 TANGUT IDEOGRAPH-#17965, TGT_MergedSrc=L2008-3677
17966 TANGUT IDEOGRAPH-#17966, TGT_MergedSrc=L2008-2750
17967 TANGUT IDEOGRAPH-#17967, TGT_MergedSrc=L2008-3643
17968 TANGUT IDEOGRAPH-#17968, TGT_MergedSrc=L2008-2784
17969 TANGUT IDEOGRAPH-#17969, TGT_MergedSrc=L2008-3216
1796A TANGUT IDEOGRAPH-#1796A, TGT_MergedSrc=L2008-3796
1796B TANGUT IDEOGRAPH-#1796B, TGT_MergedSrc=L2008-3807
1796C TANGUT IDEOGRAPH-#1796C, TGT_MergedSrc=L2008-3623
1796D TANGUT IDEOGRAPH-#1796D, TGT_MergedSrc=L2008-3716
1796E TANGUT IDEOGRAPH-#1796E, TGT_MergedSrc=L2008-2150
1796F TANGUT IDEOGRAPH-#1796F, TGT_MergedSrc=L2008-3146
17970 TANGUT IDEOGRAPH-#17970, TGT_MergedSrc=L2008-3284
17971 TANGUT IDEOGRAPH-#17971, TGT_MergedSrc=L2008-3157
17972 TANGUT IDEOGRAPH-#17972, TGT_MergedSrc=L2008-2095
17973 TANGUT IDEOGRAPH-#17973, TGT_MergedSrc=L2008-2752
17974 TANGUT IDEOGRAPH-#17974, TGT_MergedSrc=L2008-3262
17975 TANGUT IDEOGRAPH-#17975, TGT_MergedSrc=L2008-3341
17976 TANGUT IDEOGRAPH-#17976, TGT_MergedSrc=L2008-2682
17977 TANGUT IDEOGRAPH-#17977, TGT_MergedSrc=L2008-3282
17978 TANGUT IDEOGRAPH-#17978, TGT_MergedSrc=L2008-3388
17979 TANGUT IDEOGRAPH-#17979, TGT_MergedSrc=L2008-2770
1797A TANGUT IDEOGRAPH-#1797A, TGT_MergedSrc=L2008-3229
1797B TANGUT IDEOGRAPH-#1797B, TGT_MergedSrc=L2008-2771
1797C TANGUT IDEOGRAPH-#1797C, TGT_MergedSrc=L2008-3654
1797D TANGUT IDEOGRAPH-#1797D, TGT_MergedSrc=L2008-2803
1797E TANGUT IDEOGRAPH-#1797E, TGT_MergedSrc=L2008-2779
1797F TANGUT IDEOGRAPH-#1797F, TGT_MergedSrc=L2008-3280
17980 TANGUT IDEOGRAPH-#17980, TGT_MergedSrc=L2008-2224
17981 TANGUT IDEOGRAPH-#17981, TGT_MergedSrc=L2008-2516
17982 TANGUT IDEOGRAPH-#17982, TGT_MergedSrc=L2008-3259
17983 TANGUT IDEOGRAPH-#17983, TGT_MergedSrc=L2008-3617
17984 TANGUT IDEOGRAPH-#17984, TGT_MergedSrc=L2008-3710
17985 TANGUT IDEOGRAPH-#17985, TGT_MergedSrc=L2008-2802
17986 TANGUT IDEOGRAPH-#17986, TGT_MergedSrc=L2008-3213
17987 TANGUT IDEOGRAPH-#17987, TGT_MergedSrc=L2008-2090
17988 TANGUT IDEOGRAPH-#17988, TGT_MergedSrc=L2008-2510
17989 TANGUT IDEOGRAPH-#17989, TGT_MergedSrc=L2008-2129
1798A TANGUT IDEOGRAPH-#1798A, TGT_MergedSrc=L2008-2232
1798B TANGUT IDEOGRAPH-#1798B, TGT_MergedSrc=L2008-3307
1798C TANGUT IDEOGRAPH-#1798C, TGT_MergedSrc=L2008-3330
1798D TANGUT IDEOGRAPH-#1798D, TGT_MergedSrc=L2008-3693
1798E TANGUT IDEOGRAPH-#1798E, TGT_MergedSrc=L2008-2474
1798F TANGUT IDEOGRAPH-#1798F, TGT_MergedSrc=L2008-2662
17990 TANGUT IDEOGRAPH-#17990, TGT_MergedSrc=L2008-2233
17991 TANGUT IDEOGRAPH-#17991, TGT_MergedSrc=L2008-2504
17992 TANGUT IDEOGRAPH-#17992, TGT_MergedSrc=L2008-3158
17993 TANGUT IDEOGRAPH-#17993, TGT_MergedSrc=L2008-2876
17994 TANGUT IDEOGRAPH-#17994, TGT_MergedSrc=L2008-2874
17995 TANGUT IDEOGRAPH-#17995, TGT_MergedSrc=L2008-2486
17996 TANGUT IDEOGRAPH-#17996, TGT_MergedSrc=L2008-3130
17997 TANGUT IDEOGRAPH-#17997, TGT_MergedSrc=L2008-2670
17998 TANGUT IDEOGRAPH-#17998, TGT_MergedSrc=L2008-2626
17999 TANGUT IDEOGRAPH-#17999, TGT_MergedSrc=L2008-3580
1799A TANGUT IDEOGRAPH-#1799A, TGT_MergedSrc=L2008-2853
1799B TANGUT IDEOGRAPH-#1799B, TGT_MergedSrc=L2008-3353
1799C TANGUT IDEOGRAPH-#1799C, TGT_MergedSrc=L2008-3211
1799D TANGUT IDEOGRAPH-#1799D, TGT_MergedSrc=L2008-2202
1799E TANGUT IDEOGRAPH-#1799E, TGT_MergedSrc=L2008-2663
1799F TANGUT IDEOGRAPH-#1799F, TGT_MergedSrc=L2008-2884
179A0 TANGUT IDEOGRAPH-#179A0, TGT_MergedSrc=L2008-2740
179A1 TANGUT IDEOGRAPH-#179A1, TGT_MergedSrc=L2008-2234
179A2 TANGUT IDEOGRAPH-#179A2, TGT_MergedSrc=L2008-2492
179A3 TANGUT IDEOGRAPH-#179A3, TGT_MergedSrc=L2008-2083
179A4 TANGUT IDEOGRAPH-#179A4, TGT_MergedSrc=L2008-2493
179A5 TANGUT IDEOGRAPH-#179A5, TGT_MergedSrc=L2008-2117
179A6 TANGUT IDEOGRAPH-#179A6, TGT_MergedSrc=L2008-2249
179A7 TANGUT IDEOGRAPH-#179A7, TGT_MergedSrc=L2008-2291
179A8 TANGUT IDEOGRAPH-#179A8, TGT_MergedSrc=L2008-2119
179A9 TANGUT IDEOGRAPH-#179A9, TGT_MergedSrc=L2008-2257
179AA TANGUT IDEOGRAPH-#179AA, TGT_MergedSrc=L2008-2084
179AB TANGUT IDEOGRAPH-#179AB, TGT_MergedSrc=L2008-3316
179AC TANGUT IDEOGRAPH-#179AC, TGT_MergedSrc=L2008-3370
179AD TANGUT IDEOGRAPH-#179AD, TGT_MergedSrc=L2008-2686
179AE TANGUT IDEOGRAPH-#179AE, TGT_MergedSrc=L2008-3789
179AF TANGUT IDEOGRAPH-#179AF, TGT_MergedSrc=L2008-2751
179B0 TANGUT IDEOGRAPH-#179B0, TGT_MergedSrc=L2008-2120
179B1 TANGUT IDEOGRAPH-#179B1, TGT_MergedSrc=L2008-3680
179B2 TANGUT IDEOGRAPH-#179B2, TGT_MergedSrc=L2008-2618
179B3 TANGUT IDEOGRAPH-#179B3, TGT_MergedSrc=L2008-3266
179B4 TANGUT IDEOGRAPH-#179B4, TGT_MergedSrc=L2008-3333
179B5 TANGUT IDEOGRAPH-#179B5, TGT_MergedSrc=L2008-2177
179B6 TANGUT IDEOGRAPH-#179B6, TGT_MergedSrc=L2008-2468
179B7 TANGUT IDEOGRAPH-#179B7, TGT_MergedSrc=L2008-2452
179B8 TANGUT IDEOGRAPH-#179B8, TGT_MergedSrc=L2008-2631
179B9 TANGUT IDEOGRAPH-#179B9, TGT_MergedSrc=L2008-2625
179BA TANGUT IDEOGRAPH-#179BA, TGT_MergedSrc=L2008-2651
179BB TANGUT IDEOGRAPH-#179BB, TGT_MergedSrc=L2008-2639
179BC TANGUT IDEOGRAPH-#179BC, TGT_MergedSrc=L2008-2644
179BD TANGUT IDEOGRAPH-#179BD, TGT_MergedSrc=L2008-3618
179BE TANGUT IDEOGRAPH-#179BE, TGT_MergedSrc=L2008-3606
179BF TANGUT IDEOGRAPH-#179BF, TGT_MergedSrc=L2008-3803
179C0 TANGUT IDEOGRAPH-#179C0, TGT_MergedSrc=L2008-3317
179C1 TANGUT IDEOGRAPH-#179C1, TGT_MergedSrc=L2008-3202
179C2 TANGUT IDEOGRAPH-#179C2, TGT_MergedSrc=S1968-3624
179C3 TANGUT IDEOGRAPH-#179C3, TGT_MergedSrc=L2008-3717
179C4 TANGUT IDEOGRAPH-#179C4, TGT_MergedSrc=L1997-5999
179C5 TANGUT IDEOGRAPH-#179C5, TGT_MergedSrc=L2008-3592
179C6 TANGUT IDEOGRAPH-#179C6, TGT_MergedSrc=L2008-3659
179C7 TANGUT IDEOGRAPH-#179C7, TGT_MergedSrc=L2008-2755
179C8 TANGUT IDEOGRAPH-#179C8, TGT_MergedSrc=L2008-2125
179C9 TANGUT IDEOGRAPH-#179C9, TGT_MergedSrc=L2008-3644
179CA TANGUT IDEOGRAPH-#179CA, TGT_MergedSrc=L2008-3678
179CB TANGUT IDEOGRAPH-#179CB, TGT_MergedSrc=L2008-2133
179CC TANGUT IDEOGRAPH-#179CC, TGT_MergedSrc=L2008-3285
179CD TANGUT IDEOGRAPH-#179CD, TGT_MergedSrc=L2008-3265
179CE TANGUT IDEOGRAPH-#179CE, TGT_MergedSrc=L2008-3361
179CF TANGUT IDEOGRAPH-#179CF, TGT_MergedSrc=L2008-2754
179D0 TANGUT IDEOGRAPH-#179D0, TGT_MergedSrc=L2008-2162
179D1 TANGUT IDEOGRAPH-#179D1, TGT_MergedSrc=L2008-2475
179D2 TANGUT IDEOGRAPH-#179D2, TGT_MergedSrc=L2008-3143
179D3 TANGUT IDEOGRAPH-#179D3, TGT_MergedSrc=L2008-2098
179D4 TANGUT IDEOGRAPH-#179D4, TGT_MergedSrc=L2008-3198
179D5 TANGUT IDEOGRAPH-#179D5, TGT_MergedSrc=L2008-3283
179D6 TANGUT IDEOGRAPH-#179D6, TGT_MergedSrc=L2008-3239
179D7 TANGUT IDEOGRAPH-#179D7, TGT_MergedSrc=L2008-3268
179D8 TANGUT IDEOGRAPH-#179D8, TGT_MergedSrc=L2008-3183
179D9 TANGUT IDEOGRAPH-#179D9, TGT_MergedSrc=L2008-3196
179DA TANGUT IDEOGRAPH-#179DA, TGT_MergedSrc=L2008-3270
179DB TANGUT IDEOGRAPH-#179DB, TGT_MergedSrc=L2008-3712
179DC TANGUT IDEOGRAPH-#179DC, TGT_MergedSrc=L2008-2801
179DD TANGUT IDEOGRAPH-#179DD, TGT_MergedSrc=L2008-2683
179DE TANGUT IDEOGRAPH-#179DE, TGT_MergedSrc=L2008-3615
179DF TANGUT IDEOGRAPH-#179DF, TGT_MergedSrc=L2008-3713
179E0 TANGUT IDEOGRAPH-#179E0, TGT_MergedSrc=L2008-3357
179E1 TANGUT IDEOGRAPH-#179E1, TGT_MergedSrc=L2008-3356
179E2 TANGUT IDEOGRAPH-#179E2, TGT_MergedSrc=L2008-2790
179E3 TANGUT IDEOGRAPH-#179E3, TGT_MergedSrc=L2008-3696
179E4 TANGUT IDEOGRAPH-#179E4, TGT_MergedSrc=L2008-3708
179E5 TANGUT IDEOGRAPH-#179E5, TGT_MergedSrc=L2008-2858
179E6 TANGUT IDEOGRAPH-#179E6, TGT_MergedSrc=L2008-2248
179E7 TANGUT IDEOGRAPH-#179E7, TGT_MergedSrc=L2008-3286A
179E8 TANGUT IDEOGRAPH-#179E8, TGT_MergedSrc=L2008-2743
179E9 TANGUT IDEOGRAPH-#179E9, TGT_MergedSrc=L2008-2870
179EA TANGUT IDEOGRAPH-#179EA, TGT_MergedSrc=L2008-2892
179EB TANGUT IDEOGRAPH-#179EB, TGT_MergedSrc=L2008-3634
179EC TANGUT IDEOGRAPH-#179EC, TGT_MergedSrc=L2008-2477
179ED TANGUT IDEOGRAPH-#179ED, TGT_MergedSrc=L2008-2235
179EE TANGUT IDEOGRAPH-#179EE, TGT_MergedSrc=L2008-3308
179EF TANGUT IDEOGRAPH-#179EF, TGT_MergedSrc=L2008-2135
179F0 TANGUT IDEOGRAPH-#179F0, TGT_MergedSrc=L2008-2478
179F1 TANGUT IDEOGRAPH-#179F1, TGT_MergedSrc=L2008-2453
179F2 TANGUT IDEOGRAPH-#179F2, TGT_MergedSrc=L2008-2093
179F3 TANGUT IDEOGRAPH-#179F3, TGT_MergedSrc=L2008-2672
179F4 TANGUT IDEOGRAPH-#179F4, TGT_MergedSrc=L2008-3383
179F5 TANGUT IDEOGRAPH-#179F5, TGT_MergedSrc=L2008-3131
179F6 TANGUT IDEOGRAPH-#179F6, TGT_MergedSrc=L2008-3627
179F7 TANGUT IDEOGRAPH-#179F7, TGT_MergedSrc=L2008-3781
179F8 TANGUT IDEOGRAPH-#179F8, TGT_MergedSrc=L2008-3124
179F9 TANGUT IDEOGRAPH-#179F9, TGT_MergedSrc=L2008-2444
179FA TANGUT IDEOGRAPH-#179FA, TGT_MergedSrc=L2008-2182
179FB TANGUT IDEOGRAPH-#179FB, TGT_MergedSrc=L2008-2282
179FC TANGUT IDEOGRAPH-#179FC, TGT_MergedSrc=L2008-3240
179FD TANGUT IDEOGRAPH-#179FD, TGT_MergedSrc=L2008-2496
179FE TANGUT IDEOGRAPH-#179FE, TGT_MergedSrc=L2008-3150
179FF TANGUT IDEOGRAPH-#179FF, TGT_MergedSrc=L2008-3376
17A00 TANGUT IDEOGRAPH-#17A00, TGT_MergedSrc=L2008-2652
17A01 TANGUT IDEOGRAPH-#17A01, TGT_MergedSrc=L2008-2612
17A02 TANGUT IDEOGRAPH-#17A02, TGT_MergedSrc=L2008-3685
17A03 TANGUT IDEOGRAPH-#17A03, TGT_MergedSrc=L2008-2633
17A04 TANGUT IDEOGRAPH-#17A04, TGT_MergedSrc=L2008-2132
17A05 TANGUT IDEOGRAPH-#17A05, TGT_MergedSrc=L2008-2619
17A06 TANGUT IDEOGRAPH-#17A06, TGT_MergedSrc=L2008-2623
17A07 TANGUT IDEOGRAPH-#17A07, TGT_MergedSrc=L2008-3780
17A08 TANGUT IDEOGRAPH-#17A08, TGT_MergedSrc=L2008-2756
17A09 TANGUT IDEOGRAPH-#17A09, TGT_MergedSrc=L2008-3575
17A0A TANGUT IDEOGRAPH-#17A0A, TGT_MergedSrc=L2008-3582
17A0B TANGUT IDEOGRAPH-#17A0B, TGT_MergedSrc=L2008-2096
17A0C TANGUT IDEOGRAPH-#17A0C, TGT_MergedSrc=L2008-3129
17A0D TANGUT IDEOGRAPH-#17A0D, TGT_MergedSrc=L2008-2476
17A0E TANGUT IDEOGRAPH-#17A0E, TGT_MergedSrc=L2008-2613
17A0F TANGUT IDEOGRAPH-#17A0F, TGT_MergedSrc=L2008-3663
17A10 TANGUT IDEOGRAPH-#17A10, TGT_MergedSrc=L2008-3624
17A11 TANGUT IDEOGRAPH-#17A11, TGT_MergedSrc=L2008-6044
17A12 TANGUT IDEOGRAPH-#17A12, TGT_MergedSrc=L2008-2097
17A13 TANGUT IDEOGRAPH-#17A13, TGT_MergedSrc=L2008-2100
17A14 TANGUT IDEOGRAPH-#17A14, TGT_MergedSrc=L2008-2123
17A15 TANGUT IDEOGRAPH-#17A15, TGT_MergedSrc=L2008-3783
17A16 TANGUT IDEOGRAPH-#17A16, TGT_MergedSrc=L2008-3144
17A17 TANGUT IDEOGRAPH-#17A17, TGT_MergedSrc=L2008-3595
17A18 TANGUT IDEOGRAPH-#17A18, TGT_MergedSrc=L2008-3660
17A19 TANGUT IDEOGRAPH-#17A19, TGT_MergedSrc=L2008-3159
17A1A TANGUT IDEOGRAPH-#17A1A, TGT_MergedSrc=L2008-3662
17A1B TANGUT IDEOGRAPH-#17A1B, TGT_MergedSrc=L2008-2511
17A1C TANGUT IDEOGRAPH-#17A1C, TGT_MergedSrc=L2008-2664
17A1D TANGUT IDEOGRAPH-#17A1D, TGT_MergedSrc=L2008-3249
17A1E TANGUT IDEOGRAPH-#17A1E, TGT_MergedSrc=L2008-3230
17A1F TANGUT IDEOGRAPH-#17A1F, TGT_MergedSrc=L2008-2494
17A20 TANGUT IDEOGRAPH-#17A20, TGT_MergedSrc=L2008-3147
17A21 TANGUT IDEOGRAPH-#17A21, TGT_MergedSrc=L2008-3116
17A22 TANGUT IDEOGRAPH-#17A22, TGT_MergedSrc=L2008-3286B
17A23 TANGUT IDEOGRAPH-#17A23, TGT_MergedSrc=L2008-2624
17A24 TANGUT IDEOGRAPH-#17A24, TGT_MergedSrc=L2008-2179
17A25 TANGUT IDEOGRAPH-#17A25, TGT_MergedSrc=L2008-3106
17A26 TANGUT IDEOGRAPH-#17A26, TGT_MergedSrc=L2008-3381
17A27 TANGUT IDEOGRAPH-#17A27, TGT_MergedSrc=L2008-3154
17A28 TANGUT IDEOGRAPH-#17A28, TGT_MergedSrc=L2008-2757
17A29 TANGUT IDEOGRAPH-#17A29, TGT_MergedSrc=L2008-3219
17A2A TANGUT IDEOGRAPH-#17A2A, TGT_MergedSrc=L2008-3263
17A2B TANGUT IDEOGRAPH-#17A2B, TGT_MergedSrc=L2008-3197
17A2C TANGUT IDEOGRAPH-#17A2C, TGT_MergedSrc=L2008-3287
17A2D TANGUT IDEOGRAPH-#17A2D, TGT_MergedSrc=L2008-3105
17A2E TANGUT IDEOGRAPH-#17A2E, TGT_MergedSrc=L2008-3235
17A2F TANGUT IDEOGRAPH-#17A2F, TGT_MergedSrc=L2008-3267
17A30 TANGUT IDEOGRAPH-#17A30, TGT_MergedSrc=L2008-2497
17A31 TANGUT IDEOGRAPH-#17A31, TGT_MergedSrc=L2008-3656
17A32 TANGUT IDEOGRAPH-#17A32, TGT_MergedSrc=L2008-3260
17A33 TANGUT IDEOGRAPH-#17A33, TGT_MergedSrc=L2008-3175
17A34 TANGUT IDEOGRAPH-#17A34, TGT_MergedSrc=L2008-2204
17A35 TANGUT IDEOGRAPH-#17A35, TGT_MergedSrc=L2008-2607
17A36 TANGUT IDEOGRAPH-#17A36, TGT_MergedSrc=L2008-3117
17A37 TANGUT IDEOGRAPH-#17A37, TGT_MergedSrc=L2008-2236
17A38 TANGUT IDEOGRAPH-#17A38, TGT_MergedSrc=L2008-2217
17A39 TANGUT IDEOGRAPH-#17A39, TGT_MergedSrc=L2008-2092
17A3A TANGUT IDEOGRAPH-#17A3A, TGT_MergedSrc=L2008-2076
17A3B TANGUT IDEOGRAPH-#17A3B, TGT_MergedSrc=L2008-2226
17A3C TANGUT IDEOGRAPH-#17A3C, TGT_MergedSrc=L2008-2130
17A3D TANGUT IDEOGRAPH-#17A3D, TGT_MergedSrc=L2008-6045
17A3E TANGUT IDEOGRAPH-#17A3E, TGT_MergedSrc=L2008-3598
17A3F TANGUT IDEOGRAPH-#17A3F, TGT_MergedSrc=L2008-3218
17A40 TANGUT IDEOGRAPH-#17A40, TGT_MergedSrc=L2008-3302
17A41 TANGUT IDEOGRAPH-#17A41, TGT_MergedSrc=L2008-2878
17A42 TANGUT IDEOGRAPH-#17A42, TGT_MergedSrc=L2008-2286
17A43 TANGUT IDEOGRAPH-#17A43, TGT_MergedSrc=L2008-2875
17A44 TANGUT IDEOGRAPH-#17A44, TGT_MergedSrc=L2008-2860
17A45 TANGUT IDEOGRAPH-#17A45, TGT_MergedSrc=L2008-2869
17A46 TANGUT IDEOGRAPH-#17A46, TGT_MergedSrc=L2008-2882
17A47 TANGUT IDEOGRAPH-#17A47, TGT_MergedSrc=L2008-2872
17A48 TANGUT IDEOGRAPH-#17A48, TGT_MergedSrc=L2008-2805
17A49 TANGUT IDEOGRAPH-#17A49, TGT_MergedSrc=L2008-3236
17A4A TANGUT IDEOGRAPH-#17A4A, TGT_MergedSrc=L2008-3681
17A4B TANGUT IDEOGRAPH-#17A4B, TGT_MergedSrc=L2008-3682
17A4C TANGUT IDEOGRAPH-#17A4C, TGT_MergedSrc=L2008-2680
17A4D TANGUT IDEOGRAPH-#17A4D, TGT_MergedSrc=L2008-2221-2807
17A4E TANGUT IDEOGRAPH-#17A4E, TGT_MergedSrc=L2008-2785
17A4F TANGUT IDEOGRAPH-#17A4F, TGT_MergedSrc=L2008-3343
17A50 TANGUT IDEOGRAPH-#17A50, TGT_MergedSrc=L2008-2108
17A51 TANGUT IDEOGRAPH-#17A51, TGT_MergedSrc=L2008-2109
17A52 TANGUT IDEOGRAPH-#17A52, TGT_MergedSrc=L2008-3132
17A53 TANGUT IDEOGRAPH-#17A53, TGT_MergedSrc=L2008-3637
17A54 TANGUT IDEOGRAPH-#17A54, TGT_MergedSrc=L2008-2665
17A55 TANGUT IDEOGRAPH-#17A55, TGT_MergedSrc=L2008-2112
17A56 TANGUT IDEOGRAPH-#17A56, TGT_MergedSrc=L2008-3148
17A57 TANGUT IDEOGRAPH-#17A57, TGT_MergedSrc=L2008-3714
17A58 TANGUT IDEOGRAPH-#17A58, TGT_MergedSrc=L2008-2099
17A59 TANGUT IDEOGRAPH-#17A59, TGT_MergedSrc=L2008-2667
17A5A TANGUT IDEOGRAPH-#17A5A, TGT_MergedSrc=L2008-2495
17A5B TANGUT IDEOGRAPH-#17A5B, TGT_MergedSrc=L2008-3646
17A5C TANGUT IDEOGRAPH-#17A5C, TGT_MergedSrc=L2008-3611
17A5D TANGUT IDEOGRAPH-#17A5D, TGT_MergedSrc=L2008-2653
17A5E TANGUT IDEOGRAPH-#17A5E, TGT_MergedSrc=L2008-2666
17A5F TANGUT IDEOGRAPH-#17A5F, TGT_MergedSrc=L2008-3318
17A60 TANGUT IDEOGRAPH-#17A60, TGT_MergedSrc=L2008-3319
17A61 TANGUT IDEOGRAPH-#17A61, TGT_MergedSrc=L2008-3593
17A62 TANGUT IDEOGRAPH-#17A62, TGT_MergedSrc=L2008-3586
17A63 TANGUT IDEOGRAPH-#17A63, TGT_MergedSrc=L2008-2684
17A64 TANGUT IDEOGRAPH-#17A64, TGT_MergedSrc=L2008-2102
17A65 TANGUT IDEOGRAPH-#17A65, TGT_MergedSrc=L2008-3367
17A66 TANGUT IDEOGRAPH-#17A66, TGT_MergedSrc=L2008-3661
17A67 TANGUT IDEOGRAPH-#17A67, TGT_MergedSrc=L2008-2163
17A68 TANGUT IDEOGRAPH-#17A68, TGT_MergedSrc=L2008-3315
17A69 TANGUT IDEOGRAPH-#17A69, TGT_MergedSrc=L2008-3135
17A6A TANGUT IDEOGRAPH-#17A6A, TGT_MergedSrc=L2008-2859
17A6B TANGUT IDEOGRAPH-#17A6B, TGT_MergedSrc=L2008-3168
17A6C TANGUT IDEOGRAPH-#17A6C, TGT_MergedSrc=L2008-3702
17A6D TANGUT IDEOGRAPH-#17A6D, TGT_MergedSrc=L2008-2105
17A6E TANGUT IDEOGRAPH-#17A6E, TGT_MergedSrc=L2008-2110
17A6F TANGUT IDEOGRAPH-#17A6F, TGT_MergedSrc=L2008-3576
17A70 TANGUT IDEOGRAPH-#17A70, TGT_MergedSrc=L2008-3687
17A71 TANGUT IDEOGRAPH-#17A71, TGT_MergedSrc=L2008-2620
17A72 TANGUT IDEOGRAPH-#17A72, TGT_MergedSrc=L2008-3107
17A73 TANGUT IDEOGRAPH-#17A73, TGT_MergedSrc=L2008-3332
17A74 TANGUT IDEOGRAPH-#17A74, TGT_MergedSrc=L2008-2636
17A75 TANGUT IDEOGRAPH-#17A75, TGT_MergedSrc=L2008-3304
17A76 TANGUT IDEOGRAPH-#17A76, TGT_MergedSrc=L2008-3199
17A77 TANGUT IDEOGRAPH-#17A77, TGT_MergedSrc=L2008-3288
17A78 TANGUT IDEOGRAPH-#17A78, TGT_MergedSrc=L2008-3329
17A79 TANGUT IDEOGRAPH-#17A79, TGT_MergedSrc=L2008-3289
17A7A TANGUT IDEOGRAPH-#17A7A, TGT_MergedSrc=N1966-204-10GG
17A7B TANGUT IDEOGRAPH-#17A7B, TGT_MergedSrc=L2008-2222
17A7C TANGUT IDEOGRAPH-#17A7C, TGT_MergedSrc=L2008-2809
17A7D TANGUT IDEOGRAPH-#17A7D, TGT_MergedSrc=L2008-2113
17A7E TANGUT IDEOGRAPH-#17A7E, TGT_MergedSrc=L2008-2091
17A7F TANGUT IDEOGRAPH-#17A7F, TGT_MergedSrc=L2008-2067
17A80 TANGUT IDEOGRAPH-#17A80, TGT_MergedSrc=L2008-2258
17A81 TANGUT IDEOGRAPH-#17A81, TGT_MergedSrc=L2008-2124
17A82 TANGUT IDEOGRAPH-#17A82, TGT_MergedSrc=L2008-2264
17A83 TANGUT IDEOGRAPH-#17A83, TGT_MergedSrc=L2008-2078
17A84 TANGUT IDEOGRAPH-#17A84, TGT_MergedSrc=L2008-2227
17A85 TANGUT IDEOGRAPH-#17A85, TGT_MergedSrc=L2008-2292
17A86 TANGUT IDEOGRAPH-#17A86, TGT_MergedSrc=L2008-2164
17A87 TANGUT IDEOGRAPH-#17A87, TGT_MergedSrc=L2008-3331
17A88 TANGUT IDEOGRAPH-#17A88, TGT_MergedSrc=L2008-2481
17A89 TANGUT IDEOGRAPH-#17A89, TGT_MergedSrc=L2008-2134
17A8A TANGUT IDEOGRAPH-#17A8A, TGT_MergedSrc=L2008-3697
17A8B TANGUT IDEOGRAPH-#17A8B, TGT_MergedSrc=L2008-2647
17A8C TANGUT IDEOGRAPH-#17A8C, TGT_MergedSrc=L2008-3674
17A8D TANGUT IDEOGRAPH-#17A8D, TGT_MergedSrc=L2008-2251
17A8E TANGUT IDEOGRAPH-#17A8E, TGT_MergedSrc=L2008-2905
17A8F TANGUT IDEOGRAPH-#17A8F, TGT_MergedSrc=L2008-2864
17A90 TANGUT IDEOGRAPH-#17A90, TGT_MergedSrc=L2008-2867
17A91 TANGUT IDEOGRAPH-#17A91, TGT_MergedSrc=L2008-3629
17A92 TANGUT IDEOGRAPH-#17A92, TGT_MergedSrc=L2008-3372
17A93 TANGUT IDEOGRAPH-#17A93, TGT_MergedSrc=L2008-3232
17A94 TANGUT IDEOGRAPH-#17A94, TGT_MergedSrc=L2008-2515
17A95 TANGUT IDEOGRAPH-#17A95, TGT_MergedSrc=L2008-3577
17A96 TANGUT IDEOGRAPH-#17A96, TGT_MergedSrc=L2008-3384
17A97 TANGUT IDEOGRAPH-#17A97, TGT_MergedSrc=L2008-2660
17A98 TANGUT IDEOGRAPH-#17A98, TGT_MergedSrc=L2008-2104
17A99 TANGUT IDEOGRAPH-#17A99, TGT_MergedSrc=L2008-2764
17A9A TANGUT IDEOGRAPH-#17A9A, TGT_MergedSrc=L2008-2865
17A9B TANGUT IDEOGRAPH-#17A9B, TGT_MergedSrc=L2008-2634
17A9C TANGUT IDEOGRAPH-#17A9C, TGT_MergedSrc=L2008-2479
17A9D TANGUT IDEOGRAPH-#17A9D, TGT_MergedSrc=L2008-2487
17A9E TANGUT IDEOGRAPH-#17A9E, TGT_MergedSrc=L2008-2514
17A9F TANGUT IDEOGRAPH-#17A9F, TGT_MergedSrc=L2008-2103
17AA0 TANGUT IDEOGRAPH-#17AA0, TGT_MergedSrc=L2008-2763
17AA1 TANGUT IDEOGRAPH-#17AA1, TGT_MergedSrc=L2008-3686
17AA2 TANGUT IDEOGRAPH-#17AA2, TGT_MergedSrc=L2008-3371
17AA3 TANGUT IDEOGRAPH-#17AA3, TGT_MergedSrc=L2008-3220
17AA4 TANGUT IDEOGRAPH-#17AA4, TGT_MergedSrc=L2008-3326
17AA5 TANGUT IDEOGRAPH-#17AA5, TGT_MergedSrc=L2008-3145
17AA6 TANGUT IDEOGRAPH-#17AA6, TGT_MergedSrc=L2008-3587
17AA7 TANGUT IDEOGRAPH-#17AA7, TGT_MergedSrc=L2008-3616
17AA8 TANGUT IDEOGRAPH-#17AA8, TGT_MergedSrc=L2008-2259
17AA9 TANGUT IDEOGRAPH-#17AA9, TGT_MergedSrc=L2008-2866
17AAA TANGUT IDEOGRAPH-#17AAA, TGT_MergedSrc=L2008-3581
17AAB TANGUT IDEOGRAPH-#17AAB, TGT_MergedSrc=L2008-3578
17AAC TANGUT IDEOGRAPH-#17AAC, TGT_MergedSrc=L2008-2111
17AAD TANGUT IDEOGRAPH-#17AAD, TGT_MergedSrc=L2008-2151
17AAE TANGUT IDEOGRAPH-#17AAE, TGT_MergedSrc=L2008-3599
17AAF TANGUT IDEOGRAPH-#17AAF, TGT_MergedSrc=L2008-2455
17AB0 TANGUT IDEOGRAPH-#17AB0, TGT_MergedSrc=L2008-3141
17AB1 TANGUT IDEOGRAPH-#17AB1, TGT_MergedSrc=L2008-3149
17AB2 TANGUT IDEOGRAPH-#17AB2, TGT_MergedSrc=L2008-3351
17AB3 TANGUT IDEOGRAPH-#17AB3, TGT_MergedSrc=L2008-3327
17AB4 TANGUT IDEOGRAPH-#17AB4, TGT_MergedSrc=L2008-3134
17AB5 TANGUT IDEOGRAPH-#17AB5, TGT_MergedSrc=L2008-2275
17AB6 TANGUT IDEOGRAPH-#17AB6, TGT_MergedSrc=L2008-6027
17AB7 TANGUT IDEOGRAPH-#17AB7, TGT_MergedSrc=L2008-3345
17AB8 TANGUT IDEOGRAPH-#17AB8, TGT_MergedSrc=L2008-3638
17AB9 TANGUT IDEOGRAPH-#17AB9, TGT_MergedSrc=L2008-2879
17ABA TANGUT IDEOGRAPH-#17ABA, TGT_MergedSrc=L2008-3354
17ABB TANGUT IDEOGRAPH-#17ABB, TGT_MergedSrc=L2008-3151
17ABC TANGUT IDEOGRAPH-#17ABC, TGT_MergedSrc=L2008-3607
17ABD TANGUT IDEOGRAPH-#17ABD, TGT_MergedSrc=L2008-2101
17ABE TANGUT IDEOGRAPH-#17ABE, TGT_MergedSrc=L2008-2668
17ABF TANGUT IDEOGRAPH-#17ABF, TGT_MergedSrc=L2008-2614
17AC0 TANGUT IDEOGRAPH-#17AC0, TGT_MergedSrc=L2008-3221
17AC1 TANGUT IDEOGRAPH-#17AC1, TGT_MergedSrc=L2008-3596
17AC2 TANGUT IDEOGRAPH-#17AC2, TGT_MergedSrc=L2008-3583
17AC3 TANGUT IDEOGRAPH-#17AC3, TGT_MergedSrc=L2008-2885
17AC4 TANGUT IDEOGRAPH-#17AC4, TGT_MergedSrc=L2008-3711
17AC5 TANGUT IDEOGRAPH-#17AC5, TGT_MergedSrc=L2008-3588
17AC6 TANGUT IDEOGRAPH-#17AC6, TGT_MergedSrc=L2006-6054
17AC7 TANGUT IDEOGRAPH-#17AC7, TGT_MergedSrc=L2008-3176
17AC8 TANGUT IDEOGRAPH-#17AC8, TGT_MergedSrc=L2008-3133
17AC9 TANGUT IDEOGRAPH-#17AC9, TGT_MergedSrc=L2008-2480
17ACA TANGUT IDEOGRAPH-#17ACA, TGT_MergedSrc=L2008-3594
17ACB TANGUT IDEOGRAPH-#17ACB, TGT_MergedSrc=L2008-2136
17ACC TANGUT IDEOGRAPH-#17ACC, TGT_MergedSrc=L2008-2862
17ACD TANGUT IDEOGRAPH-#17ACD, TGT_MergedSrc=L2008-2152
17ACE TANGUT IDEOGRAPH-#17ACE, TGT_MergedSrc=L2008-3209
17ACF TANGUT IDEOGRAPH-#17ACF, TGT_MergedSrc=L2008-3368
17AD0 TANGUT IDEOGRAPH-#17AD0, TGT_MergedSrc=L2008-3342
17AD1 TANGUT IDEOGRAPH-#17AD1, TGT_MergedSrc=L2008-2786
17AD2 TANGUT IDEOGRAPH-#17AD2, TGT_MergedSrc=L2008-3385
17AD3 TANGUT IDEOGRAPH-#17AD3, TGT_MergedSrc=L2008-3386
17AD4 TANGUT IDEOGRAPH-#17AD4, TGT_MergedSrc=L2008-3119
17AD5 TANGUT IDEOGRAPH-#17AD5, TGT_MergedSrc=L2008-2131
17AD6 TANGUT IDEOGRAPH-#17AD6, TGT_MergedSrc=L2008-2094
17AD7 TANGUT IDEOGRAPH-#17AD7, TGT_MergedSrc=L2008-2883
17AD8 TANGUT IDEOGRAPH-#17AD8, TGT_MergedSrc=S1968-3449
17AD9 TANGUT IDEOGRAPH-#17AD9, TGT_MergedSrc=L2008-3355
17ADA TANGUT IDEOGRAPH-#17ADA, TGT_MergedSrc=L2008-2198
17ADB TANGUT IDEOGRAPH-#17ADB, TGT_MergedSrc=L2008-3123
17ADC TANGUT IDEOGRAPH-#17ADC, TGT_MergedSrc=L2008-3652
17ADD TANGUT IDEOGRAPH-#17ADD, TGT_MergedSrc=S1968-3641
17ADE TANGUT IDEOGRAPH-#17ADE, TGT_MergedSrc=L2008-2772
17ADF TANGUT IDEOGRAPH-#17ADF, TGT_MergedSrc=L2008-3163
17AE0 TANGUT IDEOGRAPH-#17AE0, TGT_MergedSrc=L2008-3688
17AE1 TANGUT IDEOGRAPH-#17AE1, TGT_MergedSrc=L2008-2679
17AE2 TANGUT IDEOGRAPH-#17AE2, TGT_MergedSrc=L2008-3692
17AE3 TANGUT IDEOGRAPH-#17AE3, TGT_MergedSrc=L2008-3172
17AE4 TANGUT IDEOGRAPH-#17AE4, TGT_MergedSrc=L2008-3252
17AE5 TANGUT IDEOGRAPH-#17AE5, TGT_MergedSrc=L2008-3231
17AE6 TANGUT IDEOGRAPH-#17AE6, TGT_MergedSrc=L2008-3320
17AE7 TANGUT IDEOGRAPH-#17AE7, TGT_MergedSrc=L2008-3715
17AE8 TANGUT IDEOGRAPH-#17AE8, TGT_MergedSrc=L2008-3613
17AE9 TANGUT IDEOGRAPH-#17AE9, TGT_MergedSrc=L2008-2180
17AEA TANGUT IDEOGRAPH-#17AEA, TGT_MergedSrc=N1966-204-13B
17AEB TANGUT IDEOGRAPH-#17AEB, TGT_MergedSrc=L2008-2245
17AEC TANGUT IDEOGRAPH-#17AEC, TGT_MergedSrc=L2008-2512
17AED TANGUT IDEOGRAPH-#17AED, TGT_MergedSrc=L2008-3140
17AEE TANGUT IDEOGRAPH-#17AEE, TGT_MergedSrc=L2008-3378
17AEF TANGUT IDEOGRAPH-#17AEF, TGT_MergedSrc=L2008-2265
17AF0 TANGUT IDEOGRAPH-#17AF0, TGT_MergedSrc=L2008-6041
17AF1 TANGUT IDEOGRAPH-#17AF1, TGT_MergedSrc=L2008-3091
17AF2 TANGUT IDEOGRAPH-#17AF2, TGT_MergedSrc=L2008-3094
17AF3 TANGUT IDEOGRAPH-#17AF3, TGT_MergedSrc=L2008-2435
17AF4 TANGUT IDEOGRAPH-#17AF4, TGT_MergedSrc=L2008-2436
17AF5 TANGUT IDEOGRAPH-#17AF5, TGT_MergedSrc=L2008-2601
17AF6 TANGUT IDEOGRAPH-#17AF6, TGT_MergedSrc=L2008-3092
17AF7 TANGUT IDEOGRAPH-#17AF7, TGT_MergedSrc=L2008-3093
17AF8 TANGUT IDEOGRAPH-#17AF8, TGT_MergedSrc=L2008-3101
17AF9 TANGUT IDEOGRAPH-#17AF9, TGT_MergedSrc=L2008-3559
17AFA TANGUT IDEOGRAPH-#17AFA, TGT_MergedSrc=L2008-3560
17AFB TANGUT IDEOGRAPH-#17AFB, TGT_MergedSrc=L2008-3099
17AFC TANGUT IDEOGRAPH-#17AFC, TGT_MergedSrc=L2008-2438
17AFD TANGUT IDEOGRAPH-#17AFD, TGT_MergedSrc=L2008-2437
17AFE TANGUT IDEOGRAPH-#17AFE, TGT_MergedSrc=L2008-3779
17AFF TANGUT IDEOGRAPH-#17AFF, TGT_MergedSrc=L2008-3096
17B00 TANGUT IDEOGRAPH-#17B00, TGT_MergedSrc=L2008-3095
17B01 TANGUT IDEOGRAPH-#17B01, TGT_MergedSrc=L2008-3098
17B02 TANGUT IDEOGRAPH-#17B02, TGT_MergedSrc=L2008-3561
17B03 TANGUT IDEOGRAPH-#17B03, TGT_MergedSrc=L2008-3100
17B04 TANGUT IDEOGRAPH-#17B04, TGT_MergedSrc=L2008-3097
17B05 TANGUT IDEOGRAPH-#17B05, TGT_MergedSrc=L2008-3562
17B06 TANGUT IDEOGRAPH-#17B06, TGT_MergedSrc=L2008-2439
17B07 TANGUT IDEOGRAPH-#17B07, TGT_MergedSrc=L2008-3102
17B08 TANGUT IDEOGRAPH-#17B08, TGT_MergedSrc=L2008-3103
17B09 TANGUT IDEOGRAPH-#17B09, TGT_MergedSrc=L2008-3563
17B0A TANGUT IDEOGRAPH-#17B0A, TGT_MergedSrc=L2008-3564
17B0B TANGUT IDEOGRAPH-#17B0B, TGT_MergedSrc=L2008-2062
17B0C TANGUT IDEOGRAPH-#17B0C, TGT_MergedSrc=L2008-1883
17B0D TANGUT IDEOGRAPH-#17B0D, TGT_MergedSrc=L2008-1889
17B0E TANGUT IDEOGRAPH-#17B0E, TGT_MergedSrc=L2008-2459
17B0F TANGUT IDEOGRAPH-#17B0F, TGT_MergedSrc=L2008-2465
17B10 TANGUT IDEOGRAPH-#17B10, TGT_MergedSrc=L2008-2460
17B11 TANGUT IDEOGRAPH-#17B11, TGT_MergedSrc=L2008-3664
17B12 TANGUT IDEOGRAPH-#17B12, TGT_MergedSrc=L2008-2646
17B13 TANGUT IDEOGRAPH-#17B13, TGT_MergedSrc=L2008-3642
17B14 TANGUT IDEOGRAPH-#17B14, TGT_MergedSrc=L2008-3665
17B15 TANGUT IDEOGRAPH-#17B15, TGT_MergedSrc=L2008-3597
17B16 TANGUT IDEOGRAPH-#17B16, TGT_MergedSrc=L2008-2425
17B17 TANGUT IDEOGRAPH-#17B17, TGT_MergedSrc=L2008-2039
17B18 TANGUT IDEOGRAPH-#17B18, TGT_MergedSrc=L2008-3189
17B19 TANGUT IDEOGRAPH-#17B19, TGT_MergedSrc=L2008-2172
17B1A TANGUT IDEOGRAPH-#17B1A, TGT_MergedSrc=L2008-3226
17B1B TANGUT IDEOGRAPH-#17B1B, TGT_MergedSrc=L2008-2457
17B1C TANGUT IDEOGRAPH-#17B1C, TGT_MergedSrc=L2008-3675
17B1D TANGUT IDEOGRAPH-#17B1D, TGT_MergedSrc=L2008-3786
17B1E TANGUT IDEOGRAPH-#17B1E, TGT_MergedSrc=L2008-3227
17B1F TANGUT IDEOGRAPH-#17B1F, TGT_MergedSrc=L2008-2745
17B20 TANGUT IDEOGRAPH-#17B20, TGT_MergedSrc=L2008-2126
17B21 TANGUT IDEOGRAPH-#17B21, TGT_MergedSrc=L2008-3364
17B22 TANGUT IDEOGRAPH-#17B22, TGT_MergedSrc=L2008-2472
17B23 TANGUT IDEOGRAPH-#17B23, TGT_MergedSrc=L2008-2306
17B24 TANGUT IDEOGRAPH-#17B24, TGT_MergedSrc=L2008-2315
17B25 TANGUT IDEOGRAPH-#17B25, TGT_MergedSrc=L2008-2532
17B26 TANGUT IDEOGRAPH-#17B26, TGT_MergedSrc=L2008-2308
17B27 TANGUT IDEOGRAPH-#17B27, TGT_MergedSrc=L2008-3405
17B28 TANGUT IDEOGRAPH-#17B28, TGT_MergedSrc=L2008-3403
17B29 TANGUT IDEOGRAPH-#17B29, TGT_MergedSrc=L2008-3740
17B2A TANGUT IDEOGRAPH-#17B2A, TGT_MergedSrc=L2008-2328
17B2B TANGUT IDEOGRAPH-#17B2B, TGT_MergedSrc=L2008-2533
17B2C TANGUT IDEOGRAPH-#17B2C, TGT_MergedSrc=L2008-2316
17B2D TANGUT IDEOGRAPH-#17B2D, TGT_MergedSrc=L2008-3745
17B2E TANGUT IDEOGRAPH-#17B2E, TGT_MergedSrc=L2008-3741
17B2F TANGUT IDEOGRAPH-#17B2F, TGT_MergedSrc=L2008-2317
17B30 TANGUT IDEOGRAPH-#17B30, TGT_MergedSrc=L2008-3746
17B31 TANGUT IDEOGRAPH-#17B31, TGT_MergedSrc=L2008-2318
17B32 TANGUT IDEOGRAPH-#17B32, TGT_MergedSrc=L2008-2897
17B33 TANGUT IDEOGRAPH-#17B33, TGT_MergedSrc=L2008-2312
17B34 TANGUT IDEOGRAPH-#17B34, TGT_MergedSrc=L2008-3421
17B35 TANGUT IDEOGRAPH-#17B35, TGT_MergedSrc=L2008-2329
17B36 TANGUT IDEOGRAPH-#17B36, TGT_MergedSrc=L2008-2307
17B37 TANGUT IDEOGRAPH-#17B37, TGT_MergedSrc=L2008-4770
17B38 TANGUT IDEOGRAPH-#17B38, TGT_MergedSrc=L2008-4765
17B39 TANGUT IDEOGRAPH-#17B39, TGT_MergedSrc=L2008-4756
17B3A TANGUT IDEOGRAPH-#17B3A, TGT_MergedSrc=L2008-4793
17B3B TANGUT IDEOGRAPH-#17B3B, TGT_MergedSrc=L2008-4748
17B3C TANGUT IDEOGRAPH-#17B3C, TGT_MergedSrc=L2008-4772
17B3D TANGUT IDEOGRAPH-#17B3D, TGT_MergedSrc=L2006-6006
17B3E TANGUT IDEOGRAPH-#17B3E, TGT_MergedSrc=L2008-4773
17B3F TANGUT IDEOGRAPH-#17B3F, TGT_MergedSrc=L2008-4771
17B40 TANGUT IDEOGRAPH-#17B40, TGT_MergedSrc=L2008-4749
17B41 TANGUT IDEOGRAPH-#17B41, TGT_MergedSrc=L2008-4747
17B42 TANGUT IDEOGRAPH-#17B42, TGT_MergedSrc=L2008-4782
17B43 TANGUT IDEOGRAPH-#17B43, TGT_MergedSrc=L2008-4774
17B44 TANGUT IDEOGRAPH-#17B44, TGT_MergedSrc=L2008-4757
17B45 TANGUT IDEOGRAPH-#17B45, TGT_MergedSrc=L2008-4742
17B46 TANGUT IDEOGRAPH-#17B46, TGT_MergedSrc=L2008-3842
17B47 TANGUT IDEOGRAPH-#17B47, TGT_MergedSrc=L2008-3861
17B48 TANGUT IDEOGRAPH-#17B48, TGT_MergedSrc=L2008-3845
17B49 TANGUT IDEOGRAPH-#17B49, TGT_MergedSrc=L2008-4012
17B4A TANGUT IDEOGRAPH-#17B4A, TGT_MergedSrc=L2008-3989
17B4B TANGUT IDEOGRAPH-#17B4B, TGT_MergedSrc=L2008-3963
17B4C TANGUT IDEOGRAPH-#17B4C, TGT_MergedSrc=L2008-3843
17B4D TANGUT IDEOGRAPH-#17B4D, TGT_MergedSrc=L2008-3844
17B4E TANGUT IDEOGRAPH-#17B4E, TGT_MergedSrc=L2008-4013
17B4F TANGUT IDEOGRAPH-#17B4F, TGT_MergedSrc=L2008-3857
17B50 TANGUT IDEOGRAPH-#17B50, TGT_MergedSrc=L2008-3908
17B51 TANGUT IDEOGRAPH-#17B51, TGT_MergedSrc=L2008-4010
17B52 TANGUT IDEOGRAPH-#17B52, TGT_MergedSrc=L2008-3990
17B53 TANGUT IDEOGRAPH-#17B53, TGT_MergedSrc=L2008-3860
17B54 TANGUT IDEOGRAPH-#17B54, TGT_MergedSrc=L2008-3945
17B55 TANGUT IDEOGRAPH-#17B55, TGT_MergedSrc=L2008-3944
17B56 TANGUT IDEOGRAPH-#17B56, TGT_MergedSrc=L2008-3994
17B57 TANGUT IDEOGRAPH-#17B57, TGT_MergedSrc=L2008-3959
17B58 TANGUT IDEOGRAPH-#17B58, TGT_MergedSrc=L2008-3964
17B59 TANGUT IDEOGRAPH-#17B59, TGT_MergedSrc=L2008-3863
17B5A TANGUT IDEOGRAPH-#17B5A, TGT_MergedSrc=L2008-3862
17B5B TANGUT IDEOGRAPH-#17B5B, TGT_MergedSrc=L2008-3924
17B5C TANGUT IDEOGRAPH-#17B5C, TGT_MergedSrc=L2008-3886
17B5D TANGUT IDEOGRAPH-#17B5D, TGT_MergedSrc=L2008-3943
17B5E TANGUT IDEOGRAPH-#17B5E, TGT_MergedSrc=L2008-3912
17B5F TANGUT IDEOGRAPH-#17B5F, TGT_MergedSrc=L2008-3885
17B60 TANGUT IDEOGRAPH-#17B60, TGT_MergedSrc=L2008-3991
17B61 TANGUT IDEOGRAPH-#17B61, TGT_MergedSrc=L2008-3848
17B62 TANGUT IDEOGRAPH-#17B62, TGT_MergedSrc=L2008-3922
17B63 TANGUT IDEOGRAPH-#17B63, TGT_MergedSrc=L2008-3961
17B64 TANGUT IDEOGRAPH-#17B64, TGT_MergedSrc=L2008-3856
17B65 TANGUT IDEOGRAPH-#17B65, TGT_MergedSrc=L2008-3855
17B66 TANGUT IDEOGRAPH-#17B66, TGT_MergedSrc=L2008-3930
17B67 TANGUT IDEOGRAPH-#17B67, TGT_MergedSrc=L2008-4009
17B68 TANGUT IDEOGRAPH-#17B68, TGT_MergedSrc=L2008-3931
17B69 TANGUT IDEOGRAPH-#17B69, TGT_MergedSrc=L2008-3979
17B6A TANGUT IDEOGRAPH-#17B6A, TGT_MergedSrc=L2008-3916
17B6B TANGUT IDEOGRAPH-#17B6B, TGT_MergedSrc=L2008-3870
17B6C TANGUT IDEOGRAPH-#17B6C, TGT_MergedSrc=L2008-3896
17B6D TANGUT IDEOGRAPH-#17B6D, TGT_MergedSrc=L2008-3988
17B6E TANGUT IDEOGRAPH-#17B6E, TGT_MergedSrc=L2008-5413
17B6F TANGUT IDEOGRAPH-#17B6F, TGT_MergedSrc=L2008-5471
17B70 TANGUT IDEOGRAPH-#17B70, TGT_MergedSrc=L1997-6000
17B71 TANGUT IDEOGRAPH-#17B71, TGT_MergedSrc=L2008-5557
17B72 TANGUT IDEOGRAPH-#17B72, TGT_MergedSrc=L2008-5295
17B73 TANGUT IDEOGRAPH-#17B73, TGT_MergedSrc=L2008-5716
17B74 TANGUT IDEOGRAPH-#17B74, TGT_MergedSrc=L2008-5087
17B75 TANGUT IDEOGRAPH-#17B75, TGT_MergedSrc=L2008-5133
17B76 TANGUT IDEOGRAPH-#17B76, TGT_MergedSrc=L2008-5256
17B77 TANGUT IDEOGRAPH-#17B77, TGT_MergedSrc=L2008-5095
17B78 TANGUT IDEOGRAPH-#17B78, TGT_MergedSrc=L2008-5805
17B79 TANGUT IDEOGRAPH-#17B79, TGT_MergedSrc=L2008-5528
17B7A TANGUT IDEOGRAPH-#17B7A, TGT_MergedSrc=L2008-5119
17B7B TANGUT IDEOGRAPH-#17B7B, TGT_MergedSrc=L2008-5522
17B7C TANGUT IDEOGRAPH-#17B7C, TGT_MergedSrc=L2008-5120
17B7D TANGUT IDEOGRAPH-#17B7D, TGT_MergedSrc=L2008-5283
17B7E TANGUT IDEOGRAPH-#17B7E, TGT_MergedSrc=L2008-5524
17B7F TANGUT IDEOGRAPH-#17B7F, TGT_MergedSrc=L2008-5112
17B80 TANGUT IDEOGRAPH-#17B80, TGT_MergedSrc=L2008-5415
17B81 TANGUT IDEOGRAPH-#17B81, TGT_MergedSrc=L2008-5532
17B82 TANGUT IDEOGRAPH-#17B82, TGT_MergedSrc=L2008-5421
17B83 TANGUT IDEOGRAPH-#17B83, TGT_MergedSrc=L2008-5084
17B84 TANGUT IDEOGRAPH-#17B84, TGT_MergedSrc=L2008-5066
17B85 TANGUT IDEOGRAPH-#17B85, TGT_MergedSrc=L2008-5414
17B86 TANGUT IDEOGRAPH-#17B86, TGT_MergedSrc=L2008-5710
17B87 TANGUT IDEOGRAPH-#17B87, TGT_MergedSrc=L2008-5115
17B88 TANGUT IDEOGRAPH-#17B88, TGT_MergedSrc=L2008-5547
17B89 TANGUT IDEOGRAPH-#17B89, TGT_MergedSrc=L2008-5293
17B8A TANGUT IDEOGRAPH-#17B8A, TGT_MergedSrc=L2008-5706
17B8B TANGUT IDEOGRAPH-#17B8B, TGT_MergedSrc=L2008-5114
17B8C TANGUT IDEOGRAPH-#17B8C, TGT_MergedSrc=L2008-5075
17B8D TANGUT IDEOGRAPH-#17B8D, TGT_MergedSrc=L2008-5260
17B8E TANGUT IDEOGRAPH-#17B8E, TGT_MergedSrc=L2008-5076
17B8F TANGUT IDEOGRAPH-#17B8F, TGT_MergedSrc=L2008-5351
17B90 TANGUT IDEOGRAPH-#17B90, TGT_MergedSrc=L2008-5150A
17B91 TANGUT IDEOGRAPH-#17B91, TGT_MergedSrc=L2008-5150B
17B92 TANGUT IDEOGRAPH-#17B92, TGT_MergedSrc=L2008-5077
17B93 TANGUT IDEOGRAPH-#17B93, TGT_MergedSrc=L2008-5291
17B94 TANGUT IDEOGRAPH-#17B94, TGT_MergedSrc=L2008-5692
17B95 TANGUT IDEOGRAPH-#17B95, TGT_MergedSrc=L2008-5078
17B96 TANGUT IDEOGRAPH-#17B96, TGT_MergedSrc=L2008-5529
17B97 TANGUT IDEOGRAPH-#17B97, TGT_MergedSrc=L2008-5496
17B98 TANGUT IDEOGRAPH-#17B98, TGT_MergedSrc=L2008-5546
17B99 TANGUT IDEOGRAPH-#17B99, TGT_MergedSrc=L2008-5530
17B9A TANGUT IDEOGRAPH-#17B9A, TGT_MergedSrc=L2008-5509
17B9B TANGUT IDEOGRAPH-#17B9B, TGT_MergedSrc=L2008-5511
17B9C TANGUT IDEOGRAPH-#17B9C, TGT_MergedSrc=L2008-5431
17B9D TANGUT IDEOGRAPH-#17B9D, TGT_MergedSrc=L2008-5359
17B9E TANGUT IDEOGRAPH-#17B9E, TGT_MergedSrc=L2008-5099
17B9F TANGUT IDEOGRAPH-#17B9F, TGT_MergedSrc=L2008-5100
17BA0 TANGUT IDEOGRAPH-#17BA0, TGT_MergedSrc=L2008-5271
17BA1 TANGUT IDEOGRAPH-#17BA1, TGT_MergedSrc=L2008-5510
17BA2 TANGUT IDEOGRAPH-#17BA2, TGT_MergedSrc=L2008-5519
17BA3 TANGUT IDEOGRAPH-#17BA3, TGT_MergedSrc=L2008-5432
17BA4 TANGUT IDEOGRAPH-#17BA4, TGT_MergedSrc=L2008-5268
17BA5 TANGUT IDEOGRAPH-#17BA5, TGT_MergedSrc=L2008-5358
17BA6 TANGUT IDEOGRAPH-#17BA6, TGT_MergedSrc=L2008-5357
17BA7 TANGUT IDEOGRAPH-#17BA7, TGT_MergedSrc=L2008-5780
17BA8 TANGUT IDEOGRAPH-#17BA8, TGT_MergedSrc=L2008-5101
17BA9 TANGUT IDEOGRAPH-#17BA9, TGT_MergedSrc=L2008-5104
17BAA TANGUT IDEOGRAPH-#17BAA, TGT_MergedSrc=L2008-5360
17BAB TANGUT IDEOGRAPH-#17BAB, TGT_MergedSrc=L2008-5272
17BAC TANGUT IDEOGRAPH-#17BAC, TGT_MergedSrc=L2008-5269
17BAD TANGUT IDEOGRAPH-#17BAD, TGT_MergedSrc=L2008-5781
17BAE TANGUT IDEOGRAPH-#17BAE, TGT_MergedSrc=L2008-5700
17BAF TANGUT IDEOGRAPH-#17BAF, TGT_MergedSrc=L2008-5701
17BB0 TANGUT IDEOGRAPH-#17BB0, TGT_MergedSrc=L2008-5273
17BB1 TANGUT IDEOGRAPH-#17BB1, TGT_MergedSrc=L2008-5704
17BB2 TANGUT IDEOGRAPH-#17BB2, TGT_MergedSrc=L2008-5103
17BB3 TANGUT IDEOGRAPH-#17BB3, TGT_MergedSrc=L2008-5102
17BB4 TANGUT IDEOGRAPH-#17BB4, TGT_MergedSrc=L2008-5702
17BB5 TANGUT IDEOGRAPH-#17BB5, TGT_MergedSrc=L2008-5513
17BB6 TANGUT IDEOGRAPH-#17BB6, TGT_MergedSrc=L2008-5515
17BB7 TANGUT IDEOGRAPH-#17BB7, TGT_MergedSrc=L2008-5512
17BB8 TANGUT IDEOGRAPH-#17BB8, TGT_MergedSrc=L2008-5274
17BB9 TANGUT IDEOGRAPH-#17BB9, TGT_MergedSrc=L2008-5108
17BBA TANGUT IDEOGRAPH-#17BBA, TGT_MergedSrc=L2008-5105
17BBB TANGUT IDEOGRAPH-#17BBB, TGT_MergedSrc=L2008-5278
17BBC TANGUT IDEOGRAPH-#17BBC, TGT_MergedSrc=L2008-5703
17BBD TANGUT IDEOGRAPH-#17BBD, TGT_MergedSrc=L2008-5514
17BBE TANGUT IDEOGRAPH-#17BBE, TGT_MergedSrc=L2008-5275
17BBF TANGUT IDEOGRAPH-#17BBF, TGT_MergedSrc=L2008-5107
17BC0 TANGUT IDEOGRAPH-#17BC0, TGT_MergedSrc=L2008-5277
17BC1 TANGUT IDEOGRAPH-#17BC1, TGT_MergedSrc=L2008-5705
17BC2 TANGUT IDEOGRAPH-#17BC2, TGT_MergedSrc=L2008-5109
17BC3 TANGUT IDEOGRAPH-#17BC3, TGT_MergedSrc=L2008-5276
17BC4 TANGUT IDEOGRAPH-#17BC4, TGT_MergedSrc=L2008-5517
17BC5 TANGUT IDEOGRAPH-#17BC5, TGT_MergedSrc=L2008-5111
17BC6 TANGUT IDEOGRAPH-#17BC6, TGT_MergedSrc=L2008-5520
17BC7 TANGUT IDEOGRAPH-#17BC7, TGT_MergedSrc=L2008-5106
17BC8 TANGUT IDEOGRAPH-#17BC8, TGT_MergedSrc=L2008-5516
17BC9 TANGUT IDEOGRAPH-#17BC9, TGT_MergedSrc=L2008-5279
17BCA TANGUT IDEOGRAPH-#17BCA, TGT_MergedSrc=L2008-5110
17BCB TANGUT IDEOGRAPH-#17BCB, TGT_MergedSrc=L2008-5362
17BCC TANGUT IDEOGRAPH-#17BCC, TGT_MergedSrc=L2008-5521
17BCD TANGUT IDEOGRAPH-#17BCD, TGT_MergedSrc=L2008-5361
17BCE TANGUT IDEOGRAPH-#17BCE, TGT_MergedSrc=L2008-5518
17BCF TANGUT IDEOGRAPH-#17BCF, TGT_MergedSrc=L2008-5270
17BD0 TANGUT IDEOGRAPH-#17BD0, TGT_MergedSrc=L2008-5962
17BD1 TANGUT IDEOGRAPH-#17BD1, TGT_MergedSrc=L2008-5848
17BD2 TANGUT IDEOGRAPH-#17BD2, TGT_MergedSrc=L2008-5964
17BD3 TANGUT IDEOGRAPH-#17BD3, TGT_MergedSrc=L2008-5854
17BD4 TANGUT IDEOGRAPH-#17BD4, TGT_MergedSrc=L2008-5874
17BD5 TANGUT IDEOGRAPH-#17BD5, TGT_MergedSrc=L2008-5946
17BD6 TANGUT IDEOGRAPH-#17BD6, TGT_MergedSrc=L2008-5841
17BD7 TANGUT IDEOGRAPH-#17BD7, TGT_MergedSrc=L2008-5834
17BD8 TANGUT IDEOGRAPH-#17BD8, TGT_MergedSrc=L2008-5895
17BD9 TANGUT IDEOGRAPH-#17BD9, TGT_MergedSrc=L2008-6073
17BDA TANGUT IDEOGRAPH-#17BDA, TGT_MergedSrc=L2008-5980
17BDB TANGUT IDEOGRAPH-#17BDB, TGT_MergedSrc=L2008-5912
17BDC TANGUT IDEOGRAPH-#17BDC, TGT_MergedSrc=L2008-5893
17BDD TANGUT IDEOGRAPH-#17BDD, TGT_MergedSrc=L2008-5842
17BDE TANGUT IDEOGRAPH-#17BDE, TGT_MergedSrc=L2008-5433
17BDF TANGUT IDEOGRAPH-#17BDF, TGT_MergedSrc=L2008-5386
17BE0 TANGUT IDEOGRAPH-#17BE0, TGT_MergedSrc=L2008-5197
17BE1 TANGUT IDEOGRAPH-#17BE1, TGT_MergedSrc=L2008-5174
17BE2 TANGUT IDEOGRAPH-#17BE2, TGT_MergedSrc=L2008-5746
17BE3 TANGUT IDEOGRAPH-#17BE3, TGT_MergedSrc=L2008-6070
17BE4 TANGUT IDEOGRAPH-#17BE4, TGT_MergedSrc=L2008-5446
17BE5 TANGUT IDEOGRAPH-#17BE5, TGT_MergedSrc=L2008-5198
17BE6 TANGUT IDEOGRAPH-#17BE6, TGT_MergedSrc=L2008-4872
17BE7 TANGUT IDEOGRAPH-#17BE7, TGT_MergedSrc=L2008-4682
17BE8 TANGUT IDEOGRAPH-#17BE8, TGT_MergedSrc=L2008-4713
17BE9 TANGUT IDEOGRAPH-#17BE9, TGT_MergedSrc=L2008-5165
17BEA TANGUT IDEOGRAPH-#17BEA, TGT_MergedSrc=L2008-5166
17BEB TANGUT IDEOGRAPH-#17BEB, TGT_MergedSrc=L2008-5239
17BEC TANGUT IDEOGRAPH-#17BEC, TGT_MergedSrc=L2008-5325
17BED TANGUT IDEOGRAPH-#17BED, TGT_MergedSrc=L2008-5739
17BEE TANGUT IDEOGRAPH-#17BEE, TGT_MergedSrc=L2008-5625
17BEF TANGUT IDEOGRAPH-#17BEF, TGT_MergedSrc=L2008-5588
17BF0 TANGUT IDEOGRAPH-#17BF0, TGT_MergedSrc=L2008-5327
17BF1 TANGUT IDEOGRAPH-#17BF1, TGT_MergedSrc=L2008-5793
17BF2 TANGUT IDEOGRAPH-#17BF2, TGT_MergedSrc=L2008-5626
17BF3 TANGUT IDEOGRAPH-#17BF3, TGT_MergedSrc=L2008-5657
17BF4 TANGUT IDEOGRAPH-#17BF4, TGT_MergedSrc=L2008-5399
17BF5 TANGUT IDEOGRAPH-#17BF5, TGT_MergedSrc=L2008-5326
17BF6 TANGUT IDEOGRAPH-#17BF6, TGT_MergedSrc=L2008-5405
17BF7 TANGUT IDEOGRAPH-#17BF7, TGT_MergedSrc=L2008-5762
17BF8 TANGUT IDEOGRAPH-#17BF8, TGT_MergedSrc=L2008-5738
17BF9 TANGUT IDEOGRAPH-#17BF9, TGT_MergedSrc=L2008-5754
17BFA TANGUT IDEOGRAPH-#17BFA, TGT_MergedSrc=L2008-5658
17BFB TANGUT IDEOGRAPH-#17BFB, TGT_MergedSrc=L2008-5240
17BFC TANGUT IDEOGRAPH-#17BFC, TGT_MergedSrc=L2008-5185
17BFD TANGUT IDEOGRAPH-#17BFD, TGT_MergedSrc=L2008-5406
17BFE TANGUT IDEOGRAPH-#17BFE, TGT_MergedSrc=L2008-5664
17BFF TANGUT IDEOGRAPH-#17BFF, TGT_MergedSrc=L2008-5659
17C00 TANGUT IDEOGRAPH-#17C00, TGT_MergedSrc=L2008-5332
17C01 TANGUT IDEOGRAPH-#17C01, TGT_MergedSrc=L2008-5176
17C02 TANGUT IDEOGRAPH-#17C02, TGT_MergedSrc=L2008-5595
17C03 TANGUT IDEOGRAPH-#17C03, TGT_MergedSrc=L2008-5186
17C04 TANGUT IDEOGRAPH-#17C04, TGT_MergedSrc=L2008-5187
17C05 TANGUT IDEOGRAPH-#17C05, TGT_MergedSrc=L2008-5597
17C06 TANGUT IDEOGRAPH-#17C06, TGT_MergedSrc=L2008-5167
17C07 TANGUT IDEOGRAPH-#17C07, TGT_MergedSrc=L2008-5623
17C08 TANGUT IDEOGRAPH-#17C08, TGT_MergedSrc=L2008-5629
17C09 TANGUT IDEOGRAPH-#17C09, TGT_MergedSrc=L2008-5238
17C0A TANGUT IDEOGRAPH-#17C0A, TGT_MergedSrc=L2008-5181
17C0B TANGUT IDEOGRAPH-#17C0B, TGT_MergedSrc=L2008-5438
17C0C TANGUT IDEOGRAPH-#17C0C, TGT_MergedSrc=L2008-5331
17C0D TANGUT IDEOGRAPH-#17C0D, TGT_MergedSrc=L2008-5630
17C0E TANGUT IDEOGRAPH-#17C0E, TGT_MergedSrc=L2008-5398
17C0F TANGUT IDEOGRAPH-#17C0F, TGT_MergedSrc=L2008-0788
17C10 TANGUT IDEOGRAPH-#17C10, TGT_MergedSrc=L2008-0781
17C11 TANGUT IDEOGRAPH-#17C11, TGT_MergedSrc=L2008-5945
17C12 TANGUT IDEOGRAPH-#17C12, TGT_MergedSrc=L2008-0744
17C13 TANGUT IDEOGRAPH-#17C13, TGT_MergedSrc=L2008-0491
17C14 TANGUT IDEOGRAPH-#17C14, TGT_MergedSrc=L2008-0997
17C15 TANGUT IDEOGRAPH-#17C15, TGT_MergedSrc=L2008-6020
17C16 TANGUT IDEOGRAPH-#17C16, TGT_MergedSrc=L2008-0478
17C17 TANGUT IDEOGRAPH-#17C17, TGT_MergedSrc=L2008-1084
17C18 TANGUT IDEOGRAPH-#17C18, TGT_MergedSrc=L2008-1097
17C19 TANGUT IDEOGRAPH-#17C19, TGT_MergedSrc=L2008-0174
17C1A TANGUT IDEOGRAPH-#17C1A, TGT_MergedSrc=L2008-0755
17C1B TANGUT IDEOGRAPH-#17C1B, TGT_MergedSrc=L2008-1640
17C1C TANGUT IDEOGRAPH-#17C1C, TGT_MergedSrc=L2008-0856
17C1D TANGUT IDEOGRAPH-#17C1D, TGT_MergedSrc=L2008-0499
17C1E TANGUT IDEOGRAPH-#17C1E, TGT_MergedSrc=L2008-0176
17C1F TANGUT IDEOGRAPH-#17C1F, TGT_MergedSrc=L2008-0175
17C20 TANGUT IDEOGRAPH-#17C20, TGT_MergedSrc=L2008-1011
17C21 TANGUT IDEOGRAPH-#17C21, TGT_MergedSrc=L2008-0963
17C22 TANGUT IDEOGRAPH-#17C22, TGT_MergedSrc=L2008-0761
17C23 TANGUT IDEOGRAPH-#17C23, TGT_MergedSrc=L2008-1012
17C24 TANGUT IDEOGRAPH-#17C24, TGT_MergedSrc=L2008-1125
17C25 TANGUT IDEOGRAPH-#17C25, TGT_MergedSrc=L2008-1649
17C26 TANGUT IDEOGRAPH-#17C26, TGT_MergedSrc=L2008-1595
17C27 TANGUT IDEOGRAPH-#17C27, TGT_MergedSrc=L2008-1126
17C28 TANGUT IDEOGRAPH-#17C28, TGT_MergedSrc=L2008-1844
17C29 TANGUT IDEOGRAPH-#17C29, TGT_MergedSrc=L2008-0964
17C2A TANGUT IDEOGRAPH-#17C2A, TGT_MergedSrc=L2008-0772
17C2B TANGUT IDEOGRAPH-#17C2B, TGT_MergedSrc=L2008-1233
17C2C TANGUT IDEOGRAPH-#17C2C, TGT_MergedSrc=L2008-1292
17C2D TANGUT IDEOGRAPH-#17C2D, TGT_MergedSrc=L2008-1040
17C2E TANGUT IDEOGRAPH-#17C2E, TGT_MergedSrc=L2008-0947
17C2F TANGUT IDEOGRAPH-#17C2F, TGT_MergedSrc=L2008-1251
17C30 TANGUT IDEOGRAPH-#17C30, TGT_MergedSrc=L2008-1264
17C31 TANGUT IDEOGRAPH-#17C31, TGT_MergedSrc=L2008-0678
17C32 TANGUT IDEOGRAPH-#17C32, TGT_MergedSrc=N1966-190-053
17C33 TANGUT IDEOGRAPH-#17C33, TGT_MergedSrc=L2008-1370
17C34 TANGUT IDEOGRAPH-#17C34, TGT_MergedSrc=L2008-1688
17C35 TANGUT IDEOGRAPH-#17C35, TGT_MergedSrc=L2008-0336
17C36 TANGUT IDEOGRAPH-#17C36, TGT_MergedSrc=S1968-4699
17C37 TANGUT IDEOGRAPH-#17C37, TGT_MergedSrc=L2008-1431
17C38 TANGUT IDEOGRAPH-#17C38, TGT_MergedSrc=L2008-0390
17C39 TANGUT IDEOGRAPH-#17C39, TGT_MergedSrc=L2008-1476
17C3A TANGUT IDEOGRAPH-#17C3A, TGT_MergedSrc=L2008-0722
17C3B TANGUT IDEOGRAPH-#17C3B, TGT_MergedSrc=L2008-1793
17C3C TANGUT IDEOGRAPH-#17C3C, TGT_MergedSrc=L2008-1788
17C3D TANGUT IDEOGRAPH-#17C3D, TGT_MergedSrc=L2008-0405
17C3E TANGUT IDEOGRAPH-#17C3E, TGT_MergedSrc=L2008-0393
17C3F TANGUT IDEOGRAPH-#17C3F, TGT_MergedSrc=L2008-1795
17C40 TANGUT IDEOGRAPH-#17C40, TGT_MergedSrc=L2008-1794
17C41 TANGUT IDEOGRAPH-#17C41, TGT_MergedSrc=L2008-0826
17C42 TANGUT IDEOGRAPH-#17C42, TGT_MergedSrc=L2008-0718
17C43 TANGUT IDEOGRAPH-#17C43, TGT_MergedSrc=L2008-0827
17C44 TANGUT IDEOGRAPH-#17C44, TGT_MergedSrc=L2008-0828
17C45 TANGUT IDEOGRAPH-#17C45, TGT_MergedSrc=L2008-0394
17C46 TANGUT IDEOGRAPH-#17C46, TGT_MergedSrc=L2008-0395
17C47 TANGUT IDEOGRAPH-#17C47, TGT_MergedSrc=L2008-0886
17C48 TANGUT IDEOGRAPH-#17C48, TGT_MergedSrc=L2008-1477
17C49 TANGUT IDEOGRAPH-#17C49, TGT_MergedSrc=L2008-1785
17C4A TANGUT IDEOGRAPH-#17C4A, TGT_MergedSrc=L2008-0608
17C4B TANGUT IDEOGRAPH-#17C4B, TGT_MergedSrc=L2008-1878
17C4C TANGUT IDEOGRAPH-#17C4C, TGT_MergedSrc=L2008-1799
17C4D TANGUT IDEOGRAPH-#17C4D, TGT_MergedSrc=L2008-0419
17C4E TANGUT IDEOGRAPH-#17C4E, TGT_MergedSrc=L2008-0988
17C4F TANGUT IDEOGRAPH-#17C4F, TGT_MergedSrc=L2008-1059
17C50 TANGUT IDEOGRAPH-#17C50, TGT_MergedSrc=L2008-0913
17C51 TANGUT IDEOGRAPH-#17C51, TGT_MergedSrc=L2008-1253
17C52 TANGUT IDEOGRAPH-#17C52, TGT_MergedSrc=L2008-0914
17C53 TANGUT IDEOGRAPH-#17C53, TGT_MergedSrc=L2008-1270
17C54 TANGUT IDEOGRAPH-#17C54, TGT_MergedSrc=L2008-1502
17C55 TANGUT IDEOGRAPH-#17C55, TGT_MergedSrc=L2008-0968
17C56 TANGUT IDEOGRAPH-#17C56, TGT_MergedSrc=L2008-1154
17C57 TANGUT IDEOGRAPH-#17C57, TGT_MergedSrc=L2008-1518
17C58 TANGUT IDEOGRAPH-#17C58, TGT_MergedSrc=L2008-0995
17C59 TANGUT IDEOGRAPH-#17C59, TGT_MergedSrc=L2008-1480
17C5A TANGUT IDEOGRAPH-#17C5A, TGT_MergedSrc=L2008-1071
17C5B TANGUT IDEOGRAPH-#17C5B, TGT_MergedSrc=L2008-0996
17C5C TANGUT IDEOGRAPH-#17C5C, TGT_MergedSrc=L2008-0922
17C5D TANGUT IDEOGRAPH-#17C5D, TGT_MergedSrc=L2008-1002
17C5E TANGUT IDEOGRAPH-#17C5E, TGT_MergedSrc=L2008-1300
17C5F TANGUT IDEOGRAPH-#17C5F, TGT_MergedSrc=L2008-1226
17C60 TANGUT IDEOGRAPH-#17C60, TGT_MergedSrc=L2008-0929
17C61 TANGUT IDEOGRAPH-#17C61, TGT_MergedSrc=L2008-1155
17C62 TANGUT IDEOGRAPH-#17C62, TGT_MergedSrc=L2008-1452
17C63 TANGUT IDEOGRAPH-#17C63, TGT_MergedSrc=L2008-1243
17C64 TANGUT IDEOGRAPH-#17C64, TGT_MergedSrc=L2008-1515
17C65 TANGUT IDEOGRAPH-#17C65, TGT_MergedSrc=L2008-1036
17C66 TANGUT IDEOGRAPH-#17C66, TGT_MergedSrc=L2008-1073
17C67 TANGUT IDEOGRAPH-#17C67, TGT_MergedSrc=L2008-1282
17C68 TANGUT IDEOGRAPH-#17C68, TGT_MergedSrc=L2008-0931
17C69 TANGUT IDEOGRAPH-#17C69, TGT_MergedSrc=L2008-1091
17C6A TANGUT IDEOGRAPH-#17C6A, TGT_MergedSrc=L2008-0932
17C6B TANGUT IDEOGRAPH-#17C6B, TGT_MergedSrc=L2008-1447
17C6C TANGUT IDEOGRAPH-#17C6C, TGT_MergedSrc=L2008-1284
17C6D TANGUT IDEOGRAPH-#17C6D, TGT_MergedSrc=L2008-1227
17C6E TANGUT IDEOGRAPH-#17C6E, TGT_MergedSrc=L2008-1301
17C6F TANGUT IDEOGRAPH-#17C6F, TGT_MergedSrc=L2008-1157
17C70 TANGUT IDEOGRAPH-#17C70, TGT_MergedSrc=L2008-1271
17C71 TANGUT IDEOGRAPH-#17C71, TGT_MergedSrc=L2008-1100
17C72 TANGUT IDEOGRAPH-#17C72, TGT_MergedSrc=L2008-1072
17C73 TANGUT IDEOGRAPH-#17C73, TGT_MergedSrc=L2008-1022
17C74 TANGUT IDEOGRAPH-#17C74, TGT_MergedSrc=L2008-1162
17C75 TANGUT IDEOGRAPH-#17C75, TGT_MergedSrc=L2008-0927
17C76 TANGUT IDEOGRAPH-#17C76, TGT_MergedSrc=L2008-0979
17C77 TANGUT IDEOGRAPH-#17C77, TGT_MergedSrc=L2008-1024
17C78 TANGUT IDEOGRAPH-#17C78, TGT_MergedSrc=L2008-1074
17C79 TANGUT IDEOGRAPH-#17C79, TGT_MergedSrc=L2008-1434
17C7A TANGUT IDEOGRAPH-#17C7A, TGT_MergedSrc=L2008-1379
17C7B TANGUT IDEOGRAPH-#17C7B, TGT_MergedSrc=L2008-0948
17C7C TANGUT IDEOGRAPH-#17C7C, TGT_MergedSrc=L2008-0961
17C7D TANGUT IDEOGRAPH-#17C7D, TGT_MergedSrc=L2008-1092
17C7E TANGUT IDEOGRAPH-#17C7E, TGT_MergedSrc=L2008-1433
17C7F TANGUT IDEOGRAPH-#17C7F, TGT_MergedSrc=L2008-0972
17C80 TANGUT IDEOGRAPH-#17C80, TGT_MergedSrc=L2008-1414
17C81 TANGUT IDEOGRAPH-#17C81, TGT_MergedSrc=L2008-1208
17C82 TANGUT IDEOGRAPH-#17C82, TGT_MergedSrc=L2008-1228
17C83 TANGUT IDEOGRAPH-#17C83, TGT_MergedSrc=L2008-1163
17C84 TANGUT IDEOGRAPH-#17C84, TGT_MergedSrc=L2008-1481
17C85 TANGUT IDEOGRAPH-#17C85, TGT_MergedSrc=L2008-1539
17C86 TANGUT IDEOGRAPH-#17C86, TGT_MergedSrc=L2008-1303
17C87 TANGUT IDEOGRAPH-#17C87, TGT_MergedSrc=L2008-0923
17C88 TANGUT IDEOGRAPH-#17C88, TGT_MergedSrc=L2008-0933
17C89 TANGUT IDEOGRAPH-#17C89, TGT_MergedSrc=L2008-1075
17C8A TANGUT IDEOGRAPH-#17C8A, TGT_MergedSrc=L2008-0986
17C8B TANGUT IDEOGRAPH-#17C8B, TGT_MergedSrc=L2008-1529
17C8C TANGUT IDEOGRAPH-#17C8C, TGT_MergedSrc=L2008-1530
17C8D TANGUT IDEOGRAPH-#17C8D, TGT_MergedSrc=L2008-0980
17C8E TANGUT IDEOGRAPH-#17C8E, TGT_MergedSrc=L2008-0973
17C8F TANGUT IDEOGRAPH-#17C8F, TGT_MergedSrc=L2008-0924
17C90 TANGUT IDEOGRAPH-#17C90, TGT_MergedSrc=L2008-1111
17C91 TANGUT IDEOGRAPH-#17C91, TGT_MergedSrc=L2008-1450
17C92 TANGUT IDEOGRAPH-#17C92, TGT_MergedSrc=L2008-1038
17C93 TANGUT IDEOGRAPH-#17C93, TGT_MergedSrc=L2008-1340
17C94 TANGUT IDEOGRAPH-#17C94, TGT_MergedSrc=L2008-1302
17C95 TANGUT IDEOGRAPH-#17C95, TGT_MergedSrc=L2008-1496
17C96 TANGUT IDEOGRAPH-#17C96, TGT_MergedSrc=L2008-1060
17C97 TANGUT IDEOGRAPH-#17C97, TGT_MergedSrc=L2008-1554
17C98 TANGUT IDEOGRAPH-#17C98, TGT_MergedSrc=L2008-1403
17C99 TANGUT IDEOGRAPH-#17C99, TGT_MergedSrc=L2008-1077
17C9A TANGUT IDEOGRAPH-#17C9A, TGT_MergedSrc=L2008-1248
17C9B TANGUT IDEOGRAPH-#17C9B, TGT_MergedSrc=L2008-1341
17C9C TANGUT IDEOGRAPH-#17C9C, TGT_MergedSrc=L2008-0950
17C9D TANGUT IDEOGRAPH-#17C9D, TGT_MergedSrc=L2008-0951
17C9E TANGUT IDEOGRAPH-#17C9E, TGT_MergedSrc=L2008-1093
17C9F TANGUT IDEOGRAPH-#17C9F, TGT_MergedSrc=L2008-1343
17CA0 TANGUT IDEOGRAPH-#17CA0, TGT_MergedSrc=L2008-1364
17CA1 TANGUT IDEOGRAPH-#17CA1, TGT_MergedSrc=L2008-1547
17CA2 TANGUT IDEOGRAPH-#17CA2, TGT_MergedSrc=L2008-1304
17CA3 TANGUT IDEOGRAPH-#17CA3, TGT_MergedSrc=L2008-1076
17CA4 TANGUT IDEOGRAPH-#17CA4, TGT_MergedSrc=L2008-0971
17CA5 TANGUT IDEOGRAPH-#17CA5, TGT_MergedSrc=L2008-1287
17CA6 TANGUT IDEOGRAPH-#17CA6, TGT_MergedSrc=L2008-1331
17CA7 TANGUT IDEOGRAPH-#17CA7, TGT_MergedSrc=L2008-1380
17CA8 TANGUT IDEOGRAPH-#17CA8, TGT_MergedSrc=L2008-1461
17CA9 TANGUT IDEOGRAPH-#17CA9, TGT_MergedSrc=L2008-0925
17CAA TANGUT IDEOGRAPH-#17CAA, TGT_MergedSrc=L2008-1023
17CAB TANGUT IDEOGRAPH-#17CAB, TGT_MergedSrc=L2008-1471
17CAC TANGUT IDEOGRAPH-#17CAC, TGT_MergedSrc=L2008-1548
17CAD TANGUT IDEOGRAPH-#17CAD, TGT_MergedSrc=L2008-1032
17CAE TANGUT IDEOGRAPH-#17CAE, TGT_MergedSrc=L2008-1437
17CAF TANGUT IDEOGRAPH-#17CAF, TGT_MergedSrc=L2008-1344
17CB0 TANGUT IDEOGRAPH-#17CB0, TGT_MergedSrc=L2008-1342
17CB1 TANGUT IDEOGRAPH-#17CB1, TGT_MergedSrc=L2008-1164
17CB2 TANGUT IDEOGRAPH-#17CB2, TGT_MergedSrc=L2008-0949
17CB3 TANGUT IDEOGRAPH-#17CB3, TGT_MergedSrc=L2008-1254
17CB4 TANGUT IDEOGRAPH-#17CB4, TGT_MergedSrc=L2008-1165
17CB5 TANGUT IDEOGRAPH-#17CB5, TGT_MergedSrc=L2008-1122
17CB6 TANGUT IDEOGRAPH-#17CB6, TGT_MergedSrc=L2008-1209
17CB7 TANGUT IDEOGRAPH-#17CB7, TGT_MergedSrc=L2008-1211
17CB8 TANGUT IDEOGRAPH-#17CB8, TGT_MergedSrc=L2008-0952
17CB9 TANGUT IDEOGRAPH-#17CB9, TGT_MergedSrc=L2008-1078
17CBA TANGUT IDEOGRAPH-#17CBA, TGT_MergedSrc=L2008-1365
17CBB TANGUT IDEOGRAPH-#17CBB, TGT_MergedSrc=L2008-1394
17CBC TANGUT IDEOGRAPH-#17CBC, TGT_MergedSrc=L2008-1166
17CBD TANGUT IDEOGRAPH-#17CBD, TGT_MergedSrc=L2008-1109
17CBE TANGUT IDEOGRAPH-#17CBE, TGT_MergedSrc=L2008-5933
17CBF TANGUT IDEOGRAPH-#17CBF, TGT_MergedSrc=L2008-4070
17CC0 TANGUT IDEOGRAPH-#17CC0, TGT_MergedSrc=L2008-4074
17CC1 TANGUT IDEOGRAPH-#17CC1, TGT_MergedSrc=L2008-4068
17CC2 TANGUT IDEOGRAPH-#17CC2, TGT_MergedSrc=L2008-4061
17CC3 TANGUT IDEOGRAPH-#17CC3, TGT_MergedSrc=L2008-1551
17CC4 TANGUT IDEOGRAPH-#17CC4, TGT_MergedSrc=L2008-0842
17CC5 TANGUT IDEOGRAPH-#17CC5, TGT_MergedSrc=L2008-0463
17CC6 TANGUT IDEOGRAPH-#17CC6, TGT_MergedSrc=L2008-1839
17CC7 TANGUT IDEOGRAPH-#17CC7, TGT_MergedSrc=L2008-0466
17CC8 TANGUT IDEOGRAPH-#17CC8, TGT_MergedSrc=L2008-0639
17CC9 TANGUT IDEOGRAPH-#17CC9, TGT_MergedSrc=L2008-1564
17CCA TANGUT IDEOGRAPH-#17CCA, TGT_MergedSrc=L2008-0843
17CCB TANGUT IDEOGRAPH-#17CCB, TGT_MergedSrc=L2008-0471
17CCC TANGUT IDEOGRAPH-#17CCC, TGT_MergedSrc=L2008-1840
17CCD TANGUT IDEOGRAPH-#17CCD, TGT_MergedSrc=L2008-1563
17CCE TANGUT IDEOGRAPH-#17CCE, TGT_MergedSrc=L2008-1842
17CCF TANGUT IDEOGRAPH-#17CCF, TGT_MergedSrc=L2008-1565
17CD0 TANGUT IDEOGRAPH-#17CD0, TGT_MergedSrc=L2008-0892
17CD1 TANGUT IDEOGRAPH-#17CD1, TGT_MergedSrc=L2008-5859
17CD2 TANGUT IDEOGRAPH-#17CD2, TGT_MergedSrc=L2008-5880
17CD3 TANGUT IDEOGRAPH-#17CD3, TGT_MergedSrc=L2008-5994
17CD4 TANGUT IDEOGRAPH-#17CD4, TGT_MergedSrc=L2008-5988
17CD5 TANGUT IDEOGRAPH-#17CD5, TGT_MergedSrc=L2008-5967
17CD6 TANGUT IDEOGRAPH-#17CD6, TGT_MergedSrc=L2008-5861
17CD7 TANGUT IDEOGRAPH-#17CD7, TGT_MergedSrc=S1968-5379
17CD8 TANGUT IDEOGRAPH-#17CD8, TGT_MergedSrc=L2008-1277
17CD9 TANGUT IDEOGRAPH-#17CD9, TGT_MergedSrc=L2008-6011
17CDA TANGUT IDEOGRAPH-#17CDA, TGT_MergedSrc=L2008-0822
17CDB TANGUT IDEOGRAPH-#17CDB, TGT_MergedSrc=L2008-0244
17CDC TANGUT IDEOGRAPH-#17CDC, TGT_MergedSrc=L2008-0374
17CDD TANGUT IDEOGRAPH-#17CDD, TGT_MergedSrc=L2008-0863
17CDE TANGUT IDEOGRAPH-#17CDE, TGT_MergedSrc=L2008-1709
17CDF TANGUT IDEOGRAPH-#17CDF, TGT_MergedSrc=L2008-1720
17CE0 TANGUT IDEOGRAPH-#17CE0, TGT_MergedSrc=L2008-0813
17CE1 TANGUT IDEOGRAPH-#17CE1, TGT_MergedSrc=L2008-0245
17CE2 TANGUT IDEOGRAPH-#17CE2, TGT_MergedSrc=L2008-0303
17CE3 TANGUT IDEOGRAPH-#17CE3, TGT_MergedSrc=L2008-0275
17CE4 TANGUT IDEOGRAPH-#17CE4, TGT_MergedSrc=L2008-1356
17CE5 TANGUT IDEOGRAPH-#17CE5, TGT_MergedSrc=L2008-1324
17CE6 TANGUT IDEOGRAPH-#17CE6, TGT_MergedSrc=L2008-1737
17CE7 TANGUT IDEOGRAPH-#17CE7, TGT_MergedSrc=L2008-1710
17CE8 TANGUT IDEOGRAPH-#17CE8, TGT_MergedSrc=L2008-0562
17CE9 TANGUT IDEOGRAPH-#17CE9, TGT_MergedSrc=L2008-1668
17CEA TANGUT IDEOGRAPH-#17CEA, TGT_MergedSrc=L2008-0793
17CEB TANGUT IDEOGRAPH-#17CEB, TGT_MergedSrc=L2008-1738
17CEC TANGUT IDEOGRAPH-#17CEC, TGT_MergedSrc=L2008-1416
17CED TANGUT IDEOGRAPH-#17CED, TGT_MergedSrc=L2008-1857
17CEE TANGUT IDEOGRAPH-#17CEE, TGT_MergedSrc=L2008-0378
17CEF TANGUT IDEOGRAPH-#17CEF, TGT_MergedSrc=L2008-1776
17CF0 TANGUT IDEOGRAPH-#17CF0, TGT_MergedSrc=S1968-5397
17CF1 TANGUT IDEOGRAPH-#17CF1, TGT_MergedSrc=L2008-0388
17CF2 TANGUT IDEOGRAPH-#17CF2, TGT_MergedSrc=L2008-0392
17CF3 TANGUT IDEOGRAPH-#17CF3, TGT_MergedSrc=L2008-0612
17CF4 TANGUT IDEOGRAPH-#17CF4, TGT_MergedSrc=L2008-0411
17CF5 TANGUT IDEOGRAPH-#17CF5, TGT_MergedSrc=L2008-1430
17CF6 TANGUT IDEOGRAPH-#17CF6, TGT_MergedSrc=L2008-1456
17CF7 TANGUT IDEOGRAPH-#17CF7, TGT_MergedSrc=L2008-1796
17CF8 TANGUT IDEOGRAPH-#17CF8, TGT_MergedSrc=L2008-1792
17CF9 TANGUT IDEOGRAPH-#17CF9, TGT_MergedSrc=L2008-1797
17CFA TANGUT IDEOGRAPH-#17CFA, TGT_MergedSrc=L2008-0396
17CFB TANGUT IDEOGRAPH-#17CFB, TGT_MergedSrc=L2008-0402
17CFC TANGUT IDEOGRAPH-#17CFC, TGT_MergedSrc=L2008-0397
17CFD TANGUT IDEOGRAPH-#17CFD, TGT_MergedSrc=L2008-0636
17CFE TANGUT IDEOGRAPH-#17CFE, TGT_MergedSrc=L2008-1552
17CFF TANGUT IDEOGRAPH-#17CFF, TGT_MergedSrc=L2008-1575
17D00 TANGUT IDEOGRAPH-#17D00, TGT_MergedSrc=L2008-0464
17D01 TANGUT IDEOGRAPH-#17D01, TGT_MergedSrc=L2008-1560
17D02 TANGUT IDEOGRAPH-#17D02, TGT_MergedSrc=L2008-1572
17D03 TANGUT IDEOGRAPH-#17D03, TGT_MergedSrc=L2008-0468
17D04 TANGUT IDEOGRAPH-#17D04, TGT_MergedSrc=L2008-1571
17D05 TANGUT IDEOGRAPH-#17D05, TGT_MergedSrc=L2008-1838
17D06 TANGUT IDEOGRAPH-#17D06, TGT_MergedSrc=L2008-1556
17D07 TANGUT IDEOGRAPH-#17D07, TGT_MergedSrc=L2008-1832
17D08 TANGUT IDEOGRAPH-#17D08, TGT_MergedSrc=L2008-1099
17D09 TANGUT IDEOGRAPH-#17D09, TGT_MergedSrc=L2008-1088
17D0A TANGUT IDEOGRAPH-#17D0A, TGT_MergedSrc=L2008-0759
17D0B TANGUT IDEOGRAPH-#17D0B, TGT_MergedSrc=L2008-4448
17D0C TANGUT IDEOGRAPH-#17D0C, TGT_MergedSrc=L2008-4443
17D0D TANGUT IDEOGRAPH-#17D0D, TGT_MergedSrc=L2008-1513
17D0E TANGUT IDEOGRAPH-#17D0E, TGT_MergedSrc=L2008-1533
17D0F TANGUT IDEOGRAPH-#17D0F, TGT_MergedSrc=L2008-3408
17D10 TANGUT IDEOGRAPH-#17D10, TGT_MergedSrc=L2008-2320
17D11 TANGUT IDEOGRAPH-#17D11, TGT_MergedSrc=L2008-3400
17D12 TANGUT IDEOGRAPH-#17D12, TGT_MergedSrc=L2008-2539
17D13 TANGUT IDEOGRAPH-#17D13, TGT_MergedSrc=L2008-3426
17D14 TANGUT IDEOGRAPH-#17D14, TGT_MergedSrc=L2008-3417
17D15 TANGUT IDEOGRAPH-#17D15, TGT_MergedSrc=L2008-2531
17D16 TANGUT IDEOGRAPH-#17D16, TGT_MergedSrc=L2008-2694
17D17 TANGUT IDEOGRAPH-#17D17, TGT_MergedSrc=L2008-2330
17D18 TANGUT IDEOGRAPH-#17D18, TGT_MergedSrc=L2008-3418
17D19 TANGUT IDEOGRAPH-#17D19, TGT_MergedSrc=L2008-3742
17D1A TANGUT IDEOGRAPH-#17D1A, TGT_MergedSrc=L2008-3427
17D1B TANGUT IDEOGRAPH-#17D1B, TGT_MergedSrc=L2008-2331
17D1C TANGUT IDEOGRAPH-#17D1C, TGT_MergedSrc=L2008-3743
17D1D TANGUT IDEOGRAPH-#17D1D, TGT_MergedSrc=L2008-2901
17D1E TANGUT IDEOGRAPH-#17D1E, TGT_MergedSrc=L2008-2540
17D1F TANGUT IDEOGRAPH-#17D1F, TGT_MergedSrc=L2008-3425
17D20 TANGUT IDEOGRAPH-#17D20, TGT_MergedSrc=L2008-2528
17D21 TANGUT IDEOGRAPH-#17D21, TGT_MergedSrc=L2008-3399
17D22 TANGUT IDEOGRAPH-#17D22, TGT_MergedSrc=L2008-3419
17D23 TANGUT IDEOGRAPH-#17D23, TGT_MergedSrc=L2008-2899
17D24 TANGUT IDEOGRAPH-#17D24, TGT_MergedSrc=L2008-3747
17D25 TANGUT IDEOGRAPH-#17D25, TGT_MergedSrc=L2008-3412
17D26 TANGUT IDEOGRAPH-#17D26, TGT_MergedSrc=L2008-1528
17D27 TANGUT IDEOGRAPH-#17D27, TGT_MergedSrc=L2008-1498
17D28 TANGUT IDEOGRAPH-#17D28, TGT_MergedSrc=L2008-1493
17D29 TANGUT IDEOGRAPH-#17D29, TGT_MergedSrc=L2008-1505
17D2A TANGUT IDEOGRAPH-#17D2A, TGT_MergedSrc=L2008-3396
17D2B TANGUT IDEOGRAPH-#17D2B, TGT_MergedSrc=L2008-3006
17D2C TANGUT IDEOGRAPH-#17D2C, TGT_MergedSrc=L2008-3272
17D2D TANGUT IDEOGRAPH-#17D2D, TGT_MergedSrc=L2008-2999
17D2E TANGUT IDEOGRAPH-#17D2E, TGT_MergedSrc=L2008-3017
17D2F TANGUT IDEOGRAPH-#17D2F, TGT_MergedSrc=L2008-5999
17D30 TANGUT IDEOGRAPH-#17D30, TGT_MergedSrc=L2008-0037
17D31 TANGUT IDEOGRAPH-#17D31, TGT_MergedSrc=L2008-0062
17D32 TANGUT IDEOGRAPH-#17D32, TGT_MergedSrc=L2008-0071
17D33 TANGUT IDEOGRAPH-#17D33, TGT_MergedSrc=L2008-0059
17D34 TANGUT IDEOGRAPH-#17D34, TGT_MergedSrc=L2008-0140
17D35 TANGUT IDEOGRAPH-#17D35, TGT_MergedSrc=L2008-0124
17D36 TANGUT IDEOGRAPH-#17D36, TGT_MergedSrc=N1966-018-083
17D37 TANGUT IDEOGRAPH-#17D37, TGT_MergedSrc=L2008-0004
17D38 TANGUT IDEOGRAPH-#17D38, TGT_MergedSrc=L2008-0054
17D39 TANGUT IDEOGRAPH-#17D39, TGT_MergedSrc=L2008-0127
17D3A TANGUT IDEOGRAPH-#17D3A, TGT_MergedSrc=L2008-0092
17D3B TANGUT IDEOGRAPH-#17D3B, TGT_MergedSrc=L2008-0110
17D3C TANGUT IDEOGRAPH-#17D3C, TGT_MergedSrc=L2008-0006
17D3D TANGUT IDEOGRAPH-#17D3D, TGT_MergedSrc=L2008-0011
17D3E TANGUT IDEOGRAPH-#17D3E, TGT_MergedSrc=L2008-0040
17D3F TANGUT IDEOGRAPH-#17D3F, TGT_MergedSrc=L2008-0105
17D40 TANGUT IDEOGRAPH-#17D40, TGT_MergedSrc=L2008-0072
17D41 TANGUT IDEOGRAPH-#17D41, TGT_MergedSrc=L2008-0153
17D42 TANGUT IDEOGRAPH-#17D42, TGT_MergedSrc=L2008-0111
17D43 TANGUT IDEOGRAPH-#17D43, TGT_MergedSrc=L2008-0083
17D44 TANGUT IDEOGRAPH-#17D44, TGT_MergedSrc=L2008-0103
17D45 TANGUT IDEOGRAPH-#17D45, TGT_MergedSrc=L2008-0047
17D46 TANGUT IDEOGRAPH-#17D46, TGT_MergedSrc=L2008-0113
17D47 TANGUT IDEOGRAPH-#17D47, TGT_MergedSrc=L2008-0033
17D48 TANGUT IDEOGRAPH-#17D48, TGT_MergedSrc=L2008-0029
17D49 TANGUT IDEOGRAPH-#17D49, TGT_MergedSrc=L2008-0060
17D4A TANGUT IDEOGRAPH-#17D4A, TGT_MergedSrc=L2008-0125
17D4B TANGUT IDEOGRAPH-#17D4B, TGT_MergedSrc=L2008-0041
17D4C TANGUT IDEOGRAPH-#17D4C, TGT_MergedSrc=L2008-0149
17D4D TANGUT IDEOGRAPH-#17D4D, TGT_MergedSrc=L2008-0119
17D4E TANGUT IDEOGRAPH-#17D4E, TGT_MergedSrc=L2008-0128
17D4F TANGUT IDEOGRAPH-#17D4F, TGT_MergedSrc=L2008-0012
17D50 TANGUT IDEOGRAPH-#17D50, TGT_MergedSrc=L2008-0139
17D51 TANGUT IDEOGRAPH-#17D51, TGT_MergedSrc=L2008-0154
17D52 TANGUT IDEOGRAPH-#17D52, TGT_MergedSrc=L2008-0152
17D53 TANGUT IDEOGRAPH-#17D53, TGT_MergedSrc=L2008-0034
17D54 TANGUT IDEOGRAPH-#17D54, TGT_MergedSrc=L2008-0051
17D55 TANGUT IDEOGRAPH-#17D55, TGT_MergedSrc=L2008-0022
17D56 TANGUT IDEOGRAPH-#17D56, TGT_MergedSrc=L2008-0131
17D57 TANGUT IDEOGRAPH-#17D57, TGT_MergedSrc=L2008-0098
17D58 TANGUT IDEOGRAPH-#17D58, TGT_MergedSrc=L2008-0020
17D59 TANGUT IDEOGRAPH-#17D59, TGT_MergedSrc=L2008-0129
17D5A TANGUT IDEOGRAPH-#17D5A, TGT_MergedSrc=L2008-0021
17D5B TANGUT IDEOGRAPH-#17D5B, TGT_MergedSrc=L2008-0137
17D5C TANGUT IDEOGRAPH-#17D5C, TGT_MergedSrc=L2008-0133
17D5D TANGUT IDEOGRAPH-#17D5D, TGT_MergedSrc=L2008-0115
17D5E TANGUT IDEOGRAPH-#17D5E, TGT_MergedSrc=L2008-0106
17D5F TANGUT IDEOGRAPH-#17D5F, TGT_MergedSrc=L2008-0144
17D60 TANGUT IDEOGRAPH-#17D60, TGT_MergedSrc=L2008-0138
17D61 TANGUT IDEOGRAPH-#17D61, TGT_MergedSrc=L2008-0146
17D62 TANGUT IDEOGRAPH-#17D62, TGT_MergedSrc=L2008-0134
17D63 TANGUT IDEOGRAPH-#17D63, TGT_MergedSrc=L2008-0055
17D64 TANGUT IDEOGRAPH-#17D64, TGT_MergedSrc=L2008-0007
17D65 TANGUT IDEOGRAPH-#17D65, TGT_MergedSrc=L2008-0130
17D66 TANGUT IDEOGRAPH-#17D66, TGT_MergedSrc=L2008-0093
17D67 TANGUT IDEOGRAPH-#17D67, TGT_MergedSrc=L2008-0136
17D68 TANGUT IDEOGRAPH-#17D68, TGT_MergedSrc=L2008-0107
17D69 TANGUT IDEOGRAPH-#17D69, TGT_MergedSrc=L2008-0120
17D6A TANGUT IDEOGRAPH-#17D6A, TGT_MergedSrc=L2008-0114
17D6B TANGUT IDEOGRAPH-#17D6B, TGT_MergedSrc=L2008-0109
17D6C TANGUT IDEOGRAPH-#17D6C, TGT_MergedSrc=L2008-0126
17D6D TANGUT IDEOGRAPH-#17D6D, TGT_MergedSrc=L2008-0135
17D6E TANGUT IDEOGRAPH-#17D6E, TGT_MergedSrc=L2008-0121
17D6F TANGUT IDEOGRAPH-#17D6F, TGT_MergedSrc=L2008-0073
17D70 TANGUT IDEOGRAPH-#17D70, TGT_MergedSrc=L2008-0078
17D71 TANGUT IDEOGRAPH-#17D71, TGT_MergedSrc=L2008-0058
17D72 TANGUT IDEOGRAPH-#17D72, TGT_MergedSrc=L2008-0023
17D73 TANGUT IDEOGRAPH-#17D73, TGT_MergedSrc=L2008-0053
17D74 TANGUT IDEOGRAPH-#17D74, TGT_MergedSrc=L2008-1283
17D75 TANGUT IDEOGRAPH-#17D75, TGT_MergedSrc=L2008-0588
17D76 TANGUT IDEOGRAPH-#17D76, TGT_MergedSrc=L2008-1867
17D77 TANGUT IDEOGRAPH-#17D77, TGT_MergedSrc=L2008-1383-1384
17D78 TANGUT IDEOGRAPH-#17D78, TGT_MergedSrc=L2008-0817
17D79 TANGUT IDEOGRAPH-#17D79, TGT_MergedSrc=L2008-1049
17D7A TANGUT IDEOGRAPH-#17D7A, TGT_MergedSrc=L2008-4451
17D7B TANGUT IDEOGRAPH-#17D7B, TGT_MergedSrc=L2008-0346
17D7C TANGUT IDEOGRAPH-#17D7C, TGT_MergedSrc=L2008-0321
17D7D TANGUT IDEOGRAPH-#17D7D, TGT_MergedSrc=L2008-0542
17D7E TANGUT IDEOGRAPH-#17D7E, TGT_MergedSrc=L2008-0691
17D7F TANGUT IDEOGRAPH-#17D7F, TGT_MergedSrc=L2008-1171
17D80 TANGUT IDEOGRAPH-#17D80, TGT_MergedSrc=L2008-1315
17D81 TANGUT IDEOGRAPH-#17D81, TGT_MergedSrc=L2008-0692
17D82 TANGUT IDEOGRAPH-#17D82, TGT_MergedSrc=L2008-1872
17D83 TANGUT IDEOGRAPH-#17D83, TGT_MergedSrc=L2008-1733
17D84 TANGUT IDEOGRAPH-#17D84, TGT_MergedSrc=L2008-0704
17D85 TANGUT IDEOGRAPH-#17D85, TGT_MergedSrc=L2008-1354
17D86 TANGUT IDEOGRAPH-#17D86, TGT_MergedSrc=L2008-1256
17D87 TANGUT IDEOGRAPH-#17D87, TGT_MergedSrc=L2008-1864
17D88 TANGUT IDEOGRAPH-#17D88, TGT_MergedSrc=L2008-1757
17D89 TANGUT IDEOGRAPH-#17D89, TGT_MergedSrc=L2008-1781
17D8A TANGUT IDEOGRAPH-#17D8A, TGT_MergedSrc=L2008-1674
17D8B TANGUT IDEOGRAPH-#17D8B, TGT_MergedSrc=L2008-1782
17D8C TANGUT IDEOGRAPH-#17D8C, TGT_MergedSrc=L2006-6014
17D8D TANGUT IDEOGRAPH-#17D8D, TGT_MergedSrc=L2008-1172
17D8E TANGUT IDEOGRAPH-#17D8E, TGT_MergedSrc=L2008-0574
17D8F TANGUT IDEOGRAPH-#17D8F, TGT_MergedSrc=L2008-1401
17D90 TANGUT IDEOGRAPH-#17D90, TGT_MergedSrc=L2008-1232
17D91 TANGUT IDEOGRAPH-#17D91, TGT_MergedSrc=L2008-6012
17D92 TANGUT IDEOGRAPH-#17D92, TGT_MergedSrc=H2004-A-5841
17D93 TANGUT IDEOGRAPH-#17D93, TGT_MergedSrc=L2008-0348
17D94 TANGUT IDEOGRAPH-#17D94, TGT_MergedSrc=L2008-1726
17D95 TANGUT IDEOGRAPH-#17D95, TGT_MergedSrc=L2008-1692
17D96 TANGUT IDEOGRAPH-#17D96, TGT_MergedSrc=L2008-6021
17D97 TANGUT IDEOGRAPH-#17D97, TGT_MergedSrc=L2008-1131
17D98 TANGUT IDEOGRAPH-#17D98, TGT_MergedSrc=L2008-1039
17D99 TANGUT IDEOGRAPH-#17D99, TGT_MergedSrc=L2008-0514
17D9A TANGUT IDEOGRAPH-#17D9A, TGT_MergedSrc=L2008-0213
17D9B TANGUT IDEOGRAPH-#17D9B, TGT_MergedSrc=L2008-0195
17D9C TANGUT IDEOGRAPH-#17D9C, TGT_MergedSrc=L2008-0905
17D9D TANGUT IDEOGRAPH-#17D9D, TGT_MergedSrc=L2008-0899
17D9E TANGUT IDEOGRAPH-#17D9E, TGT_MergedSrc=L2008-5490
17D9F TANGUT IDEOGRAPH-#17D9F, TGT_MergedSrc=L2008-0906
17DA0 TANGUT IDEOGRAPH-#17DA0, TGT_MergedSrc=L2008-2396
17DA1 TANGUT IDEOGRAPH-#17DA1, TGT_MergedSrc=L2008-5491
17DA2 TANGUT IDEOGRAPH-#17DA2, TGT_MergedSrc=L2008-0908
17DA3 TANGUT IDEOGRAPH-#17DA3, TGT_MergedSrc=L2008-2573
17DA4 TANGUT IDEOGRAPH-#17DA4, TGT_MergedSrc=L2008-0475
17DA5 TANGUT IDEOGRAPH-#17DA5, TGT_MergedSrc=L2008-0907
17DA6 TANGUT IDEOGRAPH-#17DA6, TGT_MergedSrc=L2008-1576
17DA7 TANGUT IDEOGRAPH-#17DA7, TGT_MergedSrc=L2008-2397
17DA8 TANGUT IDEOGRAPH-#17DA8, TGT_MergedSrc=L2008-2995
17DA9 TANGUT IDEOGRAPH-#17DA9, TGT_MergedSrc=L2008-2574
17DAA TANGUT IDEOGRAPH-#17DAA, TGT_MergedSrc=L2008-5862
17DAB TANGUT IDEOGRAPH-#17DAB, TGT_MergedSrc=L2008-2996
17DAC TANGUT IDEOGRAPH-#17DAC, TGT_MergedSrc=N1966-319-114
17DAD TANGUT IDEOGRAPH-#17DAD, TGT_MergedSrc=L2008-5062
17DAE TANGUT IDEOGRAPH-#17DAE, TGT_MergedSrc=L2008-0155
17DAF TANGUT IDEOGRAPH-#17DAF, TGT_MergedSrc=L2008-5492
17DB0 TANGUT IDEOGRAPH-#17DB0, TGT_MergedSrc=L2008-3520
17DB1 TANGUT IDEOGRAPH-#17DB1, TGT_MergedSrc=L2008-4479
17DB2 TANGUT IDEOGRAPH-#17DB2, TGT_MergedSrc=L2008-4478
17DB3 TANGUT IDEOGRAPH-#17DB3, TGT_MergedSrc=L2008-4473
17DB4 TANGUT IDEOGRAPH-#17DB4, TGT_MergedSrc=L2008-4475
17DB5 TANGUT IDEOGRAPH-#17DB5, TGT_MergedSrc=L2008-4472
17DB6 TANGUT IDEOGRAPH-#17DB6, TGT_MergedSrc=L2008-4496
17DB7 TANGUT IDEOGRAPH-#17DB7, TGT_MergedSrc=L2008-4481
17DB8 TANGUT IDEOGRAPH-#17DB8, TGT_MergedSrc=L2008-4498
17DB9 TANGUT IDEOGRAPH-#17DB9, TGT_MergedSrc=L2008-4469
17DBA TANGUT IDEOGRAPH-#17DBA, TGT_MergedSrc=L2008-4471
17DBB TANGUT IDEOGRAPH-#17DBB, TGT_MergedSrc=L2008-4482
17DBC TANGUT IDEOGRAPH-#17DBC, TGT_MergedSrc=L2008-4492
17DBD TANGUT IDEOGRAPH-#17DBD, TGT_MergedSrc=L2008-4488
17DBE TANGUT IDEOGRAPH-#17DBE, TGT_MergedSrc=L2008-4474
17DBF TANGUT IDEOGRAPH-#17DBF, TGT_MergedSrc=L2008-4484
17DC0 TANGUT IDEOGRAPH-#17DC0, TGT_MergedSrc=L2008-4500
17DC1 TANGUT IDEOGRAPH-#17DC1, TGT_MergedSrc=L2008-4497
17DC2 TANGUT IDEOGRAPH-#17DC2, TGT_MergedSrc=L2008-4470
17DC3 TANGUT IDEOGRAPH-#17DC3, TGT_MergedSrc=L2008-4491
17DC4 TANGUT IDEOGRAPH-#17DC4, TGT_MergedSrc=L2008-4477
17DC5 TANGUT IDEOGRAPH-#17DC5, TGT_MergedSrc=L2008-4502
17DC6 TANGUT IDEOGRAPH-#17DC6, TGT_MergedSrc=L2008-4489
17DC7 TANGUT IDEOGRAPH-#17DC7, TGT_MergedSrc=L2008-4490
17DC8 TANGUT IDEOGRAPH-#17DC8, TGT_MergedSrc=L2008-4483
17DC9 TANGUT IDEOGRAPH-#17DC9, TGT_MergedSrc=L2008-4501
17DCA TANGUT IDEOGRAPH-#17DCA, TGT_MergedSrc=L2008-6054
17DCB TANGUT IDEOGRAPH-#17DCB, TGT_MergedSrc=H2004-A-5844
17DCC TANGUT IDEOGRAPH-#17DCC, TGT_MergedSrc=L2008-4494
17DCD TANGUT IDEOGRAPH-#17DCD, TGT_MergedSrc=L2008-4493
17DCE TANGUT IDEOGRAPH-#17DCE, TGT_MergedSrc=L2008-4480
17DCF TANGUT IDEOGRAPH-#17DCF, TGT_MergedSrc=L2008-4495
17DD0 TANGUT IDEOGRAPH-#17DD0, TGT_MergedSrc=L2008-4499
17DD1 TANGUT IDEOGRAPH-#17DD1, TGT_MergedSrc=L2008-4486
17DD2 TANGUT IDEOGRAPH-#17DD2, TGT_MergedSrc=H2004-A-5845
17DD3 TANGUT IDEOGRAPH-#17DD3, TGT_MergedSrc=L2008-6053
17DD4 TANGUT IDEOGRAPH-#17DD4, TGT_MergedSrc=L2008-4487
17DD5 TANGUT IDEOGRAPH-#17DD5, TGT_MergedSrc=L2008-4476
17DD6 TANGUT IDEOGRAPH-#17DD6, TGT_MergedSrc=L2008-4485
17DD7 TANGUT IDEOGRAPH-#17DD7, TGT_MergedSrc=L2008-6052
17DD8 TANGUT IDEOGRAPH-#17DD8, TGT_MergedSrc=L2008-0651
17DD9 TANGUT IDEOGRAPH-#17DD9, TGT_MergedSrc=L2008-1065
17DDA TANGUT IDEOGRAPH-#17DDA, TGT_MergedSrc=L2008-0991
17DDB TANGUT IDEOGRAPH-#17DDB, TGT_MergedSrc=L2008-1629
17DDC TANGUT IDEOGRAPH-#17DDC, TGT_MergedSrc=L2008-0917
17DDD TANGUT IDEOGRAPH-#17DDD, TGT_MergedSrc=L2008-1064
17DDE TANGUT IDEOGRAPH-#17DDE, TGT_MergedSrc=L2008-0217
17DDF TANGUT IDEOGRAPH-#17DDF, TGT_MergedSrc=L2008-0918
17DE0 TANGUT IDEOGRAPH-#17DE0, TGT_MergedSrc=L2008-0157
17DE1 TANGUT IDEOGRAPH-#17DE1, TGT_MergedSrc=L2008-0484
17DE2 TANGUT IDEOGRAPH-#17DE2, TGT_MergedSrc=L2008-1843
17DE3 TANGUT IDEOGRAPH-#17DE3, TGT_MergedSrc=L2008-1585
17DE4 TANGUT IDEOGRAPH-#17DE4, TGT_MergedSrc=L2008-0767
17DE5 TANGUT IDEOGRAPH-#17DE5, TGT_MergedSrc=L2008-0513
17DE6 TANGUT IDEOGRAPH-#17DE6, TGT_MergedSrc=L2008-0190
17DE7 TANGUT IDEOGRAPH-#17DE7, TGT_MergedSrc=L2008-1051
17DE8 TANGUT IDEOGRAPH-#17DE8, TGT_MergedSrc=L2008-1665
17DE9 TANGUT IDEOGRAPH-#17DE9, TGT_MergedSrc=L2008-1605
17DEA TANGUT IDEOGRAPH-#17DEA, TGT_MergedSrc=L2008-1112
17DEB TANGUT IDEOGRAPH-#17DEB, TGT_MergedSrc=L2008-1120
17DEC TANGUT IDEOGRAPH-#17DEC, TGT_MergedSrc=L2008-1449
17DED TANGUT IDEOGRAPH-#17DED, TGT_MergedSrc=L2008-0830
17DEE TANGUT IDEOGRAPH-#17DEE, TGT_MergedSrc=L2008-0403
17DEF TANGUT IDEOGRAPH-#17DEF, TGT_MergedSrc=L2008-0422
17DF0 TANGUT IDEOGRAPH-#17DF0, TGT_MergedSrc=L2008-0613
17DF1 TANGUT IDEOGRAPH-#17DF1, TGT_MergedSrc=L2008-1790
17DF2 TANGUT IDEOGRAPH-#17DF2, TGT_MergedSrc=L2008-1478
17DF3 TANGUT IDEOGRAPH-#17DF3, TGT_MergedSrc=L2008-1463
17DF4 TANGUT IDEOGRAPH-#17DF4, TGT_MergedSrc=L2008-0423
17DF5 TANGUT IDEOGRAPH-#17DF5, TGT_MergedSrc=L2008-0412
17DF6 TANGUT IDEOGRAPH-#17DF6, TGT_MergedSrc=L2008-0408
17DF7 TANGUT IDEOGRAPH-#17DF7, TGT_MergedSrc=L2008-0721
17DF8 TANGUT IDEOGRAPH-#17DF8, TGT_MergedSrc=L2008-1448
17DF9 TANGUT IDEOGRAPH-#17DF9, TGT_MergedSrc=L2008-1464
17DFA TANGUT IDEOGRAPH-#17DFA, TGT_MergedSrc=L2008-0409
17DFB TANGUT IDEOGRAPH-#17DFB, TGT_MergedSrc=L2008-0424
17DFC TANGUT IDEOGRAPH-#17DFC, TGT_MergedSrc=L2008-0616
17DFD TANGUT IDEOGRAPH-#17DFD, TGT_MergedSrc=S1968-0333
17DFE TANGUT IDEOGRAPH-#17DFE, TGT_MergedSrc=L2008-1465
17DFF TANGUT IDEOGRAPH-#17DFF, TGT_MergedSrc=L2008-1803
17E00 TANGUT IDEOGRAPH-#17E00, TGT_MergedSrc=L2008-1786
17E01 TANGUT IDEOGRAPH-#17E01, TGT_MergedSrc=L2008-1800
17E02 TANGUT IDEOGRAPH-#17E02, TGT_MergedSrc=L2008-0606
17E03 TANGUT IDEOGRAPH-#17E03, TGT_MergedSrc=L2008-0410
17E04 TANGUT IDEOGRAPH-#17E04, TGT_MergedSrc=L2008-1804
17E05 TANGUT IDEOGRAPH-#17E05, TGT_MergedSrc=L2008-1466
17E06 TANGUT IDEOGRAPH-#17E06, TGT_MergedSrc=L2008-1467
17E07 TANGUT IDEOGRAPH-#17E07, TGT_MergedSrc=L2008-1438
17E08 TANGUT IDEOGRAPH-#17E08, TGT_MergedSrc=L2008-0406-0407
17E09 TANGUT IDEOGRAPH-#17E09, TGT_MergedSrc=L2008-1807
17E0A TANGUT IDEOGRAPH-#17E0A, TGT_MergedSrc=L2008-0833
17E0B TANGUT IDEOGRAPH-#17E0B, TGT_MergedSrc=L2008-1435
17E0C TANGUT IDEOGRAPH-#17E0C, TGT_MergedSrc=L2008-0832
17E0D TANGUT IDEOGRAPH-#17E0D, TGT_MergedSrc=L2008-0415
17E0E TANGUT IDEOGRAPH-#17E0E, TGT_MergedSrc=L2008-0610
17E0F TANGUT IDEOGRAPH-#17E0F, TGT_MergedSrc=L2008-1479
17E10 TANGUT IDEOGRAPH-#17E10, TGT_MergedSrc=L2008-1474
17E11 TANGUT IDEOGRAPH-#17E11, TGT_MergedSrc=L2008-0617
17E12 TANGUT IDEOGRAPH-#17E12, TGT_MergedSrc=L2008-1473
17E13 TANGUT IDEOGRAPH-#17E13, TGT_MergedSrc=L2008-0425
17E14 TANGUT IDEOGRAPH-#17E14, TGT_MergedSrc=L2008-0887
17E15 TANGUT IDEOGRAPH-#17E15, TGT_MergedSrc=L2008-0074
17E16 TANGUT IDEOGRAPH-#17E16, TGT_MergedSrc=L2008-0555
17E17 TANGUT IDEOGRAPH-#17E17, TGT_MergedSrc=L2008-0528
17E18 TANGUT IDEOGRAPH-#17E18, TGT_MergedSrc=L2008-0316
17E19 TANGUT IDEOGRAPH-#17E19, TGT_MergedSrc=L2008-0861
17E1A TANGUT IDEOGRAPH-#17E1A, TGT_MergedSrc=L2008-1873
17E1B TANGUT IDEOGRAPH-#17E1B, TGT_MergedSrc=L2008-0783
17E1C TANGUT IDEOGRAPH-#17E1C, TGT_MergedSrc=L2008-1705
17E1D TANGUT IDEOGRAPH-#17E1D, TGT_MergedSrc=L2008-1704
17E1E TANGUT IDEOGRAPH-#17E1E, TGT_MergedSrc=L2008-0317
17E1F TANGUT IDEOGRAPH-#17E1F, TGT_MergedSrc=L2008-0533
17E20 TANGUT IDEOGRAPH-#17E20, TGT_MergedSrc=L2008-0256
17E21 TANGUT IDEOGRAPH-#17E21, TGT_MergedSrc=L2008-0482
17E22 TANGUT IDEOGRAPH-#17E22, TGT_MergedSrc=L2008-0184-4510
17E23 TANGUT IDEOGRAPH-#17E23, TGT_MergedSrc=L2008-0644
17E24 TANGUT IDEOGRAPH-#17E24, TGT_MergedSrc=L2008-1134-4624
17E25 TANGUT IDEOGRAPH-#17E25, TGT_MergedSrc=L2008-1625
17E26 TANGUT IDEOGRAPH-#17E26, TGT_MergedSrc=L2008-0545
17E27 TANGUT IDEOGRAPH-#17E27, TGT_MergedSrc=L2008-1415
17E28 TANGUT IDEOGRAPH-#17E28, TGT_MergedSrc=L2008-1423
17E29 TANGUT IDEOGRAPH-#17E29, TGT_MergedSrc=L2008-0384
17E2A TANGUT IDEOGRAPH-#17E2A, TGT_MergedSrc=L2008-1257
17E2B TANGUT IDEOGRAPH-#17E2B, TGT_MergedSrc=L2008-1694
17E2C TANGUT IDEOGRAPH-#17E2C, TGT_MergedSrc=L2008-1669
17E2D TANGUT IDEOGRAPH-#17E2D, TGT_MergedSrc=L2008-0894
17E2E TANGUT IDEOGRAPH-#17E2E, TGT_MergedSrc=L2008-1293
17E2F TANGUT IDEOGRAPH-#17E2F, TGT_MergedSrc=L2008-1220
17E30 TANGUT IDEOGRAPH-#17E30, TGT_MergedSrc=L2008-1258
17E31 TANGUT IDEOGRAPH-#17E31, TGT_MergedSrc=L2008-0276
17E32 TANGUT IDEOGRAPH-#17E32, TGT_MergedSrc=L2008-1368
17E33 TANGUT IDEOGRAPH-#17E33, TGT_MergedSrc=L2008-1695
17E34 TANGUT IDEOGRAPH-#17E34, TGT_MergedSrc=L2008-0185
17E35 TANGUT IDEOGRAPH-#17E35, TGT_MergedSrc=L2008-0858
17E36 TANGUT IDEOGRAPH-#17E36, TGT_MergedSrc=L2008-0568
17E37 TANGUT IDEOGRAPH-#17E37, TGT_MergedSrc=L2008-1779
17E38 TANGUT IDEOGRAPH-#17E38, TGT_MergedSrc=L2008-0369
17E39 TANGUT IDEOGRAPH-#17E39, TGT_MergedSrc=L2008-0493
17E3A TANGUT IDEOGRAPH-#17E3A, TGT_MergedSrc=L2008-0485
17E3B TANGUT IDEOGRAPH-#17E3B, TGT_MergedSrc=L2008-0208
17E3C TANGUT IDEOGRAPH-#17E3C, TGT_MergedSrc=L2008-0198
17E3D TANGUT IDEOGRAPH-#17E3D, TGT_MergedSrc=L2008-0641
17E3E TANGUT IDEOGRAPH-#17E3E, TGT_MergedSrc=L2008-0656
17E3F TANGUT IDEOGRAPH-#17E3F, TGT_MergedSrc=L2008-0236
17E40 TANGUT IDEOGRAPH-#17E40, TGT_MergedSrc=L2008-0220
17E41 TANGUT IDEOGRAPH-#17E41, TGT_MergedSrc=L2008-1635
17E42 TANGUT IDEOGRAPH-#17E42, TGT_MergedSrc=L2008-0746
17E43 TANGUT IDEOGRAPH-#17E43, TGT_MergedSrc=L2008-0204
17E44 TANGUT IDEOGRAPH-#17E44, TGT_MergedSrc=L2008-0199
17E45 TANGUT IDEOGRAPH-#17E45, TGT_MergedSrc=L2008-1587
17E46 TANGUT IDEOGRAPH-#17E46, TGT_MergedSrc=L2008-6014
17E47 TANGUT IDEOGRAPH-#17E47, TGT_MergedSrc=L2008-0926
17E48 TANGUT IDEOGRAPH-#17E48, TGT_MergedSrc=L2008-1662
17E49 TANGUT IDEOGRAPH-#17E49, TGT_MergedSrc=L2008-0179
17E4A TANGUT IDEOGRAPH-#17E4A, TGT_MergedSrc=L2008-0211
17E4B TANGUT IDEOGRAPH-#17E4B, TGT_MergedSrc=L2008-1596
17E4C TANGUT IDEOGRAPH-#17E4C, TGT_MergedSrc=L2008-1597
17E4D TANGUT IDEOGRAPH-#17E4D, TGT_MergedSrc=L2008-1558
17E4E TANGUT IDEOGRAPH-#17E4E, TGT_MergedSrc=L2008-0637
17E4F TANGUT IDEOGRAPH-#17E4F, TGT_MergedSrc=L2008-0473
17E50 TANGUT IDEOGRAPH-#17E50, TGT_MergedSrc=L2008-1569
17E51 TANGUT IDEOGRAPH-#17E51, TGT_MergedSrc=L2008-1836
17E52 TANGUT IDEOGRAPH-#17E52, TGT_MergedSrc=L2008-1562
17E53 TANGUT IDEOGRAPH-#17E53, TGT_MergedSrc=L2008-0465
17E54 TANGUT IDEOGRAPH-#17E54, TGT_MergedSrc=L2008-0841
17E55 TANGUT IDEOGRAPH-#17E55, TGT_MergedSrc=L2008-1574
17E56 TANGUT IDEOGRAPH-#17E56, TGT_MergedSrc=L2008-1570
17E57 TANGUT IDEOGRAPH-#17E57, TGT_MergedSrc=L2008-0474
17E58 TANGUT IDEOGRAPH-#17E58, TGT_MergedSrc=L2008-1834
17E59 TANGUT IDEOGRAPH-#17E59, TGT_MergedSrc=L2008-0467
17E5A TANGUT IDEOGRAPH-#17E5A, TGT_MergedSrc=L2008-0631
17E5B TANGUT IDEOGRAPH-#17E5B, TGT_MergedSrc=L2008-0623
17E5C TANGUT IDEOGRAPH-#17E5C, TGT_MergedSrc=L2008-2388
17E5D TANGUT IDEOGRAPH-#17E5D, TGT_MergedSrc=L2008-1957
17E5E TANGUT IDEOGRAPH-#17E5E, TGT_MergedSrc=L2008-2391
17E5F TANGUT IDEOGRAPH-#17E5F, TGT_MergedSrc=L2008-3470
17E60 TANGUT IDEOGRAPH-#17E60, TGT_MergedSrc=L2008-2716
17E61 TANGUT IDEOGRAPH-#17E61, TGT_MergedSrc=L2008-1959
17E62 TANGUT IDEOGRAPH-#17E62, TGT_MergedSrc=L2008-1986
17E63 TANGUT IDEOGRAPH-#17E63, TGT_MergedSrc=L2008-2974
17E64 TANGUT IDEOGRAPH-#17E64, TGT_MergedSrc=L2008-1932
17E65 TANGUT IDEOGRAPH-#17E65, TGT_MergedSrc=L2008-2358
17E66 TANGUT IDEOGRAPH-#17E66, TGT_MergedSrc=L2008-3513
17E67 TANGUT IDEOGRAPH-#17E67, TGT_MergedSrc=L2008-1977
17E68 TANGUT IDEOGRAPH-#17E68, TGT_MergedSrc=L2008-2560
17E69 TANGUT IDEOGRAPH-#17E69, TGT_MergedSrc=L2008-2571
17E6A TANGUT IDEOGRAPH-#17E6A, TGT_MergedSrc=L2008-2393
17E6B TANGUT IDEOGRAPH-#17E6B, TGT_MergedSrc=L2008-2978
17E6C TANGUT IDEOGRAPH-#17E6C, TGT_MergedSrc=L2008-3469
17E6D TANGUT IDEOGRAPH-#17E6D, TGT_MergedSrc=L2008-1890
17E6E TANGUT IDEOGRAPH-#17E6E, TGT_MergedSrc=L2008-1931
17E6F TANGUT IDEOGRAPH-#17E6F, TGT_MergedSrc=L2008-1980
17E70 TANGUT IDEOGRAPH-#17E70, TGT_MergedSrc=L2008-2569
17E71 TANGUT IDEOGRAPH-#17E71, TGT_MergedSrc=L2008-2949
17E72 TANGUT IDEOGRAPH-#17E72, TGT_MergedSrc=L2008-2992
17E73 TANGUT IDEOGRAPH-#17E73, TGT_MergedSrc=L2008-2715
17E74 TANGUT IDEOGRAPH-#17E74, TGT_MergedSrc=L2008-1958
17E75 TANGUT IDEOGRAPH-#17E75, TGT_MergedSrc=L2008-2570
17E76 TANGUT IDEOGRAPH-#17E76, TGT_MergedSrc=L2008-2829
17E77 TANGUT IDEOGRAPH-#17E77, TGT_MergedSrc=L2008-2993
17E78 TANGUT IDEOGRAPH-#17E78, TGT_MergedSrc=L2008-2717
17E79 TANGUT IDEOGRAPH-#17E79, TGT_MergedSrc=L2008-3481
17E7A TANGUT IDEOGRAPH-#17E7A, TGT_MergedSrc=L2008-3765
17E7B TANGUT IDEOGRAPH-#17E7B, TGT_MergedSrc=L2008-3512
17E7C TANGUT IDEOGRAPH-#17E7C, TGT_MergedSrc=L2008-2718
17E7D TANGUT IDEOGRAPH-#17E7D, TGT_MergedSrc=L2008-2950
17E7E TANGUT IDEOGRAPH-#17E7E, TGT_MergedSrc=L2008-2951
17E7F TANGUT IDEOGRAPH-#17E7F, TGT_MergedSrc=L2008-2834
17E80 TANGUT IDEOGRAPH-#17E80, TGT_MergedSrc=L2008-1934
17E81 TANGUT IDEOGRAPH-#17E81, TGT_MergedSrc=L2008-1936
17E82 TANGUT IDEOGRAPH-#17E82, TGT_MergedSrc=L2008-1978
17E83 TANGUT IDEOGRAPH-#17E83, TGT_MergedSrc=L2008-3514
17E84 TANGUT IDEOGRAPH-#17E84, TGT_MergedSrc=L2008-4526
17E85 TANGUT IDEOGRAPH-#17E85, TGT_MergedSrc=L2008-4578
17E86 TANGUT IDEOGRAPH-#17E86, TGT_MergedSrc=L2008-2523
17E87 TANGUT IDEOGRAPH-#17E87, TGT_MergedSrc=L2008-3393
17E88 TANGUT IDEOGRAPH-#17E88, TGT_MergedSrc=L2008-3728
17E89 TANGUT IDEOGRAPH-#17E89, TGT_MergedSrc=L2008-4018
17E8A TANGUT IDEOGRAPH-#17E8A, TGT_MergedSrc=L2008-4035
17E8B TANGUT IDEOGRAPH-#17E8B, TGT_MergedSrc=L2008-4017
17E8C TANGUT IDEOGRAPH-#17E8C, TGT_MergedSrc=L2008-4047
17E8D TANGUT IDEOGRAPH-#17E8D, TGT_MergedSrc=L2008-4036
17E8E TANGUT IDEOGRAPH-#17E8E, TGT_MergedSrc=L2008-4059
17E8F TANGUT IDEOGRAPH-#17E8F, TGT_MergedSrc=L2008-4058
17E90 TANGUT IDEOGRAPH-#17E90, TGT_MergedSrc=L2008-2548
17E91 TANGUT IDEOGRAPH-#17E91, TGT_MergedSrc=L2008-2027-2350
17E92 TANGUT IDEOGRAPH-#17E92, TGT_MergedSrc=L2008-2591
17E93 TANGUT IDEOGRAPH-#17E93, TGT_MergedSrc=L2008-3756
17E94 TANGUT IDEOGRAPH-#17E94, TGT_MergedSrc=L2008-2352
17E95 TANGUT IDEOGRAPH-#17E95, TGT_MergedSrc=L2008-3255
17E96 TANGUT IDEOGRAPH-#17E96, TGT_MergedSrc=L2008-3256
17E97 TANGUT IDEOGRAPH-#17E97, TGT_MergedSrc=L2008-3335
17E98 TANGUT IDEOGRAPH-#17E98, TGT_MergedSrc=L2008-2142
17E99 TANGUT IDEOGRAPH-#17E99, TGT_MergedSrc=L2008-2271
17E9A TANGUT IDEOGRAPH-#17E9A, TGT_MergedSrc=L2008-2279
17E9B TANGUT IDEOGRAPH-#17E9B, TGT_MergedSrc=L2008-3244
17E9C TANGUT IDEOGRAPH-#17E9C, TGT_MergedSrc=L2008-3650
17E9D TANGUT IDEOGRAPH-#17E9D, TGT_MergedSrc=L2008-3336
17E9E TANGUT IDEOGRAPH-#17E9E, TGT_MergedSrc=L2008-2787
17E9F TANGUT IDEOGRAPH-#17E9F, TGT_MergedSrc=L2008-3246
17EA0 TANGUT IDEOGRAPH-#17EA0, TGT_MergedSrc=L2008-2277
17EA1 TANGUT IDEOGRAPH-#17EA1, TGT_MergedSrc=L2008-2506
17EA2 TANGUT IDEOGRAPH-#17EA2, TGT_MergedSrc=L2008-2155
17EA3 TANGUT IDEOGRAPH-#17EA3, TGT_MergedSrc=L2008-2443
17EA4 TANGUT IDEOGRAPH-#17EA4, TGT_MergedSrc=L2008-2676
17EA5 TANGUT IDEOGRAPH-#17EA5, TGT_MergedSrc=L2008-3795
17EA6 TANGUT IDEOGRAPH-#17EA6, TGT_MergedSrc=L2008-3651
17EA7 TANGUT IDEOGRAPH-#17EA7, TGT_MergedSrc=L2008-3373
17EA8 TANGUT IDEOGRAPH-#17EA8, TGT_MergedSrc=L2008-3338
17EA9 TANGUT IDEOGRAPH-#17EA9, TGT_MergedSrc=L2008-2158
17EAA TANGUT IDEOGRAPH-#17EAA, TGT_MergedSrc=L2008-2147
17EAB TANGUT IDEOGRAPH-#17EAB, TGT_MergedSrc=L2008-2280
17EAC TANGUT IDEOGRAPH-#17EAC, TGT_MergedSrc=L2008-2157
17EAD TANGUT IDEOGRAPH-#17EAD, TGT_MergedSrc=L2008-2156
17EAE TANGUT IDEOGRAPH-#17EAE, TGT_MergedSrc=L2008-3701
17EAF TANGUT IDEOGRAPH-#17EAF, TGT_MergedSrc=L2008-2517
17EB0 TANGUT IDEOGRAPH-#17EB0, TGT_MergedSrc=L2008-2505
17EB1 TANGUT IDEOGRAPH-#17EB1, TGT_MergedSrc=L2008-2500
17EB2 TANGUT IDEOGRAPH-#17EB2, TGT_MergedSrc=L2008-3257
17EB3 TANGUT IDEOGRAPH-#17EB3, TGT_MergedSrc=L2008-2677
17EB4 TANGUT IDEOGRAPH-#17EB4, TGT_MergedSrc=L2008-3603
17EB5 TANGUT IDEOGRAPH-#17EB5, TGT_MergedSrc=L2008-3793
17EB6 TANGUT IDEOGRAPH-#17EB6, TGT_MergedSrc=L2008-3785
17EB7 TANGUT IDEOGRAPH-#17EB7, TGT_MergedSrc=L2008-3695
17EB8 TANGUT IDEOGRAPH-#17EB8, TGT_MergedSrc=L2008-3164
17EB9 TANGUT IDEOGRAPH-#17EB9, TGT_MergedSrc=L2008-3379
17EBA TANGUT IDEOGRAPH-#17EBA, TGT_MergedSrc=L2008-2456
17EBB TANGUT IDEOGRAPH-#17EBB, TGT_MergedSrc=L2008-3339
17EBC TANGUT IDEOGRAPH-#17EBC, TGT_MergedSrc=L2008-2446
17EBD TANGUT IDEOGRAPH-#17EBD, TGT_MergedSrc=L2008-2794
17EBE TANGUT IDEOGRAPH-#17EBE, TGT_MergedSrc=L2008-2159
17EBF TANGUT IDEOGRAPH-#17EBF, TGT_MergedSrc=L2008-2886
17EC0 TANGUT IDEOGRAPH-#17EC0, TGT_MergedSrc=L2008-3337
17EC1 TANGUT IDEOGRAPH-#17EC1, TGT_MergedSrc=L2008-2788
17EC2 TANGUT IDEOGRAPH-#17EC2, TGT_MergedSrc=L2008-2166
17EC3 TANGUT IDEOGRAPH-#17EC3, TGT_MergedSrc=L2008-6046
17EC4 TANGUT IDEOGRAPH-#17EC4, TGT_MergedSrc=L2008-2445
17EC5 TANGUT IDEOGRAPH-#17EC5, TGT_MergedSrc=L2008-3346
17EC6 TANGUT IDEOGRAPH-#17EC6, TGT_MergedSrc=L2008-2687
17EC7 TANGUT IDEOGRAPH-#17EC7, TGT_MergedSrc=L2008-2622
17EC8 TANGUT IDEOGRAPH-#17EC8, TGT_MergedSrc=L2008-2678
17EC9 TANGUT IDEOGRAPH-#17EC9, TGT_MergedSrc=L2008-3604
17ECA TANGUT IDEOGRAPH-#17ECA, TGT_MergedSrc=L2008-3699
17ECB TANGUT IDEOGRAPH-#17ECB, TGT_MergedSrc=L2008-3719
17ECC TANGUT IDEOGRAPH-#17ECC, TGT_MergedSrc=L2008-3605
17ECD TANGUT IDEOGRAPH-#17ECD, TGT_MergedSrc=L2008-3806
17ECE TANGUT IDEOGRAPH-#17ECE, TGT_MergedSrc=L2008-3153
17ECF TANGUT IDEOGRAPH-#17ECF, TGT_MergedSrc=L2008-2509
17ED0 TANGUT IDEOGRAPH-#17ED0, TGT_MergedSrc=L2008-3347
17ED1 TANGUT IDEOGRAPH-#17ED1, TGT_MergedSrc=L2008-2795
17ED2 TANGUT IDEOGRAPH-#17ED2, TGT_MergedSrc=L2008-2161
17ED3 TANGUT IDEOGRAPH-#17ED3, TGT_MergedSrc=L2008-2272
17ED4 TANGUT IDEOGRAPH-#17ED4, TGT_MergedSrc=L2008-2289
17ED5 TANGUT IDEOGRAPH-#17ED5, TGT_MergedSrc=L2008-2170
17ED6 TANGUT IDEOGRAPH-#17ED6, TGT_MergedSrc=L2008-2508
17ED7 TANGUT IDEOGRAPH-#17ED7, TGT_MergedSrc=L2008-2502
17ED8 TANGUT IDEOGRAPH-#17ED8, TGT_MergedSrc=L2008-2281
17ED9 TANGUT IDEOGRAPH-#17ED9, TGT_MergedSrc=L2008-3653
17EDA TANGUT IDEOGRAPH-#17EDA, TGT_MergedSrc=L2008-3700
17EDB TANGUT IDEOGRAPH-#17EDB, TGT_MergedSrc=L2008-2792
17EDC TANGUT IDEOGRAPH-#17EDC, TGT_MergedSrc=L2008-3648
17EDD TANGUT IDEOGRAPH-#17EDD, TGT_MergedSrc=L2008-3374
17EDE TANGUT IDEOGRAPH-#17EDE, TGT_MergedSrc=L2008-2169
17EDF TANGUT IDEOGRAPH-#17EDF, TGT_MergedSrc=L2008-3245
17EE0 TANGUT IDEOGRAPH-#17EE0, TGT_MergedSrc=L2008-3161
17EE1 TANGUT IDEOGRAPH-#17EE1, TGT_MergedSrc=L2008-3344
17EE2 TANGUT IDEOGRAPH-#17EE2, TGT_MergedSrc=L2008-2167
17EE3 TANGUT IDEOGRAPH-#17EE3, TGT_MergedSrc=L2008-2793
17EE4 TANGUT IDEOGRAPH-#17EE4, TGT_MergedSrc=L2008-2501
17EE5 TANGUT IDEOGRAPH-#17EE5, TGT_MergedSrc=L2008-6033
17EE6 TANGUT IDEOGRAPH-#17EE6, TGT_MergedSrc=L2008-3609
17EE7 TANGUT IDEOGRAPH-#17EE7, TGT_MergedSrc=L2008-2160
17EE8 TANGUT IDEOGRAPH-#17EE8, TGT_MergedSrc=L2008-3165
17EE9 TANGUT IDEOGRAPH-#17EE9, TGT_MergedSrc=L2008-3166
17EEA TANGUT IDEOGRAPH-#17EEA, TGT_MergedSrc=L2008-3247
17EEB TANGUT IDEOGRAPH-#17EEB, TGT_MergedSrc=L2008-2789
17EEC TANGUT IDEOGRAPH-#17EEC, TGT_MergedSrc=L2008-3380
17EED TANGUT IDEOGRAPH-#17EED, TGT_MergedSrc=L2008-2168
17EEE TANGUT IDEOGRAPH-#17EEE, TGT_MergedSrc=L2008-2880
17EEF TANGUT IDEOGRAPH-#17EEF, TGT_MergedSrc=L2008-2808
17EF0 TANGUT IDEOGRAPH-#17EF0, TGT_MergedSrc=L2008-3704
17EF1 TANGUT IDEOGRAPH-#17EF1, TGT_MergedSrc=L2008-3610
17EF2 TANGUT IDEOGRAPH-#17EF2, TGT_MergedSrc=L2008-3348
17EF3 TANGUT IDEOGRAPH-#17EF3, TGT_MergedSrc=L2008-3375
17EF4 TANGUT IDEOGRAPH-#17EF4, TGT_MergedSrc=L2008-2881
17EF5 TANGUT IDEOGRAPH-#17EF5, TGT_MergedSrc=L2008-2278
17EF6 TANGUT IDEOGRAPH-#17EF6, TGT_MergedSrc=L2008-3162
17EF7 TANGUT IDEOGRAPH-#17EF7, TGT_MergedSrc=L2008-3705
17EF8 TANGUT IDEOGRAPH-#17EF8, TGT_MergedSrc=L2008-2148
17EF9 TANGUT IDEOGRAPH-#17EF9, TGT_MergedSrc=L2008-6040
17EFA TANGUT IDEOGRAPH-#17EFA, TGT_MergedSrc=L2008-3794
17EFB TANGUT IDEOGRAPH-#17EFB, TGT_MergedSrc=L2008-2507
17EFC TANGUT IDEOGRAPH-#17EFC, TGT_MergedSrc=L2008-2256
17EFD TANGUT IDEOGRAPH-#17EFD, TGT_MergedSrc=L2008-2174
17EFE TANGUT IDEOGRAPH-#17EFE, TGT_MergedSrc=L2008-2213
17EFF TANGUT IDEOGRAPH-#17EFF, TGT_MergedSrc=L2008-3585
17F00 TANGUT IDEOGRAPH-#17F00, TGT_MergedSrc=L2008-3152
17F01 TANGUT IDEOGRAPH-#17F01, TGT_MergedSrc=L2008-3269
17F02 TANGUT IDEOGRAPH-#17F02, TGT_MergedSrc=L2008-2200
17F03 TANGUT IDEOGRAPH-#17F03, TGT_MergedSrc=L2008-2544
17F04 TANGUT IDEOGRAPH-#17F04, TGT_MergedSrc=L2008-2341
17F05 TANGUT IDEOGRAPH-#17F05, TGT_MergedSrc=L2008-3434
17F06 TANGUT IDEOGRAPH-#17F06, TGT_MergedSrc=L2008-2335
17F07 TANGUT IDEOGRAPH-#17F07, TGT_MergedSrc=L2008-2344
17F08 TANGUT IDEOGRAPH-#17F08, TGT_MergedSrc=L2008-2546
17F09 TANGUT IDEOGRAPH-#17F09, TGT_MergedSrc=L2008-3751
17F0A TANGUT IDEOGRAPH-#17F0A, TGT_MergedSrc=L2008-3429
17F0B TANGUT IDEOGRAPH-#17F0B, TGT_MergedSrc=L2008-3442
17F0C TANGUT IDEOGRAPH-#17F0C, TGT_MergedSrc=L2008-2348
17F0D TANGUT IDEOGRAPH-#17F0D, TGT_MergedSrc=L2008-3435-3436
17F0E TANGUT IDEOGRAPH-#17F0E, TGT_MergedSrc=L2008-3752
17F0F TANGUT IDEOGRAPH-#17F0F, TGT_MergedSrc=L2008-3443
17F10 TANGUT IDEOGRAPH-#17F10, TGT_MergedSrc=L2008-2345
17F11 TANGUT IDEOGRAPH-#17F11, TGT_MergedSrc=L2008-2814
17F12 TANGUT IDEOGRAPH-#17F12, TGT_MergedSrc=L2008-2815
17F13 TANGUT IDEOGRAPH-#17F13, TGT_MergedSrc=L2008-2349
17F14 TANGUT IDEOGRAPH-#17F14, TGT_MergedSrc=L2008-2336
17F15 TANGUT IDEOGRAPH-#17F15, TGT_MergedSrc=L2008-2342
17F16 TANGUT IDEOGRAPH-#17F16, TGT_MergedSrc=L2008-2545
17F17 TANGUT IDEOGRAPH-#17F17, TGT_MergedSrc=L2008-3433
17F18 TANGUT IDEOGRAPH-#17F18, TGT_MergedSrc=L2008-3749
17F19 TANGUT IDEOGRAPH-#17F19, TGT_MergedSrc=L2008-2813
17F1A TANGUT IDEOGRAPH-#17F1A, TGT_MergedSrc=L2008-3437
17F1B TANGUT IDEOGRAPH-#17F1B, TGT_MergedSrc=L2008-2547
17F1C TANGUT IDEOGRAPH-#17F1C, TGT_MergedSrc=L2008-2337
17F1D TANGUT IDEOGRAPH-#17F1D, TGT_MergedSrc=L2008-2816
17F1E TANGUT IDEOGRAPH-#17F1E, TGT_MergedSrc=L2008-3753
17F1F TANGUT IDEOGRAPH-#17F1F, TGT_MergedSrc=L2008-3750
17F20 TANGUT IDEOGRAPH-#17F20, TGT_MergedSrc=L2008-3438
17F21 TANGUT IDEOGRAPH-#17F21, TGT_MergedSrc=L2008-3439
17F22 TANGUT IDEOGRAPH-#17F22, TGT_MergedSrc=L2008-3754
17F23 TANGUT IDEOGRAPH-#17F23, TGT_MergedSrc=L2008-2338
17F24 TANGUT IDEOGRAPH-#17F24, TGT_MergedSrc=L2008-2340
17F25 TANGUT IDEOGRAPH-#17F25, TGT_MergedSrc=L2008-3440
17F26 TANGUT IDEOGRAPH-#17F26, TGT_MergedSrc=L2008-2346
17F27 TANGUT IDEOGRAPH-#17F27, TGT_MergedSrc=L2008-6037
17F28 TANGUT IDEOGRAPH-#17F28, TGT_MergedSrc=L2008-2339
17F29 TANGUT IDEOGRAPH-#17F29, TGT_MergedSrc=L2008-3441
17F2A TANGUT IDEOGRAPH-#17F2A, TGT_MergedSrc=L2008-3430
17F2B TANGUT IDEOGRAPH-#17F2B, TGT_MergedSrc=L2008-3748
17F2C TANGUT IDEOGRAPH-#17F2C, TGT_MergedSrc=L2008-2343
17F2D TANGUT IDEOGRAPH-#17F2D, TGT_MergedSrc=L2008-2347
17F2E TANGUT IDEOGRAPH-#17F2E, TGT_MergedSrc=L2008-3431
17F2F TANGUT IDEOGRAPH-#17F2F, TGT_MergedSrc=L2008-2433
17F30 TANGUT IDEOGRAPH-#17F30, TGT_MergedSrc=L2008-3184
17F31 TANGUT IDEOGRAPH-#17F31, TGT_MergedSrc=L2008-2068
17F32 TANGUT IDEOGRAPH-#17F32, TGT_MergedSrc=L2008-2804
17F33 TANGUT IDEOGRAPH-#17F33, TGT_MergedSrc=L2008-2069
17F34 TANGUT IDEOGRAPH-#17F34, TGT_MergedSrc=L2008-2218
17F35 TANGUT IDEOGRAPH-#17F35, TGT_MergedSrc=L2008-2635
17F36 TANGUT IDEOGRAPH-#17F36, TGT_MergedSrc=L2008-3362
17F37 TANGUT IDEOGRAPH-#17F37, TGT_MergedSrc=L2008-2145
17F38 TANGUT IDEOGRAPH-#17F38, TGT_MergedSrc=L2008-2077
17F39 TANGUT IDEOGRAPH-#17F39, TGT_MergedSrc=L2008-2207
17F3A TANGUT IDEOGRAPH-#17F3A, TGT_MergedSrc=L2008-2498
17F3B TANGUT IDEOGRAPH-#17F3B, TGT_MergedSrc=L2008-2627
17F3C TANGUT IDEOGRAPH-#17F3C, TGT_MergedSrc=L2008-2605
17F3D TANGUT IDEOGRAPH-#17F3D, TGT_MergedSrc=L2008-3799
17F3E TANGUT IDEOGRAPH-#17F3E, TGT_MergedSrc=L2008-3382
17F3F TANGUT IDEOGRAPH-#17F3F, TGT_MergedSrc=L2008-3206
17F40 TANGUT IDEOGRAPH-#17F40, TGT_MergedSrc=L2008-3264
17F41 TANGUT IDEOGRAPH-#17F41, TGT_MergedSrc=L2008-2871
17F42 TANGUT IDEOGRAPH-#17F42, TGT_MergedSrc=L2008-2285
17F43 TANGUT IDEOGRAPH-#17F43, TGT_MergedSrc=L2008-2654
17F44 TANGUT IDEOGRAPH-#17F44, TGT_MergedSrc=L2008-2461
17F45 TANGUT IDEOGRAPH-#17F45, TGT_MergedSrc=L2008-2685
17F46 TANGUT IDEOGRAPH-#17F46, TGT_MergedSrc=L2008-3792
17F47 TANGUT IDEOGRAPH-#17F47, TGT_MergedSrc=L2008-3667
17F48 TANGUT IDEOGRAPH-#17F48, TGT_MergedSrc=L2008-3668
17F49 TANGUT IDEOGRAPH-#17F49, TGT_MergedSrc=L2008-3185
17F4A TANGUT IDEOGRAPH-#17F4A, TGT_MergedSrc=L2008-2889
17F4B TANGUT IDEOGRAPH-#17F4B, TGT_MergedSrc=L2008-3223
17F4C TANGUT IDEOGRAPH-#17F4C, TGT_MergedSrc=L2008-3122
17F4D TANGUT IDEOGRAPH-#17F4D, TGT_MergedSrc=L2008-2799A
17F4E TANGUT IDEOGRAPH-#17F4E, TGT_MergedSrc=L2008-2799B
17F4F TANGUT IDEOGRAPH-#17F4F, TGT_MergedSrc=L2008-2237
17F50 TANGUT IDEOGRAPH-#17F50, TGT_MergedSrc=L2008-2199
17F51 TANGUT IDEOGRAPH-#17F51, TGT_MergedSrc=L2008-3309
17F52 TANGUT IDEOGRAPH-#17F52, TGT_MergedSrc=L2008-2137
17F53 TANGUT IDEOGRAPH-#17F53, TGT_MergedSrc=L2008-2154
17F54 TANGUT IDEOGRAPH-#17F54, TGT_MergedSrc=L2008-3721
17F55 TANGUT IDEOGRAPH-#17F55, TGT_MergedSrc=L2008-2780
17F56 TANGUT IDEOGRAPH-#17F56, TGT_MergedSrc=L2008-3291
17F57 TANGUT IDEOGRAPH-#17F57, TGT_MergedSrc=L2008-3290
17F58 TANGUT IDEOGRAPH-#17F58, TGT_MergedSrc=L2008-3387
17F59 TANGUT IDEOGRAPH-#17F59, TGT_MergedSrc=L2008-2741
17F5A TANGUT IDEOGRAPH-#17F5A, TGT_MergedSrc=L2008-2773
17F5B TANGUT IDEOGRAPH-#17F5B, TGT_MergedSrc=L2008-3136
17F5C TANGUT IDEOGRAPH-#17F5C, TGT_MergedSrc=L2008-3293
17F5D TANGUT IDEOGRAPH-#17F5D, TGT_MergedSrc=L2008-3632
17F5E TANGUT IDEOGRAPH-#17F5E, TGT_MergedSrc=L2008-3666
17F5F TANGUT IDEOGRAPH-#17F5F, TGT_MergedSrc=L2008-3169
17F60 TANGUT IDEOGRAPH-#17F60, TGT_MergedSrc=L2008-3689
17F61 TANGUT IDEOGRAPH-#17F61, TGT_MergedSrc=L2008-2674
17F62 TANGUT IDEOGRAPH-#17F62, TGT_MergedSrc=L2008-3137
17F63 TANGUT IDEOGRAPH-#17F63, TGT_MergedSrc=L2008-3328
17F64 TANGUT IDEOGRAPH-#17F64, TGT_MergedSrc=L2008-2153
17F65 TANGUT IDEOGRAPH-#17F65, TGT_MergedSrc=L2008-2121
17F66 TANGUT IDEOGRAPH-#17F66, TGT_MergedSrc=L2008-2482
17F67 TANGUT IDEOGRAPH-#17F67, TGT_MergedSrc=L2008-2758
17F68 TANGUT IDEOGRAPH-#17F68, TGT_MergedSrc=L2008-3203
17F69 TANGUT IDEOGRAPH-#17F69, TGT_MergedSrc=L2008-3108
17F6A TANGUT IDEOGRAPH-#17F6A, TGT_MergedSrc=L2008-2122
17F6B TANGUT IDEOGRAPH-#17F6B, TGT_MergedSrc=L2008-2765
17F6C TANGUT IDEOGRAPH-#17F6C, TGT_MergedSrc=L2008-2861
17F6D TANGUT IDEOGRAPH-#17F6D, TGT_MergedSrc=L2008-3601
17F6E TANGUT IDEOGRAPH-#17F6E, TGT_MergedSrc=L2008-3669
17F6F TANGUT IDEOGRAPH-#17F6F, TGT_MergedSrc=L2008-2483
17F70 TANGUT IDEOGRAPH-#17F70, TGT_MergedSrc=L2008-2138
17F71 TANGUT IDEOGRAPH-#17F71, TGT_MergedSrc=L2008-3390
17F72 TANGUT IDEOGRAPH-#17F72, TGT_MergedSrc=L2008-2181
17F73 TANGUT IDEOGRAPH-#17F73, TGT_MergedSrc=L2008-2887
17F74 TANGUT IDEOGRAPH-#17F74, TGT_MergedSrc=L2008-3292
17F75 TANGUT IDEOGRAPH-#17F75, TGT_MergedSrc=L2008-3138
17F76 TANGUT IDEOGRAPH-#17F76, TGT_MergedSrc=L2008-3358
17F77 TANGUT IDEOGRAPH-#17F77, TGT_MergedSrc=L2008-2085
17F78 TANGUT IDEOGRAPH-#17F78, TGT_MergedSrc=L2008-3321
17F79 TANGUT IDEOGRAPH-#17F79, TGT_MergedSrc=L2008-2450
17F7A TANGUT IDEOGRAPH-#17F7A, TGT_MergedSrc=L2008-3177
17F7B TANGUT IDEOGRAPH-#17F7B, TGT_MergedSrc=L2008-2673
17F7C TANGUT IDEOGRAPH-#17F7C, TGT_MergedSrc=L2008-3584
17F7D TANGUT IDEOGRAPH-#17F7D, TGT_MergedSrc=L2008-2598
17F7E TANGUT IDEOGRAPH-#17F7E, TGT_MergedSrc=L2008-2585
17F7F TANGUT IDEOGRAPH-#17F7F, TGT_MergedSrc=L2008-2632
17F80 TANGUT IDEOGRAPH-#17F80, TGT_MergedSrc=L2008-2576
17F81 TANGUT IDEOGRAPH-#17F81, TGT_MergedSrc=L2008-6035
17F82 TANGUT IDEOGRAPH-#17F82, TGT_MergedSrc=L2008-2599
17F83 TANGUT IDEOGRAPH-#17F83, TGT_MergedSrc=L2008-2692
17F84 TANGUT IDEOGRAPH-#17F84, TGT_MergedSrc=L2008-2658
17F85 TANGUT IDEOGRAPH-#17F85, TGT_MergedSrc=L2008-2593
17F86 TANGUT IDEOGRAPH-#17F86, TGT_MergedSrc=L2008-3087
17F87 TANGUT IDEOGRAPH-#17F87, TGT_MergedSrc=L2008-3242
17F88 TANGUT IDEOGRAPH-#17F88, TGT_MergedSrc=L2008-3294
17F89 TANGUT IDEOGRAPH-#17F89, TGT_MergedSrc=L2008-3186
17F8A TANGUT IDEOGRAPH-#17F8A, TGT_MergedSrc=L2008-2252-2253
17F8B TANGUT IDEOGRAPH-#17F8B, TGT_MergedSrc=L2008-2742
17F8C TANGUT IDEOGRAPH-#17F8C, TGT_MergedSrc=L2008-3645
17F8D TANGUT IDEOGRAPH-#17F8D, TGT_MergedSrc=L2008-3204
17F8E TANGUT IDEOGRAPH-#17F8E, TGT_MergedSrc=L2008-3243
17F8F TANGUT IDEOGRAPH-#17F8F, TGT_MergedSrc=L2008-3109
17F90 TANGUT IDEOGRAPH-#17F90, TGT_MergedSrc=L2008-2238
17F91 TANGUT IDEOGRAPH-#17F91, TGT_MergedSrc=L2008-2254
17F92 TANGUT IDEOGRAPH-#17F92, TGT_MergedSrc=L2008-2070
17F93 TANGUT IDEOGRAPH-#17F93, TGT_MergedSrc=L2008-2079
17F94 TANGUT IDEOGRAPH-#17F94, TGT_MergedSrc=L2008-2449
17F95 TANGUT IDEOGRAPH-#17F95, TGT_MergedSrc=L2008-3295
17F96 TANGUT IDEOGRAPH-#17F96, TGT_MergedSrc=L2008-2628
17F97 TANGUT IDEOGRAPH-#17F97, TGT_MergedSrc=L2008-3670
17F98 TANGUT IDEOGRAPH-#17F98, TGT_MergedSrc=L2008-3625
17F99 TANGUT IDEOGRAPH-#17F99, TGT_MergedSrc=L2008-3800
17F9A TANGUT IDEOGRAPH-#17F9A, TGT_MergedSrc=L2008-3671
17F9B TANGUT IDEOGRAPH-#17F9B, TGT_MergedSrc=L2008-2855
17F9C TANGUT IDEOGRAPH-#17F9C, TGT_MergedSrc=L2008-2186
17F9D TANGUT IDEOGRAPH-#17F9D, TGT_MergedSrc=L2008-2086
17F9E TANGUT IDEOGRAPH-#17F9E, TGT_MergedSrc=L2008-2440
17F9F TANGUT IDEOGRAPH-#17F9F, TGT_MergedSrc=L2008-3310
17FA0 TANGUT IDEOGRAPH-#17FA0, TGT_MergedSrc=L2008-2470
17FA1 TANGUT IDEOGRAPH-#17FA1, TGT_MergedSrc=L2008-2462
17FA2 TANGUT IDEOGRAPH-#17FA2, TGT_MergedSrc=L2008-2675
17FA3 TANGUT IDEOGRAPH-#17FA3, TGT_MergedSrc=L2008-2655
17FA4 TANGUT IDEOGRAPH-#17FA4, TGT_MergedSrc=L2008-3600
17FA5 TANGUT IDEOGRAPH-#17FA5, TGT_MergedSrc=L2008-3683-3684
17FA6 TANGUT IDEOGRAPH-#17FA6, TGT_MergedSrc=L2008-2759
17FA7 TANGUT IDEOGRAPH-#17FA7, TGT_MergedSrc=L2008-3296
17FA8 TANGUT IDEOGRAPH-#17FA8, TGT_MergedSrc=L2008-2890
17FA9 TANGUT IDEOGRAPH-#17FA9, TGT_MergedSrc=L2008-2800
17FAA TANGUT IDEOGRAPH-#17FAA, TGT_MergedSrc=L2008-2519
17FAB TANGUT IDEOGRAPH-#17FAB, TGT_MergedSrc=L2008-2621
17FAC TANGUT IDEOGRAPH-#17FAC, TGT_MergedSrc=L2008-2208
17FAD TANGUT IDEOGRAPH-#17FAD, TGT_MergedSrc=L2008-2239
17FAE TANGUT IDEOGRAPH-#17FAE, TGT_MergedSrc=L2008-2087
17FAF TANGUT IDEOGRAPH-#17FAF, TGT_MergedSrc=L2008-2657
17FB0 TANGUT IDEOGRAPH-#17FB0, TGT_MergedSrc=N1966-211-078
17FB1 TANGUT IDEOGRAPH-#17FB1, TGT_MergedSrc=L2008-2781
17FB2 TANGUT IDEOGRAPH-#17FB2, TGT_MergedSrc=L2008-2209
17FB3 TANGUT IDEOGRAPH-#17FB3, TGT_MergedSrc=L2008-2760
17FB4 TANGUT IDEOGRAPH-#17FB4, TGT_MergedSrc=L2008-3224
17FB5 TANGUT IDEOGRAPH-#17FB5, TGT_MergedSrc=L2008-2615
17FB6 TANGUT IDEOGRAPH-#17FB6, TGT_MergedSrc=L2008-3808
17FB7 TANGUT IDEOGRAPH-#17FB7, TGT_MergedSrc=L2008-3110
17FB8 TANGUT IDEOGRAPH-#17FB8, TGT_MergedSrc=L2008-2868
17FB9 TANGUT IDEOGRAPH-#17FB9, TGT_MergedSrc=L2008-2175
17FBA TANGUT IDEOGRAPH-#17FBA, TGT_MergedSrc=L2008-3690
17FBB TANGUT IDEOGRAPH-#17FBB, TGT_MergedSrc=L2008-2146
17FBC TANGUT IDEOGRAPH-#17FBC, TGT_MergedSrc=L2008-6032
17FBD TANGUT IDEOGRAPH-#17FBD, TGT_MergedSrc=L2008-2451
17FBE TANGUT IDEOGRAPH-#17FBE, TGT_MergedSrc=L2008-2499
17FBF TANGUT IDEOGRAPH-#17FBF, TGT_MergedSrc=L2008-3160
17FC0 TANGUT IDEOGRAPH-#17FC0, TGT_MergedSrc=L2008-2107
17FC1 TANGUT IDEOGRAPH-#17FC1, TGT_MergedSrc=L2008-2454
17FC2 TANGUT IDEOGRAPH-#17FC2, TGT_MergedSrc=L2008-3579
17FC3 TANGUT IDEOGRAPH-#17FC3, TGT_MergedSrc=L2008-3633
17FC4 TANGUT IDEOGRAPH-#17FC4, TGT_MergedSrc=L2008-2791
17FC5 TANGUT IDEOGRAPH-#17FC5, TGT_MergedSrc=L2008-3657
17FC6 TANGUT IDEOGRAPH-#17FC6, TGT_MergedSrc=L2008-2210
17FC7 TANGUT IDEOGRAPH-#17FC7, TGT_MergedSrc=L2008-2766
17FC8 TANGUT IDEOGRAPH-#17FC8, TGT_MergedSrc=L2008-3626
17FC9 TANGUT IDEOGRAPH-#17FC9, TGT_MergedSrc=L2008-3673
17FCA TANGUT IDEOGRAPH-#17FCA, TGT_MergedSrc=L2008-3322
17FCB TANGUT IDEOGRAPH-#17FCB, TGT_MergedSrc=L2008-2165
17FCC TANGUT IDEOGRAPH-#17FCC, TGT_MergedSrc=L2008-3297
17FCD TANGUT IDEOGRAPH-#17FCD, TGT_MergedSrc=L2008-3698
17FCE TANGUT IDEOGRAPH-#17FCE, TGT_MergedSrc=L2008-2761
17FCF TANGUT IDEOGRAPH-#17FCF, TGT_MergedSrc=L2008-3251
17FD0 TANGUT IDEOGRAPH-#17FD0, TGT_MergedSrc=L2008-2241
17FD1 TANGUT IDEOGRAPH-#17FD1, TGT_MergedSrc=L2008-3571
17FD2 TANGUT IDEOGRAPH-#17FD2, TGT_MergedSrc=L2008-2893
17FD3 TANGUT IDEOGRAPH-#17FD3, TGT_MergedSrc=L2008-2240
17FD4 TANGUT IDEOGRAPH-#17FD4, TGT_MergedSrc=L2008-2139
17FD5 TANGUT IDEOGRAPH-#17FD5, TGT_MergedSrc=L2008-3635
17FD6 TANGUT IDEOGRAPH-#17FD6, TGT_MergedSrc=L2008-3323
17FD7 TANGUT IDEOGRAPH-#17FD7, TGT_MergedSrc=L2008-2656
17FD8 TANGUT IDEOGRAPH-#17FD8, TGT_MergedSrc=L2008-3127
17FD9 TANGUT IDEOGRAPH-#17FD9, TGT_MergedSrc=L2008-3254
17FDA TANGUT IDEOGRAPH-#17FDA, TGT_MergedSrc=L2008-2856
17FDB TANGUT IDEOGRAPH-#17FDB, TGT_MergedSrc=L2008-3672
17FDC TANGUT IDEOGRAPH-#17FDC, TGT_MergedSrc=L2008-3170
17FDD TANGUT IDEOGRAPH-#17FDD, TGT_MergedSrc=L2008-2669
17FDE TANGUT IDEOGRAPH-#17FDE, TGT_MergedSrc=L2008-3312
17FDF TANGUT IDEOGRAPH-#17FDF, TGT_MergedSrc=L2008-2255
17FE0 TANGUT IDEOGRAPH-#17FE0, TGT_MergedSrc=L2008-2242
17FE1 TANGUT IDEOGRAPH-#17FE1, TGT_MergedSrc=L2008-2873
17FE2 TANGUT IDEOGRAPH-#17FE2, TGT_MergedSrc=L2008-2806
17FE3 TANGUT IDEOGRAPH-#17FE3, TGT_MergedSrc=L2008-3111
17FE4 TANGUT IDEOGRAPH-#17FE4, TGT_MergedSrc=L2008-2260
17FE5 TANGUT IDEOGRAPH-#17FE5, TGT_MergedSrc=L2008-2140
17FE6 TANGUT IDEOGRAPH-#17FE6, TGT_MergedSrc=L2008-3334
17FE7 TANGUT IDEOGRAPH-#17FE7, TGT_MergedSrc=L2008-3612
17FE8 TANGUT IDEOGRAPH-#17FE8, TGT_MergedSrc=L2008-3647
17FE9 TANGUT IDEOGRAPH-#17FE9, TGT_MergedSrc=L2008-3324
17FEA TANGUT IDEOGRAPH-#17FEA, TGT_MergedSrc=L2008-2762
17FEB TANGUT IDEOGRAPH-#17FEB, TGT_MergedSrc=L2008-3709
17FEC TANGUT IDEOGRAPH-#17FEC, TGT_MergedSrc=L2008-3694
17FED TANGUT IDEOGRAPH-#17FED, TGT_MergedSrc=L2008-3171
17FEE TANGUT IDEOGRAPH-#17FEE, TGT_MergedSrc=L2008-3311
17FEF TANGUT IDEOGRAPH-#17FEF, TGT_MergedSrc=L2008-3298
17FF0 TANGUT IDEOGRAPH-#17FF0, TGT_MergedSrc=L2008-3359
17FF1 TANGUT IDEOGRAPH-#17FF1, TGT_MergedSrc=L2008-2266
17FF2 TANGUT IDEOGRAPH-#17FF2, TGT_MergedSrc=L2008-2115
17FF3 TANGUT IDEOGRAPH-#17FF3, TGT_MergedSrc=L2008-3589
17FF4 TANGUT IDEOGRAPH-#17FF4, TGT_MergedSrc=L2008-3608
17FF5 TANGUT IDEOGRAPH-#17FF5, TGT_MergedSrc=L2008-2767
17FF6 TANGUT IDEOGRAPH-#17FF6, TGT_MergedSrc=L2008-2114
17FF7 TANGUT IDEOGRAPH-#17FF7, TGT_MergedSrc=L2008-3126
17FF8 TANGUT IDEOGRAPH-#17FF8, TGT_MergedSrc=L2008-3703
17FF9 TANGUT IDEOGRAPH-#17FF9, TGT_MergedSrc=L2008-2261
17FFA TANGUT IDEOGRAPH-#17FFA, TGT_MergedSrc=L2008-2288
17FFB TANGUT IDEOGRAPH-#17FFB, TGT_MergedSrc=L2008-2267
17FFC TANGUT IDEOGRAPH-#17FFC, TGT_MergedSrc=L2008-2262
17FFD TANGUT IDEOGRAPH-#17FFD, TGT_MergedSrc=L2008-2270
17FFE TANGUT IDEOGRAPH-#17FFE, TGT_MergedSrc=L2008-2268
17FFF TANGUT IDEOGRAPH-#17FFF, TGT_MergedSrc=L2008-2463
18000 TANGUT IDEOGRAPH-#18000, TGT_MergedSrc=L2008-2906
18001 TANGUT IDEOGRAPH-#18001, TGT_MergedSrc=L2008-2326
18002 TANGUT IDEOGRAPH-#18002, TGT_MergedSrc=L2008-3415
18003 TANGUT IDEOGRAPH-#18003, TGT_MergedSrc=L2008-4030
18004 TANGUT IDEOGRAPH-#18004, TGT_MergedSrc=L2008-4031
18005 TANGUT IDEOGRAPH-#18005, TGT_MergedSrc=L2008-4067
18006 TANGUT IDEOGRAPH-#18006, TGT_MergedSrc=L2008-3846
18007 TANGUT IDEOGRAPH-#18007, TGT_MergedSrc=L2008-3891
18008 TANGUT IDEOGRAPH-#18008, TGT_MergedSrc=L2008-3910
18009 TANGUT IDEOGRAPH-#18009, TGT_MergedSrc=L2008-3960
1800A TANGUT IDEOGRAPH-#1800A, TGT_MergedSrc=L2008-3913
1800B TANGUT IDEOGRAPH-#1800B, TGT_MergedSrc=L2008-3892
1800C TANGUT IDEOGRAPH-#1800C, TGT_MergedSrc=L2008-3887
1800D TANGUT IDEOGRAPH-#1800D, TGT_MergedSrc=L2008-3926
1800E TANGUT IDEOGRAPH-#1800E, TGT_MergedSrc=L2008-3925
1800F TANGUT IDEOGRAPH-#1800F, TGT_MergedSrc=L2008-3909
18010 TANGUT IDEOGRAPH-#18010, TGT_MergedSrc=L2008-3849
18011 TANGUT IDEOGRAPH-#18011, TGT_MergedSrc=L2008-3911
18012 TANGUT IDEOGRAPH-#18012, TGT_MergedSrc=L2008-3927
18013 TANGUT IDEOGRAPH-#18013, TGT_MergedSrc=L2008-3866
18014 TANGUT IDEOGRAPH-#18014, TGT_MergedSrc=L2008-3850
18015 TANGUT IDEOGRAPH-#18015, TGT_MergedSrc=L2008-3851
18016 TANGUT IDEOGRAPH-#18016, TGT_MergedSrc=L2008-3928
18017 TANGUT IDEOGRAPH-#18017, TGT_MergedSrc=L2008-3950
18018 TANGUT IDEOGRAPH-#18018, TGT_MergedSrc=L2008-3904
18019 TANGUT IDEOGRAPH-#18019, TGT_MergedSrc=L2008-3923
1801A TANGUT IDEOGRAPH-#1801A, TGT_MergedSrc=L2008-3906
1801B TANGUT IDEOGRAPH-#1801B, TGT_MergedSrc=L2008-3946
1801C TANGUT IDEOGRAPH-#1801C, TGT_MergedSrc=L2008-3888
1801D TANGUT IDEOGRAPH-#1801D, TGT_MergedSrc=L2008-3874
1801E TANGUT IDEOGRAPH-#1801E, TGT_MergedSrc=L2008-3882
1801F TANGUT IDEOGRAPH-#1801F, TGT_MergedSrc=L2008-3900
18020 TANGUT IDEOGRAPH-#18020, TGT_MergedSrc=L2008-3869
18021 TANGUT IDEOGRAPH-#18021, TGT_MergedSrc=L2008-3901
18022 TANGUT IDEOGRAPH-#18022, TGT_MergedSrc=L2008-3973
18023 TANGUT IDEOGRAPH-#18023, TGT_MergedSrc=L2008-3967
18024 TANGUT IDEOGRAPH-#18024, TGT_MergedSrc=L2008-3996
18025 TANGUT IDEOGRAPH-#18025, TGT_MergedSrc=L2008-3980
18026 TANGUT IDEOGRAPH-#18026, TGT_MergedSrc=L2008-3933
18027 TANGUT IDEOGRAPH-#18027, TGT_MergedSrc=L2008-3877
18028 TANGUT IDEOGRAPH-#18028, TGT_MergedSrc=L2008-3880
18029 TANGUT IDEOGRAPH-#18029, TGT_MergedSrc=L2008-3884
1802A TANGUT IDEOGRAPH-#1802A, TGT_MergedSrc=L2008-3873
1802B TANGUT IDEOGRAPH-#1802B, TGT_MergedSrc=L2008-3935
1802C TANGUT IDEOGRAPH-#1802C, TGT_MergedSrc=L2008-3876
1802D TANGUT IDEOGRAPH-#1802D, TGT_MergedSrc=L2008-3934
1802E TANGUT IDEOGRAPH-#1802E, TGT_MergedSrc=L2008-3932
1802F TANGUT IDEOGRAPH-#1802F, TGT_MergedSrc=L2008-3978
18030 TANGUT IDEOGRAPH-#18030, TGT_MergedSrc=L2008-3976
18031 TANGUT IDEOGRAPH-#18031, TGT_MergedSrc=S1968-3063
18032 TANGUT IDEOGRAPH-#18032, TGT_MergedSrc=L2008-4005
18033 TANGUT IDEOGRAPH-#18033, TGT_MergedSrc=L2008-4002
18034 TANGUT IDEOGRAPH-#18034, TGT_MergedSrc=L2008-3875
18035 TANGUT IDEOGRAPH-#18035, TGT_MergedSrc=L2008-3920
18036 TANGUT IDEOGRAPH-#18036, TGT_MergedSrc=L2008-3868
18037 TANGUT IDEOGRAPH-#18037, TGT_MergedSrc=L2008-3895
18038 TANGUT IDEOGRAPH-#18038, TGT_MergedSrc=L2008-4000
18039 TANGUT IDEOGRAPH-#18039, TGT_MergedSrc=L2008-3897
1803A TANGUT IDEOGRAPH-#1803A, TGT_MergedSrc=L2008-4003
1803B TANGUT IDEOGRAPH-#1803B, TGT_MergedSrc=L2008-3899
1803C TANGUT IDEOGRAPH-#1803C, TGT_MergedSrc=L2008-3898
1803D TANGUT IDEOGRAPH-#1803D, TGT_MergedSrc=L2008-3974
1803E TANGUT IDEOGRAPH-#1803E, TGT_MergedSrc=L2008-3902
1803F TANGUT IDEOGRAPH-#1803F, TGT_MergedSrc=L2008-4004
18040 TANGUT IDEOGRAPH-#18040, TGT_MergedSrc=L2008-3872
18041 TANGUT IDEOGRAPH-#18041, TGT_MergedSrc=L2008-3982
18042 TANGUT IDEOGRAPH-#18042, TGT_MergedSrc=L2008-5314
18043 TANGUT IDEOGRAPH-#18043, TGT_MergedSrc=L2008-5640
18044 TANGUT IDEOGRAPH-#18044, TGT_MergedSrc=L2008-5798
18045 TANGUT IDEOGRAPH-#18045, TGT_MergedSrc=L2008-5674
18046 TANGUT IDEOGRAPH-#18046, TGT_MergedSrc=L2008-5175
18047 TANGUT IDEOGRAPH-#18047, TGT_MergedSrc=L2008-5168
18048 TANGUT IDEOGRAPH-#18048, TGT_MergedSrc=L2008-5665
18049 TANGUT IDEOGRAPH-#18049, TGT_MergedSrc=L2008-5723
1804A TANGUT IDEOGRAPH-#1804A, TGT_MergedSrc=L2008-5180
1804B TANGUT IDEOGRAPH-#1804B, TGT_MergedSrc=L2008-5624
1804C TANGUT IDEOGRAPH-#1804C, TGT_MergedSrc=L2008-6061
1804D TANGUT IDEOGRAPH-#1804D, TGT_MergedSrc=L2008-5310
1804E TANGUT IDEOGRAPH-#1804E, TGT_MergedSrc=L2008-5548
1804F TANGUT IDEOGRAPH-#1804F, TGT_MergedSrc=L2008-4677
18050 TANGUT IDEOGRAPH-#18050, TGT_MergedSrc=L2008-4875
18051 TANGUT IDEOGRAPH-#18051, TGT_MergedSrc=L2008-4964
18052 TANGUT IDEOGRAPH-#18052, TGT_MergedSrc=L2008-4812
18053 TANGUT IDEOGRAPH-#18053, TGT_MergedSrc=L2008-4965
18054 TANGUT IDEOGRAPH-#18054, TGT_MergedSrc=L2008-4704
18055 TANGUT IDEOGRAPH-#18055, TGT_MergedSrc=L2008-4911
18056 TANGUT IDEOGRAPH-#18056, TGT_MergedSrc=L2008-4766
18057 TANGUT IDEOGRAPH-#18057, TGT_MergedSrc=L2008-5064
18058 TANGUT IDEOGRAPH-#18058, TGT_MergedSrc=L2008-5284
18059 TANGUT IDEOGRAPH-#18059, TGT_MergedSrc=L2008-5782
1805A TANGUT IDEOGRAPH-#1805A, TGT_MergedSrc=L2008-5116
1805B TANGUT IDEOGRAPH-#1805B, TGT_MergedSrc=L2008-5525
1805C TANGUT IDEOGRAPH-#1805C, TGT_MergedSrc=L2008-5572
1805D TANGUT IDEOGRAPH-#1805D, TGT_MergedSrc=L2008-5555
1805E TANGUT IDEOGRAPH-#1805E, TGT_MergedSrc=L2008-5416
1805F TANGUT IDEOGRAPH-#1805F, TGT_MergedSrc=L2008-5419
18060 TANGUT IDEOGRAPH-#18060, TGT_MergedSrc=L2008-5069
18061 TANGUT IDEOGRAPH-#18061, TGT_MergedSrc=L2008-5462
18062 TANGUT IDEOGRAPH-#18062, TGT_MergedSrc=L2008-5363
18063 TANGUT IDEOGRAPH-#18063, TGT_MergedSrc=L2008-5497
18064 TANGUT IDEOGRAPH-#18064, TGT_MergedSrc=L2008-5549
18065 TANGUT IDEOGRAPH-#18065, TGT_MergedSrc=L2008-5556
18066 TANGUT IDEOGRAPH-#18066, TGT_MergedSrc=L2008-5573
18067 TANGUT IDEOGRAPH-#18067, TGT_MergedSrc=L2008-5526
18068 TANGUT IDEOGRAPH-#18068, TGT_MergedSrc=L2008-5085
18069 TANGUT IDEOGRAPH-#18069, TGT_MergedSrc=L2008-5713
1806A TANGUT IDEOGRAPH-#1806A, TGT_MergedSrc=L2008-5721
1806B TANGUT IDEOGRAPH-#1806B, TGT_MergedSrc=L2008-5140
1806C TANGUT IDEOGRAPH-#1806C, TGT_MergedSrc=L2008-5535
1806D TANGUT IDEOGRAPH-#1806D, TGT_MergedSrc=L2008-5079
1806E TANGUT IDEOGRAPH-#1806E, TGT_MergedSrc=L2008-5070
1806F TANGUT IDEOGRAPH-#1806F, TGT_MergedSrc=L2008-5422
18070 TANGUT IDEOGRAPH-#18070, TGT_MergedSrc=L2008-5080
18071 TANGUT IDEOGRAPH-#18071, TGT_MergedSrc=L2008-5155
18072 TANGUT IDEOGRAPH-#18072, TGT_MergedSrc=L2008-5465
18073 TANGUT IDEOGRAPH-#18073, TGT_MergedSrc=L2008-5783
18074 TANGUT IDEOGRAPH-#18074, TGT_MergedSrc=L2008-5468
18075 TANGUT IDEOGRAPH-#18075, TGT_MergedSrc=L2008-5289
18076 TANGUT IDEOGRAPH-#18076, TGT_MergedSrc=L2008-5292
18077 TANGUT IDEOGRAPH-#18077, TGT_MergedSrc=L2008-5691
18078 TANGUT IDEOGRAPH-#18078, TGT_MergedSrc=L2008-5254
18079 TANGUT IDEOGRAPH-#18079, TGT_MergedSrc=L2008-5350
1807A TANGUT IDEOGRAPH-#1807A, TGT_MergedSrc=L2008-5690
1807B TANGUT IDEOGRAPH-#1807B, TGT_MergedSrc=L2008-5315
1807C TANGUT IDEOGRAPH-#1807C, TGT_MergedSrc=L2008-5387
1807D TANGUT IDEOGRAPH-#1807D, TGT_MergedSrc=L2008-5616
1807E TANGUT IDEOGRAPH-#1807E, TGT_MergedSrc=L2008-5722
1807F TANGUT IDEOGRAPH-#1807F, TGT_MergedSrc=L2008-5660
18080 TANGUT IDEOGRAPH-#18080, TGT_MergedSrc=L2008-5243
18081 TANGUT IDEOGRAPH-#18081, TGT_MergedSrc=L2008-5225
18082 TANGUT IDEOGRAPH-#18082, TGT_MergedSrc=L2008-5200
18083 TANGUT IDEOGRAPH-#18083, TGT_MergedSrc=L2008-5666
18084 TANGUT IDEOGRAPH-#18084, TGT_MergedSrc=L2008-5935
18085 TANGUT IDEOGRAPH-#18085, TGT_MergedSrc=L2008-5831
18086 TANGUT IDEOGRAPH-#18086, TGT_MergedSrc=L2008-5815
18087 TANGUT IDEOGRAPH-#18087, TGT_MergedSrc=L2008-5915
18088 TANGUT IDEOGRAPH-#18088, TGT_MergedSrc=L2008-5914
18089 TANGUT IDEOGRAPH-#18089, TGT_MergedSrc=L2008-5900
1808A TANGUT IDEOGRAPH-#1808A, TGT_MergedSrc=L2008-5857
1808B TANGUT IDEOGRAPH-#1808B, TGT_MergedSrc=L2008-5849
1808C TANGUT IDEOGRAPH-#1808C, TGT_MergedSrc=L2008-5860
1808D TANGUT IDEOGRAPH-#1808D, TGT_MergedSrc=L2008-5858
1808E TANGUT IDEOGRAPH-#1808E, TGT_MergedSrc=L2008-5881
1808F TANGUT IDEOGRAPH-#1808F, TGT_MergedSrc=L2008-5878
18090 TANGUT IDEOGRAPH-#18090, TGT_MergedSrc=L2008-5899
18091 TANGUT IDEOGRAPH-#18091, TGT_MergedSrc=L2008-5883
18092 TANGUT IDEOGRAPH-#18092, TGT_MergedSrc=L2008-5884
18093 TANGUT IDEOGRAPH-#18093, TGT_MergedSrc=L2008-5877
18094 TANGUT IDEOGRAPH-#18094, TGT_MergedSrc=L2008-5901
18095 TANGUT IDEOGRAPH-#18095, TGT_MergedSrc=L2008-5966
18096 TANGUT IDEOGRAPH-#18096, TGT_MergedSrc=L2008-5986
18097 TANGUT IDEOGRAPH-#18097, TGT_MergedSrc=L2008-5959
18098 TANGUT IDEOGRAPH-#18098, TGT_MergedSrc=L2008-5965
18099 TANGUT IDEOGRAPH-#18099, TGT_MergedSrc=L2008-5963
1809A TANGUT IDEOGRAPH-#1809A, TGT_MergedSrc=L2008-5855
1809B TANGUT IDEOGRAPH-#1809B, TGT_MergedSrc=L2008-5919
1809C TANGUT IDEOGRAPH-#1809C, TGT_MergedSrc=L2008-5882
1809D TANGUT IDEOGRAPH-#1809D, TGT_MergedSrc=L2008-5902
1809E TANGUT IDEOGRAPH-#1809E, TGT_MergedSrc=L2008-5987
1809F TANGUT IDEOGRAPH-#1809F, TGT_MergedSrc=L2008-5989
180A0 TANGUT IDEOGRAPH-#180A0, TGT_MergedSrc=L2008-5885
180A1 TANGUT IDEOGRAPH-#180A1, TGT_MergedSrc=L2008-5853
180A2 TANGUT IDEOGRAPH-#180A2, TGT_MergedSrc=L2008-5960
180A3 TANGUT IDEOGRAPH-#180A3, TGT_MergedSrc=L2008-5850
180A4 TANGUT IDEOGRAPH-#180A4, TGT_MergedSrc=L2008-5993
180A5 TANGUT IDEOGRAPH-#180A5, TGT_MergedSrc=L2008-5968
180A6 TANGUT IDEOGRAPH-#180A6, TGT_MergedSrc=L2008-5916
180A7 TANGUT IDEOGRAPH-#180A7, TGT_MergedSrc=L2008-6074
180A8 TANGUT IDEOGRAPH-#180A8, TGT_MergedSrc=L2008-5961
180A9 TANGUT IDEOGRAPH-#180A9, TGT_MergedSrc=L2008-5852
180AA TANGUT IDEOGRAPH-#180AA, TGT_MergedSrc=L2008-4855
180AB TANGUT IDEOGRAPH-#180AB, TGT_MergedSrc=L2008-5215
180AC TANGUT IDEOGRAPH-#180AC, TGT_MergedSrc=L2008-5670
180AD TANGUT IDEOGRAPH-#180AD, TGT_MergedSrc=L2008-5675
180AE TANGUT IDEOGRAPH-#180AE, TGT_MergedSrc=L2008-5652
180AF TANGUT IDEOGRAPH-#180AF, TGT_MergedSrc=L2008-5388
180B0 TANGUT IDEOGRAPH-#180B0, TGT_MergedSrc=L2008-5747
180B1 TANGUT IDEOGRAPH-#180B1, TGT_MergedSrc=L2008-5599
180B2 TANGUT IDEOGRAPH-#180B2, TGT_MergedSrc=L2008-5684
180B3 TANGUT IDEOGRAPH-#180B3, TGT_MergedSrc=L2008-5757
180B4 TANGUT IDEOGRAPH-#180B4, TGT_MergedSrc=L2008-5677
180B5 TANGUT IDEOGRAPH-#180B5, TGT_MergedSrc=L2008-5740
180B6 TANGUT IDEOGRAPH-#180B6, TGT_MergedSrc=L2008-5303
180B7 TANGUT IDEOGRAPH-#180B7, TGT_MergedSrc=L2008-5488
180B8 TANGUT IDEOGRAPH-#180B8, TGT_MergedSrc=L2008-5344
180B9 TANGUT IDEOGRAPH-#180B9, TGT_MergedSrc=L2008-5207
180BA TANGUT IDEOGRAPH-#180BA, TGT_MergedSrc=L2008-5328
180BB TANGUT IDEOGRAPH-#180BB, TGT_MergedSrc=L2008-5587
180BC TANGUT IDEOGRAPH-#180BC, TGT_MergedSrc=L2008-5600
180BD TANGUT IDEOGRAPH-#180BD, TGT_MergedSrc=L2008-5734
180BE TANGUT IDEOGRAPH-#180BE, TGT_MergedSrc=L2008-5678
180BF TANGUT IDEOGRAPH-#180BF, TGT_MergedSrc=L2008-5329
180C0 TANGUT IDEOGRAPH-#180C0, TGT_MergedSrc=L2008-5480
180C1 TANGUT IDEOGRAPH-#180C1, TGT_MergedSrc=L2008-5605
180C2 TANGUT IDEOGRAPH-#180C2, TGT_MergedSrc=L2008-5725
180C3 TANGUT IDEOGRAPH-#180C3, TGT_MergedSrc=L2008-5768
180C4 TANGUT IDEOGRAPH-#180C4, TGT_MergedSrc=L2008-5669
180C5 TANGUT IDEOGRAPH-#180C5, TGT_MergedSrc=L2008-5589
180C6 TANGUT IDEOGRAPH-#180C6, TGT_MergedSrc=L2008-5642
180C7 TANGUT IDEOGRAPH-#180C7, TGT_MergedSrc=L2008-5606
180C8 TANGUT IDEOGRAPH-#180C8, TGT_MergedSrc=L2008-5228
180C9 TANGUT IDEOGRAPH-#180C9, TGT_MergedSrc=L2008-5570
180CA TANGUT IDEOGRAPH-#180CA, TGT_MergedSrc=L2008-5136
180CB TANGUT IDEOGRAPH-#180CB, TGT_MergedSrc=L2008-5121
180CC TANGUT IDEOGRAPH-#180CC, TGT_MergedSrc=L2008-5711
180CD TANGUT IDEOGRAPH-#180CD, TGT_MergedSrc=L2008-5298
180CE TANGUT IDEOGRAPH-#180CE, TGT_MergedSrc=L2008-5370
180CF TANGUT IDEOGRAPH-#180CF, TGT_MergedSrc=L2008-5641
180D0 TANGUT IDEOGRAPH-#180D0, TGT_MergedSrc=L2008-5799
180D1 TANGUT IDEOGRAPH-#180D1, TGT_MergedSrc=L2008-5394
180D2 TANGUT IDEOGRAPH-#180D2, TGT_MergedSrc=L2008-5316
180D3 TANGUT IDEOGRAPH-#180D3, TGT_MergedSrc=L2008-5403
180D4 TANGUT IDEOGRAPH-#180D4, TGT_MergedSrc=L2008-5756
180D5 TANGUT IDEOGRAPH-#180D5, TGT_MergedSrc=L2008-5792
180D6 TANGUT IDEOGRAPH-#180D6, TGT_MergedSrc=L2008-5191
180D7 TANGUT IDEOGRAPH-#180D7, TGT_MergedSrc=L2008-5681
180D8 TANGUT IDEOGRAPH-#180D8, TGT_MergedSrc=L2008-6059
180D9 TANGUT IDEOGRAPH-#180D9, TGT_MergedSrc=L2008-4741
180DA TANGUT IDEOGRAPH-#180DA, TGT_MergedSrc=L2008-5411
180DB TANGUT IDEOGRAPH-#180DB, TGT_MergedSrc=L2008-5417
180DC TANGUT IDEOGRAPH-#180DC, TGT_MergedSrc=L2008-5523
180DD TANGUT IDEOGRAPH-#180DD, TGT_MergedSrc=L2008-5071
180DE TANGUT IDEOGRAPH-#180DE, TGT_MergedSrc=L2008-5285
180DF TANGUT IDEOGRAPH-#180DF, TGT_MergedSrc=L2008-5467
180E0 TANGUT IDEOGRAPH-#180E0, TGT_MergedSrc=L2008-5149
180E1 TANGUT IDEOGRAPH-#180E1, TGT_MergedSrc=L2008-5113
180E2 TANGUT IDEOGRAPH-#180E2, TGT_MergedSrc=L2008-5364
180E3 TANGUT IDEOGRAPH-#180E3, TGT_MergedSrc=L2008-5574
180E4 TANGUT IDEOGRAPH-#180E4, TGT_MergedSrc=L2008-5067
180E5 TANGUT IDEOGRAPH-#180E5, TGT_MergedSrc=L2008-5418
180E6 TANGUT IDEOGRAPH-#180E6, TGT_MergedSrc=L2008-5694
180E7 TANGUT IDEOGRAPH-#180E7, TGT_MergedSrc=L2008-5086
180E8 TANGUT IDEOGRAPH-#180E8, TGT_MergedSrc=L2008-5072
180E9 TANGUT IDEOGRAPH-#180E9, TGT_MergedSrc=L2008-5122
180EA TANGUT IDEOGRAPH-#180EA, TGT_MergedSrc=L2008-5712
180EB TANGUT IDEOGRAPH-#180EB, TGT_MergedSrc=L2008-5261
180EC TANGUT IDEOGRAPH-#180EC, TGT_MergedSrc=L2008-5352
180ED TANGUT IDEOGRAPH-#180ED, TGT_MergedSrc=L2008-5353
180EE TANGUT IDEOGRAPH-#180EE, TGT_MergedSrc=L2008-5550
180EF TANGUT IDEOGRAPH-#180EF, TGT_MergedSrc=L2008-0539
180F0 TANGUT IDEOGRAPH-#180F0, TGT_MergedSrc=L2008-0258
180F1 TANGUT IDEOGRAPH-#180F1, TGT_MergedSrc=L2008-1676
180F2 TANGUT IDEOGRAPH-#180F2, TGT_MergedSrc=L2008-0688
180F3 TANGUT IDEOGRAPH-#180F3, TGT_MergedSrc=L2008-1429
180F4 TANGUT IDEOGRAPH-#180F4, TGT_MergedSrc=L2008-0389
180F5 TANGUT IDEOGRAPH-#180F5, TGT_MergedSrc=L2008-1453
180F6 TANGUT IDEOGRAPH-#180F6, TGT_MergedSrc=L2008-0398
180F7 TANGUT IDEOGRAPH-#180F7, TGT_MergedSrc=L2008-0399
180F8 TANGUT IDEOGRAPH-#180F8, TGT_MergedSrc=L2008-0496
180F9 TANGUT IDEOGRAPH-#180F9, TGT_MergedSrc=L2008-0957
180FA TANGUT IDEOGRAPH-#180FA, TGT_MergedSrc=L2008-0163
180FB TANGUT IDEOGRAPH-#180FB, TGT_MergedSrc=L2008-0494
180FC TANGUT IDEOGRAPH-#180FC, TGT_MergedSrc=L2008-0505
180FD TANGUT IDEOGRAPH-#180FD, TGT_MergedSrc=L2008-1616
180FE TANGUT IDEOGRAPH-#180FE, TGT_MergedSrc=L2008-0239
180FF TANGUT IDEOGRAPH-#180FF, TGT_MergedSrc=L2008-0660
18100 TANGUT IDEOGRAPH-#18100, TGT_MergedSrc=L2008-1013
18101 TANGUT IDEOGRAPH-#18101, TGT_MergedSrc=L2008-0495
18102 TANGUT IDEOGRAPH-#18102, TGT_MergedSrc=L2008-1598
18103 TANGUT IDEOGRAPH-#18103, TGT_MergedSrc=L2008-1592
18104 TANGUT IDEOGRAPH-#18104, TGT_MergedSrc=L2008-1085
18105 TANGUT IDEOGRAPH-#18105, TGT_MergedSrc=L2008-0221
18106 TANGUT IDEOGRAPH-#18106, TGT_MergedSrc=L2008-0183
18107 TANGUT IDEOGRAPH-#18107, TGT_MergedSrc=L2008-0166
18108 TANGUT IDEOGRAPH-#18108, TGT_MergedSrc=L2008-0643
18109 TANGUT IDEOGRAPH-#18109, TGT_MergedSrc=L2008-0958
1810A TANGUT IDEOGRAPH-#1810A, TGT_MergedSrc=L2008-0938
1810B TANGUT IDEOGRAPH-#1810B, TGT_MergedSrc=L2008-0225
1810C TANGUT IDEOGRAPH-#1810C, TGT_MergedSrc=L2008-0939
1810D TANGUT IDEOGRAPH-#1810D, TGT_MergedSrc=L2008-1637
1810E TANGUT IDEOGRAPH-#1810E, TGT_MergedSrc=L2008-1638
1810F TANGUT IDEOGRAPH-#1810F, TGT_MergedSrc=L2008-0756
18110 TANGUT IDEOGRAPH-#18110, TGT_MergedSrc=L1986-3906
18111 TANGUT IDEOGRAPH-#18111, TGT_MergedSrc=L2008-0757
18112 TANGUT IDEOGRAPH-#18112, TGT_MergedSrc=L2008-0776
18113 TANGUT IDEOGRAPH-#18113, TGT_MergedSrc=L2008-1149
18114 TANGUT IDEOGRAPH-#18114, TGT_MergedSrc=L2008-0989
18115 TANGUT IDEOGRAPH-#18115, TGT_MergedSrc=L2008-0569
18116 TANGUT IDEOGRAPH-#18116, TGT_MergedSrc=L2008-0710
18117 TANGUT IDEOGRAPH-#18117, TGT_MergedSrc=L2008-1404
18118 TANGUT IDEOGRAPH-#18118, TGT_MergedSrc=L2008-1352
18119 TANGUT IDEOGRAPH-#18119, TGT_MergedSrc=L2008-0865
1811A TANGUT IDEOGRAPH-#1811A, TGT_MergedSrc=L2008-0712
1811B TANGUT IDEOGRAPH-#1811B, TGT_MergedSrc=L2008-0331
1811C TANGUT IDEOGRAPH-#1811C, TGT_MergedSrc=L2008-0159
1811D TANGUT IDEOGRAPH-#1811D, TGT_MergedSrc=L2008-1636
1811E TANGUT IDEOGRAPH-#1811E, TGT_MergedSrc=L2008-0657
1811F TANGUT IDEOGRAPH-#1811F, TGT_MergedSrc=L2008-1273
18120 TANGUT IDEOGRAPH-#18120, TGT_MergedSrc=L2008-1385
18121 TANGUT IDEOGRAPH-#18121, TGT_MergedSrc=L2008-1771
18122 TANGUT IDEOGRAPH-#18122, TGT_MergedSrc=L2008-1718
18123 TANGUT IDEOGRAPH-#18123, TGT_MergedSrc=L2008-0344
18124 TANGUT IDEOGRAPH-#18124, TGT_MergedSrc=L2008-1286
18125 TANGUT IDEOGRAPH-#18125, TGT_MergedSrc=L2008-1205
18126 TANGUT IDEOGRAPH-#18126, TGT_MergedSrc=L2008-1772
18127 TANGUT IDEOGRAPH-#18127, TGT_MergedSrc=L2008-0871
18128 TANGUT IDEOGRAPH-#18128, TGT_MergedSrc=L2008-1015
18129 TANGUT IDEOGRAPH-#18129, TGT_MergedSrc=L2008-0500
1812A TANGUT IDEOGRAPH-#1812A, TGT_MergedSrc=L2008-1850
1812B TANGUT IDEOGRAPH-#1812B, TGT_MergedSrc=L2008-1098
1812C TANGUT IDEOGRAPH-#1812C, TGT_MergedSrc=L2008-0849
1812D TANGUT IDEOGRAPH-#1812D, TGT_MergedSrc=L2008-1646
1812E TANGUT IDEOGRAPH-#1812E, TGT_MergedSrc=L2008-0662
1812F TANGUT IDEOGRAPH-#1812F, TGT_MergedSrc=L2008-0779
18130 TANGUT IDEOGRAPH-#18130, TGT_MergedSrc=L2008-0821
18131 TANGUT IDEOGRAPH-#18131, TGT_MergedSrc=L2008-1234
18132 TANGUT IDEOGRAPH-#18132, TGT_MergedSrc=L2008-0349
18133 TANGUT IDEOGRAPH-#18133, TGT_MergedSrc=L2008-0543
18134 TANGUT IDEOGRAPH-#18134, TGT_MergedSrc=L2008-1319
18135 TANGUT IDEOGRAPH-#18135, TGT_MergedSrc=L2008-1296
18136 TANGUT IDEOGRAPH-#18136, TGT_MergedSrc=L2008-6019
18137 TANGUT IDEOGRAPH-#18137, TGT_MergedSrc=L2008-1721
18138 TANGUT IDEOGRAPH-#18138, TGT_MergedSrc=L2008-1708
18139 TANGUT IDEOGRAPH-#18139, TGT_MergedSrc=L2008-1317-1318
1813A TANGUT IDEOGRAPH-#1813A, TGT_MergedSrc=L2008-0312
1813B TANGUT IDEOGRAPH-#1813B, TGT_MergedSrc=L2008-1289
1813C TANGUT IDEOGRAPH-#1813C, TGT_MergedSrc=L2008-0361
1813D TANGUT IDEOGRAPH-#1813D, TGT_MergedSrc=L2008-0685
1813E TANGUT IDEOGRAPH-#1813E, TGT_MergedSrc=L2008-1759
1813F TANGUT IDEOGRAPH-#1813F, TGT_MergedSrc=L2008-1355
18140 TANGUT IDEOGRAPH-#18140, TGT_MergedSrc=L2008-0563
18141 TANGUT IDEOGRAPH-#18141, TGT_MergedSrc=L2008-0675
18142 TANGUT IDEOGRAPH-#18142, TGT_MergedSrc=L2008-0693
18143 TANGUT IDEOGRAPH-#18143, TGT_MergedSrc=L2008-0790
18144 TANGUT IDEOGRAPH-#18144, TGT_MergedSrc=L2008-1693
18145 TANGUT IDEOGRAPH-#18145, TGT_MergedSrc=L2008-1865
18146 TANGUT IDEOGRAPH-#18146, TGT_MergedSrc=L2008-1670
18147 TANGUT IDEOGRAPH-#18147, TGT_MergedSrc=L2008-1734-1735
18148 TANGUT IDEOGRAPH-#18148, TGT_MergedSrc=L1997-5997
18149 TANGUT IDEOGRAPH-#18149, TGT_MergedSrc=L2008-1217
1814A TANGUT IDEOGRAPH-#1814A, TGT_MergedSrc=L2008-0273
1814B TANGUT IDEOGRAPH-#1814B, TGT_MergedSrc=L2008-0333
1814C TANGUT IDEOGRAPH-#1814C, TGT_MergedSrc=L2008-0360
1814D TANGUT IDEOGRAPH-#1814D, TGT_MergedSrc=L2008-0705
1814E TANGUT IDEOGRAPH-#1814E, TGT_MergedSrc=L2008-1410
1814F TANGUT IDEOGRAPH-#1814F, TGT_MergedSrc=L2008-0295
18150 TANGUT IDEOGRAPH-#18150, TGT_MergedSrc=L2008-0350
18151 TANGUT IDEOGRAPH-#18151, TGT_MergedSrc=L2008-1758
18152 TANGUT IDEOGRAPH-#18152, TGT_MergedSrc=L2008-0791
18153 TANGUT IDEOGRAPH-#18153, TGT_MergedSrc=L2008-0818
18154 TANGUT IDEOGRAPH-#18154, TGT_MergedSrc=L2008-6016
18155 TANGUT IDEOGRAPH-#18155, TGT_MergedSrc=L2008-1173
18156 TANGUT IDEOGRAPH-#18156, TGT_MergedSrc=L2008-1320
18157 TANGUT IDEOGRAPH-#18157, TGT_MergedSrc=L2008-1321
18158 TANGUT IDEOGRAPH-#18158, TGT_MergedSrc=L2008-1419
18159 TANGUT IDEOGRAPH-#18159, TGT_MergedSrc=L2008-0575
1815A TANGUT IDEOGRAPH-#1815A, TGT_MergedSrc=L2008-0874
1815B TANGUT IDEOGRAPH-#1815B, TGT_MergedSrc=L2008-6010
1815C TANGUT IDEOGRAPH-#1815C, TGT_MergedSrc=L2008-1323
1815D TANGUT IDEOGRAPH-#1815D, TGT_MergedSrc=L2008-0305
1815E TANGUT IDEOGRAPH-#1815E, TGT_MergedSrc=L2008-1204
1815F TANGUT IDEOGRAPH-#1815F, TGT_MergedSrc=L2008-1288
18160 TANGUT IDEOGRAPH-#18160, TGT_MergedSrc=L2008-6017
18161 TANGUT IDEOGRAPH-#18161, TGT_MergedSrc=L2008-1398
18162 TANGUT IDEOGRAPH-#18162, TGT_MergedSrc=L2008-1295
18163 TANGUT IDEOGRAPH-#18163, TGT_MergedSrc=L2008-1183
18164 TANGUT IDEOGRAPH-#18164, TGT_MergedSrc=L2008-1715
18165 TANGUT IDEOGRAPH-#18165, TGT_MergedSrc=L2008-0867
18166 TANGUT IDEOGRAPH-#18166, TGT_MergedSrc=S1968-4780
18167 TANGUT IDEOGRAPH-#18167, TGT_MergedSrc=L2008-0576
18168 TANGUT IDEOGRAPH-#18168, TGT_MergedSrc=L2008-0287
18169 TANGUT IDEOGRAPH-#18169, TGT_MergedSrc=L2008-0274
1816A TANGUT IDEOGRAPH-#1816A, TGT_MergedSrc=L2008-0603
1816B TANGUT IDEOGRAPH-#1816B, TGT_MergedSrc=L2008-1736
1816C TANGUT IDEOGRAPH-#1816C, TGT_MergedSrc=L2008-0792
1816D TANGUT IDEOGRAPH-#1816D, TGT_MergedSrc=L2008-1322
1816E TANGUT IDEOGRAPH-#1816E, TGT_MergedSrc=L2008-0868
1816F TANGUT IDEOGRAPH-#1816F, TGT_MergedSrc=L2008-0342
18170 TANGUT IDEOGRAPH-#18170, TGT_MergedSrc=L2008-0866
18171 TANGUT IDEOGRAPH-#18171, TGT_MergedSrc=L2008-6007
18172 TANGUT IDEOGRAPH-#18172, TGT_MergedSrc=L2008-0717
18173 TANGUT IDEOGRAPH-#18173, TGT_MergedSrc=L2008-0880
18174 TANGUT IDEOGRAPH-#18174, TGT_MergedSrc=L2008-0259
18175 TANGUT IDEOGRAPH-#18175, TGT_MergedSrc=L2008-0345
18176 TANGUT IDEOGRAPH-#18176, TGT_MergedSrc=L2008-6022
18177 TANGUT IDEOGRAPH-#18177, TGT_MergedSrc=L2008-0873
18178 TANGUT IDEOGRAPH-#18178, TGT_MergedSrc=L2008-1388
18179 TANGUT IDEOGRAPH-#18179, TGT_MergedSrc=L2008-0877
1817A TANGUT IDEOGRAPH-#1817A, TGT_MergedSrc=L2008-0600
1817B TANGUT IDEOGRAPH-#1817B, TGT_MergedSrc=L2008-0343
1817C TANGUT IDEOGRAPH-#1817C, TGT_MergedSrc=L2008-6015
1817D TANGUT IDEOGRAPH-#1817D, TGT_MergedSrc=H2004-A-5854
1817E TANGUT IDEOGRAPH-#1817E, TGT_MergedSrc=L2008-1151
1817F TANGUT IDEOGRAPH-#1817F, TGT_MergedSrc=L2008-1443
18180 TANGUT IDEOGRAPH-#18180, TGT_MergedSrc=L2008-0825
18181 TANGUT IDEOGRAPH-#18181, TGT_MergedSrc=L2008-0723
18182 TANGUT IDEOGRAPH-#18182, TGT_MergedSrc=L2008-0391
18183 TANGUT IDEOGRAPH-#18183, TGT_MergedSrc=L2008-1454
18184 TANGUT IDEOGRAPH-#18184, TGT_MergedSrc=L2008-0724
18185 TANGUT IDEOGRAPH-#18185, TGT_MergedSrc=L2008-0829
18186 TANGUT IDEOGRAPH-#18186, TGT_MergedSrc=L2008-1441
18187 TANGUT IDEOGRAPH-#18187, TGT_MergedSrc=L2008-1442
18188 TANGUT IDEOGRAPH-#18188, TGT_MergedSrc=L2008-1784
18189 TANGUT IDEOGRAPH-#18189, TGT_MergedSrc=N1966-059-111
1818A TANGUT IDEOGRAPH-#1818A, TGT_MergedSrc=L2008-1440
1818B TANGUT IDEOGRAPH-#1818B, TGT_MergedSrc=L2008-1805
1818C TANGUT IDEOGRAPH-#1818C, TGT_MergedSrc=L2008-1880
1818D TANGUT IDEOGRAPH-#1818D, TGT_MergedSrc=L2008-0909
1818E TANGUT IDEOGRAPH-#1818E, TGT_MergedSrc=L2008-0844
1818F TANGUT IDEOGRAPH-#1818F, TGT_MergedSrc=L2008-1514
18190 TANGUT IDEOGRAPH-#18190, TGT_MergedSrc=L2008-0994
18191 TANGUT IDEOGRAPH-#18191, TGT_MergedSrc=L2008-0987
18192 TANGUT IDEOGRAPH-#18192, TGT_MergedSrc=L2008-1519
18193 TANGUT IDEOGRAPH-#18193, TGT_MergedSrc=L2008-1229
18194 TANGUT IDEOGRAPH-#18194, TGT_MergedSrc=L2008-0935
18195 TANGUT IDEOGRAPH-#18195, TGT_MergedSrc=L2008-1176
18196 TANGUT IDEOGRAPH-#18196, TGT_MergedSrc=L2008-5870
18197 TANGUT IDEOGRAPH-#18197, TGT_MergedSrc=L2008-5937
18198 TANGUT IDEOGRAPH-#18198, TGT_MergedSrc=L2008-5909
18199 TANGUT IDEOGRAPH-#18199, TGT_MergedSrc=L2008-5934
1819A TANGUT IDEOGRAPH-#1819A, TGT_MergedSrc=L2008-5938
1819B TANGUT IDEOGRAPH-#1819B, TGT_MergedSrc=L2008-5975
1819C TANGUT IDEOGRAPH-#1819C, TGT_MergedSrc=L2008-5832
1819D TANGUT IDEOGRAPH-#1819D, TGT_MergedSrc=L2008-0764
1819E TANGUT IDEOGRAPH-#1819E, TGT_MergedSrc=L2008-0216
1819F TANGUT IDEOGRAPH-#1819F, TGT_MergedSrc=L2008-0233
181A0 TANGUT IDEOGRAPH-#181A0, TGT_MergedSrc=L2008-1046
181A1 TANGUT IDEOGRAPH-#181A1, TGT_MergedSrc=L2008-0516
181A2 TANGUT IDEOGRAPH-#181A2, TGT_MergedSrc=L2008-1052
181A3 TANGUT IDEOGRAPH-#181A3, TGT_MergedSrc=L2008-1135
181A4 TANGUT IDEOGRAPH-#181A4, TGT_MergedSrc=L2008-0212
181A5 TANGUT IDEOGRAPH-#181A5, TGT_MergedSrc=L2008-0768
181A6 TANGUT IDEOGRAPH-#181A6, TGT_MergedSrc=L2008-0520
181A7 TANGUT IDEOGRAPH-#181A7, TGT_MergedSrc=L2008-0655
181A8 TANGUT IDEOGRAPH-#181A8, TGT_MergedSrc=L2008-0648
181A9 TANGUT IDEOGRAPH-#181A9, TGT_MergedSrc=L2008-0665
181AA TANGUT IDEOGRAPH-#181AA, TGT_MergedSrc=L2008-1652
181AB TANGUT IDEOGRAPH-#181AB, TGT_MergedSrc=L2008-1113
181AC TANGUT IDEOGRAPH-#181AC, TGT_MergedSrc=L2008-0847
181AD TANGUT IDEOGRAPH-#181AD, TGT_MergedSrc=L2008-1053
181AE TANGUT IDEOGRAPH-#181AE, TGT_MergedSrc=L2008-0194
181AF TANGUT IDEOGRAPH-#181AF, TGT_MergedSrc=L2008-0189
181B0 TANGUT IDEOGRAPH-#181B0, TGT_MergedSrc=L2008-0191
181B1 TANGUT IDEOGRAPH-#181B1, TGT_MergedSrc=L2008-0667
181B2 TANGUT IDEOGRAPH-#181B2, TGT_MergedSrc=L2008-0984
181B3 TANGUT IDEOGRAPH-#181B3, TGT_MergedSrc=L2008-0983
181B4 TANGUT IDEOGRAPH-#181B4, TGT_MergedSrc=L2008-0669
181B5 TANGUT IDEOGRAPH-#181B5, TGT_MergedSrc=L2008-0666
181B6 TANGUT IDEOGRAPH-#181B6, TGT_MergedSrc=L2008-1606
181B7 TANGUT IDEOGRAPH-#181B7, TGT_MergedSrc=L2008-1653
181B8 TANGUT IDEOGRAPH-#181B8, TGT_MergedSrc=L2008-1656
181B9 TANGUT IDEOGRAPH-#181B9, TGT_MergedSrc=L2008-0859
181BA TANGUT IDEOGRAPH-#181BA, TGT_MergedSrc=L2008-1114
181BB TANGUT IDEOGRAPH-#181BB, TGT_MergedSrc=L2008-1658
181BC TANGUT IDEOGRAPH-#181BC, TGT_MergedSrc=L2008-0770
181BD TANGUT IDEOGRAPH-#181BD, TGT_MergedSrc=L2008-1115
181BE TANGUT IDEOGRAPH-#181BE, TGT_MergedSrc=L2008-1048
181BF TANGUT IDEOGRAPH-#181BF, TGT_MergedSrc=L2008-0234
181C0 TANGUT IDEOGRAPH-#181C0, TGT_MergedSrc=L2008-0525
181C1 TANGUT IDEOGRAPH-#181C1, TGT_MergedSrc=L2008-0238
181C2 TANGUT IDEOGRAPH-#181C2, TGT_MergedSrc=L2008-1136
181C3 TANGUT IDEOGRAPH-#181C3, TGT_MergedSrc=L2008-1056
181C4 TANGUT IDEOGRAPH-#181C4, TGT_MergedSrc=L2008-0649
181C5 TANGUT IDEOGRAPH-#181C5, TGT_MergedSrc=L2008-1626
181C6 TANGUT IDEOGRAPH-#181C6, TGT_MergedSrc=L2008-1654
181C7 TANGUT IDEOGRAPH-#181C7, TGT_MergedSrc=L2008-1119
181C8 TANGUT IDEOGRAPH-#181C8, TGT_MergedSrc=L2008-0848
181C9 TANGUT IDEOGRAPH-#181C9, TGT_MergedSrc=L2008-0192
181CA TANGUT IDEOGRAPH-#181CA, TGT_MergedSrc=L2008-0852
181CB TANGUT IDEOGRAPH-#181CB, TGT_MergedSrc=L2008-0650
181CC TANGUT IDEOGRAPH-#181CC, TGT_MergedSrc=L2008-0672
181CD TANGUT IDEOGRAPH-#181CD, TGT_MergedSrc=L2008-1609
181CE TANGUT IDEOGRAPH-#181CE, TGT_MergedSrc=L2008-1603
181CF TANGUT IDEOGRAPH-#181CF, TGT_MergedSrc=L2008-1657
181D0 TANGUT IDEOGRAPH-#181D0, TGT_MergedSrc=L2008-4071
181D1 TANGUT IDEOGRAPH-#181D1, TGT_MergedSrc=L2008-4083
181D2 TANGUT IDEOGRAPH-#181D2, TGT_MergedSrc=L2008-4063
181D3 TANGUT IDEOGRAPH-#181D3, TGT_MergedSrc=L2008-4064
181D4 TANGUT IDEOGRAPH-#181D4, TGT_MergedSrc=L2008-4075
181D5 TANGUT IDEOGRAPH-#181D5, TGT_MergedSrc=L2008-4076
181D6 TANGUT IDEOGRAPH-#181D6, TGT_MergedSrc=L2008-0488
181D7 TANGUT IDEOGRAPH-#181D7, TGT_MergedSrc=L2008-0186
181D8 TANGUT IDEOGRAPH-#181D8, TGT_MergedSrc=L2008-1622
181D9 TANGUT IDEOGRAPH-#181D9, TGT_MergedSrc=L2008-1457
181DA TANGUT IDEOGRAPH-#181DA, TGT_MergedSrc=L2008-0720
181DB TANGUT IDEOGRAPH-#181DB, TGT_MergedSrc=L2008-0715
181DC TANGUT IDEOGRAPH-#181DC, TGT_MergedSrc=L2008-1121
181DD TANGUT IDEOGRAPH-#181DD, TGT_MergedSrc=L2008-0517
181DE TANGUT IDEOGRAPH-#181DE, TGT_MergedSrc=L2008-1116
181DF TANGUT IDEOGRAPH-#181DF, TGT_MergedSrc=L2008-0765
181E0 TANGUT IDEOGRAPH-#181E0, TGT_MergedSrc=L2008-0518
181E1 TANGUT IDEOGRAPH-#181E1, TGT_MergedSrc=L2008-1600
181E2 TANGUT IDEOGRAPH-#181E2, TGT_MergedSrc=L2008-1133
181E3 TANGUT IDEOGRAPH-#181E3, TGT_MergedSrc=L2008-1663
181E4 TANGUT IDEOGRAPH-#181E4, TGT_MergedSrc=L2008-1719
181E5 TANGUT IDEOGRAPH-#181E5, TGT_MergedSrc=L2008-1426
181E6 TANGUT IDEOGRAPH-#181E6, TGT_MergedSrc=L2008-1446
181E7 TANGUT IDEOGRAPH-#181E7, TGT_MergedSrc=L2008-0400
181E8 TANGUT IDEOGRAPH-#181E8, TGT_MergedSrc=L2008-1787
181E9 TANGUT IDEOGRAPH-#181E9, TGT_MergedSrc=L2008-1451
181EA TANGUT IDEOGRAPH-#181EA, TGT_MergedSrc=L2008-0401
181EB TANGUT IDEOGRAPH-#181EB, TGT_MergedSrc=L2008-0635
181EC TANGUT IDEOGRAPH-#181EC, TGT_MergedSrc=L2008-1557
181ED TANGUT IDEOGRAPH-#181ED, TGT_MergedSrc=L2008-1566
181EE TANGUT IDEOGRAPH-#181EE, TGT_MergedSrc=L2008-0738
181EF TANGUT IDEOGRAPH-#181EF, TGT_MergedSrc=L2008-1573
181F0 TANGUT IDEOGRAPH-#181F0, TGT_MergedSrc=L2008-1500
181F1 TANGUT IDEOGRAPH-#181F1, TGT_MergedSrc=L2008-0839
181F2 TANGUT IDEOGRAPH-#181F2, TGT_MergedSrc=L2008-0632
181F3 TANGUT IDEOGRAPH-#181F3, TGT_MergedSrc=L2008-1823
181F4 TANGUT IDEOGRAPH-#181F4, TGT_MergedSrc=L2008-0449
181F5 TANGUT IDEOGRAPH-#181F5, TGT_MergedSrc=L2008-0633
181F6 TANGUT IDEOGRAPH-#181F6, TGT_MergedSrc=L2008-1881
181F7 TANGUT IDEOGRAPH-#181F7, TGT_MergedSrc=L2008-0840
181F8 TANGUT IDEOGRAPH-#181F8, TGT_MergedSrc=L2008-1882
181F9 TANGUT IDEOGRAPH-#181F9, TGT_MergedSrc=L2008-0544
181FA TANGUT IDEOGRAPH-#181FA, TGT_MergedSrc=L2008-0352
181FB TANGUT IDEOGRAPH-#181FB, TGT_MergedSrc=L2008-0355
181FC TANGUT IDEOGRAPH-#181FC, TGT_MergedSrc=L2008-0532
181FD TANGUT IDEOGRAPH-#181FD, TGT_MergedSrc=L2008-0695
181FE TANGUT IDEOGRAPH-#181FE, TGT_MergedSrc=L2008-1742
181FF TANGUT IDEOGRAPH-#181FF, TGT_MergedSrc=L2008-0578
18200 TANGUT IDEOGRAPH-#18200, TGT_MergedSrc=L2008-0300
18201 TANGUT IDEOGRAPH-#18201, TGT_MergedSrc=L2008-1713
18202 TANGUT IDEOGRAPH-#18202, TGT_MergedSrc=L2008-1743
18203 TANGUT IDEOGRAPH-#18203, TGT_MergedSrc=L2008-0819
18204 TANGUT IDEOGRAPH-#18204, TGT_MergedSrc=L2008-1294
18205 TANGUT IDEOGRAPH-#18205, TGT_MergedSrc=L2008-1371
18206 TANGUT IDEOGRAPH-#18206, TGT_MergedSrc=L2008-0875
18207 TANGUT IDEOGRAPH-#18207, TGT_MergedSrc=L2008-2046
18208 TANGUT IDEOGRAPH-#18208, TGT_MergedSrc=L2008-2047
18209 TANGUT IDEOGRAPH-#18209, TGT_MergedSrc=L2008-3525
1820A TANGUT IDEOGRAPH-#1820A, TGT_MergedSrc=L2008-0141
1820B TANGUT IDEOGRAPH-#1820B, TGT_MergedSrc=L2008-0024
1820C TANGUT IDEOGRAPH-#1820C, TGT_MergedSrc=L2008-0122
1820D TANGUT IDEOGRAPH-#1820D, TGT_MergedSrc=L2008-0831
1820E TANGUT IDEOGRAPH-#1820E, TGT_MergedSrc=L2008-0605
1820F TANGUT IDEOGRAPH-#1820F, TGT_MergedSrc=L2008-1791
18210 TANGUT IDEOGRAPH-#18210, TGT_MergedSrc=L2008-0413
18211 TANGUT IDEOGRAPH-#18211, TGT_MergedSrc=L2008-0607
18212 TANGUT IDEOGRAPH-#18212, TGT_MergedSrc=L2008-1801
18213 TANGUT IDEOGRAPH-#18213, TGT_MergedSrc=L2008-0614
18214 TANGUT IDEOGRAPH-#18214, TGT_MergedSrc=L2008-1879
18215 TANGUT IDEOGRAPH-#18215, TGT_MergedSrc=L2008-1196
18216 TANGUT IDEOGRAPH-#18216, TGT_MergedSrc=L2008-0706
18217 TANGUT IDEOGRAPH-#18217, TGT_MergedSrc=L2008-0787
18218 TANGUT IDEOGRAPH-#18218, TGT_MergedSrc=L2008-1760
18219 TANGUT IDEOGRAPH-#18219, TGT_MergedSrc=L2008-0160
1821A TANGUT IDEOGRAPH-#1821A, TGT_MergedSrc=L2008-0102
1821B TANGUT IDEOGRAPH-#1821B, TGT_MergedSrc=L2008-0786
1821C TANGUT IDEOGRAPH-#1821C, TGT_MergedSrc=L2008-0711
1821D TANGUT IDEOGRAPH-#1821D, TGT_MergedSrc=L2008-0284
1821E TANGUT IDEOGRAPH-#1821E, TGT_MergedSrc=L2008-0330
1821F TANGUT IDEOGRAPH-#1821F, TGT_MergedSrc=L2008-0515
18220 TANGUT IDEOGRAPH-#18220, TGT_MergedSrc=L2008-1655
18221 TANGUT IDEOGRAPH-#18221, TGT_MergedSrc=L2008-1057
18222 TANGUT IDEOGRAPH-#18222, TGT_MergedSrc=L2008-0193
18223 TANGUT IDEOGRAPH-#18223, TGT_MergedSrc=L2008-0215
18224 TANGUT IDEOGRAPH-#18224, TGT_MergedSrc=L2008-0232
18225 TANGUT IDEOGRAPH-#18225, TGT_MergedSrc=L2008-0671
18226 TANGUT IDEOGRAPH-#18226, TGT_MergedSrc=L2008-0701
18227 TANGUT IDEOGRAPH-#18227, TGT_MergedSrc=L2008-1332
18228 TANGUT IDEOGRAPH-#18228, TGT_MergedSrc=L2008-1747
18229 TANGUT IDEOGRAPH-#18229, TGT_MergedSrc=L2008-0100
1822A TANGUT IDEOGRAPH-#1822A, TGT_MergedSrc=L2008-1863
1822B TANGUT IDEOGRAPH-#1822B, TGT_MergedSrc=L2008-0546
1822C TANGUT IDEOGRAPH-#1822C, TGT_MergedSrc=L2008-1722
1822D TANGUT IDEOGRAPH-#1822D, TGT_MergedSrc=L2008-1684
1822E TANGUT IDEOGRAPH-#1822E, TGT_MergedSrc=L2008-0869
1822F TANGUT IDEOGRAPH-#1822F, TGT_MergedSrc=L2008-0589
18230 TANGUT IDEOGRAPH-#18230, TGT_MergedSrc=L2008-1690
18231 TANGUT IDEOGRAPH-#18231, TGT_MergedSrc=L2008-1728
18232 TANGUT IDEOGRAPH-#18232, TGT_MergedSrc=L2008-1386
18233 TANGUT IDEOGRAPH-#18233, TGT_MergedSrc=L2008-0469
18234 TANGUT IDEOGRAPH-#18234, TGT_MergedSrc=L2008-1837
18235 TANGUT IDEOGRAPH-#18235, TGT_MergedSrc=L2008-1561
18236 TANGUT IDEOGRAPH-#18236, TGT_MergedSrc=L2008-0472
18237 TANGUT IDEOGRAPH-#18237, TGT_MergedSrc=L2008-1567
18238 TANGUT IDEOGRAPH-#18238, TGT_MergedSrc=L2008-1568
18239 TANGUT IDEOGRAPH-#18239, TGT_MergedSrc=L2008-1553
1823A TANGUT IDEOGRAPH-#1823A, TGT_MergedSrc=L2008-2390
1823B TANGUT IDEOGRAPH-#1823B, TGT_MergedSrc=L2008-2924
1823C TANGUT IDEOGRAPH-#1823C, TGT_MergedSrc=L2008-2976
1823D TANGUT IDEOGRAPH-#1823D, TGT_MergedSrc=L2008-2392
1823E TANGUT IDEOGRAPH-#1823E, TGT_MergedSrc=L2008-2925
1823F TANGUT IDEOGRAPH-#1823F, TGT_MergedSrc=N1966-136-052
18240 TANGUT IDEOGRAPH-#18240, TGT_MergedSrc=L2008-2975
18241 TANGUT IDEOGRAPH-#18241, TGT_MergedSrc=L2008-1979
18242 TANGUT IDEOGRAPH-#18242, TGT_MergedSrc=L2008-1935
18243 TANGUT IDEOGRAPH-#18243, TGT_MergedSrc=L2008-3445
18244 TANGUT IDEOGRAPH-#18244, TGT_MergedSrc=L2008-2351
18245 TANGUT IDEOGRAPH-#18245, TGT_MergedSrc=L2008-2549
18246 TANGUT IDEOGRAPH-#18246, TGT_MergedSrc=L2008-3755
18247 TANGUT IDEOGRAPH-#18247, TGT_MergedSrc=L2008-3447
18248 TANGUT IDEOGRAPH-#18248, TGT_MergedSrc=L2008-3444
18249 TANGUT IDEOGRAPH-#18249, TGT_MergedSrc=L2008-4566
1824A TANGUT IDEOGRAPH-#1824A, TGT_MergedSrc=L2008-4666
1824B TANGUT IDEOGRAPH-#1824B, TGT_MergedSrc=L2008-4602
1824C TANGUT IDEOGRAPH-#1824C, TGT_MergedSrc=L2008-4607
1824D TANGUT IDEOGRAPH-#1824D, TGT_MergedSrc=L2008-4573
1824E TANGUT IDEOGRAPH-#1824E, TGT_MergedSrc=L2008-4640
1824F TANGUT IDEOGRAPH-#1824F, TGT_MergedSrc=L2008-4515
18250 TANGUT IDEOGRAPH-#18250, TGT_MergedSrc=L2008-4587
18251 TANGUT IDEOGRAPH-#18251, TGT_MergedSrc=L2008-4574
18252 TANGUT IDEOGRAPH-#18252, TGT_MergedSrc=L2008-4575
18253 TANGUT IDEOGRAPH-#18253, TGT_MergedSrc=L2008-4655
18254 TANGUT IDEOGRAPH-#18254, TGT_MergedSrc=L2008-4626
18255 TANGUT IDEOGRAPH-#18255, TGT_MergedSrc=L2008-4645
18256 TANGUT IDEOGRAPH-#18256, TGT_MergedSrc=L2008-4646
18257 TANGUT IDEOGRAPH-#18257, TGT_MergedSrc=L2008-4590
18258 TANGUT IDEOGRAPH-#18258, TGT_MergedSrc=L2008-4562
18259 TANGUT IDEOGRAPH-#18259, TGT_MergedSrc=L2008-4570
1825A TANGUT IDEOGRAPH-#1825A, TGT_MergedSrc=L2008-4641
1825B TANGUT IDEOGRAPH-#1825B, TGT_MergedSrc=L2008-4588
1825C TANGUT IDEOGRAPH-#1825C, TGT_MergedSrc=L2008-4522
1825D TANGUT IDEOGRAPH-#1825D, TGT_MergedSrc=L2008-4595
1825E TANGUT IDEOGRAPH-#1825E, TGT_MergedSrc=L2008-4601
1825F TANGUT IDEOGRAPH-#1825F, TGT_MergedSrc=L2008-1884
18260 TANGUT IDEOGRAPH-#18260, TGT_MergedSrc=L2008-2056
18261 TANGUT IDEOGRAPH-#18261, TGT_MergedSrc=L2008-2596
18262 TANGUT IDEOGRAPH-#18262, TGT_MergedSrc=L2008-3037
18263 TANGUT IDEOGRAPH-#18263, TGT_MergedSrc=L2008-3777
18264 TANGUT IDEOGRAPH-#18264, TGT_MergedSrc=L2008-4056
18265 TANGUT IDEOGRAPH-#18265, TGT_MergedSrc=L2008-3020
18266 TANGUT IDEOGRAPH-#18266, TGT_MergedSrc=L2008-3021
18267 TANGUT IDEOGRAPH-#18267, TGT_MergedSrc=L2008-3523
18268 TANGUT IDEOGRAPH-#18268, TGT_MergedSrc=L2008-3543
18269 TANGUT IDEOGRAPH-#18269, TGT_MergedSrc=L2008-2300
1826A TANGUT IDEOGRAPH-#1826A, TGT_MergedSrc=L2008-3030
1826B TANGUT IDEOGRAPH-#1826B, TGT_MergedSrc=L2008-2035
1826C TANGUT IDEOGRAPH-#1826C, TGT_MergedSrc=L2008-2036
1826D TANGUT IDEOGRAPH-#1826D, TGT_MergedSrc=L2008-2008
1826E TANGUT IDEOGRAPH-#1826E, TGT_MergedSrc=L2008-2055
1826F TANGUT IDEOGRAPH-#1826F, TGT_MergedSrc=L2008-2037
18270 TANGUT IDEOGRAPH-#18270, TGT_MergedSrc=L2008-2580
18271 TANGUT IDEOGRAPH-#18271, TGT_MergedSrc=L2008-3079
18272 TANGUT IDEOGRAPH-#18272, TGT_MergedSrc=L2008-3062
18273 TANGUT IDEOGRAPH-#18273, TGT_MergedSrc=L2008-2059
18274 TANGUT IDEOGRAPH-#18274, TGT_MergedSrc=L2008-2010
18275 TANGUT IDEOGRAPH-#18275, TGT_MergedSrc=L2008-2033
18276 TANGUT IDEOGRAPH-#18276, TGT_MergedSrc=L2008-2060
18277 TANGUT IDEOGRAPH-#18277, TGT_MergedSrc=L2008-2594
18278 TANGUT IDEOGRAPH-#18278, TGT_MergedSrc=L2008-3530
18279 TANGUT IDEOGRAPH-#18279, TGT_MergedSrc=L2008-2426
1827A TANGUT IDEOGRAPH-#1827A, TGT_MergedSrc=L2008-2424
1827B TANGUT IDEOGRAPH-#1827B, TGT_MergedSrc=L2008-2595
1827C TANGUT IDEOGRAPH-#1827C, TGT_MergedSrc=L2008-3528
1827D TANGUT IDEOGRAPH-#1827D, TGT_MergedSrc=L2008-3531
1827E TANGUT IDEOGRAPH-#1827E, TGT_MergedSrc=L2008-3081
1827F TANGUT IDEOGRAPH-#1827F, TGT_MergedSrc=L2008-2850
18280 TANGUT IDEOGRAPH-#18280, TGT_MergedSrc=L2008-2016
18281 TANGUT IDEOGRAPH-#18281, TGT_MergedSrc=L2008-3552
18282 TANGUT IDEOGRAPH-#18282, TGT_MergedSrc=L2008-2015
18283 TANGUT IDEOGRAPH-#18283, TGT_MergedSrc=L2008-3063
18284 TANGUT IDEOGRAPH-#18284, TGT_MergedSrc=L2008-3551
18285 TANGUT IDEOGRAPH-#18285, TGT_MergedSrc=L2008-3775
18286 TANGUT IDEOGRAPH-#18286, TGT_MergedSrc=L2008-2430
18287 TANGUT IDEOGRAPH-#18287, TGT_MergedSrc=L2008-3774
18288 TANGUT IDEOGRAPH-#18288, TGT_MergedSrc=L2008-2735
18289 TANGUT IDEOGRAPH-#18289, TGT_MergedSrc=L2008-2427
1828A TANGUT IDEOGRAPH-#1828A, TGT_MergedSrc=L2008-2038
1828B TANGUT IDEOGRAPH-#1828B, TGT_MergedSrc=L2008-2428
1828C TANGUT IDEOGRAPH-#1828C, TGT_MergedSrc=L2008-3064
1828D TANGUT IDEOGRAPH-#1828D, TGT_MergedSrc=L2008-3014
1828E TANGUT IDEOGRAPH-#1828E, TGT_MergedSrc=L2008-3532
1828F TANGUT IDEOGRAPH-#1828F, TGT_MergedSrc=L2008-1887
18290 TANGUT IDEOGRAPH-#18290, TGT_MergedSrc=L2008-2219
18291 TANGUT IDEOGRAPH-#18291, TGT_MergedSrc=L2008-2071
18292 TANGUT IDEOGRAPH-#18292, TGT_MergedSrc=L2008-3801
18293 TANGUT IDEOGRAPH-#18293, TGT_MergedSrc=L2008-2106
18294 TANGUT IDEOGRAPH-#18294, TGT_MergedSrc=L2008-3568
18295 TANGUT IDEOGRAPH-#18295, TGT_MergedSrc=L2008-2891
18296 TANGUT IDEOGRAPH-#18296, TGT_MergedSrc=L2008-2293
18297 TANGUT IDEOGRAPH-#18297, TGT_MergedSrc=L2008-2768
18298 TANGUT IDEOGRAPH-#18298, TGT_MergedSrc=L2008-2485
18299 TANGUT IDEOGRAPH-#18299, TGT_MergedSrc=L2008-2244
1829A TANGUT IDEOGRAPH-#1829A, TGT_MergedSrc=L2008-3649
1829B TANGUT IDEOGRAPH-#1829B, TGT_MergedSrc=L2008-2191
1829C TANGUT IDEOGRAPH-#1829C, TGT_MergedSrc=L2008-2269
1829D TANGUT IDEOGRAPH-#1829D, TGT_MergedSrc=L2008-2798
1829E TANGUT IDEOGRAPH-#1829E, TGT_MergedSrc=L2008-3567
1829F TANGUT IDEOGRAPH-#1829F, TGT_MergedSrc=L2008-3572
182A0 TANGUT IDEOGRAPH-#182A0, TGT_MergedSrc=L2008-3205
182A1 TANGUT IDEOGRAPH-#182A1, TGT_MergedSrc=L2008-2894
182A2 TANGUT IDEOGRAPH-#182A2, TGT_MergedSrc=L2008-2409
182A3 TANGUT IDEOGRAPH-#182A3, TGT_MergedSrc=L2008-3871
182A4 TANGUT IDEOGRAPH-#182A4, TGT_MergedSrc=L2008-3881
182A5 TANGUT IDEOGRAPH-#182A5, TGT_MergedSrc=L2008-3915
182A6 TANGUT IDEOGRAPH-#182A6, TGT_MergedSrc=L2008-3918
182A7 TANGUT IDEOGRAPH-#182A7, TGT_MergedSrc=L2008-3975
182A8 TANGUT IDEOGRAPH-#182A8, TGT_MergedSrc=L2008-3981
182A9 TANGUT IDEOGRAPH-#182A9, TGT_MergedSrc=L2008-4001
182AA TANGUT IDEOGRAPH-#182AA, TGT_MergedSrc=L2008-3919
182AB TANGUT IDEOGRAPH-#182AB, TGT_MergedSrc=L2008-3903
182AC TANGUT IDEOGRAPH-#182AC, TGT_MergedSrc=L2008-3921
182AD TANGUT IDEOGRAPH-#182AD, TGT_MergedSrc=L2008-4006
182AE TANGUT IDEOGRAPH-#182AE, TGT_MergedSrc=L2008-3983
182AF TANGUT IDEOGRAPH-#182AF, TGT_MergedSrc=L2008-4016
182B0 TANGUT IDEOGRAPH-#182B0, TGT_MergedSrc=L2008-4007
182B1 TANGUT IDEOGRAPH-#182B1, TGT_MergedSrc=L2008-3936
182B2 TANGUT IDEOGRAPH-#182B2, TGT_MergedSrc=L2008-4008
182B3 TANGUT IDEOGRAPH-#182B3, TGT_MergedSrc=L2008-3890
182B4 TANGUT IDEOGRAPH-#182B4, TGT_MergedSrc=L2008-3951
182B5 TANGUT IDEOGRAPH-#182B5, TGT_MergedSrc=L2008-3949
182B6 TANGUT IDEOGRAPH-#182B6, TGT_MergedSrc=L2008-3894
182B7 TANGUT IDEOGRAPH-#182B7, TGT_MergedSrc=L2008-3864
182B8 TANGUT IDEOGRAPH-#182B8, TGT_MergedSrc=L2008-3914
182B9 TANGUT IDEOGRAPH-#182B9, TGT_MergedSrc=L2008-3985
182BA TANGUT IDEOGRAPH-#182BA, TGT_MergedSrc=L2008-3853
182BB TANGUT IDEOGRAPH-#182BB, TGT_MergedSrc=L2008-3986
182BC TANGUT IDEOGRAPH-#182BC, TGT_MergedSrc=L2008-3987
182BD TANGUT IDEOGRAPH-#182BD, TGT_MergedSrc=L2008-3955
182BE TANGUT IDEOGRAPH-#182BE, TGT_MergedSrc=L2008-3948
182BF TANGUT IDEOGRAPH-#182BF, TGT_MergedSrc=L2008-3962
182C0 TANGUT IDEOGRAPH-#182C0, TGT_MergedSrc=L2008-3854
182C1 TANGUT IDEOGRAPH-#182C1, TGT_MergedSrc=L2008-3956
182C2 TANGUT IDEOGRAPH-#182C2, TGT_MergedSrc=L2008-3905
182C3 TANGUT IDEOGRAPH-#182C3, TGT_MergedSrc=L2008-3929
182C4 TANGUT IDEOGRAPH-#182C4, TGT_MergedSrc=L2008-3995
182C5 TANGUT IDEOGRAPH-#182C5, TGT_MergedSrc=L2008-3984
182C6 TANGUT IDEOGRAPH-#182C6, TGT_MergedSrc=L2008-3958
182C7 TANGUT IDEOGRAPH-#182C7, TGT_MergedSrc=L2008-3859
182C8 TANGUT IDEOGRAPH-#182C8, TGT_MergedSrc=L2008-3907
182C9 TANGUT IDEOGRAPH-#182C9, TGT_MergedSrc=L2008-3970
182CA TANGUT IDEOGRAPH-#182CA, TGT_MergedSrc=L2008-3977
182CB TANGUT IDEOGRAPH-#182CB, TGT_MergedSrc=L2008-3969
182CC TANGUT IDEOGRAPH-#182CC, TGT_MergedSrc=L2008-3917
182CD TANGUT IDEOGRAPH-#182CD, TGT_MergedSrc=L2008-3998
182CE TANGUT IDEOGRAPH-#182CE, TGT_MergedSrc=L2008-3942
182CF TANGUT IDEOGRAPH-#182CF, TGT_MergedSrc=L2008-5301
182D0 TANGUT IDEOGRAPH-#182D0, TGT_MergedSrc=L2008-5439
182D1 TANGUT IDEOGRAPH-#182D1, TGT_MergedSrc=L2008-5679
182D2 TANGUT IDEOGRAPH-#182D2, TGT_MergedSrc=L2008-5214
182D3 TANGUT IDEOGRAPH-#182D3, TGT_MergedSrc=L2008-5596
182D4 TANGUT IDEOGRAPH-#182D4, TGT_MergedSrc=L2008-5444
182D5 TANGUT IDEOGRAPH-#182D5, TGT_MergedSrc=L2008-5661
182D6 TANGUT IDEOGRAPH-#182D6, TGT_MergedSrc=L2008-5195
182D7 TANGUT IDEOGRAPH-#182D7, TGT_MergedSrc=L2008-5635
182D8 TANGUT IDEOGRAPH-#182D8, TGT_MergedSrc=L2008-5401
182D9 TANGUT IDEOGRAPH-#182D9, TGT_MergedSrc=L2008-5680
182DA TANGUT IDEOGRAPH-#182DA, TGT_MergedSrc=L2008-5201
182DB TANGUT IDEOGRAPH-#182DB, TGT_MergedSrc=L2008-5227
182DC TANGUT IDEOGRAPH-#182DC, TGT_MergedSrc=L2008-5479
182DD TANGUT IDEOGRAPH-#182DD, TGT_MergedSrc=L2008-5807
182DE TANGUT IDEOGRAPH-#182DE, TGT_MergedSrc=L2008-5921
182DF TANGUT IDEOGRAPH-#182DF, TGT_MergedSrc=L2008-5825
182E0 TANGUT IDEOGRAPH-#182E0, TGT_MergedSrc=L2008-5932
182E1 TANGUT IDEOGRAPH-#182E1, TGT_MergedSrc=L2008-5971
182E2 TANGUT IDEOGRAPH-#182E2, TGT_MergedSrc=L2008-5906
182E3 TANGUT IDEOGRAPH-#182E3, TGT_MergedSrc=L2008-5972
182E4 TANGUT IDEOGRAPH-#182E4, TGT_MergedSrc=L2008-5907
182E5 TANGUT IDEOGRAPH-#182E5, TGT_MergedSrc=L2008-5609
182E6 TANGUT IDEOGRAPH-#182E6, TGT_MergedSrc=L2008-5617
182E7 TANGUT IDEOGRAPH-#182E7, TGT_MergedSrc=L2008-5381
182E8 TANGUT IDEOGRAPH-#182E8, TGT_MergedSrc=L2008-5306
182E9 TANGUT IDEOGRAPH-#182E9, TGT_MergedSrc=L2008-5447
182EA TANGUT IDEOGRAPH-#182EA, TGT_MergedSrc=L2008-5182
182EB TANGUT IDEOGRAPH-#182EB, TGT_MergedSrc=L2008-5375
182EC TANGUT IDEOGRAPH-#182EC, TGT_MergedSrc=L2008-5610
182ED TANGUT IDEOGRAPH-#182ED, TGT_MergedSrc=L2008-5440
182EE TANGUT IDEOGRAPH-#182EE, TGT_MergedSrc=L2008-5755
182EF TANGUT IDEOGRAPH-#182EF, TGT_MergedSrc=L2008-5650
182F0 TANGUT IDEOGRAPH-#182F0, TGT_MergedSrc=L2008-5189
182F1 TANGUT IDEOGRAPH-#182F1, TGT_MergedSrc=L2008-5632
182F2 TANGUT IDEOGRAPH-#182F2, TGT_MergedSrc=L2008-5627
182F3 TANGUT IDEOGRAPH-#182F3, TGT_MergedSrc=L2008-5598
182F4 TANGUT IDEOGRAPH-#182F4, TGT_MergedSrc=L2008-5235
182F5 TANGUT IDEOGRAPH-#182F5, TGT_MergedSrc=L2008-5190
182F6 TANGUT IDEOGRAPH-#182F6, TGT_MergedSrc=L2008-5580
182F7 TANGUT IDEOGRAPH-#182F7, TGT_MergedSrc=L2008-5651
182F8 TANGUT IDEOGRAPH-#182F8, TGT_MergedSrc=L2008-5244
182F9 TANGUT IDEOGRAPH-#182F9, TGT_MergedSrc=L2008-5342
182FA TANGUT IDEOGRAPH-#182FA, TGT_MergedSrc=L2008-5297
182FB TANGUT IDEOGRAPH-#182FB, TGT_MergedSrc=L2008-5708
182FC TANGUT IDEOGRAPH-#182FC, TGT_MergedSrc=L2008-5545
182FD TANGUT IDEOGRAPH-#182FD, TGT_MergedSrc=L2008-5507
182FE TANGUT IDEOGRAPH-#182FE, TGT_MergedSrc=L2008-5144
182FF TANGUT IDEOGRAPH-#182FF, TGT_MergedSrc=L2008-5147
18300 TANGUT IDEOGRAPH-#18300, TGT_MergedSrc=L2008-5508
18301 TANGUT IDEOGRAPH-#18301, TGT_MergedSrc=L2008-5428
18302 TANGUT IDEOGRAPH-#18302, TGT_MergedSrc=L2008-5806
18303 TANGUT IDEOGRAPH-#18303, TGT_MergedSrc=L2008-5818
18304 TANGUT IDEOGRAPH-#18304, TGT_MergedSrc=L2008-5922
18305 TANGUT IDEOGRAPH-#18305, TGT_MergedSrc=L2008-5864
18306 TANGUT IDEOGRAPH-#18306, TGT_MergedSrc=L2008-5924
18307 TANGUT IDEOGRAPH-#18307, TGT_MergedSrc=L2008-5990
18308 TANGUT IDEOGRAPH-#18308, TGT_MergedSrc=L2008-5821
18309 TANGUT IDEOGRAPH-#18309, TGT_MergedSrc=L2008-5866
1830A TANGUT IDEOGRAPH-#1830A, TGT_MergedSrc=L2008-5888
1830B TANGUT IDEOGRAPH-#1830B, TGT_MergedSrc=L2008-5926
1830C TANGUT IDEOGRAPH-#1830C, TGT_MergedSrc=L2008-5973
1830D TANGUT IDEOGRAPH-#1830D, TGT_MergedSrc=L2008-5903
1830E TANGUT IDEOGRAPH-#1830E, TGT_MergedSrc=L2008-5905
1830F TANGUT IDEOGRAPH-#1830F, TGT_MergedSrc=L2008-5917
18310 TANGUT IDEOGRAPH-#18310, TGT_MergedSrc=L2008-5868
18311 TANGUT IDEOGRAPH-#18311, TGT_MergedSrc=L2008-5827
18312 TANGUT IDEOGRAPH-#18312, TGT_MergedSrc=L2008-5891
18313 TANGUT IDEOGRAPH-#18313, TGT_MergedSrc=L2008-5927
18314 TANGUT IDEOGRAPH-#18314, TGT_MergedSrc=L2008-5928
18315 TANGUT IDEOGRAPH-#18315, TGT_MergedSrc=L2008-5822
18316 TANGUT IDEOGRAPH-#18316, TGT_MergedSrc=L2008-5824
18317 TANGUT IDEOGRAPH-#18317, TGT_MergedSrc=L2008-5823
18318 TANGUT IDEOGRAPH-#18318, TGT_MergedSrc=L2008-5867
18319 TANGUT IDEOGRAPH-#18319, TGT_MergedSrc=L2008-5829
1831A TANGUT IDEOGRAPH-#1831A, TGT_MergedSrc=L2008-5929
1831B TANGUT IDEOGRAPH-#1831B, TGT_MergedSrc=L2008-5819
1831C TANGUT IDEOGRAPH-#1831C, TGT_MergedSrc=L2008-5970
1831D TANGUT IDEOGRAPH-#1831D, TGT_MergedSrc=L2008-6072
1831E TANGUT IDEOGRAPH-#1831E, TGT_MergedSrc=L2008-5828
1831F TANGUT IDEOGRAPH-#1831F, TGT_MergedSrc=L2008-5863
18320 TANGUT IDEOGRAPH-#18320, TGT_MergedSrc=L2008-5908
18321 TANGUT IDEOGRAPH-#18321, TGT_MergedSrc=L2008-5826
18322 TANGUT IDEOGRAPH-#18322, TGT_MergedSrc=L2008-5810
18323 TANGUT IDEOGRAPH-#18323, TGT_MergedSrc=L2008-5942
18324 TANGUT IDEOGRAPH-#18324, TGT_MergedSrc=L2008-5941
18325 TANGUT IDEOGRAPH-#18325, TGT_MergedSrc=L2008-5979
18326 TANGUT IDEOGRAPH-#18326, TGT_MergedSrc=L2008-5943
18327 TANGUT IDEOGRAPH-#18327, TGT_MergedSrc=L2008-5537
18328 TANGUT IDEOGRAPH-#18328, TGT_MergedSrc=L2008-5257
18329 TANGUT IDEOGRAPH-#18329, TGT_MergedSrc=L2008-5088
1832A TANGUT IDEOGRAPH-#1832A, TGT_MergedSrc=L2008-5538
1832B TANGUT IDEOGRAPH-#1832B, TGT_MergedSrc=L2008-5124
1832C TANGUT IDEOGRAPH-#1832C, TGT_MergedSrc=L2008-5089
1832D TANGUT IDEOGRAPH-#1832D, TGT_MergedSrc=L2008-5129
1832E TANGUT IDEOGRAPH-#1832E, TGT_MergedSrc=L2008-5265
1832F TANGUT IDEOGRAPH-#1832F, TGT_MergedSrc=L2008-5296
18330 TANGUT IDEOGRAPH-#18330, TGT_MergedSrc=L2008-5707
18331 TANGUT IDEOGRAPH-#18331, TGT_MergedSrc=L2008-5539
18332 TANGUT IDEOGRAPH-#18332, TGT_MergedSrc=L2008-5559
18333 TANGUT IDEOGRAPH-#18333, TGT_MergedSrc=L2008-5141
18334 TANGUT IDEOGRAPH-#18334, TGT_MergedSrc=L2008-5151
18335 TANGUT IDEOGRAPH-#18335, TGT_MergedSrc=L2008-5125
18336 TANGUT IDEOGRAPH-#18336, TGT_MergedSrc=L2008-5090
18337 TANGUT IDEOGRAPH-#18337, TGT_MergedSrc=L2008-5366
18338 TANGUT IDEOGRAPH-#18338, TGT_MergedSrc=L2008-5558
18339 TANGUT IDEOGRAPH-#18339, TGT_MergedSrc=L2008-5575
1833A TANGUT IDEOGRAPH-#1833A, TGT_MergedSrc=L2008-5152
1833B TANGUT IDEOGRAPH-#1833B, TGT_MergedSrc=L2008-5096
1833C TANGUT IDEOGRAPH-#1833C, TGT_MergedSrc=L2008-5563
1833D TANGUT IDEOGRAPH-#1833D, TGT_MergedSrc=L2008-5354
1833E TANGUT IDEOGRAPH-#1833E, TGT_MergedSrc=L2008-5426
1833F TANGUT IDEOGRAPH-#1833F, TGT_MergedSrc=L2008-5577
18340 TANGUT IDEOGRAPH-#18340, TGT_MergedSrc=L2008-5560
18341 TANGUT IDEOGRAPH-#18341, TGT_MergedSrc=L2008-5695
18342 TANGUT IDEOGRAPH-#18342, TGT_MergedSrc=L2008-5504
18343 TANGUT IDEOGRAPH-#18343, TGT_MergedSrc=L2008-5540
18344 TANGUT IDEOGRAPH-#18344, TGT_MergedSrc=L2008-5502
18345 TANGUT IDEOGRAPH-#18345, TGT_MergedSrc=L2008-6060
18346 TANGUT IDEOGRAPH-#18346, TGT_MergedSrc=L2008-5562
18347 TANGUT IDEOGRAPH-#18347, TGT_MergedSrc=L2008-5263
18348 TANGUT IDEOGRAPH-#18348, TGT_MergedSrc=L2008-5463
18349 TANGUT IDEOGRAPH-#18349, TGT_MergedSrc=L2008-5142
1834A TANGUT IDEOGRAPH-#1834A, TGT_MergedSrc=L2008-5092
1834B TANGUT IDEOGRAPH-#1834B, TGT_MergedSrc=L2008-5561
1834C TANGUT IDEOGRAPH-#1834C, TGT_MergedSrc=L2008-5266
1834D TANGUT IDEOGRAPH-#1834D, TGT_MergedSrc=L2008-5506
1834E TANGUT IDEOGRAPH-#1834E, TGT_MergedSrc=L2008-5786
1834F TANGUT IDEOGRAPH-#1834F, TGT_MergedSrc=L2008-5063
18350 TANGUT IDEOGRAPH-#18350, TGT_MergedSrc=L2008-4675
18351 TANGUT IDEOGRAPH-#18351, TGT_MergedSrc=L2008-5267
18352 TANGUT IDEOGRAPH-#18352, TGT_MergedSrc=L2008-5097
18353 TANGUT IDEOGRAPH-#18353, TGT_MergedSrc=L2008-5154
18354 TANGUT IDEOGRAPH-#18354, TGT_MergedSrc=L2008-5566
18355 TANGUT IDEOGRAPH-#18355, TGT_MergedSrc=L2008-6058
18356 TANGUT IDEOGRAPH-#18356, TGT_MergedSrc=L2008-5470
18357 TANGUT IDEOGRAPH-#18357, TGT_MergedSrc=L2008-5720
18358 TANGUT IDEOGRAPH-#18358, TGT_MergedSrc=L2008-5145
18359 TANGUT IDEOGRAPH-#18359, TGT_MergedSrc=L2008-5699
1835A TANGUT IDEOGRAPH-#1835A, TGT_MergedSrc=L2008-5132
1835B TANGUT IDEOGRAPH-#1835B, TGT_MergedSrc=L2008-6066
1835C TANGUT IDEOGRAPH-#1835C, TGT_MergedSrc=L2008-6056
1835D TANGUT IDEOGRAPH-#1835D, TGT_MergedSrc=L2008-4743
1835E TANGUT IDEOGRAPH-#1835E, TGT_MergedSrc=L2008-5258
1835F TANGUT IDEOGRAPH-#1835F, TGT_MergedSrc=L2008-5533
18360 TANGUT IDEOGRAPH-#18360, TGT_MergedSrc=L2008-5571
18361 TANGUT IDEOGRAPH-#18361, TGT_MergedSrc=L2008-5365
18362 TANGUT IDEOGRAPH-#18362, TGT_MergedSrc=L2008-5784
18363 TANGUT IDEOGRAPH-#18363, TGT_MergedSrc=L2008-5715
18364 TANGUT IDEOGRAPH-#18364, TGT_MergedSrc=L2008-5123
18365 TANGUT IDEOGRAPH-#18365, TGT_MergedSrc=L2008-5536
18366 TANGUT IDEOGRAPH-#18366, TGT_MergedSrc=L2008-5498
18367 TANGUT IDEOGRAPH-#18367, TGT_MergedSrc=L2008-5118
18368 TANGUT IDEOGRAPH-#18368, TGT_MergedSrc=L2008-5222
18369 TANGUT IDEOGRAPH-#18369, TGT_MergedSrc=L2008-5741
1836A TANGUT IDEOGRAPH-#1836A, TGT_MergedSrc=L2008-5590
1836B TANGUT IDEOGRAPH-#1836B, TGT_MergedSrc=L2008-5248
1836C TANGUT IDEOGRAPH-#1836C, TGT_MergedSrc=L2008-5748
1836D TANGUT IDEOGRAPH-#1836D, TGT_MergedSrc=L2008-5234
1836E TANGUT IDEOGRAPH-#1836E, TGT_MergedSrc=L2008-5749
1836F TANGUT IDEOGRAPH-#1836F, TGT_MergedSrc=L2008-5441
18370 TANGUT IDEOGRAPH-#18370, TGT_MergedSrc=L2008-5634
18371 TANGUT IDEOGRAPH-#18371, TGT_MergedSrc=L2008-6062
18372 TANGUT IDEOGRAPH-#18372, TGT_MergedSrc=L2008-5311
18373 TANGUT IDEOGRAPH-#18373, TGT_MergedSrc=L2008-5531
18374 TANGUT IDEOGRAPH-#18374, TGT_MergedSrc=L2008-5065
18375 TANGUT IDEOGRAPH-#18375, TGT_MergedSrc=L2008-5286
18376 TANGUT IDEOGRAPH-#18376, TGT_MergedSrc=L2008-5073
18377 TANGUT IDEOGRAPH-#18377, TGT_MergedSrc=L2008-5074
18378 TANGUT IDEOGRAPH-#18378, TGT_MergedSrc=L2008-5579
18379 TANGUT IDEOGRAPH-#18379, TGT_MergedSrc=L2008-5290
1837A TANGUT IDEOGRAPH-#1837A, TGT_MergedSrc=L2008-5499
1837B TANGUT IDEOGRAPH-#1837B, TGT_MergedSrc=L2008-5714
1837C TANGUT IDEOGRAPH-#1837C, TGT_MergedSrc=L2008-5081
1837D TANGUT IDEOGRAPH-#1837D, TGT_MergedSrc=L2008-5082
1837E TANGUT IDEOGRAPH-#1837E, TGT_MergedSrc=L2008-5553
1837F TANGUT IDEOGRAPH-#1837F, TGT_MergedSrc=L2008-5420
18380 TANGUT IDEOGRAPH-#18380, TGT_MergedSrc=L2008-5527
18381 TANGUT IDEOGRAPH-#18381, TGT_MergedSrc=L2008-5534
18382 TANGUT IDEOGRAPH-#18382, TGT_MergedSrc=N1966-111-081
18383 TANGUT IDEOGRAPH-#18383, TGT_MergedSrc=L2008-5134
18384 TANGUT IDEOGRAPH-#18384, TGT_MergedSrc=L2008-5693
18385 TANGUT IDEOGRAPH-#18385, TGT_MergedSrc=H2004-A-5796
18386 TANGUT IDEOGRAPH-#18386, TGT_MergedSrc=L2008-4889
18387 TANGUT IDEOGRAPH-#18387, TGT_MergedSrc=L2008-4928
18388 TANGUT IDEOGRAPH-#18388, TGT_MergedSrc=L2008-4929
18389 TANGUT IDEOGRAPH-#18389, TGT_MergedSrc=L2008-5009
1838A TANGUT IDEOGRAPH-#1838A, TGT_MergedSrc=L2008-4912
1838B TANGUT IDEOGRAPH-#1838B, TGT_MergedSrc=L2008-4876
1838C TANGUT IDEOGRAPH-#1838C, TGT_MergedSrc=L2008-5023
1838D TANGUT IDEOGRAPH-#1838D, TGT_MergedSrc=L2008-4890
1838E TANGUT IDEOGRAPH-#1838E, TGT_MergedSrc=L2008-4734
1838F TANGUT IDEOGRAPH-#1838F, TGT_MergedSrc=L2008-4714
18390 TANGUT IDEOGRAPH-#18390, TGT_MergedSrc=L2008-4827
18391 TANGUT IDEOGRAPH-#18391, TGT_MergedSrc=L2008-4983
18392 TANGUT IDEOGRAPH-#18392, TGT_MergedSrc=L2008-4802
18393 TANGUT IDEOGRAPH-#18393, TGT_MergedSrc=L2008-5224
18394 TANGUT IDEOGRAPH-#18394, TGT_MergedSrc=L2008-5385
18395 TANGUT IDEOGRAPH-#18395, TGT_MergedSrc=L2008-5338
18396 TANGUT IDEOGRAPH-#18396, TGT_MergedSrc=L2008-5337
18397 TANGUT IDEOGRAPH-#18397, TGT_MergedSrc=L2008-5667
18398 TANGUT IDEOGRAPH-#18398, TGT_MergedSrc=L2008-5242
18399 TANGUT IDEOGRAPH-#18399, TGT_MergedSrc=L2008-5454
1839A TANGUT IDEOGRAPH-#1839A, TGT_MergedSrc=L2008-5602
1839B TANGUT IDEOGRAPH-#1839B, TGT_MergedSrc=L2008-5340
1839C TANGUT IDEOGRAPH-#1839C, TGT_MergedSrc=L2008-5204
1839D TANGUT IDEOGRAPH-#1839D, TGT_MergedSrc=L2008-5767
1839E TANGUT IDEOGRAPH-#1839E, TGT_MergedSrc=L2008-5731
1839F TANGUT IDEOGRAPH-#1839F, TGT_MergedSrc=L2008-5766
183A0 TANGUT IDEOGRAPH-#183A0, TGT_MergedSrc=L2008-5603
183A1 TANGUT IDEOGRAPH-#183A1, TGT_MergedSrc=L2008-5668
183A2 TANGUT IDEOGRAPH-#183A2, TGT_MergedSrc=L2008-5299
183A3 TANGUT IDEOGRAPH-#183A3, TGT_MergedSrc=L2008-5611
183A4 TANGUT IDEOGRAPH-#183A4, TGT_MergedSrc=L2008-5300
183A5 TANGUT IDEOGRAPH-#183A5, TGT_MergedSrc=L2008-5633
183A6 TANGUT IDEOGRAPH-#183A6, TGT_MergedSrc=L2008-5434
183A7 TANGUT IDEOGRAPH-#183A7, TGT_MergedSrc=L2008-5156
183A8 TANGUT IDEOGRAPH-#183A8, TGT_MergedSrc=L2008-5591
183A9 TANGUT IDEOGRAPH-#183A9, TGT_MergedSrc=L2008-5380
183AA TANGUT IDEOGRAPH-#183AA, TGT_MergedSrc=L2008-5612
183AB TANGUT IDEOGRAPH-#183AB, TGT_MergedSrc=L2008-5157
183AC TANGUT IDEOGRAPH-#183AC, TGT_MergedSrc=L2008-5241
183AD TANGUT IDEOGRAPH-#183AD, TGT_MergedSrc=L2008-5169
183AE TANGUT IDEOGRAPH-#183AE, TGT_MergedSrc=L2008-5212
183AF TANGUT IDEOGRAPH-#183AF, TGT_MergedSrc=L2008-5236
183B0 TANGUT IDEOGRAPH-#183B0, TGT_MergedSrc=L2008-5220
183B1 TANGUT IDEOGRAPH-#183B1, TGT_MergedSrc=L2008-5237
183B2 TANGUT IDEOGRAPH-#183B2, TGT_MergedSrc=L2008-5621
183B3 TANGUT IDEOGRAPH-#183B3, TGT_MergedSrc=L2008-5435
183B4 TANGUT IDEOGRAPH-#183B4, TGT_MergedSrc=L2008-5313
183B5 TANGUT IDEOGRAPH-#183B5, TGT_MergedSrc=L2008-5613
183B6 TANGUT IDEOGRAPH-#183B6, TGT_MergedSrc=L2008-5308
183B7 TANGUT IDEOGRAPH-#183B7, TGT_MergedSrc=L2008-5384
183B8 TANGUT IDEOGRAPH-#183B8, TGT_MergedSrc=L2008-5371
183B9 TANGUT IDEOGRAPH-#183B9, TGT_MergedSrc=L2008-5735
183BA TANGUT IDEOGRAPH-#183BA, TGT_MergedSrc=L2008-5802
183BB TANGUT IDEOGRAPH-#183BB, TGT_MergedSrc=L2008-5581
183BC TANGUT IDEOGRAPH-#183BC, TGT_MergedSrc=L2008-5671
183BD TANGUT IDEOGRAPH-#183BD, TGT_MergedSrc=L2008-5686
183BE TANGUT IDEOGRAPH-#183BE, TGT_MergedSrc=L2008-5644
183BF TANGUT IDEOGRAPH-#183BF, TGT_MergedSrc=L2008-5160
183C0 TANGUT IDEOGRAPH-#183C0, TGT_MergedSrc=L2008-5304
183C1 TANGUT IDEOGRAPH-#183C1, TGT_MergedSrc=L2008-5448
183C2 TANGUT IDEOGRAPH-#183C2, TGT_MergedSrc=L2008-5159
183C3 TANGUT IDEOGRAPH-#183C3, TGT_MergedSrc=L2008-5246
183C4 TANGUT IDEOGRAPH-#183C4, TGT_MergedSrc=L2008-5199
183C5 TANGUT IDEOGRAPH-#183C5, TGT_MergedSrc=S1968-2650
183C6 TANGUT IDEOGRAPH-#183C6, TGT_MergedSrc=L2008-5158
183C7 TANGUT IDEOGRAPH-#183C7, TGT_MergedSrc=L2008-5452
183C8 TANGUT IDEOGRAPH-#183C8, TGT_MergedSrc=L2008-5170
183C9 TANGUT IDEOGRAPH-#183C9, TGT_MergedSrc=L2008-5218
183CA TANGUT IDEOGRAPH-#183CA, TGT_MergedSrc=L2008-5396
183CB TANGUT IDEOGRAPH-#183CB, TGT_MergedSrc=L2008-5171
183CC TANGUT IDEOGRAPH-#183CC, TGT_MergedSrc=L2008-5676
183CD TANGUT IDEOGRAPH-#183CD, TGT_MergedSrc=L2008-5653
183CE TANGUT IDEOGRAPH-#183CE, TGT_MergedSrc=L2008-5333
183CF TANGUT IDEOGRAPH-#183CF, TGT_MergedSrc=L2008-5317
183D0 TANGUT IDEOGRAPH-#183D0, TGT_MergedSrc=L2008-5307
183D1 TANGUT IDEOGRAPH-#183D1, TGT_MergedSrc=L2008-5393
183D2 TANGUT IDEOGRAPH-#183D2, TGT_MergedSrc=L2008-5390
183D3 TANGUT IDEOGRAPH-#183D3, TGT_MergedSrc=L2008-5383
183D4 TANGUT IDEOGRAPH-#183D4, TGT_MergedSrc=L2008-5372
183D5 TANGUT IDEOGRAPH-#183D5, TGT_MergedSrc=L2008-5389
183D6 TANGUT IDEOGRAPH-#183D6, TGT_MergedSrc=L2008-5800
183D7 TANGUT IDEOGRAPH-#183D7, TGT_MergedSrc=L2008-5750
183D8 TANGUT IDEOGRAPH-#183D8, TGT_MergedSrc=L2008-5736
183D9 TANGUT IDEOGRAPH-#183D9, TGT_MergedSrc=L2008-5582
183DA TANGUT IDEOGRAPH-#183DA, TGT_MergedSrc=L2008-5645
183DB TANGUT IDEOGRAPH-#183DB, TGT_MergedSrc=L2008-5472
183DC TANGUT IDEOGRAPH-#183DC, TGT_MergedSrc=L2008-5638
183DD TANGUT IDEOGRAPH-#183DD, TGT_MergedSrc=L2008-5672
183DE TANGUT IDEOGRAPH-#183DE, TGT_MergedSrc=L2008-5685
183DF TANGUT IDEOGRAPH-#183DF, TGT_MergedSrc=L2008-5620
183E0 TANGUT IDEOGRAPH-#183E0, TGT_MergedSrc=L2008-5457
183E1 TANGUT IDEOGRAPH-#183E1, TGT_MergedSrc=L2008-5247
183E2 TANGUT IDEOGRAPH-#183E2, TGT_MergedSrc=L2008-5177
183E3 TANGUT IDEOGRAPH-#183E3, TGT_MergedSrc=L2008-5455
183E4 TANGUT IDEOGRAPH-#183E4, TGT_MergedSrc=L2008-5221
183E5 TANGUT IDEOGRAPH-#183E5, TGT_MergedSrc=L2008-5330
183E6 TANGUT IDEOGRAPH-#183E6, TGT_MergedSrc=L2008-5183
183E7 TANGUT IDEOGRAPH-#183E7, TGT_MergedSrc=L2008-5322
183E8 TANGUT IDEOGRAPH-#183E8, TGT_MergedSrc=L2008-5655
183E9 TANGUT IDEOGRAPH-#183E9, TGT_MergedSrc=L2008-5397
183EA TANGUT IDEOGRAPH-#183EA, TGT_MergedSrc=L2008-5654
183EB TANGUT IDEOGRAPH-#183EB, TGT_MergedSrc=L2008-5474
183EC TANGUT IDEOGRAPH-#183EC, TGT_MergedSrc=L2008-5592
183ED TANGUT IDEOGRAPH-#183ED, TGT_MergedSrc=L2008-5343
183EE TANGUT IDEOGRAPH-#183EE, TGT_MergedSrc=L2008-5321
183EF TANGUT IDEOGRAPH-#183EF, TGT_MergedSrc=L2008-5318
183F0 TANGUT IDEOGRAPH-#183F0, TGT_MergedSrc=L2008-5392
183F1 TANGUT IDEOGRAPH-#183F1, TGT_MergedSrc=L2008-5391
183F2 TANGUT IDEOGRAPH-#183F2, TGT_MergedSrc=L2008-5742
183F3 TANGUT IDEOGRAPH-#183F3, TGT_MergedSrc=L2008-5790
183F4 TANGUT IDEOGRAPH-#183F4, TGT_MergedSrc=L2008-5788
183F5 TANGUT IDEOGRAPH-#183F5, TGT_MergedSrc=L2008-5759
183F6 TANGUT IDEOGRAPH-#183F6, TGT_MergedSrc=L2008-5728
183F7 TANGUT IDEOGRAPH-#183F7, TGT_MergedSrc=L2008-5751
183F8 TANGUT IDEOGRAPH-#183F8, TGT_MergedSrc=L2008-5442
183F9 TANGUT IDEOGRAPH-#183F9, TGT_MergedSrc=L2008-5583
183FA TANGUT IDEOGRAPH-#183FA, TGT_MergedSrc=L2008-5796
183FB TANGUT IDEOGRAPH-#183FB, TGT_MergedSrc=L2008-5489
183FC TANGUT IDEOGRAPH-#183FC, TGT_MergedSrc=L2008-5646
183FD TANGUT IDEOGRAPH-#183FD, TGT_MergedSrc=L2008-5323
183FE TANGUT IDEOGRAPH-#183FE, TGT_MergedSrc=L2008-5478
183FF TANGUT IDEOGRAPH-#183FF, TGT_MergedSrc=L2008-5460
18400 TANGUT IDEOGRAPH-#18400, TGT_MergedSrc=L2008-5233
18401 TANGUT IDEOGRAPH-#18401, TGT_MergedSrc=L2008-5216
18402 TANGUT IDEOGRAPH-#18402, TGT_MergedSrc=L2008-5192
18403 TANGUT IDEOGRAPH-#18403, TGT_MergedSrc=N1966-236-07G
18404 TANGUT IDEOGRAPH-#18404, TGT_MergedSrc=L2008-5226
18405 TANGUT IDEOGRAPH-#18405, TGT_MergedSrc=L2008-5208
18406 TANGUT IDEOGRAPH-#18406, TGT_MergedSrc=L2008-5404
18407 TANGUT IDEOGRAPH-#18407, TGT_MergedSrc=L2008-5373
18408 TANGUT IDEOGRAPH-#18408, TGT_MergedSrc=L2008-5758
18409 TANGUT IDEOGRAPH-#18409, TGT_MergedSrc=L2008-5791
1840A TANGUT IDEOGRAPH-#1840A, TGT_MergedSrc=L2008-5760
1840B TANGUT IDEOGRAPH-#1840B, TGT_MergedSrc=L2008-5724
1840C TANGUT IDEOGRAPH-#1840C, TGT_MergedSrc=L2008-5763
1840D TANGUT IDEOGRAPH-#1840D, TGT_MergedSrc=L2008-5601
1840E TANGUT IDEOGRAPH-#1840E, TGT_MergedSrc=L2008-5456
1840F TANGUT IDEOGRAPH-#1840F, TGT_MergedSrc=L2008-5449
18410 TANGUT IDEOGRAPH-#18410, TGT_MergedSrc=L2008-5628
18411 TANGUT IDEOGRAPH-#18411, TGT_MergedSrc=L2008-5445
18412 TANGUT IDEOGRAPH-#18412, TGT_MergedSrc=L2008-5683
18413 TANGUT IDEOGRAPH-#18413, TGT_MergedSrc=L2008-5443
18414 TANGUT IDEOGRAPH-#18414, TGT_MergedSrc=L2008-5771
18415 TANGUT IDEOGRAPH-#18415, TGT_MergedSrc=L2008-5184
18416 TANGUT IDEOGRAPH-#18416, TGT_MergedSrc=L2008-5765
18417 TANGUT IDEOGRAPH-#18417, TGT_MergedSrc=L2008-5486
18418 TANGUT IDEOGRAPH-#18418, TGT_MergedSrc=L2008-5217
18419 TANGUT IDEOGRAPH-#18419, TGT_MergedSrc=L2008-5334
1841A TANGUT IDEOGRAPH-#1841A, TGT_MergedSrc=L2008-5178
1841B TANGUT IDEOGRAPH-#1841B, TGT_MergedSrc=L2008-5727
1841C TANGUT IDEOGRAPH-#1841C, TGT_MergedSrc=L2008-6063
1841D TANGUT IDEOGRAPH-#1841D, TGT_MergedSrc=L2008-5339
1841E TANGUT IDEOGRAPH-#1841E, TGT_MergedSrc=L2008-5639
1841F TANGUT IDEOGRAPH-#1841F, TGT_MergedSrc=L2008-5450
18420 TANGUT IDEOGRAPH-#18420, TGT_MergedSrc=L2008-5377
18421 TANGUT IDEOGRAPH-#18421, TGT_MergedSrc=L2008-5379
18422 TANGUT IDEOGRAPH-#18422, TGT_MergedSrc=L2008-5608
18423 TANGUT IDEOGRAPH-#18423, TGT_MergedSrc=L2008-5744
18424 TANGUT IDEOGRAPH-#18424, TGT_MergedSrc=L2008-5737
18425 TANGUT IDEOGRAPH-#18425, TGT_MergedSrc=L2008-5764
18426 TANGUT IDEOGRAPH-#18426, TGT_MergedSrc=L2008-5729
18427 TANGUT IDEOGRAPH-#18427, TGT_MergedSrc=L2008-5647
18428 TANGUT IDEOGRAPH-#18428, TGT_MergedSrc=L2008-5584
18429 TANGUT IDEOGRAPH-#18429, TGT_MergedSrc=L2008-5607
1842A TANGUT IDEOGRAPH-#1842A, TGT_MergedSrc=L2008-5245
1842B TANGUT IDEOGRAPH-#1842B, TGT_MergedSrc=L2008-5769
1842C TANGUT IDEOGRAPH-#1842C, TGT_MergedSrc=L2008-5481
1842D TANGUT IDEOGRAPH-#1842D, TGT_MergedSrc=L2008-5487
1842E TANGUT IDEOGRAPH-#1842E, TGT_MergedSrc=L2008-6065
1842F TANGUT IDEOGRAPH-#1842F, TGT_MergedSrc=L2008-5341
18430 TANGUT IDEOGRAPH-#18430, TGT_MergedSrc=L2008-5312
18431 TANGUT IDEOGRAPH-#18431, TGT_MergedSrc=L2008-5335
18432 TANGUT IDEOGRAPH-#18432, TGT_MergedSrc=L2008-5206
18433 TANGUT IDEOGRAPH-#18433, TGT_MergedSrc=L2008-5302
18434 TANGUT IDEOGRAPH-#18434, TGT_MergedSrc=L2008-5585
18435 TANGUT IDEOGRAPH-#18435, TGT_MergedSrc=L2008-5648
18436 TANGUT IDEOGRAPH-#18436, TGT_MergedSrc=L2008-5586
18437 TANGUT IDEOGRAPH-#18437, TGT_MergedSrc=L2008-5682
18438 TANGUT IDEOGRAPH-#18438, TGT_MergedSrc=L2008-5483
18439 TANGUT IDEOGRAPH-#18439, TGT_MergedSrc=L2008-5229
1843A TANGUT IDEOGRAPH-#1843A, TGT_MergedSrc=L2008-5461
1843B TANGUT IDEOGRAPH-#1843B, TGT_MergedSrc=L2008-5476
1843C TANGUT IDEOGRAPH-#1843C, TGT_MergedSrc=L2008-5484
1843D TANGUT IDEOGRAPH-#1843D, TGT_MergedSrc=L2008-5475
1843E TANGUT IDEOGRAPH-#1843E, TGT_MergedSrc=L2008-5482
1843F TANGUT IDEOGRAPH-#1843F, TGT_MergedSrc=L2008-5459
18440 TANGUT IDEOGRAPH-#18440, TGT_MergedSrc=L2008-5378
18441 TANGUT IDEOGRAPH-#18441, TGT_MergedSrc=L2008-5797
18442 TANGUT IDEOGRAPH-#18442, TGT_MergedSrc=L2008-5213
18443 TANGUT IDEOGRAPH-#18443, TGT_MergedSrc=L1986-4840
18444 TANGUT IDEOGRAPH-#18444, TGT_MergedSrc=L2008-5336
18445 TANGUT IDEOGRAPH-#18445, TGT_MergedSrc=L2008-5631
18446 TANGUT IDEOGRAPH-#18446, TGT_MergedSrc=L2008-5649
18447 TANGUT IDEOGRAPH-#18447, TGT_MergedSrc=L2008-5209
18448 TANGUT IDEOGRAPH-#18448, TGT_MergedSrc=L2008-5188
18449 TANGUT IDEOGRAPH-#18449, TGT_MergedSrc=L2008-5172
1844A TANGUT IDEOGRAPH-#1844A, TGT_MergedSrc=L2008-5231
1844B TANGUT IDEOGRAPH-#1844B, TGT_MergedSrc=L2008-6071
1844C TANGUT IDEOGRAPH-#1844C, TGT_MergedSrc=L2008-5726
1844D TANGUT IDEOGRAPH-#1844D, TGT_MergedSrc=L2008-5770
1844E TANGUT IDEOGRAPH-#1844E, TGT_MergedSrc=L2008-6069
1844F TANGUT IDEOGRAPH-#1844F, TGT_MergedSrc=L2008-5772
18450 TANGUT IDEOGRAPH-#18450, TGT_MergedSrc=L2008-5477
18451 TANGUT IDEOGRAPH-#18451, TGT_MergedSrc=L2008-5663
18452 TANGUT IDEOGRAPH-#18452, TGT_MergedSrc=L2008-5662
18453 TANGUT IDEOGRAPH-#18453, TGT_MergedSrc=L2008-5485
18454 TANGUT IDEOGRAPH-#18454, TGT_MergedSrc=L2008-5732
18455 TANGUT IDEOGRAPH-#18455, TGT_MergedSrc=L2008-5473
18456 TANGUT IDEOGRAPH-#18456, TGT_MergedSrc=L2008-5730
18457 TANGUT IDEOGRAPH-#18457, TGT_MergedSrc=L2008-4871
18458 TANGUT IDEOGRAPH-#18458, TGT_MergedSrc=L2008-4860
18459 TANGUT IDEOGRAPH-#18459, TGT_MergedSrc=L2008-1458
1845A TANGUT IDEOGRAPH-#1845A, TGT_MergedSrc=L2008-1016
1845B TANGUT IDEOGRAPH-#1845B, TGT_MergedSrc=L2008-0526
1845C TANGUT IDEOGRAPH-#1845C, TGT_MergedSrc=L2008-0780
1845D TANGUT IDEOGRAPH-#1845D, TGT_MergedSrc=L2008-0246
1845E TANGUT IDEOGRAPH-#1845E, TGT_MergedSrc=L2008-0531
1845F TANGUT IDEOGRAPH-#1845F, TGT_MergedSrc=L2008-0694
18460 TANGUT IDEOGRAPH-#18460, TGT_MergedSrc=L2008-1237
18461 TANGUT IDEOGRAPH-#18461, TGT_MergedSrc=L2008-0387
18462 TANGUT IDEOGRAPH-#18462, TGT_MergedSrc=L2008-0682
18463 TANGUT IDEOGRAPH-#18463, TGT_MergedSrc=L2008-0881
18464 TANGUT IDEOGRAPH-#18464, TGT_MergedSrc=L2008-0370
18465 TANGUT IDEOGRAPH-#18465, TGT_MergedSrc=L2008-0940
18466 TANGUT IDEOGRAPH-#18466, TGT_MergedSrc=L2008-1037
18467 TANGUT IDEOGRAPH-#18467, TGT_MergedSrc=L2008-1132
18468 TANGUT IDEOGRAPH-#18468, TGT_MergedSrc=L2008-0645
18469 TANGUT IDEOGRAPH-#18469, TGT_MergedSrc=L2008-1066
1846A TANGUT IDEOGRAPH-#1846A, TGT_MergedSrc=L2008-0417
1846B TANGUT IDEOGRAPH-#1846B, TGT_MergedSrc=L2008-0404
1846C TANGUT IDEOGRAPH-#1846C, TGT_MergedSrc=L2008-0615
1846D TANGUT IDEOGRAPH-#1846D, TGT_MergedSrc=L2008-0609
1846E TANGUT IDEOGRAPH-#1846E, TGT_MergedSrc=L2008-0725
1846F TANGUT IDEOGRAPH-#1846F, TGT_MergedSrc=L2008-1468
18470 TANGUT IDEOGRAPH-#18470, TGT_MergedSrc=L2008-1806
18471 TANGUT IDEOGRAPH-#18471, TGT_MergedSrc=L2008-0414
18472 TANGUT IDEOGRAPH-#18472, TGT_MergedSrc=L2008-1030
18473 TANGUT IDEOGRAPH-#18473, TGT_MergedSrc=L2008-0247
18474 TANGUT IDEOGRAPH-#18474, TGT_MergedSrc=L2008-1184
18475 TANGUT IDEOGRAPH-#18475, TGT_MergedSrc=L2008-1711
18476 TANGUT IDEOGRAPH-#18476, TGT_MergedSrc=L2008-1724
18477 TANGUT IDEOGRAPH-#18477, TGT_MergedSrc=L2008-0814
18478 TANGUT IDEOGRAPH-#18478, TGT_MergedSrc=L2008-1417
18479 TANGUT IDEOGRAPH-#18479, TGT_MergedSrc=L2008-0315
1847A TANGUT IDEOGRAPH-#1847A, TGT_MergedSrc=L2008-0299
1847B TANGUT IDEOGRAPH-#1847B, TGT_MergedSrc=L2008-1389
1847C TANGUT IDEOGRAPH-#1847C, TGT_MergedSrc=L2008-0794
1847D TANGUT IDEOGRAPH-#1847D, TGT_MergedSrc=L2008-0277
1847E TANGUT IDEOGRAPH-#1847E, TGT_MergedSrc=L2008-0240
1847F TANGUT IDEOGRAPH-#1847F, TGT_MergedSrc=L2008-0242
18480 TANGUT IDEOGRAPH-#18480, TGT_MergedSrc=L2008-0241
18481 TANGUT IDEOGRAPH-#18481, TGT_MergedSrc=L2008-1152
18482 TANGUT IDEOGRAPH-#18482, TGT_MergedSrc=L2008-0683
18483 TANGUT IDEOGRAPH-#18483, TGT_MergedSrc=L2008-1086
18484 TANGUT IDEOGRAPH-#18484, TGT_MergedSrc=L2008-1255
18485 TANGUT IDEOGRAPH-#18485, TGT_MergedSrc=L2008-1025
18486 TANGUT IDEOGRAPH-#18486, TGT_MergedSrc=L2008-1061
18487 TANGUT IDEOGRAPH-#18487, TGT_MergedSrc=L2008-1526
18488 TANGUT IDEOGRAPH-#18488, TGT_MergedSrc=L2008-1510
18489 TANGUT IDEOGRAPH-#18489, TGT_MergedSrc=L2008-1345
1848A TANGUT IDEOGRAPH-#1848A, TGT_MergedSrc=L2008-1094
1848B TANGUT IDEOGRAPH-#1848B, TGT_MergedSrc=L2008-0953
1848C TANGUT IDEOGRAPH-#1848C, TGT_MergedSrc=L2008-1472
1848D TANGUT IDEOGRAPH-#1848D, TGT_MergedSrc=L2008-0934
1848E TANGUT IDEOGRAPH-#1848E, TGT_MergedSrc=L2008-1408
1848F TANGUT IDEOGRAPH-#1848F, TGT_MergedSrc=L2008-1531
18490 TANGUT IDEOGRAPH-#18490, TGT_MergedSrc=L2008-1462
18491 TANGUT IDEOGRAPH-#18491, TGT_MergedSrc=L2008-1366
18492 TANGUT IDEOGRAPH-#18492, TGT_MergedSrc=L2008-1428
18493 TANGUT IDEOGRAPH-#18493, TGT_MergedSrc=L2008-0975
18494 TANGUT IDEOGRAPH-#18494, TGT_MergedSrc=L2008-1167
18495 TANGUT IDEOGRAPH-#18495, TGT_MergedSrc=L2008-1503
18496 TANGUT IDEOGRAPH-#18496, TGT_MergedSrc=L2008-1535
18497 TANGUT IDEOGRAPH-#18497, TGT_MergedSrc=L2008-1095
18498 TANGUT IDEOGRAPH-#18498, TGT_MergedSrc=L2008-1199
18499 TANGUT IDEOGRAPH-#18499, TGT_MergedSrc=L2008-1305
1849A TANGUT IDEOGRAPH-#1849A, TGT_MergedSrc=L2008-1508
1849B TANGUT IDEOGRAPH-#1849B, TGT_MergedSrc=L2008-1512
1849C TANGUT IDEOGRAPH-#1849C, TGT_MergedSrc=L2008-0954
1849D TANGUT IDEOGRAPH-#1849D, TGT_MergedSrc=L2008-0976
1849E TANGUT IDEOGRAPH-#1849E, TGT_MergedSrc=L2008-0904
1849F TANGUT IDEOGRAPH-#1849F, TGT_MergedSrc=L2008-1186
184A0 TANGUT IDEOGRAPH-#184A0, TGT_MergedSrc=L2006-1186
184A1 TANGUT IDEOGRAPH-#184A1, TGT_MergedSrc=L2008-0096
184A2 TANGUT IDEOGRAPH-#184A2, TGT_MergedSrc=L2008-1130
184A3 TANGUT IDEOGRAPH-#184A3, TGT_MergedSrc=L2008-1045
184A4 TANGUT IDEOGRAPH-#184A4, TGT_MergedSrc=L2008-0646
184A5 TANGUT IDEOGRAPH-#184A5, TGT_MergedSrc=L2008-0483
184A6 TANGUT IDEOGRAPH-#184A6, TGT_MergedSrc=L2008-1054
184A7 TANGUT IDEOGRAPH-#184A7, TGT_MergedSrc=L2008-0196
184A8 TANGUT IDEOGRAPH-#184A8, TGT_MergedSrc=L2008-0771
184A9 TANGUT IDEOGRAPH-#184A9, TGT_MergedSrc=L2008-0524
184AA TANGUT IDEOGRAPH-#184AA, TGT_MergedSrc=L2008-1117
184AB TANGUT IDEOGRAPH-#184AB, TGT_MergedSrc=L2008-5871
184AC TANGUT IDEOGRAPH-#184AC, TGT_MergedSrc=L2008-5976
184AD TANGUT IDEOGRAPH-#184AD, TGT_MergedSrc=L2008-5833
184AE TANGUT IDEOGRAPH-#184AE, TGT_MergedSrc=L2008-5869
184AF TANGUT IDEOGRAPH-#184AF, TGT_MergedSrc=L2008-5892
184B0 TANGUT IDEOGRAPH-#184B0, TGT_MergedSrc=L2008-5977
184B1 TANGUT IDEOGRAPH-#184B1, TGT_MergedSrc=L2008-5991
184B2 TANGUT IDEOGRAPH-#184B2, TGT_MergedSrc=L2008-5978
184B3 TANGUT IDEOGRAPH-#184B3, TGT_MergedSrc=L2008-5939
184B4 TANGUT IDEOGRAPH-#184B4, TGT_MergedSrc=L2008-5936
184B5 TANGUT IDEOGRAPH-#184B5, TGT_MergedSrc=L2008-5940
184B6 TANGUT IDEOGRAPH-#184B6, TGT_MergedSrc=L2008-0418
184B7 TANGUT IDEOGRAPH-#184B7, TGT_MergedSrc=L2008-0719
184B8 TANGUT IDEOGRAPH-#184B8, TGT_MergedSrc=L2008-1798
184B9 TANGUT IDEOGRAPH-#184B9, TGT_MergedSrc=L2008-1763
184BA TANGUT IDEOGRAPH-#184BA, TGT_MergedSrc=L2008-0187
184BB TANGUT IDEOGRAPH-#184BB, TGT_MergedSrc=L2008-0769
184BC TANGUT IDEOGRAPH-#184BC, TGT_MergedSrc=L2008-0647
184BD TANGUT IDEOGRAPH-#184BD, TGT_MergedSrc=L2008-1607
184BE TANGUT IDEOGRAPH-#184BE, TGT_MergedSrc=L2008-0188
184BF TANGUT IDEOGRAPH-#184BF, TGT_MergedSrc=L2008-4433
184C0 TANGUT IDEOGRAPH-#184C0, TGT_MergedSrc=L2008-4436
184C1 TANGUT IDEOGRAPH-#184C1, TGT_MergedSrc=L2008-4444
184C2 TANGUT IDEOGRAPH-#184C2, TGT_MergedSrc=L2008-4435
184C3 TANGUT IDEOGRAPH-#184C3, TGT_MergedSrc=L2008-4438
184C4 TANGUT IDEOGRAPH-#184C4, TGT_MergedSrc=L2008-4437
184C5 TANGUT IDEOGRAPH-#184C5, TGT_MergedSrc=L2008-4463
184C6 TANGUT IDEOGRAPH-#184C6, TGT_MergedSrc=L2008-4464
184C7 TANGUT IDEOGRAPH-#184C7, TGT_MergedSrc=L2008-4465
184C8 TANGUT IDEOGRAPH-#184C8, TGT_MergedSrc=L2008-4434
184C9 TANGUT IDEOGRAPH-#184C9, TGT_MergedSrc=L2008-0993
184CA TANGUT IDEOGRAPH-#184CA, TGT_MergedSrc=L2008-0502
184CB TANGUT IDEOGRAPH-#184CB, TGT_MergedSrc=L2008-1017
184CC TANGUT IDEOGRAPH-#184CC, TGT_MergedSrc=L2008-0507
184CD TANGUT IDEOGRAPH-#184CD, TGT_MergedSrc=L2008-2530
184CE TANGUT IDEOGRAPH-#184CE, TGT_MergedSrc=L2008-2333
184CF TANGUT IDEOGRAPH-#184CF, TGT_MergedSrc=L2008-2324
184D0 TANGUT IDEOGRAPH-#184D0, TGT_MergedSrc=L2008-2541
184D1 TANGUT IDEOGRAPH-#184D1, TGT_MergedSrc=L2008-2896
184D2 TANGUT IDEOGRAPH-#184D2, TGT_MergedSrc=L2008-2321
184D3 TANGUT IDEOGRAPH-#184D3, TGT_MergedSrc=L2008-2323
184D4 TANGUT IDEOGRAPH-#184D4, TGT_MergedSrc=L2008-2325
184D5 TANGUT IDEOGRAPH-#184D5, TGT_MergedSrc=L2008-3737
184D6 TANGUT IDEOGRAPH-#184D6, TGT_MergedSrc=L2008-3738
184D7 TANGUT IDEOGRAPH-#184D7, TGT_MergedSrc=L2008-3420
184D8 TANGUT IDEOGRAPH-#184D8, TGT_MergedSrc=L2008-2900
184D9 TANGUT IDEOGRAPH-#184D9, TGT_MergedSrc=L2008-2543
184DA TANGUT IDEOGRAPH-#184DA, TGT_MergedSrc=L2008-2542
184DB TANGUT IDEOGRAPH-#184DB, TGT_MergedSrc=L2008-3411
184DC TANGUT IDEOGRAPH-#184DC, TGT_MergedSrc=L2008-2696
184DD TANGUT IDEOGRAPH-#184DD, TGT_MergedSrc=L2008-2697
184DE TANGUT IDEOGRAPH-#184DE, TGT_MergedSrc=L2008-3735
184DF TANGUT IDEOGRAPH-#184DF, TGT_MergedSrc=L2008-3744
184E0 TANGUT IDEOGRAPH-#184E0, TGT_MergedSrc=L2008-2322
184E1 TANGUT IDEOGRAPH-#184E1, TGT_MergedSrc=L2008-2812
184E2 TANGUT IDEOGRAPH-#184E2, TGT_MergedSrc=L2008-2407
184E3 TANGUT IDEOGRAPH-#184E3, TGT_MergedSrc=L2008-2736
184E4 TANGUT IDEOGRAPH-#184E4, TGT_MergedSrc=L2008-2021
184E5 TANGUT IDEOGRAPH-#184E5, TGT_MergedSrc=L2008-2847
184E6 TANGUT IDEOGRAPH-#184E6, TGT_MergedSrc=L2008-0556
184E7 TANGUT IDEOGRAPH-#184E7, TGT_MergedSrc=L2008-1334
184E8 TANGUT IDEOGRAPH-#184E8, TGT_MergedSrc=L2008-1275
184E9 TANGUT IDEOGRAPH-#184E9, TGT_MergedSrc=L2008-0310
184EA TANGUT IDEOGRAPH-#184EA, TGT_MergedSrc=L2008-4062
184EB TANGUT IDEOGRAPH-#184EB, TGT_MergedSrc=L2008-1309
184EC TANGUT IDEOGRAPH-#184EC, TGT_MergedSrc=L2008-0036
184ED TANGUT IDEOGRAPH-#184ED, TGT_MergedSrc=L2008-0489
184EE TANGUT IDEOGRAPH-#184EE, TGT_MergedSrc=L2008-1624
184EF TANGUT IDEOGRAPH-#184EF, TGT_MergedSrc=L2008-1105
184F0 TANGUT IDEOGRAPH-#184F0, TGT_MergedSrc=L2008-0230
184F1 TANGUT IDEOGRAPH-#184F1, TGT_MergedSrc=L2008-1106-1107
184F2 TANGUT IDEOGRAPH-#184F2, TGT_MergedSrc=L2008-0654
184F3 TANGUT IDEOGRAPH-#184F3, TGT_MergedSrc=L2008-1602
184F4 TANGUT IDEOGRAPH-#184F4, TGT_MergedSrc=L1986-5541
184F5 TANGUT IDEOGRAPH-#184F5, TGT_MergedSrc=L2008-1108
184F6 TANGUT IDEOGRAPH-#184F6, TGT_MergedSrc=L2008-1042
184F7 TANGUT IDEOGRAPH-#184F7, TGT_MergedSrc=L2008-0860
184F8 TANGUT IDEOGRAPH-#184F8, TGT_MergedSrc=L2008-0231
184F9 TANGUT IDEOGRAPH-#184F9, TGT_MergedSrc=L2008-1623
184FA TANGUT IDEOGRAPH-#184FA, TGT_MergedSrc=L2008-0510
184FB TANGUT IDEOGRAPH-#184FB, TGT_MergedSrc=L2008-4629
184FC TANGUT IDEOGRAPH-#184FC, TGT_MergedSrc=L2008-4555
184FD TANGUT IDEOGRAPH-#184FD, TGT_MergedSrc=L2008-4556
184FE TANGUT IDEOGRAPH-#184FE, TGT_MergedSrc=L2008-4660
184FF TANGUT IDEOGRAPH-#184FF, TGT_MergedSrc=L2008-4659
18500 TANGUT IDEOGRAPH-#18500, TGT_MergedSrc=L2008-4631
18501 TANGUT IDEOGRAPH-#18501, TGT_MergedSrc=L2008-4661
18502 TANGUT IDEOGRAPH-#18502, TGT_MergedSrc=L2008-4662
18503 TANGUT IDEOGRAPH-#18503, TGT_MergedSrc=L2008-4670
18504 TANGUT IDEOGRAPH-#18504, TGT_MergedSrc=L2008-4627
18505 TANGUT IDEOGRAPH-#18505, TGT_MergedSrc=L2008-4557
18506 TANGUT IDEOGRAPH-#18506, TGT_MergedSrc=N1966-256-113
18507 TANGUT IDEOGRAPH-#18507, TGT_MergedSrc=L2008-4663
18508 TANGUT IDEOGRAPH-#18508, TGT_MergedSrc=L2008-4632
18509 TANGUT IDEOGRAPH-#18509, TGT_MergedSrc=L2008-4628
1850A TANGUT IDEOGRAPH-#1850A, TGT_MergedSrc=L2008-1266
1850B TANGUT IDEOGRAPH-#1850B, TGT_MergedSrc=L2008-1739
1850C TANGUT IDEOGRAPH-#1850C, TGT_MergedSrc=L2008-0895
1850D TANGUT IDEOGRAPH-#1850D, TGT_MergedSrc=L2008-1698
1850E TANGUT IDEOGRAPH-#1850E, TGT_MergedSrc=L2008-0381
1850F TANGUT IDEOGRAPH-#1850F, TGT_MergedSrc=L2008-0250
18510 TANGUT IDEOGRAPH-#18510, TGT_MergedSrc=L2008-0260
18511 TANGUT IDEOGRAPH-#18511, TGT_MergedSrc=L2008-0529
18512 TANGUT IDEOGRAPH-#18512, TGT_MergedSrc=L2008-0547
18513 TANGUT IDEOGRAPH-#18513, TGT_MergedSrc=L2008-0696
18514 TANGUT IDEOGRAPH-#18514, TGT_MergedSrc=L2008-0363
18515 TANGUT IDEOGRAPH-#18515, TGT_MergedSrc=L2008-0593
18516 TANGUT IDEOGRAPH-#18516, TGT_MergedSrc=L2008-1678
18517 TANGUT IDEOGRAPH-#18517, TGT_MergedSrc=L2008-1235
18518 TANGUT IDEOGRAPH-#18518, TGT_MergedSrc=L2008-1402
18519 TANGUT IDEOGRAPH-#18519, TGT_MergedSrc=L2008-0548
1851A TANGUT IDEOGRAPH-#1851A, TGT_MergedSrc=L2008-1671
1851B TANGUT IDEOGRAPH-#1851B, TGT_MergedSrc=L2008-1236
1851C TANGUT IDEOGRAPH-#1851C, TGT_MergedSrc=L2008-0298
1851D TANGUT IDEOGRAPH-#1851D, TGT_MergedSrc=L2008-1858
1851E TANGUT IDEOGRAPH-#1851E, TGT_MergedSrc=L2008-1741
1851F TANGUT IDEOGRAPH-#1851F, TGT_MergedSrc=L2008-0820
18520 TANGUT IDEOGRAPH-#18520, TGT_MergedSrc=L2008-1774
18521 TANGUT IDEOGRAPH-#18521, TGT_MergedSrc=L2008-1723
18522 TANGUT IDEOGRAPH-#18522, TGT_MergedSrc=L2008-1639
18523 TANGUT IDEOGRAPH-#18523, TGT_MergedSrc=L2008-0915
18524 TANGUT IDEOGRAPH-#18524, TGT_MergedSrc=L2008-0577
18525 TANGUT IDEOGRAPH-#18525, TGT_MergedSrc=L2008-0351
18526 TANGUT IDEOGRAPH-#18526, TGT_MergedSrc=L2008-0197
18527 TANGUT IDEOGRAPH-#18527, TGT_MergedSrc=L2008-0150
18528 TANGUT IDEOGRAPH-#18528, TGT_MergedSrc=L2008-0638
18529 TANGUT IDEOGRAPH-#18529, TGT_MergedSrc=L2008-0982
1852A TANGUT IDEOGRAPH-#1852A, TGT_MergedSrc=L2008-0522
1852B TANGUT IDEOGRAPH-#1852B, TGT_MergedSrc=L2008-0214
1852C TANGUT IDEOGRAPH-#1852C, TGT_MergedSrc=L2008-1050
1852D TANGUT IDEOGRAPH-#1852D, TGT_MergedSrc=L2008-1604
1852E TANGUT IDEOGRAPH-#1852E, TGT_MergedSrc=L2008-0981
1852F TANGUT IDEOGRAPH-#1852F, TGT_MergedSrc=L2008-4040
18530 TANGUT IDEOGRAPH-#18530, TGT_MergedSrc=L2008-3187
18531 TANGUT IDEOGRAPH-#18531, TGT_MergedSrc=L2008-3802
18532 TANGUT IDEOGRAPH-#18532, TGT_MergedSrc=L2008-2192
18533 TANGUT IDEOGRAPH-#18533, TGT_MergedSrc=L2008-3299
18534 TANGUT IDEOGRAPH-#18534, TGT_MergedSrc=L2008-3300
18535 TANGUT IDEOGRAPH-#18535, TGT_MergedSrc=L2008-3602
18536 TANGUT IDEOGRAPH-#18536, TGT_MergedSrc=L2008-2141
18537 TANGUT IDEOGRAPH-#18537, TGT_MergedSrc=L2008-2243
18538 TANGUT IDEOGRAPH-#18538, TGT_MergedSrc=L2008-2116
18539 TANGUT IDEOGRAPH-#18539, TGT_MergedSrc=L2008-2276
1853A TANGUT IDEOGRAPH-#1853A, TGT_MergedSrc=L2008-2782
1853B TANGUT IDEOGRAPH-#1853B, TGT_MergedSrc=L2008-2877
1853C TANGUT IDEOGRAPH-#1853C, TGT_MergedSrc=L2008-2484
1853D TANGUT IDEOGRAPH-#1853D, TGT_MergedSrc=L2008-3125
1853E TANGUT IDEOGRAPH-#1853E, TGT_MergedSrc=L2008-2421
1853F TANGUT IDEOGRAPH-#1853F, TGT_MergedSrc=L2008-3009
18540 TANGUT IDEOGRAPH-#18540, TGT_MergedSrc=L2008-3809
18541 TANGUT IDEOGRAPH-#18541, TGT_MergedSrc=L2008-3993
18542 TANGUT IDEOGRAPH-#18542, TGT_MergedSrc=L2008-3852
18543 TANGUT IDEOGRAPH-#18543, TGT_MergedSrc=L2008-3858
18544 TANGUT IDEOGRAPH-#18544, TGT_MergedSrc=L2008-3952
18545 TANGUT IDEOGRAPH-#18545, TGT_MergedSrc=L2008-4014
18546 TANGUT IDEOGRAPH-#18546, TGT_MergedSrc=L2008-3992
18547 TANGUT IDEOGRAPH-#18547, TGT_MergedSrc=L2008-3953
18548 TANGUT IDEOGRAPH-#18548, TGT_MergedSrc=L2008-3947
18549 TANGUT IDEOGRAPH-#18549, TGT_MergedSrc=L2008-3966
1854A TANGUT IDEOGRAPH-#1854A, TGT_MergedSrc=L2008-3968
1854B TANGUT IDEOGRAPH-#1854B, TGT_MergedSrc=L2008-5148
1854C TANGUT IDEOGRAPH-#1854C, TGT_MergedSrc=L2008-5127
1854D TANGUT IDEOGRAPH-#1854D, TGT_MergedSrc=L2008-6067
1854E TANGUT IDEOGRAPH-#1854E, TGT_MergedSrc=L2008-5554
1854F TANGUT IDEOGRAPH-#1854F, TGT_MergedSrc=L2008-5117
18550 TANGUT IDEOGRAPH-#18550, TGT_MergedSrc=L2008-5889
18551 TANGUT IDEOGRAPH-#18551, TGT_MergedSrc=L2008-5820
18552 TANGUT IDEOGRAPH-#18552, TGT_MergedSrc=L2008-5890
18553 TANGUT IDEOGRAPH-#18553, TGT_MergedSrc=L2008-5931
18554 TANGUT IDEOGRAPH-#18554, TGT_MergedSrc=L2008-5923
18555 TANGUT IDEOGRAPH-#18555, TGT_MergedSrc=L2008-5865
18556 TANGUT IDEOGRAPH-#18556, TGT_MergedSrc=L2008-5974
18557 TANGUT IDEOGRAPH-#18557, TGT_MergedSrc=L2008-5930
18558 TANGUT IDEOGRAPH-#18558, TGT_MergedSrc=L2008-5925
18559 TANGUT IDEOGRAPH-#18559, TGT_MergedSrc=L2008-5920
1855A TANGUT IDEOGRAPH-#1855A, TGT_MergedSrc=L2008-5887
1855B TANGUT IDEOGRAPH-#1855B, TGT_MergedSrc=L2008-5143
1855C TANGUT IDEOGRAPH-#1855C, TGT_MergedSrc=L2008-5091
1855D TANGUT IDEOGRAPH-#1855D, TGT_MergedSrc=L2008-5696
1855E TANGUT IDEOGRAPH-#1855E, TGT_MergedSrc=L2008-5367
1855F TANGUT IDEOGRAPH-#1855F, TGT_MergedSrc=L2008-5785
18560 TANGUT IDEOGRAPH-#18560, TGT_MergedSrc=L2008-5697
18561 TANGUT IDEOGRAPH-#18561, TGT_MergedSrc=L2008-5564
18562 TANGUT IDEOGRAPH-#18562, TGT_MergedSrc=L2008-5541
18563 TANGUT IDEOGRAPH-#18563, TGT_MergedSrc=L2008-5688
18564 TANGUT IDEOGRAPH-#18564, TGT_MergedSrc=L2008-5346
18565 TANGUT IDEOGRAPH-#18565, TGT_MergedSrc=L2008-5773
18566 TANGUT IDEOGRAPH-#18566, TGT_MergedSrc=N1966-147-062
18567 TANGUT IDEOGRAPH-#18567, TGT_MergedSrc=L2008-5250
18568 TANGUT IDEOGRAPH-#18568, TGT_MergedSrc=L2008-5348
18569 TANGUT IDEOGRAPH-#18569, TGT_MergedSrc=L2008-5777
1856A TANGUT IDEOGRAPH-#1856A, TGT_MergedSrc=L2008-5253
1856B TANGUT IDEOGRAPH-#1856B, TGT_MergedSrc=L2008-5543
1856C TANGUT IDEOGRAPH-#1856C, TGT_MergedSrc=L2008-5282
1856D TANGUT IDEOGRAPH-#1856D, TGT_MergedSrc=L2008-5567
1856E TANGUT IDEOGRAPH-#1856E, TGT_MergedSrc=L2008-5280
1856F TANGUT IDEOGRAPH-#1856F, TGT_MergedSrc=L2008-5281
18570 TANGUT IDEOGRAPH-#18570, TGT_MergedSrc=L2008-5814
18571 TANGUT IDEOGRAPH-#18571, TGT_MergedSrc=L2008-5843
18572 TANGUT IDEOGRAPH-#18572, TGT_MergedSrc=L2008-5876
18573 TANGUT IDEOGRAPH-#18573, TGT_MergedSrc=L2008-5873
18574 TANGUT IDEOGRAPH-#18574, TGT_MergedSrc=L2008-5894
18575 TANGUT IDEOGRAPH-#18575, TGT_MergedSrc=L2008-5897
18576 TANGUT IDEOGRAPH-#18576, TGT_MergedSrc=L2008-5898
18577 TANGUT IDEOGRAPH-#18577, TGT_MergedSrc=L2008-5954
18578 TANGUT IDEOGRAPH-#18578, TGT_MergedSrc=L2008-5423
18579 TANGUT IDEOGRAPH-#18579, TGT_MergedSrc=L2008-5093
1857A TANGUT IDEOGRAPH-#1857A, TGT_MergedSrc=L2008-5503
1857B TANGUT IDEOGRAPH-#1857B, TGT_MergedSrc=L2008-5565
1857C TANGUT IDEOGRAPH-#1857C, TGT_MergedSrc=L2008-5469
1857D TANGUT IDEOGRAPH-#1857D, TGT_MergedSrc=L2008-5427
1857E TANGUT IDEOGRAPH-#1857E, TGT_MergedSrc=L2008-5851
1857F TANGUT IDEOGRAPH-#1857F, TGT_MergedSrc=L2008-5856
18580 TANGUT IDEOGRAPH-#18580, TGT_MergedSrc=L2008-5879
18581 TANGUT IDEOGRAPH-#18581, TGT_MergedSrc=L2008-5969
18582 TANGUT IDEOGRAPH-#18582, TGT_MergedSrc=L2008-5194
18583 TANGUT IDEOGRAPH-#18583, TGT_MergedSrc=L2008-5139
18584 TANGUT IDEOGRAPH-#18584, TGT_MergedSrc=L2008-5161
18585 TANGUT IDEOGRAPH-#18585, TGT_MergedSrc=L2008-5287
18586 TANGUT IDEOGRAPH-#18586, TGT_MergedSrc=L2008-4946
18587 TANGUT IDEOGRAPH-#18587, TGT_MergedSrc=L2008-4873
18588 TANGUT IDEOGRAPH-#18588, TGT_MergedSrc=L2008-4779
18589 TANGUT IDEOGRAPH-#18589, TGT_MergedSrc=L2008-5402
1858A TANGUT IDEOGRAPH-#1858A, TGT_MergedSrc=L2008-5382
1858B TANGUT IDEOGRAPH-#1858B, TGT_MergedSrc=L2008-5752
1858C TANGUT IDEOGRAPH-#1858C, TGT_MergedSrc=L2008-5619
1858D TANGUT IDEOGRAPH-#1858D, TGT_MergedSrc=L2008-5618
1858E TANGUT IDEOGRAPH-#1858E, TGT_MergedSrc=L2008-5395
1858F TANGUT IDEOGRAPH-#1858F, TGT_MergedSrc=L2008-5374
18590 TANGUT IDEOGRAPH-#18590, TGT_MergedSrc=L2008-5193
18591 TANGUT IDEOGRAPH-#18591, TGT_MergedSrc=L2008-5643
18592 TANGUT IDEOGRAPH-#18592, TGT_MergedSrc=L2008-5733
18593 TANGUT IDEOGRAPH-#18593, TGT_MergedSrc=L2008-5745
18594 TANGUT IDEOGRAPH-#18594, TGT_MergedSrc=L2008-5230
18595 TANGUT IDEOGRAPH-#18595, TGT_MergedSrc=L2008-5376
18596 TANGUT IDEOGRAPH-#18596, TGT_MergedSrc=L2008-5162
18597 TANGUT IDEOGRAPH-#18597, TGT_MergedSrc=L2008-5173
18598 TANGUT IDEOGRAPH-#18598, TGT_MergedSrc=L2008-5232
18599 TANGUT IDEOGRAPH-#18599, TGT_MergedSrc=L2008-5249
1859A TANGUT IDEOGRAPH-#1859A, TGT_MergedSrc=L2008-5408
1859B TANGUT IDEOGRAPH-#1859B, TGT_MergedSrc=L2008-5345
1859C TANGUT IDEOGRAPH-#1859C, TGT_MergedSrc=L2008-5015
1859D TANGUT IDEOGRAPH-#1859D, TGT_MergedSrc=L2008-4715
1859E TANGUT IDEOGRAPH-#1859E, TGT_MergedSrc=L2008-4679
1859F TANGUT IDEOGRAPH-#1859F, TGT_MergedSrc=L2008-4764
185A0 TANGUT IDEOGRAPH-#185A0, TGT_MergedSrc=L2008-4780
185A1 TANGUT IDEOGRAPH-#185A1, TGT_MergedSrc=S1968-2589
185A2 TANGUT IDEOGRAPH-#185A2, TGT_MergedSrc=L2008-4930
185A3 TANGUT IDEOGRAPH-#185A3, TGT_MergedSrc=L2008-4738
185A4 TANGUT IDEOGRAPH-#185A4, TGT_MergedSrc=L2008-4755
185A5 TANGUT IDEOGRAPH-#185A5, TGT_MergedSrc=L2008-4877
185A6 TANGUT IDEOGRAPH-#185A6, TGT_MergedSrc=L2008-4891
185A7 TANGUT IDEOGRAPH-#185A7, TGT_MergedSrc=L2008-4935
185A8 TANGUT IDEOGRAPH-#185A8, TGT_MergedSrc=L2008-4897
185A9 TANGUT IDEOGRAPH-#185A9, TGT_MergedSrc=L2008-4787
185AA TANGUT IDEOGRAPH-#185AA, TGT_MergedSrc=L2008-4813
185AB TANGUT IDEOGRAPH-#185AB, TGT_MergedSrc=L2008-4908
185AC TANGUT IDEOGRAPH-#185AC, TGT_MergedSrc=L2008-5046
185AD TANGUT IDEOGRAPH-#185AD, TGT_MergedSrc=L2008-4680
185AE TANGUT IDEOGRAPH-#185AE, TGT_MergedSrc=L2008-4846
185AF TANGUT IDEOGRAPH-#185AF, TGT_MergedSrc=L2008-4814
185B0 TANGUT IDEOGRAPH-#185B0, TGT_MergedSrc=L2008-5041
185B1 TANGUT IDEOGRAPH-#185B1, TGT_MergedSrc=L2008-4717
185B2 TANGUT IDEOGRAPH-#185B2, TGT_MergedSrc=S1968-2556
185B3 TANGUT IDEOGRAPH-#185B3, TGT_MergedSrc=L2008-5000
185B4 TANGUT IDEOGRAPH-#185B4, TGT_MergedSrc=L2008-4705
185B5 TANGUT IDEOGRAPH-#185B5, TGT_MergedSrc=L2008-5019
185B6 TANGUT IDEOGRAPH-#185B6, TGT_MergedSrc=L2008-4879
185B7 TANGUT IDEOGRAPH-#185B7, TGT_MergedSrc=L2008-4688
185B8 TANGUT IDEOGRAPH-#185B8, TGT_MergedSrc=L2008-4996
185B9 TANGUT IDEOGRAPH-#185B9, TGT_MergedSrc=L2008-4817
185BA TANGUT IDEOGRAPH-#185BA, TGT_MergedSrc=L2008-4909
185BB TANGUT IDEOGRAPH-#185BB, TGT_MergedSrc=L2008-5013
185BC TANGUT IDEOGRAPH-#185BC, TGT_MergedSrc=L2008-4815
185BD TANGUT IDEOGRAPH-#185BD, TGT_MergedSrc=L2008-4816
185BE TANGUT IDEOGRAPH-#185BE, TGT_MergedSrc=L2008-4745
185BF TANGUT IDEOGRAPH-#185BF, TGT_MergedSrc=L2008-5033
185C0 TANGUT IDEOGRAPH-#185C0, TGT_MergedSrc=L2008-5047
185C1 TANGUT IDEOGRAPH-#185C1, TGT_MergedSrc=L2008-4735
185C2 TANGUT IDEOGRAPH-#185C2, TGT_MergedSrc=L2008-5010
185C3 TANGUT IDEOGRAPH-#185C3, TGT_MergedSrc=L2008-4966
185C4 TANGUT IDEOGRAPH-#185C4, TGT_MergedSrc=L2008-4919
185C5 TANGUT IDEOGRAPH-#185C5, TGT_MergedSrc=L2008-4781
185C6 TANGUT IDEOGRAPH-#185C6, TGT_MergedSrc=L2008-4917
185C7 TANGUT IDEOGRAPH-#185C7, TGT_MergedSrc=L2008-4716
185C8 TANGUT IDEOGRAPH-#185C8, TGT_MergedSrc=L2008-5017
185C9 TANGUT IDEOGRAPH-#185C9, TGT_MergedSrc=L2008-4967
185CA TANGUT IDEOGRAPH-#185CA, TGT_MergedSrc=L2008-4880
185CB TANGUT IDEOGRAPH-#185CB, TGT_MergedSrc=L2008-4999
185CC TANGUT IDEOGRAPH-#185CC, TGT_MergedSrc=L2008-4898
185CD TANGUT IDEOGRAPH-#185CD, TGT_MergedSrc=L2008-4878
185CE TANGUT IDEOGRAPH-#185CE, TGT_MergedSrc=L2008-5008
185CF TANGUT IDEOGRAPH-#185CF, TGT_MergedSrc=L2008-4997
185D0 TANGUT IDEOGRAPH-#185D0, TGT_MergedSrc=L2008-4841
185D1 TANGUT IDEOGRAPH-#185D1, TGT_MergedSrc=L2008-6057
185D2 TANGUT IDEOGRAPH-#185D2, TGT_MergedSrc=L2008-5146
185D3 TANGUT IDEOGRAPH-#185D3, TGT_MergedSrc=L2008-5131
185D4 TANGUT IDEOGRAPH-#185D4, TGT_MergedSrc=L2008-5719
185D5 TANGUT IDEOGRAPH-#185D5, TGT_MergedSrc=L2008-5464
185D6 TANGUT IDEOGRAPH-#185D6, TGT_MergedSrc=L2008-5569
185D7 TANGUT IDEOGRAPH-#185D7, TGT_MergedSrc=L2008-5429
185D8 TANGUT IDEOGRAPH-#185D8, TGT_MergedSrc=L2008-5718
185D9 TANGUT IDEOGRAPH-#185D9, TGT_MergedSrc=L2008-5568
185DA TANGUT IDEOGRAPH-#185DA, TGT_MergedSrc=L2008-5369
185DB TANGUT IDEOGRAPH-#185DB, TGT_MergedSrc=L2008-5430
185DC TANGUT IDEOGRAPH-#185DC, TGT_MergedSrc=L2008-5098
185DD TANGUT IDEOGRAPH-#185DD, TGT_MergedSrc=L2008-5252
185DE TANGUT IDEOGRAPH-#185DE, TGT_MergedSrc=L2008-5349
185DF TANGUT IDEOGRAPH-#185DF, TGT_MergedSrc=L2008-5776
185E0 TANGUT IDEOGRAPH-#185E0, TGT_MergedSrc=L2008-5689
185E1 TANGUT IDEOGRAPH-#185E1, TGT_MergedSrc=L2008-5775
185E2 TANGUT IDEOGRAPH-#185E2, TGT_MergedSrc=L2008-5251
185E3 TANGUT IDEOGRAPH-#185E3, TGT_MergedSrc=L2008-5407
185E4 TANGUT IDEOGRAPH-#185E4, TGT_MergedSrc=L2008-5053
185E5 TANGUT IDEOGRAPH-#185E5, TGT_MergedSrc=L2008-5255
185E6 TANGUT IDEOGRAPH-#185E6, TGT_MergedSrc=N1966-172-041
185E7 TANGUT IDEOGRAPH-#185E7, TGT_MergedSrc=L2008-1851
185E8 TANGUT IDEOGRAPH-#185E8, TGT_MergedSrc=L2008-0857
185E9 TANGUT IDEOGRAPH-#185E9, TGT_MergedSrc=L2008-1055
185EA TANGUT IDEOGRAPH-#185EA, TGT_MergedSrc=L2008-1175
185EB TANGUT IDEOGRAPH-#185EB, TGT_MergedSrc=L2008-0255
185EC TANGUT IDEOGRAPH-#185EC, TGT_MergedSrc=L2008-0557
185ED TANGUT IDEOGRAPH-#185ED, TGT_MergedSrc=L2008-1673
185EE TANGUT IDEOGRAPH-#185EE, TGT_MergedSrc=L2008-1333
185EF TANGUT IDEOGRAPH-#185EF, TGT_MergedSrc=L2008-1746
185F0 TANGUT IDEOGRAPH-#185F0, TGT_MergedSrc=L2008-0864
185F1 TANGUT IDEOGRAPH-#185F1, TGT_MergedSrc=L2008-0674
185F2 TANGUT IDEOGRAPH-#185F2, TGT_MergedSrc=L2008-0248
185F3 TANGUT IDEOGRAPH-#185F3, TGT_MergedSrc=L2008-0766
185F4 TANGUT IDEOGRAPH-#185F4, TGT_MergedSrc=L2008-1141
185F5 TANGUT IDEOGRAPH-#185F5, TGT_MergedSrc=L2008-0550
185F6 TANGUT IDEOGRAPH-#185F6, TGT_MergedSrc=L2008-0803
185F7 TANGUT IDEOGRAPH-#185F7, TGT_MergedSrc=L2008-0713
185F8 TANGUT IDEOGRAPH-#185F8, TGT_MergedSrc=L2008-0380
185F9 TANGUT IDEOGRAPH-#185F9, TGT_MergedSrc=L2008-1308
185FA TANGUT IDEOGRAPH-#185FA, TGT_MergedSrc=L2008-0686
185FB TANGUT IDEOGRAPH-#185FB, TGT_MergedSrc=L2008-0834
185FC TANGUT IDEOGRAPH-#185FC, TGT_MergedSrc=L2008-0442
185FD TANGUT IDEOGRAPH-#185FD, TGT_MergedSrc=L2008-0590
185FE TANGUT IDEOGRAPH-#185FE, TGT_MergedSrc=L2008-1387
185FF TANGUT IDEOGRAPH-#185FF, TGT_MergedSrc=L2008-0307
18600 TANGUT IDEOGRAPH-#18600, TGT_MergedSrc=L2008-1699
18601 TANGUT IDEOGRAPH-#18601, TGT_MergedSrc=L2008-0893
18602 TANGUT IDEOGRAPH-#18602, TGT_MergedSrc=L2008-0872
18603 TANGUT IDEOGRAPH-#18603, TGT_MergedSrc=L2008-0750
18604 TANGUT IDEOGRAPH-#18604, TGT_MergedSrc=L2008-0169
18605 TANGUT IDEOGRAPH-#18605, TGT_MergedSrc=L2008-0228
18606 TANGUT IDEOGRAPH-#18606, TGT_MergedSrc=L2008-0941
18607 TANGUT IDEOGRAPH-#18607, TGT_MergedSrc=L2008-0501
18608 TANGUT IDEOGRAPH-#18608, TGT_MergedSrc=L2008-1647
18609 TANGUT IDEOGRAPH-#18609, TGT_MergedSrc=L2008-0854
1860A TANGUT IDEOGRAPH-#1860A, TGT_MergedSrc=L2008-1620
1860B TANGUT IDEOGRAPH-#1860B, TGT_MergedSrc=L2008-1482
1860C TANGUT IDEOGRAPH-#1860C, TGT_MergedSrc=L2008-0621
1860D TANGUT IDEOGRAPH-#1860D, TGT_MergedSrc=L2008-0726
1860E TANGUT IDEOGRAPH-#1860E, TGT_MergedSrc=L2008-1808
1860F TANGUT IDEOGRAPH-#1860F, TGT_MergedSrc=L2008-0622
18610 TANGUT IDEOGRAPH-#18610, TGT_MergedSrc=L2008-0356
18611 TANGUT IDEOGRAPH-#18611, TGT_MergedSrc=L2008-0540
18612 TANGUT IDEOGRAPH-#18612, TGT_MergedSrc=L2008-0689
18613 TANGUT IDEOGRAPH-#18613, TGT_MergedSrc=L2008-1231
18614 TANGUT IDEOGRAPH-#18614, TGT_MergedSrc=L2008-0339
18615 TANGUT IDEOGRAPH-#18615, TGT_MergedSrc=L2008-0690
18616 TANGUT IDEOGRAPH-#18616, TGT_MergedSrc=L2008-1677
18617 TANGUT IDEOGRAPH-#18617, TGT_MergedSrc=L2008-1856
18618 TANGUT IDEOGRAPH-#18618, TGT_MergedSrc=L2008-1348
18619 TANGUT IDEOGRAPH-#18619, TGT_MergedSrc=L2008-0742
1861A TANGUT IDEOGRAPH-#1861A, TGT_MergedSrc=L2008-0998
1861B TANGUT IDEOGRAPH-#1861B, TGT_MergedSrc=L2008-0171
1861C TANGUT IDEOGRAPH-#1861C, TGT_MergedSrc=L2008-0479
1861D TANGUT IDEOGRAPH-#1861D, TGT_MergedSrc=L2008-1087
1861E TANGUT IDEOGRAPH-#1861E, TGT_MergedSrc=L2008-1846
1861F TANGUT IDEOGRAPH-#1861F, TGT_MergedSrc=L2008-1648
18620 TANGUT IDEOGRAPH-#18620, TGT_MergedSrc=L2008-1033
18621 TANGUT IDEOGRAPH-#18621, TGT_MergedSrc=L2008-0758
18622 TANGUT IDEOGRAPH-#18622, TGT_MergedSrc=L2008-0490
18623 TANGUT IDEOGRAPH-#18623, TGT_MergedSrc=L2008-1278
18624 TANGUT IDEOGRAPH-#18624, TGT_MergedSrc=L2008-1153
18625 TANGUT IDEOGRAPH-#18625, TGT_MergedSrc=L2008-1279
18626 TANGUT IDEOGRAPH-#18626, TGT_MergedSrc=L2008-0322
18627 TANGUT IDEOGRAPH-#18627, TGT_MergedSrc=L2008-0375
18628 TANGUT IDEOGRAPH-#18628, TGT_MergedSrc=L2008-1213
18629 TANGUT IDEOGRAPH-#18629, TGT_MergedSrc=L2008-1725
1862A TANGUT IDEOGRAPH-#1862A, TGT_MergedSrc=L2008-1325
1862B TANGUT IDEOGRAPH-#1862B, TGT_MergedSrc=L2008-0251
1862C TANGUT IDEOGRAPH-#1862C, TGT_MergedSrc=L2008-0353
1862D TANGUT IDEOGRAPH-#1862D, TGT_MergedSrc=L2008-0385
1862E TANGUT IDEOGRAPH-#1862E, TGT_MergedSrc=L2008-0261
1862F TANGUT IDEOGRAPH-#1862F, TGT_MergedSrc=L2008-0304
18630 TANGUT IDEOGRAPH-#18630, TGT_MergedSrc=L2008-0314
18631 TANGUT IDEOGRAPH-#18631, TGT_MergedSrc=L2008-0323
18632 TANGUT IDEOGRAPH-#18632, TGT_MergedSrc=L2008-0252
18633 TANGUT IDEOGRAPH-#18633, TGT_MergedSrc=L2008-0679
18634 TANGUT IDEOGRAPH-#18634, TGT_MergedSrc=L2008-0698
18635 TANGUT IDEOGRAPH-#18635, TGT_MergedSrc=L2008-1679
18636 TANGUT IDEOGRAPH-#18636, TGT_MergedSrc=L2008-1712
18637 TANGUT IDEOGRAPH-#18637, TGT_MergedSrc=L2008-1239
18638 TANGUT IDEOGRAPH-#18638, TGT_MergedSrc=L2008-1238
18639 TANGUT IDEOGRAPH-#18639, TGT_MergedSrc=L2008-0386
1863A TANGUT IDEOGRAPH-#1863A, TGT_MergedSrc=L2008-0278
1863B TANGUT IDEOGRAPH-#1863B, TGT_MergedSrc=L2008-0268
1863C TANGUT IDEOGRAPH-#1863C, TGT_MergedSrc=L2008-1761
1863D TANGUT IDEOGRAPH-#1863D, TGT_MergedSrc=L2008-1411
1863E TANGUT IDEOGRAPH-#1863E, TGT_MergedSrc=L2008-0564
1863F TANGUT IDEOGRAPH-#1863F, TGT_MergedSrc=L2008-0808
18640 TANGUT IDEOGRAPH-#18640, TGT_MergedSrc=L2008-0697
18641 TANGUT IDEOGRAPH-#18641, TGT_MergedSrc=L2008-1672
18642 TANGUT IDEOGRAPH-#18642, TGT_MergedSrc=L2008-1866
18643 TANGUT IDEOGRAPH-#18643, TGT_MergedSrc=L2008-1859
18644 TANGUT IDEOGRAPH-#18644, TGT_MergedSrc=L2008-1680
18645 TANGUT IDEOGRAPH-#18645, TGT_MergedSrc=L2008-1744
18646 TANGUT IDEOGRAPH-#18646, TGT_MergedSrc=L2008-1197
18647 TANGUT IDEOGRAPH-#18647, TGT_MergedSrc=L2008-0795
18648 TANGUT IDEOGRAPH-#18648, TGT_MergedSrc=L2008-0882
18649 TANGUT IDEOGRAPH-#18649, TGT_MergedSrc=L2008-0580
1864A TANGUT IDEOGRAPH-#1864A, TGT_MergedSrc=L2008-1762
1864B TANGUT IDEOGRAPH-#1864B, TGT_MergedSrc=L2008-0809
1864C TANGUT IDEOGRAPH-#1864C, TGT_MergedSrc=L2008-1326
1864D TANGUT IDEOGRAPH-#1864D, TGT_MergedSrc=L2008-0878
1864E TANGUT IDEOGRAPH-#1864E, TGT_MergedSrc=L2008-0354
1864F TANGUT IDEOGRAPH-#1864F, TGT_MergedSrc=L2008-0801
18650 TANGUT IDEOGRAPH-#18650, TGT_MergedSrc=L2008-0376
18651 TANGUT IDEOGRAPH-#18651, TGT_MergedSrc=L2008-1405
18652 TANGUT IDEOGRAPH-#18652, TGT_MergedSrc=L2008-0601
18653 TANGUT IDEOGRAPH-#18653, TGT_MergedSrc=L2008-0810
18654 TANGUT IDEOGRAPH-#18654, TGT_MergedSrc=L2008-0296
18655 TANGUT IDEOGRAPH-#18655, TGT_MergedSrc=L2008-1729
18656 TANGUT IDEOGRAPH-#18656, TGT_MergedSrc=L2008-1773
18657 TANGUT IDEOGRAPH-#18657, TGT_MergedSrc=L2008-1221
18658 TANGUT IDEOGRAPH-#18658, TGT_MergedSrc=L2008-1240
18659 TANGUT IDEOGRAPH-#18659, TGT_MergedSrc=N1966-297-097
1865A TANGUT IDEOGRAPH-#1865A, TGT_MergedSrc=L2008-0341
1865B TANGUT IDEOGRAPH-#1865B, TGT_MergedSrc=L2008-0288
1865C TANGUT IDEOGRAPH-#1865C, TGT_MergedSrc=L2008-1854
1865D TANGUT IDEOGRAPH-#1865D, TGT_MergedSrc=L2008-0796
1865E TANGUT IDEOGRAPH-#1865E, TGT_MergedSrc=L2008-0802
1865F TANGUT IDEOGRAPH-#1865F, TGT_MergedSrc=L2008-1390
18660 TANGUT IDEOGRAPH-#18660, TGT_MergedSrc=L2008-1730
18661 TANGUT IDEOGRAPH-#18661, TGT_MergedSrc=L2008-0581
18662 TANGUT IDEOGRAPH-#18662, TGT_MergedSrc=L2008-1391
18663 TANGUT IDEOGRAPH-#18663, TGT_MergedSrc=L2008-0716
18664 TANGUT IDEOGRAPH-#18664, TGT_MergedSrc=L2008-1731
18665 TANGUT IDEOGRAPH-#18665, TGT_MergedSrc=L2008-0594
18666 TANGUT IDEOGRAPH-#18666, TGT_MergedSrc=L2008-0297
18667 TANGUT IDEOGRAPH-#18667, TGT_MergedSrc=L2008-1212
18668 TANGUT IDEOGRAPH-#18668, TGT_MergedSrc=L2008-1610
18669 TANGUT IDEOGRAPH-#18669, TGT_MergedSrc=L2008-0985
1866A TANGUT IDEOGRAPH-#1866A, TGT_MergedSrc=L2008-0670
1866B TANGUT IDEOGRAPH-#1866B, TGT_MergedSrc=L2008-5872
1866C TANGUT IDEOGRAPH-#1866C, TGT_MergedSrc=L2008-1043
1866D TANGUT IDEOGRAPH-#1866D, TGT_MergedSrc=L2008-0668
1866E TANGUT IDEOGRAPH-#1866E, TGT_MergedSrc=L2008-1659
1866F TANGUT IDEOGRAPH-#1866F, TGT_MergedSrc=L2008-0521
18670 TANGUT IDEOGRAPH-#18670, TGT_MergedSrc=L2008-1608
18671 TANGUT IDEOGRAPH-#18671, TGT_MergedSrc=L2008-1660
18672 TANGUT IDEOGRAPH-#18672, TGT_MergedSrc=L2008-0443
18673 TANGUT IDEOGRAPH-#18673, TGT_MergedSrc=L2008-0459
18674 TANGUT IDEOGRAPH-#18674, TGT_MergedSrc=L2008-0458
18675 TANGUT IDEOGRAPH-#18675, TGT_MergedSrc=L2008-0460
18676 TANGUT IDEOGRAPH-#18676, TGT_MergedSrc=L2008-0624
18677 TANGUT IDEOGRAPH-#18677, TGT_MergedSrc=L2008-1816
18678 TANGUT IDEOGRAPH-#18678, TGT_MergedSrc=L2008-1541
18679 TANGUT IDEOGRAPH-#18679, TGT_MergedSrc=L2008-0890
1867A TANGUT IDEOGRAPH-#1867A, TGT_MergedSrc=L2008-0451
1867B TANGUT IDEOGRAPH-#1867B, TGT_MergedSrc=L2008-0889
1867C TANGUT IDEOGRAPH-#1867C, TGT_MergedSrc=L2008-0730
1867D TANGUT IDEOGRAPH-#1867D, TGT_MergedSrc=L2008-0664
1867E TANGUT IDEOGRAPH-#1867E, TGT_MergedSrc=L2008-1601
1867F TANGUT IDEOGRAPH-#1867F, TGT_MergedSrc=L2008-1280
18680 TANGUT IDEOGRAPH-#18680, TGT_MergedSrc=L2008-2597
18681 TANGUT IDEOGRAPH-#18681, TGT_MergedSrc=L2008-3032
18682 TANGUT IDEOGRAPH-#18682, TGT_MergedSrc=L2008-0658
18683 TANGUT IDEOGRAPH-#18683, TGT_MergedSrc=L2008-1618
18684 TANGUT IDEOGRAPH-#18684, TGT_MergedSrc=L2008-0172
18685 TANGUT IDEOGRAPH-#18685, TGT_MergedSrc=L2008-1848
18686 TANGUT IDEOGRAPH-#18686, TGT_MergedSrc=L2008-0362
18687 TANGUT IDEOGRAPH-#18687, TGT_MergedSrc=L2008-0324
18688 TANGUT IDEOGRAPH-#18688, TGT_MergedSrc=L2008-0263
18689 TANGUT IDEOGRAPH-#18689, TGT_MergedSrc=L2008-1853
1868A TANGUT IDEOGRAPH-#1868A, TGT_MergedSrc=L2008-1874
1868B TANGUT IDEOGRAPH-#1868B, TGT_MergedSrc=L2008-0549
1868C TANGUT IDEOGRAPH-#1868C, TGT_MergedSrc=L2008-4022
1868D TANGUT IDEOGRAPH-#1868D, TGT_MergedSrc=L2008-4430
1868E TANGUT IDEOGRAPH-#1868E, TGT_MergedSrc=L2008-4453
1868F TANGUT IDEOGRAPH-#1868F, TGT_MergedSrc=L2008-4441
18690 TANGUT IDEOGRAPH-#18690, TGT_MergedSrc=L2008-4274
18691 TANGUT IDEOGRAPH-#18691, TGT_MergedSrc=L2008-4446
18692 TANGUT IDEOGRAPH-#18692, TGT_MergedSrc=L2008-4461
18693 TANGUT IDEOGRAPH-#18693, TGT_MergedSrc=L2008-4432
18694 TANGUT IDEOGRAPH-#18694, TGT_MergedSrc=L2008-4625
18695 TANGUT IDEOGRAPH-#18695, TGT_MergedSrc=L2008-0200
18696 TANGUT IDEOGRAPH-#18696, TGT_MergedSrc=L2008-1018
18697 TANGUT IDEOGRAPH-#18697, TGT_MergedSrc=L2008-0642
18698 TANGUT IDEOGRAPH-#18698, TGT_MergedSrc=L2008-0552
18699 TANGUT IDEOGRAPH-#18699, TGT_MergedSrc=L2008-1681
1869A TANGUT IDEOGRAPH-#1869A, TGT_MergedSrc=L2008-0265
1869B TANGUT IDEOGRAPH-#1869B, TGT_MergedSrc=L2008-0554
1869C TANGUT IDEOGRAPH-#1869C, TGT_MergedSrc=L2008-0883
1869D TANGUT IDEOGRAPH-#1869D, TGT_MergedSrc=L2008-1328
1869E TANGUT IDEOGRAPH-#1869E, TGT_MergedSrc=L1997-5995
1869F TANGUT IDEOGRAPH-#1869F, TGT_MergedSrc=L2008-0308
186A0 TANGUT IDEOGRAPH-#186A0, TGT_MergedSrc=L2008-4554
186A1 TANGUT IDEOGRAPH-#186A1, TGT_MergedSrc=L2008-0523-4565
186A2 TANGUT IDEOGRAPH-#186A2, TGT_MergedSrc=L2008-0762
186A3 TANGUT IDEOGRAPH-#186A3, TGT_MergedSrc=L2008-0237
186A4 TANGUT IDEOGRAPH-#186A4, TGT_MergedSrc=L2008-4671
186A5 TANGUT IDEOGRAPH-#186A5, TGT_MergedSrc=L2008-4579
186A6 TANGUT IDEOGRAPH-#186A6, TGT_MergedSrc=L2008-4561
186A7 TANGUT IDEOGRAPH-#186A7, TGT_MergedSrc=L2008-4654
186A8 TANGUT IDEOGRAPH-#186A8, TGT_MergedSrc=L2008-0551
186A9 TANGUT IDEOGRAPH-#186A9, TGT_MergedSrc=L2008-2810
186AA TANGUT IDEOGRAPH-#186AA, TGT_MergedSrc=L2008-2524
186AB TANGUT IDEOGRAPH-#186AB, TGT_MergedSrc=L2008-2522
186AC TANGUT IDEOGRAPH-#186AC, TGT_MergedSrc=L2008-3727
186AD TANGUT IDEOGRAPH-#186AD, TGT_MergedSrc=L2008-2305
186AE TANGUT IDEOGRAPH-#186AE, TGT_MergedSrc=L2008-2690
186AF TANGUT IDEOGRAPH-#186AF, TGT_MergedSrc=L2008-2526
186B0 TANGUT IDEOGRAPH-#186B0, TGT_MergedSrc=L2008-2689
186B1 TANGUT IDEOGRAPH-#186B1, TGT_MergedSrc=L2008-3810
186B2 TANGUT IDEOGRAPH-#186B2, TGT_MergedSrc=L2008-2895
186B3 TANGUT IDEOGRAPH-#186B3, TGT_MergedSrc=L2008-2301
186B4 TANGUT IDEOGRAPH-#186B4, TGT_MergedSrc=L2008-2525
186B5 TANGUT IDEOGRAPH-#186B5, TGT_MergedSrc=L2008-3724
186B6 TANGUT IDEOGRAPH-#186B6, TGT_MergedSrc=L2008-2302
186B7 TANGUT IDEOGRAPH-#186B7, TGT_MergedSrc=L2008-2811
186B8 TANGUT IDEOGRAPH-#186B8, TGT_MergedSrc=L2008-3395
186B9 TANGUT IDEOGRAPH-#186B9, TGT_MergedSrc=L2008-2304
186BA TANGUT IDEOGRAPH-#186BA, TGT_MergedSrc=L2008-3394
186BB TANGUT IDEOGRAPH-#186BB, TGT_MergedSrc=L2008-4630
186BC TANGUT IDEOGRAPH-#186BC, TGT_MergedSrc=L2008-6030
186BD TANGUT IDEOGRAPH-#186BD, TGT_MergedSrc=L2008-2402
186BE TANGUT IDEOGRAPH-#186BE, TGT_MergedSrc=L2008-2043
186BF TANGUT IDEOGRAPH-#186BF, TGT_MergedSrc=L2008-3878
186C0 TANGUT IDEOGRAPH-#186C0, TGT_MergedSrc=L2008-3889
186C1 TANGUT IDEOGRAPH-#186C1, TGT_MergedSrc=L2008-4011
186C2 TANGUT IDEOGRAPH-#186C2, TGT_MergedSrc=L2008-4015
186C3 TANGUT IDEOGRAPH-#186C3, TGT_MergedSrc=L2008-3819
186C4 TANGUT IDEOGRAPH-#186C4, TGT_MergedSrc=L2008-3847
186C5 TANGUT IDEOGRAPH-#186C5, TGT_MergedSrc=L2008-3865
186C6 TANGUT IDEOGRAPH-#186C6, TGT_MergedSrc=L2008-3972
186C7 TANGUT IDEOGRAPH-#186C7, TGT_MergedSrc=L2008-3879
186C8 TANGUT IDEOGRAPH-#186C8, TGT_MergedSrc=L2008-3867
186C9 TANGUT IDEOGRAPH-#186C9, TGT_MergedSrc=L2008-3965
186CA TANGUT IDEOGRAPH-#186CA, TGT_MergedSrc=L2008-3999
186CB TANGUT IDEOGRAPH-#186CB, TGT_MergedSrc=L2008-5803
186CC TANGUT IDEOGRAPH-#186CC, TGT_MergedSrc=L2008-5774
186CD TANGUT IDEOGRAPH-#186CD, TGT_MergedSrc=L2008-4674
186CE TANGUT IDEOGRAPH-#186CE, TGT_MergedSrc=L2008-5135
186CF TANGUT IDEOGRAPH-#186CF, TGT_MergedSrc=L2008-5709
186D0 TANGUT IDEOGRAPH-#186D0, TGT_MergedSrc=L2008-5128
186D1 TANGUT IDEOGRAPH-#186D1, TGT_MergedSrc=L2008-6068
186D2 TANGUT IDEOGRAPH-#186D2, TGT_MergedSrc=L2008-5262
186D3 TANGUT IDEOGRAPH-#186D3, TGT_MergedSrc=L2008-5830
186D4 TANGUT IDEOGRAPH-#186D4, TGT_MergedSrc=L2008-5578
186D5 TANGUT IDEOGRAPH-#186D5, TGT_MergedSrc=L2008-5542
186D6 TANGUT IDEOGRAPH-#186D6, TGT_MergedSrc=L2008-4881
186D7 TANGUT IDEOGRAPH-#186D7, TGT_MergedSrc=L2008-5789
186D8 TANGUT IDEOGRAPH-#186D8, TGT_MergedSrc=L2008-5673
186D9 TANGUT IDEOGRAPH-#186D9, TGT_MergedSrc=L2008-4948
186DA TANGUT IDEOGRAPH-#186DA, TGT_MergedSrc=L2008-5202
186DB TANGUT IDEOGRAPH-#186DB, TGT_MergedSrc=L2008-5319
186DC TANGUT IDEOGRAPH-#186DC, TGT_MergedSrc=L2008-5036
186DD TANGUT IDEOGRAPH-#186DD, TGT_MergedSrc=L2008-5409
186DE TANGUT IDEOGRAPH-#186DE, TGT_MergedSrc=L2008-5210
186DF TANGUT IDEOGRAPH-#186DF, TGT_MergedSrc=L2008-5305
186E0 TANGUT IDEOGRAPH-#186E0, TGT_MergedSrc=L2008-5844
186E1 TANGUT IDEOGRAPH-#186E1, TGT_MergedSrc=L2008-5094
186E2 TANGUT IDEOGRAPH-#186E2, TGT_MergedSrc=L2008-5264
186E3 TANGUT IDEOGRAPH-#186E3, TGT_MergedSrc=L2008-5505
186E4 TANGUT IDEOGRAPH-#186E4, TGT_MergedSrc=L2008-5544
186E5 TANGUT IDEOGRAPH-#186E5, TGT_MergedSrc=L2008-5130
186E6 TANGUT IDEOGRAPH-#186E6, TGT_MergedSrc=L2008-5500
186E7 TANGUT IDEOGRAPH-#186E7, TGT_MergedSrc=L2008-5196
186E8 TANGUT IDEOGRAPH-#186E8, TGT_MergedSrc=L2008-5400
186E9 TANGUT IDEOGRAPH-#186E9, TGT_MergedSrc=L2008-5576
186EA TANGUT IDEOGRAPH-#186EA, TGT_MergedSrc=L2008-5347
186EB TANGUT IDEOGRAPH-#186EB, TGT_MergedSrc=L2008-5259
186EC TANGUT IDEOGRAPH-#186EC, TGT_MergedSrc=L2008-5687
186ED TANGUT IDEOGRAPH-#186ED, TGT_MergedSrc=L2008-5656
186EE TANGUT IDEOGRAPH-#186EE, TGT_MergedSrc=L2008-5288
186EF TANGUT IDEOGRAPH-#186EF, TGT_MergedSrc=L2008-5551
186F0 TANGUT IDEOGRAPH-#186F0, TGT_MergedSrc=L2008-5552
186F1 TANGUT IDEOGRAPH-#186F1, TGT_MergedSrc=L2008-5466
186F2 TANGUT IDEOGRAPH-#186F2, TGT_MergedSrc=L2008-5083
186F3 TANGUT IDEOGRAPH-#186F3, TGT_MergedSrc=L2008-5137
186F4 TANGUT IDEOGRAPH-#186F4, TGT_MergedSrc=L2008-5138
186F5 TANGUT IDEOGRAPH-#186F5, TGT_MergedSrc=L2008-4859
186F6 TANGUT IDEOGRAPH-#186F6, TGT_MergedSrc=L2008-5223
186F7 TANGUT IDEOGRAPH-#186F7, TGT_MergedSrc=L2008-5211
186F8 TANGUT IDEOGRAPH-#186F8, TGT_MergedSrc=L2008-5320
186F9 TANGUT IDEOGRAPH-#186F9, TGT_MergedSrc=L2008-5753
186FA TANGUT IDEOGRAPH-#186FA, TGT_MergedSrc=L2008-5453
186FB TANGUT IDEOGRAPH-#186FB, TGT_MergedSrc=L2008-5179
186FC TANGUT IDEOGRAPH-#186FC, TGT_MergedSrc=H2004-A-5647
186FD TANGUT IDEOGRAPH-#186FD, TGT_MergedSrc=L2008-1546
186FE TANGUT IDEOGRAPH-#186FE, TGT_MergedSrc=L2008-0736
186FF TANGUT IDEOGRAPH-#186FF, TGT_MergedSrc=L2008-0891
18700 TANGUT IDEOGRAPH-#18700, TGT_MergedSrc=L2008-0611
18701 TANGUT IDEOGRAPH-#18701, TGT_MergedSrc=L2008-0416
18702 TANGUT IDEOGRAPH-#18702, TGT_MergedSrc=L2008-0249
18703 TANGUT IDEOGRAPH-#18703, TGT_MergedSrc=L2008-0382
18704 TANGUT IDEOGRAPH-#18704, TGT_MergedSrc=L2008-1357
18705 TANGUT IDEOGRAPH-#18705, TGT_MergedSrc=L2008-0383
18706 TANGUT IDEOGRAPH-#18706, TGT_MergedSrc=L2008-1395
18707 TANGUT IDEOGRAPH-#18707, TGT_MergedSrc=L2008-1218
18708 TANGUT IDEOGRAPH-#18708, TGT_MergedSrc=L2008-0570
18709 TANGUT IDEOGRAPH-#18709, TGT_MergedSrc=L2008-1427
1870A TANGUT IDEOGRAPH-#1870A, TGT_MergedSrc=L2008-1802
1870B TANGUT IDEOGRAPH-#1870B, TGT_MergedSrc=L2008-0420
1870C TANGUT IDEOGRAPH-#1870C, TGT_MergedSrc=L2008-0421
1870D TANGUT IDEOGRAPH-#1870D, TGT_MergedSrc=L2008-0811
1870E TANGUT IDEOGRAPH-#1870E, TGT_MergedSrc=L2008-1494
1870F TANGUT IDEOGRAPH-#1870F, TGT_MergedSrc=L2008-1815
18710 TANGUT IDEOGRAPH-#18710, TGT_MergedSrc=L2008-1495
18711 TANGUT IDEOGRAPH-#18711, TGT_MergedSrc=L2008-0999
18712 TANGUT IDEOGRAPH-#18712, TGT_MergedSrc=L2008-0743
18713 TANGUT IDEOGRAPH-#18713, TGT_MergedSrc=L2008-0170
18714 TANGUT IDEOGRAPH-#18714, TGT_MergedSrc=L2008-0497
18715 TANGUT IDEOGRAPH-#18715, TGT_MergedSrc=L2008-1617
18716 TANGUT IDEOGRAPH-#18716, TGT_MergedSrc=L2008-0235
18717 TANGUT IDEOGRAPH-#18717, TGT_MergedSrc=L2008-0747
18718 TANGUT IDEOGRAPH-#18718, TGT_MergedSrc=L2008-1599
18719 TANGUT IDEOGRAPH-#18719, TGT_MergedSrc=L2008-1852
1871A TANGUT IDEOGRAPH-#1871A, TGT_MergedSrc=L2008-0851
1871B TANGUT IDEOGRAPH-#1871B, TGT_MergedSrc=L2008-1611
1871C TANGUT IDEOGRAPH-#1871C, TGT_MergedSrc=L2008-0699
1871D TANGUT IDEOGRAPH-#1871D, TGT_MergedSrc=L2008-1330
1871E TANGUT IDEOGRAPH-#1871E, TGT_MergedSrc=L2008-1224
1871F TANGUT IDEOGRAPH-#1871F, TGT_MergedSrc=L2008-0579
18720 TANGUT IDEOGRAPH-#18720, TGT_MergedSrc=L2008-6042
18721 TANGUT IDEOGRAPH-#18721, TGT_MergedSrc=L2008-2303
18722 TANGUT IDEOGRAPH-#18722, TGT_MergedSrc=L2008-6028
18723 TANGUT IDEOGRAPH-#18723, TGT_MergedSrc=L2008-6034
18724 TANGUT IDEOGRAPH-#18724, TGT_MergedSrc=L2008-2521
18725 TANGUT IDEOGRAPH-#18725, TGT_MergedSrc=L2008-6029
18726 TANGUT IDEOGRAPH-#18726, TGT_MergedSrc=L2008-2298-2299
18727 TANGUT IDEOGRAPH-#18727, TGT_MergedSrc=L2008-3726
18728 TANGUT IDEOGRAPH-#18728, TGT_MergedSrc=L2008-3723
18729 TANGUT IDEOGRAPH-#18729, TGT_MergedSrc=L2008-0253
1872A TANGUT IDEOGRAPH-#1872A, TGT_MergedSrc=L2008-0681
1872B TANGUT IDEOGRAPH-#1872B, TGT_MergedSrc=L2008-4504
1872C TANGUT IDEOGRAPH-#1872C, TGT_MergedSrc=L2008-4503
1872D TANGUT IDEOGRAPH-#1872D, TGT_MergedSrc=L2008-4423
1872E TANGUT IDEOGRAPH-#1872E, TGT_MergedSrc=L2008-4466
1872F TANGUT IDEOGRAPH-#1872F, TGT_MergedSrc=L2008-4214
18730 TANGUT IDEOGRAPH-#18730, TGT_MergedSrc=L2008-4431
18731 TANGUT IDEOGRAPH-#18731, TGT_MergedSrc=L2008-4468
18732 TANGUT IDEOGRAPH-#18732, TGT_MergedSrc=L2008-4425
18733 TANGUT IDEOGRAPH-#18733, TGT_MergedSrc=L2008-4455
18734 TANGUT IDEOGRAPH-#18734, TGT_MergedSrc=L2008-4449
18735 TANGUT IDEOGRAPH-#18735, TGT_MergedSrc=L2008-4439
18736 TANGUT IDEOGRAPH-#18736, TGT_MergedSrc=L2008-4456-4457
18737 TANGUT IDEOGRAPH-#18737, TGT_MergedSrc=L2008-4445
18738 TANGUT IDEOGRAPH-#18738, TGT_MergedSrc=L2008-4467
18739 TANGUT IDEOGRAPH-#18739, TGT_MergedSrc=L2008-4447
1873A TANGUT IDEOGRAPH-#1873A, TGT_MergedSrc=L2008-4454
1873B TANGUT IDEOGRAPH-#1873B, TGT_MergedSrc=L2008-0536
1873C TANGUT IDEOGRAPH-#1873C, TGT_MergedSrc=L2008-1223
1873D TANGUT IDEOGRAPH-#1873D, TGT_MergedSrc=L2008-0254
1873E TANGUT IDEOGRAPH-#1873E, TGT_MergedSrc=L2008-0264
1873F TANGUT IDEOGRAPH-#1873F, TGT_MergedSrc=L2008-1406
18740 TANGUT IDEOGRAPH-#18740, TGT_MergedSrc=L2008-1327
18741 TANGUT IDEOGRAPH-#18741, TGT_MergedSrc=L2008-0673
18742 TANGUT IDEOGRAPH-#18742, TGT_MergedSrc=L2008-0700
18743 TANGUT IDEOGRAPH-#18743, TGT_MergedSrc=L2008-0553
18744 TANGUT IDEOGRAPH-#18744, TGT_MergedSrc=L2008-1697
18745 TANGUT IDEOGRAPH-#18745, TGT_MergedSrc=L2008-0680
18746 TANGUT IDEOGRAPH-#18746, TGT_MergedSrc=L2008-0301
18747 TANGUT IDEOGRAPH-#18747, TGT_MergedSrc=L2008-1281
18748 TANGUT IDEOGRAPH-#18748, TGT_MergedSrc=L2008-1716
18749 TANGUT IDEOGRAPH-#18749, TGT_MergedSrc=L2008-1860
1874A TANGUT IDEOGRAPH-#1874A, TGT_MergedSrc=L2008-1764
1874B TANGUT IDEOGRAPH-#1874B, TGT_MergedSrc=L2008-1242
1874C TANGUT IDEOGRAPH-#1874C, TGT_MergedSrc=L2008-1174
1874D TANGUT IDEOGRAPH-#1874D, TGT_MergedSrc=L2008-1420
1874E TANGUT IDEOGRAPH-#1874E, TGT_MergedSrc=L2008-1358
1874F TANGUT IDEOGRAPH-#1874F, TGT_MergedSrc=L2008-0812
18750 TANGUT IDEOGRAPH-#18750, TGT_MergedSrc=L2008-3725
18751 TANGUT IDEOGRAPH-#18751, TGT_MergedSrc=L2008-3770
18752 TANGUT IDEOGRAPH-#18752, TGT_MergedSrc=L2008-3522
18753 TANGUT IDEOGRAPH-#18753, TGT_MergedSrc=L2008-2842
18754 TANGUT IDEOGRAPH-#18754, TGT_MergedSrc=L2008-3521
18755 TANGUT IDEOGRAPH-#18755, TGT_MergedSrc=L2008-3823
18756 TANGUT IDEOGRAPH-#18756, TGT_MergedSrc=L2008-3954
18757 TANGUT IDEOGRAPH-#18757, TGT_MergedSrc=L2008-3939
18758 TANGUT IDEOGRAPH-#18758, TGT_MergedSrc=L2008-3937
18759 TANGUT IDEOGRAPH-#18759, TGT_MergedSrc=L2008-5164
1875A TANGUT IDEOGRAPH-#1875A, TGT_MergedSrc=L2008-5817
1875B TANGUT IDEOGRAPH-#1875B, TGT_MergedSrc=L2008-5886
1875C TANGUT IDEOGRAPH-#1875C, TGT_MergedSrc=L2008-5904
1875D TANGUT IDEOGRAPH-#1875D, TGT_MergedSrc=L2006-5998
1875E TANGUT IDEOGRAPH-#1875E, TGT_MergedSrc=L2008-4797
1875F TANGUT IDEOGRAPH-#1875F, TGT_MergedSrc=L2008-5424
18760 TANGUT IDEOGRAPH-#18760, TGT_MergedSrc=L2008-5355
18761 TANGUT IDEOGRAPH-#18761, TGT_MergedSrc=L2008-5947
18762 TANGUT IDEOGRAPH-#18762, TGT_MergedSrc=L2008-5983
18763 TANGUT IDEOGRAPH-#18763, TGT_MergedSrc=L2008-4672
18764 TANGUT IDEOGRAPH-#18764, TGT_MergedSrc=L2008-5410
18765 TANGUT IDEOGRAPH-#18765, TGT_MergedSrc=L2008-5615
18766 TANGUT IDEOGRAPH-#18766, TGT_MergedSrc=L2008-5604
18767 TANGUT IDEOGRAPH-#18767, TGT_MergedSrc=L2008-5594
18768 TANGUT IDEOGRAPH-#18768, TGT_MergedSrc=L2008-4861
18769 TANGUT IDEOGRAPH-#18769, TGT_MergedSrc=N1966-299-021
1876A TANGUT IDEOGRAPH-#1876A, TGT_MergedSrc=L2008-5163
1876B TANGUT IDEOGRAPH-#1876B, TGT_MergedSrc=L2008-5219
1876C TANGUT IDEOGRAPH-#1876C, TGT_MergedSrc=L2008-5801
1876D TANGUT IDEOGRAPH-#1876D, TGT_MergedSrc=L2008-5458
1876E TANGUT IDEOGRAPH-#1876E, TGT_MergedSrc=L2008-5614
1876F TANGUT IDEOGRAPH-#1876F, TGT_MergedSrc=L2008-5593
18770 TANGUT IDEOGRAPH-#18770, TGT_MergedSrc=L2008-5622
18771 TANGUT IDEOGRAPH-#18771, TGT_MergedSrc=L2008-5324
18772 TANGUT IDEOGRAPH-#18772, TGT_MergedSrc=L2008-5451
18773 TANGUT IDEOGRAPH-#18773, TGT_MergedSrc=L2008-5795
18774 TANGUT IDEOGRAPH-#18774, TGT_MergedSrc=L2008-6064
18775 TANGUT IDEOGRAPH-#18775, TGT_MergedSrc=L2008-1245
18776 TANGUT IDEOGRAPH-#18776, TGT_MergedSrc=L2008-0582
18777 TANGUT IDEOGRAPH-#18777, TGT_MergedSrc=L2008-0470
18778 TANGUT IDEOGRAPH-#18778, TGT_MergedSrc=L2008-1835
18779 TANGUT IDEOGRAPH-#18779, TGT_MergedSrc=L2008-0156
1877A TANGUT IDEOGRAPH-#1877A, TGT_MergedSrc=L2008-1580
1877B TANGUT IDEOGRAPH-#1877B, TGT_MergedSrc=L2008-1034
1877C TANGUT IDEOGRAPH-#1877C, TGT_MergedSrc=L2008-0977
1877D TANGUT IDEOGRAPH-#1877D, TGT_MergedSrc=L2008-0511
1877E TANGUT IDEOGRAPH-#1877E, TGT_MergedSrc=L2008-1142
1877F TANGUT IDEOGRAPH-#1877F, TGT_MergedSrc=L2008-1222
18780 TANGUT IDEOGRAPH-#18780, TGT_MergedSrc=L2008-1740
18781 TANGUT IDEOGRAPH-#18781, TGT_MergedSrc=L2008-1241
18782 TANGUT IDEOGRAPH-#18782, TGT_MergedSrc=L2008-1118
18783 TANGUT IDEOGRAPH-#18783, TGT_MergedSrc=L2008-1329
18784 TANGUT IDEOGRAPH-#18784, TGT_MergedSrc=L2008-1696
18785 TANGUT IDEOGRAPH-#18785, TGT_MergedSrc=L2008-1372
18786 TANGUT IDEOGRAPH-#18786, TGT_MergedSrc=L2008-1475
18787 TANGUT IDEOGRAPH-#18787, TGT_MergedSrc=L2008-1789
18788 TANGUT IDEOGRAPH-#18788, TGT_MergedSrc=L2008-1439
18789 TANGUT IDEOGRAPH-#18789, TGT_MergedSrc=L2008-0262
1878A TANGUT IDEOGRAPH-#1878A, TGT_MergedSrc=L2008-0565
1878B TANGUT IDEOGRAPH-#1878B, TGT_MergedSrc=L2008-1745
1878C TANGUT IDEOGRAPH-#1878C, TGT_MergedSrc=L2008-0902
1878D TANGUT IDEOGRAPH-#1878D, TGT_MergedSrc=L2008-0739
1878E TANGUT IDEOGRAPH-#1878E, TGT_MergedSrc=L2008-0640
1878F TANGUT IDEOGRAPH-#1878F, TGT_MergedSrc=L2008-0884
18790 TANGUT IDEOGRAPH-#18790, TGT_MergedSrc=L2008-0151
18791 TANGUT IDEOGRAPH-#18791, TGT_MergedSrc=L2008-1841
18792 TANGUT IDEOGRAPH-#18792, TGT_MergedSrc=L2008-1833
18793 TANGUT IDEOGRAPH-#18793, TGT_MergedSrc=L2008-0676
18794 TANGUT IDEOGRAPH-#18794, TGT_MergedSrc=L2008-4462
18795 TANGUT IDEOGRAPH-#18795, TGT_MergedSrc=L2008-6051
18796 TANGUT IDEOGRAPH-#18796, TGT_MergedSrc=L2008-4442
18797 TANGUT IDEOGRAPH-#18797, TGT_MergedSrc=L2008-0001
18798 TANGUT IDEOGRAPH-#18798, TGT_MergedSrc=L2008-1577
18799 TANGUT IDEOGRAPH-#18799, TGT_MergedSrc=L2008-1582
1879A TANGUT IDEOGRAPH-#1879A, TGT_MergedSrc=L2008-0740
1879B TANGUT IDEOGRAPH-#1879B, TGT_MergedSrc=L2008-1578
1879C TANGUT IDEOGRAPH-#1879C, TGT_MergedSrc=L2008-1583
1879D TANGUT IDEOGRAPH-#1879D, TGT_MergedSrc=L2008-0031
1879E TANGUT IDEOGRAPH-#1879E, TGT_MergedSrc=L2008-1019
1879F TANGUT IDEOGRAPH-#1879F, TGT_MergedSrc=L2008-1621
187A0 TANGUT IDEOGRAPH-#187A0, TGT_MergedSrc=L2008-3971
187A1 TANGUT IDEOGRAPH-#187A1, TGT_MergedSrc=L2008-3941
187A2 TANGUT IDEOGRAPH-#187A2, TGT_MergedSrc=L2008-3997
187A3 TANGUT IDEOGRAPH-#187A3, TGT_MergedSrc=L2008-3940
187A4 TANGUT IDEOGRAPH-#187A4, TGT_MergedSrc=L2008-4874
187A5 TANGUT IDEOGRAPH-#187A5, TGT_MergedSrc=L2008-5636
187A6 TANGUT IDEOGRAPH-#187A6, TGT_MergedSrc=L2008-5637
187A7 TANGUT IDEOGRAPH-#187A7, TGT_MergedSrc=L2008-4777
187A8 TANGUT IDEOGRAPH-#187A8, TGT_MergedSrc=L2008-5425
187A9 TANGUT IDEOGRAPH-#187A9, TGT_MergedSrc=L2008-5126
187AA TANGUT IDEOGRAPH-#187AA, TGT_MergedSrc=L2008-5356
187AB TANGUT IDEOGRAPH-#187AB, TGT_MergedSrc=L2008-5368
187AC TANGUT IDEOGRAPH-#187AC, TGT_MergedSrc=L2008-5698
187AD TANGUT IDEOGRAPH-#187AD, TGT_MergedSrc=L2008-5717
187AE TANGUT IDEOGRAPH-#187AE, TGT_MergedSrc=L2008-5743
187AF TANGUT IDEOGRAPH-#187AF, TGT_MergedSrc=L2008-5436
187B0 TANGUT IDEOGRAPH-#187B0, TGT_MergedSrc=L2008-5761
187B1 TANGUT IDEOGRAPH-#187B1, TGT_MergedSrc=L2008-0900
187B2 TANGUT IDEOGRAPH-#187B2, TGT_MergedSrc=L2008-0910
187B3 TANGUT IDEOGRAPH-#187B3, TGT_MergedSrc=L2008-0527
187B4 TANGUT IDEOGRAPH-#187B4, TGT_MergedSrc=L2008-0595
187B5 TANGUT IDEOGRAPH-#187B5, TGT_MergedSrc=L2008-0596
187B6 TANGUT IDEOGRAPH-#187B6, TGT_MergedSrc=L2008-1876
187B7 TANGUT IDEOGRAPH-#187B7, TGT_MergedSrc=L2008-0334
187B8 TANGUT IDEOGRAPH-#187B8, TGT_MergedSrc=L2008-0519
187B9 TANGUT IDEOGRAPH-#187B9, TGT_MergedSrc=L2008-1156
187BA TANGUT IDEOGRAPH-#187BA, TGT_MergedSrc=L2008-0337
187BB TANGUT IDEOGRAPH-#187BB, TGT_MergedSrc=L2008-1185
187BC TANGUT IDEOGRAPH-#187BC, TGT_MergedSrc=L2008-0003
187BD TANGUT IDEOGRAPH-#187BD, TGT_MergedSrc=L2008-0477
187BE TANGUT IDEOGRAPH-#187BE, TGT_MergedSrc=L2008-1579
187BF TANGUT IDEOGRAPH-#187BF, TGT_MergedSrc=L2008-0476
187C0 TANGUT IDEOGRAPH-#187C0, TGT_MergedSrc=L2008-0046
187C1 TANGUT IDEOGRAPH-#187C1, TGT_MergedSrc=L2008-0210
187C2 TANGUT IDEOGRAPH-#187C2, TGT_MergedSrc=L2008-0508
187C3 TANGUT IDEOGRAPH-#187C3, TGT_MergedSrc=L2008-0118
187C4 TANGUT IDEOGRAPH-#187C4, TGT_MergedSrc=L2008-0597
187C5 TANGUT IDEOGRAPH-#187C5, TGT_MergedSrc=L2008-0063
187C6 TANGUT IDEOGRAPH-#187C6, TGT_MergedSrc=L2008-0782
187C7 TANGUT IDEOGRAPH-#187C7, TGT_MergedSrc=L2008-0002
187C8 TANGUT IDEOGRAPH-#187C8, TGT_MergedSrc=L2008-1581
187C9 TANGUT IDEOGRAPH-#187C9, TGT_MergedSrc=L2008-0741
187CA TANGUT IDEOGRAPH-#187CA, TGT_MergedSrc=L2008-4452
187CB TANGUT IDEOGRAPH-#187CB, TGT_MergedSrc=L2008-0045
187CC TANGUT IDEOGRAPH-#187CC, TGT_MergedSrc=L2008-0512
187CD TANGUT IDEOGRAPH-#187CD, TGT_MergedSrc=L2008-4665
187CE TANGUT IDEOGRAPH-#187CE, TGT_MergedSrc=L2008-4634
187CF TANGUT IDEOGRAPH-#187CF, TGT_MergedSrc=L2008-3883
187D0 TANGUT IDEOGRAPH-#187D0, TGT_MergedSrc=L2008-5495
187D1 TANGUT IDEOGRAPH-#187D1, TGT_MergedSrc=L2008-5493
187D2 TANGUT IDEOGRAPH-#187D2, TGT_MergedSrc=L2008-5494
187D3 TANGUT IDEOGRAPH-#187D3, TGT_MergedSrc=L2008-0583
187D4 TANGUT IDEOGRAPH-#187D4, TGT_MergedSrc=L2008-1035
187D5 TANGUT IDEOGRAPH-#187D5, TGT_MergedSrc=L2008-0763
187D6 TANGUT IDEOGRAPH-#187D6, TGT_MergedSrc=L2008-1031
187D7 TANGUT IDEOGRAPH-#187D7, TGT_MergedSrc=L2008-0039
187D8 TANGUT IDEOGRAPH-#187D8, TGT_MergedSrc=L2008-1041
187D9 TANGUT IDEOGRAPH-#187D9, TGT_MergedSrc=L2008-3830
187DA TANGUT IDEOGRAPH-#187DA, TGT_MergedSrc=L2008-3957
187DB TANGUT IDEOGRAPH-#187DB, TGT_MergedSrc=L2008-4882
187DC TANGUT IDEOGRAPH-#187DC, TGT_MergedSrc=L2008-5437
187DD TANGUT IDEOGRAPH-#187DD, TGT_MergedSrc=L2008-5309
187DE TANGUT IDEOGRAPH-#187DE, TGT_MergedSrc=L2008-5037
187DF TANGUT IDEOGRAPH-#187DF, TGT_MergedSrc=L2008-5778
187E0 TANGUT IDEOGRAPH-#187E0, TGT_MergedSrc=L2008-1338
187E1 TANGUT IDEOGRAPH-#187E1, TGT_MergedSrc=L2008-1265
187E2 TANGUT IDEOGRAPH-#187E2, TGT_MergedSrc=L2008-0373
187E3 TANGUT IDEOGRAPH-#187E3, TGT_MergedSrc=L2008-0930
187E4 TANGUT IDEOGRAPH-#187E4, TGT_MergedSrc=L2008-0487
187E5 TANGUT IDEOGRAPH-#187E5, TGT_MergedSrc=L2008-1888
187E6 TANGUT IDEOGRAPH-#187E6, TGT_MergedSrc=L2008-3301
187E7 TANGUT IDEOGRAPH-#187E7, TGT_MergedSrc=L2008-5794
187E8 TANGUT IDEOGRAPH-#187E8, TGT_MergedSrc=L2008-5787
187E9 TANGUT IDEOGRAPH-#187E9, TGT_MergedSrc=L2008-5779
187EA TANGUT IDEOGRAPH-#187EA, TGT_MergedSrc=L2008-4995
187EB TANGUT IDEOGRAPH-#187EB, TGT_MergedSrc=L2008-5205
187EC TANGUT IDEOGRAPH-#187EC, TGT_MergedSrc=L2008-5203
18800 TANGUT COMPONENT-001
18801 TANGUT COMPONENT-002
18802 TANGUT COMPONENT-003
18803 TANGUT COMPONENT-004
18804 TANGUT COMPONENT-005
18805 TANGUT COMPONENT-006
18806 TANGUT COMPONENT-007
18807 TANGUT COMPONENT-008
18808 TANGUT COMPONENT-009
18809 TANGUT COMPONENT-010
1880A TANGUT COMPONENT-011
1880B TANGUT COMPONENT-012
1880C TANGUT COMPONENT-013
1880D TANGUT COMPONENT-014
1880E TANGUT COMPONENT-015
1880F TANGUT COMPONENT-016
18810 TANGUT COMPONENT-017
18811 TANGUT COMPONENT-018
18812 TANGUT COMPONENT-019
18813 TANGUT COMPONENT-020
18814 TANGUT COMPONENT-021
18815 TANGUT COMPONENT-022
18816 TANGUT COMPONENT-023
18817 TANGUT COMPONENT-024
18818 TANGUT COMPONENT-025
18819 TANGUT COMPONENT-026
1881A TANGUT COMPONENT-027
1881B TANGUT COMPONENT-028
1881C TANGUT COMPONENT-029
1881D TANGUT COMPONENT-030
1881E TANGUT COMPONENT-031
1881F TANGUT COMPONENT-032
18820 TANGUT COMPONENT-033
18821 TANGUT COMPONENT-034
18822 TANGUT COMPONENT-035
18823 TANGUT COMPONENT-036
18824 TANGUT COMPONENT-037
18825 TANGUT COMPONENT-038
18826 TANGUT COMPONENT-039
18827 TANGUT COMPONENT-040
18828 TANGUT COMPONENT-041
18829 TANGUT COMPONENT-042
1882A TANGUT COMPONENT-043
1882B TANGUT COMPONENT-044
1882C TANGUT COMPONENT-045
1882D TANGUT COMPONENT-046
1882E TANGUT COMPONENT-047
1882F TANGUT COMPONENT-048
18830 TANGUT COMPONENT-049
18831 TANGUT COMPONENT-050
18832 TANGUT COMPONENT-051
18833 TANGUT COMPONENT-052
18834 TANGUT COMPONENT-053
18835 TANGUT COMPONENT-054
18836 TANGUT COMPONENT-055
18837 TANGUT COMPONENT-056
18838 TANGUT COMPONENT-057
18839 TANGUT COMPONENT-058
1883A TANGUT COMPONENT-059
1883B TANGUT COMPONENT-060
1883C TANGUT COMPONENT-061
1883D TANGUT COMPONENT-062
1883E TANGUT COMPONENT-063
1883F TANGUT COMPONENT-064
18840 TANGUT COMPONENT-065
18841 TANGUT COMPONENT-066
18842 TANGUT COMPONENT-067
18843 TANGUT COMPONENT-068
18844 TANGUT COMPONENT-069
18845 TANGUT COMPONENT-070
18846 TANGUT COMPONENT-071
18847 TANGUT COMPONENT-072
18848 TANGUT COMPONENT-073
18849 TANGUT COMPONENT-074
1884A TANGUT COMPONENT-075
1884B TANGUT COMPONENT-076
1884C TANGUT COMPONENT-077
1884D TANGUT COMPONENT-078
1884E TANGUT COMPONENT-079
1884F TANGUT COMPONENT-080
18850 TANGUT COMPONENT-081
18851 TANGUT COMPONENT-082
18852 TANGUT COMPONENT-083
18853 TANGUT COMPONENT-084
18854 TANGUT COMPONENT-085
18855 TANGUT COMPONENT-086
18856 TANGUT COMPONENT-087
18857 TANGUT COMPONENT-088
18858 TANGUT COMPONENT-089
18859 TANGUT COMPONENT-090
1885A TANGUT COMPONENT-091
1885B TANGUT COMPONENT-092
1885C TANGUT COMPONENT-093
1885D TANGUT COMPONENT-094
1885E TANGUT COMPONENT-095
1885F TANGUT COMPONENT-096
18860 TANGUT COMPONENT-097
18861 TANGUT COMPONENT-098
18862 TANGUT COMPONENT-099
18863 TANGUT COMPONENT-100
18864 TANGUT COMPONENT-101
18865 TANGUT COMPONENT-102
18866 TANGUT COMPONENT-103
18867 TANGUT COMPONENT-104
18868 TANGUT COMPONENT-105
18869 TANGUT COMPONENT-106
1886A TANGUT COMPONENT-107
1886B TANGUT COMPONENT-108
1886C TANGUT COMPONENT-109
1886D TANGUT COMPONENT-110
1886E TANGUT COMPONENT-111
1886F TANGUT COMPONENT-112
18870 TANGUT COMPONENT-113
18871 TANGUT COMPONENT-114
18872 TANGUT COMPONENT-115
18873 TANGUT COMPONENT-116
18874 TANGUT COMPONENT-117
18875 TANGUT COMPONENT-118
18876 TANGUT COMPONENT-119
18877 TANGUT COMPONENT-120
18878 TANGUT COMPONENT-121
18879 TANGUT COMPONENT-122
1887A TANGUT COMPONENT-123
1887B TANGUT COMPONENT-124
1887C TANGUT COMPONENT-125
1887D TANGUT COMPONENT-126
1887E TANGUT COMPONENT-127
1887F TANGUT COMPONENT-128
18880 TANGUT COMPONENT-129
18881 TANGUT COMPONENT-130
18882 TANGUT COMPONENT-131
18883 TANGUT COMPONENT-132
18884 TANGUT COMPONENT-133
18885 TANGUT COMPONENT-134
18886 TANGUT COMPONENT-135
18887 TANGUT COMPONENT-136
18888 TANGUT COMPONENT-137
18889 TANGUT COMPONENT-138
1888A TANGUT COMPONENT-139
1888B TANGUT COMPONENT-140
1888C TANGUT COMPONENT-141
1888D TANGUT COMPONENT-142
1888E TANGUT COMPONENT-143
1888F TANGUT COMPONENT-144
18890 TANGUT COMPONENT-145
18891 TANGUT COMPONENT-146
18892 TANGUT COMPONENT-147
18893 TANGUT COMPONENT-148
18894 TANGUT COMPONENT-149
18895 TANGUT COMPONENT-150
18896 TANGUT COMPONENT-151
18897 TANGUT COMPONENT-152
18898 TANGUT COMPONENT-153
18899 TANGUT COMPONENT-154
1889A TANGUT COMPONENT-155
1889B TANGUT COMPONENT-156
1889C TANGUT COMPONENT-157
1889D TANGUT COMPONENT-158
1889E TANGUT COMPONENT-159
1889F TANGUT COMPONENT-160
188A0 TANGUT COMPONENT-161
188A1 TANGUT COMPONENT-162
188A2 TANGUT COMPONENT-163
188A3 TANGUT COMPONENT-164
188A4 TANGUT COMPONENT-165
188A5 TANGUT COMPONENT-166
188A6 TANGUT COMPONENT-167
188A7 TANGUT COMPONENT-168
188A8 TANGUT COMPONENT-169
188A9 TANGUT COMPONENT-170
188AA TANGUT COMPONENT-171
188AB TANGUT COMPONENT-172
188AC TANGUT COMPONENT-173
188AD TANGUT COMPONENT-174
188AE TANGUT COMPONENT-175
188AF TANGUT COMPONENT-176
188B0 TANGUT COMPONENT-177
188B1 TANGUT COMPONENT-178
188B2 TANGUT COMPONENT-179
188B3 TANGUT COMPONENT-180
188B4 TANGUT COMPONENT-181
188B5 TANGUT COMPONENT-182
188B6 TANGUT COMPONENT-183
188B7 TANGUT COMPONENT-184
188B8 TANGUT COMPONENT-185
188B9 TANGUT COMPONENT-186
188BA TANGUT COMPONENT-187
188BB TANGUT COMPONENT-188
188BC TANGUT COMPONENT-189
188BD TANGUT COMPONENT-190
188BE TANGUT COMPONENT-191
188BF TANGUT COMPONENT-192
188C0 TANGUT COMPONENT-193
188C1 TANGUT COMPONENT-194
188C2 TANGUT COMPONENT-195
188C3 TANGUT COMPONENT-196
188C4 TANGUT COMPONENT-197
188C5 TANGUT COMPONENT-198
188C6 TANGUT COMPONENT-199
188C7 TANGUT COMPONENT-200
188C8 TANGUT COMPONENT-201
188C9 TANGUT COMPONENT-202
188CA TANGUT COMPONENT-203
188CB TANGUT COMPONENT-204
188CC TANGUT COMPONENT-205
188CD TANGUT COMPONENT-206
188CE TANGUT COMPONENT-207
188CF TANGUT COMPONENT-208
188D0 TANGUT COMPONENT-209
188D1 TANGUT COMPONENT-210
188D2 TANGUT COMPONENT-211
188D3 TANGUT COMPONENT-212
188D4 TANGUT COMPONENT-213
188D5 TANGUT COMPONENT-214
188D6 TANGUT COMPONENT-215
188D7 TANGUT COMPONENT-216
188D8 TANGUT COMPONENT-217
188D9 TANGUT COMPONENT-218
188DA TANGUT COMPONENT-219
188DB TANGUT COMPONENT-220
188DC TANGUT COMPONENT-221
188DD TANGUT COMPONENT-222
188DE TANGUT COMPONENT-223
188DF TANGUT COMPONENT-224
188E0 TANGUT COMPONENT-225
188E1 TANGUT COMPONENT-226
188E2 TANGUT COMPONENT-227
188E3 TANGUT COMPONENT-228
188E4 TANGUT COMPONENT-229
188E5 TANGUT COMPONENT-230
188E6 TANGUT COMPONENT-231
188E7 TANGUT COMPONENT-232
188E8 TANGUT COMPONENT-233
188E9 TANGUT COMPONENT-234
188EA TANGUT COMPONENT-235
188EB TANGUT COMPONENT-236
188EC TANGUT COMPONENT-237
188ED TANGUT COMPONENT-238
188EE TANGUT COMPONENT-239
188EF TANGUT COMPONENT-240
188F0 TANGUT COMPONENT-241
188F1 TANGUT COMPONENT-242
188F2 TANGUT COMPONENT-243
188F3 TANGUT COMPONENT-244
188F4 TANGUT COMPONENT-245
188F5 TANGUT COMPONENT-246
188F6 TANGUT COMPONENT-247
188F7 TANGUT COMPONENT-248
188F8 TANGUT COMPONENT-249
188F9 TANGUT COMPONENT-250
188FA TANGUT COMPONENT-251
188FB TANGUT COMPONENT-252
188FC TANGUT COMPONENT-253
188FD TANGUT COMPONENT-254
188FE TANGUT COMPONENT-255
188FF TANGUT COMPONENT-256
18900 TANGUT COMPONENT-257
18901 TANGUT COMPONENT-258
18902 TANGUT COMPONENT-259
18903 TANGUT COMPONENT-260
18904 TANGUT COMPONENT-261
18905 TANGUT COMPONENT-262
18906 TANGUT COMPONENT-263
18907 TANGUT COMPONENT-264
18908 TANGUT COMPONENT-265
18909 TANGUT COMPONENT-266
1890A TANGUT COMPONENT-267
1890B TANGUT COMPONENT-268
1890C TANGUT COMPONENT-269
1890D TANGUT COMPONENT-270
1890E TANGUT COMPONENT-271
1890F TANGUT COMPONENT-272
18910 TANGUT COMPONENT-273
18911 TANGUT COMPONENT-274
18912 TANGUT COMPONENT-275
18913 TANGUT COMPONENT-276
18914 TANGUT COMPONENT-277
18915 TANGUT COMPONENT-278
18916 TANGUT COMPONENT-279
18917 TANGUT COMPONENT-280
18918 TANGUT COMPONENT-281
18919 TANGUT COMPONENT-282
1891A TANGUT COMPONENT-283
1891B TANGUT COMPONENT-284
1891C TANGUT COMPONENT-285
1891D TANGUT COMPONENT-286
1891E TANGUT COMPONENT-287
1891F TANGUT COMPONENT-288
18920 TANGUT COMPONENT-289
18921 TANGUT COMPONENT-290
18922 TANGUT COMPONENT-291
18923 TANGUT COMPONENT-292
18924 TANGUT COMPONENT-293
18925 TANGUT COMPONENT-294
18926 TANGUT COMPONENT-295
18927 TANGUT COMPONENT-296
18928 TANGUT COMPONENT-297
18929 TANGUT COMPONENT-298
1892A TANGUT COMPONENT-299
1892B TANGUT COMPONENT-300
1892C TANGUT COMPONENT-301
1892D TANGUT COMPONENT-302
1892E TANGUT COMPONENT-303
1892F TANGUT COMPONENT-304
18930 TANGUT COMPONENT-305
18931 TANGUT COMPONENT-306
18932 TANGUT COMPONENT-307
18933 TANGUT COMPONENT-308
18934 TANGUT COMPONENT-309
18935 TANGUT COMPONENT-310
18936 TANGUT COMPONENT-311
18937 TANGUT COMPONENT-312
18938 TANGUT COMPONENT-313
18939 TANGUT COMPONENT-314
1893A TANGUT COMPONENT-315
1893B TANGUT COMPONENT-316
1893C TANGUT COMPONENT-317
1893D TANGUT COMPONENT-318
1893E TANGUT COMPONENT-319
1893F TANGUT COMPONENT-320
18940 TANGUT COMPONENT-321
18941 TANGUT COMPONENT-322
18942 TANGUT COMPONENT-323
18943 TANGUT COMPONENT-324
18944 TANGUT COMPONENT-325
18945 TANGUT COMPONENT-326
18946 TANGUT COMPONENT-327
18947 TANGUT COMPONENT-328
18948 TANGUT COMPONENT-329
18949 TANGUT COMPONENT-330
1894A TANGUT COMPONENT-331
1894B TANGUT COMPONENT-332
1894C TANGUT COMPONENT-333
1894D TANGUT COMPONENT-334
1894E TANGUT COMPONENT-335
1894F TANGUT COMPONENT-336
18950 TANGUT COMPONENT-337
18951 TANGUT COMPONENT-338
18952 TANGUT COMPONENT-339
18953 TANGUT COMPONENT-340
18954 TANGUT COMPONENT-341
18955 TANGUT COMPONENT-342
18956 TANGUT COMPONENT-343
18957 TANGUT COMPONENT-344
18958 TANGUT COMPONENT-345
18959 TANGUT COMPONENT-346
1895A TANGUT COMPONENT-347
1895B TANGUT COMPONENT-348
1895C TANGUT COMPONENT-349
1895D TANGUT COMPONENT-350
1895E TANGUT COMPONENT-351
1895F TANGUT COMPONENT-352
18960 TANGUT COMPONENT-353
18961 TANGUT COMPONENT-354
18962 TANGUT COMPONENT-355
18963 TANGUT COMPONENT-356
18964 TANGUT COMPONENT-357
18965 TANGUT COMPONENT-358
18966 TANGUT COMPONENT-359
18967 TANGUT COMPONENT-360
18968 TANGUT COMPONENT-361
18969 TANGUT COMPONENT-362
1896A TANGUT COMPONENT-363
1896B TANGUT COMPONENT-364
1896C TANGUT COMPONENT-365
1896D TANGUT COMPONENT-366
1896E TANGUT COMPONENT-367
1896F TANGUT COMPONENT-368
18970 TANGUT COMPONENT-369
18971 TANGUT COMPONENT-370
18972 TANGUT COMPONENT-371
18973 TANGUT COMPONENT-372
18974 TANGUT COMPONENT-373
18975 TANGUT COMPONENT-374
18976 TANGUT COMPONENT-375
18977 TANGUT COMPONENT-376
18978 TANGUT COMPONENT-377
18979 TANGUT COMPONENT-378
1897A TANGUT COMPONENT-379
1897B TANGUT COMPONENT-380
1897C TANGUT COMPONENT-381
1897D TANGUT COMPONENT-382
1897E TANGUT COMPONENT-383
1897F TANGUT COMPONENT-384
18980 TANGUT COMPONENT-385
18981 TANGUT COMPONENT-386
18982 TANGUT COMPONENT-387
18983 TANGUT COMPONENT-388
18984 TANGUT COMPONENT-389
18985 TANGUT COMPONENT-390
18986 TANGUT COMPONENT-391
18987 TANGUT COMPONENT-392
18988 TANGUT COMPONENT-393
18989 TANGUT COMPONENT-394
1898A TANGUT COMPONENT-395
1898B TANGUT COMPONENT-396
1898C TANGUT COMPONENT-397
1898D TANGUT COMPONENT-398
1898E TANGUT COMPONENT-399
1898F TANGUT COMPONENT-400
18990 TANGUT COMPONENT-401
18991 TANGUT COMPONENT-402
18992 TANGUT COMPONENT-403
18993 TANGUT COMPONENT-404
18994 TANGUT COMPONENT-405
18995 TANGUT COMPONENT-406
18996 TANGUT COMPONENT-407
18997 TANGUT COMPONENT-408
18998 TANGUT COMPONENT-409
18999 TANGUT COMPONENT-410
1899A TANGUT COMPONENT-411
1899B TANGUT COMPONENT-412
1899C TANGUT COMPONENT-413
1899D TANGUT COMPONENT-414
1899E TANGUT COMPONENT-415
1899F TANGUT COMPONENT-416
189A0 TANGUT COMPONENT-417
189A1 TANGUT COMPONENT-418
189A2 TANGUT COMPONENT-419
189A3 TANGUT COMPONENT-420
189A4 TANGUT COMPONENT-421
189A5 TANGUT COMPONENT-422
189A6 TANGUT COMPONENT-423
189A7 TANGUT COMPONENT-424
189A8 TANGUT COMPONENT-425
189A9 TANGUT COMPONENT-426
189AA TANGUT COMPONENT-427
189AB TANGUT COMPONENT-428
189AC TANGUT COMPONENT-429
189AD TANGUT COMPONENT-430
189AE TANGUT COMPONENT-431
189AF TANGUT COMPONENT-432
189B0 TANGUT COMPONENT-433
189B1 TANGUT COMPONENT-434
189B2 TANGUT COMPONENT-435
189B3 TANGUT COMPONENT-436
189B4 TANGUT COMPONENT-437
189B5 TANGUT COMPONENT-438
189B6 TANGUT COMPONENT-439
189B7 TANGUT COMPONENT-440
189B8 TANGUT COMPONENT-441
189B9 TANGUT COMPONENT-442
189BA TANGUT COMPONENT-443
189BB TANGUT COMPONENT-444
189BC TANGUT COMPONENT-445
189BD TANGUT COMPONENT-446
189BE TANGUT COMPONENT-447
189BF TANGUT COMPONENT-448
189C0 TANGUT COMPONENT-449
189C1 TANGUT COMPONENT-450
189C2 TANGUT COMPONENT-451
189C3 TANGUT COMPONENT-452
189C4 TANGUT COMPONENT-453
189C5 TANGUT COMPONENT-454
189C6 TANGUT COMPONENT-455
189C7 TANGUT COMPONENT-456
189C8 TANGUT COMPONENT-457
189C9 TANGUT COMPONENT-458
189CA TANGUT COMPONENT-459
189CB TANGUT COMPONENT-460
189CC TANGUT COMPONENT-461
189CD TANGUT COMPONENT-462
189CE TANGUT COMPONENT-463
189CF TANGUT COMPONENT-464
189D0 TANGUT COMPONENT-465
189D1 TANGUT COMPONENT-466
189D2 TANGUT COMPONENT-467
189D3 TANGUT COMPONENT-468
189D4 TANGUT COMPONENT-469
189D5 TANGUT COMPONENT-470
189D6 TANGUT COMPONENT-471
189D7 TANGUT COMPONENT-472
189D8 TANGUT COMPONENT-473
189D9 TANGUT COMPONENT-474
189DA TANGUT COMPONENT-475
189DB TANGUT COMPONENT-476
189DC TANGUT COMPONENT-477
189DD TANGUT COMPONENT-478
189DE TANGUT COMPONENT-479
189DF TANGUT COMPONENT-480
189E0 TANGUT COMPONENT-481
189E1 TANGUT COMPONENT-482
189E2 TANGUT COMPONENT-483
189E3 TANGUT COMPONENT-484
189E4 TANGUT COMPONENT-485
189E5 TANGUT COMPONENT-486
189E6 TANGUT COMPONENT-487
189E7 TANGUT COMPONENT-488
189E8 TANGUT COMPONENT-489
189E9 TANGUT COMPONENT-490
189EA TANGUT COMPONENT-491
189EB TANGUT COMPONENT-492
189EC TANGUT COMPONENT-493
189ED TANGUT COMPONENT-494
189EE TANGUT COMPONENT-495
189EF TANGUT COMPONENT-496
189F0 TANGUT COMPONENT-497
189F1 TANGUT COMPONENT-498
189F2 TANGUT COMPONENT-499
189F3 TANGUT COMPONENT-500
189F4 TANGUT COMPONENT-501
189F5 TANGUT COMPONENT-502
189F6 TANGUT COMPONENT-503
189F7 TANGUT COMPONENT-504
189F8 TANGUT COMPONENT-505
189F9 TANGUT COMPONENT-506
189FA TANGUT COMPONENT-507
189FB TANGUT COMPONENT-508
189FC TANGUT COMPONENT-509
189FD TANGUT COMPONENT-510
189FE TANGUT COMPONENT-511
189FF TANGUT COMPONENT-512
18A00 TANGUT COMPONENT-513
18A01 TANGUT COMPONENT-514
18A02 TANGUT COMPONENT-515
18A03 TANGUT COMPONENT-516
18A04 TANGUT COMPONENT-517
18A05 TANGUT COMPONENT-518
18A06 TANGUT COMPONENT-519
18A07 TANGUT COMPONENT-520
18A08 TANGUT COMPONENT-521
18A09 TANGUT COMPONENT-522
18A0A TANGUT COMPONENT-523
18A0B TANGUT COMPONENT-524
18A0C TANGUT COMPONENT-525
18A0D TANGUT COMPONENT-526
18A0E TANGUT COMPONENT-527
18A0F TANGUT COMPONENT-528
18A10 TANGUT COMPONENT-529
18A11 TANGUT COMPONENT-530
18A12 TANGUT COMPONENT-531
18A13 TANGUT COMPONENT-532
18A14 TANGUT COMPONENT-533
18A15 TANGUT COMPONENT-534
18A16 TANGUT COMPONENT-535
18A17 TANGUT COMPONENT-536
18A18 TANGUT COMPONENT-537
18A19 TANGUT COMPONENT-538
18A1A TANGUT COMPONENT-539
18A1B TANGUT COMPONENT-540
18A1C TANGUT COMPONENT-541
18A1D TANGUT COMPONENT-542
18A1E TANGUT COMPONENT-543
18A1F TANGUT COMPONENT-544
18A20 TANGUT COMPONENT-545
18A21 TANGUT COMPONENT-546
18A22 TANGUT COMPONENT-547
18A23 TANGUT COMPONENT-548
18A24 TANGUT COMPONENT-549
18A25 TANGUT COMPONENT-550
18A26 TANGUT COMPONENT-551
18A27 TANGUT COMPONENT-552
18A28 TANGUT COMPONENT-553
18A29 TANGUT COMPONENT-554
18A2A TANGUT COMPONENT-555
18A2B TANGUT COMPONENT-556
18A2C TANGUT COMPONENT-557
18A2D TANGUT COMPONENT-558
18A2E TANGUT COMPONENT-559
18A2F TANGUT COMPONENT-560
18A30 TANGUT COMPONENT-561
18A31 TANGUT COMPONENT-562
18A32 TANGUT COMPONENT-563
18A33 TANGUT COMPONENT-564
18A34 TANGUT COMPONENT-565
18A35 TANGUT COMPONENT-566
18A36 TANGUT COMPONENT-567
18A37 TANGUT COMPONENT-568
18A38 TANGUT COMPONENT-569
18A39 TANGUT COMPONENT-570
18A3A TANGUT COMPONENT-571
18A3B TANGUT COMPONENT-572
18A3C TANGUT COMPONENT-573
18A3D TANGUT COMPONENT-574
18A3E TANGUT COMPONENT-575
18A3F TANGUT COMPONENT-576
18A40 TANGUT COMPONENT-577
18A41 TANGUT COMPONENT-578
18A42 TANGUT COMPONENT-579
18A43 TANGUT COMPONENT-580
18A44 TANGUT COMPONENT-581
18A45 TANGUT COMPONENT-582
18A46 TANGUT COMPONENT-583
18A47 TANGUT COMPONENT-584
18A48 TANGUT COMPONENT-585
18A49 TANGUT COMPONENT-586
18A4A TANGUT COMPONENT-587
18A4B TANGUT COMPONENT-588
18A4C TANGUT COMPONENT-589
18A4D TANGUT COMPONENT-590
18A4E TANGUT COMPONENT-591
18A4F TANGUT COMPONENT-592
18A50 TANGUT COMPONENT-593
18A51 TANGUT COMPONENT-594
18A52 TANGUT COMPONENT-595
18A53 TANGUT COMPONENT-596
18A54 TANGUT COMPONENT-597
18A55 TANGUT COMPONENT-598
18A56 TANGUT COMPONENT-599
18A57 TANGUT COMPONENT-600
18A58 TANGUT COMPONENT-601
18A59 TANGUT COMPONENT-602
18A5A TANGUT COMPONENT-603
18A5B TANGUT COMPONENT-604
18A5C TANGUT COMPONENT-605
18A5D TANGUT COMPONENT-606
18A5E TANGUT COMPONENT-607
18A5F TANGUT COMPONENT-608
18A60 TANGUT COMPONENT-609
18A61 TANGUT COMPONENT-610
18A62 TANGUT COMPONENT-611
18A63 TANGUT COMPONENT-612
18A64 TANGUT COMPONENT-613
18A65 TANGUT COMPONENT-614
18A66 TANGUT COMPONENT-615
18A67 TANGUT COMPONENT-616
18A68 TANGUT COMPONENT-617
18A69 TANGUT COMPONENT-618
18A6A TANGUT COMPONENT-619
18A6B TANGUT COMPONENT-620
18A6C TANGUT COMPONENT-621
18A6D TANGUT COMPONENT-622
18A6E TANGUT COMPONENT-623
18A6F TANGUT COMPONENT-624
18A70 TANGUT COMPONENT-625
18A71 TANGUT COMPONENT-626
18A72 TANGUT COMPONENT-627
18A73 TANGUT COMPONENT-628
18A74 TANGUT COMPONENT-629
18A75 TANGUT COMPONENT-630
18A76 TANGUT COMPONENT-631
18A77 TANGUT COMPONENT-632
18A78 TANGUT COMPONENT-633
18A79 TANGUT COMPONENT-634
18A7A TANGUT COMPONENT-635
18A7B TANGUT COMPONENT-636
18A7C TANGUT COMPONENT-637
18A7D TANGUT COMPONENT-638
18A7E TANGUT COMPONENT-639
18A7F TANGUT COMPONENT-640
18A80 TANGUT COMPONENT-641
18A81 TANGUT COMPONENT-642
18A82 TANGUT COMPONENT-643
18A83 TANGUT COMPONENT-644
18A84 TANGUT COMPONENT-645
18A85 TANGUT COMPONENT-646
18A86 TANGUT COMPONENT-647
18A87 TANGUT COMPONENT-648
18A88 TANGUT COMPONENT-649
18A89 TANGUT COMPONENT-650
18A8A TANGUT COMPONENT-651
18A8B TANGUT COMPONENT-652
18A8C TANGUT COMPONENT-653
18A8D TANGUT COMPONENT-654
18A8E TANGUT COMPONENT-655
18A8F TANGUT COMPONENT-656
18A90 TANGUT COMPONENT-657
18A91 TANGUT COMPONENT-658
18A92 TANGUT COMPONENT-659
18A93 TANGUT COMPONENT-660
18A94 TANGUT COMPONENT-661
18A95 TANGUT COMPONENT-662
18A96 TANGUT COMPONENT-663
18A97 TANGUT COMPONENT-664
18A98 TANGUT COMPONENT-665
18A99 TANGUT COMPONENT-666
18A9A TANGUT COMPONENT-667
18A9B TANGUT COMPONENT-668
18A9C TANGUT COMPONENT-669
18A9D TANGUT COMPONENT-670
18A9E TANGUT COMPONENT-671
18A9F TANGUT COMPONENT-672
18AA0 TANGUT COMPONENT-673
18AA1 TANGUT COMPONENT-674
18AA2 TANGUT COMPONENT-675
18AA3 TANGUT COMPONENT-676
18AA4 TANGUT COMPONENT-677
18AA5 TANGUT COMPONENT-678
18AA6 TANGUT COMPONENT-679
18AA7 TANGUT COMPONENT-680
18AA8 TANGUT COMPONENT-681
18AA9 TANGUT COMPONENT-682
18AAA TANGUT COMPONENT-683
18AAB TANGUT COMPONENT-684
18AAC TANGUT COMPONENT-685
18AAD TANGUT COMPONENT-686
18AAE TANGUT COMPONENT-687
18AAF TANGUT COMPONENT-688
18AB0 TANGUT COMPONENT-689
18AB1 TANGUT COMPONENT-690
18AB2 TANGUT COMPONENT-691
18AB3 TANGUT COMPONENT-692
18AB4 TANGUT COMPONENT-693
18AB5 TANGUT COMPONENT-694
18AB6 TANGUT COMPONENT-695
18AB7 TANGUT COMPONENT-696
18AB8 TANGUT COMPONENT-697
18AB9 TANGUT COMPONENT-698
18ABA TANGUT COMPONENT-699
18ABB TANGUT COMPONENT-700
18ABC TANGUT COMPONENT-701
18ABD TANGUT COMPONENT-702
18ABE TANGUT COMPONENT-703
18ABF TANGUT COMPONENT-704
18AC0 TANGUT COMPONENT-705
18AC1 TANGUT COMPONENT-706
18AC2 TANGUT COMPONENT-707
18AC3 TANGUT COMPONENT-708
18AC4 TANGUT COMPONENT-709
18AC5 TANGUT COMPONENT-710
18AC6 TANGUT COMPONENT-711
18AC7 TANGUT COMPONENT-712
18AC8 TANGUT COMPONENT-713
18AC9 TANGUT COMPONENT-714
18ACA TANGUT COMPONENT-715
18ACB TANGUT COMPONENT-716
18ACC TANGUT COMPONENT-717
18ACD TANGUT COMPONENT-718
18ACE TANGUT COMPONENT-719
18ACF TANGUT COMPONENT-720
18AD0 TANGUT COMPONENT-721
18AD1 TANGUT COMPONENT-722
18AD2 TANGUT COMPONENT-723
18AD3 TANGUT COMPONENT-724
18AD4 TANGUT COMPONENT-725
18AD5 TANGUT COMPONENT-726
18AD6 TANGUT COMPONENT-727
18AD7 TANGUT COMPONENT-728
18AD8 TANGUT COMPONENT-729
18AD9 TANGUT COMPONENT-730
18ADA TANGUT COMPONENT-731
18ADB TANGUT COMPONENT-732
18ADC TANGUT COMPONENT-733
18ADD TANGUT COMPONENT-734
18ADE TANGUT COMPONENT-735
18ADF TANGUT COMPONENT-736
18AE0 TANGUT COMPONENT-737
18AE1 TANGUT COMPONENT-738
18AE2 TANGUT COMPONENT-739
18AE3 TANGUT COMPONENT-740
18AE4 TANGUT COMPONENT-741
18AE5 TANGUT COMPONENT-742
18AE6 TANGUT COMPONENT-743
18AE7 TANGUT COMPONENT-744
18AE8 TANGUT COMPONENT-745
18AE9 TANGUT COMPONENT-746
18AEA TANGUT COMPONENT-747
18AEB TANGUT COMPONENT-748
18AEC TANGUT COMPONENT-749
18AED TANGUT COMPONENT-750
18AEE TANGUT COMPONENT-751
18AEF TANGUT COMPONENT-752
18AF0 TANGUT COMPONENT-753
18AF1 TANGUT COMPONENT-754
18AF2 TANGUT COMPONENT-755
1B000 KATAKANA LETTER ARCHAIC E
1B001 HIRAGANA LETTER ARCHAIC YE
1B002 HENTAIGANA LETTER A-1
1B003 HENTAIGANA LETTER A-2
1B004 HENTAIGANA LETTER A-3
1B005 HENTAIGANA LETTER A-WO
1B006 HENTAIGANA LETTER I-1
1B007 HENTAIGANA LETTER I-2
1B008 HENTAIGANA LETTER I-3
1B009 HENTAIGANA LETTER I-4
1B00A HENTAIGANA LETTER U-1
1B00B HENTAIGANA LETTER U-2
1B00C HENTAIGANA LETTER U-3
1B00D HENTAIGANA LETTER U-4
1B00E HENTAIGANA LETTER U-5
1B00F HENTAIGANA LETTER E-2
1B010 HENTAIGANA LETTER E-3
1B011 HENTAIGANA LETTER E-4
1B012 HENTAIGANA LETTER E-5
1B013 HENTAIGANA LETTER E-6
1B014 HENTAIGANA LETTER O-1
1B015 HENTAIGANA LETTER O-2
1B016 HENTAIGANA LETTER O-3
1B017 HENTAIGANA LETTER KA-1
1B018 HENTAIGANA LETTER KA-2
1B019 HENTAIGANA LETTER KA-3
1B01A HENTAIGANA LETTER KA-4
1B01B HENTAIGANA LETTER KA-5
1B01C HENTAIGANA LETTER KA-6
1B01D HENTAIGANA LETTER KA-7
1B01E HENTAIGANA LETTER KA-8
1B01F HENTAIGANA LETTER KA-9
1B020 HENTAIGANA LETTER KA-10
1B021 HENTAIGANA LETTER KA-11
1B022 HENTAIGANA LETTER KA-KE
1B023 HENTAIGANA LETTER KI-1
1B024 HENTAIGANA LETTER KI-2
1B025 HENTAIGANA LETTER KI-3
1B026 HENTAIGANA LETTER KI-4
1B027 HENTAIGANA LETTER KI-5
1B028 HENTAIGANA LETTER KI-6
1B029 HENTAIGANA LETTER KI-7
1B02A HENTAIGANA LETTER KI-8
1B02B HENTAIGANA LETTER KU-1
1B02C HENTAIGANA LETTER KU-2
1B02D HENTAIGANA LETTER KU-3
1B02E HENTAIGANA LETTER KU-4
1B02F HENTAIGANA LETTER KU-5
1B030 HENTAIGANA LETTER KU-6
1B031 HENTAIGANA LETTER KU-7
1B032 HENTAIGANA LETTER KE-1
1B033 HENTAIGANA LETTER KE-2
1B034 HENTAIGANA LETTER KE-3
1B035 HENTAIGANA LETTER KE-4
1B036 HENTAIGANA LETTER KE-5
1B037 HENTAIGANA LETTER KE-6
1B038 HENTAIGANA LETTER KO-1
1B039 HENTAIGANA LETTER KO-2
1B03A HENTAIGANA LETTER KO-3
1B03B HENTAIGANA LETTER KO-KI
1B03C HENTAIGANA LETTER SA-1
1B03D HENTAIGANA LETTER SA-2
1B03E HENTAIGANA LETTER SA-3
1B03F HENTAIGANA LETTER SA-4
1B040 HENTAIGANA LETTER SA-5
1B041 HENTAIGANA LETTER SA-6
1B042 HENTAIGANA LETTER SA-7
1B043 HENTAIGANA LETTER SA-8
1B044 HENTAIGANA LETTER SI-1
1B045 HENTAIGANA LETTER SI-2
1B046 HENTAIGANA LETTER SI-3
1B047 HENTAIGANA LETTER SI-4
1B048 HENTAIGANA LETTER SI-5
1B049 HENTAIGANA LETTER SI-6
1B04A HENTAIGANA LETTER SU-1
1B04B HENTAIGANA LETTER SU-2
1B04C HENTAIGANA LETTER SU-3
1B04D HENTAIGANA LETTER SU-4
1B04E HENTAIGANA LETTER SU-5
1B04F HENTAIGANA LETTER SU-6
1B050 HENTAIGANA LETTER SU-7
1B051 HENTAIGANA LETTER SU-8
1B052 HENTAIGANA LETTER SE-1
1B053 HENTAIGANA LETTER SE-2
1B054 HENTAIGANA LETTER SE-3
1B055 HENTAIGANA LETTER SE-4
1B056 HENTAIGANA LETTER SE-5
1B057 HENTAIGANA LETTER SO-1
1B058 HENTAIGANA LETTER SO-2
1B059 HENTAIGANA LETTER SO-3
1B05A HENTAIGANA LETTER SO-4
1B05B HENTAIGANA LETTER SO-5
1B05C HENTAIGANA LETTER SO-6
1B05D HENTAIGANA LETTER SO-7
1B05E HENTAIGANA LETTER TA-1
1B05F HENTAIGANA LETTER TA-2
1B060 HENTAIGANA LETTER TA-3
1B061 HENTAIGANA LETTER TA-4
1B062 HENTAIGANA LETTER TI-1
1B063 HENTAIGANA LETTER TI-2
1B064 HENTAIGANA LETTER TI-3
1B065 HENTAIGANA LETTER TI-4
1B066 HENTAIGANA LETTER TI-5
1B067 HENTAIGANA LETTER TI-6
1B068 HENTAIGANA LETTER TI-7
1B069 HENTAIGANA LETTER TU-1
1B06A HENTAIGANA LETTER TU-2
1B06B HENTAIGANA LETTER TU-3
1B06C HENTAIGANA LETTER TU-4
1B06D HENTAIGANA LETTER TU-TO
1B06E HENTAIGANA LETTER TE-1
1B06F HENTAIGANA LETTER TE-2
1B070 HENTAIGANA LETTER TE-3
1B071 HENTAIGANA LETTER TE-4
1B072 HENTAIGANA LETTER TE-5
1B073 HENTAIGANA LETTER TE-6
1B074 HENTAIGANA LETTER TE-7
1B075 HENTAIGANA LETTER TE-8
1B076 HENTAIGANA LETTER TE-9
1B077 HENTAIGANA LETTER TO-1
1B078 HENTAIGANA LETTER TO-2
1B079 HENTAIGANA LETTER TO-3
1B07A HENTAIGANA LETTER TO-4
1B07B HENTAIGANA LETTER TO-5
1B07C HENTAIGANA LETTER TO-6
1B07D HENTAIGANA LETTER TO-RA
1B07E HENTAIGANA LETTER NA-1
1B07F HENTAIGANA LETTER NA-2
1B080 HENTAIGANA LETTER NA-3
1B081 HENTAIGANA LETTER NA-4
1B082 HENTAIGANA LETTER NA-5
1B083 HENTAIGANA LETTER NA-6
1B084 HENTAIGANA LETTER NA-7
1B085 HENTAIGANA LETTER NA-8
1B086 HENTAIGANA LETTER NA-9
1B087 HENTAIGANA LETTER NI-1
1B088 HENTAIGANA LETTER NI-2
1B089 HENTAIGANA LETTER NI-3
1B08A HENTAIGANA LETTER NI-4
1B08B HENTAIGANA LETTER NI-5
1B08C HENTAIGANA LETTER NI-6
1B08D HENTAIGANA LETTER NI-7
1B08E HENTAIGANA LETTER NI-TE
1B08F HENTAIGANA LETTER NU-1
1B090 HENTAIGANA LETTER NU-2
1B091 HENTAIGANA LETTER NU-3
1B092 HENTAIGANA LETTER NE-1
1B093 HENTAIGANA LETTER NE-2
1B094 HENTAIGANA LETTER NE-3
1B095 HENTAIGANA LETTER NE-4
1B096 HENTAIGANA LETTER NE-5
1B097 HENTAIGANA LETTER NE-6
1B098 HENTAIGANA LETTER NE-KO
1B099 HENTAIGANA LETTER NO-1
1B09A HENTAIGANA LETTER NO-2
1B09B HENTAIGANA LETTER NO-3
1B09C HENTAIGANA LETTER NO-4
1B09D HENTAIGANA LETTER NO-5
1B09E HENTAIGANA LETTER HA-1
1B09F HENTAIGANA LETTER HA-2
1B0A0 HENTAIGANA LETTER HA-3
1B0A1 HENTAIGANA LETTER HA-4
1B0A2 HENTAIGANA LETTER HA-5
1B0A3 HENTAIGANA LETTER HA-6
1B0A4 HENTAIGANA LETTER HA-7
1B0A5 HENTAIGANA LETTER HA-8
1B0A6 HENTAIGANA LETTER HA-9
1B0A7 HENTAIGANA LETTER HA-10
1B0A8 HENTAIGANA LETTER HA-11
1B0A9 HENTAIGANA LETTER HI-1
1B0AA HENTAIGANA LETTER HI-2
1B0AB HENTAIGANA LETTER HI-3
1B0AC HENTAIGANA LETTER HI-4
1B0AD HENTAIGANA LETTER HI-5
1B0AE HENTAIGANA LETTER HI-6
1B0AF HENTAIGANA LETTER HI-7
1B0B0 HENTAIGANA LETTER HU-1
1B0B1 HENTAIGANA LETTER HU-2
1B0B2 HENTAIGANA LETTER HU-3
1B0B3 HENTAIGANA LETTER HE-1
1B0B4 HENTAIGANA LETTER HE-2
1B0B5 HENTAIGANA LETTER HE-3
1B0B6 HENTAIGANA LETTER HE-4
1B0B7 HENTAIGANA LETTER HE-5
1B0B8 HENTAIGANA LETTER HE-6
1B0B9 HENTAIGANA LETTER HE-7
1B0BA HENTAIGANA LETTER HO-1
1B0BB HENTAIGANA LETTER HO-2
1B0BC HENTAIGANA LETTER HO-3
1B0BD HENTAIGANA LETTER HO-4
1B0BE HENTAIGANA LETTER HO-5
1B0BF HENTAIGANA LETTER HO-6
1B0C0 HENTAIGANA LETTER HO-7
1B0C1 HENTAIGANA LETTER HO-8
1B0C2 HENTAIGANA LETTER MA-1
1B0C3 HENTAIGANA LETTER MA-2
1B0C4 HENTAIGANA LETTER MA-3
1B0C5 HENTAIGANA LETTER MA-4
1B0C6 HENTAIGANA LETTER MA-5
1B0C7 HENTAIGANA LETTER MA-6
1B0C8 HENTAIGANA LETTER MA-7
1B0C9 HENTAIGANA LETTER MI-1
1B0CA HENTAIGANA LETTER MI-2
1B0CB HENTAIGANA LETTER MI-3
1B0CC HENTAIGANA LETTER MI-4
1B0CD HENTAIGANA LETTER MI-5
1B0CE HENTAIGANA LETTER MI-6
1B0CF HENTAIGANA LETTER MI-7
1B0D0 HENTAIGANA LETTER MU-1
1B0D1 HENTAIGANA LETTER MU-2
1B0D2 HENTAIGANA LETTER MU-3
1B0D3 HENTAIGANA LETTER MU-4
1B0D4 HENTAIGANA LETTER ME-1
1B0D5 HENTAIGANA LETTER ME-2
1B0D6 HENTAIGANA LETTER ME-MA
1B0D7 HENTAIGANA LETTER MO-1
1B0D8 HENTAIGANA LETTER MO-2
1B0D9 HENTAIGANA LETTER MO-3
1B0DA HENTAIGANA LETTER MO-4
1B0DB HENTAIGANA LETTER MO-5
1B0DC HENTAIGANA LETTER MO-6
1B0DD HENTAIGANA LETTER YA-1
1B0DE HENTAIGANA LETTER YA-2
1B0DF HENTAIGANA LETTER YA-3
1B0E0 HENTAIGANA LETTER YA-4
1B0E1 HENTAIGANA LETTER YA-5
1B0E2 HENTAIGANA LETTER YA-YO
1B0E3 HENTAIGANA LETTER YU-1
1B0E4 HENTAIGANA LETTER YU-2
1B0E5 HENTAIGANA LETTER YU-3
1B0E6 HENTAIGANA LETTER YU-4
1B0E7 HENTAIGANA LETTER YO-1
1B0E8 HENTAIGANA LETTER YO-2
1B0E9 HENTAIGANA LETTER YO-3
1B0EA HENTAIGANA LETTER YO-4
1B0EB HENTAIGANA LETTER YO-5
1B0EC HENTAIGANA LETTER YO-6
1B0ED HENTAIGANA LETTER RA-1
1B0EE HENTAIGANA LETTER RA-2
1B0EF HENTAIGANA LETTER RA-3
1B0F0 HENTAIGANA LETTER RA-4
1B0F1 HENTAIGANA LETTER RI-1
1B0F2 HENTAIGANA LETTER RI-2
1B0F3 HENTAIGANA LETTER RI-3
1B0F4 HENTAIGANA LETTER RI-4
1B0F5 HENTAIGANA LETTER RI-5
1B0F6 HENTAIGANA LETTER RI-6
1B0F7 HENTAIGANA LETTER RI-7
1B0F8 HENTAIGANA LETTER RU-1
1B0F9 HENTAIGANA LETTER RU-2
1B0FA HENTAIGANA LETTER RU-3
1B0FB HENTAIGANA LETTER RU-4
1B0FC HENTAIGANA LETTER RU-5
1B0FD HENTAIGANA LETTER RU-6
1B0FE HENTAIGANA LETTER RE-1
1B0FF HENTAIGANA LETTER RE-2
1B100 HENTAIGANA LETTER RE-3
1B101 HENTAIGANA LETTER RE-4
1B102 HENTAIGANA LETTER RO-1
1B103 HENTAIGANA LETTER RO-2
1B104 HENTAIGANA LETTER RO-3
1B105 HENTAIGANA LETTER RO-4
1B106 HENTAIGANA LETTER RO-5
1B107 HENTAIGANA LETTER RO-6
1B108 HENTAIGANA LETTER WA-1
1B109 HENTAIGANA LETTER WA-2
1B10A HENTAIGANA LETTER WA-3
1B10B HENTAIGANA LETTER WA-4
1B10C HENTAIGANA LETTER WA-5
1B10D HENTAIGANA LETTER WI-1
1B10E HENTAIGANA LETTER WI-2
1B10F HENTAIGANA LETTER WI-3
1B110 HENTAIGANA LETTER WI-4
1B111 HENTAIGANA LETTER WI-5
1B112 HENTAIGANA LETTER WE-1
1B113 HENTAIGANA LETTER WE-2
1B114 HENTAIGANA LETTER WE-3
1B115 HENTAIGANA LETTER WE-4
1B116 HENTAIGANA LETTER WO-1
1B117 HENTAIGANA LETTER WO-2
1B118 HENTAIGANA LETTER WO-3
1B119 HENTAIGANA LETTER WO-4
1B11A HENTAIGANA LETTER WO-5
1B11B HENTAIGANA LETTER WO-6
1B11C HENTAIGANA LETTER WO-7
1B11D HENTAIGANA LETTER N-MU-MO-1
1B11E HENTAIGANA LETTER N-MU-MO-2
1B170 NUSHU CHARACTER-#1B170
1B171 NUSHU CHARACTER-#1B171
1B172 NUSHU CHARACTER-#1B172
1B173 NUSHU CHARACTER-#1B173
1B174 NUSHU CHARACTER-#1B174
1B175 NUSHU CHARACTER-#1B175
1B176 NUSHU CHARACTER-#1B176
1B177 NUSHU CHARACTER-#1B177
1B178 NUSHU CHARACTER-#1B178
1B179 NUSHU CHARACTER-#1B179
1B17A NUSHU CHARACTER-#1B17A
1B17B NUSHU CHARACTER-#1B17B
1B17C NUSHU CHARACTER-#1B17C
1B17D NUSHU CHARACTER-#1B17D
1B17E NUSHU CHARACTER-#1B17E
1B17F NUSHU CHARACTER-#1B17F
1B180 NUSHU CHARACTER-#1B180
1B181 NUSHU CHARACTER-#1B181
1B182 NUSHU CHARACTER-#1B182
1B183 NUSHU CHARACTER-#1B183
1B184 NUSHU CHARACTER-#1B184
1B185 NUSHU CHARACTER-#1B185
1B186 NUSHU CHARACTER-#1B186
1B187 NUSHU CHARACTER-#1B187
1B188 NUSHU CHARACTER-#1B188
1B189 NUSHU CHARACTER-#1B189
1B18A NUSHU CHARACTER-#1B18A
1B18B NUSHU CHARACTER-#1B18B
1B18C NUSHU CHARACTER-#1B18C
1B18D NUSHU CHARACTER-#1B18D
1B18E NUSHU CHARACTER-#1B18E
1B18F NUSHU CHARACTER-#1B18F
1B190 NUSHU CHARACTER-#1B190
1B191 NUSHU CHARACTER-#1B191
1B192 NUSHU CHARACTER-#1B192
1B193 NUSHU CHARACTER-#1B193
1B194 NUSHU CHARACTER-#1B194
1B195 NUSHU CHARACTER-#1B195
1B196 NUSHU CHARACTER-#1B196
1B197 NUSHU CHARACTER-#1B197
1B198 NUSHU CHARACTER-#1B198
1B199 NUSHU CHARACTER-#1B199
1B19A NUSHU CHARACTER-#1B19A
1B19B NUSHU CHARACTER-#1B19B
1B19C NUSHU CHARACTER-#1B19C
1B19D NUSHU CHARACTER-#1B19D
1B19E NUSHU CHARACTER-#1B19E
1B19F NUSHU CHARACTER-#1B19F
1B1A0 NUSHU CHARACTER-#1B1A0
1B1A1 NUSHU CHARACTER-#1B1A1
1B1A2 NUSHU CHARACTER-#1B1A2
1B1A3 NUSHU CHARACTER-#1B1A3
1B1A4 NUSHU CHARACTER-#1B1A4
1B1A5 NUSHU CHARACTER-#1B1A5
1B1A6 NUSHU CHARACTER-#1B1A6
1B1A7 NUSHU CHARACTER-#1B1A7
1B1A8 NUSHU CHARACTER-#1B1A8
1B1A9 NUSHU CHARACTER-#1B1A9
1B1AA NUSHU CHARACTER-#1B1AA
1B1AB NUSHU CHARACTER-#1B1AB
1B1AC NUSHU CHARACTER-#1B1AC
1B1AD NUSHU CHARACTER-#1B1AD
1B1AE NUSHU CHARACTER-#1B1AE
1B1AF NUSHU CHARACTER-#1B1AF
1B1B0 NUSHU CHARACTER-#1B1B0
1B1B1 NUSHU CHARACTER-#1B1B1
1B1B2 NUSHU CHARACTER-#1B1B2
1B1B3 NUSHU CHARACTER-#1B1B3
1B1B4 NUSHU CHARACTER-#1B1B4
1B1B5 NUSHU CHARACTER-#1B1B5
1B1B6 NUSHU CHARACTER-#1B1B6
1B1B7 NUSHU CHARACTER-#1B1B7
1B1B8 NUSHU CHARACTER-#1B1B8
1B1B9 NUSHU CHARACTER-#1B1B9
1B1BA NUSHU CHARACTER-#1B1BA
1B1BB NUSHU CHARACTER-#1B1BB
1B1BC NUSHU CHARACTER-#1B1BC
1B1BD NUSHU CHARACTER-#1B1BD
1B1BE NUSHU CHARACTER-#1B1BE
1B1BF NUSHU CHARACTER-#1B1BF
1B1C0 NUSHU CHARACTER-#1B1C0
1B1C1 NUSHU CHARACTER-#1B1C1
1B1C2 NUSHU CHARACTER-#1B1C2
1B1C3 NUSHU CHARACTER-#1B1C3
1B1C4 NUSHU CHARACTER-#1B1C4
1B1C5 NUSHU CHARACTER-#1B1C5
1B1C6 NUSHU CHARACTER-#1B1C6
1B1C7 NUSHU CHARACTER-#1B1C7
1B1C8 NUSHU CHARACTER-#1B1C8
1B1C9 NUSHU CHARACTER-#1B1C9
1B1CA NUSHU CHARACTER-#1B1CA
1B1CB NUSHU CHARACTER-#1B1CB
1B1CC NUSHU CHARACTER-#1B1CC
1B1CD NUSHU CHARACTER-#1B1CD
1B1CE NUSHU CHARACTER-#1B1CE
1B1CF NUSHU CHARACTER-#1B1CF
1B1D0 NUSHU CHARACTER-#1B1D0
1B1D1 NUSHU CHARACTER-#1B1D1
1B1D2 NUSHU CHARACTER-#1B1D2
1B1D3 NUSHU CHARACTER-#1B1D3
1B1D4 NUSHU CHARACTER-#1B1D4
1B1D5 NUSHU CHARACTER-#1B1D5
1B1D6 NUSHU CHARACTER-#1B1D6
1B1D7 NUSHU CHARACTER-#1B1D7
1B1D8 NUSHU CHARACTER-#1B1D8
1B1D9 NUSHU CHARACTER-#1B1D9
1B1DA NUSHU CHARACTER-#1B1DA
1B1DB NUSHU CHARACTER-#1B1DB
1B1DC NUSHU CHARACTER-#1B1DC
1B1DD NUSHU CHARACTER-#1B1DD
1B1DE NUSHU CHARACTER-#1B1DE
1B1DF NUSHU CHARACTER-#1B1DF
1B1E0 NUSHU CHARACTER-#1B1E0
1B1E1 NUSHU CHARACTER-#1B1E1
1B1E2 NUSHU CHARACTER-#1B1E2
1B1E3 NUSHU CHARACTER-#1B1E3
1B1E4 NUSHU CHARACTER-#1B1E4
1B1E5 NUSHU CHARACTER-#1B1E5
1B1E6 NUSHU CHARACTER-#1B1E6
1B1E7 NUSHU CHARACTER-#1B1E7
1B1E8 NUSHU CHARACTER-#1B1E8
1B1E9 NUSHU CHARACTER-#1B1E9
1B1EA NUSHU CHARACTER-#1B1EA
1B1EB NUSHU CHARACTER-#1B1EB
1B1EC NUSHU CHARACTER-#1B1EC
1B1ED NUSHU CHARACTER-#1B1ED
1B1EE NUSHU CHARACTER-#1B1EE
1B1EF NUSHU CHARACTER-#1B1EF
1B1F0 NUSHU CHARACTER-#1B1F0
1B1F1 NUSHU CHARACTER-#1B1F1
1B1F2 NUSHU CHARACTER-#1B1F2
1B1F3 NUSHU CHARACTER-#1B1F3
1B1F4 NUSHU CHARACTER-#1B1F4
1B1F5 NUSHU CHARACTER-#1B1F5
1B1F6 NUSHU CHARACTER-#1B1F6
1B1F7 NUSHU CHARACTER-#1B1F7
1B1F8 NUSHU CHARACTER-#1B1F8
1B1F9 NUSHU CHARACTER-#1B1F9
1B1FA NUSHU CHARACTER-#1B1FA
1B1FB NUSHU CHARACTER-#1B1FB
1B1FC NUSHU CHARACTER-#1B1FC
1B1FD NUSHU CHARACTER-#1B1FD
1B1FE NUSHU CHARACTER-#1B1FE
1B1FF NUSHU CHARACTER-#1B1FF
1B200 NUSHU CHARACTER-#1B200
1B201 NUSHU CHARACTER-#1B201
1B202 NUSHU CHARACTER-#1B202
1B203 NUSHU CHARACTER-#1B203
1B204 NUSHU CHARACTER-#1B204
1B205 NUSHU CHARACTER-#1B205
1B206 NUSHU CHARACTER-#1B206
1B207 NUSHU CHARACTER-#1B207
1B208 NUSHU CHARACTER-#1B208
1B209 NUSHU CHARACTER-#1B209
1B20A NUSHU CHARACTER-#1B20A
1B20B NUSHU CHARACTER-#1B20B
1B20C NUSHU CHARACTER-#1B20C
1B20D NUSHU CHARACTER-#1B20D
1B20E NUSHU CHARACTER-#1B20E
1B20F NUSHU CHARACTER-#1B20F
1B210 NUSHU CHARACTER-#1B210
1B211 NUSHU CHARACTER-#1B211
1B212 NUSHU CHARACTER-#1B212
1B213 NUSHU CHARACTER-#1B213
1B214 NUSHU CHARACTER-#1B214
1B215 NUSHU CHARACTER-#1B215
1B216 NUSHU CHARACTER-#1B216
1B217 NUSHU CHARACTER-#1B217
1B218 NUSHU CHARACTER-#1B218
1B219 NUSHU CHARACTER-#1B219
1B21A NUSHU CHARACTER-#1B21A
1B21B NUSHU CHARACTER-#1B21B
1B21C NUSHU CHARACTER-#1B21C
1B21D NUSHU CHARACTER-#1B21D
1B21E NUSHU CHARACTER-#1B21E
1B21F NUSHU CHARACTER-#1B21F
1B220 NUSHU CHARACTER-#1B220
1B221 NUSHU CHARACTER-#1B221
1B222 NUSHU CHARACTER-#1B222
1B223 NUSHU CHARACTER-#1B223
1B224 NUSHU CHARACTER-#1B224
1B225 NUSHU CHARACTER-#1B225
1B226 NUSHU CHARACTER-#1B226
1B227 NUSHU CHARACTER-#1B227
1B228 NUSHU CHARACTER-#1B228
1B229 NUSHU CHARACTER-#1B229
1B22A NUSHU CHARACTER-#1B22A
1B22B NUSHU CHARACTER-#1B22B
1B22C NUSHU CHARACTER-#1B22C
1B22D NUSHU CHARACTER-#1B22D
1B22E NUSHU CHARACTER-#1B22E
1B22F NUSHU CHARACTER-#1B22F
1B230 NUSHU CHARACTER-#1B230
1B231 NUSHU CHARACTER-#1B231
1B232 NUSHU CHARACTER-#1B232
1B233 NUSHU CHARACTER-#1B233
1B234 NUSHU CHARACTER-#1B234
1B235 NUSHU CHARACTER-#1B235
1B236 NUSHU CHARACTER-#1B236
1B237 NUSHU CHARACTER-#1B237
1B238 NUSHU CHARACTER-#1B238
1B239 NUSHU CHARACTER-#1B239
1B23A NUSHU CHARACTER-#1B23A
1B23B NUSHU CHARACTER-#1B23B
1B23C NUSHU CHARACTER-#1B23C
1B23D NUSHU CHARACTER-#1B23D
1B23E NUSHU CHARACTER-#1B23E
1B23F NUSHU CHARACTER-#1B23F
1B240 NUSHU CHARACTER-#1B240
1B241 NUSHU CHARACTER-#1B241
1B242 NUSHU CHARACTER-#1B242
1B243 NUSHU CHARACTER-#1B243
1B244 NUSHU CHARACTER-#1B244
1B245 NUSHU CHARACTER-#1B245
1B246 NUSHU CHARACTER-#1B246
1B247 NUSHU CHARACTER-#1B247
1B248 NUSHU CHARACTER-#1B248
1B249 NUSHU CHARACTER-#1B249
1B24A NUSHU CHARACTER-#1B24A
1B24B NUSHU CHARACTER-#1B24B
1B24C NUSHU CHARACTER-#1B24C
1B24D NUSHU CHARACTER-#1B24D
1B24E NUSHU CHARACTER-#1B24E
1B24F NUSHU CHARACTER-#1B24F
1B250 NUSHU CHARACTER-#1B250
1B251 NUSHU CHARACTER-#1B251
1B252 NUSHU CHARACTER-#1B252
1B253 NUSHU CHARACTER-#1B253
1B254 NUSHU CHARACTER-#1B254
1B255 NUSHU CHARACTER-#1B255
1B256 NUSHU CHARACTER-#1B256
1B257 NUSHU CHARACTER-#1B257
1B258 NUSHU CHARACTER-#1B258
1B259 NUSHU CHARACTER-#1B259
1B25A NUSHU CHARACTER-#1B25A
1B25B NUSHU CHARACTER-#1B25B
1B25C NUSHU CHARACTER-#1B25C
1B25D NUSHU CHARACTER-#1B25D
1B25E NUSHU CHARACTER-#1B25E
1B25F NUSHU CHARACTER-#1B25F
1B260 NUSHU CHARACTER-#1B260
1B261 NUSHU CHARACTER-#1B261
1B262 NUSHU CHARACTER-#1B262
1B263 NUSHU CHARACTER-#1B263
1B264 NUSHU CHARACTER-#1B264
1B265 NUSHU CHARACTER-#1B265
1B266 NUSHU CHARACTER-#1B266
1B267 NUSHU CHARACTER-#1B267
1B268 NUSHU CHARACTER-#1B268
1B269 NUSHU CHARACTER-#1B269
1B26A NUSHU CHARACTER-#1B26A
1B26B NUSHU CHARACTER-#1B26B
1B26C NUSHU CHARACTER-#1B26C
1B26D NUSHU CHARACTER-#1B26D
1B26E NUSHU CHARACTER-#1B26E
1B26F NUSHU CHARACTER-#1B26F
1B270 NUSHU CHARACTER-#1B270
1B271 NUSHU CHARACTER-#1B271
1B272 NUSHU CHARACTER-#1B272
1B273 NUSHU CHARACTER-#1B273
1B274 NUSHU CHARACTER-#1B274
1B275 NUSHU CHARACTER-#1B275
1B276 NUSHU CHARACTER-#1B276
1B277 NUSHU CHARACTER-#1B277
1B278 NUSHU CHARACTER-#1B278
1B279 NUSHU CHARACTER-#1B279
1B27A NUSHU CHARACTER-#1B27A
1B27B NUSHU CHARACTER-#1B27B
1B27C NUSHU CHARACTER-#1B27C
1B27D NUSHU CHARACTER-#1B27D
1B27E NUSHU CHARACTER-#1B27E
1B27F NUSHU CHARACTER-#1B27F
1B280 NUSHU CHARACTER-#1B280
1B281 NUSHU CHARACTER-#1B281
1B282 NUSHU CHARACTER-#1B282
1B283 NUSHU CHARACTER-#1B283
1B284 NUSHU CHARACTER-#1B284
1B285 NUSHU CHARACTER-#1B285
1B286 NUSHU CHARACTER-#1B286
1B287 NUSHU CHARACTER-#1B287
1B288 NUSHU CHARACTER-#1B288
1B289 NUSHU CHARACTER-#1B289
1B28A NUSHU CHARACTER-#1B28A
1B28B NUSHU CHARACTER-#1B28B
1B28C NUSHU CHARACTER-#1B28C
1B28D NUSHU CHARACTER-#1B28D
1B28E NUSHU CHARACTER-#1B28E
1B28F NUSHU CHARACTER-#1B28F
1B290 NUSHU CHARACTER-#1B290
1B291 NUSHU CHARACTER-#1B291
1B292 NUSHU CHARACTER-#1B292
1B293 NUSHU CHARACTER-#1B293
1B294 NUSHU CHARACTER-#1B294
1B295 NUSHU CHARACTER-#1B295
1B296 NUSHU CHARACTER-#1B296
1B297 NUSHU CHARACTER-#1B297
1B298 NUSHU CHARACTER-#1B298
1B299 NUSHU CHARACTER-#1B299
1B29A NUSHU CHARACTER-#1B29A
1B29B NUSHU CHARACTER-#1B29B
1B29C NUSHU CHARACTER-#1B29C
1B29D NUSHU CHARACTER-#1B29D
1B29E NUSHU CHARACTER-#1B29E
1B29F NUSHU CHARACTER-#1B29F
1B2A0 NUSHU CHARACTER-#1B2A0
1B2A1 NUSHU CHARACTER-#1B2A1
1B2A2 NUSHU CHARACTER-#1B2A2
1B2A3 NUSHU CHARACTER-#1B2A3
1B2A4 NUSHU CHARACTER-#1B2A4
1B2A5 NUSHU CHARACTER-#1B2A5
1B2A6 NUSHU CHARACTER-#1B2A6
1B2A7 NUSHU CHARACTER-#1B2A7
1B2A8 NUSHU CHARACTER-#1B2A8
1B2A9 NUSHU CHARACTER-#1B2A9
1B2AA NUSHU CHARACTER-#1B2AA
1B2AB NUSHU CHARACTER-#1B2AB
1B2AC NUSHU CHARACTER-#1B2AC
1B2AD NUSHU CHARACTER-#1B2AD
1B2AE NUSHU CHARACTER-#1B2AE
1B2AF NUSHU CHARACTER-#1B2AF
1B2B0 NUSHU CHARACTER-#1B2B0
1B2B1 NUSHU CHARACTER-#1B2B1
1B2B2 NUSHU CHARACTER-#1B2B2
1B2B3 NUSHU CHARACTER-#1B2B3
1B2B4 NUSHU CHARACTER-#1B2B4
1B2B5 NUSHU CHARACTER-#1B2B5
1B2B6 NUSHU CHARACTER-#1B2B6
1B2B7 NUSHU CHARACTER-#1B2B7
1B2B8 NUSHU CHARACTER-#1B2B8
1B2B9 NUSHU CHARACTER-#1B2B9
1B2BA NUSHU CHARACTER-#1B2BA
1B2BB NUSHU CHARACTER-#1B2BB
1B2BC NUSHU CHARACTER-#1B2BC
1B2BD NUSHU CHARACTER-#1B2BD
1B2BE NUSHU CHARACTER-#1B2BE
1B2BF NUSHU CHARACTER-#1B2BF
1B2C0 NUSHU CHARACTER-#1B2C0
1B2C1 NUSHU CHARACTER-#1B2C1
1B2C2 NUSHU CHARACTER-#1B2C2
1B2C3 NUSHU CHARACTER-#1B2C3
1B2C4 NUSHU CHARACTER-#1B2C4
1B2C5 NUSHU CHARACTER-#1B2C5
1B2C6 NUSHU CHARACTER-#1B2C6
1B2C7 NUSHU CHARACTER-#1B2C7
1B2C8 NUSHU CHARACTER-#1B2C8
1B2C9 NUSHU CHARACTER-#1B2C9
1B2CA NUSHU CHARACTER-#1B2CA
1B2CB NUSHU CHARACTER-#1B2CB
1B2CC NUSHU CHARACTER-#1B2CC
1B2CD NUSHU CHARACTER-#1B2CD
1B2CE NUSHU CHARACTER-#1B2CE
1B2CF NUSHU CHARACTER-#1B2CF
1B2D0 NUSHU CHARACTER-#1B2D0
1B2D1 NUSHU CHARACTER-#1B2D1
1B2D2 NUSHU CHARACTER-#1B2D2
1B2D3 NUSHU CHARACTER-#1B2D3
1B2D4 NUSHU CHARACTER-#1B2D4
1B2D5 NUSHU CHARACTER-#1B2D5
1B2D6 NUSHU CHARACTER-#1B2D6
1B2D7 NUSHU CHARACTER-#1B2D7
1B2D8 NUSHU CHARACTER-#1B2D8
1B2D9 NUSHU CHARACTER-#1B2D9
1B2DA NUSHU CHARACTER-#1B2DA
1B2DB NUSHU CHARACTER-#1B2DB
1B2DC NUSHU CHARACTER-#1B2DC
1B2DD NUSHU CHARACTER-#1B2DD
1B2DE NUSHU CHARACTER-#1B2DE
1B2DF NUSHU CHARACTER-#1B2DF
1B2E0 NUSHU CHARACTER-#1B2E0
1B2E1 NUSHU CHARACTER-#1B2E1
1B2E2 NUSHU CHARACTER-#1B2E2
1B2E3 NUSHU CHARACTER-#1B2E3
1B2E4 NUSHU CHARACTER-#1B2E4
1B2E5 NUSHU CHARACTER-#1B2E5
1B2E6 NUSHU CHARACTER-#1B2E6
1B2E7 NUSHU CHARACTER-#1B2E7
1B2E8 NUSHU CHARACTER-#1B2E8
1B2E9 NUSHU CHARACTER-#1B2E9
1B2EA NUSHU CHARACTER-#1B2EA
1B2EB NUSHU CHARACTER-#1B2EB
1B2EC NUSHU CHARACTER-#1B2EC
1B2ED NUSHU CHARACTER-#1B2ED
1B2EE NUSHU CHARACTER-#1B2EE
1B2EF NUSHU CHARACTER-#1B2EF
1B2F0 NUSHU CHARACTER-#1B2F0
1B2F1 NUSHU CHARACTER-#1B2F1
1B2F2 NUSHU CHARACTER-#1B2F2
1B2F3 NUSHU CHARACTER-#1B2F3
1B2F4 NUSHU CHARACTER-#1B2F4
1B2F5 NUSHU CHARACTER-#1B2F5
1B2F6 NUSHU CHARACTER-#1B2F6
1B2F7 NUSHU CHARACTER-#1B2F7
1B2F8 NUSHU CHARACTER-#1B2F8
1B2F9 NUSHU CHARACTER-#1B2F9
1B2FA NUSHU CHARACTER-#1B2FA
1B2FB NUSHU CHARACTER-#1B2FB
1BC00 DUPLOYAN LETTER H
1BC01 DUPLOYAN LETTER X
1BC02 DUPLOYAN LETTER P
1BC03 DUPLOYAN LETTER T
1BC04 DUPLOYAN LETTER F
1BC05 DUPLOYAN LETTER K
1BC06 DUPLOYAN LETTER L
1BC07 DUPLOYAN LETTER B
1BC08 DUPLOYAN LETTER D
1BC09 DUPLOYAN LETTER V
1BC0A DUPLOYAN LETTER G
1BC0B DUPLOYAN LETTER R
1BC0C DUPLOYAN LETTER P N
1BC0D DUPLOYAN LETTER D S
1BC0E DUPLOYAN LETTER F N
1BC0F DUPLOYAN LETTER K M
1BC10 DUPLOYAN LETTER R S
1BC11 DUPLOYAN LETTER TH
1BC12 DUPLOYAN LETTER SLOAN DH
1BC13 DUPLOYAN LETTER DH
1BC14 DUPLOYAN LETTER KK
1BC15 DUPLOYAN LETTER SLOAN J
1BC16 DUPLOYAN LETTER HL
1BC17 DUPLOYAN LETTER LH
1BC18 DUPLOYAN LETTER RH
1BC19 DUPLOYAN LETTER M
1BC1A DUPLOYAN LETTER N
1BC1B DUPLOYAN LETTER J
1BC1C DUPLOYAN LETTER S
1BC1D DUPLOYAN LETTER M N
1BC1E DUPLOYAN LETTER N M
1BC1F DUPLOYAN LETTER J M
1BC20 DUPLOYAN LETTER S J
1BC21 DUPLOYAN LETTER M WITH DOT
1BC22 DUPLOYAN LETTER N WITH DOT
1BC23 DUPLOYAN LETTER J WITH DOT
1BC24 DUPLOYAN LETTER J WITH DOTS INSIDE AND ABOVE
1BC25 DUPLOYAN LETTER S WITH DOT
1BC26 DUPLOYAN LETTER S WITH DOT BELOW
1BC27 DUPLOYAN LETTER M S
1BC28 DUPLOYAN LETTER N S
1BC29 DUPLOYAN LETTER J S
1BC2A DUPLOYAN LETTER S S
1BC2B DUPLOYAN LETTER M N S
1BC2C DUPLOYAN LETTER N M S
1BC2D DUPLOYAN LETTER J M S
1BC2E DUPLOYAN LETTER S J S
1BC2F DUPLOYAN LETTER J S WITH DOT
1BC30 DUPLOYAN LETTER J N
1BC31 DUPLOYAN LETTER J N S
1BC32 DUPLOYAN LETTER S T
1BC33 DUPLOYAN LETTER S T R
1BC34 DUPLOYAN LETTER S P
1BC35 DUPLOYAN LETTER S P R
1BC36 DUPLOYAN LETTER T S
1BC37 DUPLOYAN LETTER T R S
1BC38 DUPLOYAN LETTER W
1BC39 DUPLOYAN LETTER WH
1BC3A DUPLOYAN LETTER W R
1BC3B DUPLOYAN LETTER S N
1BC3C DUPLOYAN LETTER S M
1BC3D DUPLOYAN LETTER K R S
1BC3E DUPLOYAN LETTER G R S
1BC3F DUPLOYAN LETTER S K
1BC40 DUPLOYAN LETTER S K R
1BC41 DUPLOYAN LETTER A
1BC42 DUPLOYAN LETTER SLOAN OW
1BC43 DUPLOYAN LETTER OA
1BC44 DUPLOYAN LETTER O
1BC45 DUPLOYAN LETTER AOU
1BC46 DUPLOYAN LETTER I
1BC47 DUPLOYAN LETTER E
1BC48 DUPLOYAN LETTER IE
1BC49 DUPLOYAN LETTER SHORT I
1BC4A DUPLOYAN LETTER UI
1BC4B DUPLOYAN LETTER EE
1BC4C DUPLOYAN LETTER SLOAN EH
1BC4D DUPLOYAN LETTER ROMANIAN I
1BC4E DUPLOYAN LETTER SLOAN EE
1BC4F DUPLOYAN LETTER LONG I
1BC50 DUPLOYAN LETTER YE
1BC51 DUPLOYAN LETTER U
1BC52 DUPLOYAN LETTER EU
1BC53 DUPLOYAN LETTER XW
1BC54 DUPLOYAN LETTER U N
1BC55 DUPLOYAN LETTER LONG U
1BC56 DUPLOYAN LETTER ROMANIAN U
1BC57 DUPLOYAN LETTER UH
1BC58 DUPLOYAN LETTER SLOAN U
1BC59 DUPLOYAN LETTER OOH
1BC5A DUPLOYAN LETTER OW
1BC5B DUPLOYAN LETTER OU
1BC5C DUPLOYAN LETTER WA
1BC5D DUPLOYAN LETTER WO
1BC5E DUPLOYAN LETTER WI
1BC5F DUPLOYAN LETTER WEI
1BC60 DUPLOYAN LETTER WOW
1BC61 DUPLOYAN LETTER NASAL U
1BC62 DUPLOYAN LETTER NASAL O
1BC63 DUPLOYAN LETTER NASAL I
1BC64 DUPLOYAN LETTER NASAL A
1BC65 DUPLOYAN LETTER PERNIN AN
1BC66 DUPLOYAN LETTER PERNIN AM
1BC67 DUPLOYAN LETTER SLOAN EN
1BC68 DUPLOYAN LETTER SLOAN AN
1BC69 DUPLOYAN LETTER SLOAN ON
1BC6A DUPLOYAN LETTER VOCALIC M
1BC70 DUPLOYAN AFFIX LEFT HORIZONTAL SECANT
1BC71 DUPLOYAN AFFIX MID HORIZONTAL SECANT
1BC72 DUPLOYAN AFFIX RIGHT HORIZONTAL SECANT
1BC73 DUPLOYAN AFFIX LOW VERTICAL SECANT
1BC74 DUPLOYAN AFFIX MID VERTICAL SECANT
1BC75 DUPLOYAN AFFIX HIGH VERTICAL SECANT
1BC76 DUPLOYAN AFFIX ATTACHED SECANT
1BC77 DUPLOYAN AFFIX ATTACHED LEFT-TO-RIGHT SECANT
1BC78 DUPLOYAN AFFIX ATTACHED TANGENT
1BC79 DUPLOYAN AFFIX ATTACHED TAIL
1BC7A DUPLOYAN AFFIX ATTACHED E HOOK
1BC7B DUPLOYAN AFFIX ATTACHED I HOOK
1BC7C DUPLOYAN AFFIX ATTACHED TANGENT HOOK
1BC80 DUPLOYAN AFFIX HIGH ACUTE
1BC81 DUPLOYAN AFFIX HIGH TIGHT ACUTE
1BC82 DUPLOYAN AFFIX HIGH GRAVE
1BC83 DUPLOYAN AFFIX HIGH LONG GRAVE
1BC84 DUPLOYAN AFFIX HIGH DOT
1BC85 DUPLOYAN AFFIX HIGH CIRCLE
1BC86 DUPLOYAN AFFIX HIGH LINE
1BC87 DUPLOYAN AFFIX HIGH WAVE
1BC88 DUPLOYAN AFFIX HIGH VERTICAL
1BC90 DUPLOYAN AFFIX LOW ACUTE
1BC91 DUPLOYAN AFFIX LOW TIGHT ACUTE
1BC92 DUPLOYAN AFFIX LOW GRAVE
1BC93 DUPLOYAN AFFIX LOW LONG GRAVE
1BC94 DUPLOYAN AFFIX LOW DOT
1BC95 DUPLOYAN AFFIX LOW CIRCLE
1BC96 DUPLOYAN AFFIX LOW LINE
1BC97 DUPLOYAN AFFIX LOW WAVE
1BC98 DUPLOYAN AFFIX LOW VERTICAL
1BC99 DUPLOYAN AFFIX LOW ARROW
1BC9C DUPLOYAN SIGN O WITH CROSS
1BC9D DUPLOYAN THICK LETTER SELECTOR
1BC9E DUPLOYAN DOUBLE MARK
1BC9F DUPLOYAN PUNCTUATION CHINOOK FULL STOP
1BCA0 SHORTHAND FORMAT LETTER OVERLAP
1BCA1 SHORTHAND FORMAT CONTINUING OVERLAP
1BCA2 SHORTHAND FORMAT DOWN STEP
1BCA3 SHORTHAND FORMAT UP STEP
1D000 BYZANTINE MUSICAL SYMBOL PSILI
1D001 BYZANTINE MUSICAL SYMBOL DASEIA
1D002 BYZANTINE MUSICAL SYMBOL PERISPOMENI
1D003 BYZANTINE MUSICAL SYMBOL OXEIA EKFONITIKON
1D004 BYZANTINE MUSICAL SYMBOL OXEIA DIPLI
1D005 BYZANTINE MUSICAL SYMBOL VAREIA EKFONITIKON
1D006 BYZANTINE MUSICAL SYMBOL VAREIA DIPLI
1D007 BYZANTINE MUSICAL SYMBOL KATHISTI
1D008 BYZANTINE MUSICAL SYMBOL SYRMATIKI
1D009 BYZANTINE MUSICAL SYMBOL PARAKLITIKI
1D00A BYZANTINE MUSICAL SYMBOL YPOKRISIS
1D00B BYZANTINE MUSICAL SYMBOL YPOKRISIS DIPLI
1D00C BYZANTINE MUSICAL SYMBOL KREMASTI
1D00D BYZANTINE MUSICAL SYMBOL APESO EKFONITIKON
1D00E BYZANTINE MUSICAL SYMBOL EXO EKFONITIKON
1D00F BYZANTINE MUSICAL SYMBOL TELEIA
1D010 BYZANTINE MUSICAL SYMBOL KENTIMATA
1D011 BYZANTINE MUSICAL SYMBOL APOSTROFOS
1D012 BYZANTINE MUSICAL SYMBOL APOSTROFOS DIPLI
1D013 BYZANTINE MUSICAL SYMBOL SYNEVMA
1D014 BYZANTINE MUSICAL SYMBOL THITA
1D015 BYZANTINE MUSICAL SYMBOL OLIGON ARCHAION
1D016 BYZANTINE MUSICAL SYMBOL GORGON ARCHAION
1D017 BYZANTINE MUSICAL SYMBOL PSILON
1D018 BYZANTINE MUSICAL SYMBOL CHAMILON
1D019 BYZANTINE MUSICAL SYMBOL VATHY
1D01A BYZANTINE MUSICAL SYMBOL ISON ARCHAION
1D01B BYZANTINE MUSICAL SYMBOL KENTIMA ARCHAION
1D01C BYZANTINE MUSICAL SYMBOL KENTIMATA ARCHAION
1D01D BYZANTINE MUSICAL SYMBOL SAXIMATA
1D01E BYZANTINE MUSICAL SYMBOL PARICHON
1D01F BYZANTINE MUSICAL SYMBOL STAVROS APODEXIA
1D020 BYZANTINE MUSICAL SYMBOL OXEIAI ARCHAION
1D021 BYZANTINE MUSICAL SYMBOL VAREIAI ARCHAION
1D022 BYZANTINE MUSICAL SYMBOL APODERMA ARCHAION
1D023 BYZANTINE MUSICAL SYMBOL APOTHEMA
1D024 BYZANTINE MUSICAL SYMBOL KLASMA
1D025 BYZANTINE MUSICAL SYMBOL REVMA
1D026 BYZANTINE MUSICAL SYMBOL PIASMA ARCHAION
1D027 BYZANTINE MUSICAL SYMBOL TINAGMA
1D028 BYZANTINE MUSICAL SYMBOL ANATRICHISMA
1D029 BYZANTINE MUSICAL SYMBOL SEISMA
1D02A BYZANTINE MUSICAL SYMBOL SYNAGMA ARCHAION
1D02B BYZANTINE MUSICAL SYMBOL SYNAGMA META STAVROU
1D02C BYZANTINE MUSICAL SYMBOL OYRANISMA ARCHAION
1D02D BYZANTINE MUSICAL SYMBOL THEMA
1D02E BYZANTINE MUSICAL SYMBOL LEMOI
1D02F BYZANTINE MUSICAL SYMBOL DYO
1D030 BYZANTINE MUSICAL SYMBOL TRIA
1D031 BYZANTINE MUSICAL SYMBOL TESSERA
1D032 BYZANTINE MUSICAL SYMBOL KRATIMATA
1D033 BYZANTINE MUSICAL SYMBOL APESO EXO NEO
1D034 BYZANTINE MUSICAL SYMBOL FTHORA ARCHAION
1D035 BYZANTINE MUSICAL SYMBOL IMIFTHORA
1D036 BYZANTINE MUSICAL SYMBOL TROMIKON ARCHAION
1D037 BYZANTINE MUSICAL SYMBOL KATAVA TROMIKON
1D038 BYZANTINE MUSICAL SYMBOL PELASTON
1D039 BYZANTINE MUSICAL SYMBOL PSIFISTON
1D03A BYZANTINE MUSICAL SYMBOL KONTEVMA
1D03B BYZANTINE MUSICAL SYMBOL CHOREVMA ARCHAION
1D03C BYZANTINE MUSICAL SYMBOL RAPISMA
1D03D BYZANTINE MUSICAL SYMBOL PARAKALESMA ARCHAION
1D03E BYZANTINE MUSICAL SYMBOL PARAKLITIKI ARCHAION
1D03F BYZANTINE MUSICAL SYMBOL ICHADIN
1D040 BYZANTINE MUSICAL SYMBOL NANA
1D041 BYZANTINE MUSICAL SYMBOL PETASMA
1D042 BYZANTINE MUSICAL SYMBOL KONTEVMA ALLO
1D043 BYZANTINE MUSICAL SYMBOL TROMIKON ALLO
1D044 BYZANTINE MUSICAL SYMBOL STRAGGISMATA
1D045 BYZANTINE MUSICAL SYMBOL GRONTHISMATA
1D046 BYZANTINE MUSICAL SYMBOL ISON NEO
1D047 BYZANTINE MUSICAL SYMBOL OLIGON NEO
1D048 BYZANTINE MUSICAL SYMBOL OXEIA NEO
1D049 BYZANTINE MUSICAL SYMBOL PETASTI
1D04A BYZANTINE MUSICAL SYMBOL KOUFISMA
1D04B BYZANTINE MUSICAL SYMBOL PETASTOKOUFISMA
1D04C BYZANTINE MUSICAL SYMBOL KRATIMOKOUFISMA
1D04D BYZANTINE MUSICAL SYMBOL PELASTON NEO
1D04E BYZANTINE MUSICAL SYMBOL KENTIMATA NEO ANO
1D04F BYZANTINE MUSICAL SYMBOL KENTIMA NEO ANO
1D050 BYZANTINE MUSICAL SYMBOL YPSILI
1D051 BYZANTINE MUSICAL SYMBOL APOSTROFOS NEO
1D052 BYZANTINE MUSICAL SYMBOL APOSTROFOI SYNDESMOS NEO
1D053 BYZANTINE MUSICAL SYMBOL YPORROI
1D054 BYZANTINE MUSICAL SYMBOL KRATIMOYPORROON
1D055 BYZANTINE MUSICAL SYMBOL ELAFRON
1D056 BYZANTINE MUSICAL SYMBOL CHAMILI
1D057 BYZANTINE MUSICAL SYMBOL MIKRON ISON
1D058 BYZANTINE MUSICAL SYMBOL VAREIA NEO
1D059 BYZANTINE MUSICAL SYMBOL PIASMA NEO
1D05A BYZANTINE MUSICAL SYMBOL PSIFISTON NEO
1D05B BYZANTINE MUSICAL SYMBOL OMALON
1D05C BYZANTINE MUSICAL SYMBOL ANTIKENOMA
1D05D BYZANTINE MUSICAL SYMBOL LYGISMA
1D05E BYZANTINE MUSICAL SYMBOL PARAKLITIKI NEO
1D05F BYZANTINE MUSICAL SYMBOL PARAKALESMA NEO
1D060 BYZANTINE MUSICAL SYMBOL ETERON PARAKALESMA
1D061 BYZANTINE MUSICAL SYMBOL KYLISMA
1D062 BYZANTINE MUSICAL SYMBOL ANTIKENOKYLISMA
1D063 BYZANTINE MUSICAL SYMBOL TROMIKON NEO
1D064 BYZANTINE MUSICAL SYMBOL EKSTREPTON
1D065 BYZANTINE MUSICAL SYMBOL SYNAGMA NEO
1D066 BYZANTINE MUSICAL SYMBOL SYRMA
1D067 BYZANTINE MUSICAL SYMBOL CHOREVMA NEO
1D068 BYZANTINE MUSICAL SYMBOL EPEGERMA
1D069 BYZANTINE MUSICAL SYMBOL SEISMA NEO
1D06A BYZANTINE MUSICAL SYMBOL XIRON KLASMA
1D06B BYZANTINE MUSICAL SYMBOL TROMIKOPSIFISTON
1D06C BYZANTINE MUSICAL SYMBOL PSIFISTOLYGISMA
1D06D BYZANTINE MUSICAL SYMBOL TROMIKOLYGISMA
1D06E BYZANTINE MUSICAL SYMBOL TROMIKOPARAKALESMA
1D06F BYZANTINE MUSICAL SYMBOL PSIFISTOPARAKALESMA
1D070 BYZANTINE MUSICAL SYMBOL TROMIKOSYNAGMA
1D071 BYZANTINE MUSICAL SYMBOL PSIFISTOSYNAGMA
1D072 BYZANTINE MUSICAL SYMBOL GORGOSYNTHETON
1D073 BYZANTINE MUSICAL SYMBOL ARGOSYNTHETON
1D074 BYZANTINE MUSICAL SYMBOL ETERON ARGOSYNTHETON
1D075 BYZANTINE MUSICAL SYMBOL OYRANISMA NEO
1D076 BYZANTINE MUSICAL SYMBOL THEMATISMOS ESO
1D077 BYZANTINE MUSICAL SYMBOL THEMATISMOS EXO
1D078 BYZANTINE MUSICAL SYMBOL THEMA APLOUN
1D079 BYZANTINE MUSICAL SYMBOL THES KAI APOTHES
1D07A BYZANTINE MUSICAL SYMBOL KATAVASMA
1D07B BYZANTINE MUSICAL SYMBOL ENDOFONON
1D07C BYZANTINE MUSICAL SYMBOL YFEN KATO
1D07D BYZANTINE MUSICAL SYMBOL YFEN ANO
1D07E BYZANTINE MUSICAL SYMBOL STAVROS
1D07F BYZANTINE MUSICAL SYMBOL KLASMA ANO
1D080 BYZANTINE MUSICAL SYMBOL DIPLI ARCHAION
1D081 BYZANTINE MUSICAL SYMBOL KRATIMA ARCHAION
1D082 BYZANTINE MUSICAL SYMBOL KRATIMA ALLO
1D083 BYZANTINE MUSICAL SYMBOL KRATIMA NEO
1D084 BYZANTINE MUSICAL SYMBOL APODERMA NEO
1D085 BYZANTINE MUSICAL SYMBOL APLI
1D086 BYZANTINE MUSICAL SYMBOL DIPLI
1D087 BYZANTINE MUSICAL SYMBOL TRIPLI
1D088 BYZANTINE MUSICAL SYMBOL TETRAPLI
1D089 BYZANTINE MUSICAL SYMBOL KORONIS
1D08A BYZANTINE MUSICAL SYMBOL LEIMMA ENOS CHRONOU
1D08B BYZANTINE MUSICAL SYMBOL LEIMMA DYO CHRONON
1D08C BYZANTINE MUSICAL SYMBOL LEIMMA TRION CHRONON
1D08D BYZANTINE MUSICAL SYMBOL LEIMMA TESSARON CHRONON
1D08E BYZANTINE MUSICAL SYMBOL LEIMMA IMISEOS CHRONOU
1D08F BYZANTINE MUSICAL SYMBOL GORGON NEO ANO
1D090 BYZANTINE MUSICAL SYMBOL GORGON PARESTIGMENON ARISTERA
1D091 BYZANTINE MUSICAL SYMBOL GORGON PARESTIGMENON DEXIA
1D092 BYZANTINE MUSICAL SYMBOL DIGORGON
1D093 BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON ARISTERA KATO
1D094 BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON ARISTERA ANO
1D095 BYZANTINE MUSICAL SYMBOL DIGORGON PARESTIGMENON DEXIA
1D096 BYZANTINE MUSICAL SYMBOL TRIGORGON
1D097 BYZANTINE MUSICAL SYMBOL ARGON
1D098 BYZANTINE MUSICAL SYMBOL IMIDIARGON
1D099 BYZANTINE MUSICAL SYMBOL DIARGON
1D09A BYZANTINE MUSICAL SYMBOL AGOGI POLI ARGI
1D09B BYZANTINE MUSICAL SYMBOL AGOGI ARGOTERI
1D09C BYZANTINE MUSICAL SYMBOL AGOGI ARGI
1D09D BYZANTINE MUSICAL SYMBOL AGOGI METRIA
1D09E BYZANTINE MUSICAL SYMBOL AGOGI MESI
1D09F BYZANTINE MUSICAL SYMBOL AGOGI GORGI
1D0A0 BYZANTINE MUSICAL SYMBOL AGOGI GORGOTERI
1D0A1 BYZANTINE MUSICAL SYMBOL AGOGI POLI GORGI
1D0A2 BYZANTINE MUSICAL SYMBOL MARTYRIA PROTOS ICHOS
1D0A3 BYZANTINE MUSICAL SYMBOL MARTYRIA ALLI PROTOS ICHOS
1D0A4 BYZANTINE MUSICAL SYMBOL MARTYRIA DEYTEROS ICHOS
1D0A5 BYZANTINE MUSICAL SYMBOL MARTYRIA ALLI DEYTEROS ICHOS
1D0A6 BYZANTINE MUSICAL SYMBOL MARTYRIA TRITOS ICHOS
1D0A7 BYZANTINE MUSICAL SYMBOL MARTYRIA TRIFONIAS
1D0A8 BYZANTINE MUSICAL SYMBOL MARTYRIA TETARTOS ICHOS
1D0A9 BYZANTINE MUSICAL SYMBOL MARTYRIA TETARTOS LEGETOS ICHOS
1D0AA BYZANTINE MUSICAL SYMBOL MARTYRIA LEGETOS ICHOS
1D0AB BYZANTINE MUSICAL SYMBOL MARTYRIA PLAGIOS ICHOS
1D0AC BYZANTINE MUSICAL SYMBOL ISAKIA TELOUS ICHIMATOS
1D0AD BYZANTINE MUSICAL SYMBOL APOSTROFOI TELOUS ICHIMATOS
1D0AE BYZANTINE MUSICAL SYMBOL FANEROSIS TETRAFONIAS
1D0AF BYZANTINE MUSICAL SYMBOL FANEROSIS MONOFONIAS
1D0B0 BYZANTINE MUSICAL SYMBOL FANEROSIS DIFONIAS
1D0B1 BYZANTINE MUSICAL SYMBOL MARTYRIA VARYS ICHOS
1D0B2 BYZANTINE MUSICAL SYMBOL MARTYRIA PROTOVARYS ICHOS
1D0B3 BYZANTINE MUSICAL SYMBOL MARTYRIA PLAGIOS TETARTOS ICHOS
1D0B4 BYZANTINE MUSICAL SYMBOL GORTHMIKON N APLOUN
1D0B5 BYZANTINE MUSICAL SYMBOL GORTHMIKON N DIPLOUN
1D0B6 BYZANTINE MUSICAL SYMBOL ENARXIS KAI FTHORA VOU
1D0B7 BYZANTINE MUSICAL SYMBOL IMIFONON
1D0B8 BYZANTINE MUSICAL SYMBOL IMIFTHORON
1D0B9 BYZANTINE MUSICAL SYMBOL FTHORA ARCHAION DEYTEROU ICHOU
1D0BA BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI PA
1D0BB BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NANA
1D0BC BYZANTINE MUSICAL SYMBOL FTHORA NAOS ICHOS
1D0BD BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI DI
1D0BE BYZANTINE MUSICAL SYMBOL FTHORA SKLIRON DIATONON DI
1D0BF BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI KE
1D0C0 BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI ZO
1D0C1 BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NI KATO
1D0C2 BYZANTINE MUSICAL SYMBOL FTHORA DIATONIKI NI ANO
1D0C3 BYZANTINE MUSICAL SYMBOL FTHORA MALAKON CHROMA DIFONIAS
1D0C4 BYZANTINE MUSICAL SYMBOL FTHORA MALAKON CHROMA MONOFONIAS
1D0C5 BYZANTINE MUSICAL SYMBOL FHTORA SKLIRON CHROMA VASIS
1D0C6 BYZANTINE MUSICAL SYMBOL FTHORA SKLIRON CHROMA SYNAFI
1D0C7 BYZANTINE MUSICAL SYMBOL FTHORA NENANO
1D0C8 BYZANTINE MUSICAL SYMBOL CHROA ZYGOS
1D0C9 BYZANTINE MUSICAL SYMBOL CHROA KLITON
1D0CA BYZANTINE MUSICAL SYMBOL CHROA SPATHI
1D0CB BYZANTINE MUSICAL SYMBOL FTHORA I YFESIS TETARTIMORION
1D0CC BYZANTINE MUSICAL SYMBOL FTHORA ENARMONIOS ANTIFONIA
1D0CD BYZANTINE MUSICAL SYMBOL YFESIS TRITIMORION
1D0CE BYZANTINE MUSICAL SYMBOL DIESIS TRITIMORION
1D0CF BYZANTINE MUSICAL SYMBOL DIESIS TETARTIMORION
1D0D0 BYZANTINE MUSICAL SYMBOL DIESIS APLI DYO DODEKATA
1D0D1 BYZANTINE MUSICAL SYMBOL DIESIS MONOGRAMMOS TESSERA DODEKATA
1D0D2 BYZANTINE MUSICAL SYMBOL DIESIS DIGRAMMOS EX DODEKATA
1D0D3 BYZANTINE MUSICAL SYMBOL DIESIS TRIGRAMMOS OKTO DODEKATA
1D0D4 BYZANTINE MUSICAL SYMBOL YFESIS APLI DYO DODEKATA
1D0D5 BYZANTINE MUSICAL SYMBOL YFESIS MONOGRAMMOS TESSERA DODEKATA
1D0D6 BYZANTINE MUSICAL SYMBOL YFESIS DIGRAMMOS EX DODEKATA
1D0D7 BYZANTINE MUSICAL SYMBOL YFESIS TRIGRAMMOS OKTO DODEKATA
1D0D8 BYZANTINE MUSICAL SYMBOL GENIKI DIESIS
1D0D9 BYZANTINE MUSICAL SYMBOL GENIKI YFESIS
1D0DA BYZANTINE MUSICAL SYMBOL DIASTOLI APLI MIKRI
1D0DB BYZANTINE MUSICAL SYMBOL DIASTOLI APLI MEGALI
1D0DC BYZANTINE MUSICAL SYMBOL DIASTOLI DIPLI
1D0DD BYZANTINE MUSICAL SYMBOL DIASTOLI THESEOS
1D0DE BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS
1D0DF BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS DISIMOU
1D0E0 BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS TRISIMOU
1D0E1 BYZANTINE MUSICAL SYMBOL SIMANSIS THESEOS TETRASIMOU
1D0E2 BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS
1D0E3 BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS DISIMOU
1D0E4 BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS TRISIMOU
1D0E5 BYZANTINE MUSICAL SYMBOL SIMANSIS ARSEOS TETRASIMOU
1D0E6 BYZANTINE MUSICAL SYMBOL DIGRAMMA GG
1D0E7 BYZANTINE MUSICAL SYMBOL DIFTOGGOS OU
1D0E8 BYZANTINE MUSICAL SYMBOL STIGMA
1D0E9 BYZANTINE MUSICAL SYMBOL ARKTIKO PA
1D0EA BYZANTINE MUSICAL SYMBOL ARKTIKO VOU
1D0EB BYZANTINE MUSICAL SYMBOL ARKTIKO GA
1D0EC BYZANTINE MUSICAL SYMBOL ARKTIKO DI
1D0ED BYZANTINE MUSICAL SYMBOL ARKTIKO KE
1D0EE BYZANTINE MUSICAL SYMBOL ARKTIKO ZO
1D0EF BYZANTINE MUSICAL SYMBOL ARKTIKO NI
1D0F0 BYZANTINE MUSICAL SYMBOL KENTIMATA NEO MESO
1D0F1 BYZANTINE MUSICAL SYMBOL KENTIMA NEO MESO
1D0F2 BYZANTINE MUSICAL SYMBOL KENTIMATA NEO KATO
1D0F3 BYZANTINE MUSICAL SYMBOL KENTIMA NEO KATO
1D0F4 BYZANTINE MUSICAL SYMBOL KLASMA KATO
1D0F5 BYZANTINE MUSICAL SYMBOL GORGON NEO KATO
1D100 MUSICAL SYMBOL SINGLE BARLINE
1D101 MUSICAL SYMBOL DOUBLE BARLINE
1D102 MUSICAL SYMBOL FINAL BARLINE
1D103 MUSICAL SYMBOL REVERSE FINAL BARLINE
1D104 MUSICAL SYMBOL DASHED BARLINE
1D105 MUSICAL SYMBOL SHORT BARLINE
1D106 MUSICAL SYMBOL LEFT REPEAT SIGN
1D107 MUSICAL SYMBOL RIGHT REPEAT SIGN
1D108 MUSICAL SYMBOL REPEAT DOTS
1D109 MUSICAL SYMBOL DAL SEGNO
1D10A MUSICAL SYMBOL DA CAPO
1D10B MUSICAL SYMBOL SEGNO
1D10C MUSICAL SYMBOL CODA
1D10D MUSICAL SYMBOL REPEATED FIGURE-1
1D10E MUSICAL SYMBOL REPEATED FIGURE-2
1D10F MUSICAL SYMBOL REPEATED FIGURE-3
1D110 MUSICAL SYMBOL FERMATA
1D111 MUSICAL SYMBOL FERMATA BELOW
1D112 MUSICAL SYMBOL BREATH MARK
1D113 MUSICAL SYMBOL CAESURA
1D114 MUSICAL SYMBOL BRACE
1D115 MUSICAL SYMBOL BRACKET
1D116 MUSICAL SYMBOL ONE-LINE STAFF
1D117 MUSICAL SYMBOL TWO-LINE STAFF
1D118 MUSICAL SYMBOL THREE-LINE STAFF
1D119 MUSICAL SYMBOL FOUR-LINE STAFF
1D11A MUSICAL SYMBOL FIVE-LINE STAFF
1D11B MUSICAL SYMBOL SIX-LINE STAFF
1D11C MUSICAL SYMBOL SIX-STRING FRETBOARD
1D11D MUSICAL SYMBOL FOUR-STRING FRETBOARD
1D11E MUSICAL SYMBOL G CLEF
1D11F MUSICAL SYMBOL G CLEF OTTAVA ALTA
1D120 MUSICAL SYMBOL G CLEF OTTAVA BASSA
1D121 MUSICAL SYMBOL C CLEF
1D122 MUSICAL SYMBOL F CLEF
1D123 MUSICAL SYMBOL F CLEF OTTAVA ALTA
1D124 MUSICAL SYMBOL F CLEF OTTAVA BASSA
1D125 MUSICAL SYMBOL DRUM CLEF-1
1D126 MUSICAL SYMBOL DRUM CLEF-2
1D129 MUSICAL SYMBOL MULTIPLE MEASURE REST
1D12A MUSICAL SYMBOL DOUBLE SHARP
1D12B MUSICAL SYMBOL DOUBLE FLAT
1D12C MUSICAL SYMBOL FLAT UP
1D12D MUSICAL SYMBOL FLAT DOWN
1D12E MUSICAL SYMBOL NATURAL UP
1D12F MUSICAL SYMBOL NATURAL DOWN
1D130 MUSICAL SYMBOL SHARP UP
1D131 MUSICAL SYMBOL SHARP DOWN
1D132 MUSICAL SYMBOL QUARTER TONE SHARP
1D133 MUSICAL SYMBOL QUARTER TONE FLAT
1D134 MUSICAL SYMBOL COMMON TIME
1D135 MUSICAL SYMBOL CUT TIME
1D136 MUSICAL SYMBOL OTTAVA ALTA
1D137 MUSICAL SYMBOL OTTAVA BASSA
1D138 MUSICAL SYMBOL QUINDICESIMA ALTA
1D139 MUSICAL SYMBOL QUINDICESIMA BASSA
1D13A MUSICAL SYMBOL MULTI REST
1D13B MUSICAL SYMBOL WHOLE REST
1D13C MUSICAL SYMBOL HALF REST
1D13D MUSICAL SYMBOL QUARTER REST
1D13E MUSICAL SYMBOL EIGHTH REST
1D13F MUSICAL SYMBOL SIXTEENTH REST
1D140 MUSICAL SYMBOL THIRTY-SECOND REST
1D141 MUSICAL SYMBOL SIXTY-FOURTH REST
1D142 MUSICAL SYMBOL ONE HUNDRED TWENTY-EIGHTH REST
1D143 MUSICAL SYMBOL X NOTEHEAD
1D144 MUSICAL SYMBOL PLUS NOTEHEAD
1D145 MUSICAL SYMBOL CIRCLE X NOTEHEAD
1D146 MUSICAL SYMBOL SQUARE NOTEHEAD WHITE
1D147 MUSICAL SYMBOL SQUARE NOTEHEAD BLACK
1D148 MUSICAL SYMBOL TRIANGLE NOTEHEAD UP WHITE
1D149 MUSICAL SYMBOL TRIANGLE NOTEHEAD UP BLACK
1D14A MUSICAL SYMBOL TRIANGLE NOTEHEAD LEFT WHITE
1D14B MUSICAL SYMBOL TRIANGLE NOTEHEAD LEFT BLACK
1D14C MUSICAL SYMBOL TRIANGLE NOTEHEAD RIGHT WHITE
1D14D MUSICAL SYMBOL TRIANGLE NOTEHEAD RIGHT BLACK
1D14E MUSICAL SYMBOL TRIANGLE NOTEHEAD DOWN WHITE
1D14F MUSICAL SYMBOL TRIANGLE NOTEHEAD DOWN BLACK
1D150 MUSICAL SYMBOL TRIANGLE NOTEHEAD UP RIGHT WHITE
1D151 MUSICAL SYMBOL TRIANGLE NOTEHEAD UP RIGHT BLACK
1D152 MUSICAL SYMBOL MOON NOTEHEAD WHITE
1D153 MUSICAL SYMBOL MOON NOTEHEAD BLACK
1D154 MUSICAL SYMBOL TRIANGLE-ROUND NOTEHEAD DOWN WHITE
1D155 MUSICAL SYMBOL TRIANGLE-ROUND NOTEHEAD DOWN BLACK
1D156 MUSICAL SYMBOL PARENTHESIS NOTEHEAD
1D157 MUSICAL SYMBOL VOID NOTEHEAD
1D158 MUSICAL SYMBOL NOTEHEAD BLACK
1D159 MUSICAL SYMBOL NULL NOTEHEAD
1D15A MUSICAL SYMBOL CLUSTER NOTEHEAD WHITE
1D15B MUSICAL SYMBOL CLUSTER NOTEHEAD BLACK
1D15C MUSICAL SYMBOL BREVE
1D15D MUSICAL SYMBOL WHOLE NOTE
1D15E MUSICAL SYMBOL HALF NOTE
1D15F MUSICAL SYMBOL QUARTER NOTE
1D160 MUSICAL SYMBOL EIGHTH NOTE
1D161 MUSICAL SYMBOL SIXTEENTH NOTE
1D162 MUSICAL SYMBOL THIRTY-SECOND NOTE
1D163 MUSICAL SYMBOL SIXTY-FOURTH NOTE
1D164 MUSICAL SYMBOL ONE HUNDRED TWENTY-EIGHTH NOTE
1D165 MUSICAL SYMBOL COMBINING STEM
1D166 MUSICAL SYMBOL COMBINING SPRECHGESANG STEM
1D167 MUSICAL SYMBOL COMBINING TREMOLO-1
1D168 MUSICAL SYMBOL COMBINING TREMOLO-2
1D169 MUSICAL SYMBOL COMBINING TREMOLO-3
1D16A MUSICAL SYMBOL FINGERED TREMOLO-1
1D16B MUSICAL SYMBOL FINGERED TREMOLO-2
1D16C MUSICAL SYMBOL FINGERED TREMOLO-3
1D16D MUSICAL SYMBOL COMBINING AUGMENTATION DOT
1D16E MUSICAL SYMBOL COMBINING FLAG-1
1D16F MUSICAL SYMBOL COMBINING FLAG-2
1D170 MUSICAL SYMBOL COMBINING FLAG-3
1D171 MUSICAL SYMBOL COMBINING FLAG-4
1D172 MUSICAL SYMBOL COMBINING FLAG-5
1D173 MUSICAL SYMBOL BEGIN BEAM
1D174 MUSICAL SYMBOL END BEAM
1D175 MUSICAL SYMBOL BEGIN TIE
1D176 MUSICAL SYMBOL END TIE
1D177 MUSICAL SYMBOL BEGIN SLUR
1D178 MUSICAL SYMBOL END SLUR
1D179 MUSICAL SYMBOL BEGIN PHRASE
1D17A MUSICAL SYMBOL END PHRASE
1D17B MUSICAL SYMBOL COMBINING ACCENT
1D17C MUSICAL SYMBOL COMBINING STACCATO
1D17D MUSICAL SYMBOL COMBINING TENUTO
1D17E MUSICAL SYMBOL COMBINING STACCATISSIMO
1D17F MUSICAL SYMBOL COMBINING MARCATO
1D180 MUSICAL SYMBOL COMBINING MARCATO-STACCATO
1D181 MUSICAL SYMBOL COMBINING ACCENT-STACCATO
1D182 MUSICAL SYMBOL COMBINING LOURE
1D183 MUSICAL SYMBOL ARPEGGIATO UP
1D184 MUSICAL SYMBOL ARPEGGIATO DOWN
1D185 MUSICAL SYMBOL COMBINING DOIT
1D186 MUSICAL SYMBOL COMBINING RIP
1D187 MUSICAL SYMBOL COMBINING FLIP
1D188 MUSICAL SYMBOL COMBINING SMEAR
1D189 MUSICAL SYMBOL COMBINING BEND
1D18A MUSICAL SYMBOL COMBINING DOUBLE TONGUE
1D18B MUSICAL SYMBOL COMBINING TRIPLE TONGUE
1D18C MUSICAL SYMBOL RINFORZANDO
1D18D MUSICAL SYMBOL SUBITO
1D18E MUSICAL SYMBOL Z
1D18F MUSICAL SYMBOL PIANO
1D190 MUSICAL SYMBOL MEZZO
1D191 MUSICAL SYMBOL FORTE
1D192 MUSICAL SYMBOL CRESCENDO
1D193 MUSICAL SYMBOL DECRESCENDO
1D194 MUSICAL SYMBOL GRACE NOTE SLASH
1D195 MUSICAL SYMBOL GRACE NOTE NO SLASH
1D196 MUSICAL SYMBOL TR
1D197 MUSICAL SYMBOL TURN
1D198 MUSICAL SYMBOL INVERTED TURN
1D199 MUSICAL SYMBOL TURN SLASH
1D19A MUSICAL SYMBOL TURN UP
1D19B MUSICAL SYMBOL ORNAMENT STROKE-1
1D19C MUSICAL SYMBOL ORNAMENT STROKE-2
1D19D MUSICAL SYMBOL ORNAMENT STROKE-3
1D19E MUSICAL SYMBOL ORNAMENT STROKE-4
1D19F MUSICAL SYMBOL ORNAMENT STROKE-5
1D1A0 MUSICAL SYMBOL ORNAMENT STROKE-6
1D1A1 MUSICAL SYMBOL ORNAMENT STROKE-7
1D1A2 MUSICAL SYMBOL ORNAMENT STROKE-8
1D1A3 MUSICAL SYMBOL ORNAMENT STROKE-9
1D1A4 MUSICAL SYMBOL ORNAMENT STROKE-10
1D1A5 MUSICAL SYMBOL ORNAMENT STROKE-11
1D1A6 MUSICAL SYMBOL HAUPTSTIMME
1D1A7 MUSICAL SYMBOL NEBENSTIMME
1D1A8 MUSICAL SYMBOL END OF STIMME
1D1A9 MUSICAL SYMBOL DEGREE SLASH
1D1AA MUSICAL SYMBOL COMBINING DOWN BOW
1D1AB MUSICAL SYMBOL COMBINING UP BOW
1D1AC MUSICAL SYMBOL COMBINING HARMONIC
1D1AD MUSICAL SYMBOL COMBINING SNAP PIZZICATO
1D1AE MUSICAL SYMBOL PEDAL MARK
1D1AF MUSICAL SYMBOL PEDAL UP MARK
1D1B0 MUSICAL SYMBOL HALF PEDAL MARK
1D1B1 MUSICAL SYMBOL GLISSANDO UP
1D1B2 MUSICAL SYMBOL GLISSANDO DOWN
1D1B3 MUSICAL SYMBOL WITH FINGERNAILS
1D1B4 MUSICAL SYMBOL DAMP
1D1B5 MUSICAL SYMBOL DAMP ALL
1D1B6 MUSICAL SYMBOL MAXIMA
1D1B7 MUSICAL SYMBOL LONGA
1D1B8 MUSICAL SYMBOL BREVIS
1D1B9 MUSICAL SYMBOL SEMIBREVIS WHITE
1D1BA MUSICAL SYMBOL SEMIBREVIS BLACK
1D1BB MUSICAL SYMBOL MINIMA
1D1BC MUSICAL SYMBOL MINIMA BLACK
1D1BD MUSICAL SYMBOL SEMIMINIMA WHITE
1D1BE MUSICAL SYMBOL SEMIMINIMA BLACK
1D1BF MUSICAL SYMBOL FUSA WHITE
1D1C0 MUSICAL SYMBOL FUSA BLACK
1D1C1 MUSICAL SYMBOL LONGA PERFECTA REST
1D1C2 MUSICAL SYMBOL LONGA IMPERFECTA REST
1D1C3 MUSICAL SYMBOL BREVIS REST
1D1C4 MUSICAL SYMBOL SEMIBREVIS REST
1D1C5 MUSICAL SYMBOL MINIMA REST
1D1C6 MUSICAL SYMBOL SEMIMINIMA REST
1D1C7 MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE PERFECTA
1D1C8 MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE IMPERFECTA
1D1C9 MUSICAL SYMBOL TEMPUS PERFECTUM CUM PROLATIONE PERFECTA DIMINUTION-1
1D1CA MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE PERFECTA
1D1CB MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA
1D1CC MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-1
1D1CD MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-2
1D1CE MUSICAL SYMBOL TEMPUS IMPERFECTUM CUM PROLATIONE IMPERFECTA DIMINUTION-3
1D1CF MUSICAL SYMBOL CROIX
1D1D0 MUSICAL SYMBOL GREGORIAN C CLEF
1D1D1 MUSICAL SYMBOL GREGORIAN F CLEF
1D1D2 MUSICAL SYMBOL SQUARE B
1D1D3 MUSICAL SYMBOL VIRGA
1D1D4 MUSICAL SYMBOL PODATUS
1D1D5 MUSICAL SYMBOL CLIVIS
1D1D6 MUSICAL SYMBOL SCANDICUS
1D1D7 MUSICAL SYMBOL CLIMACUS
1D1D8 MUSICAL SYMBOL TORCULUS
1D1D9 MUSICAL SYMBOL PORRECTUS
1D1DA MUSICAL SYMBOL PORRECTUS FLEXUS
1D1DB MUSICAL SYMBOL SCANDICUS FLEXUS
1D1DC MUSICAL SYMBOL TORCULUS RESUPINUS
1D1DD MUSICAL SYMBOL PES SUBPUNCTIS
1D1DE MUSICAL SYMBOL KIEVAN C CLEF
1D1DF MUSICAL SYMBOL KIEVAN END OF PIECE
1D1E0 MUSICAL SYMBOL KIEVAN FINAL NOTE
1D1E1 MUSICAL SYMBOL KIEVAN RECITATIVE MARK
1D1E2 MUSICAL SYMBOL KIEVAN WHOLE NOTE
1D1E3 MUSICAL SYMBOL KIEVAN HALF NOTE
1D1E4 MUSICAL SYMBOL KIEVAN QUARTER NOTE STEM DOWN
1D1E5 MUSICAL SYMBOL KIEVAN QUARTER NOTE STEM UP
1D1E6 MUSICAL SYMBOL KIEVAN EIGHTH NOTE STEM DOWN
1D1E7 MUSICAL SYMBOL KIEVAN EIGHTH NOTE STEM UP
1D1E8 MUSICAL SYMBOL KIEVAN FLAT SIGN
1D200 GREEK VOCAL NOTATION SYMBOL-1
1D201 GREEK VOCAL NOTATION SYMBOL-2
1D202 GREEK VOCAL NOTATION SYMBOL-3
1D203 GREEK VOCAL NOTATION SYMBOL-4
1D204 GREEK VOCAL NOTATION SYMBOL-5
1D205 GREEK VOCAL NOTATION SYMBOL-6
1D206 GREEK VOCAL NOTATION SYMBOL-7
1D207 GREEK VOCAL NOTATION SYMBOL-8
1D208 GREEK VOCAL NOTATION SYMBOL-9
1D209 GREEK VOCAL NOTATION SYMBOL-10
1D20A GREEK VOCAL NOTATION SYMBOL-11
1D20B GREEK VOCAL NOTATION SYMBOL-12
1D20C GREEK VOCAL NOTATION SYMBOL-13
1D20D GREEK VOCAL NOTATION SYMBOL-14
1D20E GREEK VOCAL NOTATION SYMBOL-15
1D20F GREEK VOCAL NOTATION SYMBOL-16
1D210 GREEK VOCAL NOTATION SYMBOL-17
1D211 GREEK VOCAL NOTATION SYMBOL-18
1D212 GREEK VOCAL NOTATION SYMBOL-19
1D213 GREEK VOCAL NOTATION SYMBOL-20
1D214 GREEK VOCAL NOTATION SYMBOL-21
1D215 GREEK VOCAL NOTATION SYMBOL-22
1D216 GREEK VOCAL NOTATION SYMBOL-23
1D217 GREEK VOCAL NOTATION SYMBOL-24
1D218 GREEK VOCAL NOTATION SYMBOL-50
1D219 GREEK VOCAL NOTATION SYMBOL-51
1D21A GREEK VOCAL NOTATION SYMBOL-52
1D21B GREEK VOCAL NOTATION SYMBOL-53
1D21C GREEK VOCAL NOTATION SYMBOL-54
1D21D GREEK INSTRUMENTAL NOTATION SYMBOL-1
1D21E GREEK INSTRUMENTAL NOTATION SYMBOL-2
1D21F GREEK INSTRUMENTAL NOTATION SYMBOL-4
1D220 GREEK INSTRUMENTAL NOTATION SYMBOL-5
1D221 GREEK INSTRUMENTAL NOTATION SYMBOL-7
1D222 GREEK INSTRUMENTAL NOTATION SYMBOL-8
1D223 GREEK INSTRUMENTAL NOTATION SYMBOL-11
1D224 GREEK INSTRUMENTAL NOTATION SYMBOL-12
1D225 GREEK INSTRUMENTAL NOTATION SYMBOL-13
1D226 GREEK INSTRUMENTAL NOTATION SYMBOL-14
1D227 GREEK INSTRUMENTAL NOTATION SYMBOL-17
1D228 GREEK INSTRUMENTAL NOTATION SYMBOL-18
1D229 GREEK INSTRUMENTAL NOTATION SYMBOL-19
1D22A GREEK INSTRUMENTAL NOTATION SYMBOL-23
1D22B GREEK INSTRUMENTAL NOTATION SYMBOL-24
1D22C GREEK INSTRUMENTAL NOTATION SYMBOL-25
1D22D GREEK INSTRUMENTAL NOTATION SYMBOL-26
1D22E GREEK INSTRUMENTAL NOTATION SYMBOL-27
1D22F GREEK INSTRUMENTAL NOTATION SYMBOL-29
1D230 GREEK INSTRUMENTAL NOTATION SYMBOL-30
1D231 GREEK INSTRUMENTAL NOTATION SYMBOL-32
1D232 GREEK INSTRUMENTAL NOTATION SYMBOL-36
1D233 GREEK INSTRUMENTAL NOTATION SYMBOL-37
1D234 GREEK INSTRUMENTAL NOTATION SYMBOL-38
1D235 GREEK INSTRUMENTAL NOTATION SYMBOL-39
1D236 GREEK INSTRUMENTAL NOTATION SYMBOL-40
1D237 GREEK INSTRUMENTAL NOTATION SYMBOL-42
1D238 GREEK INSTRUMENTAL NOTATION SYMBOL-43
1D239 GREEK INSTRUMENTAL NOTATION SYMBOL-45
1D23A GREEK INSTRUMENTAL NOTATION SYMBOL-47
1D23B GREEK INSTRUMENTAL NOTATION SYMBOL-48
1D23C GREEK INSTRUMENTAL NOTATION SYMBOL-49
1D23D GREEK INSTRUMENTAL NOTATION SYMBOL-50
1D23E GREEK INSTRUMENTAL NOTATION SYMBOL-51
1D23F GREEK INSTRUMENTAL NOTATION SYMBOL-52
1D240 GREEK INSTRUMENTAL NOTATION SYMBOL-53
1D241 GREEK INSTRUMENTAL NOTATION SYMBOL-54
1D242 COMBINING GREEK MUSICAL TRISEME
1D243 COMBINING GREEK MUSICAL TETRASEME
1D244 COMBINING GREEK MUSICAL PENTASEME
1D245 GREEK MUSICAL LEIMMA
1D300 MONOGRAM FOR EARTH
1D301 DIGRAM FOR HEAVENLY EARTH
1D302 DIGRAM FOR HUMAN EARTH
1D303 DIGRAM FOR EARTHLY HEAVEN
1D304 DIGRAM FOR EARTHLY HUMAN
1D305 DIGRAM FOR EARTH
1D306 TETRAGRAM FOR CENTRE
1D307 TETRAGRAM FOR FULL CIRCLE
1D308 TETRAGRAM FOR MIRED
1D309 TETRAGRAM FOR BARRIER
1D30A TETRAGRAM FOR KEEPING SMALL
1D30B TETRAGRAM FOR CONTRARIETY
1D30C TETRAGRAM FOR ASCENT
1D30D TETRAGRAM FOR OPPOSITION
1D30E TETRAGRAM FOR BRANCHING OUT
1D30F TETRAGRAM FOR DEFECTIVENESS OR DISTORTION
1D310 TETRAGRAM FOR DIVERGENCE
1D311 TETRAGRAM FOR YOUTHFULNESS
1D312 TETRAGRAM FOR INCREASE
1D313 TETRAGRAM FOR PENETRATION
1D314 TETRAGRAM FOR REACH
1D315 TETRAGRAM FOR CONTACT
1D316 TETRAGRAM FOR HOLDING BACK
1D317 TETRAGRAM FOR WAITING
1D318 TETRAGRAM FOR FOLLOWING
1D319 TETRAGRAM FOR ADVANCE
1D31A TETRAGRAM FOR RELEASE
1D31B TETRAGRAM FOR RESISTANCE
1D31C TETRAGRAM FOR EASE
1D31D TETRAGRAM FOR JOY
1D31E TETRAGRAM FOR CONTENTION
1D31F TETRAGRAM FOR ENDEAVOUR
1D320 TETRAGRAM FOR DUTIES
1D321 TETRAGRAM FOR CHANGE
1D322 TETRAGRAM FOR DECISIVENESS
1D323 TETRAGRAM FOR BOLD RESOLUTION
1D324 TETRAGRAM FOR PACKING
1D325 TETRAGRAM FOR LEGION
1D326 TETRAGRAM FOR CLOSENESS
1D327 TETRAGRAM FOR KINSHIP
1D328 TETRAGRAM FOR GATHERING
1D329 TETRAGRAM FOR STRENGTH
1D32A TETRAGRAM FOR PURITY
1D32B TETRAGRAM FOR FULLNESS
1D32C TETRAGRAM FOR RESIDENCE
1D32D TETRAGRAM FOR LAW OR MODEL
1D32E TETRAGRAM FOR RESPONSE
1D32F TETRAGRAM FOR GOING TO MEET
1D330 TETRAGRAM FOR ENCOUNTERS
1D331 TETRAGRAM FOR STOVE
1D332 TETRAGRAM FOR GREATNESS
1D333 TETRAGRAM FOR ENLARGEMENT
1D334 TETRAGRAM FOR PATTERN
1D335 TETRAGRAM FOR RITUAL
1D336 TETRAGRAM FOR FLIGHT
1D337 TETRAGRAM FOR VASTNESS OR WASTING
1D338 TETRAGRAM FOR CONSTANCY
1D339 TETRAGRAM FOR MEASURE
1D33A TETRAGRAM FOR ETERNITY
1D33B TETRAGRAM FOR UNITY
1D33C TETRAGRAM FOR DIMINISHMENT
1D33D TETRAGRAM FOR CLOSED MOUTH
1D33E TETRAGRAM FOR GUARDEDNESS
1D33F TETRAGRAM FOR GATHERING IN
1D340 TETRAGRAM FOR MASSING
1D341 TETRAGRAM FOR ACCUMULATION
1D342 TETRAGRAM FOR EMBELLISHMENT
1D343 TETRAGRAM FOR DOUBT
1D344 TETRAGRAM FOR WATCH
1D345 TETRAGRAM FOR SINKING
1D346 TETRAGRAM FOR INNER
1D347 TETRAGRAM FOR DEPARTURE
1D348 TETRAGRAM FOR DARKENING
1D349 TETRAGRAM FOR DIMMING
1D34A TETRAGRAM FOR EXHAUSTION
1D34B TETRAGRAM FOR SEVERANCE
1D34C TETRAGRAM FOR STOPPAGE
1D34D TETRAGRAM FOR HARDNESS
1D34E TETRAGRAM FOR COMPLETION
1D34F TETRAGRAM FOR CLOSURE
1D350 TETRAGRAM FOR FAILURE
1D351 TETRAGRAM FOR AGGRAVATION
1D352 TETRAGRAM FOR COMPLIANCE
1D353 TETRAGRAM FOR ON THE VERGE
1D354 TETRAGRAM FOR DIFFICULTIES
1D355 TETRAGRAM FOR LABOURING
1D356 TETRAGRAM FOR FOSTERING
1D360 COUNTING ROD UNIT DIGIT ONE
1D361 COUNTING ROD UNIT DIGIT TWO
1D362 COUNTING ROD UNIT DIGIT THREE
1D363 COUNTING ROD UNIT DIGIT FOUR
1D364 COUNTING ROD UNIT DIGIT FIVE
1D365 COUNTING ROD UNIT DIGIT SIX
1D366 COUNTING ROD UNIT DIGIT SEVEN
1D367 COUNTING ROD UNIT DIGIT EIGHT
1D368 COUNTING ROD UNIT DIGIT NINE
1D369 COUNTING ROD TENS DIGIT ONE
1D36A COUNTING ROD TENS DIGIT TWO
1D36B COUNTING ROD TENS DIGIT THREE
1D36C COUNTING ROD TENS DIGIT FOUR
1D36D COUNTING ROD TENS DIGIT FIVE
1D36E COUNTING ROD TENS DIGIT SIX
1D36F COUNTING ROD TENS DIGIT SEVEN
1D370 COUNTING ROD TENS DIGIT EIGHT
1D371 COUNTING ROD TENS DIGIT NINE
1D400 MATHEMATICAL BOLD CAPITAL A
1D401 MATHEMATICAL BOLD CAPITAL B
1D402 MATHEMATICAL BOLD CAPITAL C
1D403 MATHEMATICAL BOLD CAPITAL D
1D404 MATHEMATICAL BOLD CAPITAL E
1D405 MATHEMATICAL BOLD CAPITAL F
1D406 MATHEMATICAL BOLD CAPITAL G
1D407 MATHEMATICAL BOLD CAPITAL H
1D408 MATHEMATICAL BOLD CAPITAL I
1D409 MATHEMATICAL BOLD CAPITAL J
1D40A MATHEMATICAL BOLD CAPITAL K
1D40B MATHEMATICAL BOLD CAPITAL L
1D40C MATHEMATICAL BOLD CAPITAL M
1D40D MATHEMATICAL BOLD CAPITAL N
1D40E MATHEMATICAL BOLD CAPITAL O
1D40F MATHEMATICAL BOLD CAPITAL P
1D410 MATHEMATICAL BOLD CAPITAL Q
1D411 MATHEMATICAL BOLD CAPITAL R
1D412 MATHEMATICAL BOLD CAPITAL S
1D413 MATHEMATICAL BOLD CAPITAL T
1D414 MATHEMATICAL BOLD CAPITAL U
1D415 MATHEMATICAL BOLD CAPITAL V
1D416 MATHEMATICAL BOLD CAPITAL W
1D417 MATHEMATICAL BOLD CAPITAL X
1D418 MATHEMATICAL BOLD CAPITAL Y
1D419 MATHEMATICAL BOLD CAPITAL Z
1D41A MATHEMATICAL BOLD SMALL A
1D41B MATHEMATICAL BOLD SMALL B
1D41C MATHEMATICAL BOLD SMALL C
1D41D MATHEMATICAL BOLD SMALL D
1D41E MATHEMATICAL BOLD SMALL E
1D41F MATHEMATICAL BOLD SMALL F
1D420 MATHEMATICAL BOLD SMALL G
1D421 MATHEMATICAL BOLD SMALL H
1D422 MATHEMATICAL BOLD SMALL I
1D423 MATHEMATICAL BOLD SMALL J
1D424 MATHEMATICAL BOLD SMALL K
1D425 MATHEMATICAL BOLD SMALL L
1D426 MATHEMATICAL BOLD SMALL M
1D427 MATHEMATICAL BOLD SMALL N
1D428 MATHEMATICAL BOLD SMALL O
1D429 MATHEMATICAL BOLD SMALL P
1D42A MATHEMATICAL BOLD SMALL Q
1D42B MATHEMATICAL BOLD SMALL R
1D42C MATHEMATICAL BOLD SMALL S
1D42D MATHEMATICAL BOLD SMALL T
1D42E MATHEMATICAL BOLD SMALL U
1D42F MATHEMATICAL BOLD SMALL V
1D430 MATHEMATICAL BOLD SMALL W
1D431 MATHEMATICAL BOLD SMALL X
1D432 MATHEMATICAL BOLD SMALL Y
1D433 MATHEMATICAL BOLD SMALL Z
1D434 MATHEMATICAL ITALIC CAPITAL A
1D435 MATHEMATICAL ITALIC CAPITAL B
1D436 MATHEMATICAL ITALIC CAPITAL C
1D437 MATHEMATICAL ITALIC CAPITAL D
1D438 MATHEMATICAL ITALIC CAPITAL E
1D439 MATHEMATICAL ITALIC CAPITAL F
1D43A MATHEMATICAL ITALIC CAPITAL G
1D43B MATHEMATICAL ITALIC CAPITAL H
1D43C MATHEMATICAL ITALIC CAPITAL I
1D43D MATHEMATICAL ITALIC CAPITAL J
1D43E MATHEMATICAL ITALIC CAPITAL K
1D43F MATHEMATICAL ITALIC CAPITAL L
1D440 MATHEMATICAL ITALIC CAPITAL M
1D441 MATHEMATICAL ITALIC CAPITAL N
1D442 MATHEMATICAL ITALIC CAPITAL O
1D443 MATHEMATICAL ITALIC CAPITAL P
1D444 MATHEMATICAL ITALIC CAPITAL Q
1D445 MATHEMATICAL ITALIC CAPITAL R
1D446 MATHEMATICAL ITALIC CAPITAL S
1D447 MATHEMATICAL ITALIC CAPITAL T
1D448 MATHEMATICAL ITALIC CAPITAL U
1D449 MATHEMATICAL ITALIC CAPITAL V
1D44A MATHEMATICAL ITALIC CAPITAL W
1D44B MATHEMATICAL ITALIC CAPITAL X
1D44C MATHEMATICAL ITALIC CAPITAL Y
1D44D MATHEMATICAL ITALIC CAPITAL Z
1D44E MATHEMATICAL ITALIC SMALL A
1D44F MATHEMATICAL ITALIC SMALL B
1D450 MATHEMATICAL ITALIC SMALL C
1D451 MATHEMATICAL ITALIC SMALL D
1D452 MATHEMATICAL ITALIC SMALL E
1D453 MATHEMATICAL ITALIC SMALL F
1D454 MATHEMATICAL ITALIC SMALL G
1D456 MATHEMATICAL ITALIC SMALL I
1D457 MATHEMATICAL ITALIC SMALL J
1D458 MATHEMATICAL ITALIC SMALL K
1D459 MATHEMATICAL ITALIC SMALL L
1D45A MATHEMATICAL ITALIC SMALL M
1D45B MATHEMATICAL ITALIC SMALL N
1D45C MATHEMATICAL ITALIC SMALL O
1D45D MATHEMATICAL ITALIC SMALL P
1D45E MATHEMATICAL ITALIC SMALL Q
1D45F MATHEMATICAL ITALIC SMALL R
1D460 MATHEMATICAL ITALIC SMALL S
1D461 MATHEMATICAL ITALIC SMALL T
1D462 MATHEMATICAL ITALIC SMALL U
1D463 MATHEMATICAL ITALIC SMALL V
1D464 MATHEMATICAL ITALIC SMALL W
1D465 MATHEMATICAL ITALIC SMALL X
1D466 MATHEMATICAL ITALIC SMALL Y
1D467 MATHEMATICAL ITALIC SMALL Z
1D468 MATHEMATICAL BOLD ITALIC CAPITAL A
1D469 MATHEMATICAL BOLD ITALIC CAPITAL B
1D46A MATHEMATICAL BOLD ITALIC CAPITAL C
1D46B MATHEMATICAL BOLD ITALIC CAPITAL D
1D46C MATHEMATICAL BOLD ITALIC CAPITAL E
1D46D MATHEMATICAL BOLD ITALIC CAPITAL F
1D46E MATHEMATICAL BOLD ITALIC CAPITAL G
1D46F MATHEMATICAL BOLD ITALIC CAPITAL H
1D470 MATHEMATICAL BOLD ITALIC CAPITAL I
1D471 MATHEMATICAL BOLD ITALIC CAPITAL J
1D472 MATHEMATICAL BOLD ITALIC CAPITAL K
1D473 MATHEMATICAL BOLD ITALIC CAPITAL L
1D474 MATHEMATICAL BOLD ITALIC CAPITAL M
1D475 MATHEMATICAL BOLD ITALIC CAPITAL N
1D476 MATHEMATICAL BOLD ITALIC CAPITAL O
1D477 MATHEMATICAL BOLD ITALIC CAPITAL P
1D478 MATHEMATICAL BOLD ITALIC CAPITAL Q
1D479 MATHEMATICAL BOLD ITALIC CAPITAL R
1D47A MATHEMATICAL BOLD ITALIC CAPITAL S
1D47B MATHEMATICAL BOLD ITALIC CAPITAL T
1D47C MATHEMATICAL BOLD ITALIC CAPITAL U
1D47D MATHEMATICAL BOLD ITALIC CAPITAL V
1D47E MATHEMATICAL BOLD ITALIC CAPITAL W
1D47F MATHEMATICAL BOLD ITALIC CAPITAL X
1D480 MATHEMATICAL BOLD ITALIC CAPITAL Y
1D481 MATHEMATICAL BOLD ITALIC CAPITAL Z
1D482 MATHEMATICAL BOLD ITALIC SMALL A
1D483 MATHEMATICAL BOLD ITALIC SMALL B
1D484 MATHEMATICAL BOLD ITALIC SMALL C
1D485 MATHEMATICAL BOLD ITALIC SMALL D
1D486 MATHEMATICAL BOLD ITALIC SMALL E
1D487 MATHEMATICAL BOLD ITALIC SMALL F
1D488 MATHEMATICAL BOLD ITALIC SMALL G
1D489 MATHEMATICAL BOLD ITALIC SMALL H
1D48A MATHEMATICAL BOLD ITALIC SMALL I
1D48B MATHEMATICAL BOLD ITALIC SMALL J
1D48C MATHEMATICAL BOLD ITALIC SMALL K
1D48D MATHEMATICAL BOLD ITALIC SMALL L
1D48E MATHEMATICAL BOLD ITALIC SMALL M
1D48F MATHEMATICAL BOLD ITALIC SMALL N
1D490 MATHEMATICAL BOLD ITALIC SMALL O
1D491 MATHEMATICAL BOLD ITALIC SMALL P
1D492 MATHEMATICAL BOLD ITALIC SMALL Q
1D493 MATHEMATICAL BOLD ITALIC SMALL R
1D494 MATHEMATICAL BOLD ITALIC SMALL S
1D495 MATHEMATICAL BOLD ITALIC SMALL T
1D496 MATHEMATICAL BOLD ITALIC SMALL U
1D497 MATHEMATICAL BOLD ITALIC SMALL V
1D498 MATHEMATICAL BOLD ITALIC SMALL W
1D499 MATHEMATICAL BOLD ITALIC SMALL X
1D49A MATHEMATICAL BOLD ITALIC SMALL Y
1D49B MATHEMATICAL BOLD ITALIC SMALL Z
1D49C MATHEMATICAL SCRIPT CAPITAL A
1D49E MATHEMATICAL SCRIPT CAPITAL C
1D49F MATHEMATICAL SCRIPT CAPITAL D
1D4A2 MATHEMATICAL SCRIPT CAPITAL G
1D4A5 MATHEMATICAL SCRIPT CAPITAL J
1D4A6 MATHEMATICAL SCRIPT CAPITAL K
1D4A9 MATHEMATICAL SCRIPT CAPITAL N
1D4AA MATHEMATICAL SCRIPT CAPITAL O
1D4AB MATHEMATICAL SCRIPT CAPITAL P
1D4AC MATHEMATICAL SCRIPT CAPITAL Q
1D4AE MATHEMATICAL SCRIPT CAPITAL S
1D4AF MATHEMATICAL SCRIPT CAPITAL T
1D4B0 MATHEMATICAL SCRIPT CAPITAL U
1D4B1 MATHEMATICAL SCRIPT CAPITAL V
1D4B2 MATHEMATICAL SCRIPT CAPITAL W
1D4B3 MATHEMATICAL SCRIPT CAPITAL X
1D4B4 MATHEMATICAL SCRIPT CAPITAL Y
1D4B5 MATHEMATICAL SCRIPT CAPITAL Z
1D4B6 MATHEMATICAL SCRIPT SMALL A
1D4B7 MATHEMATICAL SCRIPT SMALL B
1D4B8 MATHEMATICAL SCRIPT SMALL C
1D4B9 MATHEMATICAL SCRIPT SMALL D
1D4BB MATHEMATICAL SCRIPT SMALL F
1D4BD MATHEMATICAL SCRIPT SMALL H
1D4BE MATHEMATICAL SCRIPT SMALL I
1D4BF MATHEMATICAL SCRIPT SMALL J
1D4C0 MATHEMATICAL SCRIPT SMALL K
1D4C1 MATHEMATICAL SCRIPT SMALL L
1D4C2 MATHEMATICAL SCRIPT SMALL M
1D4C3 MATHEMATICAL SCRIPT SMALL N
1D4C5 MATHEMATICAL SCRIPT SMALL P
1D4C6 MATHEMATICAL SCRIPT SMALL Q
1D4C7 MATHEMATICAL SCRIPT SMALL R
1D4C8 MATHEMATICAL SCRIPT SMALL S
1D4C9 MATHEMATICAL SCRIPT SMALL T
1D4CA MATHEMATICAL SCRIPT SMALL U
1D4CB MATHEMATICAL SCRIPT SMALL V
1D4CC MATHEMATICAL SCRIPT SMALL W
1D4CD MATHEMATICAL SCRIPT SMALL X
1D4CE MATHEMATICAL SCRIPT SMALL Y
1D4CF MATHEMATICAL SCRIPT SMALL Z
1D4D0 MATHEMATICAL BOLD SCRIPT CAPITAL A
1D4D1 MATHEMATICAL BOLD SCRIPT CAPITAL B
1D4D2 MATHEMATICAL BOLD SCRIPT CAPITAL C
1D4D3 MATHEMATICAL BOLD SCRIPT CAPITAL D
1D4D4 MATHEMATICAL BOLD SCRIPT CAPITAL E
1D4D5 MATHEMATICAL BOLD SCRIPT CAPITAL F
1D4D6 MATHEMATICAL BOLD SCRIPT CAPITAL G
1D4D7 MATHEMATICAL BOLD SCRIPT CAPITAL H
1D4D8 MATHEMATICAL BOLD SCRIPT CAPITAL I
1D4D9 MATHEMATICAL BOLD SCRIPT CAPITAL J
1D4DA MATHEMATICAL BOLD SCRIPT CAPITAL K
1D4DB MATHEMATICAL BOLD SCRIPT CAPITAL L
1D4DC MATHEMATICAL BOLD SCRIPT CAPITAL M
1D4DD MATHEMATICAL BOLD SCRIPT CAPITAL N
1D4DE MATHEMATICAL BOLD SCRIPT CAPITAL O
1D4DF MATHEMATICAL BOLD SCRIPT CAPITAL P
1D4E0 MATHEMATICAL BOLD SCRIPT CAPITAL Q
1D4E1 MATHEMATICAL BOLD SCRIPT CAPITAL R
1D4E2 MATHEMATICAL BOLD SCRIPT CAPITAL S
1D4E3 MATHEMATICAL BOLD SCRIPT CAPITAL T
1D4E4 MATHEMATICAL BOLD SCRIPT CAPITAL U
1D4E5 MATHEMATICAL BOLD SCRIPT CAPITAL V
1D4E6 MATHEMATICAL BOLD SCRIPT CAPITAL W
1D4E7 MATHEMATICAL BOLD SCRIPT CAPITAL X
1D4E8 MATHEMATICAL BOLD SCRIPT CAPITAL Y
1D4E9 MATHEMATICAL BOLD SCRIPT CAPITAL Z
1D4EA MATHEMATICAL BOLD SCRIPT SMALL A
1D4EB MATHEMATICAL BOLD SCRIPT SMALL B
1D4EC MATHEMATICAL BOLD SCRIPT SMALL C
1D4ED MATHEMATICAL BOLD SCRIPT SMALL D
1D4EE MATHEMATICAL BOLD SCRIPT SMALL E
1D4EF MATHEMATICAL BOLD SCRIPT SMALL F
1D4F0 MATHEMATICAL BOLD SCRIPT SMALL G
1D4F1 MATHEMATICAL BOLD SCRIPT SMALL H
1D4F2 MATHEMATICAL BOLD SCRIPT SMALL I
1D4F3 MATHEMATICAL BOLD SCRIPT SMALL J
1D4F4 MATHEMATICAL BOLD SCRIPT SMALL K
1D4F5 MATHEMATICAL BOLD SCRIPT SMALL L
1D4F6 MATHEMATICAL BOLD SCRIPT SMALL M
1D4F7 MATHEMATICAL BOLD SCRIPT SMALL N
1D4F8 MATHEMATICAL BOLD SCRIPT SMALL O
1D4F9 MATHEMATICAL BOLD SCRIPT SMALL P
1D4FA MATHEMATICAL BOLD SCRIPT SMALL Q
1D4FB MATHEMATICAL BOLD SCRIPT SMALL R
1D4FC MATHEMATICAL BOLD SCRIPT SMALL S
1D4FD MATHEMATICAL BOLD SCRIPT SMALL T
1D4FE MATHEMATICAL BOLD SCRIPT SMALL U
1D4FF MATHEMATICAL BOLD SCRIPT SMALL V
1D500 MATHEMATICAL BOLD SCRIPT SMALL W
1D501 MATHEMATICAL BOLD SCRIPT SMALL X
1D502 MATHEMATICAL BOLD SCRIPT SMALL Y
1D503 MATHEMATICAL BOLD SCRIPT SMALL Z
1D504 MATHEMATICAL FRAKTUR CAPITAL A
1D505 MATHEMATICAL FRAKTUR CAPITAL B
1D507 MATHEMATICAL FRAKTUR CAPITAL D
1D508 MATHEMATICAL FRAKTUR CAPITAL E
1D509 MATHEMATICAL FRAKTUR CAPITAL F
1D50A MATHEMATICAL FRAKTUR CAPITAL G
1D50D MATHEMATICAL FRAKTUR CAPITAL J
1D50E MATHEMATICAL FRAKTUR CAPITAL K
1D50F MATHEMATICAL FRAKTUR CAPITAL L
1D510 MATHEMATICAL FRAKTUR CAPITAL M
1D511 MATHEMATICAL FRAKTUR CAPITAL N
1D512 MATHEMATICAL FRAKTUR CAPITAL O
1D513 MATHEMATICAL FRAKTUR CAPITAL P
1D514 MATHEMATICAL FRAKTUR CAPITAL Q
1D516 MATHEMATICAL FRAKTUR CAPITAL S
1D517 MATHEMATICAL FRAKTUR CAPITAL T
1D518 MATHEMATICAL FRAKTUR CAPITAL U
1D519 MATHEMATICAL FRAKTUR CAPITAL V
1D51A MATHEMATICAL FRAKTUR CAPITAL W
1D51B MATHEMATICAL FRAKTUR CAPITAL X
1D51C MATHEMATICAL FRAKTUR CAPITAL Y
1D51E MATHEMATICAL FRAKTUR SMALL A
1D51F MATHEMATICAL FRAKTUR SMALL B
1D520 MATHEMATICAL FRAKTUR SMALL C
1D521 MATHEMATICAL FRAKTUR SMALL D
1D522 MATHEMATICAL FRAKTUR SMALL E
1D523 MATHEMATICAL FRAKTUR SMALL F
1D524 MATHEMATICAL FRAKTUR SMALL G
1D525 MATHEMATICAL FRAKTUR SMALL H
1D526 MATHEMATICAL FRAKTUR SMALL I
1D527 MATHEMATICAL FRAKTUR SMALL J
1D528 MATHEMATICAL FRAKTUR SMALL K
1D529 MATHEMATICAL FRAKTUR SMALL L
1D52A MATHEMATICAL FRAKTUR SMALL M
1D52B MATHEMATICAL FRAKTUR SMALL N
1D52C MATHEMATICAL FRAKTUR SMALL O
1D52D MATHEMATICAL FRAKTUR SMALL P
1D52E MATHEMATICAL FRAKTUR SMALL Q
1D52F MATHEMATICAL FRAKTUR SMALL R
1D530 MATHEMATICAL FRAKTUR SMALL S
1D531 MATHEMATICAL FRAKTUR SMALL T
1D532 MATHEMATICAL FRAKTUR SMALL U
1D533 MATHEMATICAL FRAKTUR SMALL V
1D534 MATHEMATICAL FRAKTUR SMALL W
1D535 MATHEMATICAL FRAKTUR SMALL X
1D536 MATHEMATICAL FRAKTUR SMALL Y
1D537 MATHEMATICAL FRAKTUR SMALL Z
1D538 MATHEMATICAL DOUBLE-STRUCK CAPITAL A
1D539 MATHEMATICAL DOUBLE-STRUCK CAPITAL B
1D53B MATHEMATICAL DOUBLE-STRUCK CAPITAL D
1D53C MATHEMATICAL DOUBLE-STRUCK CAPITAL E
1D53D MATHEMATICAL DOUBLE-STRUCK CAPITAL F
1D53E MATHEMATICAL DOUBLE-STRUCK CAPITAL G
1D540 MATHEMATICAL DOUBLE-STRUCK CAPITAL I
1D541 MATHEMATICAL DOUBLE-STRUCK CAPITAL J
1D542 MATHEMATICAL DOUBLE-STRUCK CAPITAL K
1D543 MATHEMATICAL DOUBLE-STRUCK CAPITAL L
1D544 MATHEMATICAL DOUBLE-STRUCK CAPITAL M
1D546 MATHEMATICAL DOUBLE-STRUCK CAPITAL O
1D54A MATHEMATICAL DOUBLE-STRUCK CAPITAL S
1D54B MATHEMATICAL DOUBLE-STRUCK CAPITAL T
1D54C MATHEMATICAL DOUBLE-STRUCK CAPITAL U
1D54D MATHEMATICAL DOUBLE-STRUCK CAPITAL V
1D54E MATHEMATICAL DOUBLE-STRUCK CAPITAL W
1D54F MATHEMATICAL DOUBLE-STRUCK CAPITAL X
1D550 MATHEMATICAL DOUBLE-STRUCK CAPITAL Y
1D552 MATHEMATICAL DOUBLE-STRUCK SMALL A
1D553 MATHEMATICAL DOUBLE-STRUCK SMALL B
1D554 MATHEMATICAL DOUBLE-STRUCK SMALL C
1D555 MATHEMATICAL DOUBLE-STRUCK SMALL D
1D556 MATHEMATICAL DOUBLE-STRUCK SMALL E
1D557 MATHEMATICAL DOUBLE-STRUCK SMALL F
1D558 MATHEMATICAL DOUBLE-STRUCK SMALL G
1D559 MATHEMATICAL DOUBLE-STRUCK SMALL H
1D55A MATHEMATICAL DOUBLE-STRUCK SMALL I
1D55B MATHEMATICAL DOUBLE-STRUCK SMALL J
1D55C MATHEMATICAL DOUBLE-STRUCK SMALL K
1D55D MATHEMATICAL DOUBLE-STRUCK SMALL L
1D55E MATHEMATICAL DOUBLE-STRUCK SMALL M
1D55F MATHEMATICAL DOUBLE-STRUCK SMALL N
1D560 MATHEMATICAL DOUBLE-STRUCK SMALL O
1D561 MATHEMATICAL DOUBLE-STRUCK SMALL P
1D562 MATHEMATICAL DOUBLE-STRUCK SMALL Q
1D563 MATHEMATICAL DOUBLE-STRUCK SMALL R
1D564 MATHEMATICAL DOUBLE-STRUCK SMALL S
1D565 MATHEMATICAL DOUBLE-STRUCK SMALL T
1D566 MATHEMATICAL DOUBLE-STRUCK SMALL U
1D567 MATHEMATICAL DOUBLE-STRUCK SMALL V
1D568 MATHEMATICAL DOUBLE-STRUCK SMALL W
1D569 MATHEMATICAL DOUBLE-STRUCK SMALL X
1D56A MATHEMATICAL DOUBLE-STRUCK SMALL Y
1D56B MATHEMATICAL DOUBLE-STRUCK SMALL Z
1D56C MATHEMATICAL BOLD FRAKTUR CAPITAL A
1D56D MATHEMATICAL BOLD FRAKTUR CAPITAL B
1D56E MATHEMATICAL BOLD FRAKTUR CAPITAL C
1D56F MATHEMATICAL BOLD FRAKTUR CAPITAL D
1D570 MATHEMATICAL BOLD FRAKTUR CAPITAL E
1D571 MATHEMATICAL BOLD FRAKTUR CAPITAL F
1D572 MATHEMATICAL BOLD FRAKTUR CAPITAL G
1D573 MATHEMATICAL BOLD FRAKTUR CAPITAL H
1D574 MATHEMATICAL BOLD FRAKTUR CAPITAL I
1D575 MATHEMATICAL BOLD FRAKTUR CAPITAL J
1D576 MATHEMATICAL BOLD FRAKTUR CAPITAL K
1D577 MATHEMATICAL BOLD FRAKTUR CAPITAL L
1D578 MATHEMATICAL BOLD FRAKTUR CAPITAL M
1D579 MATHEMATICAL BOLD FRAKTUR CAPITAL N
1D57A MATHEMATICAL BOLD FRAKTUR CAPITAL O
1D57B MATHEMATICAL BOLD FRAKTUR CAPITAL P
1D57C MATHEMATICAL BOLD FRAKTUR CAPITAL Q
1D57D MATHEMATICAL BOLD FRAKTUR CAPITAL R
1D57E MATHEMATICAL BOLD FRAKTUR CAPITAL S
1D57F MATHEMATICAL BOLD FRAKTUR CAPITAL T
1D580 MATHEMATICAL BOLD FRAKTUR CAPITAL U
1D581 MATHEMATICAL BOLD FRAKTUR CAPITAL V
1D582 MATHEMATICAL BOLD FRAKTUR CAPITAL W
1D583 MATHEMATICAL BOLD FRAKTUR CAPITAL X
1D584 MATHEMATICAL BOLD FRAKTUR CAPITAL Y
1D585 MATHEMATICAL BOLD FRAKTUR CAPITAL Z
1D586 MATHEMATICAL BOLD FRAKTUR SMALL A
1D587 MATHEMATICAL BOLD FRAKTUR SMALL B
1D588 MATHEMATICAL BOLD FRAKTUR SMALL C
1D589 MATHEMATICAL BOLD FRAKTUR SMALL D
1D58A MATHEMATICAL BOLD FRAKTUR SMALL E
1D58B MATHEMATICAL BOLD FRAKTUR SMALL F
1D58C MATHEMATICAL BOLD FRAKTUR SMALL G
1D58D MATHEMATICAL BOLD FRAKTUR SMALL H
1D58E MATHEMATICAL BOLD FRAKTUR SMALL I
1D58F MATHEMATICAL BOLD FRAKTUR SMALL J
1D590 MATHEMATICAL BOLD FRAKTUR SMALL K
1D591 MATHEMATICAL BOLD FRAKTUR SMALL L
1D592 MATHEMATICAL BOLD FRAKTUR SMALL M
1D593 MATHEMATICAL BOLD FRAKTUR SMALL N
1D594 MATHEMATICAL BOLD FRAKTUR SMALL O
1D595 MATHEMATICAL BOLD FRAKTUR SMALL P
1D596 MATHEMATICAL BOLD FRAKTUR SMALL Q
1D597 MATHEMATICAL BOLD FRAKTUR SMALL R
1D598 MATHEMATICAL BOLD FRAKTUR SMALL S
1D599 MATHEMATICAL BOLD FRAKTUR SMALL T
1D59A MATHEMATICAL BOLD FRAKTUR SMALL U
1D59B MATHEMATICAL BOLD FRAKTUR SMALL V
1D59C MATHEMATICAL BOLD FRAKTUR SMALL W
1D59D MATHEMATICAL BOLD FRAKTUR SMALL X
1D59E MATHEMATICAL BOLD FRAKTUR SMALL Y
1D59F MATHEMATICAL BOLD FRAKTUR SMALL Z
1D5A0 MATHEMATICAL SANS-SERIF CAPITAL A
1D5A1 MATHEMATICAL SANS-SERIF CAPITAL B
1D5A2 MATHEMATICAL SANS-SERIF CAPITAL C
1D5A3 MATHEMATICAL SANS-SERIF CAPITAL D
1D5A4 MATHEMATICAL SANS-SERIF CAPITAL E
1D5A5 MATHEMATICAL SANS-SERIF CAPITAL F
1D5A6 MATHEMATICAL SANS-SERIF CAPITAL G
1D5A7 MATHEMATICAL SANS-SERIF CAPITAL H
1D5A8 MATHEMATICAL SANS-SERIF CAPITAL I
1D5A9 MATHEMATICAL SANS-SERIF CAPITAL J
1D5AA MATHEMATICAL SANS-SERIF CAPITAL K
1D5AB MATHEMATICAL SANS-SERIF CAPITAL L
1D5AC MATHEMATICAL SANS-SERIF CAPITAL M
1D5AD MATHEMATICAL SANS-SERIF CAPITAL N
1D5AE MATHEMATICAL SANS-SERIF CAPITAL O
1D5AF MATHEMATICAL SANS-SERIF CAPITAL P
1D5B0 MATHEMATICAL SANS-SERIF CAPITAL Q
1D5B1 MATHEMATICAL SANS-SERIF CAPITAL R
1D5B2 MATHEMATICAL SANS-SERIF CAPITAL S
1D5B3 MATHEMATICAL SANS-SERIF CAPITAL T
1D5B4 MATHEMATICAL SANS-SERIF CAPITAL U
1D5B5 MATHEMATICAL SANS-SERIF CAPITAL V
1D5B6 MATHEMATICAL SANS-SERIF CAPITAL W
1D5B7 MATHEMATICAL SANS-SERIF CAPITAL X
1D5B8 MATHEMATICAL SANS-SERIF CAPITAL Y
1D5B9 MATHEMATICAL SANS-SERIF CAPITAL Z
1D5BA MATHEMATICAL SANS-SERIF SMALL A
1D5BB MATHEMATICAL SANS-SERIF SMALL B
1D5BC MATHEMATICAL SANS-SERIF SMALL C
1D5BD MATHEMATICAL SANS-SERIF SMALL D
1D5BE MATHEMATICAL SANS-SERIF SMALL E
1D5BF MATHEMATICAL SANS-SERIF SMALL F
1D5C0 MATHEMATICAL SANS-SERIF SMALL G
1D5C1 MATHEMATICAL SANS-SERIF SMALL H
1D5C2 MATHEMATICAL SANS-SERIF SMALL I
1D5C3 MATHEMATICAL SANS-SERIF SMALL J
1D5C4 MATHEMATICAL SANS-SERIF SMALL K
1D5C5 MATHEMATICAL SANS-SERIF SMALL L
1D5C6 MATHEMATICAL SANS-SERIF SMALL M
1D5C7 MATHEMATICAL SANS-SERIF SMALL N
1D5C8 MATHEMATICAL SANS-SERIF SMALL O
1D5C9 MATHEMATICAL SANS-SERIF SMALL P
1D5CA MATHEMATICAL SANS-SERIF SMALL Q
1D5CB MATHEMATICAL SANS-SERIF SMALL R
1D5CC MATHEMATICAL SANS-SERIF SMALL S
1D5CD MATHEMATICAL SANS-SERIF SMALL T
1D5CE MATHEMATICAL SANS-SERIF SMALL U
1D5CF MATHEMATICAL SANS-SERIF SMALL V
1D5D0 MATHEMATICAL SANS-SERIF SMALL W
1D5D1 MATHEMATICAL SANS-SERIF SMALL X
1D5D2 MATHEMATICAL SANS-SERIF SMALL Y
1D5D3 MATHEMATICAL SANS-SERIF SMALL Z
1D5D4 MATHEMATICAL SANS-SERIF BOLD CAPITAL A
1D5D5 MATHEMATICAL SANS-SERIF BOLD CAPITAL B
1D5D6 MATHEMATICAL SANS-SERIF BOLD CAPITAL C
1D5D7 MATHEMATICAL SANS-SERIF BOLD CAPITAL D
1D5D8 MATHEMATICAL SANS-SERIF BOLD CAPITAL E
1D5D9 MATHEMATICAL SANS-SERIF BOLD CAPITAL F
1D5DA MATHEMATICAL SANS-SERIF BOLD CAPITAL G
1D5DB MATHEMATICAL SANS-SERIF BOLD CAPITAL H
1D5DC MATHEMATICAL SANS-SERIF BOLD CAPITAL I
1D5DD MATHEMATICAL SANS-SERIF BOLD CAPITAL J
1D5DE MATHEMATICAL SANS-SERIF BOLD CAPITAL K
1D5DF MATHEMATICAL SANS-SERIF BOLD CAPITAL L
1D5E0 MATHEMATICAL SANS-SERIF BOLD CAPITAL M
1D5E1 MATHEMATICAL SANS-SERIF BOLD CAPITAL N
1D5E2 MATHEMATICAL SANS-SERIF BOLD CAPITAL O
1D5E3 MATHEMATICAL SANS-SERIF BOLD CAPITAL P
1D5E4 MATHEMATICAL SANS-SERIF BOLD CAPITAL Q
1D5E5 MATHEMATICAL SANS-SERIF BOLD CAPITAL R
1D5E6 MATHEMATICAL SANS-SERIF BOLD CAPITAL S
1D5E7 MATHEMATICAL SANS-SERIF BOLD CAPITAL T
1D5E8 MATHEMATICAL SANS-SERIF BOLD CAPITAL U
1D5E9 MATHEMATICAL SANS-SERIF BOLD CAPITAL V
1D5EA MATHEMATICAL SANS-SERIF BOLD CAPITAL W
1D5EB MATHEMATICAL SANS-SERIF BOLD CAPITAL X
1D5EC MATHEMATICAL SANS-SERIF BOLD CAPITAL Y
1D5ED MATHEMATICAL SANS-SERIF BOLD CAPITAL Z
1D5EE MATHEMATICAL SANS-SERIF BOLD SMALL A
1D5EF MATHEMATICAL SANS-SERIF BOLD SMALL B
1D5F0 MATHEMATICAL SANS-SERIF BOLD SMALL C
1D5F1 MATHEMATICAL SANS-SERIF BOLD SMALL D
1D5F2 MATHEMATICAL SANS-SERIF BOLD SMALL E
1D5F3 MATHEMATICAL SANS-SERIF BOLD SMALL F
1D5F4 MATHEMATICAL SANS-SERIF BOLD SMALL G
1D5F5 MATHEMATICAL SANS-SERIF BOLD SMALL H
1D5F6 MATHEMATICAL SANS-SERIF BOLD SMALL I
1D5F7 MATHEMATICAL SANS-SERIF BOLD SMALL J
1D5F8 MATHEMATICAL SANS-SERIF BOLD SMALL K
1D5F9 MATHEMATICAL SANS-SERIF BOLD SMALL L
1D5FA MATHEMATICAL SANS-SERIF BOLD SMALL M
1D5FB MATHEMATICAL SANS-SERIF BOLD SMALL N
1D5FC MATHEMATICAL SANS-SERIF BOLD SMALL O
1D5FD MATHEMATICAL SANS-SERIF BOLD SMALL P
1D5FE MATHEMATICAL SANS-SERIF BOLD SMALL Q
1D5FF MATHEMATICAL SANS-SERIF BOLD SMALL R
1D600 MATHEMATICAL SANS-SERIF BOLD SMALL S
1D601 MATHEMATICAL SANS-SERIF BOLD SMALL T
1D602 MATHEMATICAL SANS-SERIF BOLD SMALL U
1D603 MATHEMATICAL SANS-SERIF BOLD SMALL V
1D604 MATHEMATICAL SANS-SERIF BOLD SMALL W
1D605 MATHEMATICAL SANS-SERIF BOLD SMALL X
1D606 MATHEMATICAL SANS-SERIF BOLD SMALL Y
1D607 MATHEMATICAL SANS-SERIF BOLD SMALL Z
1D608 MATHEMATICAL SANS-SERIF ITALIC CAPITAL A
1D609 MATHEMATICAL SANS-SERIF ITALIC CAPITAL B
1D60A MATHEMATICAL SANS-SERIF ITALIC CAPITAL C
1D60B MATHEMATICAL SANS-SERIF ITALIC CAPITAL D
1D60C MATHEMATICAL SANS-SERIF ITALIC CAPITAL E
1D60D MATHEMATICAL SANS-SERIF ITALIC CAPITAL F
1D60E MATHEMATICAL SANS-SERIF ITALIC CAPITAL G
1D60F MATHEMATICAL SANS-SERIF ITALIC CAPITAL H
1D610 MATHEMATICAL SANS-SERIF ITALIC CAPITAL I
1D611 MATHEMATICAL SANS-SERIF ITALIC CAPITAL J
1D612 MATHEMATICAL SANS-SERIF ITALIC CAPITAL K
1D613 MATHEMATICAL SANS-SERIF ITALIC CAPITAL L
1D614 MATHEMATICAL SANS-SERIF ITALIC CAPITAL M
1D615 MATHEMATICAL SANS-SERIF ITALIC CAPITAL N
1D616 MATHEMATICAL SANS-SERIF ITALIC CAPITAL O
1D617 MATHEMATICAL SANS-SERIF ITALIC CAPITAL P
1D618 MATHEMATICAL SANS-SERIF ITALIC CAPITAL Q
1D619 MATHEMATICAL SANS-SERIF ITALIC CAPITAL R
1D61A MATHEMATICAL SANS-SERIF ITALIC CAPITAL S
1D61B MATHEMATICAL SANS-SERIF ITALIC CAPITAL T
1D61C MATHEMATICAL SANS-SERIF ITALIC CAPITAL U
1D61D MATHEMATICAL SANS-SERIF ITALIC CAPITAL V
1D61E MATHEMATICAL SANS-SERIF ITALIC CAPITAL W
1D61F MATHEMATICAL SANS-SERIF ITALIC CAPITAL X
1D620 MATHEMATICAL SANS-SERIF ITALIC CAPITAL Y
1D621 MATHEMATICAL SANS-SERIF ITALIC CAPITAL Z
1D622 MATHEMATICAL SANS-SERIF ITALIC SMALL A
1D623 MATHEMATICAL SANS-SERIF ITALIC SMALL B
1D624 MATHEMATICAL SANS-SERIF ITALIC SMALL C
1D625 MATHEMATICAL SANS-SERIF ITALIC SMALL D
1D626 MATHEMATICAL SANS-SERIF ITALIC SMALL E
1D627 MATHEMATICAL SANS-SERIF ITALIC SMALL F
1D628 MATHEMATICAL SANS-SERIF ITALIC SMALL G
1D629 MATHEMATICAL SANS-SERIF ITALIC SMALL H
1D62A MATHEMATICAL SANS-SERIF ITALIC SMALL I
1D62B MATHEMATICAL SANS-SERIF ITALIC SMALL J
1D62C MATHEMATICAL SANS-SERIF ITALIC SMALL K
1D62D MATHEMATICAL SANS-SERIF ITALIC SMALL L
1D62E MATHEMATICAL SANS-SERIF ITALIC SMALL M
1D62F MATHEMATICAL SANS-SERIF ITALIC SMALL N
1D630 MATHEMATICAL SANS-SERIF ITALIC SMALL O
1D631 MATHEMATICAL SANS-SERIF ITALIC SMALL P
1D632 MATHEMATICAL SANS-SERIF ITALIC SMALL Q
1D633 MATHEMATICAL SANS-SERIF ITALIC SMALL R
1D634 MATHEMATICAL SANS-SERIF ITALIC SMALL S
1D635 MATHEMATICAL SANS-SERIF ITALIC SMALL T
1D636 MATHEMATICAL SANS-SERIF ITALIC SMALL U
1D637 MATHEMATICAL SANS-SERIF ITALIC SMALL V
1D638 MATHEMATICAL SANS-SERIF ITALIC SMALL W
1D639 MATHEMATICAL SANS-SERIF ITALIC SMALL X
1D63A MATHEMATICAL SANS-SERIF ITALIC SMALL Y
1D63B MATHEMATICAL SANS-SERIF ITALIC SMALL Z
1D63C MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL A
1D63D MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL B
1D63E MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL C
1D63F MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL D
1D640 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL E
1D641 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL F
1D642 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL G
1D643 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL H
1D644 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL I
1D645 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL J
1D646 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL K
1D647 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL L
1D648 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL M
1D649 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL N
1D64A MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL O
1D64B MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL P
1D64C MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Q
1D64D MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL R
1D64E MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL S
1D64F MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL T
1D650 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL U
1D651 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL V
1D652 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL W
1D653 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL X
1D654 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Y
1D655 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL Z
1D656 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL A
1D657 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL B
1D658 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL C
1D659 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL D
1D65A MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL E
1D65B MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL F
1D65C MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL G
1D65D MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL H
1D65E MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL I
1D65F MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL J
1D660 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL K
1D661 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL L
1D662 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL M
1D663 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL N
1D664 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL O
1D665 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL P
1D666 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Q
1D667 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL R
1D668 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL S
1D669 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL T
1D66A MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL U
1D66B MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL V
1D66C MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL W
1D66D MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL X
1D66E MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Y
1D66F MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL Z
1D670 MATHEMATICAL MONOSPACE CAPITAL A
1D671 MATHEMATICAL MONOSPACE CAPITAL B
1D672 MATHEMATICAL MONOSPACE CAPITAL C
1D673 MATHEMATICAL MONOSPACE CAPITAL D
1D674 MATHEMATICAL MONOSPACE CAPITAL E
1D675 MATHEMATICAL MONOSPACE CAPITAL F
1D676 MATHEMATICAL MONOSPACE CAPITAL G
1D677 MATHEMATICAL MONOSPACE CAPITAL H
1D678 MATHEMATICAL MONOSPACE CAPITAL I
1D679 MATHEMATICAL MONOSPACE CAPITAL J
1D67A MATHEMATICAL MONOSPACE CAPITAL K
1D67B MATHEMATICAL MONOSPACE CAPITAL L
1D67C MATHEMATICAL MONOSPACE CAPITAL M
1D67D MATHEMATICAL MONOSPACE CAPITAL N
1D67E MATHEMATICAL MONOSPACE CAPITAL O
1D67F MATHEMATICAL MONOSPACE CAPITAL P
1D680 MATHEMATICAL MONOSPACE CAPITAL Q
1D681 MATHEMATICAL MONOSPACE CAPITAL R
1D682 MATHEMATICAL MONOSPACE CAPITAL S
1D683 MATHEMATICAL MONOSPACE CAPITAL T
1D684 MATHEMATICAL MONOSPACE CAPITAL U
1D685 MATHEMATICAL MONOSPACE CAPITAL V
1D686 MATHEMATICAL MONOSPACE CAPITAL W
1D687 MATHEMATICAL MONOSPACE CAPITAL X
1D688 MATHEMATICAL MONOSPACE CAPITAL Y
1D689 MATHEMATICAL MONOSPACE CAPITAL Z
1D68A MATHEMATICAL MONOSPACE SMALL A
1D68B MATHEMATICAL MONOSPACE SMALL B
1D68C MATHEMATICAL MONOSPACE SMALL C
1D68D MATHEMATICAL MONOSPACE SMALL D
1D68E MATHEMATICAL MONOSPACE SMALL E
1D68F MATHEMATICAL MONOSPACE SMALL F
1D690 MATHEMATICAL MONOSPACE SMALL G
1D691 MATHEMATICAL MONOSPACE SMALL H
1D692 MATHEMATICAL MONOSPACE SMALL I
1D693 MATHEMATICAL MONOSPACE SMALL J
1D694 MATHEMATICAL MONOSPACE SMALL K
1D695 MATHEMATICAL MONOSPACE SMALL L
1D696 MATHEMATICAL MONOSPACE SMALL M
1D697 MATHEMATICAL MONOSPACE SMALL N
1D698 MATHEMATICAL MONOSPACE SMALL O
1D699 MATHEMATICAL MONOSPACE SMALL P
1D69A MATHEMATICAL MONOSPACE SMALL Q
1D69B MATHEMATICAL MONOSPACE SMALL R
1D69C MATHEMATICAL MONOSPACE SMALL S
1D69D MATHEMATICAL MONOSPACE SMALL T
1D69E MATHEMATICAL MONOSPACE SMALL U
1D69F MATHEMATICAL MONOSPACE SMALL V
1D6A0 MATHEMATICAL MONOSPACE SMALL W
1D6A1 MATHEMATICAL MONOSPACE SMALL X
1D6A2 MATHEMATICAL MONOSPACE SMALL Y
1D6A3 MATHEMATICAL MONOSPACE SMALL Z
1D6A4 MATHEMATICAL ITALIC SMALL DOTLESS I
1D6A5 MATHEMATICAL ITALIC SMALL DOTLESS J
1D6A8 MATHEMATICAL BOLD CAPITAL ALPHA
1D6A9 MATHEMATICAL BOLD CAPITAL BETA
1D6AA MATHEMATICAL BOLD CAPITAL GAMMA
1D6AB MATHEMATICAL BOLD CAPITAL DELTA
1D6AC MATHEMATICAL BOLD CAPITAL EPSILON
1D6AD MATHEMATICAL BOLD CAPITAL ZETA
1D6AE MATHEMATICAL BOLD CAPITAL ETA
1D6AF MATHEMATICAL BOLD CAPITAL THETA
1D6B0 MATHEMATICAL BOLD CAPITAL IOTA
1D6B1 MATHEMATICAL BOLD CAPITAL KAPPA
1D6B2 MATHEMATICAL BOLD CAPITAL LAMDA
1D6B3 MATHEMATICAL BOLD CAPITAL MU
1D6B4 MATHEMATICAL BOLD CAPITAL NU
1D6B5 MATHEMATICAL BOLD CAPITAL XI
1D6B6 MATHEMATICAL BOLD CAPITAL OMICRON
1D6B7 MATHEMATICAL BOLD CAPITAL PI
1D6B8 MATHEMATICAL BOLD CAPITAL RHO
1D6B9 MATHEMATICAL BOLD CAPITAL THETA SYMBOL
1D6BA MATHEMATICAL BOLD CAPITAL SIGMA
1D6BB MATHEMATICAL BOLD CAPITAL TAU
1D6BC MATHEMATICAL BOLD CAPITAL UPSILON
1D6BD MATHEMATICAL BOLD CAPITAL PHI
1D6BE MATHEMATICAL BOLD CAPITAL CHI
1D6BF MATHEMATICAL BOLD CAPITAL PSI
1D6C0 MATHEMATICAL BOLD CAPITAL OMEGA
1D6C1 MATHEMATICAL BOLD NABLA
1D6C2 MATHEMATICAL BOLD SMALL ALPHA
1D6C3 MATHEMATICAL BOLD SMALL BETA
1D6C4 MATHEMATICAL BOLD SMALL GAMMA
1D6C5 MATHEMATICAL BOLD SMALL DELTA
1D6C6 MATHEMATICAL BOLD SMALL EPSILON
1D6C7 MATHEMATICAL BOLD SMALL ZETA
1D6C8 MATHEMATICAL BOLD SMALL ETA
1D6C9 MATHEMATICAL BOLD SMALL THETA
1D6CA MATHEMATICAL BOLD SMALL IOTA
1D6CB MATHEMATICAL BOLD SMALL KAPPA
1D6CC MATHEMATICAL BOLD SMALL LAMDA
1D6CD MATHEMATICAL BOLD SMALL MU
1D6CE MATHEMATICAL BOLD SMALL NU
1D6CF MATHEMATICAL BOLD SMALL XI
1D6D0 MATHEMATICAL BOLD SMALL OMICRON
1D6D1 MATHEMATICAL BOLD SMALL PI
1D6D2 MATHEMATICAL BOLD SMALL RHO
1D6D3 MATHEMATICAL BOLD SMALL FINAL SIGMA
1D6D4 MATHEMATICAL BOLD SMALL SIGMA
1D6D5 MATHEMATICAL BOLD SMALL TAU
1D6D6 MATHEMATICAL BOLD SMALL UPSILON
1D6D7 MATHEMATICAL BOLD SMALL PHI
1D6D8 MATHEMATICAL BOLD SMALL CHI
1D6D9 MATHEMATICAL BOLD SMALL PSI
1D6DA MATHEMATICAL BOLD SMALL OMEGA
1D6DB MATHEMATICAL BOLD PARTIAL DIFFERENTIAL
1D6DC MATHEMATICAL BOLD EPSILON SYMBOL
1D6DD MATHEMATICAL BOLD THETA SYMBOL
1D6DE MATHEMATICAL BOLD KAPPA SYMBOL
1D6DF MATHEMATICAL BOLD PHI SYMBOL
1D6E0 MATHEMATICAL BOLD RHO SYMBOL
1D6E1 MATHEMATICAL BOLD PI SYMBOL
1D6E2 MATHEMATICAL ITALIC CAPITAL ALPHA
1D6E3 MATHEMATICAL ITALIC CAPITAL BETA
1D6E4 MATHEMATICAL ITALIC CAPITAL GAMMA
1D6E5 MATHEMATICAL ITALIC CAPITAL DELTA
1D6E6 MATHEMATICAL ITALIC CAPITAL EPSILON
1D6E7 MATHEMATICAL ITALIC CAPITAL ZETA
1D6E8 MATHEMATICAL ITALIC CAPITAL ETA
1D6E9 MATHEMATICAL ITALIC CAPITAL THETA
1D6EA MATHEMATICAL ITALIC CAPITAL IOTA
1D6EB MATHEMATICAL ITALIC CAPITAL KAPPA
1D6EC MATHEMATICAL ITALIC CAPITAL LAMDA
1D6ED MATHEMATICAL ITALIC CAPITAL MU
1D6EE MATHEMATICAL ITALIC CAPITAL NU
1D6EF MATHEMATICAL ITALIC CAPITAL XI
1D6F0 MATHEMATICAL ITALIC CAPITAL OMICRON
1D6F1 MATHEMATICAL ITALIC CAPITAL PI
1D6F2 MATHEMATICAL ITALIC CAPITAL RHO
1D6F3 MATHEMATICAL ITALIC CAPITAL THETA SYMBOL
1D6F4 MATHEMATICAL ITALIC CAPITAL SIGMA
1D6F5 MATHEMATICAL ITALIC CAPITAL TAU
1D6F6 MATHEMATICAL ITALIC CAPITAL UPSILON
1D6F7 MATHEMATICAL ITALIC CAPITAL PHI
1D6F8 MATHEMATICAL ITALIC CAPITAL CHI
1D6F9 MATHEMATICAL ITALIC CAPITAL PSI
1D6FA MATHEMATICAL ITALIC CAPITAL OMEGA
1D6FB MATHEMATICAL ITALIC NABLA
1D6FC MATHEMATICAL ITALIC SMALL ALPHA
1D6FD MATHEMATICAL ITALIC SMALL BETA
1D6FE MATHEMATICAL ITALIC SMALL GAMMA
1D6FF MATHEMATICAL ITALIC SMALL DELTA
1D700 MATHEMATICAL ITALIC SMALL EPSILON
1D701 MATHEMATICAL ITALIC SMALL ZETA
1D702 MATHEMATICAL ITALIC SMALL ETA
1D703 MATHEMATICAL ITALIC SMALL THETA
1D704 MATHEMATICAL ITALIC SMALL IOTA
1D705 MATHEMATICAL ITALIC SMALL KAPPA
1D706 MATHEMATICAL ITALIC SMALL LAMDA
1D707 MATHEMATICAL ITALIC SMALL MU
1D708 MATHEMATICAL ITALIC SMALL NU
1D709 MATHEMATICAL ITALIC SMALL XI
1D70A MATHEMATICAL ITALIC SMALL OMICRON
1D70B MATHEMATICAL ITALIC SMALL PI
1D70C MATHEMATICAL ITALIC SMALL RHO
1D70D MATHEMATICAL ITALIC SMALL FINAL SIGMA
1D70E MATHEMATICAL ITALIC SMALL SIGMA
1D70F MATHEMATICAL ITALIC SMALL TAU
1D710 MATHEMATICAL ITALIC SMALL UPSILON
1D711 MATHEMATICAL ITALIC SMALL PHI
1D712 MATHEMATICAL ITALIC SMALL CHI
1D713 MATHEMATICAL ITALIC SMALL PSI
1D714 MATHEMATICAL ITALIC SMALL OMEGA
1D715 MATHEMATICAL ITALIC PARTIAL DIFFERENTIAL
1D716 MATHEMATICAL ITALIC EPSILON SYMBOL
1D717 MATHEMATICAL ITALIC THETA SYMBOL
1D718 MATHEMATICAL ITALIC KAPPA SYMBOL
1D719 MATHEMATICAL ITALIC PHI SYMBOL
1D71A MATHEMATICAL ITALIC RHO SYMBOL
1D71B MATHEMATICAL ITALIC PI SYMBOL
1D71C MATHEMATICAL BOLD ITALIC CAPITAL ALPHA
1D71D MATHEMATICAL BOLD ITALIC CAPITAL BETA
1D71E MATHEMATICAL BOLD ITALIC CAPITAL GAMMA
1D71F MATHEMATICAL BOLD ITALIC CAPITAL DELTA
1D720 MATHEMATICAL BOLD ITALIC CAPITAL EPSILON
1D721 MATHEMATICAL BOLD ITALIC CAPITAL ZETA
1D722 MATHEMATICAL BOLD ITALIC CAPITAL ETA
1D723 MATHEMATICAL BOLD ITALIC CAPITAL THETA
1D724 MATHEMATICAL BOLD ITALIC CAPITAL IOTA
1D725 MATHEMATICAL BOLD ITALIC CAPITAL KAPPA
1D726 MATHEMATICAL BOLD ITALIC CAPITAL LAMDA
1D727 MATHEMATICAL BOLD ITALIC CAPITAL MU
1D728 MATHEMATICAL BOLD ITALIC CAPITAL NU
1D729 MATHEMATICAL BOLD ITALIC CAPITAL XI
1D72A MATHEMATICAL BOLD ITALIC CAPITAL OMICRON
1D72B MATHEMATICAL BOLD ITALIC CAPITAL PI
1D72C MATHEMATICAL BOLD ITALIC CAPITAL RHO
1D72D MATHEMATICAL BOLD ITALIC CAPITAL THETA SYMBOL
1D72E MATHEMATICAL BOLD ITALIC CAPITAL SIGMA
1D72F MATHEMATICAL BOLD ITALIC CAPITAL TAU
1D730 MATHEMATICAL BOLD ITALIC CAPITAL UPSILON
1D731 MATHEMATICAL BOLD ITALIC CAPITAL PHI
1D732 MATHEMATICAL BOLD ITALIC CAPITAL CHI
1D733 MATHEMATICAL BOLD ITALIC CAPITAL PSI
1D734 MATHEMATICAL BOLD ITALIC CAPITAL OMEGA
1D735 MATHEMATICAL BOLD ITALIC NABLA
1D736 MATHEMATICAL BOLD ITALIC SMALL ALPHA
1D737 MATHEMATICAL BOLD ITALIC SMALL BETA
1D738 MATHEMATICAL BOLD ITALIC SMALL GAMMA
1D739 MATHEMATICAL BOLD ITALIC SMALL DELTA
1D73A MATHEMATICAL BOLD ITALIC SMALL EPSILON
1D73B MATHEMATICAL BOLD ITALIC SMALL ZETA
1D73C MATHEMATICAL BOLD ITALIC SMALL ETA
1D73D MATHEMATICAL BOLD ITALIC SMALL THETA
1D73E MATHEMATICAL BOLD ITALIC SMALL IOTA
1D73F MATHEMATICAL BOLD ITALIC SMALL KAPPA
1D740 MATHEMATICAL BOLD ITALIC SMALL LAMDA
1D741 MATHEMATICAL BOLD ITALIC SMALL MU
1D742 MATHEMATICAL BOLD ITALIC SMALL NU
1D743 MATHEMATICAL BOLD ITALIC SMALL XI
1D744 MATHEMATICAL BOLD ITALIC SMALL OMICRON
1D745 MATHEMATICAL BOLD ITALIC SMALL PI
1D746 MATHEMATICAL BOLD ITALIC SMALL RHO
1D747 MATHEMATICAL BOLD ITALIC SMALL FINAL SIGMA
1D748 MATHEMATICAL BOLD ITALIC SMALL SIGMA
1D749 MATHEMATICAL BOLD ITALIC SMALL TAU
1D74A MATHEMATICAL BOLD ITALIC SMALL UPSILON
1D74B MATHEMATICAL BOLD ITALIC SMALL PHI
1D74C MATHEMATICAL BOLD ITALIC SMALL CHI
1D74D MATHEMATICAL BOLD ITALIC SMALL PSI
1D74E MATHEMATICAL BOLD ITALIC SMALL OMEGA
1D74F MATHEMATICAL BOLD ITALIC PARTIAL DIFFERENTIAL
1D750 MATHEMATICAL BOLD ITALIC EPSILON SYMBOL
1D751 MATHEMATICAL BOLD ITALIC THETA SYMBOL
1D752 MATHEMATICAL BOLD ITALIC KAPPA SYMBOL
1D753 MATHEMATICAL BOLD ITALIC PHI SYMBOL
1D754 MATHEMATICAL BOLD ITALIC RHO SYMBOL
1D755 MATHEMATICAL BOLD ITALIC PI SYMBOL
1D756 MATHEMATICAL SANS-SERIF BOLD CAPITAL ALPHA
1D757 MATHEMATICAL SANS-SERIF BOLD CAPITAL BETA
1D758 MATHEMATICAL SANS-SERIF BOLD CAPITAL GAMMA
1D759 MATHEMATICAL SANS-SERIF BOLD CAPITAL DELTA
1D75A MATHEMATICAL SANS-SERIF BOLD CAPITAL EPSILON
1D75B MATHEMATICAL SANS-SERIF BOLD CAPITAL ZETA
1D75C MATHEMATICAL SANS-SERIF BOLD CAPITAL ETA
1D75D MATHEMATICAL SANS-SERIF BOLD CAPITAL THETA
1D75E MATHEMATICAL SANS-SERIF BOLD CAPITAL IOTA
1D75F MATHEMATICAL SANS-SERIF BOLD CAPITAL KAPPA
1D760 MATHEMATICAL SANS-SERIF BOLD CAPITAL LAMDA
1D761 MATHEMATICAL SANS-SERIF BOLD CAPITAL MU
1D762 MATHEMATICAL SANS-SERIF BOLD CAPITAL NU
1D763 MATHEMATICAL SANS-SERIF BOLD CAPITAL XI
1D764 MATHEMATICAL SANS-SERIF BOLD CAPITAL OMICRON
1D765 MATHEMATICAL SANS-SERIF BOLD CAPITAL PI
1D766 MATHEMATICAL SANS-SERIF BOLD CAPITAL RHO
1D767 MATHEMATICAL SANS-SERIF BOLD CAPITAL THETA SYMBOL
1D768 MATHEMATICAL SANS-SERIF BOLD CAPITAL SIGMA
1D769 MATHEMATICAL SANS-SERIF BOLD CAPITAL TAU
1D76A MATHEMATICAL SANS-SERIF BOLD CAPITAL UPSILON
1D76B MATHEMATICAL SANS-SERIF BOLD CAPITAL PHI
1D76C MATHEMATICAL SANS-SERIF BOLD CAPITAL CHI
1D76D MATHEMATICAL SANS-SERIF BOLD CAPITAL PSI
1D76E MATHEMATICAL SANS-SERIF BOLD CAPITAL OMEGA
1D76F MATHEMATICAL SANS-SERIF BOLD NABLA
1D770 MATHEMATICAL SANS-SERIF BOLD SMALL ALPHA
1D771 MATHEMATICAL SANS-SERIF BOLD SMALL BETA
1D772 MATHEMATICAL SANS-SERIF BOLD SMALL GAMMA
1D773 MATHEMATICAL SANS-SERIF BOLD SMALL DELTA
1D774 MATHEMATICAL SANS-SERIF BOLD SMALL EPSILON
1D775 MATHEMATICAL SANS-SERIF BOLD SMALL ZETA
1D776 MATHEMATICAL SANS-SERIF BOLD SMALL ETA
1D777 MATHEMATICAL SANS-SERIF BOLD SMALL THETA
1D778 MATHEMATICAL SANS-SERIF BOLD SMALL IOTA
1D779 MATHEMATICAL SANS-SERIF BOLD SMALL KAPPA
1D77A MATHEMATICAL SANS-SERIF BOLD SMALL LAMDA
1D77B MATHEMATICAL SANS-SERIF BOLD SMALL MU
1D77C MATHEMATICAL SANS-SERIF BOLD SMALL NU
1D77D MATHEMATICAL SANS-SERIF BOLD SMALL XI
1D77E MATHEMATICAL SANS-SERIF BOLD SMALL OMICRON
1D77F MATHEMATICAL SANS-SERIF BOLD SMALL PI
1D780 MATHEMATICAL SANS-SERIF BOLD SMALL RHO
1D781 MATHEMATICAL SANS-SERIF BOLD SMALL FINAL SIGMA
1D782 MATHEMATICAL SANS-SERIF BOLD SMALL SIGMA
1D783 MATHEMATICAL SANS-SERIF BOLD SMALL TAU
1D784 MATHEMATICAL SANS-SERIF BOLD SMALL UPSILON
1D785 MATHEMATICAL SANS-SERIF BOLD SMALL PHI
1D786 MATHEMATICAL SANS-SERIF BOLD SMALL CHI
1D787 MATHEMATICAL SANS-SERIF BOLD SMALL PSI
1D788 MATHEMATICAL SANS-SERIF BOLD SMALL OMEGA
1D789 MATHEMATICAL SANS-SERIF BOLD PARTIAL DIFFERENTIAL
1D78A MATHEMATICAL SANS-SERIF BOLD EPSILON SYMBOL
1D78B MATHEMATICAL SANS-SERIF BOLD THETA SYMBOL
1D78C MATHEMATICAL SANS-SERIF BOLD KAPPA SYMBOL
1D78D MATHEMATICAL SANS-SERIF BOLD PHI SYMBOL
1D78E MATHEMATICAL SANS-SERIF BOLD RHO SYMBOL
1D78F MATHEMATICAL SANS-SERIF BOLD PI SYMBOL
1D790 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ALPHA
1D791 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL BETA
1D792 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL GAMMA
1D793 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL DELTA
1D794 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL EPSILON
1D795 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ZETA
1D796 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL ETA
1D797 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL THETA
1D798 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL IOTA
1D799 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL KAPPA
1D79A MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL LAMDA
1D79B MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL MU
1D79C MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL NU
1D79D MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL XI
1D79E MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL OMICRON
1D79F MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PI
1D7A0 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL RHO
1D7A1 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL THETA SYMBOL
1D7A2 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL SIGMA
1D7A3 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL TAU
1D7A4 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL UPSILON
1D7A5 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PHI
1D7A6 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL CHI
1D7A7 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL PSI
1D7A8 MATHEMATICAL SANS-SERIF BOLD ITALIC CAPITAL OMEGA
1D7A9 MATHEMATICAL SANS-SERIF BOLD ITALIC NABLA
1D7AA MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ALPHA
1D7AB MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL BETA
1D7AC MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL GAMMA
1D7AD MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL DELTA
1D7AE MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL EPSILON
1D7AF MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ZETA
1D7B0 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL ETA
1D7B1 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL THETA
1D7B2 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL IOTA
1D7B3 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL KAPPA
1D7B4 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL LAMDA
1D7B5 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL MU
1D7B6 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL NU
1D7B7 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL XI
1D7B8 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL OMICRON
1D7B9 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PI
1D7BA MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL RHO
1D7BB MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL FINAL SIGMA
1D7BC MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL SIGMA
1D7BD MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL TAU
1D7BE MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL UPSILON
1D7BF MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PHI
1D7C0 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL CHI
1D7C1 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL PSI
1D7C2 MATHEMATICAL SANS-SERIF BOLD ITALIC SMALL OMEGA
1D7C3 MATHEMATICAL SANS-SERIF BOLD ITALIC PARTIAL DIFFERENTIAL
1D7C4 MATHEMATICAL SANS-SERIF BOLD ITALIC EPSILON SYMBOL
1D7C5 MATHEMATICAL SANS-SERIF BOLD ITALIC THETA SYMBOL
1D7C6 MATHEMATICAL SANS-SERIF BOLD ITALIC KAPPA SYMBOL
1D7C7 MATHEMATICAL SANS-SERIF BOLD ITALIC PHI SYMBOL
1D7C8 MATHEMATICAL SANS-SERIF BOLD ITALIC RHO SYMBOL
1D7C9 MATHEMATICAL SANS-SERIF BOLD ITALIC PI SYMBOL
1D7CA MATHEMATICAL BOLD CAPITAL DIGAMMA
1D7CB MATHEMATICAL BOLD SMALL DIGAMMA
1D7CE MATHEMATICAL BOLD DIGIT ZERO
1D7CF MATHEMATICAL BOLD DIGIT ONE
1D7D0 MATHEMATICAL BOLD DIGIT TWO
1D7D1 MATHEMATICAL BOLD DIGIT THREE
1D7D2 MATHEMATICAL BOLD DIGIT FOUR
1D7D3 MATHEMATICAL BOLD DIGIT FIVE
1D7D4 MATHEMATICAL BOLD DIGIT SIX
1D7D5 MATHEMATICAL BOLD DIGIT SEVEN
1D7D6 MATHEMATICAL BOLD DIGIT EIGHT
1D7D7 MATHEMATICAL BOLD DIGIT NINE
1D7D8 MATHEMATICAL DOUBLE-STRUCK DIGIT ZERO
1D7D9 MATHEMATICAL DOUBLE-STRUCK DIGIT ONE
1D7DA MATHEMATICAL DOUBLE-STRUCK DIGIT TWO
1D7DB MATHEMATICAL DOUBLE-STRUCK DIGIT THREE
1D7DC MATHEMATICAL DOUBLE-STRUCK DIGIT FOUR
1D7DD MATHEMATICAL DOUBLE-STRUCK DIGIT FIVE
1D7DE MATHEMATICAL DOUBLE-STRUCK DIGIT SIX
1D7DF MATHEMATICAL DOUBLE-STRUCK DIGIT SEVEN
1D7E0 MATHEMATICAL DOUBLE-STRUCK DIGIT EIGHT
1D7E1 MATHEMATICAL DOUBLE-STRUCK DIGIT NINE
1D7E2 MATHEMATICAL SANS-SERIF DIGIT ZERO
1D7E3 MATHEMATICAL SANS-SERIF DIGIT ONE
1D7E4 MATHEMATICAL SANS-SERIF DIGIT TWO
1D7E5 MATHEMATICAL SANS-SERIF DIGIT THREE
1D7E6 MATHEMATICAL SANS-SERIF DIGIT FOUR
1D7E7 MATHEMATICAL SANS-SERIF DIGIT FIVE
1D7E8 MATHEMATICAL SANS-SERIF DIGIT SIX
1D7E9 MATHEMATICAL SANS-SERIF DIGIT SEVEN
1D7EA MATHEMATICAL SANS-SERIF DIGIT EIGHT
1D7EB MATHEMATICAL SANS-SERIF DIGIT NINE
1D7EC MATHEMATICAL SANS-SERIF BOLD DIGIT ZERO
1D7ED MATHEMATICAL SANS-SERIF BOLD DIGIT ONE
1D7EE MATHEMATICAL SANS-SERIF BOLD DIGIT TWO
1D7EF MATHEMATICAL SANS-SERIF BOLD DIGIT THREE
1D7F0 MATHEMATICAL SANS-SERIF BOLD DIGIT FOUR
1D7F1 MATHEMATICAL SANS-SERIF BOLD DIGIT FIVE
1D7F2 MATHEMATICAL SANS-SERIF BOLD DIGIT SIX
1D7F3 MATHEMATICAL SANS-SERIF BOLD DIGIT SEVEN
1D7F4 MATHEMATICAL SANS-SERIF BOLD DIGIT EIGHT
1D7F5 MATHEMATICAL SANS-SERIF BOLD DIGIT NINE
1D7F6 MATHEMATICAL MONOSPACE DIGIT ZERO
1D7F7 MATHEMATICAL MONOSPACE DIGIT ONE
1D7F8 MATHEMATICAL MONOSPACE DIGIT TWO
1D7F9 MATHEMATICAL MONOSPACE DIGIT THREE
1D7FA MATHEMATICAL MONOSPACE DIGIT FOUR
1D7FB MATHEMATICAL MONOSPACE DIGIT FIVE
1D7FC MATHEMATICAL MONOSPACE DIGIT SIX
1D7FD MATHEMATICAL MONOSPACE DIGIT SEVEN
1D7FE MATHEMATICAL MONOSPACE DIGIT EIGHT
1D7FF MATHEMATICAL MONOSPACE DIGIT NINE
1D800 SIGNWRITING HAND-FIST INDEX
1D801 SIGNWRITING HAND-CIRCLE INDEX
1D802 SIGNWRITING HAND-CUP INDEX
1D803 SIGNWRITING HAND-OVAL INDEX
1D804 SIGNWRITING HAND-HINGE INDEX
1D805 SIGNWRITING HAND-ANGLE INDEX
1D806 SIGNWRITING HAND-FIST INDEX BENT
1D807 SIGNWRITING HAND-CIRCLE INDEX BENT
1D808 SIGNWRITING HAND-FIST THUMB UNDER INDEX BENT
1D809 SIGNWRITING HAND-FIST INDEX RAISED KNUCKLE
1D80A SIGNWRITING HAND-FIST INDEX CUPPED
1D80B SIGNWRITING HAND-FIST INDEX HINGED
1D80C SIGNWRITING HAND-FIST INDEX HINGED LOW
1D80D SIGNWRITING HAND-CIRCLE INDEX HINGE
1D80E SIGNWRITING HAND-FIST INDEX MIDDLE
1D80F SIGNWRITING HAND-CIRCLE INDEX MIDDLE
1D810 SIGNWRITING HAND-FIST INDEX MIDDLE BENT
1D811 SIGNWRITING HAND-FIST INDEX MIDDLE RAISED KNUCKLES
1D812 SIGNWRITING HAND-FIST INDEX MIDDLE HINGED
1D813 SIGNWRITING HAND-FIST INDEX UP MIDDLE HINGED
1D814 SIGNWRITING HAND-FIST INDEX HINGED MIDDLE UP
1D815 SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED
1D816 SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED INDEX BENT
1D817 SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED MIDDLE BENT
1D818 SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED CUPPED
1D819 SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED HINGED
1D81A SIGNWRITING HAND-FIST INDEX MIDDLE CROSSED
1D81B SIGNWRITING HAND-CIRCLE INDEX MIDDLE CROSSED
1D81C SIGNWRITING HAND-FIST MIDDLE BENT OVER INDEX
1D81D SIGNWRITING HAND-FIST INDEX BENT OVER MIDDLE
1D81E SIGNWRITING HAND-FIST INDEX MIDDLE THUMB
1D81F SIGNWRITING HAND-CIRCLE INDEX MIDDLE THUMB
1D820 SIGNWRITING HAND-FIST INDEX MIDDLE STRAIGHT THUMB BENT
1D821 SIGNWRITING HAND-FIST INDEX MIDDLE BENT THUMB STRAIGHT
1D822 SIGNWRITING HAND-FIST INDEX MIDDLE THUMB BENT
1D823 SIGNWRITING HAND-FIST INDEX MIDDLE HINGED SPREAD THUMB SIDE
1D824 SIGNWRITING HAND-FIST INDEX UP MIDDLE HINGED THUMB SIDE
1D825 SIGNWRITING HAND-FIST INDEX UP MIDDLE HINGED THUMB CONJOINED
1D826 SIGNWRITING HAND-FIST INDEX HINGED MIDDLE UP THUMB SIDE
1D827 SIGNWRITING HAND-FIST INDEX MIDDLE UP SPREAD THUMB FORWARD
1D828 SIGNWRITING HAND-FIST INDEX MIDDLE THUMB CUPPED
1D829 SIGNWRITING HAND-FIST INDEX MIDDLE THUMB CIRCLED
1D82A SIGNWRITING HAND-FIST INDEX MIDDLE THUMB HOOKED
1D82B SIGNWRITING HAND-FIST INDEX MIDDLE THUMB HINGED
1D82C SIGNWRITING HAND-FIST THUMB BETWEEN INDEX MIDDLE STRAIGHT
1D82D SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB SIDE
1D82E SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB SIDE CONJOINED
1D82F SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB SIDE BENT
1D830 SIGNWRITING HAND-FIST MIDDLE THUMB HOOKED INDEX UP
1D831 SIGNWRITING HAND-FIST INDEX THUMB HOOKED MIDDLE UP
1D832 SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED HINGED THUMB SIDE
1D833 SIGNWRITING HAND-FIST INDEX MIDDLE CROSSED THUMB SIDE
1D834 SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED THUMB FORWARD
1D835 SIGNWRITING HAND-FIST INDEX MIDDLE CONJOINED CUPPED THUMB FORWARD
1D836 SIGNWRITING HAND-FIST MIDDLE THUMB CUPPED INDEX UP
1D837 SIGNWRITING HAND-FIST INDEX THUMB CUPPED MIDDLE UP
1D838 SIGNWRITING HAND-FIST MIDDLE THUMB CIRCLED INDEX UP
1D839 SIGNWRITING HAND-FIST MIDDLE THUMB CIRCLED INDEX HINGED
1D83A SIGNWRITING HAND-FIST INDEX THUMB ANGLED OUT MIDDLE UP
1D83B SIGNWRITING HAND-FIST INDEX THUMB ANGLED IN MIDDLE UP
1D83C SIGNWRITING HAND-FIST INDEX THUMB CIRCLED MIDDLE UP
1D83D SIGNWRITING HAND-FIST INDEX MIDDLE THUMB CONJOINED HINGED
1D83E SIGNWRITING HAND-FIST INDEX MIDDLE THUMB ANGLED OUT
1D83F SIGNWRITING HAND-FIST INDEX MIDDLE THUMB ANGLED
1D840 SIGNWRITING HAND-FIST MIDDLE THUMB ANGLED OUT INDEX UP
1D841 SIGNWRITING HAND-FIST MIDDLE THUMB ANGLED OUT INDEX CROSSED
1D842 SIGNWRITING HAND-FIST MIDDLE THUMB ANGLED INDEX UP
1D843 SIGNWRITING HAND-FIST INDEX THUMB HOOKED MIDDLE HINGED
1D844 SIGNWRITING HAND-FLAT FOUR FINGERS
1D845 SIGNWRITING HAND-FLAT FOUR FINGERS BENT
1D846 SIGNWRITING HAND-FLAT FOUR FINGERS HINGED
1D847 SIGNWRITING HAND-FLAT FOUR FINGERS CONJOINED
1D848 SIGNWRITING HAND-FLAT FOUR FINGERS CONJOINED SPLIT
1D849 SIGNWRITING HAND-CLAW FOUR FINGERS CONJOINED
1D84A SIGNWRITING HAND-FIST FOUR FINGERS CONJOINED BENT
1D84B SIGNWRITING HAND-HINGE FOUR FINGERS CONJOINED
1D84C SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD
1D84D SIGNWRITING HAND-FLAT HEEL FIVE FINGERS SPREAD
1D84E SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD FOUR BENT
1D84F SIGNWRITING HAND-FLAT HEEL FIVE FINGERS SPREAD FOUR BENT
1D850 SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD BENT
1D851 SIGNWRITING HAND-FLAT HEEL FIVE FINGERS SPREAD BENT
1D852 SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD THUMB FORWARD
1D853 SIGNWRITING HAND-CUP FIVE FINGERS SPREAD
1D854 SIGNWRITING HAND-CUP FIVE FINGERS SPREAD OPEN
1D855 SIGNWRITING HAND-HINGE FIVE FINGERS SPREAD OPEN
1D856 SIGNWRITING HAND-OVAL FIVE FINGERS SPREAD
1D857 SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD HINGED
1D858 SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD HINGED THUMB SIDE
1D859 SIGNWRITING HAND-FLAT FIVE FINGERS SPREAD HINGED NO THUMB
1D85A SIGNWRITING HAND-FLAT
1D85B SIGNWRITING HAND-FLAT BETWEEN PALM FACINGS
1D85C SIGNWRITING HAND-FLAT HEEL
1D85D SIGNWRITING HAND-FLAT THUMB SIDE
1D85E SIGNWRITING HAND-FLAT HEEL THUMB SIDE
1D85F SIGNWRITING HAND-FLAT THUMB BENT
1D860 SIGNWRITING HAND-FLAT THUMB FORWARD
1D861 SIGNWRITING HAND-FLAT SPLIT INDEX THUMB SIDE
1D862 SIGNWRITING HAND-FLAT SPLIT CENTRE
1D863 SIGNWRITING HAND-FLAT SPLIT CENTRE THUMB SIDE
1D864 SIGNWRITING HAND-FLAT SPLIT CENTRE THUMB SIDE BENT
1D865 SIGNWRITING HAND-FLAT SPLIT LITTLE
1D866 SIGNWRITING HAND-CLAW
1D867 SIGNWRITING HAND-CLAW THUMB SIDE
1D868 SIGNWRITING HAND-CLAW NO THUMB
1D869 SIGNWRITING HAND-CLAW THUMB FORWARD
1D86A SIGNWRITING HAND-HOOK CURLICUE
1D86B SIGNWRITING HAND-HOOK
1D86C SIGNWRITING HAND-CUP OPEN
1D86D SIGNWRITING HAND-CUP
1D86E SIGNWRITING HAND-CUP OPEN THUMB SIDE
1D86F SIGNWRITING HAND-CUP THUMB SIDE
1D870 SIGNWRITING HAND-CUP OPEN NO THUMB
1D871 SIGNWRITING HAND-CUP NO THUMB
1D872 SIGNWRITING HAND-CUP OPEN THUMB FORWARD
1D873 SIGNWRITING HAND-CUP THUMB FORWARD
1D874 SIGNWRITING HAND-CURLICUE OPEN
1D875 SIGNWRITING HAND-CURLICUE
1D876 SIGNWRITING HAND-CIRCLE
1D877 SIGNWRITING HAND-OVAL
1D878 SIGNWRITING HAND-OVAL THUMB SIDE
1D879 SIGNWRITING HAND-OVAL NO THUMB
1D87A SIGNWRITING HAND-OVAL THUMB FORWARD
1D87B SIGNWRITING HAND-HINGE OPEN
1D87C SIGNWRITING HAND-HINGE OPEN THUMB FORWARD
1D87D SIGNWRITING HAND-HINGE
1D87E SIGNWRITING HAND-HINGE SMALL
1D87F SIGNWRITING HAND-HINGE OPEN THUMB SIDE
1D880 SIGNWRITING HAND-HINGE THUMB SIDE
1D881 SIGNWRITING HAND-HINGE OPEN NO THUMB
1D882 SIGNWRITING HAND-HINGE NO THUMB
1D883 SIGNWRITING HAND-HINGE THUMB SIDE TOUCHING INDEX
1D884 SIGNWRITING HAND-HINGE THUMB BETWEEN MIDDLE RING
1D885 SIGNWRITING HAND-ANGLE
1D886 SIGNWRITING HAND-FIST INDEX MIDDLE RING
1D887 SIGNWRITING HAND-CIRCLE INDEX MIDDLE RING
1D888 SIGNWRITING HAND-HINGE INDEX MIDDLE RING
1D889 SIGNWRITING HAND-ANGLE INDEX MIDDLE RING
1D88A SIGNWRITING HAND-HINGE LITTLE
1D88B SIGNWRITING HAND-FIST INDEX MIDDLE RING BENT
1D88C SIGNWRITING HAND-FIST INDEX MIDDLE RING CONJOINED
1D88D SIGNWRITING HAND-HINGE INDEX MIDDLE RING CONJOINED
1D88E SIGNWRITING HAND-FIST LITTLE DOWN
1D88F SIGNWRITING HAND-FIST LITTLE DOWN RIPPLE STRAIGHT
1D890 SIGNWRITING HAND-FIST LITTLE DOWN RIPPLE CURVED
1D891 SIGNWRITING HAND-FIST LITTLE DOWN OTHERS CIRCLED
1D892 SIGNWRITING HAND-FIST LITTLE UP
1D893 SIGNWRITING HAND-FIST THUMB UNDER LITTLE UP
1D894 SIGNWRITING HAND-CIRCLE LITTLE UP
1D895 SIGNWRITING HAND-OVAL LITTLE UP
1D896 SIGNWRITING HAND-ANGLE LITTLE UP
1D897 SIGNWRITING HAND-FIST LITTLE RAISED KNUCKLE
1D898 SIGNWRITING HAND-FIST LITTLE BENT
1D899 SIGNWRITING HAND-FIST LITTLE TOUCHES THUMB
1D89A SIGNWRITING HAND-FIST LITTLE THUMB
1D89B SIGNWRITING HAND-HINGE LITTLE THUMB
1D89C SIGNWRITING HAND-FIST LITTLE INDEX THUMB
1D89D SIGNWRITING HAND-HINGE LITTLE INDEX THUMB
1D89E SIGNWRITING HAND-ANGLE LITTLE INDEX THUMB INDEX THUMB OUT
1D89F SIGNWRITING HAND-ANGLE LITTLE INDEX THUMB INDEX THUMB
1D8A0 SIGNWRITING HAND-FIST LITTLE INDEX
1D8A1 SIGNWRITING HAND-CIRCLE LITTLE INDEX
1D8A2 SIGNWRITING HAND-HINGE LITTLE INDEX
1D8A3 SIGNWRITING HAND-ANGLE LITTLE INDEX
1D8A4 SIGNWRITING HAND-FIST INDEX MIDDLE LITTLE
1D8A5 SIGNWRITING HAND-CIRCLE INDEX MIDDLE LITTLE
1D8A6 SIGNWRITING HAND-HINGE INDEX MIDDLE LITTLE
1D8A7 SIGNWRITING HAND-HINGE RING
1D8A8 SIGNWRITING HAND-ANGLE INDEX MIDDLE LITTLE
1D8A9 SIGNWRITING HAND-FIST INDEX MIDDLE CROSS LITTLE
1D8AA SIGNWRITING HAND-CIRCLE INDEX MIDDLE CROSS LITTLE
1D8AB SIGNWRITING HAND-FIST RING DOWN
1D8AC SIGNWRITING HAND-HINGE RING DOWN INDEX THUMB HOOK MIDDLE
1D8AD SIGNWRITING HAND-ANGLE RING DOWN MIDDLE THUMB INDEX CROSS
1D8AE SIGNWRITING HAND-FIST RING UP
1D8AF SIGNWRITING HAND-FIST RING RAISED KNUCKLE
1D8B0 SIGNWRITING HAND-FIST RING LITTLE
1D8B1 SIGNWRITING HAND-CIRCLE RING LITTLE
1D8B2 SIGNWRITING HAND-OVAL RING LITTLE
1D8B3 SIGNWRITING HAND-ANGLE RING LITTLE
1D8B4 SIGNWRITING HAND-FIST RING MIDDLE
1D8B5 SIGNWRITING HAND-FIST RING MIDDLE CONJOINED
1D8B6 SIGNWRITING HAND-FIST RING MIDDLE RAISED KNUCKLES
1D8B7 SIGNWRITING HAND-FIST RING INDEX
1D8B8 SIGNWRITING HAND-FIST RING THUMB
1D8B9 SIGNWRITING HAND-HOOK RING THUMB
1D8BA SIGNWRITING HAND-FIST INDEX RING LITTLE
1D8BB SIGNWRITING HAND-CIRCLE INDEX RING LITTLE
1D8BC SIGNWRITING HAND-CURLICUE INDEX RING LITTLE ON
1D8BD SIGNWRITING HAND-HOOK INDEX RING LITTLE OUT
1D8BE SIGNWRITING HAND-HOOK INDEX RING LITTLE IN
1D8BF SIGNWRITING HAND-HOOK INDEX RING LITTLE UNDER
1D8C0 SIGNWRITING HAND-CUP INDEX RING LITTLE
1D8C1 SIGNWRITING HAND-HINGE INDEX RING LITTLE
1D8C2 SIGNWRITING HAND-ANGLE INDEX RING LITTLE OUT
1D8C3 SIGNWRITING HAND-ANGLE INDEX RING LITTLE
1D8C4 SIGNWRITING HAND-FIST MIDDLE DOWN
1D8C5 SIGNWRITING HAND-HINGE MIDDLE
1D8C6 SIGNWRITING HAND-FIST MIDDLE UP
1D8C7 SIGNWRITING HAND-CIRCLE MIDDLE UP
1D8C8 SIGNWRITING HAND-FIST MIDDLE RAISED KNUCKLE
1D8C9 SIGNWRITING HAND-FIST MIDDLE UP THUMB SIDE
1D8CA SIGNWRITING HAND-HOOK MIDDLE THUMB
1D8CB SIGNWRITING HAND-FIST MIDDLE THUMB LITTLE
1D8CC SIGNWRITING HAND-FIST MIDDLE LITTLE
1D8CD SIGNWRITING HAND-FIST MIDDLE RING LITTLE
1D8CE SIGNWRITING HAND-CIRCLE MIDDLE RING LITTLE
1D8CF SIGNWRITING HAND-CURLICUE MIDDLE RING LITTLE ON
1D8D0 SIGNWRITING HAND-CUP MIDDLE RING LITTLE
1D8D1 SIGNWRITING HAND-HINGE MIDDLE RING LITTLE
1D8D2 SIGNWRITING HAND-ANGLE MIDDLE RING LITTLE OUT
1D8D3 SIGNWRITING HAND-ANGLE MIDDLE RING LITTLE IN
1D8D4 SIGNWRITING HAND-ANGLE MIDDLE RING LITTLE
1D8D5 SIGNWRITING HAND-CIRCLE MIDDLE RING LITTLE BENT
1D8D6 SIGNWRITING HAND-CLAW MIDDLE RING LITTLE CONJOINED
1D8D7 SIGNWRITING HAND-CLAW MIDDLE RING LITTLE CONJOINED SIDE
1D8D8 SIGNWRITING HAND-HOOK MIDDLE RING LITTLE CONJOINED OUT
1D8D9 SIGNWRITING HAND-HOOK MIDDLE RING LITTLE CONJOINED IN
1D8DA SIGNWRITING HAND-HOOK MIDDLE RING LITTLE CONJOINED
1D8DB SIGNWRITING HAND-HINGE INDEX HINGED
1D8DC SIGNWRITING HAND-FIST INDEX THUMB SIDE
1D8DD SIGNWRITING HAND-HINGE INDEX THUMB SIDE
1D8DE SIGNWRITING HAND-FIST INDEX THUMB SIDE THUMB DIAGONAL
1D8DF SIGNWRITING HAND-FIST INDEX THUMB SIDE THUMB CONJOINED
1D8E0 SIGNWRITING HAND-FIST INDEX THUMB SIDE THUMB BENT
1D8E1 SIGNWRITING HAND-FIST INDEX THUMB SIDE INDEX BENT
1D8E2 SIGNWRITING HAND-FIST INDEX THUMB SIDE BOTH BENT
1D8E3 SIGNWRITING HAND-FIST INDEX THUMB SIDE INDEX HINGE
1D8E4 SIGNWRITING HAND-FIST INDEX THUMB FORWARD INDEX STRAIGHT
1D8E5 SIGNWRITING HAND-FIST INDEX THUMB FORWARD INDEX BENT
1D8E6 SIGNWRITING HAND-FIST INDEX THUMB HOOK
1D8E7 SIGNWRITING HAND-FIST INDEX THUMB CURLICUE
1D8E8 SIGNWRITING HAND-FIST INDEX THUMB CURVE THUMB INSIDE
1D8E9 SIGNWRITING HAND-CLAW INDEX THUMB CURVE THUMB INSIDE
1D8EA SIGNWRITING HAND-FIST INDEX THUMB CURVE THUMB UNDER
1D8EB SIGNWRITING HAND-FIST INDEX THUMB CIRCLE
1D8EC SIGNWRITING HAND-CUP INDEX THUMB
1D8ED SIGNWRITING HAND-CUP INDEX THUMB OPEN
1D8EE SIGNWRITING HAND-HINGE INDEX THUMB OPEN
1D8EF SIGNWRITING HAND-HINGE INDEX THUMB LARGE
1D8F0 SIGNWRITING HAND-HINGE INDEX THUMB
1D8F1 SIGNWRITING HAND-HINGE INDEX THUMB SMALL
1D8F2 SIGNWRITING HAND-ANGLE INDEX THUMB OUT
1D8F3 SIGNWRITING HAND-ANGLE INDEX THUMB IN
1D8F4 SIGNWRITING HAND-ANGLE INDEX THUMB
1D8F5 SIGNWRITING HAND-FIST THUMB
1D8F6 SIGNWRITING HAND-FIST THUMB HEEL
1D8F7 SIGNWRITING HAND-FIST THUMB SIDE DIAGONAL
1D8F8 SIGNWRITING HAND-FIST THUMB SIDE CONJOINED
1D8F9 SIGNWRITING HAND-FIST THUMB SIDE BENT
1D8FA SIGNWRITING HAND-FIST THUMB FORWARD
1D8FB SIGNWRITING HAND-FIST THUMB BETWEEN INDEX MIDDLE
1D8FC SIGNWRITING HAND-FIST THUMB BETWEEN MIDDLE RING
1D8FD SIGNWRITING HAND-FIST THUMB BETWEEN RING LITTLE
1D8FE SIGNWRITING HAND-FIST THUMB UNDER TWO FINGERS
1D8FF SIGNWRITING HAND-FIST THUMB OVER TWO FINGERS
1D900 SIGNWRITING HAND-FIST THUMB UNDER THREE FINGERS
1D901 SIGNWRITING HAND-FIST THUMB UNDER FOUR FINGERS
1D902 SIGNWRITING HAND-FIST THUMB OVER FOUR RAISED KNUCKLES
1D903 SIGNWRITING HAND-FIST
1D904 SIGNWRITING HAND-FIST HEEL
1D905 SIGNWRITING TOUCH SINGLE
1D906 SIGNWRITING TOUCH MULTIPLE
1D907 SIGNWRITING TOUCH BETWEEN
1D908 SIGNWRITING GRASP SINGLE
1D909 SIGNWRITING GRASP MULTIPLE
1D90A SIGNWRITING GRASP BETWEEN
1D90B SIGNWRITING STRIKE SINGLE
1D90C SIGNWRITING STRIKE MULTIPLE
1D90D SIGNWRITING STRIKE BETWEEN
1D90E SIGNWRITING BRUSH SINGLE
1D90F SIGNWRITING BRUSH MULTIPLE
1D910 SIGNWRITING BRUSH BETWEEN
1D911 SIGNWRITING RUB SINGLE
1D912 SIGNWRITING RUB MULTIPLE
1D913 SIGNWRITING RUB BETWEEN
1D914 SIGNWRITING SURFACE SYMBOLS
1D915 SIGNWRITING SURFACE BETWEEN
1D916 SIGNWRITING SQUEEZE LARGE SINGLE
1D917 SIGNWRITING SQUEEZE SMALL SINGLE
1D918 SIGNWRITING SQUEEZE LARGE MULTIPLE
1D919 SIGNWRITING SQUEEZE SMALL MULTIPLE
1D91A SIGNWRITING SQUEEZE SEQUENTIAL
1D91B SIGNWRITING FLICK LARGE SINGLE
1D91C SIGNWRITING FLICK SMALL SINGLE
1D91D SIGNWRITING FLICK LARGE MULTIPLE
1D91E SIGNWRITING FLICK SMALL MULTIPLE
1D91F SIGNWRITING FLICK SEQUENTIAL
1D920 SIGNWRITING SQUEEZE FLICK ALTERNATING
1D921 SIGNWRITING MOVEMENT-HINGE UP DOWN LARGE
1D922 SIGNWRITING MOVEMENT-HINGE UP DOWN SMALL
1D923 SIGNWRITING MOVEMENT-HINGE UP SEQUENTIAL
1D924 SIGNWRITING MOVEMENT-HINGE DOWN SEQUENTIAL
1D925 SIGNWRITING MOVEMENT-HINGE UP DOWN ALTERNATING LARGE
1D926 SIGNWRITING MOVEMENT-HINGE UP DOWN ALTERNATING SMALL
1D927 SIGNWRITING MOVEMENT-HINGE SIDE TO SIDE SCISSORS
1D928 SIGNWRITING MOVEMENT-WALLPLANE FINGER CONTACT
1D929 SIGNWRITING MOVEMENT-FLOORPLANE FINGER CONTACT
1D92A SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT SMALL
1D92B SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT MEDIUM
1D92C SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT LARGE
1D92D SIGNWRITING MOVEMENT-WALLPLANE SINGLE STRAIGHT LARGEST
1D92E SIGNWRITING MOVEMENT-WALLPLANE SINGLE WRIST FLEX
1D92F SIGNWRITING MOVEMENT-WALLPLANE DOUBLE STRAIGHT
1D930 SIGNWRITING MOVEMENT-WALLPLANE DOUBLE WRIST FLEX
1D931 SIGNWRITING MOVEMENT-WALLPLANE DOUBLE ALTERNATING
1D932 SIGNWRITING MOVEMENT-WALLPLANE DOUBLE ALTERNATING WRIST FLEX
1D933 SIGNWRITING MOVEMENT-WALLPLANE CROSS
1D934 SIGNWRITING MOVEMENT-WALLPLANE TRIPLE STRAIGHT MOVEMENT
1D935 SIGNWRITING MOVEMENT-WALLPLANE TRIPLE WRIST FLEX
1D936 SIGNWRITING MOVEMENT-WALLPLANE TRIPLE ALTERNATING
1D937 SIGNWRITING MOVEMENT-WALLPLANE TRIPLE ALTERNATING WRIST FLEX
1D938 SIGNWRITING MOVEMENT-WALLPLANE BEND SMALL
1D939 SIGNWRITING MOVEMENT-WALLPLANE BEND MEDIUM
1D93A SIGNWRITING MOVEMENT-WALLPLANE BEND LARGE
1D93B SIGNWRITING MOVEMENT-WALLPLANE CORNER SMALL
1D93C SIGNWRITING MOVEMENT-WALLPLANE CORNER MEDIUM
1D93D SIGNWRITING MOVEMENT-WALLPLANE CORNER LARGE
1D93E SIGNWRITING MOVEMENT-WALLPLANE CORNER ROTATION
1D93F SIGNWRITING MOVEMENT-WALLPLANE CHECK SMALL
1D940 SIGNWRITING MOVEMENT-WALLPLANE CHECK MEDIUM
1D941 SIGNWRITING MOVEMENT-WALLPLANE CHECK LARGE
1D942 SIGNWRITING MOVEMENT-WALLPLANE BOX SMALL
1D943 SIGNWRITING MOVEMENT-WALLPLANE BOX MEDIUM
1D944 SIGNWRITING MOVEMENT-WALLPLANE BOX LARGE
1D945 SIGNWRITING MOVEMENT-WALLPLANE ZIGZAG SMALL
1D946 SIGNWRITING MOVEMENT-WALLPLANE ZIGZAG MEDIUM
1D947 SIGNWRITING MOVEMENT-WALLPLANE ZIGZAG LARGE
1D948 SIGNWRITING MOVEMENT-WALLPLANE PEAKS SMALL
1D949 SIGNWRITING MOVEMENT-WALLPLANE PEAKS MEDIUM
1D94A SIGNWRITING MOVEMENT-WALLPLANE PEAKS LARGE
1D94B SIGNWRITING TRAVEL-WALLPLANE ROTATION-WALLPLANE SINGLE
1D94C SIGNWRITING TRAVEL-WALLPLANE ROTATION-WALLPLANE DOUBLE
1D94D SIGNWRITING TRAVEL-WALLPLANE ROTATION-WALLPLANE ALTERNATING
1D94E SIGNWRITING TRAVEL-WALLPLANE ROTATION-FLOORPLANE SINGLE
1D94F SIGNWRITING TRAVEL-WALLPLANE ROTATION-FLOORPLANE DOUBLE
1D950 SIGNWRITING TRAVEL-WALLPLANE ROTATION-FLOORPLANE ALTERNATING
1D951 SIGNWRITING TRAVEL-WALLPLANE SHAKING
1D952 SIGNWRITING TRAVEL-WALLPLANE ARM SPIRAL SINGLE
1D953 SIGNWRITING TRAVEL-WALLPLANE ARM SPIRAL DOUBLE
1D954 SIGNWRITING TRAVEL-WALLPLANE ARM SPIRAL TRIPLE
1D955 SIGNWRITING MOVEMENT-DIAGONAL AWAY SMALL
1D956 SIGNWRITING MOVEMENT-DIAGONAL AWAY MEDIUM
1D957 SIGNWRITING MOVEMENT-DIAGONAL AWAY LARGE
1D958 SIGNWRITING MOVEMENT-DIAGONAL AWAY LARGEST
1D959 SIGNWRITING MOVEMENT-DIAGONAL TOWARDS SMALL
1D95A SIGNWRITING MOVEMENT-DIAGONAL TOWARDS MEDIUM
1D95B SIGNWRITING MOVEMENT-DIAGONAL TOWARDS LARGE
1D95C SIGNWRITING MOVEMENT-DIAGONAL TOWARDS LARGEST
1D95D SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY SMALL
1D95E SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY MEDIUM
1D95F SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY LARGE
1D960 SIGNWRITING MOVEMENT-DIAGONAL BETWEEN AWAY LARGEST
1D961 SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS SMALL
1D962 SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS MEDIUM
1D963 SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS LARGE
1D964 SIGNWRITING MOVEMENT-DIAGONAL BETWEEN TOWARDS LARGEST
1D965 SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT SMALL
1D966 SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT MEDIUM
1D967 SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT LARGE
1D968 SIGNWRITING MOVEMENT-FLOORPLANE SINGLE STRAIGHT LARGEST
1D969 SIGNWRITING MOVEMENT-FLOORPLANE SINGLE WRIST FLEX
1D96A SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE STRAIGHT
1D96B SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE WRIST FLEX
1D96C SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE ALTERNATING
1D96D SIGNWRITING MOVEMENT-FLOORPLANE DOUBLE ALTERNATING WRIST FLEX
1D96E SIGNWRITING MOVEMENT-FLOORPLANE CROSS
1D96F SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE STRAIGHT MOVEMENT
1D970 SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE WRIST FLEX
1D971 SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE ALTERNATING MOVEMENT
1D972 SIGNWRITING MOVEMENT-FLOORPLANE TRIPLE ALTERNATING WRIST FLEX
1D973 SIGNWRITING MOVEMENT-FLOORPLANE BEND
1D974 SIGNWRITING MOVEMENT-FLOORPLANE CORNER SMALL
1D975 SIGNWRITING MOVEMENT-FLOORPLANE CORNER MEDIUM
1D976 SIGNWRITING MOVEMENT-FLOORPLANE CORNER LARGE
1D977 SIGNWRITING MOVEMENT-FLOORPLANE CHECK
1D978 SIGNWRITING MOVEMENT-FLOORPLANE BOX SMALL
1D979 SIGNWRITING MOVEMENT-FLOORPLANE BOX MEDIUM
1D97A SIGNWRITING MOVEMENT-FLOORPLANE BOX LARGE
1D97B SIGNWRITING MOVEMENT-FLOORPLANE ZIGZAG SMALL
1D97C SIGNWRITING MOVEMENT-FLOORPLANE ZIGZAG MEDIUM
1D97D SIGNWRITING MOVEMENT-FLOORPLANE ZIGZAG LARGE
1D97E SIGNWRITING MOVEMENT-FLOORPLANE PEAKS SMALL
1D97F SIGNWRITING MOVEMENT-FLOORPLANE PEAKS MEDIUM
1D980 SIGNWRITING MOVEMENT-FLOORPLANE PEAKS LARGE
1D981 SIGNWRITING TRAVEL-FLOORPLANE ROTATION-FLOORPLANE SINGLE
1D982 SIGNWRITING TRAVEL-FLOORPLANE ROTATION-FLOORPLANE DOUBLE
1D983 SIGNWRITING TRAVEL-FLOORPLANE ROTATION-FLOORPLANE ALTERNATING
1D984 SIGNWRITING TRAVEL-FLOORPLANE ROTATION-WALLPLANE SINGLE
1D985 SIGNWRITING TRAVEL-FLOORPLANE ROTATION-WALLPLANE DOUBLE
1D986 SIGNWRITING TRAVEL-FLOORPLANE ROTATION-WALLPLANE ALTERNATING
1D987 SIGNWRITING TRAVEL-FLOORPLANE SHAKING
1D988 SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER SMALL
1D989 SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER MEDIUM
1D98A SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER LARGE
1D98B SIGNWRITING MOVEMENT-WALLPLANE CURVE QUARTER LARGEST
1D98C SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE SMALL
1D98D SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE MEDIUM
1D98E SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE LARGE
1D98F SIGNWRITING MOVEMENT-WALLPLANE CURVE HALF-CIRCLE LARGEST
1D990 SIGNWRITING MOVEMENT-WALLPLANE CURVE THREE-QUARTER CIRCLE SMALL
1D991 SIGNWRITING MOVEMENT-WALLPLANE CURVE THREE-QUARTER CIRCLE MEDIUM
1D992 SIGNWRITING MOVEMENT-WALLPLANE HUMP SMALL
1D993 SIGNWRITING MOVEMENT-WALLPLANE HUMP MEDIUM
1D994 SIGNWRITING MOVEMENT-WALLPLANE HUMP LARGE
1D995 SIGNWRITING MOVEMENT-WALLPLANE LOOP SMALL
1D996 SIGNWRITING MOVEMENT-WALLPLANE LOOP MEDIUM
1D997 SIGNWRITING MOVEMENT-WALLPLANE LOOP LARGE
1D998 SIGNWRITING MOVEMENT-WALLPLANE LOOP SMALL DOUBLE
1D999 SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE DOUBLE SMALL
1D99A SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE DOUBLE MEDIUM
1D99B SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE DOUBLE LARGE
1D99C SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE TRIPLE SMALL
1D99D SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE TRIPLE MEDIUM
1D99E SIGNWRITING MOVEMENT-WALLPLANE WAVE CURVE TRIPLE LARGE
1D99F SIGNWRITING MOVEMENT-WALLPLANE CURVE THEN STRAIGHT
1D9A0 SIGNWRITING MOVEMENT-WALLPLANE CURVED CROSS SMALL
1D9A1 SIGNWRITING MOVEMENT-WALLPLANE CURVED CROSS MEDIUM
1D9A2 SIGNWRITING ROTATION-WALLPLANE SINGLE
1D9A3 SIGNWRITING ROTATION-WALLPLANE DOUBLE
1D9A4 SIGNWRITING ROTATION-WALLPLANE ALTERNATE
1D9A5 SIGNWRITING MOVEMENT-WALLPLANE SHAKING
1D9A6 SIGNWRITING MOVEMENT-WALLPLANE CURVE HITTING FRONT WALL
1D9A7 SIGNWRITING MOVEMENT-WALLPLANE HUMP HITTING FRONT WALL
1D9A8 SIGNWRITING MOVEMENT-WALLPLANE LOOP HITTING FRONT WALL
1D9A9 SIGNWRITING MOVEMENT-WALLPLANE WAVE HITTING FRONT WALL
1D9AA SIGNWRITING ROTATION-WALLPLANE SINGLE HITTING FRONT WALL
1D9AB SIGNWRITING ROTATION-WALLPLANE DOUBLE HITTING FRONT WALL
1D9AC SIGNWRITING ROTATION-WALLPLANE ALTERNATING HITTING FRONT WALL
1D9AD SIGNWRITING MOVEMENT-WALLPLANE CURVE HITTING CHEST
1D9AE SIGNWRITING MOVEMENT-WALLPLANE HUMP HITTING CHEST
1D9AF SIGNWRITING MOVEMENT-WALLPLANE LOOP HITTING CHEST
1D9B0 SIGNWRITING MOVEMENT-WALLPLANE WAVE HITTING CHEST
1D9B1 SIGNWRITING ROTATION-WALLPLANE SINGLE HITTING CHEST
1D9B2 SIGNWRITING ROTATION-WALLPLANE DOUBLE HITTING CHEST
1D9B3 SIGNWRITING ROTATION-WALLPLANE ALTERNATING HITTING CHEST
1D9B4 SIGNWRITING MOVEMENT-WALLPLANE WAVE DIAGONAL PATH SMALL
1D9B5 SIGNWRITING MOVEMENT-WALLPLANE WAVE DIAGONAL PATH MEDIUM
1D9B6 SIGNWRITING MOVEMENT-WALLPLANE WAVE DIAGONAL PATH LARGE
1D9B7 SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING CEILING SMALL
1D9B8 SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING CEILING LARGE
1D9B9 SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING SMALL DOUBLE
1D9BA SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING LARGE DOUBLE
1D9BB SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING SMALL TRIPLE
1D9BC SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING CEILING LARGE TRIPLE
1D9BD SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING SMALL SINGLE
1D9BE SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING LARGE SINGLE
1D9BF SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING SMALL DOUBLE
1D9C0 SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING CEILING LARGE DOUBLE
1D9C1 SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING CEILING SMALL
1D9C2 SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING CEILING LARGE
1D9C3 SIGNWRITING ROTATION-FLOORPLANE SINGLE HITTING CEILING
1D9C4 SIGNWRITING ROTATION-FLOORPLANE DOUBLE HITTING CEILING
1D9C5 SIGNWRITING ROTATION-FLOORPLANE ALTERNATING HITTING CEILING
1D9C6 SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING FLOOR SMALL
1D9C7 SIGNWRITING MOVEMENT-FLOORPLANE CURVE HITTING FLOOR LARGE
1D9C8 SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR SMALL DOUBLE
1D9C9 SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR LARGE DOUBLE
1D9CA SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR TRIPLE SMALL TRIPLE
1D9CB SIGNWRITING MOVEMENT-FLOORPLANE HUMP HITTING FLOOR TRIPLE LARGE TRIPLE
1D9CC SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR SMALL SINGLE
1D9CD SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR LARGE SINGLE
1D9CE SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR SMALL DOUBLE
1D9CF SIGNWRITING MOVEMENT-FLOORPLANE LOOP HITTING FLOOR LARGE DOUBLE
1D9D0 SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING FLOOR SMALL
1D9D1 SIGNWRITING MOVEMENT-FLOORPLANE WAVE HITTING FLOOR LARGE
1D9D2 SIGNWRITING ROTATION-FLOORPLANE SINGLE HITTING FLOOR
1D9D3 SIGNWRITING ROTATION-FLOORPLANE DOUBLE HITTING FLOOR
1D9D4 SIGNWRITING ROTATION-FLOORPLANE ALTERNATING HITTING FLOOR
1D9D5 SIGNWRITING MOVEMENT-FLOORPLANE CURVE SMALL
1D9D6 SIGNWRITING MOVEMENT-FLOORPLANE CURVE MEDIUM
1D9D7 SIGNWRITING MOVEMENT-FLOORPLANE CURVE LARGE
1D9D8 SIGNWRITING MOVEMENT-FLOORPLANE CURVE LARGEST
1D9D9 SIGNWRITING MOVEMENT-FLOORPLANE CURVE COMBINED
1D9DA SIGNWRITING MOVEMENT-FLOORPLANE HUMP SMALL
1D9DB SIGNWRITING MOVEMENT-FLOORPLANE LOOP SMALL
1D9DC SIGNWRITING MOVEMENT-FLOORPLANE WAVE SNAKE
1D9DD SIGNWRITING MOVEMENT-FLOORPLANE WAVE SMALL
1D9DE SIGNWRITING MOVEMENT-FLOORPLANE WAVE LARGE
1D9DF SIGNWRITING ROTATION-FLOORPLANE SINGLE
1D9E0 SIGNWRITING ROTATION-FLOORPLANE DOUBLE
1D9E1 SIGNWRITING ROTATION-FLOORPLANE ALTERNATING
1D9E2 SIGNWRITING MOVEMENT-FLOORPLANE SHAKING PARALLEL
1D9E3 SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE SMALL SINGLE
1D9E4 SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE MEDIUM SINGLE
1D9E5 SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE SMALL DOUBLE
1D9E6 SIGNWRITING MOVEMENT-WALLPLANE ARM CIRCLE MEDIUM DOUBLE
1D9E7 SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL SMALL SINGLE
1D9E8 SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL MEDIUM SINGLE
1D9E9 SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL LARGE SINGLE
1D9EA SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL SMALL DOUBLE
1D9EB SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL MEDIUM DOUBLE
1D9EC SIGNWRITING MOVEMENT-FLOORPLANE ARM CIRCLE HITTING WALL LARGE DOUBLE
1D9ED SIGNWRITING MOVEMENT-WALLPLANE WRIST CIRCLE FRONT SINGLE
1D9EE SIGNWRITING MOVEMENT-WALLPLANE WRIST CIRCLE FRONT DOUBLE
1D9EF SIGNWRITING MOVEMENT-FLOORPLANE WRIST CIRCLE HITTING WALL SINGLE
1D9F0 SIGNWRITING MOVEMENT-FLOORPLANE WRIST CIRCLE HITTING WALL DOUBLE
1D9F1 SIGNWRITING MOVEMENT-WALLPLANE FINGER CIRCLES SINGLE
1D9F2 SIGNWRITING MOVEMENT-WALLPLANE FINGER CIRCLES DOUBLE
1D9F3 SIGNWRITING MOVEMENT-FLOORPLANE FINGER CIRCLES HITTING WALL SINGLE
1D9F4 SIGNWRITING MOVEMENT-FLOORPLANE FINGER CIRCLES HITTING WALL DOUBLE
1D9F5 SIGNWRITING DYNAMIC ARROWHEAD SMALL
1D9F6 SIGNWRITING DYNAMIC ARROWHEAD LARGE
1D9F7 SIGNWRITING DYNAMIC FAST
1D9F8 SIGNWRITING DYNAMIC SLOW
1D9F9 SIGNWRITING DYNAMIC TENSE
1D9FA SIGNWRITING DYNAMIC RELAXED
1D9FB SIGNWRITING DYNAMIC SIMULTANEOUS
1D9FC SIGNWRITING DYNAMIC SIMULTANEOUS ALTERNATING
1D9FD SIGNWRITING DYNAMIC EVERY OTHER TIME
1D9FE SIGNWRITING DYNAMIC GRADUAL
1D9FF SIGNWRITING HEAD
1DA00 SIGNWRITING HEAD RIM
1DA01 SIGNWRITING HEAD MOVEMENT-WALLPLANE STRAIGHT
1DA02 SIGNWRITING HEAD MOVEMENT-WALLPLANE TILT
1DA03 SIGNWRITING HEAD MOVEMENT-FLOORPLANE STRAIGHT
1DA04 SIGNWRITING HEAD MOVEMENT-WALLPLANE CURVE
1DA05 SIGNWRITING HEAD MOVEMENT-FLOORPLANE CURVE
1DA06 SIGNWRITING HEAD MOVEMENT CIRCLE
1DA07 SIGNWRITING FACE DIRECTION POSITION NOSE FORWARD TILTING
1DA08 SIGNWRITING FACE DIRECTION POSITION NOSE UP OR DOWN
1DA09 SIGNWRITING FACE DIRECTION POSITION NOSE UP OR DOWN TILTING
1DA0A SIGNWRITING EYEBROWS STRAIGHT UP
1DA0B SIGNWRITING EYEBROWS STRAIGHT NEUTRAL
1DA0C SIGNWRITING EYEBROWS STRAIGHT DOWN
1DA0D SIGNWRITING DREAMY EYEBROWS NEUTRAL DOWN
1DA0E SIGNWRITING DREAMY EYEBROWS DOWN NEUTRAL
1DA0F SIGNWRITING DREAMY EYEBROWS UP NEUTRAL
1DA10 SIGNWRITING DREAMY EYEBROWS NEUTRAL UP
1DA11 SIGNWRITING FOREHEAD NEUTRAL
1DA12 SIGNWRITING FOREHEAD CONTACT
1DA13 SIGNWRITING FOREHEAD WRINKLED
1DA14 SIGNWRITING EYES OPEN
1DA15 SIGNWRITING EYES SQUEEZED
1DA16 SIGNWRITING EYES CLOSED
1DA17 SIGNWRITING EYE BLINK SINGLE
1DA18 SIGNWRITING EYE BLINK MULTIPLE
1DA19 SIGNWRITING EYES HALF OPEN
1DA1A SIGNWRITING EYES WIDE OPEN
1DA1B SIGNWRITING EYES HALF CLOSED
1DA1C SIGNWRITING EYES WIDENING MOVEMENT
1DA1D SIGNWRITING EYE WINK
1DA1E SIGNWRITING EYELASHES UP
1DA1F SIGNWRITING EYELASHES DOWN
1DA20 SIGNWRITING EYELASHES FLUTTERING
1DA21 SIGNWRITING EYEGAZE-WALLPLANE STRAIGHT
1DA22 SIGNWRITING EYEGAZE-WALLPLANE STRAIGHT DOUBLE
1DA23 SIGNWRITING EYEGAZE-WALLPLANE STRAIGHT ALTERNATING
1DA24 SIGNWRITING EYEGAZE-FLOORPLANE STRAIGHT
1DA25 SIGNWRITING EYEGAZE-FLOORPLANE STRAIGHT DOUBLE
1DA26 SIGNWRITING EYEGAZE-FLOORPLANE STRAIGHT ALTERNATING
1DA27 SIGNWRITING EYEGAZE-WALLPLANE CURVED
1DA28 SIGNWRITING EYEGAZE-FLOORPLANE CURVED
1DA29 SIGNWRITING EYEGAZE-WALLPLANE CIRCLING
1DA2A SIGNWRITING CHEEKS PUFFED
1DA2B SIGNWRITING CHEEKS NEUTRAL
1DA2C SIGNWRITING CHEEKS SUCKED
1DA2D SIGNWRITING TENSE CHEEKS HIGH
1DA2E SIGNWRITING TENSE CHEEKS MIDDLE
1DA2F SIGNWRITING TENSE CHEEKS LOW
1DA30 SIGNWRITING EARS
1DA31 SIGNWRITING NOSE NEUTRAL
1DA32 SIGNWRITING NOSE CONTACT
1DA33 SIGNWRITING NOSE WRINKLES
1DA34 SIGNWRITING NOSE WIGGLES
1DA35 SIGNWRITING AIR BLOWING OUT
1DA36 SIGNWRITING AIR SUCKING IN
1DA37 SIGNWRITING AIR BLOW SMALL ROTATIONS
1DA38 SIGNWRITING AIR SUCK SMALL ROTATIONS
1DA39 SIGNWRITING BREATH INHALE
1DA3A SIGNWRITING BREATH EXHALE
1DA3B SIGNWRITING MOUTH CLOSED NEUTRAL
1DA3C SIGNWRITING MOUTH CLOSED FORWARD
1DA3D SIGNWRITING MOUTH CLOSED CONTACT
1DA3E SIGNWRITING MOUTH SMILE
1DA3F SIGNWRITING MOUTH SMILE WRINKLED
1DA40 SIGNWRITING MOUTH SMILE OPEN
1DA41 SIGNWRITING MOUTH FROWN
1DA42 SIGNWRITING MOUTH FROWN WRINKLED
1DA43 SIGNWRITING MOUTH FROWN OPEN
1DA44 SIGNWRITING MOUTH OPEN CIRCLE
1DA45 SIGNWRITING MOUTH OPEN FORWARD
1DA46 SIGNWRITING MOUTH OPEN WRINKLED
1DA47 SIGNWRITING MOUTH OPEN OVAL
1DA48 SIGNWRITING MOUTH OPEN OVAL WRINKLED
1DA49 SIGNWRITING MOUTH OPEN OVAL YAWN
1DA4A SIGNWRITING MOUTH OPEN RECTANGLE
1DA4B SIGNWRITING MOUTH OPEN RECTANGLE WRINKLED
1DA4C SIGNWRITING MOUTH OPEN RECTANGLE YAWN
1DA4D SIGNWRITING MOUTH KISS
1DA4E SIGNWRITING MOUTH KISS FORWARD
1DA4F SIGNWRITING MOUTH KISS WRINKLED
1DA50 SIGNWRITING MOUTH TENSE
1DA51 SIGNWRITING MOUTH TENSE FORWARD
1DA52 SIGNWRITING MOUTH TENSE SUCKED
1DA53 SIGNWRITING LIPS PRESSED TOGETHER
1DA54 SIGNWRITING LIP LOWER OVER UPPER
1DA55 SIGNWRITING LIP UPPER OVER LOWER
1DA56 SIGNWRITING MOUTH CORNERS
1DA57 SIGNWRITING MOUTH WRINKLES SINGLE
1DA58 SIGNWRITING MOUTH WRINKLES DOUBLE
1DA59 SIGNWRITING TONGUE STICKING OUT FAR
1DA5A SIGNWRITING TONGUE LICKING LIPS
1DA5B SIGNWRITING TONGUE TIP BETWEEN LIPS
1DA5C SIGNWRITING TONGUE TIP TOUCHING INSIDE MOUTH
1DA5D SIGNWRITING TONGUE INSIDE MOUTH RELAXED
1DA5E SIGNWRITING TONGUE MOVES AGAINST CHEEK
1DA5F SIGNWRITING TONGUE CENTRE STICKING OUT
1DA60 SIGNWRITING TONGUE CENTRE INSIDE MOUTH
1DA61 SIGNWRITING TEETH
1DA62 SIGNWRITING TEETH MOVEMENT
1DA63 SIGNWRITING TEETH ON TONGUE
1DA64 SIGNWRITING TEETH ON TONGUE MOVEMENT
1DA65 SIGNWRITING TEETH ON LIPS
1DA66 SIGNWRITING TEETH ON LIPS MOVEMENT
1DA67 SIGNWRITING TEETH BITE LIPS
1DA68 SIGNWRITING MOVEMENT-WALLPLANE JAW
1DA69 SIGNWRITING MOVEMENT-FLOORPLANE JAW
1DA6A SIGNWRITING NECK
1DA6B SIGNWRITING HAIR
1DA6C SIGNWRITING EXCITEMENT
1DA6D SIGNWRITING SHOULDER HIP SPINE
1DA6E SIGNWRITING SHOULDER HIP POSITIONS
1DA6F SIGNWRITING WALLPLANE SHOULDER HIP MOVE
1DA70 SIGNWRITING FLOORPLANE SHOULDER HIP MOVE
1DA71 SIGNWRITING SHOULDER TILTING FROM WAIST
1DA72 SIGNWRITING TORSO-WALLPLANE STRAIGHT STRETCH
1DA73 SIGNWRITING TORSO-WALLPLANE CURVED BEND
1DA74 SIGNWRITING TORSO-FLOORPLANE TWISTING
1DA75 SIGNWRITING UPPER BODY TILTING FROM HIP JOINTS
1DA76 SIGNWRITING LIMB COMBINATION
1DA77 SIGNWRITING LIMB LENGTH-1
1DA78 SIGNWRITING LIMB LENGTH-2
1DA79 SIGNWRITING LIMB LENGTH-3
1DA7A SIGNWRITING LIMB LENGTH-4
1DA7B SIGNWRITING LIMB LENGTH-5
1DA7C SIGNWRITING LIMB LENGTH-6
1DA7D SIGNWRITING LIMB LENGTH-7
1DA7E SIGNWRITING FINGER
1DA7F SIGNWRITING LOCATION-WALLPLANE SPACE
1DA80 SIGNWRITING LOCATION-FLOORPLANE SPACE
1DA81 SIGNWRITING LOCATION HEIGHT
1DA82 SIGNWRITING LOCATION WIDTH
1DA83 SIGNWRITING LOCATION DEPTH
1DA84 SIGNWRITING LOCATION HEAD NECK
1DA85 SIGNWRITING LOCATION TORSO
1DA86 SIGNWRITING LOCATION LIMBS DIGITS
1DA87 SIGNWRITING COMMA
1DA88 SIGNWRITING FULL STOP
1DA89 SIGNWRITING SEMICOLON
1DA8A SIGNWRITING COLON
1DA8B SIGNWRITING PARENTHESIS
1DA9B SIGNWRITING FILL MODIFIER-2
1DA9C SIGNWRITING FILL MODIFIER-3
1DA9D SIGNWRITING FILL MODIFIER-4
1DA9E SIGNWRITING FILL MODIFIER-5
1DA9F SIGNWRITING FILL MODIFIER-6
1DAA1 SIGNWRITING ROTATION MODIFIER-2
1DAA2 SIGNWRITING ROTATION MODIFIER-3
1DAA3 SIGNWRITING ROTATION MODIFIER-4
1DAA4 SIGNWRITING ROTATION MODIFIER-5
1DAA5 SIGNWRITING ROTATION MODIFIER-6
1DAA6 SIGNWRITING ROTATION MODIFIER-7
1DAA7 SIGNWRITING ROTATION MODIFIER-8
1DAA8 SIGNWRITING ROTATION MODIFIER-9
1DAA9 SIGNWRITING ROTATION MODIFIER-10
1DAAA SIGNWRITING ROTATION MODIFIER-11
1DAAB SIGNWRITING ROTATION MODIFIER-12
1DAAC SIGNWRITING ROTATION MODIFIER-13
1DAAD SIGNWRITING ROTATION MODIFIER-14
1DAAE SIGNWRITING ROTATION MODIFIER-15
1DAAF SIGNWRITING ROTATION MODIFIER-16
1E000 COMBINING GLAGOLITIC LETTER AZU
1E001 COMBINING GLAGOLITIC LETTER BUKY
1E002 COMBINING GLAGOLITIC LETTER VEDE
1E003 COMBINING GLAGOLITIC LETTER GLAGOLI
1E004 COMBINING GLAGOLITIC LETTER DOBRO
1E005 COMBINING GLAGOLITIC LETTER YESTU
1E006 COMBINING GLAGOLITIC LETTER ZHIVETE
1E008 COMBINING GLAGOLITIC LETTER ZEMLJA
1E009 COMBINING GLAGOLITIC LETTER IZHE
1E00A COMBINING GLAGOLITIC LETTER INITIAL IZHE
1E00B COMBINING GLAGOLITIC LETTER I
1E00C COMBINING GLAGOLITIC LETTER DJERVI
1E00D COMBINING GLAGOLITIC LETTER KAKO
1E00E COMBINING GLAGOLITIC LETTER LJUDIJE
1E00F COMBINING GLAGOLITIC LETTER MYSLITE
1E010 COMBINING GLAGOLITIC LETTER NASHI
1E011 COMBINING GLAGOLITIC LETTER ONU
1E012 COMBINING GLAGOLITIC LETTER POKOJI
1E013 COMBINING GLAGOLITIC LETTER RITSI
1E014 COMBINING GLAGOLITIC LETTER SLOVO
1E015 COMBINING GLAGOLITIC LETTER TVRIDO
1E016 COMBINING GLAGOLITIC LETTER UKU
1E017 COMBINING GLAGOLITIC LETTER FRITU
1E018 COMBINING GLAGOLITIC LETTER HERU
1E01B COMBINING GLAGOLITIC LETTER SHTA
1E01C COMBINING GLAGOLITIC LETTER TSI
1E01D COMBINING GLAGOLITIC LETTER CHRIVI
1E01E COMBINING GLAGOLITIC LETTER SHA
1E01F COMBINING GLAGOLITIC LETTER YERU
1E020 COMBINING GLAGOLITIC LETTER YERI
1E021 COMBINING GLAGOLITIC LETTER YATI
1E023 COMBINING GLAGOLITIC LETTER YU
1E024 COMBINING GLAGOLITIC LETTER SMALL YUS
1E026 COMBINING GLAGOLITIC LETTER YO
1E027 COMBINING GLAGOLITIC LETTER IOTATED SMALL YUS
1E028 COMBINING GLAGOLITIC LETTER BIG YUS
1E029 COMBINING GLAGOLITIC LETTER IOTATED BIG YUS
1E02A COMBINING GLAGOLITIC LETTER FITA
1E800 MENDE KIKAKUI SYLLABLE M001 KI
1E801 MENDE KIKAKUI SYLLABLE M002 KA
1E802 MENDE KIKAKUI SYLLABLE M003 KU
1E803 MENDE KIKAKUI SYLLABLE M065 KEE
1E804 MENDE KIKAKUI SYLLABLE M095 KE
1E805 MENDE KIKAKUI SYLLABLE M076 KOO
1E806 MENDE KIKAKUI SYLLABLE M048 KO
1E807 MENDE KIKAKUI SYLLABLE M179 KUA
1E808 MENDE KIKAKUI SYLLABLE M004 WI
1E809 MENDE KIKAKUI SYLLABLE M005 WA
1E80A MENDE KIKAKUI SYLLABLE M006 WU
1E80B MENDE KIKAKUI SYLLABLE M126 WEE
1E80C MENDE KIKAKUI SYLLABLE M118 WE
1E80D MENDE KIKAKUI SYLLABLE M114 WOO
1E80E MENDE KIKAKUI SYLLABLE M045 WO
1E80F MENDE KIKAKUI SYLLABLE M194 WUI
1E810 MENDE KIKAKUI SYLLABLE M143 WEI
1E811 MENDE KIKAKUI SYLLABLE M061 WVI
1E812 MENDE KIKAKUI SYLLABLE M049 WVA
1E813 MENDE KIKAKUI SYLLABLE M139 WVE
1E814 MENDE KIKAKUI SYLLABLE M007 MIN
1E815 MENDE KIKAKUI SYLLABLE M008 MAN
1E816 MENDE KIKAKUI SYLLABLE M009 MUN
1E817 MENDE KIKAKUI SYLLABLE M059 MEN
1E818 MENDE KIKAKUI SYLLABLE M094 MON
1E819 MENDE KIKAKUI SYLLABLE M154 MUAN
1E81A MENDE KIKAKUI SYLLABLE M189 MUEN
1E81B MENDE KIKAKUI SYLLABLE M010 BI
1E81C MENDE KIKAKUI SYLLABLE M011 BA
1E81D MENDE KIKAKUI SYLLABLE M012 BU
1E81E MENDE KIKAKUI SYLLABLE M150 BEE
1E81F MENDE KIKAKUI SYLLABLE M097 BE
1E820 MENDE KIKAKUI SYLLABLE M103 BOO
1E821 MENDE KIKAKUI SYLLABLE M138 BO
1E822 MENDE KIKAKUI SYLLABLE M013 I
1E823 MENDE KIKAKUI SYLLABLE M014 A
1E824 MENDE KIKAKUI SYLLABLE M015 U
1E825 MENDE KIKAKUI SYLLABLE M163 EE
1E826 MENDE KIKAKUI SYLLABLE M100 E
1E827 MENDE KIKAKUI SYLLABLE M165 OO
1E828 MENDE KIKAKUI SYLLABLE M147 O
1E829 MENDE KIKAKUI SYLLABLE M137 EI
1E82A MENDE KIKAKUI SYLLABLE M131 IN
1E82B MENDE KIKAKUI SYLLABLE M135 IN
1E82C MENDE KIKAKUI SYLLABLE M195 AN
1E82D MENDE KIKAKUI SYLLABLE M178 EN
1E82E MENDE KIKAKUI SYLLABLE M019 SI
1E82F MENDE KIKAKUI SYLLABLE M020 SA
1E830 MENDE KIKAKUI SYLLABLE M021 SU
1E831 MENDE KIKAKUI SYLLABLE M162 SEE
1E832 MENDE KIKAKUI SYLLABLE M116 SE
1E833 MENDE KIKAKUI SYLLABLE M136 SOO
1E834 MENDE KIKAKUI SYLLABLE M079 SO
1E835 MENDE KIKAKUI SYLLABLE M196 SIA
1E836 MENDE KIKAKUI SYLLABLE M025 LI
1E837 MENDE KIKAKUI SYLLABLE M026 LA
1E838 MENDE KIKAKUI SYLLABLE M027 LU
1E839 MENDE KIKAKUI SYLLABLE M084 LEE
1E83A MENDE KIKAKUI SYLLABLE M073 LE
1E83B MENDE KIKAKUI SYLLABLE M054 LOO
1E83C MENDE KIKAKUI SYLLABLE M153 LO
1E83D MENDE KIKAKUI SYLLABLE M110 LONG LE
1E83E MENDE KIKAKUI SYLLABLE M016 DI
1E83F MENDE KIKAKUI SYLLABLE M017 DA
1E840 MENDE KIKAKUI SYLLABLE M018 DU
1E841 MENDE KIKAKUI SYLLABLE M089 DEE
1E842 MENDE KIKAKUI SYLLABLE M180 DOO
1E843 MENDE KIKAKUI SYLLABLE M181 DO
1E844 MENDE KIKAKUI SYLLABLE M022 TI
1E845 MENDE KIKAKUI SYLLABLE M023 TA
1E846 MENDE KIKAKUI SYLLABLE M024 TU
1E847 MENDE KIKAKUI SYLLABLE M091 TEE
1E848 MENDE KIKAKUI SYLLABLE M055 TE
1E849 MENDE KIKAKUI SYLLABLE M104 TOO
1E84A MENDE KIKAKUI SYLLABLE M069 TO
1E84B MENDE KIKAKUI SYLLABLE M028 JI
1E84C MENDE KIKAKUI SYLLABLE M029 JA
1E84D MENDE KIKAKUI SYLLABLE M030 JU
1E84E MENDE KIKAKUI SYLLABLE M157 JEE
1E84F MENDE KIKAKUI SYLLABLE M113 JE
1E850 MENDE KIKAKUI SYLLABLE M160 JOO
1E851 MENDE KIKAKUI SYLLABLE M063 JO
1E852 MENDE KIKAKUI SYLLABLE M175 LONG JO
1E853 MENDE KIKAKUI SYLLABLE M031 YI
1E854 MENDE KIKAKUI SYLLABLE M032 YA
1E855 MENDE KIKAKUI SYLLABLE M033 YU
1E856 MENDE KIKAKUI SYLLABLE M109 YEE
1E857 MENDE KIKAKUI SYLLABLE M080 YE
1E858 MENDE KIKAKUI SYLLABLE M141 YOO
1E859 MENDE KIKAKUI SYLLABLE M121 YO
1E85A MENDE KIKAKUI SYLLABLE M034 FI
1E85B MENDE KIKAKUI SYLLABLE M035 FA
1E85C MENDE KIKAKUI SYLLABLE M036 FU
1E85D MENDE KIKAKUI SYLLABLE M078 FEE
1E85E MENDE KIKAKUI SYLLABLE M075 FE
1E85F MENDE KIKAKUI SYLLABLE M133 FOO
1E860 MENDE KIKAKUI SYLLABLE M088 FO
1E861 MENDE KIKAKUI SYLLABLE M197 FUA
1E862 MENDE KIKAKUI SYLLABLE M101 FAN
1E863 MENDE KIKAKUI SYLLABLE M037 NIN
1E864 MENDE KIKAKUI SYLLABLE M038 NAN
1E865 MENDE KIKAKUI SYLLABLE M039 NUN
1E866 MENDE KIKAKUI SYLLABLE M117 NEN
1E867 MENDE KIKAKUI SYLLABLE M169 NON
1E868 MENDE KIKAKUI SYLLABLE M176 HI
1E869 MENDE KIKAKUI SYLLABLE M041 HA
1E86A MENDE KIKAKUI SYLLABLE M186 HU
1E86B MENDE KIKAKUI SYLLABLE M040 HEE
1E86C MENDE KIKAKUI SYLLABLE M096 HE
1E86D MENDE KIKAKUI SYLLABLE M042 HOO
1E86E MENDE KIKAKUI SYLLABLE M140 HO
1E86F MENDE KIKAKUI SYLLABLE M083 HEEI
1E870 MENDE KIKAKUI SYLLABLE M128 HOOU
1E871 MENDE KIKAKUI SYLLABLE M053 HIN
1E872 MENDE KIKAKUI SYLLABLE M130 HAN
1E873 MENDE KIKAKUI SYLLABLE M087 HUN
1E874 MENDE KIKAKUI SYLLABLE M052 HEN
1E875 MENDE KIKAKUI SYLLABLE M193 HON
1E876 MENDE KIKAKUI SYLLABLE M046 HUAN
1E877 MENDE KIKAKUI SYLLABLE M090 NGGI
1E878 MENDE KIKAKUI SYLLABLE M043 NGGA
1E879 MENDE KIKAKUI SYLLABLE M082 NGGU
1E87A MENDE KIKAKUI SYLLABLE M115 NGGEE
1E87B MENDE KIKAKUI SYLLABLE M146 NGGE
1E87C MENDE KIKAKUI SYLLABLE M156 NGGOO
1E87D MENDE KIKAKUI SYLLABLE M120 NGGO
1E87E MENDE KIKAKUI SYLLABLE M159 NGGAA
1E87F MENDE KIKAKUI SYLLABLE M127 NGGUA
1E880 MENDE KIKAKUI SYLLABLE M086 LONG NGGE
1E881 MENDE KIKAKUI SYLLABLE M106 LONG NGGOO
1E882 MENDE KIKAKUI SYLLABLE M183 LONG NGGO
1E883 MENDE KIKAKUI SYLLABLE M155 GI
1E884 MENDE KIKAKUI SYLLABLE M111 GA
1E885 MENDE KIKAKUI SYLLABLE M168 GU
1E886 MENDE KIKAKUI SYLLABLE M190 GEE
1E887 MENDE KIKAKUI SYLLABLE M166 GUEI
1E888 MENDE KIKAKUI SYLLABLE M167 GUAN
1E889 MENDE KIKAKUI SYLLABLE M184 NGEN
1E88A MENDE KIKAKUI SYLLABLE M057 NGON
1E88B MENDE KIKAKUI SYLLABLE M177 NGUAN
1E88C MENDE KIKAKUI SYLLABLE M068 PI
1E88D MENDE KIKAKUI SYLLABLE M099 PA
1E88E MENDE KIKAKUI SYLLABLE M050 PU
1E88F MENDE KIKAKUI SYLLABLE M081 PEE
1E890 MENDE KIKAKUI SYLLABLE M051 PE
1E891 MENDE KIKAKUI SYLLABLE M102 POO
1E892 MENDE KIKAKUI SYLLABLE M066 PO
1E893 MENDE KIKAKUI SYLLABLE M145 MBI
1E894 MENDE KIKAKUI SYLLABLE M062 MBA
1E895 MENDE KIKAKUI SYLLABLE M122 MBU
1E896 MENDE KIKAKUI SYLLABLE M047 MBEE
1E897 MENDE KIKAKUI SYLLABLE M188 MBEE
1E898 MENDE KIKAKUI SYLLABLE M072 MBE
1E899 MENDE KIKAKUI SYLLABLE M172 MBOO
1E89A MENDE KIKAKUI SYLLABLE M174 MBO
1E89B MENDE KIKAKUI SYLLABLE M187 MBUU
1E89C MENDE KIKAKUI SYLLABLE M161 LONG MBE
1E89D MENDE KIKAKUI SYLLABLE M105 LONG MBOO
1E89E MENDE KIKAKUI SYLLABLE M142 LONG MBO
1E89F MENDE KIKAKUI SYLLABLE M132 KPI
1E8A0 MENDE KIKAKUI SYLLABLE M092 KPA
1E8A1 MENDE KIKAKUI SYLLABLE M074 KPU
1E8A2 MENDE KIKAKUI SYLLABLE M044 KPEE
1E8A3 MENDE KIKAKUI SYLLABLE M108 KPE
1E8A4 MENDE KIKAKUI SYLLABLE M112 KPOO
1E8A5 MENDE KIKAKUI SYLLABLE M158 KPO
1E8A6 MENDE KIKAKUI SYLLABLE M124 GBI
1E8A7 MENDE KIKAKUI SYLLABLE M056 GBA
1E8A8 MENDE KIKAKUI SYLLABLE M148 GBU
1E8A9 MENDE KIKAKUI SYLLABLE M093 GBEE
1E8AA MENDE KIKAKUI SYLLABLE M107 GBE
1E8AB MENDE KIKAKUI SYLLABLE M071 GBOO
1E8AC MENDE KIKAKUI SYLLABLE M070 GBO
1E8AD MENDE KIKAKUI SYLLABLE M171 RA
1E8AE MENDE KIKAKUI SYLLABLE M123 NDI
1E8AF MENDE KIKAKUI SYLLABLE M129 NDA
1E8B0 MENDE KIKAKUI SYLLABLE M125 NDU
1E8B1 MENDE KIKAKUI SYLLABLE M191 NDEE
1E8B2 MENDE KIKAKUI SYLLABLE M119 NDE
1E8B3 MENDE KIKAKUI SYLLABLE M067 NDOO
1E8B4 MENDE KIKAKUI SYLLABLE M064 NDO
1E8B5 MENDE KIKAKUI SYLLABLE M152 NJA
1E8B6 MENDE KIKAKUI SYLLABLE M192 NJU
1E8B7 MENDE KIKAKUI SYLLABLE M149 NJEE
1E8B8 MENDE KIKAKUI SYLLABLE M134 NJOO
1E8B9 MENDE KIKAKUI SYLLABLE M182 VI
1E8BA MENDE KIKAKUI SYLLABLE M185 VA
1E8BB MENDE KIKAKUI SYLLABLE M151 VU
1E8BC MENDE KIKAKUI SYLLABLE M173 VEE
1E8BD MENDE KIKAKUI SYLLABLE M085 VE
1E8BE MENDE KIKAKUI SYLLABLE M144 VOO
1E8BF MENDE KIKAKUI SYLLABLE M077 VO
1E8C0 MENDE KIKAKUI SYLLABLE M164 NYIN
1E8C1 MENDE KIKAKUI SYLLABLE M058 NYAN
1E8C2 MENDE KIKAKUI SYLLABLE M170 NYUN
1E8C3 MENDE KIKAKUI SYLLABLE M098 NYEN
1E8C4 MENDE KIKAKUI SYLLABLE M060 NYON
1E8C7 MENDE KIKAKUI DIGIT ONE
1E8C8 MENDE KIKAKUI DIGIT TWO
1E8C9 MENDE KIKAKUI DIGIT THREE
1E8CA MENDE KIKAKUI DIGIT FOUR
1E8CB MENDE KIKAKUI DIGIT FIVE
1E8CC MENDE KIKAKUI DIGIT SIX
1E8CD MENDE KIKAKUI DIGIT SEVEN
1E8CE MENDE KIKAKUI DIGIT EIGHT
1E8CF MENDE KIKAKUI DIGIT NINE
1E8D0 MENDE KIKAKUI COMBINING NUMBER TEENS
1E8D1 MENDE KIKAKUI COMBINING NUMBER TENS
1E8D2 MENDE KIKAKUI COMBINING NUMBER HUNDREDS
1E8D3 MENDE KIKAKUI COMBINING NUMBER THOUSANDS
1E8D4 MENDE KIKAKUI COMBINING NUMBER TEN THOUSANDS
1E8D5 MENDE KIKAKUI COMBINING NUMBER HUNDRED THOUSANDS
1E8D6 MENDE KIKAKUI COMBINING NUMBER MILLIONS
1E900 ADLAM CAPITAL LETTER ALIF
1E901 ADLAM CAPITAL LETTER DAALI
1E902 ADLAM CAPITAL LETTER LAAM
1E903 ADLAM CAPITAL LETTER MIIM
1E904 ADLAM CAPITAL LETTER BA
1E905 ADLAM CAPITAL LETTER SINNYIIYHE
1E906 ADLAM CAPITAL LETTER PE
1E907 ADLAM CAPITAL LETTER BHE
1E908 ADLAM CAPITAL LETTER RA
1E909 ADLAM CAPITAL LETTER E
1E90A ADLAM CAPITAL LETTER FA
1E90B ADLAM CAPITAL LETTER I
1E90C ADLAM CAPITAL LETTER O
1E90D ADLAM CAPITAL LETTER DHA
1E90E ADLAM CAPITAL LETTER YHE
1E90F ADLAM CAPITAL LETTER WAW
1E910 ADLAM CAPITAL LETTER NUN
1E911 ADLAM CAPITAL LETTER KAF
1E912 ADLAM CAPITAL LETTER YA
1E913 ADLAM CAPITAL LETTER U
1E914 ADLAM CAPITAL LETTER JIIM
1E915 ADLAM CAPITAL LETTER CHI
1E916 ADLAM CAPITAL LETTER HA
1E917 ADLAM CAPITAL LETTER QAAF
1E918 ADLAM CAPITAL LETTER GA
1E919 ADLAM CAPITAL LETTER NYA
1E91A ADLAM CAPITAL LETTER TU
1E91B ADLAM CAPITAL LETTER NHA
1E91C ADLAM CAPITAL LETTER VA
1E91D ADLAM CAPITAL LETTER KHA
1E91E ADLAM CAPITAL LETTER GBE
1E91F ADLAM CAPITAL LETTER ZAL
1E920 ADLAM CAPITAL LETTER KPO
1E921 ADLAM CAPITAL LETTER SHA
1E922 ADLAM SMALL LETTER ALIF
1E923 ADLAM SMALL LETTER DAALI
1E924 ADLAM SMALL LETTER LAAM
1E925 ADLAM SMALL LETTER MIIM
1E926 ADLAM SMALL LETTER BA
1E927 ADLAM SMALL LETTER SINNYIIYHE
1E928 ADLAM SMALL LETTER PE
1E929 ADLAM SMALL LETTER BHE
1E92A ADLAM SMALL LETTER RA
1E92B ADLAM SMALL LETTER E
1E92C ADLAM SMALL LETTER FA
1E92D ADLAM SMALL LETTER I
1E92E ADLAM SMALL LETTER O
1E92F ADLAM SMALL LETTER DHA
1E930 ADLAM SMALL LETTER YHE
1E931 ADLAM SMALL LETTER WAW
1E932 ADLAM SMALL LETTER NUN
1E933 ADLAM SMALL LETTER KAF
1E934 ADLAM SMALL LETTER YA
1E935 ADLAM SMALL LETTER U
1E936 ADLAM SMALL LETTER JIIM
1E937 ADLAM SMALL LETTER CHI
1E938 ADLAM SMALL LETTER HA
1E939 ADLAM SMALL LETTER QAAF
1E93A ADLAM SMALL LETTER GA
1E93B ADLAM SMALL LETTER NYA
1E93C ADLAM SMALL LETTER TU
1E93D ADLAM SMALL LETTER NHA
1E93E ADLAM SMALL LETTER VA
1E93F ADLAM SMALL LETTER KHA
1E940 ADLAM SMALL LETTER GBE
1E941 ADLAM SMALL LETTER ZAL
1E942 ADLAM SMALL LETTER KPO
1E943 ADLAM SMALL LETTER SHA
1E944 ADLAM ALIF LENGTHENER
1E945 ADLAM VOWEL LENGTHENER
1E946 ADLAM GEMINATION MARK
1E947 ADLAM HAMZA
1E948 ADLAM CONSONANT MODIFIER
1E949 ADLAM GEMINATE CONSONANT MODIFIER
1E94A ADLAM NUKTA
1E950 ADLAM DIGIT ZERO
1E951 ADLAM DIGIT ONE
1E952 ADLAM DIGIT TWO
1E953 ADLAM DIGIT THREE
1E954 ADLAM DIGIT FOUR
1E955 ADLAM DIGIT FIVE
1E956 ADLAM DIGIT SIX
1E957 ADLAM DIGIT SEVEN
1E958 ADLAM DIGIT EIGHT
1E959 ADLAM DIGIT NINE
1E95E ADLAM INITIAL EXCLAMATION MARK
1E95F ADLAM INITIAL QUESTION MARK
1EE00 ARABIC MATHEMATICAL ALEF
1EE01 ARABIC MATHEMATICAL BEH
1EE02 ARABIC MATHEMATICAL JEEM
1EE03 ARABIC MATHEMATICAL DAL
1EE05 ARABIC MATHEMATICAL WAW
1EE06 ARABIC MATHEMATICAL ZAIN
1EE07 ARABIC MATHEMATICAL HAH
1EE08 ARABIC MATHEMATICAL TAH
1EE09 ARABIC MATHEMATICAL YEH
1EE0A ARABIC MATHEMATICAL KAF
1EE0B ARABIC MATHEMATICAL LAM
1EE0C ARABIC MATHEMATICAL MEEM
1EE0D ARABIC MATHEMATICAL NOON
1EE0E ARABIC MATHEMATICAL SEEN
1EE0F ARABIC MATHEMATICAL AIN
1EE10 ARABIC MATHEMATICAL FEH
1EE11 ARABIC MATHEMATICAL SAD
1EE12 ARABIC MATHEMATICAL QAF
1EE13 ARABIC MATHEMATICAL REH
1EE14 ARABIC MATHEMATICAL SHEEN
1EE15 ARABIC MATHEMATICAL TEH
1EE16 ARABIC MATHEMATICAL THEH
1EE17 ARABIC MATHEMATICAL KHAH
1EE18 ARABIC MATHEMATICAL THAL
1EE19 ARABIC MATHEMATICAL DAD
1EE1A ARABIC MATHEMATICAL ZAH
1EE1B ARABIC MATHEMATICAL GHAIN
1EE1C ARABIC MATHEMATICAL DOTLESS BEH
1EE1D ARABIC MATHEMATICAL DOTLESS NOON
1EE1E ARABIC MATHEMATICAL DOTLESS FEH
1EE1F ARABIC MATHEMATICAL DOTLESS QAF
1EE21 ARABIC MATHEMATICAL INITIAL BEH
1EE22 ARABIC MATHEMATICAL INITIAL JEEM
1EE24 ARABIC MATHEMATICAL INITIAL HEH
1EE27 ARABIC MATHEMATICAL INITIAL HAH
1EE29 ARABIC MATHEMATICAL INITIAL YEH
1EE2A ARABIC MATHEMATICAL INITIAL KAF
1EE2B ARABIC MATHEMATICAL INITIAL LAM
1EE2C ARABIC MATHEMATICAL INITIAL MEEM
1EE2D ARABIC MATHEMATICAL INITIAL NOON
1EE2E ARABIC MATHEMATICAL INITIAL SEEN
1EE2F ARABIC MATHEMATICAL INITIAL AIN
1EE30 ARABIC MATHEMATICAL INITIAL FEH
1EE31 ARABIC MATHEMATICAL INITIAL SAD
1EE32 ARABIC MATHEMATICAL INITIAL QAF
1EE34 ARABIC MATHEMATICAL INITIAL SHEEN
1EE35 ARABIC MATHEMATICAL INITIAL TEH
1EE36 ARABIC MATHEMATICAL INITIAL THEH
1EE37 ARABIC MATHEMATICAL INITIAL KHAH
1EE39 ARABIC MATHEMATICAL INITIAL DAD
1EE3B ARABIC MATHEMATICAL INITIAL GHAIN
1EE42 ARABIC MATHEMATICAL TAILED JEEM
1EE47 ARABIC MATHEMATICAL TAILED HAH
1EE49 ARABIC MATHEMATICAL TAILED YEH
1EE4B ARABIC MATHEMATICAL TAILED LAM
1EE4D ARABIC MATHEMATICAL TAILED NOON
1EE4E ARABIC MATHEMATICAL TAILED SEEN
1EE4F ARABIC MATHEMATICAL TAILED AIN
1EE51 ARABIC MATHEMATICAL TAILED SAD
1EE52 ARABIC MATHEMATICAL TAILED QAF
1EE54 ARABIC MATHEMATICAL TAILED SHEEN
1EE57 ARABIC MATHEMATICAL TAILED KHAH
1EE59 ARABIC MATHEMATICAL TAILED DAD
1EE5B ARABIC MATHEMATICAL TAILED GHAIN
1EE5D ARABIC MATHEMATICAL TAILED DOTLESS NOON
1EE5F ARABIC MATHEMATICAL TAILED DOTLESS QAF
1EE61 ARABIC MATHEMATICAL STRETCHED BEH
1EE62 ARABIC MATHEMATICAL STRETCHED JEEM
1EE64 ARABIC MATHEMATICAL STRETCHED HEH
1EE67 ARABIC MATHEMATICAL STRETCHED HAH
1EE68 ARABIC MATHEMATICAL STRETCHED TAH
1EE69 ARABIC MATHEMATICAL STRETCHED YEH
1EE6A ARABIC MATHEMATICAL STRETCHED KAF
1EE6C ARABIC MATHEMATICAL STRETCHED MEEM
1EE6D ARABIC MATHEMATICAL STRETCHED NOON
1EE6E ARABIC MATHEMATICAL STRETCHED SEEN
1EE6F ARABIC MATHEMATICAL STRETCHED AIN
1EE70 ARABIC MATHEMATICAL STRETCHED FEH
1EE71 ARABIC MATHEMATICAL STRETCHED SAD
1EE72 ARABIC MATHEMATICAL STRETCHED QAF
1EE74 ARABIC MATHEMATICAL STRETCHED SHEEN
1EE75 ARABIC MATHEMATICAL STRETCHED TEH
1EE76 ARABIC MATHEMATICAL STRETCHED THEH
1EE77 ARABIC MATHEMATICAL STRETCHED KHAH
1EE79 ARABIC MATHEMATICAL STRETCHED DAD
1EE7A ARABIC MATHEMATICAL STRETCHED ZAH
1EE7B ARABIC MATHEMATICAL STRETCHED GHAIN
1EE7C ARABIC MATHEMATICAL STRETCHED DOTLESS BEH
1EE7E ARABIC MATHEMATICAL STRETCHED DOTLESS FEH
1EE80 ARABIC MATHEMATICAL LOOPED ALEF
1EE81 ARABIC MATHEMATICAL LOOPED BEH
1EE82 ARABIC MATHEMATICAL LOOPED JEEM
1EE83 ARABIC MATHEMATICAL LOOPED DAL
1EE84 ARABIC MATHEMATICAL LOOPED HEH
1EE85 ARABIC MATHEMATICAL LOOPED WAW
1EE86 ARABIC MATHEMATICAL LOOPED ZAIN
1EE87 ARABIC MATHEMATICAL LOOPED HAH
1EE88 ARABIC MATHEMATICAL LOOPED TAH
1EE89 ARABIC MATHEMATICAL LOOPED YEH
1EE8B ARABIC MATHEMATICAL LOOPED LAM
1EE8C ARABIC MATHEMATICAL LOOPED MEEM
1EE8D ARABIC MATHEMATICAL LOOPED NOON
1EE8E ARABIC MATHEMATICAL LOOPED SEEN
1EE8F ARABIC MATHEMATICAL LOOPED AIN
1EE90 ARABIC MATHEMATICAL LOOPED FEH
1EE91 ARABIC MATHEMATICAL LOOPED SAD
1EE92 ARABIC MATHEMATICAL LOOPED QAF
1EE93 ARABIC MATHEMATICAL LOOPED REH
1EE94 ARABIC MATHEMATICAL LOOPED SHEEN
1EE95 ARABIC MATHEMATICAL LOOPED TEH
1EE96 ARABIC MATHEMATICAL LOOPED THEH
1EE97 ARABIC MATHEMATICAL LOOPED KHAH
1EE98 ARABIC MATHEMATICAL LOOPED THAL
1EE99 ARABIC MATHEMATICAL LOOPED DAD
1EE9A ARABIC MATHEMATICAL LOOPED ZAH
1EE9B ARABIC MATHEMATICAL LOOPED GHAIN
1EEA1 ARABIC MATHEMATICAL DOUBLE-STRUCK BEH
1EEA2 ARABIC MATHEMATICAL DOUBLE-STRUCK JEEM
1EEA3 ARABIC MATHEMATICAL DOUBLE-STRUCK DAL
1EEA5 ARABIC MATHEMATICAL DOUBLE-STRUCK WAW
1EEA6 ARABIC MATHEMATICAL DOUBLE-STRUCK ZAIN
1EEA7 ARABIC MATHEMATICAL DOUBLE-STRUCK HAH
1EEA8 ARABIC MATHEMATICAL DOUBLE-STRUCK TAH
1EEA9 ARABIC MATHEMATICAL DOUBLE-STRUCK YEH
1EEAB ARABIC MATHEMATICAL DOUBLE-STRUCK LAM
1EEAC ARABIC MATHEMATICAL DOUBLE-STRUCK MEEM
1EEAD ARABIC MATHEMATICAL DOUBLE-STRUCK NOON
1EEAE ARABIC MATHEMATICAL DOUBLE-STRUCK SEEN
1EEAF ARABIC MATHEMATICAL DOUBLE-STRUCK AIN
1EEB0 ARABIC MATHEMATICAL DOUBLE-STRUCK FEH
1EEB1 ARABIC MATHEMATICAL DOUBLE-STRUCK SAD
1EEB2 ARABIC MATHEMATICAL DOUBLE-STRUCK QAF
1EEB3 ARABIC MATHEMATICAL DOUBLE-STRUCK REH
1EEB4 ARABIC MATHEMATICAL DOUBLE-STRUCK SHEEN
1EEB5 ARABIC MATHEMATICAL DOUBLE-STRUCK TEH
1EEB6 ARABIC MATHEMATICAL DOUBLE-STRUCK THEH
1EEB7 ARABIC MATHEMATICAL DOUBLE-STRUCK KHAH
1EEB8 ARABIC MATHEMATICAL DOUBLE-STRUCK THAL
1EEB9 ARABIC MATHEMATICAL DOUBLE-STRUCK DAD
1EEBA ARABIC MATHEMATICAL DOUBLE-STRUCK ZAH
1EEBB ARABIC MATHEMATICAL DOUBLE-STRUCK GHAIN
1EEF0 ARABIC MATHEMATICAL OPERATOR MEEM WITH HAH WITH TATWEEL
1EEF1 ARABIC MATHEMATICAL OPERATOR HAH WITH DAL
1F000 MAHJONG TILE EAST WIND
1F001 MAHJONG TILE SOUTH WIND
1F002 MAHJONG TILE WEST WIND
1F003 MAHJONG TILE NORTH WIND
1F004 MAHJONG TILE RED DRAGON
1F005 MAHJONG TILE GREEN DRAGON
1F006 MAHJONG TILE WHITE DRAGON
1F007 MAHJONG TILE ONE OF CHARACTERS
1F008 MAHJONG TILE TWO OF CHARACTERS
1F009 MAHJONG TILE THREE OF CHARACTERS
1F00A MAHJONG TILE FOUR OF CHARACTERS
1F00B MAHJONG TILE FIVE OF CHARACTERS
1F00C MAHJONG TILE SIX OF CHARACTERS
1F00D MAHJONG TILE SEVEN OF CHARACTERS
1F00E MAHJONG TILE EIGHT OF CHARACTERS
1F00F MAHJONG TILE NINE OF CHARACTERS
1F010 MAHJONG TILE ONE OF BAMBOOS
1F011 MAHJONG TILE TWO OF BAMBOOS
1F012 MAHJONG TILE THREE OF BAMBOOS
1F013 MAHJONG TILE FOUR OF BAMBOOS
1F014 MAHJONG TILE FIVE OF BAMBOOS
1F015 MAHJONG TILE SIX OF BAMBOOS
1F016 MAHJONG TILE SEVEN OF BAMBOOS
1F017 MAHJONG TILE EIGHT OF BAMBOOS
1F018 MAHJONG TILE NINE OF BAMBOOS
1F019 MAHJONG TILE ONE OF CIRCLES
1F01A MAHJONG TILE TWO OF CIRCLES
1F01B MAHJONG TILE THREE OF CIRCLES
1F01C MAHJONG TILE FOUR OF CIRCLES
1F01D MAHJONG TILE FIVE OF CIRCLES
1F01E MAHJONG TILE SIX OF CIRCLES
1F01F MAHJONG TILE SEVEN OF CIRCLES
1F020 MAHJONG TILE EIGHT OF CIRCLES
1F021 MAHJONG TILE NINE OF CIRCLES
1F022 MAHJONG TILE PLUM
1F023 MAHJONG TILE ORCHID
1F024 MAHJONG TILE BAMBOO
1F025 MAHJONG TILE CHRYSANTHEMUM
1F026 MAHJONG TILE SPRING
1F027 MAHJONG TILE SUMMER
1F028 MAHJONG TILE AUTUMN
1F029 MAHJONG TILE WINTER
1F02A MAHJONG TILE JOKER
1F02B MAHJONG TILE BACK
1F030 DOMINO TILE HORIZONTAL BACK
1F031 DOMINO TILE HORIZONTAL-00-00
1F032 DOMINO TILE HORIZONTAL-00-01
1F033 DOMINO TILE HORIZONTAL-00-02
1F034 DOMINO TILE HORIZONTAL-00-03
1F035 DOMINO TILE HORIZONTAL-00-04
1F036 DOMINO TILE HORIZONTAL-00-05
1F037 DOMINO TILE HORIZONTAL-00-06
1F038 DOMINO TILE HORIZONTAL-01-00
1F039 DOMINO TILE HORIZONTAL-01-01
1F03A DOMINO TILE HORIZONTAL-01-02
1F03B DOMINO TILE HORIZONTAL-01-03
1F03C DOMINO TILE HORIZONTAL-01-04
1F03D DOMINO TILE HORIZONTAL-01-05
1F03E DOMINO TILE HORIZONTAL-01-06
1F03F DOMINO TILE HORIZONTAL-02-00
1F040 DOMINO TILE HORIZONTAL-02-01
1F041 DOMINO TILE HORIZONTAL-02-02
1F042 DOMINO TILE HORIZONTAL-02-03
1F043 DOMINO TILE HORIZONTAL-02-04
1F044 DOMINO TILE HORIZONTAL-02-05
1F045 DOMINO TILE HORIZONTAL-02-06
1F046 DOMINO TILE HORIZONTAL-03-00
1F047 DOMINO TILE HORIZONTAL-03-01
1F048 DOMINO TILE HORIZONTAL-03-02
1F049 DOMINO TILE HORIZONTAL-03-03
1F04A DOMINO TILE HORIZONTAL-03-04
1F04B DOMINO TILE HORIZONTAL-03-05
1F04C DOMINO TILE HORIZONTAL-03-06
1F04D DOMINO TILE HORIZONTAL-04-00
1F04E DOMINO TILE HORIZONTAL-04-01
1F04F DOMINO TILE HORIZONTAL-04-02
1F050 DOMINO TILE HORIZONTAL-04-03
1F051 DOMINO TILE HORIZONTAL-04-04
1F052 DOMINO TILE HORIZONTAL-04-05
1F053 DOMINO TILE HORIZONTAL-04-06
1F054 DOMINO TILE HORIZONTAL-05-00
1F055 DOMINO TILE HORIZONTAL-05-01
1F056 DOMINO TILE HORIZONTAL-05-02
1F057 DOMINO TILE HORIZONTAL-05-03
1F058 DOMINO TILE HORIZONTAL-05-04
1F059 DOMINO TILE HORIZONTAL-05-05
1F05A DOMINO TILE HORIZONTAL-05-06
1F05B DOMINO TILE HORIZONTAL-06-00
1F05C DOMINO TILE HORIZONTAL-06-01
1F05D DOMINO TILE HORIZONTAL-06-02
1F05E DOMINO TILE HORIZONTAL-06-03
1F05F DOMINO TILE HORIZONTAL-06-04
1F060 DOMINO TILE HORIZONTAL-06-05
1F061 DOMINO TILE HORIZONTAL-06-06
1F062 DOMINO TILE VERTICAL BACK
1F063 DOMINO TILE VERTICAL-00-00
1F064 DOMINO TILE VERTICAL-00-01
1F065 DOMINO TILE VERTICAL-00-02
1F066 DOMINO TILE VERTICAL-00-03
1F067 DOMINO TILE VERTICAL-00-04
1F068 DOMINO TILE VERTICAL-00-05
1F069 DOMINO TILE VERTICAL-00-06
1F06A DOMINO TILE VERTICAL-01-00
1F06B DOMINO TILE VERTICAL-01-01
1F06C DOMINO TILE VERTICAL-01-02
1F06D DOMINO TILE VERTICAL-01-03
1F06E DOMINO TILE VERTICAL-01-04
1F06F DOMINO TILE VERTICAL-01-05
1F070 DOMINO TILE VERTICAL-01-06
1F071 DOMINO TILE VERTICAL-02-00
1F072 DOMINO TILE VERTICAL-02-01
1F073 DOMINO TILE VERTICAL-02-02
1F074 DOMINO TILE VERTICAL-02-03
1F075 DOMINO TILE VERTICAL-02-04
1F076 DOMINO TILE VERTICAL-02-05
1F077 DOMINO TILE VERTICAL-02-06
1F078 DOMINO TILE VERTICAL-03-00
1F079 DOMINO TILE VERTICAL-03-01
1F07A DOMINO TILE VERTICAL-03-02
1F07B DOMINO TILE VERTICAL-03-03
1F07C DOMINO TILE VERTICAL-03-04
1F07D DOMINO TILE VERTICAL-03-05
1F07E DOMINO TILE VERTICAL-03-06
1F07F DOMINO TILE VERTICAL-04-00
1F080 DOMINO TILE VERTICAL-04-01
1F081 DOMINO TILE VERTICAL-04-02
1F082 DOMINO TILE VERTICAL-04-03
1F083 DOMINO TILE VERTICAL-04-04
1F084 DOMINO TILE VERTICAL-04-05
1F085 DOMINO TILE VERTICAL-04-06
1F086 DOMINO TILE VERTICAL-05-00
1F087 DOMINO TILE VERTICAL-05-01
1F088 DOMINO TILE VERTICAL-05-02
1F089 DOMINO TILE VERTICAL-05-03
1F08A DOMINO TILE VERTICAL-05-04
1F08B DOMINO TILE VERTICAL-05-05
1F08C DOMINO TILE VERTICAL-05-06
1F08D DOMINO TILE VERTICAL-06-00
1F08E DOMINO TILE VERTICAL-06-01
1F08F DOMINO TILE VERTICAL-06-02
1F090 DOMINO TILE VERTICAL-06-03
1F091 DOMINO TILE VERTICAL-06-04
1F092 DOMINO TILE VERTICAL-06-05
1F093 DOMINO TILE VERTICAL-06-06
1F0A0 PLAYING CARD BACK
1F0A1 PLAYING CARD ACE OF SPADES
1F0A2 PLAYING CARD TWO OF SPADES
1F0A3 PLAYING CARD THREE OF SPADES
1F0A4 PLAYING CARD FOUR OF SPADES
1F0A5 PLAYING CARD FIVE OF SPADES
1F0A6 PLAYING CARD SIX OF SPADES
1F0A7 PLAYING CARD SEVEN OF SPADES
1F0A8 PLAYING CARD EIGHT OF SPADES
1F0A9 PLAYING CARD NINE OF SPADES
1F0AA PLAYING CARD TEN OF SPADES
1F0AB PLAYING CARD JACK OF SPADES
1F0AC PLAYING CARD KNIGHT OF SPADES
1F0AD PLAYING CARD QUEEN OF SPADES
1F0AE PLAYING CARD KING OF SPADES
1F0B1 PLAYING CARD ACE OF HEARTS
1F0B2 PLAYING CARD TWO OF HEARTS
1F0B3 PLAYING CARD THREE OF HEARTS
1F0B4 PLAYING CARD FOUR OF HEARTS
1F0B5 PLAYING CARD FIVE OF HEARTS
1F0B6 PLAYING CARD SIX OF HEARTS
1F0B7 PLAYING CARD SEVEN OF HEARTS
1F0B8 PLAYING CARD EIGHT OF HEARTS
1F0B9 PLAYING CARD NINE OF HEARTS
1F0BA PLAYING CARD TEN OF HEARTS
1F0BB PLAYING CARD JACK OF HEARTS
1F0BC PLAYING CARD KNIGHT OF HEARTS
1F0BD PLAYING CARD QUEEN OF HEARTS
1F0BE PLAYING CARD KING OF HEARTS
1F0BF PLAYING CARD RED JOKER
1F0C1 PLAYING CARD ACE OF DIAMONDS
1F0C2 PLAYING CARD TWO OF DIAMONDS
1F0C3 PLAYING CARD THREE OF DIAMONDS
1F0C4 PLAYING CARD FOUR OF DIAMONDS
1F0C5 PLAYING CARD FIVE OF DIAMONDS
1F0C6 PLAYING CARD SIX OF DIAMONDS
1F0C7 PLAYING CARD SEVEN OF DIAMONDS
1F0C8 PLAYING CARD EIGHT OF DIAMONDS
1F0C9 PLAYING CARD NINE OF DIAMONDS
1F0CA PLAYING CARD TEN OF DIAMONDS
1F0CB PLAYING CARD JACK OF DIAMONDS
1F0CC PLAYING CARD KNIGHT OF DIAMONDS
1F0CD PLAYING CARD QUEEN OF DIAMONDS
1F0CE PLAYING CARD KING OF DIAMONDS
1F0CF PLAYING CARD BLACK JOKER
1F0D1 PLAYING CARD ACE OF CLUBS
1F0D2 PLAYING CARD TWO OF CLUBS
1F0D3 PLAYING CARD THREE OF CLUBS
1F0D4 PLAYING CARD FOUR OF CLUBS
1F0D5 PLAYING CARD FIVE OF CLUBS
1F0D6 PLAYING CARD SIX OF CLUBS
1F0D7 PLAYING CARD SEVEN OF CLUBS
1F0D8 PLAYING CARD EIGHT OF CLUBS
1F0D9 PLAYING CARD NINE OF CLUBS
1F0DA PLAYING CARD TEN OF CLUBS
1F0DB PLAYING CARD JACK OF CLUBS
1F0DC PLAYING CARD KNIGHT OF CLUBS
1F0DD PLAYING CARD QUEEN OF CLUBS
1F0DE PLAYING CARD KING OF CLUBS
1F0DF PLAYING CARD WHITE JOKER
1F0E0 PLAYING CARD FOOL
1F0E1 PLAYING CARD TRUMP-1
1F0E2 PLAYING CARD TRUMP-2
1F0E3 PLAYING CARD TRUMP-3
1F0E4 PLAYING CARD TRUMP-4
1F0E5 PLAYING CARD TRUMP-5
1F0E6 PLAYING CARD TRUMP-6
1F0E7 PLAYING CARD TRUMP-7
1F0E8 PLAYING CARD TRUMP-8
1F0E9 PLAYING CARD TRUMP-9
1F0EA PLAYING CARD TRUMP-10
1F0EB PLAYING CARD TRUMP-11
1F0EC PLAYING CARD TRUMP-12
1F0ED PLAYING CARD TRUMP-13
1F0EE PLAYING CARD TRUMP-14
1F0EF PLAYING CARD TRUMP-15
1F0F0 PLAYING CARD TRUMP-16
1F0F1 PLAYING CARD TRUMP-17
1F0F2 PLAYING CARD TRUMP-18
1F0F3 PLAYING CARD TRUMP-19
1F0F4 PLAYING CARD TRUMP-20
1F0F5 PLAYING CARD TRUMP-21
1F100 DIGIT ZERO FULL STOP
1F101 DIGIT ZERO COMMA
1F102 DIGIT ONE COMMA
1F103 DIGIT TWO COMMA
1F104 DIGIT THREE COMMA
1F105 DIGIT FOUR COMMA
1F106 DIGIT FIVE COMMA
1F107 DIGIT SIX COMMA
1F108 DIGIT SEVEN COMMA
1F109 DIGIT EIGHT COMMA
1F10A DIGIT NINE COMMA
1F10B DINGBAT CIRCLED SANS-SERIF DIGIT ZERO
1F10C DINGBAT NEGATIVE CIRCLED SANS-SERIF DIGIT ZERO
1F110 PARENTHESIZED LATIN CAPITAL LETTER A
1F111 PARENTHESIZED LATIN CAPITAL LETTER B
1F112 PARENTHESIZED LATIN CAPITAL LETTER C
1F113 PARENTHESIZED LATIN CAPITAL LETTER D
1F114 PARENTHESIZED LATIN CAPITAL LETTER E
1F115 PARENTHESIZED LATIN CAPITAL LETTER F
1F116 PARENTHESIZED LATIN CAPITAL LETTER G
1F117 PARENTHESIZED LATIN CAPITAL LETTER H
1F118 PARENTHESIZED LATIN CAPITAL LETTER I
1F119 PARENTHESIZED LATIN CAPITAL LETTER J
1F11A PARENTHESIZED LATIN CAPITAL LETTER K
1F11B PARENTHESIZED LATIN CAPITAL LETTER L
1F11C PARENTHESIZED LATIN CAPITAL LETTER M
1F11D PARENTHESIZED LATIN CAPITAL LETTER N
1F11E PARENTHESIZED LATIN CAPITAL LETTER O
1F11F PARENTHESIZED LATIN CAPITAL LETTER P
1F120 PARENTHESIZED LATIN CAPITAL LETTER Q
1F121 PARENTHESIZED LATIN CAPITAL LETTER R
1F122 PARENTHESIZED LATIN CAPITAL LETTER S
1F123 PARENTHESIZED LATIN CAPITAL LETTER T
1F124 PARENTHESIZED LATIN CAPITAL LETTER U
1F125 PARENTHESIZED LATIN CAPITAL LETTER V
1F126 PARENTHESIZED LATIN CAPITAL LETTER W
1F127 PARENTHESIZED LATIN CAPITAL LETTER X
1F128 PARENTHESIZED LATIN CAPITAL LETTER Y
1F129 PARENTHESIZED LATIN CAPITAL LETTER Z
1F12A TORTOISE SHELL BRACKETED LATIN CAPITAL LETTER S
1F12B CIRCLED ITALIC LATIN CAPITAL LETTER C
1F12C CIRCLED ITALIC LATIN CAPITAL LETTER R
1F12D CIRCLED CD
1F12E CIRCLED WZ
1F130 SQUARED LATIN CAPITAL LETTER A
1F131 SQUARED LATIN CAPITAL LETTER B
1F132 SQUARED LATIN CAPITAL LETTER C
1F133 SQUARED LATIN CAPITAL LETTER D
1F134 SQUARED LATIN CAPITAL LETTER E
1F135 SQUARED LATIN CAPITAL LETTER F
1F136 SQUARED LATIN CAPITAL LETTER G
1F137 SQUARED LATIN CAPITAL LETTER H
1F138 SQUARED LATIN CAPITAL LETTER I
1F139 SQUARED LATIN CAPITAL LETTER J
1F13A SQUARED LATIN CAPITAL LETTER K
1F13B SQUARED LATIN CAPITAL LETTER L
1F13C SQUARED LATIN CAPITAL LETTER M
1F13D SQUARED LATIN CAPITAL LETTER N
1F13E SQUARED LATIN CAPITAL LETTER O
1F13F SQUARED LATIN CAPITAL LETTER P
1F140 SQUARED LATIN CAPITAL LETTER Q
1F141 SQUARED LATIN CAPITAL LETTER R
1F142 SQUARED LATIN CAPITAL LETTER S
1F143 SQUARED LATIN CAPITAL LETTER T
1F144 SQUARED LATIN CAPITAL LETTER U
1F145 SQUARED LATIN CAPITAL LETTER V
1F146 SQUARED LATIN CAPITAL LETTER W
1F147 SQUARED LATIN CAPITAL LETTER X
1F148 SQUARED LATIN CAPITAL LETTER Y
1F149 SQUARED LATIN CAPITAL LETTER Z
1F14A SQUARED HV
1F14B SQUARED MV
1F14C SQUARED SD
1F14D SQUARED SS
1F14E SQUARED PPV
1F14F SQUARED WC
1F150 NEGATIVE CIRCLED LATIN CAPITAL LETTER A
1F151 NEGATIVE CIRCLED LATIN CAPITAL LETTER B
1F152 NEGATIVE CIRCLED LATIN CAPITAL LETTER C
1F153 NEGATIVE CIRCLED LATIN CAPITAL LETTER D
1F154 NEGATIVE CIRCLED LATIN CAPITAL LETTER E
1F155 NEGATIVE CIRCLED LATIN CAPITAL LETTER F
1F156 NEGATIVE CIRCLED LATIN CAPITAL LETTER G
1F157 NEGATIVE CIRCLED LATIN CAPITAL LETTER H
1F158 NEGATIVE CIRCLED LATIN CAPITAL LETTER I
1F159 NEGATIVE CIRCLED LATIN CAPITAL LETTER J
1F15A NEGATIVE CIRCLED LATIN CAPITAL LETTER K
1F15B NEGATIVE CIRCLED LATIN CAPITAL LETTER L
1F15C NEGATIVE CIRCLED LATIN CAPITAL LETTER M
1F15D NEGATIVE CIRCLED LATIN CAPITAL LETTER N
1F15E NEGATIVE CIRCLED LATIN CAPITAL LETTER O
1F15F NEGATIVE CIRCLED LATIN CAPITAL LETTER P
1F160 NEGATIVE CIRCLED LATIN CAPITAL LETTER Q
1F161 NEGATIVE CIRCLED LATIN CAPITAL LETTER R
1F162 NEGATIVE CIRCLED LATIN CAPITAL LETTER S
1F163 NEGATIVE CIRCLED LATIN CAPITAL LETTER T
1F164 NEGATIVE CIRCLED LATIN CAPITAL LETTER U
1F165 NEGATIVE CIRCLED LATIN CAPITAL LETTER V
1F166 NEGATIVE CIRCLED LATIN CAPITAL LETTER W
1F167 NEGATIVE CIRCLED LATIN CAPITAL LETTER X
1F168 NEGATIVE CIRCLED LATIN CAPITAL LETTER Y
1F169 NEGATIVE CIRCLED LATIN CAPITAL LETTER Z
1F16A RAISED MC SIGN
1F16B RAISED MD SIGN
1F170 NEGATIVE SQUARED LATIN CAPITAL LETTER A
1F171 NEGATIVE SQUARED LATIN CAPITAL LETTER B
1F172 NEGATIVE SQUARED LATIN CAPITAL LETTER C
1F173 NEGATIVE SQUARED LATIN CAPITAL LETTER D
1F174 NEGATIVE SQUARED LATIN CAPITAL LETTER E
1F175 NEGATIVE SQUARED LATIN CAPITAL LETTER F
1F176 NEGATIVE SQUARED LATIN CAPITAL LETTER G
1F177 NEGATIVE SQUARED LATIN CAPITAL LETTER H
1F178 NEGATIVE SQUARED LATIN CAPITAL LETTER I
1F179 NEGATIVE SQUARED LATIN CAPITAL LETTER J
1F17A NEGATIVE SQUARED LATIN CAPITAL LETTER K
1F17B NEGATIVE SQUARED LATIN CAPITAL LETTER L
1F17C NEGATIVE SQUARED LATIN CAPITAL LETTER M
1F17D NEGATIVE SQUARED LATIN CAPITAL LETTER N
1F17E NEGATIVE SQUARED LATIN CAPITAL LETTER O
1F17F NEGATIVE SQUARED LATIN CAPITAL LETTER P
1F180 NEGATIVE SQUARED LATIN CAPITAL LETTER Q
1F181 NEGATIVE SQUARED LATIN CAPITAL LETTER R
1F182 NEGATIVE SQUARED LATIN CAPITAL LETTER S
1F183 NEGATIVE SQUARED LATIN CAPITAL LETTER T
1F184 NEGATIVE SQUARED LATIN CAPITAL LETTER U
1F185 NEGATIVE SQUARED LATIN CAPITAL LETTER V
1F186 NEGATIVE SQUARED LATIN CAPITAL LETTER W
1F187 NEGATIVE SQUARED LATIN CAPITAL LETTER X
1F188 NEGATIVE SQUARED LATIN CAPITAL LETTER Y
1F189 NEGATIVE SQUARED LATIN CAPITAL LETTER Z
1F18A CROSSED NEGATIVE SQUARED LATIN CAPITAL LETTER P
1F18B NEGATIVE SQUARED IC
1F18C NEGATIVE SQUARED PA
1F18D NEGATIVE SQUARED SA
1F18E NEGATIVE SQUARED AB
1F18F NEGATIVE SQUARED WC
1F190 SQUARE DJ
1F191 SQUARED CL
1F192 SQUARED COOL
1F193 SQUARED FREE
1F194 SQUARED ID
1F195 SQUARED NEW
1F196 SQUARED NG
1F197 SQUARED OK
1F198 SQUARED SOS
1F199 SQUARED UP WITH EXCLAMATION MARK
1F19A SQUARED VS
1F19B SQUARED THREE D
1F19C SQUARED SECOND SCREEN
1F19D SQUARED TWO K
1F19E SQUARED FOUR K
1F19F SQUARED EIGHT K
1F1A0 SQUARED FIVE POINT ONE
1F1A1 SQUARED SEVEN POINT ONE
1F1A2 SQUARED TWENTY-TWO POINT TWO
1F1A3 SQUARED SIXTY P
1F1A4 SQUARED ONE HUNDRED TWENTY P
1F1A5 SQUARED LATIN SMALL LETTER D
1F1A6 SQUARED HC
1F1A7 SQUARED HDR
1F1A8 SQUARED HI-RES
1F1A9 SQUARED LOSSLESS
1F1AA SQUARED SHV
1F1AB SQUARED UHD
1F1AC SQUARED VOD
1F1E6 REGIONAL INDICATOR SYMBOL LETTER A
1F1E7 REGIONAL INDICATOR SYMBOL LETTER B
1F1E8 REGIONAL INDICATOR SYMBOL LETTER C
1F1E9 REGIONAL INDICATOR SYMBOL LETTER D
1F1EA REGIONAL INDICATOR SYMBOL LETTER E
1F1EB REGIONAL INDICATOR SYMBOL LETTER F
1F1EC REGIONAL INDICATOR SYMBOL LETTER G
1F1ED REGIONAL INDICATOR SYMBOL LETTER H
1F1EE REGIONAL INDICATOR SYMBOL LETTER I
1F1EF REGIONAL INDICATOR SYMBOL LETTER J
1F1F0 REGIONAL INDICATOR SYMBOL LETTER K
1F1F1 REGIONAL INDICATOR SYMBOL LETTER L
1F1F2 REGIONAL INDICATOR SYMBOL LETTER M
1F1F3 REGIONAL INDICATOR SYMBOL LETTER N
1F1F4 REGIONAL INDICATOR SYMBOL LETTER O
1F1F5 REGIONAL INDICATOR SYMBOL LETTER P
1F1F6 REGIONAL INDICATOR SYMBOL LETTER Q
1F1F7 REGIONAL INDICATOR SYMBOL LETTER R
1F1F8 REGIONAL INDICATOR SYMBOL LETTER S
1F1F9 REGIONAL INDICATOR SYMBOL LETTER T
1F1FA REGIONAL INDICATOR SYMBOL LETTER U
1F1FB REGIONAL INDICATOR SYMBOL LETTER V
1F1FC REGIONAL INDICATOR SYMBOL LETTER W
1F1FD REGIONAL INDICATOR SYMBOL LETTER X
1F1FE REGIONAL INDICATOR SYMBOL LETTER Y
1F1FF REGIONAL INDICATOR SYMBOL LETTER Z
1F200 SQUARE HIRAGANA HOKA
1F201 SQUARED KATAKANA KOKO
1F202 SQUARED KATAKANA SA
1F210 SQUARED CJK UNIFIED IDEOGRAPH-624B
1F211 SQUARED CJK UNIFIED IDEOGRAPH-5B57
1F212 SQUARED CJK UNIFIED IDEOGRAPH-53CC
1F213 SQUARED KATAKANA DE
1F214 SQUARED CJK UNIFIED IDEOGRAPH-4E8C
1F215 SQUARED CJK UNIFIED IDEOGRAPH-591A
1F216 SQUARED CJK UNIFIED IDEOGRAPH-89E3
1F217 SQUARED CJK UNIFIED IDEOGRAPH-5929
1F218 SQUARED CJK UNIFIED IDEOGRAPH-4EA4
1F219 SQUARED CJK UNIFIED IDEOGRAPH-6620
1F21A SQUARED CJK UNIFIED IDEOGRAPH-7121
1F21B SQUARED CJK UNIFIED IDEOGRAPH-6599
1F21C SQUARED CJK UNIFIED IDEOGRAPH-524D
1F21D SQUARED CJK UNIFIED IDEOGRAPH-5F8C
1F21E SQUARED CJK UNIFIED IDEOGRAPH-518D
1F21F SQUARED CJK UNIFIED IDEOGRAPH-65B0
1F220 SQUARED CJK UNIFIED IDEOGRAPH-521D
1F221 SQUARED CJK UNIFIED IDEOGRAPH-7D42
1F222 SQUARED CJK UNIFIED IDEOGRAPH-751F
1F223 SQUARED CJK UNIFIED IDEOGRAPH-8CA9
1F224 SQUARED CJK UNIFIED IDEOGRAPH-58F0
1F225 SQUARED CJK UNIFIED IDEOGRAPH-5439
1F226 SQUARED CJK UNIFIED IDEOGRAPH-6F14
1F227 SQUARED CJK UNIFIED IDEOGRAPH-6295
1F228 SQUARED CJK UNIFIED IDEOGRAPH-6355
1F229 SQUARED CJK UNIFIED IDEOGRAPH-4E00
1F22A SQUARED CJK UNIFIED IDEOGRAPH-4E09
1F22B SQUARED CJK UNIFIED IDEOGRAPH-904A
1F22C SQUARED CJK UNIFIED IDEOGRAPH-5DE6
1F22D SQUARED CJK UNIFIED IDEOGRAPH-4E2D
1F22E SQUARED CJK UNIFIED IDEOGRAPH-53F3
1F22F SQUARED CJK UNIFIED IDEOGRAPH-6307
1F230 SQUARED CJK UNIFIED IDEOGRAPH-8D70
1F231 SQUARED CJK UNIFIED IDEOGRAPH-6253
1F232 SQUARED CJK UNIFIED IDEOGRAPH-7981
1F233 SQUARED CJK UNIFIED IDEOGRAPH-7A7A
1F234 SQUARED CJK UNIFIED IDEOGRAPH-5408
1F235 SQUARED CJK UNIFIED IDEOGRAPH-6E80
1F236 SQUARED CJK UNIFIED IDEOGRAPH-6709
1F237 SQUARED CJK UNIFIED IDEOGRAPH-6708
1F238 SQUARED CJK UNIFIED IDEOGRAPH-7533
1F239 SQUARED CJK UNIFIED IDEOGRAPH-5272
1F23A SQUARED CJK UNIFIED IDEOGRAPH-55B6
1F23B SQUARED CJK UNIFIED IDEOGRAPH-914D
1F240 TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-672C
1F241 TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-4E09
1F242 TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-4E8C
1F243 TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-5B89
1F244 TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-70B9
1F245 TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-6253
1F246 TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-76D7
1F247 TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-52DD
1F248 TORTOISE SHELL BRACKETED CJK UNIFIED IDEOGRAPH-6557
1F250 CIRCLED IDEOGRAPH ADVANTAGE
1F251 CIRCLED IDEOGRAPH ACCEPT
1F260 ROUNDED SYMBOL FOR FU
1F261 ROUNDED SYMBOL FOR LU
1F262 ROUNDED SYMBOL FOR SHOU
1F263 ROUNDED SYMBOL FOR XI
1F264 ROUNDED SYMBOL FOR SHUANGXI
1F265 ROUNDED SYMBOL FOR CAI
1F300 CYCLONE
1F301 FOGGY
1F302 CLOSED UMBRELLA
1F303 NIGHT WITH STARS
1F304 SUNRISE OVER MOUNTAINS
1F305 SUNRISE
1F306 CITYSCAPE AT DUSK
1F307 SUNSET OVER BUILDINGS
1F308 RAINBOW
1F309 BRIDGE AT NIGHT
1F30A WATER WAVE
1F30B VOLCANO
1F30C MILKY WAY
1F30D EARTH GLOBE EUROPE-AFRICA
1F30E EARTH GLOBE AMERICAS
1F30F EARTH GLOBE ASIA-AUSTRALIA
1F310 GLOBE WITH MERIDIANS
1F311 NEW MOON SYMBOL
1F312 WAXING CRESCENT MOON SYMBOL
1F313 FIRST QUARTER MOON SYMBOL
1F314 WAXING GIBBOUS MOON SYMBOL
1F315 FULL MOON SYMBOL
1F316 WANING GIBBOUS MOON SYMBOL
1F317 LAST QUARTER MOON SYMBOL
1F318 WANING CRESCENT MOON SYMBOL
1F319 CRESCENT MOON
1F31A NEW MOON WITH FACE
1F31B FIRST QUARTER MOON WITH FACE
1F31C LAST QUARTER MOON WITH FACE
1F31D FULL MOON WITH FACE
1F31E SUN WITH FACE
1F31F GLOWING STAR
1F320 SHOOTING STAR
1F321 THERMOMETER
1F322 BLACK DROPLET
1F323 WHITE SUN
1F324 WHITE SUN WITH SMALL CLOUD
1F325 WHITE SUN BEHIND CLOUD
1F326 WHITE SUN BEHIND CLOUD WITH RAIN
1F327 CLOUD WITH RAIN
1F328 CLOUD WITH SNOW
1F329 CLOUD WITH LIGHTNING
1F32A CLOUD WITH TORNADO
1F32B FOG
1F32C WIND BLOWING FACE
1F32D HOT DOG
1F32E TACO
1F32F BURRITO
1F330 CHESTNUT
1F331 SEEDLING
1F332 EVERGREEN TREE
1F333 DECIDUOUS TREE
1F334 PALM TREE
1F335 CACTUS
1F336 HOT PEPPER
1F337 TULIP
1F338 CHERRY BLOSSOM
1F339 ROSE
1F33A HIBISCUS
1F33B SUNFLOWER
1F33C BLOSSOM
1F33D EAR OF MAIZE
1F33E EAR OF RICE
1F33F HERB
1F340 FOUR LEAF CLOVER
1F341 MAPLE LEAF
1F342 FALLEN LEAF
1F343 LEAF FLUTTERING IN WIND
1F344 MUSHROOM
1F345 TOMATO
1F346 AUBERGINE
1F347 GRAPES
1F348 MELON
1F349 WATERMELON
1F34A TANGERINE
1F34B LEMON
1F34C BANANA
1F34D PINEAPPLE
1F34E RED APPLE
1F34F GREEN APPLE
1F350 PEAR
1F351 PEACH
1F352 CHERRIES
1F353 STRAWBERRY
1F354 HAMBURGER
1F355 SLICE OF PIZZA
1F356 MEAT ON BONE
1F357 POULTRY LEG
1F358 RICE CRACKER
1F359 RICE BALL
1F35A COOKED RICE
1F35B CURRY AND RICE
1F35C STEAMING BOWL
1F35D SPAGHETTI
1F35E BREAD
1F35F FRENCH FRIES
1F360 ROASTED SWEET POTATO
1F361 DANGO
1F362 ODEN
1F363 SUSHI
1F364 FRIED SHRIMP
1F365 FISH CAKE WITH SWIRL DESIGN
1F366 SOFT ICE CREAM
1F367 SHAVED ICE
1F368 ICE CREAM
1F369 DOUGHNUT
1F36A COOKIE
1F36B CHOCOLATE BAR
1F36C CANDY
1F36D LOLLIPOP
1F36E CUSTARD
1F36F HONEY POT
1F370 SHORTCAKE
1F371 BENTO BOX
1F372 POT OF FOOD
1F373 COOKING
1F374 FORK AND KNIFE
1F375 TEACUP WITHOUT HANDLE
1F376 SAKE BOTTLE AND CUP
1F377 WINE GLASS
1F378 COCKTAIL GLASS
1F379 TROPICAL DRINK
1F37A BEER MUG
1F37B CLINKING BEER MUGS
1F37C BABY BOTTLE
1F37D FORK AND KNIFE WITH PLATE
1F37E BOTTLE WITH POPPING CORK
1F37F POPCORN
1F380 RIBBON
1F381 WRAPPED PRESENT
1F382 BIRTHDAY CAKE
1F383 JACK-O-LANTERN
1F384 CHRISTMAS TREE
1F385 FATHER CHRISTMAS
1F386 FIREWORKS
1F387 FIREWORK SPARKLER
1F388 BALLOON
1F389 PARTY POPPER
1F38A CONFETTI BALL
1F38B TANABATA TREE
1F38C CROSSED FLAGS
1F38D PINE DECORATION
1F38E JAPANESE DOLLS
1F38F CARP STREAMER
1F390 WIND CHIME
1F391 MOON VIEWING CEREMONY
1F392 SCHOOL SATCHEL
1F393 GRADUATION CAP
1F394 HEART WITH TIP ON THE LEFT
1F395 BOUQUET OF FLOWERS
1F396 MILITARY MEDAL
1F397 REMINDER RIBBON
1F398 MUSICAL KEYBOARD WITH JACKS
1F399 STUDIO MICROPHONE
1F39A LEVEL SLIDER
1F39B CONTROL KNOBS
1F39C BEAMED ASCENDING MUSICAL NOTES
1F39D BEAMED DESCENDING MUSICAL NOTES
1F39E FILM FRAMES
1F39F ADMISSION TICKETS
1F3A0 CAROUSEL HORSE
1F3A1 FERRIS WHEEL
1F3A2 ROLLER COASTER
1F3A3 FISHING POLE AND FISH
1F3A4 MICROPHONE
1F3A5 MOVIE CAMERA
1F3A6 CINEMA
1F3A7 HEADPHONE
1F3A8 ARTIST PALETTE
1F3A9 TOP HAT
1F3AA CIRCUS TENT
1F3AB TICKET
1F3AC CLAPPER BOARD
1F3AD PERFORMING ARTS
1F3AE VIDEO GAME
1F3AF DIRECT HIT
1F3B0 SLOT MACHINE
1F3B1 BILLIARDS
1F3B2 GAME DIE
1F3B3 BOWLING
1F3B4 FLOWER PLAYING CARDS
1F3B5 MUSICAL NOTE
1F3B6 MULTIPLE MUSICAL NOTES
1F3B7 SAXOPHONE
1F3B8 GUITAR
1F3B9 MUSICAL KEYBOARD
1F3BA TRUMPET
1F3BB VIOLIN
1F3BC MUSICAL SCORE
1F3BD RUNNING SHIRT WITH SASH
1F3BE TENNIS RACQUET AND BALL
1F3BF SKI AND SKI BOOT
1F3C0 BASKETBALL AND HOOP
1F3C1 CHEQUERED FLAG
1F3C2 SNOWBOARDER
1F3C3 RUNNER
1F3C4 SURFER
1F3C5 SPORTS MEDAL
1F3C6 TROPHY
1F3C7 HORSE RACING
1F3C8 AMERICAN FOOTBALL
1F3C9 RUGBY FOOTBALL
1F3CA SWIMMER
1F3CB WEIGHT LIFTER
1F3CC GOLFER
1F3CD RACING MOTORCYCLE
1F3CE RACING CAR
1F3CF CRICKET BAT AND BALL
1F3D0 VOLLEYBALL
1F3D1 FIELD HOCKEY STICK AND BALL
1F3D2 ICE HOCKEY STICK AND PUCK
1F3D3 TABLE TENNIS PADDLE AND BALL
1F3D4 SNOW CAPPED MOUNTAIN
1F3D5 CAMPING
1F3D6 BEACH WITH UMBRELLA
1F3D7 BUILDING CONSTRUCTION
1F3D8 HOUSE BUILDINGS
1F3D9 CITYSCAPE
1F3DA DERELICT HOUSE BUILDING
1F3DB CLASSICAL BUILDING
1F3DC DESERT
1F3DD DESERT ISLAND
1F3DE NATIONAL PARK
1F3DF STADIUM
1F3E0 HOUSE BUILDING
1F3E1 HOUSE WITH GARDEN
1F3E2 OFFICE BUILDING
1F3E3 JAPANESE POST OFFICE
1F3E4 EUROPEAN POST OFFICE
1F3E5 HOSPITAL
1F3E6 BANK
1F3E7 AUTOMATED TELLER MACHINE
1F3E8 HOTEL
1F3E9 LOVE HOTEL
1F3EA CONVENIENCE STORE
1F3EB SCHOOL
1F3EC DEPARTMENT STORE
1F3ED FACTORY
1F3EE IZAKAYA LANTERN
1F3EF JAPANESE CASTLE
1F3F0 EUROPEAN CASTLE
1F3F1 WHITE PENNANT
1F3F2 BLACK PENNANT
1F3F3 WAVING WHITE FLAG
1F3F4 WAVING BLACK FLAG
1F3F5 ROSETTE
1F3F6 BLACK ROSETTE
1F3F7 LABEL
1F3F8 BADMINTON RACQUET AND SHUTTLECOCK
1F3F9 BOW AND ARROW
1F3FA AMPHORA
1F3FB EMOJI MODIFIER FITZPATRICK TYPE-1-2
1F3FC EMOJI MODIFIER FITZPATRICK TYPE-3
1F3FD EMOJI MODIFIER FITZPATRICK TYPE-4
1F3FE EMOJI MODIFIER FITZPATRICK TYPE-5
1F3FF EMOJI MODIFIER FITZPATRICK TYPE-6
1F400 RAT
1F401 MOUSE
1F402 OX
1F403 WATER BUFFALO
1F404 COW
1F405 TIGER
1F406 LEOPARD
1F407 RABBIT
1F408 CAT
1F409 DRAGON
1F40A CROCODILE
1F40B WHALE
1F40C SNAIL
1F40D SNAKE
1F40E HORSE
1F40F RAM
1F410 GOAT
1F411 SHEEP
1F412 MONKEY
1F413 ROOSTER
1F414 CHICKEN
1F415 DOG
1F416 PIG
1F417 BOAR
1F418 ELEPHANT
1F419 OCTOPUS
1F41A SPIRAL SHELL
1F41B BUG
1F41C ANT
1F41D HONEYBEE
1F41E LADY BEETLE
1F41F FISH
1F420 TROPICAL FISH
1F421 BLOWFISH
1F422 TURTLE
1F423 HATCHING CHICK
1F424 BABY CHICK
1F425 FRONT-FACING BABY CHICK
1F426 BIRD
1F427 PENGUIN
1F428 KOALA
1F429 POODLE
1F42A DROMEDARY CAMEL
1F42B BACTRIAN CAMEL
1F42C DOLPHIN
1F42D MOUSE FACE
1F42E COW FACE
1F42F TIGER FACE
1F430 RABBIT FACE
1F431 CAT FACE
1F432 DRAGON FACE
1F433 SPOUTING WHALE
1F434 HORSE FACE
1F435 MONKEY FACE
1F436 DOG FACE
1F437 PIG FACE
1F438 FROG FACE
1F439 HAMSTER FACE
1F43A WOLF FACE
1F43B BEAR FACE
1F43C PANDA FACE
1F43D PIG NOSE
1F43E PAW PRINTS
1F43F CHIPMUNK
1F440 EYES
1F441 EYE
1F442 EAR
1F443 NOSE
1F444 MOUTH
1F445 TONGUE
1F446 WHITE UP POINTING BACKHAND INDEX
1F447 WHITE DOWN POINTING BACKHAND INDEX
1F448 WHITE LEFT POINTING BACKHAND INDEX
1F449 WHITE RIGHT POINTING BACKHAND INDEX
1F44A FISTED HAND SIGN
1F44B WAVING HAND SIGN
1F44C OK HAND SIGN
1F44D THUMBS UP SIGN
1F44E THUMBS DOWN SIGN
1F44F CLAPPING HANDS SIGN
1F450 OPEN HANDS SIGN
1F451 CROWN
1F452 WOMANS HAT
1F453 EYEGLASSES
1F454 NECKTIE
1F455 T-SHIRT
1F456 JEANS
1F457 DRESS
1F458 KIMONO
1F459 BIKINI
1F45A WOMANS CLOTHES
1F45B PURSE
1F45C HANDBAG
1F45D POUCH
1F45E MANS SHOE
1F45F ATHLETIC SHOE
1F460 HIGH-HEELED SHOE
1F461 WOMANS SANDAL
1F462 WOMANS BOOTS
1F463 FOOTPRINTS
1F464 BUST IN SILHOUETTE
1F465 BUSTS IN SILHOUETTE
1F466 BOY
1F467 GIRL
1F468 MAN
1F469 WOMAN
1F46A FAMILY
1F46B MAN AND WOMAN HOLDING HANDS
1F46C TWO MEN HOLDING HANDS
1F46D TWO WOMEN HOLDING HANDS
1F46E POLICE OFFICER
1F46F WOMAN WITH BUNNY EARS
1F470 BRIDE WITH VEIL
1F471 PERSON WITH BLOND HAIR
1F472 MAN WITH GUA PI MAO
1F473 MAN WITH TURBAN
1F474 OLDER MAN
1F475 OLDER WOMAN
1F476 BABY
1F477 CONSTRUCTION WORKER
1F478 PRINCESS
1F479 JAPANESE OGRE
1F47A JAPANESE GOBLIN
1F47B GHOST
1F47C BABY ANGEL
1F47D EXTRATERRESTRIAL ALIEN
1F47E ALIEN MONSTER
1F47F IMP
1F480 SKULL
1F481 INFORMATION DESK PERSON
1F482 GUARDSMAN
1F483 DANCER
1F484 LIPSTICK
1F485 NAIL POLISH
1F486 FACE MASSAGE
1F487 HAIRCUT
1F488 BARBER POLE
1F489 SYRINGE
1F48A PILL
1F48B KISS MARK
1F48C LOVE LETTER
1F48D RING
1F48E GEM STONE
1F48F KISS
1F490 BOUQUET
1F491 COUPLE WITH HEART
1F492 WEDDING
1F493 BEATING HEART
1F494 BROKEN HEART
1F495 TWO HEARTS
1F496 SPARKLING HEART
1F497 GROWING HEART
1F498 HEART WITH ARROW
1F499 BLUE HEART
1F49A GREEN HEART
1F49B YELLOW HEART
1F49C PURPLE HEART
1F49D HEART WITH RIBBON
1F49E REVOLVING HEARTS
1F49F HEART DECORATION
1F4A0 DIAMOND SHAPE WITH A DOT INSIDE
1F4A1 ELECTRIC LIGHT BULB
1F4A2 ANGER SYMBOL
1F4A3 BOMB
1F4A4 SLEEPING SYMBOL
1F4A5 COLLISION SYMBOL
1F4A6 SPLASHING SWEAT SYMBOL
1F4A7 DROPLET
1F4A8 DASH SYMBOL
1F4A9 PILE OF POO
1F4AA FLEXED BICEPS
1F4AB DIZZY SYMBOL
1F4AC SPEECH BALLOON
1F4AD THOUGHT BALLOON
1F4AE WHITE FLOWER
1F4AF HUNDRED POINTS SYMBOL
1F4B0 MONEY BAG
1F4B1 CURRENCY EXCHANGE
1F4B2 HEAVY DOLLAR SIGN
1F4B3 CREDIT CARD
1F4B4 BANKNOTE WITH YEN SIGN
1F4B5 BANKNOTE WITH DOLLAR SIGN
1F4B6 BANKNOTE WITH EURO SIGN
1F4B7 BANKNOTE WITH POUND SIGN
1F4B8 MONEY WITH WINGS
1F4B9 CHART WITH UPWARDS TREND AND YEN SIGN
1F4BA SEAT
1F4BB PERSONAL COMPUTER
1F4BC BRIEFCASE
1F4BD MINIDISC
1F4BE FLOPPY DISK
1F4BF OPTICAL DISC
1F4C0 DVD
1F4C1 FILE FOLDER
1F4C2 OPEN FILE FOLDER
1F4C3 PAGE WITH CURL
1F4C4 PAGE FACING UP
1F4C5 CALENDAR
1F4C6 TEAR-OFF CALENDAR
1F4C7 CARD INDEX
1F4C8 CHART WITH UPWARDS TREND
1F4C9 CHART WITH DOWNWARDS TREND
1F4CA BAR CHART
1F4CB CLIPBOARD
1F4CC PUSHPIN
1F4CD ROUND PUSHPIN
1F4CE PAPERCLIP
1F4CF STRAIGHT RULER
1F4D0 TRIANGULAR RULER
1F4D1 BOOKMARK TABS
1F4D2 LEDGER
1F4D3 NOTEBOOK
1F4D4 NOTEBOOK WITH DECORATIVE COVER
1F4D5 CLOSED BOOK
1F4D6 OPEN BOOK
1F4D7 GREEN BOOK
1F4D8 BLUE BOOK
1F4D9 ORANGE BOOK
1F4DA BOOKS
1F4DB NAME BADGE
1F4DC SCROLL
1F4DD MEMO
1F4DE TELEPHONE RECEIVER
1F4DF PAGER
1F4E0 FAX MACHINE
1F4E1 SATELLITE ANTENNA
1F4E2 PUBLIC ADDRESS LOUDSPEAKER
1F4E3 CHEERING MEGAPHONE
1F4E4 OUTBOX TRAY
1F4E5 INBOX TRAY
1F4E6 PACKAGE
1F4E7 E-MAIL SYMBOL
1F4E8 INCOMING ENVELOPE
1F4E9 ENVELOPE WITH DOWNWARDS ARROW ABOVE
1F4EA CLOSED MAILBOX WITH LOWERED FLAG
1F4EB CLOSED MAILBOX WITH RAISED FLAG
1F4EC OPEN MAILBOX WITH RAISED FLAG
1F4ED OPEN MAILBOX WITH LOWERED FLAG
1F4EE POSTBOX
1F4EF POSTAL HORN
1F4F0 NEWSPAPER
1F4F1 MOBILE PHONE
1F4F2 MOBILE PHONE WITH RIGHTWARDS ARROW AT LEFT
1F4F3 VIBRATION MODE
1F4F4 MOBILE PHONE OFF
1F4F5 NO MOBILE PHONES
1F4F6 ANTENNA WITH BARS
1F4F7 CAMERA
1F4F8 CAMERA WITH FLASH
1F4F9 VIDEO CAMERA
1F4FA TELEVISION
1F4FB RADIO
1F4FC VIDEOCASSETTE
1F4FD FILM PROJECTOR
1F4FE PORTABLE STEREO
1F4FF PRAYER BEADS
1F500 TWISTED RIGHTWARDS ARROWS
1F501 CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS
1F502 CLOCKWISE RIGHTWARDS AND LEFTWARDS OPEN CIRCLE ARROWS WITH CIRCLED ONE OVERLAY
1F503 CLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS
1F504 ANTICLOCKWISE DOWNWARDS AND UPWARDS OPEN CIRCLE ARROWS
1F505 LOW BRIGHTNESS SYMBOL
1F506 HIGH BRIGHTNESS SYMBOL
1F507 SPEAKER WITH CANCELLATION STROKE
1F508 SPEAKER
1F509 SPEAKER WITH ONE SOUND WAVE
1F50A SPEAKER WITH THREE SOUND WAVES
1F50B BATTERY
1F50C ELECTRIC PLUG
1F50D LEFT-POINTING MAGNIFYING GLASS
1F50E RIGHT-POINTING MAGNIFYING GLASS
1F50F LOCK WITH INK PEN
1F510 CLOSED LOCK WITH KEY
1F511 KEY
1F512 LOCK
1F513 OPEN LOCK
1F514 BELL
1F515 BELL WITH CANCELLATION STROKE
1F516 BOOKMARK
1F517 LINK SYMBOL
1F518 RADIO BUTTON
1F519 BACK WITH LEFTWARDS ARROW ABOVE
1F51A END WITH LEFTWARDS ARROW ABOVE
1F51B ON WITH EXCLAMATION MARK WITH LEFT RIGHT ARROW ABOVE
1F51C SOON WITH RIGHTWARDS ARROW ABOVE
1F51D TOP WITH UPWARDS ARROW ABOVE
1F51E NO ONE UNDER EIGHTEEN SYMBOL
1F51F KEYCAP TEN
1F520 INPUT SYMBOL FOR LATIN CAPITAL LETTERS
1F521 INPUT SYMBOL FOR LATIN SMALL LETTERS
1F522 INPUT SYMBOL FOR NUMBERS
1F523 INPUT SYMBOL FOR SYMBOLS
1F524 INPUT SYMBOL FOR LATIN LETTERS
1F525 FIRE
1F526 ELECTRIC TORCH
1F527 WRENCH
1F528 HAMMER
1F529 NUT AND BOLT
1F52A HOCHO
1F52B PISTOL
1F52C MICROSCOPE
1F52D TELESCOPE
1F52E CRYSTAL BALL
1F52F SIX POINTED STAR WITH MIDDLE DOT
1F530 JAPANESE SYMBOL FOR BEGINNER
1F531 TRIDENT EMBLEM
1F532 BLACK SQUARE BUTTON
1F533 WHITE SQUARE BUTTON
1F534 LARGE RED CIRCLE
1F535 LARGE BLUE CIRCLE
1F536 LARGE ORANGE DIAMOND
1F537 LARGE BLUE DIAMOND
1F538 SMALL ORANGE DIAMOND
1F539 SMALL BLUE DIAMOND
1F53A UP-POINTING RED TRIANGLE
1F53B DOWN-POINTING RED TRIANGLE
1F53C UP-POINTING SMALL RED TRIANGLE
1F53D DOWN-POINTING SMALL RED TRIANGLE
1F53E LOWER RIGHT SHADOWED WHITE CIRCLE
1F53F UPPER RIGHT SHADOWED WHITE CIRCLE
1F540 CIRCLED CROSS POMMEE
1F541 CROSS POMMEE WITH HALF-CIRCLE BELOW
1F542 CROSS POMMEE
1F543 NOTCHED LEFT SEMICIRCLE WITH THREE DOTS
1F544 NOTCHED RIGHT SEMICIRCLE WITH THREE DOTS
1F545 SYMBOL FOR MARKS CHAPTER
1F546 WHITE LATIN CROSS
1F547 HEAVY LATIN CROSS
1F548 CELTIC CROSS
1F549 OM SYMBOL
1F54A DOVE OF PEACE
1F54B KAABA
1F54C MOSQUE
1F54D SYNAGOGUE
1F54E MENORAH WITH NINE BRANCHES
1F54F BOWL OF HYGIEIA
1F550 CLOCK FACE ONE OCLOCK
1F551 CLOCK FACE TWO OCLOCK
1F552 CLOCK FACE THREE OCLOCK
1F553 CLOCK FACE FOUR OCLOCK
1F554 CLOCK FACE FIVE OCLOCK
1F555 CLOCK FACE SIX OCLOCK
1F556 CLOCK FACE SEVEN OCLOCK
1F557 CLOCK FACE EIGHT OCLOCK
1F558 CLOCK FACE NINE OCLOCK
1F559 CLOCK FACE TEN OCLOCK
1F55A CLOCK FACE ELEVEN OCLOCK
1F55B CLOCK FACE TWELVE OCLOCK
1F55C CLOCK FACE ONE-THIRTY
1F55D CLOCK FACE TWO-THIRTY
1F55E CLOCK FACE THREE-THIRTY
1F55F CLOCK FACE FOUR-THIRTY
1F560 CLOCK FACE FIVE-THIRTY
1F561 CLOCK FACE SIX-THIRTY
1F562 CLOCK FACE SEVEN-THIRTY
1F563 CLOCK FACE EIGHT-THIRTY
1F564 CLOCK FACE NINE-THIRTY
1F565 CLOCK FACE TEN-THIRTY
1F566 CLOCK FACE ELEVEN-THIRTY
1F567 CLOCK FACE TWELVE-THIRTY
1F568 RIGHT SPEAKER
1F569 RIGHT SPEAKER WITH ONE SOUND WAVE
1F56A RIGHT SPEAKER WITH THREE SOUND WAVES
1F56B BULLHORN
1F56C BULLHORN WITH SOUND WAVES
1F56D RINGING BELL
1F56E BOOK
1F56F CANDLE
1F570 MANTELPIECE CLOCK
1F571 BLACK SKULL AND CROSSBONES
1F572 NO PIRACY
1F573 HOLE
1F574 MAN IN BUSINESS SUIT LEVITATING
1F575 SLEUTH OR SPY
1F576 DARK SUNGLASSES
1F577 SPIDER
1F578 SPIDER WEB
1F579 JOYSTICK
1F57A MAN DANCING
1F57B LEFT HAND TELEPHONE RECEIVER
1F57C TELEPHONE RECEIVER WITH PAGE
1F57D RIGHT HAND TELEPHONE RECEIVER
1F57E WHITE TOUCHTONE TELEPHONE
1F57F BLACK TOUCHTONE TELEPHONE
1F580 TELEPHONE ON TOP OF MODEM
1F581 CLAMSHELL MOBILE PHONE
1F582 BACK OF ENVELOPE
1F583 STAMPED ENVELOPE
1F584 ENVELOPE WITH LIGHTNING
1F585 FLYING ENVELOPE
1F586 PEN OVER STAMPED ENVELOPE
1F587 LINKED PAPERCLIPS
1F588 BLACK PUSHPIN
1F589 LOWER LEFT PENCIL
1F58A LOWER LEFT BALLPOINT PEN
1F58B LOWER LEFT FOUNTAIN PEN
1F58C LOWER LEFT PAINTBRUSH
1F58D LOWER LEFT CRAYON
1F58E LEFT WRITING HAND
1F58F TURNED OK HAND SIGN
1F590 RAISED HAND WITH FINGERS SPLAYED
1F591 REVERSED RAISED HAND WITH FINGERS SPLAYED
1F592 REVERSED THUMBS UP SIGN
1F593 REVERSED THUMBS DOWN SIGN
1F594 REVERSED VICTORY HAND
1F595 REVERSED HAND WITH MIDDLE FINGER EXTENDED
1F596 RAISED HAND WITH PART BETWEEN MIDDLE AND RING FINGERS
1F597 WHITE DOWN POINTING LEFT HAND INDEX
1F598 SIDEWAYS WHITE LEFT POINTING INDEX
1F599 SIDEWAYS WHITE RIGHT POINTING INDEX
1F59A SIDEWAYS BLACK LEFT POINTING INDEX
1F59B SIDEWAYS BLACK RIGHT POINTING INDEX
1F59C BLACK LEFT POINTING BACKHAND INDEX
1F59D BLACK RIGHT POINTING BACKHAND INDEX
1F59E SIDEWAYS WHITE UP POINTING INDEX
1F59F SIDEWAYS WHITE DOWN POINTING INDEX
1F5A0 SIDEWAYS BLACK UP POINTING INDEX
1F5A1 SIDEWAYS BLACK DOWN POINTING INDEX
1F5A2 BLACK UP POINTING BACKHAND INDEX
1F5A3 BLACK DOWN POINTING BACKHAND INDEX
1F5A4 BLACK HEART
1F5A5 DESKTOP COMPUTER
1F5A6 KEYBOARD AND MOUSE
1F5A7 THREE NETWORKED COMPUTERS
1F5A8 PRINTER
1F5A9 POCKET CALCULATOR
1F5AA BLACK HARD SHELL FLOPPY DISK
1F5AB WHITE HARD SHELL FLOPPY DISK
1F5AC SOFT SHELL FLOPPY DISK
1F5AD TAPE CARTRIDGE
1F5AE WIRED KEYBOARD
1F5AF ONE BUTTON MOUSE
1F5B0 TWO BUTTON MOUSE
1F5B1 THREE BUTTON MOUSE
1F5B2 TRACKBALL
1F5B3 OLD PERSONAL COMPUTER
1F5B4 HARD DISK
1F5B5 SCREEN
1F5B6 PRINTER ICON
1F5B7 FAX ICON
1F5B8 OPTICAL DISC ICON
1F5B9 DOCUMENT WITH TEXT
1F5BA DOCUMENT WITH TEXT AND PICTURE
1F5BB DOCUMENT WITH PICTURE
1F5BC FRAME WITH PICTURE
1F5BD FRAME WITH TILES
1F5BE FRAME WITH AN X
1F5BF BLACK FOLDER
1F5C0 FOLDER
1F5C1 OPEN FOLDER
1F5C2 CARD INDEX DIVIDERS
1F5C3 CARD FILE BOX
1F5C4 FILE CABINET
1F5C5 EMPTY NOTE
1F5C6 EMPTY NOTE PAGE
1F5C7 EMPTY NOTE PAD
1F5C8 NOTE
1F5C9 NOTE PAGE
1F5CA NOTE PAD
1F5CB EMPTY DOCUMENT
1F5CC EMPTY PAGE
1F5CD EMPTY PAGES
1F5CE DOCUMENT
1F5CF PAGE
1F5D0 PAGES
1F5D1 WASTEBASKET
1F5D2 SPIRAL NOTE PAD
1F5D3 SPIRAL CALENDAR PAD
1F5D4 DESKTOP WINDOW
1F5D5 MINIMIZE
1F5D6 MAXIMIZE
1F5D7 OVERLAP
1F5D8 CLOCKWISE RIGHT AND LEFT SEMICIRCLE ARROWS
1F5D9 CANCELLATION X
1F5DA INCREASE FONT SIZE SYMBOL
1F5DB DECREASE FONT SIZE SYMBOL
1F5DC COMPRESSION
1F5DD OLD KEY
1F5DE ROLLED-UP NEWSPAPER
1F5DF PAGE WITH CIRCLED TEXT
1F5E0 STOCK CHART
1F5E1 DAGGER KNIFE
1F5E2 LIPS
1F5E3 SPEAKING HEAD IN SILHOUETTE
1F5E4 THREE RAYS ABOVE
1F5E5 THREE RAYS BELOW
1F5E6 THREE RAYS LEFT
1F5E7 THREE RAYS RIGHT
1F5E8 LEFT SPEECH BUBBLE
1F5E9 RIGHT SPEECH BUBBLE
1F5EA TWO SPEECH BUBBLES
1F5EB THREE SPEECH BUBBLES
1F5EC LEFT THOUGHT BUBBLE
1F5ED RIGHT THOUGHT BUBBLE
1F5EE LEFT ANGER BUBBLE
1F5EF RIGHT ANGER BUBBLE
1F5F0 MOOD BUBBLE
1F5F1 LIGHTNING MOOD BUBBLE
1F5F2 LIGHTNING MOOD
1F5F3 BALLOT BOX WITH BALLOT
1F5F4 BALLOT SCRIPT X
1F5F5 BALLOT BOX WITH SCRIPT X
1F5F6 BALLOT BOLD SCRIPT X
1F5F7 BALLOT BOX WITH BOLD SCRIPT X
1F5F8 LIGHT CHECK MARK
1F5F9 BALLOT BOX WITH BOLD CHECK
1F5FA WORLD MAP
1F5FB MOUNT FUJI
1F5FC TOKYO TOWER
1F5FD STATUE OF LIBERTY
1F5FE SILHOUETTE OF JAPAN
1F5FF MOYAI
1F600 GRINNING FACE
1F601 GRINNING FACE WITH SMILING EYES
1F602 FACE WITH TEARS OF JOY
1F603 SMILING FACE WITH OPEN MOUTH
1F604 SMILING FACE WITH OPEN MOUTH AND SMILING EYES
1F605 SMILING FACE WITH OPEN MOUTH AND COLD SWEAT
1F606 SMILING FACE WITH OPEN MOUTH AND TIGHTLY-CLOSED EYES
1F607 SMILING FACE WITH HALO
1F608 SMILING FACE WITH HORNS
1F609 WINKING FACE
1F60A SMILING FACE WITH SMILING EYES
1F60B FACE SAVOURING DELICIOUS FOOD
1F60C RELIEVED FACE
1F60D SMILING FACE WITH HEART-SHAPED EYES
1F60E SMILING FACE WITH SUNGLASSES
1F60F SMIRKING FACE
1F610 NEUTRAL FACE
1F611 EXPRESSIONLESS FACE
1F612 UNAMUSED FACE
1F613 FACE WITH COLD SWEAT
1F614 PENSIVE FACE
1F615 CONFUSED FACE
1F616 CONFOUNDED FACE
1F617 KISSING FACE
1F618 FACE THROWING A KISS
1F619 KISSING FACE WITH SMILING EYES
1F61A KISSING FACE WITH CLOSED EYES
1F61B FACE WITH STUCK-OUT TONGUE
1F61C FACE WITH STUCK-OUT TONGUE AND WINKING EYE
1F61D FACE WITH STUCK-OUT TONGUE AND TIGHTLY-CLOSED EYES
1F61E DISAPPOINTED FACE
1F61F WORRIED FACE
1F620 ANGRY FACE
1F621 POUTING FACE
1F622 CRYING FACE
1F623 PERSEVERING FACE
1F624 FACE WITH LOOK OF TRIUMPH
1F625 DISAPPOINTED BUT RELIEVED FACE
1F626 FROWNING FACE WITH OPEN MOUTH
1F627 ANGUISHED FACE
1F628 FEARFUL FACE
1F629 WEARY FACE
1F62A SLEEPY FACE
1F62B TIRED FACE
1F62C GRIMACING FACE
1F62D LOUDLY CRYING FACE
1F62E FACE WITH OPEN MOUTH
1F62F HUSHED FACE
1F630 FACE WITH OPEN MOUTH AND COLD SWEAT
1F631 FACE SCREAMING IN FEAR
1F632 ASTONISHED FACE
1F633 FLUSHED FACE
1F634 SLEEPING FACE
1F635 DIZZY FACE
1F636 FACE WITHOUT MOUTH
1F637 FACE WITH MEDICAL MASK
1F638 GRINNING CAT FACE WITH SMILING EYES
1F639 CAT FACE WITH TEARS OF JOY
1F63A SMILING CAT FACE WITH OPEN MOUTH
1F63B SMILING CAT FACE WITH HEART-SHAPED EYES
1F63C CAT FACE WITH WRY SMILE
1F63D KISSING CAT FACE WITH CLOSED EYES
1F63E POUTING CAT FACE
1F63F CRYING CAT FACE
1F640 WEARY CAT FACE
1F641 SLIGHTLY FROWNING FACE
1F642 SLIGHTLY SMILING FACE
1F643 UPSIDE-DOWN FACE
1F644 FACE WITH ROLLING EYES
1F645 FACE WITH NO GOOD GESTURE
1F646 FACE WITH OK GESTURE
1F647 PERSON BOWING DEEPLY
1F648 SEE-NO-EVIL MONKEY
1F649 HEAR-NO-EVIL MONKEY
1F64A SPEAK-NO-EVIL MONKEY
1F64B HAPPY PERSON RAISING ONE HAND
1F64C PERSON RAISING BOTH HANDS IN CELEBRATION
1F64D PERSON FROWNING
1F64E PERSON WITH POUTING FACE
1F64F PERSON WITH FOLDED HANDS
1F650 NORTH WEST POINTING LEAF
1F651 SOUTH WEST POINTING LEAF
1F652 NORTH EAST POINTING LEAF
1F653 SOUTH EAST POINTING LEAF
1F654 TURNED NORTH WEST POINTING LEAF
1F655 TURNED SOUTH WEST POINTING LEAF
1F656 TURNED NORTH EAST POINTING LEAF
1F657 TURNED SOUTH EAST POINTING LEAF
1F658 NORTH WEST POINTING VINE LEAF
1F659 SOUTH WEST POINTING VINE LEAF
1F65A NORTH EAST POINTING VINE LEAF
1F65B SOUTH EAST POINTING VINE LEAF
1F65C HEAVY NORTH WEST POINTING VINE LEAF
1F65D HEAVY SOUTH WEST POINTING VINE LEAF
1F65E HEAVY NORTH EAST POINTING VINE LEAF
1F65F HEAVY SOUTH EAST POINTING VINE LEAF
1F660 NORTH WEST POINTING BUD
1F661 SOUTH WEST POINTING BUD
1F662 NORTH EAST POINTING BUD
1F663 SOUTH EAST POINTING BUD
1F664 HEAVY NORTH WEST POINTING BUD
1F665 HEAVY SOUTH WEST POINTING BUD
1F666 HEAVY NORTH EAST POINTING BUD
1F667 HEAVY SOUTH EAST POINTING BUD
1F668 HOLLOW QUILT SQUARE ORNAMENT
1F669 HOLLOW QUILT SQUARE ORNAMENT IN BLACK SQUARE
1F66A SOLID QUILT SQUARE ORNAMENT
1F66B SOLID QUILT SQUARE ORNAMENT IN BLACK SQUARE
1F66C LEFTWARDS ROCKET
1F66D UPWARDS ROCKET
1F66E RIGHTWARDS ROCKET
1F66F DOWNWARDS ROCKET
1F670 SCRIPT LIGATURE ET ORNAMENT
1F671 HEAVY SCRIPT LIGATURE ET ORNAMENT
1F672 LIGATURE OPEN ET ORNAMENT
1F673 HEAVY LIGATURE OPEN ET ORNAMENT
1F674 HEAVY AMPERSAND ORNAMENT
1F675 SWASH AMPERSAND ORNAMENT
1F676 SANS-SERIF HEAVY DOUBLE TURNED COMMA QUOTATION MARK ORNAMENT
1F677 SANS-SERIF HEAVY DOUBLE COMMA QUOTATION MARK ORNAMENT
1F678 SANS-SERIF HEAVY LOW DOUBLE COMMA QUOTATION MARK ORNAMENT
1F679 HEAVY INTERROBANG ORNAMENT
1F67A SANS-SERIF INTERROBANG ORNAMENT
1F67B HEAVY SANS-SERIF INTERROBANG ORNAMENT
1F67C VERY HEAVY SOLIDUS
1F67D VERY HEAVY REVERSE SOLIDUS
1F67E CHECKER BOARD
1F67F REVERSE CHECKER BOARD
1F680 ROCKET
1F681 HELICOPTER
1F682 STEAM LOCOMOTIVE
1F683 RAILWAY CAR
1F684 HIGH-SPEED TRAIN
1F685 HIGH-SPEED TRAIN WITH BULLET NOSE
1F686 TRAIN
1F687 METRO
1F688 LIGHT RAIL
1F689 STATION
1F68A TRAM
1F68B TRAM CAR
1F68C BUS
1F68D ONCOMING BUS
1F68E TROLLEYBUS
1F68F BUS STOP
1F690 MINIBUS
1F691 AMBULANCE
1F692 FIRE ENGINE
1F693 POLICE CAR
1F694 ONCOMING POLICE CAR
1F695 TAXI
1F696 ONCOMING TAXI
1F697 AUTOMOBILE
1F698 ONCOMING AUTOMOBILE
1F699 RECREATIONAL VEHICLE
1F69A DELIVERY TRUCK
1F69B ARTICULATED LORRY
1F69C TRACTOR
1F69D MONORAIL
1F69E MOUNTAIN RAILWAY
1F69F SUSPENSION RAILWAY
1F6A0 MOUNTAIN CABLEWAY
1F6A1 AERIAL TRAMWAY
1F6A2 SHIP
1F6A3 ROWBOAT
1F6A4 SPEEDBOAT
1F6A5 HORIZONTAL TRAFFIC LIGHT
1F6A6 VERTICAL TRAFFIC LIGHT
1F6A7 CONSTRUCTION SIGN
1F6A8 POLICE CARS REVOLVING LIGHT
1F6A9 TRIANGULAR FLAG ON POST
1F6AA DOOR
1F6AB NO ENTRY SIGN
1F6AC SMOKING SYMBOL
1F6AD NO SMOKING SYMBOL
1F6AE PUT LITTER IN ITS PLACE SYMBOL
1F6AF DO NOT LITTER SYMBOL
1F6B0 POTABLE WATER SYMBOL
1F6B1 NON-POTABLE WATER SYMBOL
1F6B2 BICYCLE
1F6B3 NO BICYCLES
1F6B4 BICYCLIST
1F6B5 MOUNTAIN BICYCLIST
1F6B6 PEDESTRIAN
1F6B7 NO PEDESTRIANS
1F6B8 CHILDREN CROSSING
1F6B9 MENS SYMBOL
1F6BA WOMENS SYMBOL
1F6BB RESTROOM
1F6BC BABY SYMBOL
1F6BD TOILET
1F6BE WATER CLOSET
1F6BF SHOWER
1F6C0 BATH
1F6C1 BATHTUB
1F6C2 PASSPORT CONTROL
1F6C3 CUSTOMS
1F6C4 BAGGAGE CLAIM
1F6C5 LEFT LUGGAGE
1F6C6 TRIANGLE WITH ROUNDED CORNERS
1F6C7 PROHIBITED SIGN
1F6C8 CIRCLED INFORMATION SOURCE
1F6C9 BOYS SYMBOL
1F6CA GIRLS SYMBOL
1F6CB COUCH AND LAMP
1F6CC SLEEPING ACCOMMODATION
1F6CD SHOPPING BAGS
1F6CE BELLHOP BELL
1F6CF BED
1F6D0 PLACE OF WORSHIP
1F6D1 OCTAGONAL SIGN
1F6D2 SHOPPING TROLLEY
1F6D3 STUPA
1F6D4 PAGODA
1F6E0 HAMMER AND WRENCH
1F6E1 SHIELD
1F6E2 OIL DRUM
1F6E3 MOTORWAY
1F6E4 RAILWAY TRACK
1F6E5 MOTOR BOAT
1F6E6 UP-POINTING MILITARY AIRPLANE
1F6E7 UP-POINTING AIRPLANE
1F6E8 UP-POINTING SMALL AIRPLANE
1F6E9 SMALL AIRPLANE
1F6EA NORTHEAST-POINTING AIRPLANE
1F6EB AIRPLANE DEPARTURE
1F6EC AIRPLANE ARRIVING
1F6F0 SATELLITE
1F6F1 ONCOMING FIRE ENGINE
1F6F2 DIESEL LOCOMOTIVE
1F6F3 PASSENGER SHIP
1F6F4 SCOOTER
1F6F5 MOTOR SCOOTER
1F6F6 CANOE
1F6F7 SLED
1F6F8 FLYING SAUCER
1F700 ALCHEMICAL SYMBOL FOR QUINTESSENCE
1F701 ALCHEMICAL SYMBOL FOR AIR
1F702 ALCHEMICAL SYMBOL FOR FIRE
1F703 ALCHEMICAL SYMBOL FOR EARTH
1F704 ALCHEMICAL SYMBOL FOR WATER
1F705 ALCHEMICAL SYMBOL FOR AQUAFORTIS
1F706 ALCHEMICAL SYMBOL FOR AQUA REGIA
1F707 ALCHEMICAL SYMBOL FOR AQUA REGIA-2
1F708 ALCHEMICAL SYMBOL FOR AQUA VITAE
1F709 ALCHEMICAL SYMBOL FOR AQUA VITAE-2
1F70A ALCHEMICAL SYMBOL FOR VINEGAR
1F70B ALCHEMICAL SYMBOL FOR VINEGAR-2
1F70C ALCHEMICAL SYMBOL FOR VINEGAR-3
1F70D ALCHEMICAL SYMBOL FOR SULFUR
1F70E ALCHEMICAL SYMBOL FOR PHILOSOPHERS SULFUR
1F70F ALCHEMICAL SYMBOL FOR BLACK SULFUR
1F710 ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE
1F711 ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE-2
1F712 ALCHEMICAL SYMBOL FOR MERCURY SUBLIMATE-3
1F713 ALCHEMICAL SYMBOL FOR CINNABAR
1F714 ALCHEMICAL SYMBOL FOR SALT
1F715 ALCHEMICAL SYMBOL FOR NITRE
1F716 ALCHEMICAL SYMBOL FOR VITRIOL
1F717 ALCHEMICAL SYMBOL FOR VITRIOL-2
1F718 ALCHEMICAL SYMBOL FOR ROCK SALT
1F719 ALCHEMICAL SYMBOL FOR ROCK SALT-2
1F71A ALCHEMICAL SYMBOL FOR GOLD
1F71B ALCHEMICAL SYMBOL FOR SILVER
1F71C ALCHEMICAL SYMBOL FOR IRON ORE
1F71D ALCHEMICAL SYMBOL FOR IRON ORE-2
1F71E ALCHEMICAL SYMBOL FOR CROCUS OF IRON
1F71F ALCHEMICAL SYMBOL FOR REGULUS OF IRON
1F720 ALCHEMICAL SYMBOL FOR COPPER ORE
1F721 ALCHEMICAL SYMBOL FOR IRON-COPPER ORE
1F722 ALCHEMICAL SYMBOL FOR SUBLIMATE OF COPPER
1F723 ALCHEMICAL SYMBOL FOR CROCUS OF COPPER
1F724 ALCHEMICAL SYMBOL FOR CROCUS OF COPPER-2
1F725 ALCHEMICAL SYMBOL FOR COPPER ANTIMONIATE
1F726 ALCHEMICAL SYMBOL FOR SALT OF COPPER ANTIMONIATE
1F727 ALCHEMICAL SYMBOL FOR SUBLIMATE OF SALT OF COPPER
1F728 ALCHEMICAL SYMBOL FOR VERDIGRIS
1F729 ALCHEMICAL SYMBOL FOR TIN ORE
1F72A ALCHEMICAL SYMBOL FOR LEAD ORE
1F72B ALCHEMICAL SYMBOL FOR ANTIMONY ORE
1F72C ALCHEMICAL SYMBOL FOR SUBLIMATE OF ANTIMONY
1F72D ALCHEMICAL SYMBOL FOR SALT OF ANTIMONY
1F72E ALCHEMICAL SYMBOL FOR SUBLIMATE OF SALT OF ANTIMONY
1F72F ALCHEMICAL SYMBOL FOR VINEGAR OF ANTIMONY
1F730 ALCHEMICAL SYMBOL FOR REGULUS OF ANTIMONY
1F731 ALCHEMICAL SYMBOL FOR REGULUS OF ANTIMONY-2
1F732 ALCHEMICAL SYMBOL FOR REGULUS
1F733 ALCHEMICAL SYMBOL FOR REGULUS-2
1F734 ALCHEMICAL SYMBOL FOR REGULUS-3
1F735 ALCHEMICAL SYMBOL FOR REGULUS-4
1F736 ALCHEMICAL SYMBOL FOR ALKALI
1F737 ALCHEMICAL SYMBOL FOR ALKALI-2
1F738 ALCHEMICAL SYMBOL FOR MARCASITE
1F739 ALCHEMICAL SYMBOL FOR SAL-AMMONIAC
1F73A ALCHEMICAL SYMBOL FOR ARSENIC
1F73B ALCHEMICAL SYMBOL FOR REALGAR
1F73C ALCHEMICAL SYMBOL FOR REALGAR-2
1F73D ALCHEMICAL SYMBOL FOR AURIPIGMENT
1F73E ALCHEMICAL SYMBOL FOR BISMUTH ORE
1F73F ALCHEMICAL SYMBOL FOR TARTAR
1F740 ALCHEMICAL SYMBOL FOR TARTAR-2
1F741 ALCHEMICAL SYMBOL FOR QUICK LIME
1F742 ALCHEMICAL SYMBOL FOR BORAX
1F743 ALCHEMICAL SYMBOL FOR BORAX-2
1F744 ALCHEMICAL SYMBOL FOR BORAX-3
1F745 ALCHEMICAL SYMBOL FOR ALUM
1F746 ALCHEMICAL SYMBOL FOR OIL
1F747 ALCHEMICAL SYMBOL FOR SPIRIT
1F748 ALCHEMICAL SYMBOL FOR TINCTURE
1F749 ALCHEMICAL SYMBOL FOR GUM
1F74A ALCHEMICAL SYMBOL FOR WAX
1F74B ALCHEMICAL SYMBOL FOR POWDER
1F74C ALCHEMICAL SYMBOL FOR CALX
1F74D ALCHEMICAL SYMBOL FOR TUTTY
1F74E ALCHEMICAL SYMBOL FOR CAPUT MORTUUM
1F74F ALCHEMICAL SYMBOL FOR SCEPTER OF JOVE
1F750 ALCHEMICAL SYMBOL FOR CADUCEUS
1F751 ALCHEMICAL SYMBOL FOR TRIDENT
1F752 ALCHEMICAL SYMBOL FOR STARRED TRIDENT
1F753 ALCHEMICAL SYMBOL FOR LODESTONE
1F754 ALCHEMICAL SYMBOL FOR SOAP
1F755 ALCHEMICAL SYMBOL FOR URINE
1F756 ALCHEMICAL SYMBOL FOR HORSE DUNG
1F757 ALCHEMICAL SYMBOL FOR ASHES
1F758 ALCHEMICAL SYMBOL FOR POT ASHES
1F759 ALCHEMICAL SYMBOL FOR BRICK
1F75A ALCHEMICAL SYMBOL FOR POWDERED BRICK
1F75B ALCHEMICAL SYMBOL FOR AMALGAM
1F75C ALCHEMICAL SYMBOL FOR STRATUM SUPER STRATUM
1F75D ALCHEMICAL SYMBOL FOR STRATUM SUPER STRATUM-2
1F75E ALCHEMICAL SYMBOL FOR SUBLIMATION
1F75F ALCHEMICAL SYMBOL FOR PRECIPITATE
1F760 ALCHEMICAL SYMBOL FOR DISTILL
1F761 ALCHEMICAL SYMBOL FOR DISSOLVE
1F762 ALCHEMICAL SYMBOL FOR DISSOLVE-2
1F763 ALCHEMICAL SYMBOL FOR PURIFY
1F764 ALCHEMICAL SYMBOL FOR PUTREFACTION
1F765 ALCHEMICAL SYMBOL FOR CRUCIBLE
1F766 ALCHEMICAL SYMBOL FOR CRUCIBLE-2
1F767 ALCHEMICAL SYMBOL FOR CRUCIBLE-3
1F768 ALCHEMICAL SYMBOL FOR CRUCIBLE-4
1F769 ALCHEMICAL SYMBOL FOR CRUCIBLE-5
1F76A ALCHEMICAL SYMBOL FOR ALEMBIC
1F76B ALCHEMICAL SYMBOL FOR BATH OF MARY
1F76C ALCHEMICAL SYMBOL FOR BATH OF VAPOURS
1F76D ALCHEMICAL SYMBOL FOR RETORT
1F76E ALCHEMICAL SYMBOL FOR HOUR
1F76F ALCHEMICAL SYMBOL FOR NIGHT
1F770 ALCHEMICAL SYMBOL FOR DAY-NIGHT
1F771 ALCHEMICAL SYMBOL FOR MONTH
1F772 ALCHEMICAL SYMBOL FOR HALF DRAM
1F773 ALCHEMICAL SYMBOL FOR HALF OUNCE
1F780 BLACK LEFT-POINTING ISOSCELES RIGHT TRIANGLE
1F781 BLACK UP-POINTING ISOSCELES RIGHT TRIANGLE
1F782 BLACK RIGHT-POINTING ISOSCELES RIGHT TRIANGLE
1F783 BLACK DOWN-POINTING ISOSCELES RIGHT TRIANGLE
1F784 BLACK SLIGHTLY SMALL CIRCLE
1F785 MEDIUM BOLD WHITE CIRCLE
1F786 BOLD WHITE CIRCLE
1F787 HEAVY WHITE CIRCLE
1F788 VERY HEAVY WHITE CIRCLE
1F789 EXTREMELY HEAVY WHITE CIRCLE
1F78A WHITE CIRCLE CONTAINING BLACK SMALL CIRCLE
1F78B ROUND TARGET
1F78C BLACK TINY SQUARE
1F78D BLACK SLIGHTLY SMALL SQUARE
1F78E LIGHT WHITE SQUARE
1F78F MEDIUM WHITE SQUARE
1F790 BOLD WHITE SQUARE
1F791 HEAVY WHITE SQUARE
1F792 VERY HEAVY WHITE SQUARE
1F793 EXTREMELY HEAVY WHITE SQUARE
1F794 WHITE SQUARE CONTAINING BLACK VERY SMALL SQUARE
1F795 WHITE SQUARE CONTAINING BLACK MEDIUM SQUARE
1F796 SQUARE TARGET
1F797 BLACK TINY DIAMOND
1F798 BLACK VERY SMALL DIAMOND
1F799 BLACK MEDIUM SMALL DIAMOND
1F79A WHITE DIAMOND CONTAINING BLACK VERY SMALL DIAMOND
1F79B WHITE DIAMOND CONTAINING BLACK MEDIUM DIAMOND
1F79C DIAMOND TARGET
1F79D BLACK TINY LOZENGE
1F79E BLACK VERY SMALL LOZENGE
1F79F BLACK MEDIUM SMALL LOZENGE
1F7A0 WHITE LOZENGE CONTAINING BLACK SMALL LOZENGE
1F7A1 THIN GREEK CROSS
1F7A2 LIGHT GREEK CROSS
1F7A3 MEDIUM GREEK CROSS
1F7A4 BOLD GREEK CROSS
1F7A5 VERY BOLD GREEK CROSS
1F7A6 VERY HEAVY GREEK CROSS
1F7A7 EXTREMELY HEAVY GREEK CROSS
1F7A8 THIN SALTIRE
1F7A9 LIGHT SALTIRE
1F7AA MEDIUM SALTIRE
1F7AB BOLD SALTIRE
1F7AC HEAVY SALTIRE
1F7AD VERY HEAVY SALTIRE
1F7AE EXTREMELY HEAVY SALTIRE
1F7AF LIGHT FIVE SPOKED ASTERISK
1F7B0 MEDIUM FIVE SPOKED ASTERISK
1F7B1 BOLD FIVE SPOKED ASTERISK
1F7B2 HEAVY FIVE SPOKED ASTERISK
1F7B3 VERY HEAVY FIVE SPOKED ASTERISK
1F7B4 EXTREMELY HEAVY FIVE SPOKED ASTERISK
1F7B5 LIGHT SIX SPOKED ASTERISK
1F7B6 MEDIUM SIX SPOKED ASTERISK
1F7B7 BOLD SIX SPOKED ASTERISK
1F7B8 HEAVY SIX SPOKED ASTERISK
1F7B9 VERY HEAVY SIX SPOKED ASTERISK
1F7BA EXTREMELY HEAVY SIX SPOKED ASTERISK
1F7BB LIGHT EIGHT SPOKED ASTERISK
1F7BC MEDIUM EIGHT SPOKED ASTERISK
1F7BD BOLD EIGHT SPOKED ASTERISK
1F7BE HEAVY EIGHT SPOKED ASTERISK
1F7BF VERY HEAVY EIGHT SPOKED ASTERISK
1F7C0 LIGHT THREE POINTED BLACK STAR
1F7C1 MEDIUM THREE POINTED BLACK STAR
1F7C2 THREE POINTED BLACK STAR
1F7C3 MEDIUM THREE POINTED PINWHEEL STAR
1F7C4 LIGHT FOUR POINTED BLACK STAR
1F7C5 MEDIUM FOUR POINTED BLACK STAR
1F7C6 FOUR POINTED BLACK STAR
1F7C7 MEDIUM FOUR POINTED PINWHEEL STAR
1F7C8 REVERSE LIGHT FOUR POINTED PINWHEEL STAR
1F7C9 LIGHT FIVE POINTED BLACK STAR
1F7CA HEAVY FIVE POINTED BLACK STAR
1F7CB MEDIUM SIX POINTED BLACK STAR
1F7CC HEAVY SIX POINTED BLACK STAR
1F7CD SIX POINTED PINWHEEL STAR
1F7CE MEDIUM EIGHT POINTED BLACK STAR
1F7CF HEAVY EIGHT POINTED BLACK STAR
1F7D0 VERY HEAVY EIGHT POINTED BLACK STAR
1F7D1 HEAVY EIGHT POINTED PINWHEEL STAR
1F7D2 LIGHT TWELVE POINTED BLACK STAR
1F7D3 HEAVY TWELVE POINTED BLACK STAR
1F7D4 HEAVY TWELVE POINTED PINWHEEL STAR
1F800 LEFTWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD
1F801 UPWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD
1F802 RIGHTWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD
1F803 DOWNWARDS ARROW WITH SMALL TRIANGLE ARROWHEAD
1F804 LEFTWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD
1F805 UPWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD
1F806 RIGHTWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD
1F807 DOWNWARDS ARROW WITH MEDIUM TRIANGLE ARROWHEAD
1F808 LEFTWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD
1F809 UPWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD
1F80A RIGHTWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD
1F80B DOWNWARDS ARROW WITH LARGE TRIANGLE ARROWHEAD
1F810 LEFTWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD
1F811 UPWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD
1F812 RIGHTWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD
1F813 DOWNWARDS ARROW WITH SMALL EQUILATERAL ARROWHEAD
1F814 LEFTWARDS ARROW WITH EQUILATERAL ARROWHEAD
1F815 UPWARDS ARROW WITH EQUILATERAL ARROWHEAD
1F816 RIGHTWARDS ARROW WITH EQUILATERAL ARROWHEAD
1F817 DOWNWARDS ARROW WITH EQUILATERAL ARROWHEAD
1F818 HEAVY LEFTWARDS ARROW WITH EQUILATERAL ARROWHEAD
1F819 HEAVY UPWARDS ARROW WITH EQUILATERAL ARROWHEAD
1F81A HEAVY RIGHTWARDS ARROW WITH EQUILATERAL ARROWHEAD
1F81B HEAVY DOWNWARDS ARROW WITH EQUILATERAL ARROWHEAD
1F81C HEAVY LEFTWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD
1F81D HEAVY UPWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD
1F81E HEAVY RIGHTWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD
1F81F HEAVY DOWNWARDS ARROW WITH LARGE EQUILATERAL ARROWHEAD
1F820 LEFTWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT
1F821 UPWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT
1F822 RIGHTWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT
1F823 DOWNWARDS TRIANGLE-HEADED ARROW WITH NARROW SHAFT
1F824 LEFTWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT
1F825 UPWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT
1F826 RIGHTWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT
1F827 DOWNWARDS TRIANGLE-HEADED ARROW WITH MEDIUM SHAFT
1F828 LEFTWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT
1F829 UPWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT
1F82A RIGHTWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT
1F82B DOWNWARDS TRIANGLE-HEADED ARROW WITH BOLD SHAFT
1F82C LEFTWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT
1F82D UPWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT
1F82E RIGHTWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT
1F82F DOWNWARDS TRIANGLE-HEADED ARROW WITH HEAVY SHAFT
1F830 LEFTWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT
1F831 UPWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT
1F832 RIGHTWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT
1F833 DOWNWARDS TRIANGLE-HEADED ARROW WITH VERY HEAVY SHAFT
1F834 LEFTWARDS FINGER-POST ARROW
1F835 UPWARDS FINGER-POST ARROW
1F836 RIGHTWARDS FINGER-POST ARROW
1F837 DOWNWARDS FINGER-POST ARROW
1F838 LEFTWARDS SQUARED ARROW
1F839 UPWARDS SQUARED ARROW
1F83A RIGHTWARDS SQUARED ARROW
1F83B DOWNWARDS SQUARED ARROW
1F83C LEFTWARDS COMPRESSED ARROW
1F83D UPWARDS COMPRESSED ARROW
1F83E RIGHTWARDS COMPRESSED ARROW
1F83F DOWNWARDS COMPRESSED ARROW
1F840 LEFTWARDS HEAVY COMPRESSED ARROW
1F841 UPWARDS HEAVY COMPRESSED ARROW
1F842 RIGHTWARDS HEAVY COMPRESSED ARROW
1F843 DOWNWARDS HEAVY COMPRESSED ARROW
1F844 LEFTWARDS HEAVY ARROW
1F845 UPWARDS HEAVY ARROW
1F846 RIGHTWARDS HEAVY ARROW
1F847 DOWNWARDS HEAVY ARROW
1F850 LEFTWARDS SANS-SERIF ARROW
1F851 UPWARDS SANS-SERIF ARROW
1F852 RIGHTWARDS SANS-SERIF ARROW
1F853 DOWNWARDS SANS-SERIF ARROW
1F854 NORTH WEST SANS-SERIF ARROW
1F855 NORTH EAST SANS-SERIF ARROW
1F856 SOUTH EAST SANS-SERIF ARROW
1F857 SOUTH WEST SANS-SERIF ARROW
1F858 LEFT RIGHT SANS-SERIF ARROW
1F859 UP DOWN SANS-SERIF ARROW
1F860 WIDE-HEADED LEFTWARDS LIGHT BARB ARROW
1F861 WIDE-HEADED UPWARDS LIGHT BARB ARROW
1F862 WIDE-HEADED RIGHTWARDS LIGHT BARB ARROW
1F863 WIDE-HEADED DOWNWARDS LIGHT BARB ARROW
1F864 WIDE-HEADED NORTH WEST LIGHT BARB ARROW
1F865 WIDE-HEADED NORTH EAST LIGHT BARB ARROW
1F866 WIDE-HEADED SOUTH EAST LIGHT BARB ARROW
1F867 WIDE-HEADED SOUTH WEST LIGHT BARB ARROW
1F868 WIDE-HEADED LEFTWARDS BARB ARROW
1F869 WIDE-HEADED UPWARDS BARB ARROW
1F86A WIDE-HEADED RIGHTWARDS BARB ARROW
1F86B WIDE-HEADED DOWNWARDS BARB ARROW
1F86C WIDE-HEADED NORTH WEST BARB ARROW
1F86D WIDE-HEADED NORTH EAST BARB ARROW
1F86E WIDE-HEADED SOUTH EAST BARB ARROW
1F86F WIDE-HEADED SOUTH WEST BARB ARROW
1F870 WIDE-HEADED LEFTWARDS MEDIUM BARB ARROW
1F871 WIDE-HEADED UPWARDS MEDIUM BARB ARROW
1F872 WIDE-HEADED RIGHTWARDS MEDIUM BARB ARROW
1F873 WIDE-HEADED DOWNWARDS MEDIUM BARB ARROW
1F874 WIDE-HEADED NORTH WEST MEDIUM BARB ARROW
1F875 WIDE-HEADED NORTH EAST MEDIUM BARB ARROW
1F876 WIDE-HEADED SOUTH EAST MEDIUM BARB ARROW
1F877 WIDE-HEADED SOUTH WEST MEDIUM BARB ARROW
1F878 WIDE-HEADED LEFTWARDS HEAVY BARB ARROW
1F879 WIDE-HEADED UPWARDS HEAVY BARB ARROW
1F87A WIDE-HEADED RIGHTWARDS HEAVY BARB ARROW
1F87B WIDE-HEADED DOWNWARDS HEAVY BARB ARROW
1F87C WIDE-HEADED NORTH WEST HEAVY BARB ARROW
1F87D WIDE-HEADED NORTH EAST HEAVY BARB ARROW
1F87E WIDE-HEADED SOUTH EAST HEAVY BARB ARROW
1F87F WIDE-HEADED SOUTH WEST HEAVY BARB ARROW
1F880 WIDE-HEADED LEFTWARDS VERY HEAVY BARB ARROW
1F881 WIDE-HEADED UPWARDS VERY HEAVY BARB ARROW
1F882 WIDE-HEADED RIGHTWARDS VERY HEAVY BARB ARROW
1F883 WIDE-HEADED DOWNWARDS VERY HEAVY BARB ARROW
1F884 WIDE-HEADED NORTH WEST VERY HEAVY BARB ARROW
1F885 WIDE-HEADED NORTH EAST VERY HEAVY BARB ARROW
1F886 WIDE-HEADED SOUTH EAST VERY HEAVY BARB ARROW
1F887 WIDE-HEADED SOUTH WEST VERY HEAVY BARB ARROW
1F890 LEFTWARDS TRIANGLE ARROWHEAD
1F891 UPWARDS TRIANGLE ARROWHEAD
1F892 RIGHTWARDS TRIANGLE ARROWHEAD
1F893 DOWNWARDS TRIANGLE ARROWHEAD
1F894 LEFTWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD
1F895 UPWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD
1F896 RIGHTWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD
1F897 DOWNWARDS WHITE ARROW WITHIN TRIANGLE ARROWHEAD
1F898 LEFTWARDS ARROW WITH NOTCHED TAIL
1F899 UPWARDS ARROW WITH NOTCHED TAIL
1F89A RIGHTWARDS ARROW WITH NOTCHED TAIL
1F89B DOWNWARDS ARROW WITH NOTCHED TAIL
1F89C HEAVY ARROW SHAFT WIDTH ONE
1F89D HEAVY ARROW SHAFT WIDTH TWO THIRDS
1F89E HEAVY ARROW SHAFT WIDTH ONE HALF
1F89F HEAVY ARROW SHAFT WIDTH ONE THIRD
1F8A0 LEFTWARDS BOTTOM-SHADED WHITE ARROW
1F8A1 RIGHTWARDS BOTTOM SHADED WHITE ARROW
1F8A2 LEFTWARDS TOP SHADED WHITE ARROW
1F8A3 RIGHTWARDS TOP SHADED WHITE ARROW
1F8A4 LEFTWARDS LEFT-SHADED WHITE ARROW
1F8A5 RIGHTWARDS RIGHT-SHADED WHITE ARROW
1F8A6 LEFTWARDS RIGHT-SHADED WHITE ARROW
1F8A7 RIGHTWARDS LEFT-SHADED WHITE ARROW
1F8A8 LEFTWARDS BACK-TILTED SHADOWED WHITE ARROW
1F8A9 RIGHTWARDS BACK-TILTED SHADOWED WHITE ARROW
1F8AA LEFTWARDS FRONT-TILTED SHADOWED WHITE ARROW
1F8AB RIGHTWARDS FRONT-TILTED SHADOWED WHITE ARROW
1F8AC WHITE ARROW SHAFT WIDTH ONE
1F8AD WHITE ARROW SHAFT WIDTH TWO THIRDS
1F900 CIRCLED CROSS FORMEE WITH FOUR DOTS
1F901 CIRCLED CROSS FORMEE WITH TWO DOTS
1F902 CIRCLED CROSS FORMEE
1F903 LEFT HALF CIRCLE WITH FOUR DOTS
1F904 LEFT HALF CIRCLE WITH THREE DOTS
1F905 LEFT HALF CIRCLE WITH TWO DOTS
1F906 LEFT HALF CIRCLE WITH DOT
1F907 LEFT HALF CIRCLE
1F908 DOWNWARD FACING HOOK
1F909 DOWNWARD FACING NOTCHED HOOK
1F90A DOWNWARD FACING HOOK WITH DOT
1F90B DOWNWARD FACING NOTCHED HOOK WITH DOT
1F910 ZIPPER-MOUTH FACE
1F911 MONEY-MOUTH FACE
1F912 FACE WITH THERMOMETER
1F913 NERD FACE
1F914 THINKING FACE
1F915 FACE WITH HEAD-BANDAGE
1F916 ROBOT FACE
1F917 HUGGING FACE
1F918 SIGN OF THE HORNS
1F919 CALL ME HAND
1F91A RAISED BACK OF HAND
1F91B LEFT-FACING FIST
1F91C RIGHT-FACING FIST
1F91D HANDSHAKE
1F91E HAND WITH INDEX AND MIDDLE FINGERS CROSSED
1F91F I LOVE YOU HAND SIGN
1F920 FACE WITH COWBOY HAT
1F921 CLOWN FACE
1F922 NAUSEATED FACE
1F923 ROLLING ON THE FLOOR LAUGHING
1F924 DROOLING FACE
1F925 LYING FACE
1F926 FACE PALM
1F927 SNEEZING FACE
1F928 FACE WITH ONE EYEBROW RAISED
1F929 GRINNING FACE WITH STAR EYES
1F92A GRINNING FACE WITH ONE LARGE AND ONE SMALL EYE
1F92B FACE WITH FINGER COVERING CLOSED LIPS
1F92C SERIOUS FACE WITH SYMBOLS COVERING MOUTH
1F92D SMILING FACE WITH SMILING EYES AND HAND COVERING MOUTH
1F92E FACE WITH OPEN MOUTH VOMITING
1F92F SHOCKED FACE WITH EXPLODING HEAD
1F930 PREGNANT WOMAN
1F931 BREAST-FEEDING
1F932 PALMS UP TOGETHER
1F933 SELFIE
1F934 PRINCE
1F935 MAN IN TUXEDO
1F936 MOTHER CHRISTMAS
1F937 SHRUG
1F938 PERSON DOING CARTWHEEL
1F939 JUGGLING
1F93A FENCER
1F93B MODERN PENTATHLON
1F93C WRESTLERS
1F93D WATER POLO
1F93E HANDBALL
1F940 WILTED FLOWER
1F941 DRUM WITH DRUMSTICKS
1F942 CLINKING GLASSES
1F943 TUMBLER GLASS
1F944 SPOON
1F945 GOAL NET
1F946 RIFLE
1F947 FIRST PLACE MEDAL
1F948 SECOND PLACE MEDAL
1F949 THIRD PLACE MEDAL
1F94A BOXING GLOVE
1F94B MARTIAL ARTS UNIFORM
1F94C CURLING STONE
1F950 CROISSANT
1F951 AVOCADO
1F952 CUCUMBER
1F953 BACON
1F954 POTATO
1F955 CARROT
1F956 BAGUETTE BREAD
1F957 GREEN SALAD
1F958 SHALLOW PAN OF FOOD
1F959 STUFFED FLATBREAD
1F95A EGG
1F95B GLASS OF MILK
1F95C PEANUTS
1F95D KIWIFRUIT
1F95E PANCAKES
1F95F DUMPLING
1F960 FORTUNE COOKIE
1F961 TAKEOUT BOX
1F962 CHOPSTICKS
1F963 BOWL WITH SPOON
1F964 CUP WITH STRAW
1F965 COCONUT
1F966 BROCCOLI
1F967 PIE
1F968 PRETZEL
1F969 CUT OF MEAT
1F96A SANDWICH
1F96B CANNED FOOD
1F980 CRAB
1F981 LION FACE
1F982 SCORPION
1F983 TURKEY
1F984 UNICORN FACE
1F985 EAGLE
1F986 DUCK
1F987 BAT
1F988 SHARK
1F989 OWL
1F98A FOX FACE
1F98B BUTTERFLY
1F98C DEER
1F98D GORILLA
1F98E LIZARD
1F98F RHINOCEROS
1F990 SHRIMP
1F991 SQUID
1F992 GIRAFFE FACE
1F993 ZEBRA FACE
1F994 HEDGEHOG
1F995 SAUROPOD
1F996 T-REX
1F997 CRICKET
1F9C0 CHEESE WEDGE
1F9D0 FACE WITH MONOCLE
1F9D1 ADULT
1F9D2 CHILD
1F9D3 OLDER ADULT
1F9D4 BEARDED PERSON
1F9D5 PERSON WITH HEADSCARF
1F9D6 PERSON IN STEAMY ROOM
1F9D7 PERSON CLIMBING
1F9D8 PERSON IN LOTUS POSITION
1F9D9 MAGE
1F9DA FAIRY
1F9DB VAMPIRE
1F9DC MERPERSON
1F9DD ELF
1F9DE GENIE
1F9DF ZOMBIE
1F9E0 BRAIN
1F9E1 ORANGE HEART
1F9E2 BILLED CAP
1F9E3 SCARF
1F9E4 GLOVES
1F9E5 COAT
1F9E6 SOCKS
20000 CJK UNIFIED IDEOGRAPH-#20000, IRGKangXi=0075.060, RSKangXi=1.1, Def{the sound made by breathing in; oh! (cf. U+311B BOPOMOFO LETTER O, which is derived from this character)}
20001 CJK UNIFIED IDEOGRAPH-#20001, IRGKangXi=0076.021, RSKangXi=1.1, Def{the original form for 七 U+4E03}
20002 CJK UNIFIED IDEOGRAPH-#20002, IRGKangXi=0076.021, RSKangXi=1.1
20003 CJK UNIFIED IDEOGRAPH-#20003, IRGKangXi=0076.140, RSKangXi=1.2
20004 CJK UNIFIED IDEOGRAPH-#20004, IRGKangXi=0076.141, RSKangXi=1.2
20005 CJK UNIFIED IDEOGRAPH-#20005, IRGKangXi=0076.141, RSKangXi=1.2, Def{an alternate form of U+4EA5 亥}
20006 CJK UNIFIED IDEOGRAPH-#20006, IRGKangXi=0076.141, RSKangXi=1.2
20007 CJK UNIFIED IDEOGRAPH-#20007, IRGKangXi=0077.050, RSKangXi=1.3
20008 CJK UNIFIED IDEOGRAPH-#20008, IRGKangXi=0077.060, RSKangXi=1.3
20009 CJK UNIFIED IDEOGRAPH-#20009, IRGKangXi=0077.061, RSKangXi=1.3, Def{(the same as U+4E18 丘) a hill; elder; empty; a name}
2000A CJK UNIFIED IDEOGRAPH-#2000A, IRGKangXi=0077.061, RSKangXi=1.3
2000B CJK UNIFIED IDEOGRAPH-#2000B, IRGKangXi=0077.061, RSKangXi=1.3
2000C CJK UNIFIED IDEOGRAPH-#2000C, IRGKangXi=0077.061, RSKangXi=1.3
2000D CJK UNIFIED IDEOGRAPH-#2000D, IRGKangXi=0077.130, RSKangXi=1.4, Def{(same as U+4E16 世) generation; world; era}
2000E CJK UNIFIED IDEOGRAPH-#2000E, IRGKangXi=0078.021, RSKangXi=1.4
2000F CJK UNIFIED IDEOGRAPH-#2000F, IRGKangXi=0078.021, RSKangXi=1.4
20010 CJK UNIFIED IDEOGRAPH-#20010, IRGKangXi=0078.021, RSKangXi=1.4
20011 CJK UNIFIED IDEOGRAPH-#20011, IRGKangXi=0078.021, RSKangXi=1.4
20012 CJK UNIFIED IDEOGRAPH-#20012, IRGKangXi=0078.021, RSKangXi=1.4
20013 CJK UNIFIED IDEOGRAPH-#20013, IRGKangXi=0078.021, RSKangXi=1.4
20014 CJK UNIFIED IDEOGRAPH-#20014, IRGKangXi=0078.021, RSKangXi=1.4
20015 CJK UNIFIED IDEOGRAPH-#20015, IRGKangXi=0078.021, RSKangXi=1.4, Def{Variant of U+4E99 亙}
20016 CJK UNIFIED IDEOGRAPH-#20016, IRGKangXi=0078.021, RSKangXi=1.4
20017 CJK UNIFIED IDEOGRAPH-#20017, IRGKangXi=0078.021, RSKangXi=1.4
20018 CJK UNIFIED IDEOGRAPH-#20018, IRGKangXi=0078.070, RSKangXi=1.5
20019 CJK UNIFIED IDEOGRAPH-#20019, IRGKangXi=0078.080, RSKangXi=1.5
2001A CJK UNIFIED IDEOGRAPH-#2001A, IRGKangXi=0078.090, RSKangXi=1.5
2001B CJK UNIFIED IDEOGRAPH-#2001B, IRGKangXi=0078.101, RSKangXi=37.3
2001C CJK UNIFIED IDEOGRAPH-#2001C, IRGKangXi=0078.101, RSKangXi=1.5
2001D CJK UNIFIED IDEOGRAPH-#2001D, IRGKangXi=0078.101, RSKangXi=25.4
2001E CJK UNIFIED IDEOGRAPH-#2001E, IRGKangXi=0078.101, RSKangXi=1.5
2001F CJK UNIFIED IDEOGRAPH-#2001F, IRGKangXi=0078.101, RSKangXi=1.5
20020 CJK UNIFIED IDEOGRAPH-#20020, IRGKangXi=0078.101, RSKangXi=1.5
20021 CJK UNIFIED IDEOGRAPH-#20021, IRGKangXi=0078.120, RSKangXi=1.6
20022 CJK UNIFIED IDEOGRAPH-#20022, IRGKangXi=0078.130, RSKangXi=1.6
20023 CJK UNIFIED IDEOGRAPH-#20023, IRGKangXi=0078.131, RSKangXi=1.6
20024 CJK UNIFIED IDEOGRAPH-#20024, IRGKangXi=0078.131, RSKangXi=1.6
20025 CJK UNIFIED IDEOGRAPH-#20025, IRGKangXi=0078.131, RSKangXi=7.5
20026 CJK UNIFIED IDEOGRAPH-#20026, IRGKangXi=0078.131, RSKangXi=1.6
20027 CJK UNIFIED IDEOGRAPH-#20027, IRGKangXi=0078.131, RSKangXi=1.6
20028 CJK UNIFIED IDEOGRAPH-#20028, IRGKangXi=0078.131, RSKangXi=1.6
20029 CJK UNIFIED IDEOGRAPH-#20029, IRGKangXi=0078.131, RSKangXi=6.5
2002A CJK UNIFIED IDEOGRAPH-#2002A, IRGKangXi=0078.131, RSKangXi=1.6
2002B CJK UNIFIED IDEOGRAPH-#2002B, IRGKangXi=0078.131, RSKangXi=1.6
2002C CJK UNIFIED IDEOGRAPH-#2002C, IRGKangXi=0078.150, RSKangXi=1.7
2002D CJK UNIFIED IDEOGRAPH-#2002D, IRGKangXi=0078.160, RSKangXi=1.7
2002E CJK UNIFIED IDEOGRAPH-#2002E, IRGKangXi=0078.170, RSKangXi=1.7
2002F CJK UNIFIED IDEOGRAPH-#2002F, IRGKangXi=0078.171, RSKangXi=31.5
20030 CJK UNIFIED IDEOGRAPH-#20030, IRGKangXi=0078.171, RSKangXi=1.7
20031 CJK UNIFIED IDEOGRAPH-#20031, IRGKangXi=0078.171, RSKangXi=1.7
20032 CJK UNIFIED IDEOGRAPH-#20032, IRGKangXi=0078.171, RSKangXi=1.7
20033 CJK UNIFIED IDEOGRAPH-#20033, IRGKangXi=0078.171, RSKangXi=1.7
20034 CJK UNIFIED IDEOGRAPH-#20034, IRGKangXi=0078.171, RSKangXi=1.7
20035 CJK UNIFIED IDEOGRAPH-#20035, IRGKangXi=0078.171, RSKangXi=1.8
20036 CJK UNIFIED IDEOGRAPH-#20036, IRGKangXi=0078.171, RSKangXi=1.8
20037 CJK UNIFIED IDEOGRAPH-#20037, IRGKangXi=0078.171, RSKangXi=30.6
20038 CJK UNIFIED IDEOGRAPH-#20038, IRGKangXi=0078.171, RSKangXi=1.8
20039 CJK UNIFIED IDEOGRAPH-#20039, IRGKangXi=0078.171, RSKangXi=30.6
2003A CJK UNIFIED IDEOGRAPH-#2003A, IRGKangXi=0078.171, RSKangXi=1.8
2003B CJK UNIFIED IDEOGRAPH-#2003B, IRGKangXi=0078.171, RSKangXi=1.8
2003C CJK UNIFIED IDEOGRAPH-#2003C, IRGKangXi=0078.171, RSKangXi=35.7
2003D CJK UNIFIED IDEOGRAPH-#2003D, IRGKangXi=0078.171, RSKangXi=1.9
2003E CJK UNIFIED IDEOGRAPH-#2003E, IRGKangXi=0078.171, RSKangXi=1.9
2003F CJK UNIFIED IDEOGRAPH-#2003F, IRGKangXi=0078.171, RSKangXi=1.9
20040 CJK UNIFIED IDEOGRAPH-#20040, IRGKangXi=0078.171, RSKangXi=1.9
20041 CJK UNIFIED IDEOGRAPH-#20041, IRGKangXi=0078.180, RSKangXi=1.10, Def{a flagon}
20042 CJK UNIFIED IDEOGRAPH-#20042, IRGKangXi=0078.181, RSKangXi=1.10
20043 CJK UNIFIED IDEOGRAPH-#20043, IRGKangXi=0078.181, RSKangXi=1.10
20044 CJK UNIFIED IDEOGRAPH-#20044, IRGKangXi=0078.181, RSKangXi=1.10
20045 CJK UNIFIED IDEOGRAPH-#20045, IRGKangXi=0078.181, RSKangXi=1.10
20046 CJK UNIFIED IDEOGRAPH-#20046, IRGKangXi=0078.181, RSKangXi=1.11
20047 CJK UNIFIED IDEOGRAPH-#20047, IRGKangXi=0078.181, RSKangXi=1.11
20048 CJK UNIFIED IDEOGRAPH-#20048, IRGKangXi=0078.181, RSKangXi=1.11
20049 CJK UNIFIED IDEOGRAPH-#20049, IRGKangXi=0078.181, RSKangXi=16.10
2004A CJK UNIFIED IDEOGRAPH-#2004A, IRGKangXi=0078.181, RSKangXi=1.11
2004B CJK UNIFIED IDEOGRAPH-#2004B, IRGKangXi=0078.181, RSKangXi=1.11
2004C CJK UNIFIED IDEOGRAPH-#2004C, IRGKangXi=0078.181, RSKangXi=1.12
2004D CJK UNIFIED IDEOGRAPH-#2004D, IRGKangXi=0078.181, RSKangXi=1.12
2004E CJK UNIFIED IDEOGRAPH-#2004E, IRGKangXi=0078.181, RSKangXi=1.13
2004F CJK UNIFIED IDEOGRAPH-#2004F, IRGKangXi=0078.181, RSKangXi=1.13
20050 CJK UNIFIED IDEOGRAPH-#20050, IRGKangXi=0078.181, RSKangXi=1.13
20051 CJK UNIFIED IDEOGRAPH-#20051, IRGKangXi=0078.181, RSKangXi=1.13
20052 CJK UNIFIED IDEOGRAPH-#20052, IRGKangXi=0078.181, RSKangXi=1.13
20053 CJK UNIFIED IDEOGRAPH-#20053, IRGKangXi=0078.181, RSKangXi=1.14
20054 CJK UNIFIED IDEOGRAPH-#20054, IRGKangXi=0078.181, RSKangXi=1.14
20055 CJK UNIFIED IDEOGRAPH-#20055, IRGKangXi=0078.190, RSKangXi=1.15
20056 CJK UNIFIED IDEOGRAPH-#20056, IRGKangXi=0078.191, RSKangXi=1.16
20057 CJK UNIFIED IDEOGRAPH-#20057, IRGKangXi=0078.191, RSKangXi=1.15
20058 CJK UNIFIED IDEOGRAPH-#20058, IRGKangXi=0078.191, RSKangXi=1.15
20059 CJK UNIFIED IDEOGRAPH-#20059, IRGKangXi=0078.191, RSKangXi=1.15
2005A CJK UNIFIED IDEOGRAPH-#2005A, IRGKangXi=0078.191, RSKangXi=1.15
2005B CJK UNIFIED IDEOGRAPH-#2005B, IRGKangXi=0078.191, RSKangXi=1.15
2005C CJK UNIFIED IDEOGRAPH-#2005C, IRGKangXi=0078.191, RSKangXi=12.15
2005D CJK UNIFIED IDEOGRAPH-#2005D, IRGKangXi=0078.191, RSKangXi=1.15
2005E CJK UNIFIED IDEOGRAPH-#2005E, IRGKangXi=0078.191, RSKangXi=72.13
2005F CJK UNIFIED IDEOGRAPH-#2005F, IRGKangXi=0078.191, RSKangXi=1.15
20060 CJK UNIFIED IDEOGRAPH-#20060, IRGKangXi=0078.191, RSKangXi=1.19
20061 CJK UNIFIED IDEOGRAPH-#20061, IRGKangXi=0078.220, RSKangXi=2.1
20062 CJK UNIFIED IDEOGRAPH-#20062, IRGKangXi=0078.221, RSKangXi=2.1
20063 CJK UNIFIED IDEOGRAPH-#20063, IRGKangXi=0079.091, RSKangXi=2.3
20064 CJK UNIFIED IDEOGRAPH-#20064, IRGKangXi=0079.101, RSKangXi=31.2
20065 CJK UNIFIED IDEOGRAPH-#20065, IRGKangXi=0079.101, RSKangXi=2.4, Def{the horns of a sheep}
20066 CJK UNIFIED IDEOGRAPH-#20066, IRGKangXi=0080.010, RSKangXi=2.5
20067 CJK UNIFIED IDEOGRAPH-#20067, IRGKangXi=0080.030, RSKangXi=2.6
20068 CJK UNIFIED IDEOGRAPH-#20068, IRGKangXi=0080.031, RSKangXi=2.6
20069 CJK UNIFIED IDEOGRAPH-#20069, IRGKangXi=0080.050, RSKangXi=2.7
2006A CJK UNIFIED IDEOGRAPH-#2006A, IRGKangXi=0080.051, RSKangXi=2.7
2006B CJK UNIFIED IDEOGRAPH-#2006B, IRGKangXi=0080.051, RSKangXi=2.7
2006C CJK UNIFIED IDEOGRAPH-#2006C, IRGKangXi=0080.051, RSKangXi=2.7
2006D CJK UNIFIED IDEOGRAPH-#2006D, IRGKangXi=0080.060, RSKangXi=2.8
2006E CJK UNIFIED IDEOGRAPH-#2006E, IRGKangXi=0080.070, RSKangXi=2.8
2006F CJK UNIFIED IDEOGRAPH-#2006F, IRGKangXi=0080.071, RSKangXi=2.8
20070 CJK UNIFIED IDEOGRAPH-#20070, IRGKangXi=0080.090, RSKangXi=2.9
20071 CJK UNIFIED IDEOGRAPH-#20071, IRGKangXi=0080.100, RSKangXi=2.9
20072 CJK UNIFIED IDEOGRAPH-#20072, IRGKangXi=0080.101, RSKangXi=170.9
20073 CJK UNIFIED IDEOGRAPH-#20073, IRGKangXi=0080.101, RSKangXi=2.10
20074 CJK UNIFIED IDEOGRAPH-#20074, IRGKangXi=0080.110, RSKangXi=2.11
20075 CJK UNIFIED IDEOGRAPH-#20075, IRGKangXi=0080.111, RSKangXi=2.11
20076 CJK UNIFIED IDEOGRAPH-#20076, IRGKangXi=0080.111, RSKangXi=2.13
20077 CJK UNIFIED IDEOGRAPH-#20077, IRGKangXi=0080.111, RSKangXi=30.11
20078 CJK UNIFIED IDEOGRAPH-#20078, IRGKangXi=0080.111, RSKangXi=2.14
20079 CJK UNIFIED IDEOGRAPH-#20079, IRGKangXi=0080.111, RSKangXi=2.17
2007A CJK UNIFIED IDEOGRAPH-#2007A, IRGKangXi=0080.111, RSKangXi=2.18
2007B CJK UNIFIED IDEOGRAPH-#2007B, IRGKangXi=0080.111, RSKangXi=2.21
2007C CJK UNIFIED IDEOGRAPH-#2007C, IRGKangXi=0080.130, RSKangXi=3.2
2007D CJK UNIFIED IDEOGRAPH-#2007D, IRGKangXi=0080.140, RSKangXi=3.2
2007E CJK UNIFIED IDEOGRAPH-#2007E, IRGKangXi=0080.191, RSKangXi=5.3
2007F CJK UNIFIED IDEOGRAPH-#2007F, IRGKangXi=0081.020, RSKangXi=3.4
20080 CJK UNIFIED IDEOGRAPH-#20080, IRGKangXi=0081.021, RSKangXi=3.4
20081 CJK UNIFIED IDEOGRAPH-#20081, IRGKangXi=0081.021, RSKangXi=3.4
20082 CJK UNIFIED IDEOGRAPH-#20082, IRGKangXi=0081.030, RSKangXi=3.5
20083 CJK UNIFIED IDEOGRAPH-#20083, IRGKangXi=0081.041, RSKangXi=3.9
20084 CJK UNIFIED IDEOGRAPH-#20084, IRGKangXi=0081.050, RSKangXi=3.12
20085 CJK UNIFIED IDEOGRAPH-#20085, IRGKangXi=0081.051, RSKangXi=3.15
20086 CJK UNIFIED IDEOGRAPH-#20086, IRGKangXi=0081.080, RSKangXi=4.1
20087 CJK UNIFIED IDEOGRAPH-#20087, IRGKangXi=0081.110, RSKangXi=4.1
20088 CJK UNIFIED IDEOGRAPH-#20088, IRGKangXi=0081.170, RSKangXi=4.1
20089 CJK UNIFIED IDEOGRAPH-#20089, IRGKangXi=0081.181, RSKangXi=4.1
2008A CJK UNIFIED IDEOGRAPH-#2008A, IRGKangXi=0081.181, RSKangXi=4.1
2008B CJK UNIFIED IDEOGRAPH-#2008B, IRGKangXi=0082.031, RSKangXi=4.2
2008C CJK UNIFIED IDEOGRAPH-#2008C, IRGKangXi=0082.031, RSKangXi=4.2
2008D CJK UNIFIED IDEOGRAPH-#2008D, IRGKangXi=0082.031, RSKangXi=4.2
2008E CJK UNIFIED IDEOGRAPH-#2008E, IRGKangXi=0082.031, RSKangXi=4.2
2008F CJK UNIFIED IDEOGRAPH-#2008F, IRGKangXi=0082.051, RSKangXi=4.3
20090 CJK UNIFIED IDEOGRAPH-#20090, IRGKangXi=0082.051, RSKangXi=4.3
20091 CJK UNIFIED IDEOGRAPH-#20091, IRGKangXi=0082.051, RSKangXi=4.3
20092 CJK UNIFIED IDEOGRAPH-#20092, IRGKangXi=0082.051, RSKangXi=4.3
20093 CJK UNIFIED IDEOGRAPH-#20093, IRGKangXi=0082.051, RSKangXi=4.3
20094 CJK UNIFIED IDEOGRAPH-#20094, IRGKangXi=0082.090, RSKangXi=4.4, Def{to stop}
20095 CJK UNIFIED IDEOGRAPH-#20095, IRGKangXi=0082.120, RSKangXi=4.4
20096 CJK UNIFIED IDEOGRAPH-#20096, IRGKangXi=0082.130, RSKangXi=4.4
20097 CJK UNIFIED IDEOGRAPH-#20097, IRGKangXi=0082.131, RSKangXi=4.4
20098 CJK UNIFIED IDEOGRAPH-#20098, IRGKangXi=0082.131, RSKangXi=4.4
20099 CJK UNIFIED IDEOGRAPH-#20099, IRGKangXi=0082.131, RSKangXi=4.4
2009A CJK UNIFIED IDEOGRAPH-#2009A, IRGKangXi=0082.131, RSKangXi=4.4
2009B CJK UNIFIED IDEOGRAPH-#2009B, IRGKangXi=0082.131, RSKangXi=4.4
2009C CJK UNIFIED IDEOGRAPH-#2009C, IRGKangXi=0082.131, RSKangXi=4.4
2009D CJK UNIFIED IDEOGRAPH-#2009D, IRGKangXi=0082.131, RSKangXi=4.4, Def{every, all; a multitude}
2009E CJK UNIFIED IDEOGRAPH-#2009E, IRGKangXi=0082.131, RSKangXi=4.4
2009F CJK UNIFIED IDEOGRAPH-#2009F, IRGKangXi=0082.131, RSKangXi=4.4
200A0 CJK UNIFIED IDEOGRAPH-#200A0, IRGKangXi=0082.131, RSKangXi=4.4
200A1 CJK UNIFIED IDEOGRAPH-#200A1, IRGKangXi=0082.131, RSKangXi=4.4
200A2 CJK UNIFIED IDEOGRAPH-#200A2, IRGKangXi=0082.140, RSKangXi=4.5, Def{to branch}
200A3 CJK UNIFIED IDEOGRAPH-#200A3, IRGKangXi=0082.160, RSKangXi=4.5
200A4 CJK UNIFIED IDEOGRAPH-#200A4, IRGKangXi=0082.170, RSKangXi=4.5, Def{to store up, to pile up}
200A5 CJK UNIFIED IDEOGRAPH-#200A5, IRGKangXi=0083.010, RSKangXi=4.5
200A6 CJK UNIFIED IDEOGRAPH-#200A6, IRGKangXi=0083.011, RSKangXi=4.5
200A7 CJK UNIFIED IDEOGRAPH-#200A7, IRGKangXi=0083.011, RSKangXi=4.5
200A8 CJK UNIFIED IDEOGRAPH-#200A8, IRGKangXi=0083.011, RSKangXi=137.0
200A9 CJK UNIFIED IDEOGRAPH-#200A9, IRGKangXi=0083.011, RSKangXi=4.5
200AA CJK UNIFIED IDEOGRAPH-#200AA, IRGKangXi=0083.011, RSKangXi=4.5
200AB CJK UNIFIED IDEOGRAPH-#200AB, IRGKangXi=0083.011, RSKangXi=4.5
200AC CJK UNIFIED IDEOGRAPH-#200AC, IRGKangXi=0083.011, RSKangXi=27.4
200AD CJK UNIFIED IDEOGRAPH-#200AD, IRGKangXi=0083.011, RSKangXi=4.5
200AE CJK UNIFIED IDEOGRAPH-#200AE, IRGKangXi=0083.011, RSKangXi=27.4
200AF CJK UNIFIED IDEOGRAPH-#200AF, IRGKangXi=0083.020, RSKangXi=4.6
200B0 CJK UNIFIED IDEOGRAPH-#200B0, IRGKangXi=0083.021, RSKangXi=27.5
200B1 CJK UNIFIED IDEOGRAPH-#200B1, IRGKangXi=0083.021, RSKangXi=81.3
200B2 CJK UNIFIED IDEOGRAPH-#200B2, IRGKangXi=0083.060, RSKangXi=4.7
200B3 CJK UNIFIED IDEOGRAPH-#200B3, IRGKangXi=0083.070, RSKangXi=4.7
200B4 CJK UNIFIED IDEOGRAPH-#200B4, IRGKangXi=0083.071, RSKangXi=4.8
200B5 CJK UNIFIED IDEOGRAPH-#200B5, IRGKangXi=0083.071, RSKangXi=101.3
200B6 CJK UNIFIED IDEOGRAPH-#200B6, IRGKangXi=0083.071, RSKangXi=4.7
200B7 CJK UNIFIED IDEOGRAPH-#200B7, IRGKangXi=0083.080, RSKangXi=4.8
200B8 CJK UNIFIED IDEOGRAPH-#200B8, IRGKangXi=0083.081, RSKangXi=5.8
200B9 CJK UNIFIED IDEOGRAPH-#200B9, IRGKangXi=0083.120, RSKangXi=4.9
200BA CJK UNIFIED IDEOGRAPH-#200BA, IRGKangXi=0083.130, RSKangXi=4.9
200BB CJK UNIFIED IDEOGRAPH-#200BB, IRGKangXi=0083.131, RSKangXi=4.9
200BC CJK UNIFIED IDEOGRAPH-#200BC, IRGKangXi=0083.131, RSKangXi=4.9
200BD CJK UNIFIED IDEOGRAPH-#200BD, IRGKangXi=0083.131, RSKangXi=4.9
200BE CJK UNIFIED IDEOGRAPH-#200BE, IRGKangXi=0083.131, RSKangXi=4.9
200BF CJK UNIFIED IDEOGRAPH-#200BF, IRGKangXi=0083.140, RSKangXi=4.10
200C0 CJK UNIFIED IDEOGRAPH-#200C0, IRGKangXi=0083.141, RSKangXi=4.10
200C1 CJK UNIFIED IDEOGRAPH-#200C1, IRGKangXi=0083.141, RSKangXi=4.10
200C2 CJK UNIFIED IDEOGRAPH-#200C2, IRGKangXi=0083.141, RSKangXi=4.10
200C3 CJK UNIFIED IDEOGRAPH-#200C3, IRGKangXi=0083.141, RSKangXi=4.11
200C4 CJK UNIFIED IDEOGRAPH-#200C4, IRGKangXi=0083.141, RSKangXi=4.11
200C5 CJK UNIFIED IDEOGRAPH-#200C5, IRGKangXi=0083.141, RSKangXi=4.13
200C6 CJK UNIFIED IDEOGRAPH-#200C6, IRGKangXi=0083.141, RSKangXi=4.12
200C7 CJK UNIFIED IDEOGRAPH-#200C7, IRGKangXi=0083.141, RSKangXi=4.14
200C8 CJK UNIFIED IDEOGRAPH-#200C8, IRGKangXi=0083.141, RSKangXi=4.22
200C9 CJK UNIFIED IDEOGRAPH-#200C9, IRGKangXi=0083.160, RSKangXi=5.0
200CA CJK UNIFIED IDEOGRAPH-#200CA, IRGKangXi=0083.171, RSKangXi=5.0
200CB CJK UNIFIED IDEOGRAPH-#200CB, IRGKangXi=0083.171, RSKangXi=5.0
200CC CJK UNIFIED IDEOGRAPH-#200CC, IRGKangXi=0083.171, RSKangXi=5.0
200CD CJK UNIFIED IDEOGRAPH-#200CD, IRGKangXi=0083.171, RSKangXi=5.0
200CE CJK UNIFIED IDEOGRAPH-#200CE, IRGKangXi=0083.171, RSKangXi=5.0
200CF CJK UNIFIED IDEOGRAPH-#200CF, IRGKangXi=0084.010, RSKangXi=5.1
200D0 CJK UNIFIED IDEOGRAPH-#200D0, IRGKangXi=0084.020, RSKangXi=5.1
200D1 CJK UNIFIED IDEOGRAPH-#200D1, IRGKangXi=0084.021, RSKangXi=5.0
200D2 CJK UNIFIED IDEOGRAPH-#200D2, IRGKangXi=0084.051, RSKangXi=5.2
200D3 CJK UNIFIED IDEOGRAPH-#200D3, IRGKangXi=0084.051, RSKangXi=5.2
200D4 CJK UNIFIED IDEOGRAPH-#200D4, IRGKangXi=0084.051, RSKangXi=5.2
200D5 CJK UNIFIED IDEOGRAPH-#200D5, IRGKangXi=0084.060, RSKangXi=5.3
200D6 CJK UNIFIED IDEOGRAPH-#200D6, IRGKangXi=0084.070, RSKangXi=5.3
200D7 CJK UNIFIED IDEOGRAPH-#200D7, IRGKangXi=0084.071, RSKangXi=5.3
200D8 CJK UNIFIED IDEOGRAPH-#200D8, IRGKangXi=0084.071, RSKangXi=5.3
200D9 CJK UNIFIED IDEOGRAPH-#200D9, IRGKangXi=0084.071, RSKangXi=5.3
200DA CJK UNIFIED IDEOGRAPH-#200DA, IRGKangXi=0084.071, RSKangXi=5.3
200DB CJK UNIFIED IDEOGRAPH-#200DB, IRGKangXi=0084.071, RSKangXi=5.3
200DC CJK UNIFIED IDEOGRAPH-#200DC, IRGKangXi=0084.071, RSKangXi=5.3
200DD CJK UNIFIED IDEOGRAPH-#200DD, IRGKangXi=0084.071, RSKangXi=5.3
200DE CJK UNIFIED IDEOGRAPH-#200DE, IRGKangXi=0084.090, RSKangXi=5.4
200DF CJK UNIFIED IDEOGRAPH-#200DF, IRGKangXi=0084.100, RSKangXi=5.4
200E0 CJK UNIFIED IDEOGRAPH-#200E0, IRGKangXi=0084.101, RSKangXi=5.4
200E1 CJK UNIFIED IDEOGRAPH-#200E1, IRGKangXi=0084.101, RSKangXi=5.4
200E2 CJK UNIFIED IDEOGRAPH-#200E2, IRGKangXi=0084.101, RSKangXi=5.4
200E3 CJK UNIFIED IDEOGRAPH-#200E3, IRGKangXi=0084.101, RSKangXi=5.4
200E4 CJK UNIFIED IDEOGRAPH-#200E4, IRGKangXi=0084.130, RSKangXi=5.5
200E5 CJK UNIFIED IDEOGRAPH-#200E5, IRGKangXi=0084.140, RSKangXi=5.5
200E6 CJK UNIFIED IDEOGRAPH-#200E6, IRGKangXi=0084.141, RSKangXi=5.5
200E7 CJK UNIFIED IDEOGRAPH-#200E7, IRGKangXi=0084.141, RSKangXi=5.5
200E8 CJK UNIFIED IDEOGRAPH-#200E8, IRGKangXi=0084.141, RSKangXi=5.5
200E9 CJK UNIFIED IDEOGRAPH-#200E9, IRGKangXi=0084.161, RSKangXi=5.6
200EA CJK UNIFIED IDEOGRAPH-#200EA, IRGKangXi=0084.161, RSKangXi=5.6
200EB CJK UNIFIED IDEOGRAPH-#200EB, IRGKangXi=0084.161, RSKangXi=102.2
200EC CJK UNIFIED IDEOGRAPH-#200EC, IRGKangXi=0084.161, RSKangXi=5.6
200ED CJK UNIFIED IDEOGRAPH-#200ED, IRGKangXi=0084.200, RSKangXi=5.7
200EE CJK UNIFIED IDEOGRAPH-#200EE, IRGKangXi=0084.201, RSKangXi=5.7
200EF CJK UNIFIED IDEOGRAPH-#200EF, IRGKangXi=0084.201, RSKangXi=5.7
200F0 CJK UNIFIED IDEOGRAPH-#200F0, IRGKangXi=0084.201, RSKangXi=101.3
200F1 CJK UNIFIED IDEOGRAPH-#200F1, IRGKangXi=0084.201, RSKangXi=39.5
200F2 CJK UNIFIED IDEOGRAPH-#200F2, IRGKangXi=0084.230, RSKangXi=5.8
200F3 CJK UNIFIED IDEOGRAPH-#200F3, IRGKangXi=0084.240, RSKangXi=5.8
200F4 CJK UNIFIED IDEOGRAPH-#200F4, IRGKangXi=0084.241, RSKangXi=5.8
200F5 CJK UNIFIED IDEOGRAPH-#200F5, IRGKangXi=0084.241, RSKangXi=5.8
200F6 CJK UNIFIED IDEOGRAPH-#200F6, IRGKangXi=0084.241, RSKangXi=5.8
200F7 CJK UNIFIED IDEOGRAPH-#200F7, IRGKangXi=0084.241, RSKangXi=5.8
200F8 CJK UNIFIED IDEOGRAPH-#200F8, IRGKangXi=0084.241, RSKangXi=5.9
200F9 CJK UNIFIED IDEOGRAPH-#200F9, IRGKangXi=0084.241, RSKangXi=5.9
200FA CJK UNIFIED IDEOGRAPH-#200FA, IRGKangXi=0084.241, RSKangXi=5.9
200FB CJK UNIFIED IDEOGRAPH-#200FB, IRGKangXi=0084.241, RSKangXi=5.9
200FC CJK UNIFIED IDEOGRAPH-#200FC, IRGKangXi=0084.290, RSKangXi=5.10
200FD CJK UNIFIED IDEOGRAPH-#200FD, IRGKangXi=0084.300, RSKangXi=5.10
200FE CJK UNIFIED IDEOGRAPH-#200FE, IRGKangXi=0084.320, RSKangXi=5.10
200FF CJK UNIFIED IDEOGRAPH-#200FF, IRGKangXi=0084.321, RSKangXi=5.10
20100 CJK UNIFIED IDEOGRAPH-#20100, IRGKangXi=0084.321, RSKangXi=5.10
20101 CJK UNIFIED IDEOGRAPH-#20101, IRGKangXi=0084.321, RSKangXi=5.10
20102 CJK UNIFIED IDEOGRAPH-#20102, IRGKangXi=0084.321, RSKangXi=5.10
20103 CJK UNIFIED IDEOGRAPH-#20103, IRGKangXi=0085.030, RSKangXi=5.12
20104 CJK UNIFIED IDEOGRAPH-#20104, IRGKangXi=0085.031, RSKangXi=5.12
20105 CJK UNIFIED IDEOGRAPH-#20105, IRGKangXi=0085.040, RSKangXi=5.13
20106 CJK UNIFIED IDEOGRAPH-#20106, IRGKangXi=0085.041, RSKangXi=5.13
20107 CJK UNIFIED IDEOGRAPH-#20107, IRGKangXi=0085.050, RSKangXi=5.13
20108 CJK UNIFIED IDEOGRAPH-#20108, IRGKangXi=0085.060, RSKangXi=5.13
20109 CJK UNIFIED IDEOGRAPH-#20109, IRGKangXi=0085.070, RSKangXi=5.16
2010A CJK UNIFIED IDEOGRAPH-#2010A, IRGKangXi=0085.071, RSKangXi=5.18
2010B CJK UNIFIED IDEOGRAPH-#2010B, IRGKangXi=0085.080, RSKangXi=5.19
2010C CJK UNIFIED IDEOGRAPH-#2010C, IRGKangXi=0085.100, RSKangXi=6.0
2010D CJK UNIFIED IDEOGRAPH-#2010D, IRGKangXi=0085.120, RSKangXi=6.1
2010E CJK UNIFIED IDEOGRAPH-#2010E, IRGKangXi=0085.130, RSKangXi=6.1
2010F CJK UNIFIED IDEOGRAPH-#2010F, IRGKangXi=0085.140, RSKangXi=6.1
20110 CJK UNIFIED IDEOGRAPH-#20110, IRGKangXi=0085.141, RSKangXi=6.1
20111 CJK UNIFIED IDEOGRAPH-#20111, IRGKangXi=0085.150, RSKangXi=6.2
20112 CJK UNIFIED IDEOGRAPH-#20112, IRGKangXi=0085.170, RSKangXi=6.3
20113 CJK UNIFIED IDEOGRAPH-#20113, IRGKangXi=0085.180, RSKangXi=6.3
20114 CJK UNIFIED IDEOGRAPH-#20114, IRGKangXi=0085.190, RSKangXi=6.3
20115 CJK UNIFIED IDEOGRAPH-#20115, IRGKangXi=0085.200, RSKangXi=6.5
20116 CJK UNIFIED IDEOGRAPH-#20116, IRGKangXi=0085.210, RSKangXi=6.6
20117 CJK UNIFIED IDEOGRAPH-#20117, IRGKangXi=0085.220, RSKangXi=6.6
20118 CJK UNIFIED IDEOGRAPH-#20118, IRGKangXi=0085.221, RSKangXi=6.6
20119 CJK UNIFIED IDEOGRAPH-#20119, IRGKangXi=0085.270, RSKangXi=6.7
2011A CJK UNIFIED IDEOGRAPH-#2011A, IRGKangXi=0085.280, RSKangXi=6.10
2011B CJK UNIFIED IDEOGRAPH-#2011B, IRGKangXi=0085.290, RSKangXi=6.11
2011C CJK UNIFIED IDEOGRAPH-#2011C, IRGKangXi=0085.291, RSKangXi=6.14
2011D CJK UNIFIED IDEOGRAPH-#2011D, IRGKangXi=0085.300, RSKangXi=6.15
2011E CJK UNIFIED IDEOGRAPH-#2011E, IRGKangXi=0086.030, RSKangXi=7.0
2011F CJK UNIFIED IDEOGRAPH-#2011F, IRGKangXi=0086.040, RSKangXi=7.0
20120 CJK UNIFIED IDEOGRAPH-#20120, IRGKangXi=0086.041, RSKangXi=7.0
20121 CJK UNIFIED IDEOGRAPH-#20121, IRGKangXi=0087.020, RSKangXi=7.2
20122 CJK UNIFIED IDEOGRAPH-#20122, IRGKangXi=0087.050, RSKangXi=7.4
20123 CJK UNIFIED IDEOGRAPH-#20123, IRGKangXi=0087.060, RSKangXi=7.4
20124 CJK UNIFIED IDEOGRAPH-#20124, IRGKangXi=0087.080, RSKangXi=7.4
20125 CJK UNIFIED IDEOGRAPH-#20125, IRGKangXi=0087.081, RSKangXi=7.4
20126 CJK UNIFIED IDEOGRAPH-#20126, IRGKangXi=0087.081, RSKangXi=7.4
20127 CJK UNIFIED IDEOGRAPH-#20127, IRGKangXi=0087.081, RSKangXi=7.4
20128 CJK UNIFIED IDEOGRAPH-#20128, IRGKangXi=0087.110, RSKangXi=7.5
20129 CJK UNIFIED IDEOGRAPH-#20129, IRGKangXi=0087.111, RSKangXi=7.5
2012A CJK UNIFIED IDEOGRAPH-#2012A, IRGKangXi=0087.111, RSKangXi=7.5
2012B CJK UNIFIED IDEOGRAPH-#2012B, IRGKangXi=0087.141, RSKangXi=7.6
2012C CJK UNIFIED IDEOGRAPH-#2012C, IRGKangXi=0087.141, RSKangXi=7.6
2012D CJK UNIFIED IDEOGRAPH-#2012D, IRGKangXi=0087.141, RSKangXi=7.6
2012E CJK UNIFIED IDEOGRAPH-#2012E, IRGKangXi=0087.141, RSKangXi=7.6
2012F CJK UNIFIED IDEOGRAPH-#2012F, IRGKangXi=0087.141, RSKangXi=7.6
20130 CJK UNIFIED IDEOGRAPH-#20130, IRGKangXi=0087.150, RSKangXi=7.7
20131 CJK UNIFIED IDEOGRAPH-#20131, IRGKangXi=0087.160, RSKangXi=7.7
20132 CJK UNIFIED IDEOGRAPH-#20132, IRGKangXi=0087.161, RSKangXi=7.7
20133 CJK UNIFIED IDEOGRAPH-#20133, IRGKangXi=0087.161, RSKangXi=7.7
20134 CJK UNIFIED IDEOGRAPH-#20134, IRGKangXi=0087.161, RSKangXi=57.6
20135 CJK UNIFIED IDEOGRAPH-#20135, IRGKangXi=0087.170, RSKangXi=7.8
20136 CJK UNIFIED IDEOGRAPH-#20136, IRGKangXi=0087.171, RSKangXi=7.8
20137 CJK UNIFIED IDEOGRAPH-#20137, IRGKangXi=0087.171, RSKangXi=7.8
20138 CJK UNIFIED IDEOGRAPH-#20138, IRGKangXi=0087.171, RSKangXi=7.8
20139 CJK UNIFIED IDEOGRAPH-#20139, IRGKangXi=0087.180, RSKangXi=7.9
2013A CJK UNIFIED IDEOGRAPH-#2013A, IRGKangXi=0087.181, RSKangXi=7.9
2013B CJK UNIFIED IDEOGRAPH-#2013B, IRGKangXi=0087.181, RSKangXi=7.10
2013C CJK UNIFIED IDEOGRAPH-#2013C, IRGKangXi=0087.181, RSKangXi=7.11
2013D CJK UNIFIED IDEOGRAPH-#2013D, IRGKangXi=0087.181, RSKangXi=7.11
2013E CJK UNIFIED IDEOGRAPH-#2013E, IRGKangXi=0087.181, RSKangXi=7.11
2013F CJK UNIFIED IDEOGRAPH-#2013F, IRGKangXi=0088.010, RSKangXi=7.12
20140 CJK UNIFIED IDEOGRAPH-#20140, IRGKangXi=0088.011, RSKangXi=7.13
20141 CJK UNIFIED IDEOGRAPH-#20141, IRGKangXi=0088.051, RSKangXi=8.2
20142 CJK UNIFIED IDEOGRAPH-#20142, IRGKangXi=0088.051, RSKangXi=8.3
20143 CJK UNIFIED IDEOGRAPH-#20143, IRGKangXi=0088.110, RSKangXi=8.4
20144 CJK UNIFIED IDEOGRAPH-#20144, IRGKangXi=0088.111, RSKangXi=8.4
20145 CJK UNIFIED IDEOGRAPH-#20145, IRGKangXi=0088.111, RSKangXi=8.4
20146 CJK UNIFIED IDEOGRAPH-#20146, IRGKangXi=0088.111, RSKangXi=8.4
20147 CJK UNIFIED IDEOGRAPH-#20147, IRGKangXi=0088.111, RSKangXi=8.4
20148 CJK UNIFIED IDEOGRAPH-#20148, IRGKangXi=0088.160, RSKangXi=8.5
20149 CJK UNIFIED IDEOGRAPH-#20149, IRGKangXi=0088.161, RSKangXi=8.5
2014A CJK UNIFIED IDEOGRAPH-#2014A, IRGKangXi=0088.161, RSKangXi=8.5
2014B CJK UNIFIED IDEOGRAPH-#2014B, IRGKangXi=0088.161, RSKangXi=8.5
2014C CJK UNIFIED IDEOGRAPH-#2014C, IRGKangXi=0089.020, RSKangXi=8.6
2014D CJK UNIFIED IDEOGRAPH-#2014D, IRGKangXi=0089.021, RSKangXi=8.6
2014E CJK UNIFIED IDEOGRAPH-#2014E, IRGKangXi=0089.021, RSKangXi=8.6
2014F CJK UNIFIED IDEOGRAPH-#2014F, IRGKangXi=0089.021, RSKangXi=8.6
20150 CJK UNIFIED IDEOGRAPH-#20150, IRGKangXi=0089.021, RSKangXi=8.6
20151 CJK UNIFIED IDEOGRAPH-#20151, IRGKangXi=0089.021, RSKangXi=8.6
20152 CJK UNIFIED IDEOGRAPH-#20152, IRGKangXi=0089.021, RSKangXi=8.6
20153 CJK UNIFIED IDEOGRAPH-#20153, IRGKangXi=0089.060, RSKangXi=8.7
20154 CJK UNIFIED IDEOGRAPH-#20154, IRGKangXi=0089.080, RSKangXi=8.7
20155 CJK UNIFIED IDEOGRAPH-#20155, IRGKangXi=0089.081, RSKangXi=8.7
20156 CJK UNIFIED IDEOGRAPH-#20156, IRGKangXi=0089.100, RSKangXi=8.8
20157 CJK UNIFIED IDEOGRAPH-#20157, IRGKangXi=0089.101, RSKangXi=36.7
20158 CJK UNIFIED IDEOGRAPH-#20158, IRGKangXi=0089.101, RSKangXi=8.8
20159 CJK UNIFIED IDEOGRAPH-#20159, IRGKangXi=0089.101, RSKangXi=8.8
2015A CJK UNIFIED IDEOGRAPH-#2015A, IRGKangXi=0089.101, RSKangXi=8.8
2015B CJK UNIFIED IDEOGRAPH-#2015B, IRGKangXi=0089.101, RSKangXi=8.8
2015C CJK UNIFIED IDEOGRAPH-#2015C, IRGKangXi=0089.101, RSKangXi=8.8
2015D CJK UNIFIED IDEOGRAPH-#2015D, IRGKangXi=0089.101, RSKangXi=8.8
2015E CJK UNIFIED IDEOGRAPH-#2015E, IRGKangXi=0089.110, RSKangXi=8.9
2015F CJK UNIFIED IDEOGRAPH-#2015F, IRGKangXi=0089.120, RSKangXi=8.9
20160 CJK UNIFIED IDEOGRAPH-#20160, IRGKangXi=0089.130, RSKangXi=8.9
20161 CJK UNIFIED IDEOGRAPH-#20161, IRGKangXi=0089.140, RSKangXi=8.9
20162 CJK UNIFIED IDEOGRAPH-#20162, IRGKangXi=0089.141, RSKangXi=8.9
20163 CJK UNIFIED IDEOGRAPH-#20163, IRGKangXi=0089.141, RSKangXi=8.9
20164 CJK UNIFIED IDEOGRAPH-#20164, IRGKangXi=0089.141, RSKangXi=8.9
20165 CJK UNIFIED IDEOGRAPH-#20165, IRGKangXi=0089.141, RSKangXi=8.9
20166 CJK UNIFIED IDEOGRAPH-#20166, IRGKangXi=0089.141, RSKangXi=8.9
20167 CJK UNIFIED IDEOGRAPH-#20167, IRGKangXi=0089.141, RSKangXi=8.9
20168 CJK UNIFIED IDEOGRAPH-#20168, IRGKangXi=0089.141, RSKangXi=8.10
20169 CJK UNIFIED IDEOGRAPH-#20169, IRGKangXi=0089.150, RSKangXi=8.10
2016A CJK UNIFIED IDEOGRAPH-#2016A, IRGKangXi=0089.160, RSKangXi=8.10
2016B CJK UNIFIED IDEOGRAPH-#2016B, IRGKangXi=0089.170, RSKangXi=8.10
2016C CJK UNIFIED IDEOGRAPH-#2016C, IRGKangXi=0089.180, RSKangXi=8.10
2016D CJK UNIFIED IDEOGRAPH-#2016D, IRGKangXi=0089.191, RSKangXi=8.10
2016E CJK UNIFIED IDEOGRAPH-#2016E, IRGKangXi=0089.191, RSKangXi=8.10
2016F CJK UNIFIED IDEOGRAPH-#2016F, IRGKangXi=0089.191, RSKangXi=8.10
20170 CJK UNIFIED IDEOGRAPH-#20170, IRGKangXi=0089.191, RSKangXi=111.7
20171 CJK UNIFIED IDEOGRAPH-#20171, IRGKangXi=0089.191, RSKangXi=36.9
20172 CJK UNIFIED IDEOGRAPH-#20172, IRGKangXi=0089.191, RSKangXi=8.10
20173 CJK UNIFIED IDEOGRAPH-#20173, IRGKangXi=0089.201, RSKangXi=8.11
20174 CJK UNIFIED IDEOGRAPH-#20174, IRGKangXi=0089.201, RSKangXi=8.11
20175 CJK UNIFIED IDEOGRAPH-#20175, IRGKangXi=0089.201, RSKangXi=8.11
20176 CJK UNIFIED IDEOGRAPH-#20176, IRGKangXi=0089.201, RSKangXi=8.11
20177 CJK UNIFIED IDEOGRAPH-#20177, IRGKangXi=0089.201, RSKangXi=8.11
20178 CJK UNIFIED IDEOGRAPH-#20178, IRGKangXi=0089.201, RSKangXi=8.11
20179 CJK UNIFIED IDEOGRAPH-#20179, IRGKangXi=0089.201, RSKangXi=52.10
2017A CJK UNIFIED IDEOGRAPH-#2017A, IRGKangXi=0089.201, RSKangXi=8.11
2017B CJK UNIFIED IDEOGRAPH-#2017B, IRGKangXi=0089.201, RSKangXi=8.11
2017C CJK UNIFIED IDEOGRAPH-#2017C, IRGKangXi=0089.201, RSKangXi=8.11
2017D CJK UNIFIED IDEOGRAPH-#2017D, IRGKangXi=0089.201, RSKangXi=42.10
2017E CJK UNIFIED IDEOGRAPH-#2017E, IRGKangXi=0089.201, RSKangXi=8.12
2017F CJK UNIFIED IDEOGRAPH-#2017F, IRGKangXi=0089.201, RSKangXi=8.12
20180 CJK UNIFIED IDEOGRAPH-#20180, IRGKangXi=0089.201, RSKangXi=8.11
20181 CJK UNIFIED IDEOGRAPH-#20181, IRGKangXi=0089.210, RSKangXi=8.13
20182 CJK UNIFIED IDEOGRAPH-#20182, IRGKangXi=0089.220, RSKangXi=8.13
20183 CJK UNIFIED IDEOGRAPH-#20183, IRGKangXi=0089.221, RSKangXi=8.13
20184 CJK UNIFIED IDEOGRAPH-#20184, IRGKangXi=0089.221, RSKangXi=8.13
20185 CJK UNIFIED IDEOGRAPH-#20185, IRGKangXi=0089.221, RSKangXi=8.13
20186 CJK UNIFIED IDEOGRAPH-#20186, IRGKangXi=0089.221, RSKangXi=8.13
20187 CJK UNIFIED IDEOGRAPH-#20187, IRGKangXi=0089.221, RSKangXi=8.13
20188 CJK UNIFIED IDEOGRAPH-#20188, IRGKangXi=0089.221, RSKangXi=8.13
20189 CJK UNIFIED IDEOGRAPH-#20189, IRGKangXi=0089.221, RSKangXi=8.13
2018A CJK UNIFIED IDEOGRAPH-#2018A, IRGKangXi=0089.221, RSKangXi=30.12
2018B CJK UNIFIED IDEOGRAPH-#2018B, IRGKangXi=0089.230, RSKangXi=8.14
2018C CJK UNIFIED IDEOGRAPH-#2018C, IRGKangXi=0089.240, RSKangXi=8.14, Def{(variant of U+5EB8 庸) usual, common; to use}
2018D CJK UNIFIED IDEOGRAPH-#2018D, IRGKangXi=0089.241, RSKangXi=8.14
2018E CJK UNIFIED IDEOGRAPH-#2018E, IRGKangXi=0089.241, RSKangXi=8.14
2018F CJK UNIFIED IDEOGRAPH-#2018F, IRGKangXi=0089.241, RSKangXi=8.14
20190 CJK UNIFIED IDEOGRAPH-#20190, IRGKangXi=0089.241, RSKangXi=8.14
20191 CJK UNIFIED IDEOGRAPH-#20191, IRGKangXi=0089.241, RSKangXi=8.14
20192 CJK UNIFIED IDEOGRAPH-#20192, IRGKangXi=0089.241, RSKangXi=8.14
20193 CJK UNIFIED IDEOGRAPH-#20193, IRGKangXi=0089.241, RSKangXi=36.13
20194 CJK UNIFIED IDEOGRAPH-#20194, IRGKangXi=0089.241, RSKangXi=8.14
20195 CJK UNIFIED IDEOGRAPH-#20195, IRGKangXi=0089.241, RSKangXi=36.13
20196 CJK UNIFIED IDEOGRAPH-#20196, IRGKangXi=0089.241, RSKangXi=8.14
20197 CJK UNIFIED IDEOGRAPH-#20197, IRGKangXi=0089.241, RSKangXi=8.14
20198 CJK UNIFIED IDEOGRAPH-#20198, IRGKangXi=0089.241, RSKangXi=8.14
20199 CJK UNIFIED IDEOGRAPH-#20199, IRGKangXi=0089.241, RSKangXi=36.14
2019A CJK UNIFIED IDEOGRAPH-#2019A, IRGKangXi=0089.241, RSKangXi=8.16
2019B CJK UNIFIED IDEOGRAPH-#2019B, IRGKangXi=0089.241, RSKangXi=72.14
2019C CJK UNIFIED IDEOGRAPH-#2019C, IRGKangXi=0089.241, RSKangXi=210.4
2019D CJK UNIFIED IDEOGRAPH-#2019D, IRGKangXi=0089.250, RSKangXi=8.17
2019E CJK UNIFIED IDEOGRAPH-#2019E, IRGKangXi=0090.011, RSKangXi=8.19
2019F CJK UNIFIED IDEOGRAPH-#2019F, IRGKangXi=0090.011, RSKangXi=8.22
201A0 CJK UNIFIED IDEOGRAPH-#201A0, IRGKangXi=0090.011, RSKangXi=8.26
201A1 CJK UNIFIED IDEOGRAPH-#201A1, IRGKangXi=0090.011, RSKangXi=8.27
201A2 CJK UNIFIED IDEOGRAPH-#201A2, IRGKangXi=0091.011, RSKangXi=9.0
201A3 CJK UNIFIED IDEOGRAPH-#201A3, IRGKangXi=0091.040, RSKangXi=9.1
201A4 CJK UNIFIED IDEOGRAPH-#201A4, IRGKangXi=0091.050, RSKangXi=9.1
201A5 CJK UNIFIED IDEOGRAPH-#201A5, IRGKangXi=0091.051, RSKangXi=9.1
201A6 CJK UNIFIED IDEOGRAPH-#201A6, IRGKangXi=0092.040, RSKangXi=9.2
201A7 CJK UNIFIED IDEOGRAPH-#201A7, IRGKangXi=0092.051, RSKangXi=9.2
201A8 CJK UNIFIED IDEOGRAPH-#201A8, IRGKangXi=0092.051, RSKangXi=9.2
201A9 CJK UNIFIED IDEOGRAPH-#201A9, IRGKangXi=0093.090, RSKangXi=9.3, Def{(Cant.) to play}
201AA CJK UNIFIED IDEOGRAPH-#201AA, IRGKangXi=0094.040, RSKangXi=9.3
201AB CJK UNIFIED IDEOGRAPH-#201AB, IRGKangXi=0094.051, RSKangXi=9.3
201AC CJK UNIFIED IDEOGRAPH-#201AC, IRGKangXi=0094.051, RSKangXi=9.3
201AD CJK UNIFIED IDEOGRAPH-#201AD, IRGKangXi=0094.051, RSKangXi=9.3
201AE CJK UNIFIED IDEOGRAPH-#201AE, IRGKangXi=0094.051, RSKangXi=19.3
201AF CJK UNIFIED IDEOGRAPH-#201AF, IRGKangXi=0094.051, RSKangXi=9.3
201B0 CJK UNIFIED IDEOGRAPH-#201B0, IRGKangXi=0094.051, RSKangXi=9.3
201B1 CJK UNIFIED IDEOGRAPH-#201B1, IRGKangXi=0094.051, RSKangXi=24.3
201B2 CJK UNIFIED IDEOGRAPH-#201B2, IRGKangXi=0094.051, RSKangXi=53.2
201B3 CJK UNIFIED IDEOGRAPH-#201B3, IRGKangXi=0094.051, RSKangXi=9.3
201B4 CJK UNIFIED IDEOGRAPH-#201B4, IRGKangXi=0094.130, RSKangXi=9.4
201B5 CJK UNIFIED IDEOGRAPH-#201B5, IRGKangXi=0094.150, RSKangXi=9.4
201B6 CJK UNIFIED IDEOGRAPH-#201B6, IRGKangXi=0094.190, RSKangXi=9.4
201B7 CJK UNIFIED IDEOGRAPH-#201B7, IRGKangXi=0095.060, RSKangXi=9.4
201B8 CJK UNIFIED IDEOGRAPH-#201B8, IRGKangXi=0096.030, RSKangXi=9.4
201B9 CJK UNIFIED IDEOGRAPH-#201B9, IRGKangXi=0096.040, RSKangXi=9.4
201BA CJK UNIFIED IDEOGRAPH-#201BA, IRGKangXi=0096.050, RSKangXi=9.4
201BB CJK UNIFIED IDEOGRAPH-#201BB, IRGKangXi=0096.070, RSKangXi=9.4
201BC CJK UNIFIED IDEOGRAPH-#201BC, IRGKangXi=0096.120, RSKangXi=9.4
201BD CJK UNIFIED IDEOGRAPH-#201BD, IRGKangXi=0096.121, RSKangXi=9.4
201BE CJK UNIFIED IDEOGRAPH-#201BE, IRGKangXi=0096.121, RSKangXi=9.4
201BF CJK UNIFIED IDEOGRAPH-#201BF, IRGKangXi=0096.121, RSKangXi=9.4
201C0 CJK UNIFIED IDEOGRAPH-#201C0, IRGKangXi=0096.121, RSKangXi=9.4
201C1 CJK UNIFIED IDEOGRAPH-#201C1, IRGKangXi=0096.121, RSKangXi=9.4
201C2 CJK UNIFIED IDEOGRAPH-#201C2, IRGKangXi=0096.121, RSKangXi=9.4
201C3 CJK UNIFIED IDEOGRAPH-#201C3, IRGKangXi=0096.121, RSKangXi=9.4
201C4 CJK UNIFIED IDEOGRAPH-#201C4, IRGKangXi=0096.121, RSKangXi=9.4
201C5 CJK UNIFIED IDEOGRAPH-#201C5, IRGKangXi=0096.121, RSKangXi=9.4
201C6 CJK UNIFIED IDEOGRAPH-#201C6, IRGKangXi=0096.121, RSKangXi=9.4
201C7 CJK UNIFIED IDEOGRAPH-#201C7, IRGKangXi=0096.121, RSKangXi=9.4
201C8 CJK UNIFIED IDEOGRAPH-#201C8, IRGKangXi=0096.121, RSKangXi=9.4
201C9 CJK UNIFIED IDEOGRAPH-#201C9, IRGKangXi=0096.121, RSKangXi=9.4
201CA CJK UNIFIED IDEOGRAPH-#201CA, IRGKangXi=0096.121, RSKangXi=9.4
201CB CJK UNIFIED IDEOGRAPH-#201CB, IRGKangXi=0096.121, RSKangXi=9.4
201CC CJK UNIFIED IDEOGRAPH-#201CC, IRGKangXi=0096.121, RSKangXi=9.4
201CD CJK UNIFIED IDEOGRAPH-#201CD, IRGKangXi=0096.121, RSKangXi=9.4
201CE CJK UNIFIED IDEOGRAPH-#201CE, IRGKangXi=0096.121, RSKangXi=9.4
201CF CJK UNIFIED IDEOGRAPH-#201CF, IRGKangXi=0096.121, RSKangXi=9.4
201D0 CJK UNIFIED IDEOGRAPH-#201D0, IRGKangXi=0096.121, RSKangXi=9.4
201D1 CJK UNIFIED IDEOGRAPH-#201D1, IRGKangXi=0096.121, RSKangXi=9.4
201D2 CJK UNIFIED IDEOGRAPH-#201D2, IRGKangXi=0096.121, RSKangXi=11.4
201D3 CJK UNIFIED IDEOGRAPH-#201D3, IRGKangXi=0096.121, RSKangXi=9.4
201D4 CJK UNIFIED IDEOGRAPH-#201D4, IRGKangXi=0096.121, RSKangXi=9.4
201D5 CJK UNIFIED IDEOGRAPH-#201D5, IRGKangXi=0096.121, RSKangXi=9.4
201D6 CJK UNIFIED IDEOGRAPH-#201D6, IRGKangXi=0096.121, RSKangXi=9.5
201D7 CJK UNIFIED IDEOGRAPH-#201D7, IRGKangXi=0096.180, RSKangXi=9.5
201D8 CJK UNIFIED IDEOGRAPH-#201D8, IRGKangXi=0097.010, RSKangXi=9.5
201D9 CJK UNIFIED IDEOGRAPH-#201D9, IRGKangXi=0099.130, RSKangXi=9.5
201DA CJK UNIFIED IDEOGRAPH-#201DA, IRGKangXi=0099.140, RSKangXi=9.5
201DB CJK UNIFIED IDEOGRAPH-#201DB, IRGKangXi=0100.010, RSKangXi=9.5
201DC CJK UNIFIED IDEOGRAPH-#201DC, IRGKangXi=0100.020, RSKangXi=9.5
201DD CJK UNIFIED IDEOGRAPH-#201DD, IRGKangXi=0100.021, RSKangXi=9.5
201DE CJK UNIFIED IDEOGRAPH-#201DE, IRGKangXi=0100.021, RSKangXi=9.5
201DF CJK UNIFIED IDEOGRAPH-#201DF, IRGKangXi=0100.021, RSKangXi=9.5
201E0 CJK UNIFIED IDEOGRAPH-#201E0, IRGKangXi=0100.021, RSKangXi=9.5
201E1 CJK UNIFIED IDEOGRAPH-#201E1, IRGKangXi=0100.021, RSKangXi=9.5
201E2 CJK UNIFIED IDEOGRAPH-#201E2, IRGKangXi=0100.021, RSKangXi=9.5
201E3 CJK UNIFIED IDEOGRAPH-#201E3, IRGKangXi=0100.021, RSKangXi=9.5
201E4 CJK UNIFIED IDEOGRAPH-#201E4, IRGKangXi=0100.021, RSKangXi=9.5
201E5 CJK UNIFIED IDEOGRAPH-#201E5, IRGKangXi=0100.021, RSKangXi=9.5
201E6 CJK UNIFIED IDEOGRAPH-#201E6, IRGKangXi=0100.021, RSKangXi=9.5
201E7 CJK UNIFIED IDEOGRAPH-#201E7, IRGKangXi=0100.021, RSKangXi=9.5
201E8 CJK UNIFIED IDEOGRAPH-#201E8, IRGKangXi=0100.021, RSKangXi=9.5
201E9 CJK UNIFIED IDEOGRAPH-#201E9, IRGKangXi=0100.021, RSKangXi=9.5
201EA CJK UNIFIED IDEOGRAPH-#201EA, IRGKangXi=0100.021, RSKangXi=9.5
201EB CJK UNIFIED IDEOGRAPH-#201EB, IRGKangXi=0100.021, RSKangXi=9.5
201EC CJK UNIFIED IDEOGRAPH-#201EC, IRGKangXi=0100.021, RSKangXi=9.5
201ED CJK UNIFIED IDEOGRAPH-#201ED, IRGKangXi=0100.021, RSKangXi=9.5
201EE CJK UNIFIED IDEOGRAPH-#201EE, IRGKangXi=0100.021, RSKangXi=9.5
201EF CJK UNIFIED IDEOGRAPH-#201EF, IRGKangXi=0100.021, RSKangXi=9.5
201F0 CJK UNIFIED IDEOGRAPH-#201F0, IRGKangXi=0100.021, RSKangXi=9.5
201F1 CJK UNIFIED IDEOGRAPH-#201F1, IRGKangXi=0100.021, RSKangXi=9.5
201F2 CJK UNIFIED IDEOGRAPH-#201F2, IRGKangXi=0100.021, RSKangXi=9.5
201F3 CJK UNIFIED IDEOGRAPH-#201F3, IRGKangXi=0100.021, RSKangXi=9.5
201F4 CJK UNIFIED IDEOGRAPH-#201F4, IRGKangXi=0100.021, RSKangXi=9.5
201F5 CJK UNIFIED IDEOGRAPH-#201F5, IRGKangXi=0100.021, RSKangXi=9.5
201F6 CJK UNIFIED IDEOGRAPH-#201F6, IRGKangXi=0100.021, RSKangXi=9.5
201F7 CJK UNIFIED IDEOGRAPH-#201F7, IRGKangXi=0100.021, RSKangXi=9.5
201F8 CJK UNIFIED IDEOGRAPH-#201F8, IRGKangXi=0100.021, RSKangXi=9.5
201F9 CJK UNIFIED IDEOGRAPH-#201F9, IRGKangXi=0100.021, RSKangXi=9.5
201FA CJK UNIFIED IDEOGRAPH-#201FA, IRGKangXi=0100.021, RSKangXi=9.5
201FB CJK UNIFIED IDEOGRAPH-#201FB, IRGKangXi=0100.021, RSKangXi=9.5
201FC CJK UNIFIED IDEOGRAPH-#201FC, IRGKangXi=0100.021, RSKangXi=9.5
201FD CJK UNIFIED IDEOGRAPH-#201FD, IRGKangXi=0100.021, RSKangXi=9.5
201FE CJK UNIFIED IDEOGRAPH-#201FE, IRGKangXi=0100.021, RSKangXi=9.5
201FF CJK UNIFIED IDEOGRAPH-#201FF, IRGKangXi=0100.021, RSKangXi=9.5
20200 CJK UNIFIED IDEOGRAPH-#20200, IRGKangXi=0100.021, RSKangXi=9.5
20201 CJK UNIFIED IDEOGRAPH-#20201, IRGKangXi=0100.021, RSKangXi=9.5
20202 CJK UNIFIED IDEOGRAPH-#20202, IRGKangXi=0100.021, RSKangXi=30.4
20203 CJK UNIFIED IDEOGRAPH-#20203, IRGKangXi=0100.030, RSKangXi=9.6
20204 CJK UNIFIED IDEOGRAPH-#20204, IRGKangXi=0100.070, RSKangXi=9.6
20205 CJK UNIFIED IDEOGRAPH-#20205, IRGKangXi=0100.110, RSKangXi=9.6
20206 CJK UNIFIED IDEOGRAPH-#20206, IRGKangXi=0100.160, RSKangXi=9.6
20207 CJK UNIFIED IDEOGRAPH-#20207, IRGKangXi=0100.190, RSKangXi=9.6
20208 CJK UNIFIED IDEOGRAPH-#20208, IRGKangXi=0100.280, RSKangXi=9.6
20209 CJK UNIFIED IDEOGRAPH-#20209, IRGKangXi=0101.130, RSKangXi=9.6
2020A CJK UNIFIED IDEOGRAPH-#2020A, IRGKangXi=0102.010, RSKangXi=9.6
2020B CJK UNIFIED IDEOGRAPH-#2020B, IRGKangXi=0102.200, RSKangXi=9.6
2020C CJK UNIFIED IDEOGRAPH-#2020C, IRGKangXi=0102.220, RSKangXi=9.6
2020D CJK UNIFIED IDEOGRAPH-#2020D, IRGKangXi=0102.240, RSKangXi=9.6
2020E CJK UNIFIED IDEOGRAPH-#2020E, IRGKangXi=0102.260, RSKangXi=9.6
2020F CJK UNIFIED IDEOGRAPH-#2020F, IRGKangXi=0102.270, RSKangXi=9.6
20210 CJK UNIFIED IDEOGRAPH-#20210, IRGKangXi=0102.280, RSKangXi=9.6
20211 CJK UNIFIED IDEOGRAPH-#20211, IRGKangXi=0102.290, RSKangXi=9.6
20212 CJK UNIFIED IDEOGRAPH-#20212, IRGKangXi=0102.291, RSKangXi=9.6
20213 CJK UNIFIED IDEOGRAPH-#20213, IRGKangXi=0102.291, RSKangXi=9.6
20214 CJK UNIFIED IDEOGRAPH-#20214, IRGKangXi=0102.291, RSKangXi=9.6
20215 CJK UNIFIED IDEOGRAPH-#20215, IRGKangXi=0102.291, RSKangXi=9.6
20216 CJK UNIFIED IDEOGRAPH-#20216, IRGKangXi=0102.291, RSKangXi=9.6
20217 CJK UNIFIED IDEOGRAPH-#20217, IRGKangXi=0102.291, RSKangXi=9.6
20218 CJK UNIFIED IDEOGRAPH-#20218, IRGKangXi=0102.291, RSKangXi=9.6
20219 CJK UNIFIED IDEOGRAPH-#20219, IRGKangXi=0102.291, RSKangXi=9.6
2021A CJK UNIFIED IDEOGRAPH-#2021A, IRGKangXi=0102.291, RSKangXi=9.6
2021B CJK UNIFIED IDEOGRAPH-#2021B, IRGKangXi=0102.291, RSKangXi=9.6
2021C CJK UNIFIED IDEOGRAPH-#2021C, IRGKangXi=0102.291, RSKangXi=9.6
2021D CJK UNIFIED IDEOGRAPH-#2021D, IRGKangXi=0102.291, RSKangXi=9.6
2021E CJK UNIFIED IDEOGRAPH-#2021E, IRGKangXi=0102.291, RSKangXi=9.6
2021F CJK UNIFIED IDEOGRAPH-#2021F, IRGKangXi=0102.291, RSKangXi=9.6
20220 CJK UNIFIED IDEOGRAPH-#20220, IRGKangXi=0102.291, RSKangXi=9.6
20221 CJK UNIFIED IDEOGRAPH-#20221, IRGKangXi=0102.291, RSKangXi=9.6
20222 CJK UNIFIED IDEOGRAPH-#20222, IRGKangXi=0102.291, RSKangXi=9.6
20223 CJK UNIFIED IDEOGRAPH-#20223, IRGKangXi=0102.291, RSKangXi=9.6
20224 CJK UNIFIED IDEOGRAPH-#20224, IRGKangXi=0102.291, RSKangXi=42.5
20225 CJK UNIFIED IDEOGRAPH-#20225, IRGKangXi=0102.291, RSKangXi=9.6
20226 CJK UNIFIED IDEOGRAPH-#20226, IRGKangXi=0102.291, RSKangXi=9.6
20227 CJK UNIFIED IDEOGRAPH-#20227, IRGKangXi=0102.291, RSKangXi=9.6
20228 CJK UNIFIED IDEOGRAPH-#20228, IRGKangXi=0102.291, RSKangXi=9.6
20229 CJK UNIFIED IDEOGRAPH-#20229, IRGKangXi=0102.291, RSKangXi=9.6
2022A CJK UNIFIED IDEOGRAPH-#2022A, IRGKangXi=0102.291, RSKangXi=9.6
2022B CJK UNIFIED IDEOGRAPH-#2022B, IRGKangXi=0102.291, RSKangXi=9.6
2022C CJK UNIFIED IDEOGRAPH-#2022C, IRGKangXi=0102.291, RSKangXi=9.6
2022D CJK UNIFIED IDEOGRAPH-#2022D, IRGKangXi=0103.060, RSKangXi=9.7
2022E CJK UNIFIED IDEOGRAPH-#2022E, IRGKangXi=0103.100, RSKangXi=9.7
2022F CJK UNIFIED IDEOGRAPH-#2022F, IRGKangXi=0103.130, RSKangXi=9.7
20230 CJK UNIFIED IDEOGRAPH-#20230, IRGKangXi=0103.150, RSKangXi=9.7
20231 CJK UNIFIED IDEOGRAPH-#20231, IRGKangXi=0103.160, RSKangXi=9.7
20232 CJK UNIFIED IDEOGRAPH-#20232, IRGKangXi=0103.300, RSKangXi=9.7
20233 CJK UNIFIED IDEOGRAPH-#20233, IRGKangXi=0104.020, RSKangXi=9.7
20234 CJK UNIFIED IDEOGRAPH-#20234, IRGKangXi=0104.070, RSKangXi=9.7
20235 CJK UNIFIED IDEOGRAPH-#20235, IRGKangXi=0104.080, RSKangXi=9.7
20236 CJK UNIFIED IDEOGRAPH-#20236, IRGKangXi=0104.170, RSKangXi=9.7
20237 CJK UNIFIED IDEOGRAPH-#20237, IRGKangXi=0104.230, RSKangXi=9.7
20238 CJK UNIFIED IDEOGRAPH-#20238, IRGKangXi=0105.020, RSKangXi=9.7
20239 CJK UNIFIED IDEOGRAPH-#20239, IRGKangXi=0105.030, RSKangXi=9.7
2023A CJK UNIFIED IDEOGRAPH-#2023A, IRGKangXi=0105.040, RSKangXi=9.7
2023B CJK UNIFIED IDEOGRAPH-#2023B, IRGKangXi=0105.110, RSKangXi=9.7
2023C CJK UNIFIED IDEOGRAPH-#2023C, IRGKangXi=0106.010, RSKangXi=9.7
2023D CJK UNIFIED IDEOGRAPH-#2023D, IRGKangXi=0106.020, RSKangXi=9.7
2023E CJK UNIFIED IDEOGRAPH-#2023E, IRGKangXi=0106.030, RSKangXi=9.7
2023F CJK UNIFIED IDEOGRAPH-#2023F, IRGKangXi=0106.040, RSKangXi=9.7
20240 CJK UNIFIED IDEOGRAPH-#20240, IRGKangXi=0106.041, RSKangXi=9.7
20241 CJK UNIFIED IDEOGRAPH-#20241, IRGKangXi=0106.041, RSKangXi=9.7
20242 CJK UNIFIED IDEOGRAPH-#20242, IRGKangXi=0106.041, RSKangXi=9.7
20243 CJK UNIFIED IDEOGRAPH-#20243, IRGKangXi=0106.041, RSKangXi=9.7
20244 CJK UNIFIED IDEOGRAPH-#20244, IRGKangXi=0106.041, RSKangXi=9.7
20245 CJK UNIFIED IDEOGRAPH-#20245, IRGKangXi=0106.041, RSKangXi=9.7
20246 CJK UNIFIED IDEOGRAPH-#20246, IRGKangXi=0106.041, RSKangXi=9.7
20247 CJK UNIFIED IDEOGRAPH-#20247, IRGKangXi=0106.041, RSKangXi=9.7
20248 CJK UNIFIED IDEOGRAPH-#20248, IRGKangXi=0106.041, RSKangXi=9.7
20249 CJK UNIFIED IDEOGRAPH-#20249, IRGKangXi=0106.041, RSKangXi=9.7
2024A CJK UNIFIED IDEOGRAPH-#2024A, IRGKangXi=0106.041, RSKangXi=9.7
2024B CJK UNIFIED IDEOGRAPH-#2024B, IRGKangXi=0106.041, RSKangXi=9.7
2024C CJK UNIFIED IDEOGRAPH-#2024C, IRGKangXi=0106.041, RSKangXi=9.7
2024D CJK UNIFIED IDEOGRAPH-#2024D, IRGKangXi=0106.041, RSKangXi=9.7
2024E CJK UNIFIED IDEOGRAPH-#2024E, IRGKangXi=0106.041, RSKangXi=9.7
2024F CJK UNIFIED IDEOGRAPH-#2024F, IRGKangXi=0106.041, RSKangXi=9.7
20250 CJK UNIFIED IDEOGRAPH-#20250, IRGKangXi=0106.041, RSKangXi=9.7
20251 CJK UNIFIED IDEOGRAPH-#20251, IRGKangXi=0106.041, RSKangXi=9.7
20252 CJK UNIFIED IDEOGRAPH-#20252, IRGKangXi=0106.041, RSKangXi=9.7
20253 CJK UNIFIED IDEOGRAPH-#20253, IRGKangXi=0106.041, RSKangXi=9.7
20254 CJK UNIFIED IDEOGRAPH-#20254, IRGKangXi=0106.041, RSKangXi=9.7
20255 CJK UNIFIED IDEOGRAPH-#20255, IRGKangXi=0106.041, RSKangXi=9.7
20256 CJK UNIFIED IDEOGRAPH-#20256, IRGKangXi=0106.041, RSKangXi=9.7
20257 CJK UNIFIED IDEOGRAPH-#20257, IRGKangXi=0106.041, RSKangXi=9.7
20258 CJK UNIFIED IDEOGRAPH-#20258, IRGKangXi=0106.041, RSKangXi=9.7
20259 CJK UNIFIED IDEOGRAPH-#20259, IRGKangXi=0106.041, RSKangXi=9.7
2025A CJK UNIFIED IDEOGRAPH-#2025A, IRGKangXi=0106.041, RSKangXi=9.7
2025B CJK UNIFIED IDEOGRAPH-#2025B, IRGKangXi=0106.041, RSKangXi=9.7
2025C CJK UNIFIED IDEOGRAPH-#2025C, IRGKangXi=0106.041, RSKangXi=9.7
2025D CJK UNIFIED IDEOGRAPH-#2025D, IRGKangXi=0106.041, RSKangXi=9.7
2025E CJK UNIFIED IDEOGRAPH-#2025E, IRGKangXi=0106.041, RSKangXi=9.7
2025F CJK UNIFIED IDEOGRAPH-#2025F, IRGKangXi=0106.041, RSKangXi=9.7
20260 CJK UNIFIED IDEOGRAPH-#20260, IRGKangXi=0106.041, RSKangXi=9.7
20261 CJK UNIFIED IDEOGRAPH-#20261, IRGKangXi=0106.041, RSKangXi=9.7
20262 CJK UNIFIED IDEOGRAPH-#20262, IRGKangXi=0106.041, RSKangXi=9.7
20263 CJK UNIFIED IDEOGRAPH-#20263, IRGKangXi=0106.120, RSKangXi=9.8
20264 CJK UNIFIED IDEOGRAPH-#20264, IRGKangXi=0107.020, RSKangXi=9.8
20265 CJK UNIFIED IDEOGRAPH-#20265, IRGKangXi=0107.030, RSKangXi=9.8
20266 CJK UNIFIED IDEOGRAPH-#20266, IRGKangXi=0107.060, RSKangXi=9.8
20267 CJK UNIFIED IDEOGRAPH-#20267, IRGKangXi=0107.100, RSKangXi=9.8
20268 CJK UNIFIED IDEOGRAPH-#20268, IRGKangXi=0107.110, RSKangXi=9.8
20269 CJK UNIFIED IDEOGRAPH-#20269, IRGKangXi=0107.250, RSKangXi=9.8
2026A CJK UNIFIED IDEOGRAPH-#2026A, IRGKangXi=0108.020, RSKangXi=9.8
2026B CJK UNIFIED IDEOGRAPH-#2026B, IRGKangXi=0109.050, RSKangXi=9.8
2026C CJK UNIFIED IDEOGRAPH-#2026C, IRGKangXi=0109.130, RSKangXi=9.8
2026D CJK UNIFIED IDEOGRAPH-#2026D, IRGKangXi=0109.140, RSKangXi=9.8
2026E CJK UNIFIED IDEOGRAPH-#2026E, IRGKangXi=0109.150, RSKangXi=9.8
2026F CJK UNIFIED IDEOGRAPH-#2026F, IRGKangXi=0109.171, RSKangXi=9.8
20270 CJK UNIFIED IDEOGRAPH-#20270, IRGKangXi=0109.171, RSKangXi=9.8
20271 CJK UNIFIED IDEOGRAPH-#20271, IRGKangXi=0109.171, RSKangXi=9.8
20272 CJK UNIFIED IDEOGRAPH-#20272, IRGKangXi=0109.171, RSKangXi=9.8
20273 CJK UNIFIED IDEOGRAPH-#20273, IRGKangXi=0109.171, RSKangXi=9.8
20274 CJK UNIFIED IDEOGRAPH-#20274, IRGKangXi=0109.171, RSKangXi=9.8
20275 CJK UNIFIED IDEOGRAPH-#20275, IRGKangXi=0109.171, RSKangXi=9.8
20276 CJK UNIFIED IDEOGRAPH-#20276, IRGKangXi=0109.171, RSKangXi=9.8
20277 CJK UNIFIED IDEOGRAPH-#20277, IRGKangXi=0109.171, RSKangXi=9.8
20278 CJK UNIFIED IDEOGRAPH-#20278, IRGKangXi=0109.171, RSKangXi=9.8
20279 CJK UNIFIED IDEOGRAPH-#20279, IRGKangXi=0109.171, RSKangXi=9.8
2027A CJK UNIFIED IDEOGRAPH-#2027A, IRGKangXi=0109.171, RSKangXi=9.8
2027B CJK UNIFIED IDEOGRAPH-#2027B, IRGKangXi=0109.171, RSKangXi=9.8
2027C CJK UNIFIED IDEOGRAPH-#2027C, IRGKangXi=0109.171, RSKangXi=9.8
2027D CJK UNIFIED IDEOGRAPH-#2027D, IRGKangXi=0109.171, RSKangXi=9.8
2027E CJK UNIFIED IDEOGRAPH-#2027E, IRGKangXi=0109.171, RSKangXi=9.8
2027F CJK UNIFIED IDEOGRAPH-#2027F, IRGKangXi=0109.171, RSKangXi=9.8
20280 CJK UNIFIED IDEOGRAPH-#20280, IRGKangXi=0109.171, RSKangXi=9.8
20281 CJK UNIFIED IDEOGRAPH-#20281, IRGKangXi=0109.171, RSKangXi=9.8
20282 CJK UNIFIED IDEOGRAPH-#20282, IRGKangXi=0109.171, RSKangXi=9.8
20283 CJK UNIFIED IDEOGRAPH-#20283, IRGKangXi=0109.171, RSKangXi=9.8
20284 CJK UNIFIED IDEOGRAPH-#20284, IRGKangXi=0109.171, RSKangXi=9.8
20285 CJK UNIFIED IDEOGRAPH-#20285, IRGKangXi=0109.171, RSKangXi=9.8
20286 CJK UNIFIED IDEOGRAPH-#20286, IRGKangXi=0109.171, RSKangXi=9.8
20287 CJK UNIFIED IDEOGRAPH-#20287, IRGKangXi=0109.171, RSKangXi=9.8
20288 CJK UNIFIED IDEOGRAPH-#20288, IRGKangXi=0109.171, RSKangXi=9.8
20289 CJK UNIFIED IDEOGRAPH-#20289, IRGKangXi=0109.171, RSKangXi=9.8
2028A CJK UNIFIED IDEOGRAPH-#2028A, IRGKangXi=0109.171, RSKangXi=9.8
2028B CJK UNIFIED IDEOGRAPH-#2028B, IRGKangXi=0109.171, RSKangXi=9.8
2028C CJK UNIFIED IDEOGRAPH-#2028C, IRGKangXi=0109.171, RSKangXi=9.8
2028D CJK UNIFIED IDEOGRAPH-#2028D, IRGKangXi=0109.171, RSKangXi=9.8
2028E CJK UNIFIED IDEOGRAPH-#2028E, IRGKangXi=0109.171, RSKangXi=9.8
2028F CJK UNIFIED IDEOGRAPH-#2028F, IRGKangXi=0109.171, RSKangXi=9.8
20290 CJK UNIFIED IDEOGRAPH-#20290, IRGKangXi=0109.171, RSKangXi=9.8
20291 CJK UNIFIED IDEOGRAPH-#20291, IRGKangXi=0109.171, RSKangXi=9.8
20292 CJK UNIFIED IDEOGRAPH-#20292, IRGKangXi=0109.171, RSKangXi=9.8
20293 CJK UNIFIED IDEOGRAPH-#20293, IRGKangXi=0109.171, RSKangXi=9.8
20294 CJK UNIFIED IDEOGRAPH-#20294, IRGKangXi=0109.171, RSKangXi=9.8
20295 CJK UNIFIED IDEOGRAPH-#20295, IRGKangXi=0109.171, RSKangXi=9.8
20296 CJK UNIFIED IDEOGRAPH-#20296, IRGKangXi=0109.171, RSKangXi=9.8
20297 CJK UNIFIED IDEOGRAPH-#20297, IRGKangXi=0109.171, RSKangXi=9.8
20298 CJK UNIFIED IDEOGRAPH-#20298, IRGKangXi=0109.171, RSKangXi=9.8
20299 CJK UNIFIED IDEOGRAPH-#20299, IRGKangXi=0109.171, RSKangXi=9.8
2029A CJK UNIFIED IDEOGRAPH-#2029A, IRGKangXi=0109.171, RSKangXi=9.8
2029B CJK UNIFIED IDEOGRAPH-#2029B, IRGKangXi=0109.171, RSKangXi=9.8
2029C CJK UNIFIED IDEOGRAPH-#2029C, IRGKangXi=0109.171, RSKangXi=9.8
2029D CJK UNIFIED IDEOGRAPH-#2029D, IRGKangXi=0109.171, RSKangXi=9.8
2029E CJK UNIFIED IDEOGRAPH-#2029E, IRGKangXi=0109.171, RSKangXi=9.8
2029F CJK UNIFIED IDEOGRAPH-#2029F, IRGKangXi=0109.171, RSKangXi=9.8
202A0 CJK UNIFIED IDEOGRAPH-#202A0, IRGKangXi=0109.171, RSKangXi=9.8
202A1 CJK UNIFIED IDEOGRAPH-#202A1, IRGKangXi=0109.171, RSKangXi=9.8
202A2 CJK UNIFIED IDEOGRAPH-#202A2, IRGKangXi=0109.171, RSKangXi=9.8
202A3 CJK UNIFIED IDEOGRAPH-#202A3, IRGKangXi=0109.171, RSKangXi=9.8
202A4 CJK UNIFIED IDEOGRAPH-#202A4, IRGKangXi=0109.171, RSKangXi=9.8
202A5 CJK UNIFIED IDEOGRAPH-#202A5, IRGKangXi=0109.171, RSKangXi=9.8
202A6 CJK UNIFIED IDEOGRAPH-#202A6, IRGKangXi=0109.171, RSKangXi=9.8
202A7 CJK UNIFIED IDEOGRAPH-#202A7, IRGKangXi=0109.180, RSKangXi=9.9, Def{even, together; to reduce, equalize}
202A8 CJK UNIFIED IDEOGRAPH-#202A8, IRGKangXi=0110.020, RSKangXi=9.9
202A9 CJK UNIFIED IDEOGRAPH-#202A9, IRGKangXi=0110.120, RSKangXi=9.9
202AA CJK UNIFIED IDEOGRAPH-#202AA, IRGKangXi=0110.130, RSKangXi=9.9
202AB CJK UNIFIED IDEOGRAPH-#202AB, IRGKangXi=0110.140, RSKangXi=9.9
202AC CJK UNIFIED IDEOGRAPH-#202AC, IRGKangXi=0110.150, RSKangXi=9.9
202AD CJK UNIFIED IDEOGRAPH-#202AD, IRGKangXi=0110.170, RSKangXi=9.9
202AE CJK UNIFIED IDEOGRAPH-#202AE, IRGKangXi=0110.270, RSKangXi=9.9
202AF CJK UNIFIED IDEOGRAPH-#202AF, IRGKangXi=0110.300, RSKangXi=9.9
202B0 CJK UNIFIED IDEOGRAPH-#202B0, IRGKangXi=0111.020, RSKangXi=9.9
202B1 CJK UNIFIED IDEOGRAPH-#202B1, IRGKangXi=0111.080, RSKangXi=9.9
202B2 CJK UNIFIED IDEOGRAPH-#202B2, IRGKangXi=0111.120, RSKangXi=9.9
202B3 CJK UNIFIED IDEOGRAPH-#202B3, IRGKangXi=0111.140, RSKangXi=9.9
202B4 CJK UNIFIED IDEOGRAPH-#202B4, IRGKangXi=0111.180, RSKangXi=9.9
202B5 CJK UNIFIED IDEOGRAPH-#202B5, IRGKangXi=0111.200, RSKangXi=9.9
202B6 CJK UNIFIED IDEOGRAPH-#202B6, IRGKangXi=0111.210, RSKangXi=9.9
202B7 CJK UNIFIED IDEOGRAPH-#202B7, IRGKangXi=0112.020, RSKangXi=9.9
202B8 CJK UNIFIED IDEOGRAPH-#202B8, IRGKangXi=0112.040, RSKangXi=9.9
202B9 CJK UNIFIED IDEOGRAPH-#202B9, IRGKangXi=0112.050, RSKangXi=9.9
202BA CJK UNIFIED IDEOGRAPH-#202BA, IRGKangXi=0112.060, RSKangXi=9.9
202BB CJK UNIFIED IDEOGRAPH-#202BB, IRGKangXi=0112.070, RSKangXi=9.9
202BC CJK UNIFIED IDEOGRAPH-#202BC, IRGKangXi=0112.071, RSKangXi=9.9
202BD CJK UNIFIED IDEOGRAPH-#202BD, IRGKangXi=0112.071, RSKangXi=9.9
202BE CJK UNIFIED IDEOGRAPH-#202BE, IRGKangXi=0112.071, RSKangXi=9.9
202BF CJK UNIFIED IDEOGRAPH-#202BF, IRGKangXi=0112.071, RSKangXi=9.9
202C0 CJK UNIFIED IDEOGRAPH-#202C0, IRGKangXi=0112.071, RSKangXi=9.9
202C1 CJK UNIFIED IDEOGRAPH-#202C1, IRGKangXi=0112.071, RSKangXi=9.9
202C2 CJK UNIFIED IDEOGRAPH-#202C2, IRGKangXi=0112.071, RSKangXi=9.9
202C3 CJK UNIFIED IDEOGRAPH-#202C3, IRGKangXi=0112.071, RSKangXi=9.9
202C4 CJK UNIFIED IDEOGRAPH-#202C4, IRGKangXi=0112.071, RSKangXi=9.9
202C5 CJK UNIFIED IDEOGRAPH-#202C5, IRGKangXi=0112.071, RSKangXi=9.9
202C6 CJK UNIFIED IDEOGRAPH-#202C6, IRGKangXi=0112.071, RSKangXi=9.9
202C7 CJK UNIFIED IDEOGRAPH-#202C7, IRGKangXi=0112.071, RSKangXi=9.9
202C8 CJK UNIFIED IDEOGRAPH-#202C8, IRGKangXi=0112.071, RSKangXi=9.9
202C9 CJK UNIFIED IDEOGRAPH-#202C9, IRGKangXi=0112.071, RSKangXi=9.9
202CA CJK UNIFIED IDEOGRAPH-#202CA, IRGKangXi=0112.071, RSKangXi=9.9
202CB CJK UNIFIED IDEOGRAPH-#202CB, IRGKangXi=0112.071, RSKangXi=9.9
202CC CJK UNIFIED IDEOGRAPH-#202CC, IRGKangXi=0112.071, RSKangXi=9.9
202CD CJK UNIFIED IDEOGRAPH-#202CD, IRGKangXi=0112.071, RSKangXi=9.9
202CE CJK UNIFIED IDEOGRAPH-#202CE, IRGKangXi=0112.071, RSKangXi=9.9
202CF CJK UNIFIED IDEOGRAPH-#202CF, IRGKangXi=0112.071, RSKangXi=9.9
202D0 CJK UNIFIED IDEOGRAPH-#202D0, IRGKangXi=0112.071, RSKangXi=9.9
202D1 CJK UNIFIED IDEOGRAPH-#202D1, IRGKangXi=0112.071, RSKangXi=184.0
202D2 CJK UNIFIED IDEOGRAPH-#202D2, IRGKangXi=0112.071, RSKangXi=9.9
202D3 CJK UNIFIED IDEOGRAPH-#202D3, IRGKangXi=0112.071, RSKangXi=9.9
202D4 CJK UNIFIED IDEOGRAPH-#202D4, IRGKangXi=0112.071, RSKangXi=9.9
202D5 CJK UNIFIED IDEOGRAPH-#202D5, IRGKangXi=0112.071, RSKangXi=9.9
202D6 CJK UNIFIED IDEOGRAPH-#202D6, IRGKangXi=0112.071, RSKangXi=9.9
202D7 CJK UNIFIED IDEOGRAPH-#202D7, IRGKangXi=0112.071, RSKangXi=9.9
202D8 CJK UNIFIED IDEOGRAPH-#202D8, IRGKangXi=0112.071, RSKangXi=9.9
202D9 CJK UNIFIED IDEOGRAPH-#202D9, IRGKangXi=0112.071, RSKangXi=9.9
202DA CJK UNIFIED IDEOGRAPH-#202DA, IRGKangXi=0112.071, RSKangXi=9.9
202DB CJK UNIFIED IDEOGRAPH-#202DB, IRGKangXi=0112.071, RSKangXi=9.9
202DC CJK UNIFIED IDEOGRAPH-#202DC, IRGKangXi=0112.071, RSKangXi=9.9
202DD CJK UNIFIED IDEOGRAPH-#202DD, IRGKangXi=0112.071, RSKangXi=9.9
202DE CJK UNIFIED IDEOGRAPH-#202DE, IRGKangXi=0112.071, RSKangXi=9.9
202DF CJK UNIFIED IDEOGRAPH-#202DF, IRGKangXi=0112.071, RSKangXi=9.8
202E0 CJK UNIFIED IDEOGRAPH-#202E0, IRGKangXi=0112.071, RSKangXi=9.9
202E1 CJK UNIFIED IDEOGRAPH-#202E1, IRGKangXi=0112.071, RSKangXi=9.9
202E2 CJK UNIFIED IDEOGRAPH-#202E2, IRGKangXi=0112.071, RSKangXi=9.9
202E3 CJK UNIFIED IDEOGRAPH-#202E3, IRGKangXi=0112.071, RSKangXi=9.9
202E4 CJK UNIFIED IDEOGRAPH-#202E4, IRGKangXi=0112.071, RSKangXi=9.9
202E5 CJK UNIFIED IDEOGRAPH-#202E5, IRGKangXi=0112.071, RSKangXi=9.9
202E6 CJK UNIFIED IDEOGRAPH-#202E6, IRGKangXi=0112.071, RSKangXi=9.9
202E7 CJK UNIFIED IDEOGRAPH-#202E7, IRGKangXi=0112.071, RSKangXi=9.9
202E8 CJK UNIFIED IDEOGRAPH-#202E8, IRGKangXi=0112.071, RSKangXi=9.9
202E9 CJK UNIFIED IDEOGRAPH-#202E9, IRGKangXi=0112.071, RSKangXi=9.9
202EA CJK UNIFIED IDEOGRAPH-#202EA, IRGKangXi=0112.071, RSKangXi=9.9
202EB CJK UNIFIED IDEOGRAPH-#202EB, IRGKangXi=0112.071, RSKangXi=9.9
202EC CJK UNIFIED IDEOGRAPH-#202EC, IRGKangXi=0112.071, RSKangXi=9.9
202ED CJK UNIFIED IDEOGRAPH-#202ED, IRGKangXi=0112.071, RSKangXi=9.10
202EE CJK UNIFIED IDEOGRAPH-#202EE, IRGKangXi=0112.071, RSKangXi=9.10
202EF CJK UNIFIED IDEOGRAPH-#202EF, IRGKangXi=0112.071, RSKangXi=9.10
202F0 CJK UNIFIED IDEOGRAPH-#202F0, IRGKangXi=0112.071, RSKangXi=9.10
202F1 CJK UNIFIED IDEOGRAPH-#202F1, IRGKangXi=0112.150, RSKangXi=9.10
202F2 CJK UNIFIED IDEOGRAPH-#202F2, IRGKangXi=0112.160, RSKangXi=9.10
202F3 CJK UNIFIED IDEOGRAPH-#202F3, IRGKangXi=0112.170, RSKangXi=9.10
202F4 CJK UNIFIED IDEOGRAPH-#202F4, IRGKangXi=0112.180, RSKangXi=9.10
202F5 CJK UNIFIED IDEOGRAPH-#202F5, IRGKangXi=0112.250, RSKangXi=9.10
202F6 CJK UNIFIED IDEOGRAPH-#202F6, IRGKangXi=0113.100, RSKangXi=9.10
202F7 CJK UNIFIED IDEOGRAPH-#202F7, IRGKangXi=0113.110, RSKangXi=9.10
202F8 CJK UNIFIED IDEOGRAPH-#202F8, IRGKangXi=0113.120, RSKangXi=9.10
202F9 CJK UNIFIED IDEOGRAPH-#202F9, IRGKangXi=0113.140, RSKangXi=9.10
202FA CJK UNIFIED IDEOGRAPH-#202FA, IRGKangXi=0113.230, RSKangXi=9.10
202FB CJK UNIFIED IDEOGRAPH-#202FB, IRGKangXi=0113.300, RSKangXi=9.10
202FC CJK UNIFIED IDEOGRAPH-#202FC, IRGKangXi=0113.320, RSKangXi=9.10
202FD CJK UNIFIED IDEOGRAPH-#202FD, IRGKangXi=0114.010, RSKangXi=9.10
202FE CJK UNIFIED IDEOGRAPH-#202FE, IRGKangXi=0114.020, RSKangXi=9.10
202FF CJK UNIFIED IDEOGRAPH-#202FF, IRGKangXi=0114.030, RSKangXi=9.10
20300 CJK UNIFIED IDEOGRAPH-#20300, IRGKangXi=0114.040, RSKangXi=9.10
20301 CJK UNIFIED IDEOGRAPH-#20301, IRGKangXi=0114.050, RSKangXi=9.10
20302 CJK UNIFIED IDEOGRAPH-#20302, IRGKangXi=0114.051, RSKangXi=9.10
20303 CJK UNIFIED IDEOGRAPH-#20303, IRGKangXi=0114.051, RSKangXi=9.10
20304 CJK UNIFIED IDEOGRAPH-#20304, IRGKangXi=0114.051, RSKangXi=9.10
20305 CJK UNIFIED IDEOGRAPH-#20305, IRGKangXi=0114.051, RSKangXi=9.10
20306 CJK UNIFIED IDEOGRAPH-#20306, IRGKangXi=0114.051, RSKangXi=11.10
20307 CJK UNIFIED IDEOGRAPH-#20307, IRGKangXi=0114.051, RSKangXi=9.10
20308 CJK UNIFIED IDEOGRAPH-#20308, IRGKangXi=0114.051, RSKangXi=9.10
20309 CJK UNIFIED IDEOGRAPH-#20309, IRGKangXi=0114.051, RSKangXi=9.10
2030A CJK UNIFIED IDEOGRAPH-#2030A, IRGKangXi=0114.051, RSKangXi=9.10
2030B CJK UNIFIED IDEOGRAPH-#2030B, IRGKangXi=0114.051, RSKangXi=9.10
2030C CJK UNIFIED IDEOGRAPH-#2030C, IRGKangXi=0114.051, RSKangXi=9.10
2030D CJK UNIFIED IDEOGRAPH-#2030D, IRGKangXi=0114.051, RSKangXi=9.10
2030E CJK UNIFIED IDEOGRAPH-#2030E, IRGKangXi=0114.051, RSKangXi=9.10
2030F CJK UNIFIED IDEOGRAPH-#2030F, IRGKangXi=0114.051, RSKangXi=9.10
20310 CJK UNIFIED IDEOGRAPH-#20310, IRGKangXi=0114.051, RSKangXi=9.10
20311 CJK UNIFIED IDEOGRAPH-#20311, IRGKangXi=0114.051, RSKangXi=9.10
20312 CJK UNIFIED IDEOGRAPH-#20312, IRGKangXi=0114.051, RSKangXi=9.10
20313 CJK UNIFIED IDEOGRAPH-#20313, IRGKangXi=0114.051, RSKangXi=9.10
20314 CJK UNIFIED IDEOGRAPH-#20314, IRGKangXi=0114.051, RSKangXi=9.10
20315 CJK UNIFIED IDEOGRAPH-#20315, IRGKangXi=0114.051, RSKangXi=9.10
20316 CJK UNIFIED IDEOGRAPH-#20316, IRGKangXi=0114.051, RSKangXi=9.10
20317 CJK UNIFIED IDEOGRAPH-#20317, IRGKangXi=0114.051, RSKangXi=9.10
20318 CJK UNIFIED IDEOGRAPH-#20318, IRGKangXi=0114.051, RSKangXi=9.10
20319 CJK UNIFIED IDEOGRAPH-#20319, IRGKangXi=0114.051, RSKangXi=9.10
2031A CJK UNIFIED IDEOGRAPH-#2031A, IRGKangXi=0114.051, RSKangXi=9.10
2031B CJK UNIFIED IDEOGRAPH-#2031B, IRGKangXi=0114.051, RSKangXi=9.10
2031C CJK UNIFIED IDEOGRAPH-#2031C, IRGKangXi=0114.051, RSKangXi=9.10
2031D CJK UNIFIED IDEOGRAPH-#2031D, IRGKangXi=0114.051, RSKangXi=9.10
2031E CJK UNIFIED IDEOGRAPH-#2031E, IRGKangXi=0114.051, RSKangXi=35.9
2031F CJK UNIFIED IDEOGRAPH-#2031F, IRGKangXi=0114.051, RSKangXi=106.7
20320 CJK UNIFIED IDEOGRAPH-#20320, IRGKangXi=0114.051, RSKangXi=9.10
20321 CJK UNIFIED IDEOGRAPH-#20321, IRGKangXi=0114.051, RSKangXi=9.10
20322 CJK UNIFIED IDEOGRAPH-#20322, IRGKangXi=0114.051, RSKangXi=9.10
20323 CJK UNIFIED IDEOGRAPH-#20323, IRGKangXi=0114.051, RSKangXi=9.10
20324 CJK UNIFIED IDEOGRAPH-#20324, IRGKangXi=0114.051, RSKangXi=9.10
20325 CJK UNIFIED IDEOGRAPH-#20325, IRGKangXi=0114.051, RSKangXi=9.10, Def{(Cant.) to bow, stoop}
20326 CJK UNIFIED IDEOGRAPH-#20326, IRGKangXi=0114.051, RSKangXi=9.10
20327 CJK UNIFIED IDEOGRAPH-#20327, IRGKangXi=0114.051, RSKangXi=9.10
20328 CJK UNIFIED IDEOGRAPH-#20328, IRGKangXi=0114.051, RSKangXi=9.10
20329 CJK UNIFIED IDEOGRAPH-#20329, IRGKangXi=0114.051, RSKangXi=9.10
2032A CJK UNIFIED IDEOGRAPH-#2032A, IRGKangXi=0114.051, RSKangXi=109.6
2032B CJK UNIFIED IDEOGRAPH-#2032B, IRGKangXi=0114.080, RSKangXi=9.11
2032C CJK UNIFIED IDEOGRAPH-#2032C, IRGKangXi=0114.100, RSKangXi=9.11
2032D CJK UNIFIED IDEOGRAPH-#2032D, IRGKangXi=0114.140, RSKangXi=9.11
2032E CJK UNIFIED IDEOGRAPH-#2032E, IRGKangXi=0114.180, RSKangXi=9.11
2032F CJK UNIFIED IDEOGRAPH-#2032F, IRGKangXi=0114.200, RSKangXi=9.11
20330 CJK UNIFIED IDEOGRAPH-#20330, IRGKangXi=0114.220, RSKangXi=9.11
20331 CJK UNIFIED IDEOGRAPH-#20331, IRGKangXi=0114.250, RSKangXi=9.11
20332 CJK UNIFIED IDEOGRAPH-#20332, IRGKangXi=0114.300, RSKangXi=9.11
20333 CJK UNIFIED IDEOGRAPH-#20333, IRGKangXi=0114.310, RSKangXi=9.11
20334 CJK UNIFIED IDEOGRAPH-#20334, IRGKangXi=0114.320, RSKangXi=9.11
20335 CJK UNIFIED IDEOGRAPH-#20335, IRGKangXi=0115.020, RSKangXi=9.11
20336 CJK UNIFIED IDEOGRAPH-#20336, IRGKangXi=0115.080, RSKangXi=9.11
20337 CJK UNIFIED IDEOGRAPH-#20337, IRGKangXi=0115.120, RSKangXi=9.11
20338 CJK UNIFIED IDEOGRAPH-#20338, IRGKangXi=0115.260, RSKangXi=9.11
20339 CJK UNIFIED IDEOGRAPH-#20339, IRGKangXi=0115.310, RSKangXi=9.11
2033A CJK UNIFIED IDEOGRAPH-#2033A, IRGKangXi=0115.320, RSKangXi=9.11
2033B CJK UNIFIED IDEOGRAPH-#2033B, IRGKangXi=0115.330, RSKangXi=9.11
2033C CJK UNIFIED IDEOGRAPH-#2033C, IRGKangXi=0115.350, RSKangXi=9.11
2033D CJK UNIFIED IDEOGRAPH-#2033D, IRGKangXi=0116.010, RSKangXi=9.11
2033E CJK UNIFIED IDEOGRAPH-#2033E, IRGKangXi=0116.020, RSKangXi=9.11
2033F CJK UNIFIED IDEOGRAPH-#2033F, IRGKangXi=0116.030, RSKangXi=9.11
20340 CJK UNIFIED IDEOGRAPH-#20340, IRGKangXi=0116.040, RSKangXi=9.11
20341 CJK UNIFIED IDEOGRAPH-#20341, IRGKangXi=0116.041, RSKangXi=9.11, Def{(Cant.) an undesirable situation}
20342 CJK UNIFIED IDEOGRAPH-#20342, IRGKangXi=0116.041, RSKangXi=9.11
20343 CJK UNIFIED IDEOGRAPH-#20343, IRGKangXi=0116.041, RSKangXi=9.11
20344 CJK UNIFIED IDEOGRAPH-#20344, IRGKangXi=0116.041, RSKangXi=9.11
20345 CJK UNIFIED IDEOGRAPH-#20345, IRGKangXi=0116.041, RSKangXi=9.11
20346 CJK UNIFIED IDEOGRAPH-#20346, IRGKangXi=0116.041, RSKangXi=9.11
20347 CJK UNIFIED IDEOGRAPH-#20347, IRGKangXi=0116.041, RSKangXi=9.11
20348 CJK UNIFIED IDEOGRAPH-#20348, IRGKangXi=0116.041, RSKangXi=9.11
20349 CJK UNIFIED IDEOGRAPH-#20349, IRGKangXi=0116.041, RSKangXi=9.11
2034A CJK UNIFIED IDEOGRAPH-#2034A, IRGKangXi=0116.041, RSKangXi=9.11
2034B CJK UNIFIED IDEOGRAPH-#2034B, IRGKangXi=0116.041, RSKangXi=9.11
2034C CJK UNIFIED IDEOGRAPH-#2034C, IRGKangXi=0116.041, RSKangXi=9.11
2034D CJK UNIFIED IDEOGRAPH-#2034D, IRGKangXi=0116.041, RSKangXi=9.11
2034E CJK UNIFIED IDEOGRAPH-#2034E, IRGKangXi=0116.041, RSKangXi=9.11
2034F CJK UNIFIED IDEOGRAPH-#2034F, IRGKangXi=0116.041, RSKangXi=9.11
20350 CJK UNIFIED IDEOGRAPH-#20350, IRGKangXi=0116.041, RSKangXi=9.11
20351 CJK UNIFIED IDEOGRAPH-#20351, IRGKangXi=0116.041, RSKangXi=9.11
20352 CJK UNIFIED IDEOGRAPH-#20352, IRGKangXi=0116.041, RSKangXi=9.11
20353 CJK UNIFIED IDEOGRAPH-#20353, IRGKangXi=0116.041, RSKangXi=9.11
20354 CJK UNIFIED IDEOGRAPH-#20354, IRGKangXi=0116.041, RSKangXi=9.11
20355 CJK UNIFIED IDEOGRAPH-#20355, IRGKangXi=0116.041, RSKangXi=9.11
20356 CJK UNIFIED IDEOGRAPH-#20356, IRGKangXi=0116.041, RSKangXi=9.11
20357 CJK UNIFIED IDEOGRAPH-#20357, IRGKangXi=0116.041, RSKangXi=9.11
20358 CJK UNIFIED IDEOGRAPH-#20358, IRGKangXi=0116.041, RSKangXi=9.11
20359 CJK UNIFIED IDEOGRAPH-#20359, IRGKangXi=0116.041, RSKangXi=9.11
2035A CJK UNIFIED IDEOGRAPH-#2035A, IRGKangXi=0116.041, RSKangXi=9.11
2035B CJK UNIFIED IDEOGRAPH-#2035B, IRGKangXi=0116.041, RSKangXi=9.11
2035C CJK UNIFIED IDEOGRAPH-#2035C, IRGKangXi=0116.041, RSKangXi=9.11
2035D CJK UNIFIED IDEOGRAPH-#2035D, IRGKangXi=0116.041, RSKangXi=9.11
2035E CJK UNIFIED IDEOGRAPH-#2035E, IRGKangXi=0116.041, RSKangXi=9.11
2035F CJK UNIFIED IDEOGRAPH-#2035F, IRGKangXi=0116.041, RSKangXi=9.11
20360 CJK UNIFIED IDEOGRAPH-#20360, IRGKangXi=0116.041, RSKangXi=9.11
20361 CJK UNIFIED IDEOGRAPH-#20361, IRGKangXi=0116.041, RSKangXi=9.11
20362 CJK UNIFIED IDEOGRAPH-#20362, IRGKangXi=0116.041, RSKangXi=110.8
20363 CJK UNIFIED IDEOGRAPH-#20363, IRGKangXi=0116.041, RSKangXi=9.11
20364 CJK UNIFIED IDEOGRAPH-#20364, IRGKangXi=0116.041, RSKangXi=9.11
20365 CJK UNIFIED IDEOGRAPH-#20365, IRGKangXi=0116.041, RSKangXi=9.12
20366 CJK UNIFIED IDEOGRAPH-#20366, IRGKangXi=0116.041, RSKangXi=9.11
20367 CJK UNIFIED IDEOGRAPH-#20367, IRGKangXi=0116.041, RSKangXi=9.11
20368 CJK UNIFIED IDEOGRAPH-#20368, IRGKangXi=0116.041, RSKangXi=9.11
20369 CJK UNIFIED IDEOGRAPH-#20369, IRGKangXi=0116.041, RSKangXi=9.11
2036A CJK UNIFIED IDEOGRAPH-#2036A, IRGKangXi=0116.041, RSKangXi=9.11
2036B CJK UNIFIED IDEOGRAPH-#2036B, IRGKangXi=0116.041, RSKangXi=9.11
2036C CJK UNIFIED IDEOGRAPH-#2036C, IRGKangXi=0116.041, RSKangXi=9.11
2036D CJK UNIFIED IDEOGRAPH-#2036D, IRGKangXi=0116.041, RSKangXi=9.12
2036E CJK UNIFIED IDEOGRAPH-#2036E, IRGKangXi=0116.050, RSKangXi=9.12
2036F CJK UNIFIED IDEOGRAPH-#2036F, IRGKangXi=0116.060, RSKangXi=9.12
20370 CJK UNIFIED IDEOGRAPH-#20370, IRGKangXi=0116.100, RSKangXi=9.12
20371 CJK UNIFIED IDEOGRAPH-#20371, IRGKangXi=0116.150, RSKangXi=9.12
20372 CJK UNIFIED IDEOGRAPH-#20372, IRGKangXi=0116.160, RSKangXi=9.12
20373 CJK UNIFIED IDEOGRAPH-#20373, IRGKangXi=0117.010, RSKangXi=9.12
20374 CJK UNIFIED IDEOGRAPH-#20374, IRGKangXi=0117.170, RSKangXi=9.12
20375 CJK UNIFIED IDEOGRAPH-#20375, IRGKangXi=0117.180, RSKangXi=9.12
20376 CJK UNIFIED IDEOGRAPH-#20376, IRGKangXi=0117.210, RSKangXi=9.12
20377 CJK UNIFIED IDEOGRAPH-#20377, IRGKangXi=0117.270, RSKangXi=9.12
20378 CJK UNIFIED IDEOGRAPH-#20378, IRGKangXi=0117.290, RSKangXi=9.12
20379 CJK UNIFIED IDEOGRAPH-#20379, IRGKangXi=0118.020, RSKangXi=9.12
2037A CJK UNIFIED IDEOGRAPH-#2037A, IRGKangXi=0118.040, RSKangXi=9.12
2037B CJK UNIFIED IDEOGRAPH-#2037B, IRGKangXi=0118.050, RSKangXi=9.12
2037C CJK UNIFIED IDEOGRAPH-#2037C, IRGKangXi=0118.051, RSKangXi=9.12
2037D CJK UNIFIED IDEOGRAPH-#2037D, IRGKangXi=0118.051, RSKangXi=9.12
2037E CJK UNIFIED IDEOGRAPH-#2037E, IRGKangXi=0118.051, RSKangXi=9.12
2037F CJK UNIFIED IDEOGRAPH-#2037F, IRGKangXi=0118.051, RSKangXi=9.12
20380 CJK UNIFIED IDEOGRAPH-#20380, IRGKangXi=0118.051, RSKangXi=9.12
20381 CJK UNIFIED IDEOGRAPH-#20381, IRGKangXi=0118.051, RSKangXi=9.12
20382 CJK UNIFIED IDEOGRAPH-#20382, IRGKangXi=0118.051, RSKangXi=9.12
20383 CJK UNIFIED IDEOGRAPH-#20383, IRGKangXi=0118.051, RSKangXi=9.12
20384 CJK UNIFIED IDEOGRAPH-#20384, IRGKangXi=0118.051, RSKangXi=9.12
20385 CJK UNIFIED IDEOGRAPH-#20385, IRGKangXi=0118.051, RSKangXi=9.12
20386 CJK UNIFIED IDEOGRAPH-#20386, IRGKangXi=0118.051, RSKangXi=9.12
20387 CJK UNIFIED IDEOGRAPH-#20387, IRGKangXi=0118.051, RSKangXi=9.12
20388 CJK UNIFIED IDEOGRAPH-#20388, IRGKangXi=0118.051, RSKangXi=9.12
20389 CJK UNIFIED IDEOGRAPH-#20389, IRGKangXi=0118.051, RSKangXi=9.12
2038A CJK UNIFIED IDEOGRAPH-#2038A, IRGKangXi=0118.051, RSKangXi=9.12
2038B CJK UNIFIED IDEOGRAPH-#2038B, IRGKangXi=0118.051, RSKangXi=9.12
2038C CJK UNIFIED IDEOGRAPH-#2038C, IRGKangXi=0118.051, RSKangXi=9.12
2038D CJK UNIFIED IDEOGRAPH-#2038D, IRGKangXi=0118.051, RSKangXi=9.12
2038E CJK UNIFIED IDEOGRAPH-#2038E, IRGKangXi=0118.051, RSKangXi=9.12
2038F CJK UNIFIED IDEOGRAPH-#2038F, IRGKangXi=0118.051, RSKangXi=9.12
20390 CJK UNIFIED IDEOGRAPH-#20390, IRGKangXi=0118.051, RSKangXi=9.12
20391 CJK UNIFIED IDEOGRAPH-#20391, IRGKangXi=0118.051, RSKangXi=9.12
20392 CJK UNIFIED IDEOGRAPH-#20392, IRGKangXi=0118.051, RSKangXi=9.12
20393 CJK UNIFIED IDEOGRAPH-#20393, IRGKangXi=0118.051, RSKangXi=9.12
20394 CJK UNIFIED IDEOGRAPH-#20394, IRGKangXi=0118.051, RSKangXi=9.12
20395 CJK UNIFIED IDEOGRAPH-#20395, IRGKangXi=0118.051, RSKangXi=9.12
20396 CJK UNIFIED IDEOGRAPH-#20396, IRGKangXi=0118.051, RSKangXi=9.12
20397 CJK UNIFIED IDEOGRAPH-#20397, IRGKangXi=0118.051, RSKangXi=9.12
20398 CJK UNIFIED IDEOGRAPH-#20398, IRGKangXi=0118.051, RSKangXi=114.10
20399 CJK UNIFIED IDEOGRAPH-#20399, IRGKangXi=0118.051, RSKangXi=9.12
2039A CJK UNIFIED IDEOGRAPH-#2039A, IRGKangXi=0118.051, RSKangXi=9.12
2039B CJK UNIFIED IDEOGRAPH-#2039B, IRGKangXi=0118.051, RSKangXi=89.10
2039C CJK UNIFIED IDEOGRAPH-#2039C, IRGKangXi=0118.051, RSKangXi=211.5
2039D CJK UNIFIED IDEOGRAPH-#2039D, IRGKangXi=0118.051, RSKangXi=9.12
2039E CJK UNIFIED IDEOGRAPH-#2039E, IRGKangXi=0118.051, RSKangXi=9.12
2039F CJK UNIFIED IDEOGRAPH-#2039F, IRGKangXi=0118.051, RSKangXi=9.12
203A0 CJK UNIFIED IDEOGRAPH-#203A0, IRGKangXi=0118.051, RSKangXi=9.12
203A1 CJK UNIFIED IDEOGRAPH-#203A1, IRGKangXi=0118.051, RSKangXi=9.12
203A2 CJK UNIFIED IDEOGRAPH-#203A2, IRGKangXi=0118.051, RSKangXi=9.12
203A3 CJK UNIFIED IDEOGRAPH-#203A3, IRGKangXi=0118.051, RSKangXi=9.12
203A4 CJK UNIFIED IDEOGRAPH-#203A4, IRGKangXi=0118.051, RSKangXi=9.12
203A5 CJK UNIFIED IDEOGRAPH-#203A5, IRGKangXi=0118.051, RSKangXi=9.12
203A6 CJK UNIFIED IDEOGRAPH-#203A6, IRGKangXi=0118.051, RSKangXi=9.12
203A7 CJK UNIFIED IDEOGRAPH-#203A7, IRGKangXi=0118.051, RSKangXi=9.12
203A8 CJK UNIFIED IDEOGRAPH-#203A8, IRGKangXi=0118.051, RSKangXi=9.12
203A9 CJK UNIFIED IDEOGRAPH-#203A9, IRGKangXi=0118.051, RSKangXi=9.12
203AA CJK UNIFIED IDEOGRAPH-#203AA, IRGKangXi=0118.051, RSKangXi=9.12
203AB CJK UNIFIED IDEOGRAPH-#203AB, IRGKangXi=0118.051, RSKangXi=9.12
203AC CJK UNIFIED IDEOGRAPH-#203AC, IRGKangXi=0118.051, RSKangXi=9.12
203AD CJK UNIFIED IDEOGRAPH-#203AD, IRGKangXi=0118.051, RSKangXi=9.12
203AE CJK UNIFIED IDEOGRAPH-#203AE, IRGKangXi=0118.051, RSKangXi=9.12
203AF CJK UNIFIED IDEOGRAPH-#203AF, IRGKangXi=0118.051, RSKangXi=9.12
203B0 CJK UNIFIED IDEOGRAPH-#203B0, IRGKangXi=0118.051, RSKangXi=9.12
203B1 CJK UNIFIED IDEOGRAPH-#203B1, IRGKangXi=0118.051, RSKangXi=9.12
203B2 CJK UNIFIED IDEOGRAPH-#203B2, IRGKangXi=0118.051, RSKangXi=9.12
203B3 CJK UNIFIED IDEOGRAPH-#203B3, IRGKangXi=0118.051, RSKangXi=9.12
203B4 CJK UNIFIED IDEOGRAPH-#203B4, IRGKangXi=0118.051, RSKangXi=9.12
203B5 CJK UNIFIED IDEOGRAPH-#203B5, IRGKangXi=0118.051, RSKangXi=9.11
203B6 CJK UNIFIED IDEOGRAPH-#203B6, IRGKangXi=0118.051, RSKangXi=62.10
203B7 CJK UNIFIED IDEOGRAPH-#203B7, IRGKangXi=0118.100, RSKangXi=9.13
203B8 CJK UNIFIED IDEOGRAPH-#203B8, IRGKangXi=0118.150, RSKangXi=9.13
203B9 CJK UNIFIED IDEOGRAPH-#203B9, IRGKangXi=0118.180, RSKangXi=9.13
203BA CJK UNIFIED IDEOGRAPH-#203BA, IRGKangXi=0119.030, RSKangXi=9.13
203BB CJK UNIFIED IDEOGRAPH-#203BB, IRGKangXi=0119.040, RSKangXi=9.13
203BC CJK UNIFIED IDEOGRAPH-#203BC, IRGKangXi=0119.050, RSKangXi=9.13
203BD CJK UNIFIED IDEOGRAPH-#203BD, IRGKangXi=0119.060, RSKangXi=9.13
203BE CJK UNIFIED IDEOGRAPH-#203BE, IRGKangXi=0119.080, RSKangXi=9.13
203BF CJK UNIFIED IDEOGRAPH-#203BF, IRGKangXi=0119.150, RSKangXi=9.13
203C0 CJK UNIFIED IDEOGRAPH-#203C0, IRGKangXi=0119.170, RSKangXi=9.13
203C1 CJK UNIFIED IDEOGRAPH-#203C1, IRGKangXi=0119.200, RSKangXi=9.13
203C2 CJK UNIFIED IDEOGRAPH-#203C2, IRGKangXi=0119.210, RSKangXi=9.13
203C3 CJK UNIFIED IDEOGRAPH-#203C3, IRGKangXi=0119.220, RSKangXi=9.13
203C4 CJK UNIFIED IDEOGRAPH-#203C4, IRGKangXi=0119.230, RSKangXi=9.13
203C5 CJK UNIFIED IDEOGRAPH-#203C5, IRGKangXi=0119.231, RSKangXi=9.13
203C6 CJK UNIFIED IDEOGRAPH-#203C6, IRGKangXi=0119.231, RSKangXi=9.13
203C7 CJK UNIFIED IDEOGRAPH-#203C7, IRGKangXi=0119.231, RSKangXi=9.13
203C8 CJK UNIFIED IDEOGRAPH-#203C8, IRGKangXi=0119.231, RSKangXi=9.13
203C9 CJK UNIFIED IDEOGRAPH-#203C9, IRGKangXi=0119.231, RSKangXi=9.13
203CA CJK UNIFIED IDEOGRAPH-#203CA, IRGKangXi=0119.231, RSKangXi=9.13
203CB CJK UNIFIED IDEOGRAPH-#203CB, IRGKangXi=0119.231, RSKangXi=9.13
203CC CJK UNIFIED IDEOGRAPH-#203CC, IRGKangXi=0119.231, RSKangXi=9.13
203CD CJK UNIFIED IDEOGRAPH-#203CD, IRGKangXi=0119.231, RSKangXi=9.13
203CE CJK UNIFIED IDEOGRAPH-#203CE, IRGKangXi=0119.231, RSKangXi=9.13
203CF CJK UNIFIED IDEOGRAPH-#203CF, IRGKangXi=0119.231, RSKangXi=9.13
203D0 CJK UNIFIED IDEOGRAPH-#203D0, IRGKangXi=0119.231, RSKangXi=9.12
203D1 CJK UNIFIED IDEOGRAPH-#203D1, IRGKangXi=0119.231, RSKangXi=9.13
203D2 CJK UNIFIED IDEOGRAPH-#203D2, IRGKangXi=0119.231, RSKangXi=9.14
203D3 CJK UNIFIED IDEOGRAPH-#203D3, IRGKangXi=0119.231, RSKangXi=30.12
203D4 CJK UNIFIED IDEOGRAPH-#203D4, IRGKangXi=0119.231, RSKangXi=9.13
203D5 CJK UNIFIED IDEOGRAPH-#203D5, IRGKangXi=0119.231, RSKangXi=9.13
203D6 CJK UNIFIED IDEOGRAPH-#203D6, IRGKangXi=0119.231, RSKangXi=9.13
203D7 CJK UNIFIED IDEOGRAPH-#203D7, IRGKangXi=0119.231, RSKangXi=9.13
203D8 CJK UNIFIED IDEOGRAPH-#203D8, IRGKangXi=0119.231, RSKangXi=9.13
203D9 CJK UNIFIED IDEOGRAPH-#203D9, IRGKangXi=0119.231, RSKangXi=9.13
203DA CJK UNIFIED IDEOGRAPH-#203DA, IRGKangXi=0119.231, RSKangXi=9.13
203DB CJK UNIFIED IDEOGRAPH-#203DB, IRGKangXi=0119.231, RSKangXi=9.13
203DC CJK UNIFIED IDEOGRAPH-#203DC, IRGKangXi=0119.231, RSKangXi=9.13
203DD CJK UNIFIED IDEOGRAPH-#203DD, IRGKangXi=0119.231, RSKangXi=9.13
203DE CJK UNIFIED IDEOGRAPH-#203DE, IRGKangXi=0119.231, RSKangXi=9.13
203DF CJK UNIFIED IDEOGRAPH-#203DF, IRGKangXi=0119.231, RSKangXi=9.13
203E0 CJK UNIFIED IDEOGRAPH-#203E0, IRGKangXi=0119.231, RSKangXi=9.13
203E1 CJK UNIFIED IDEOGRAPH-#203E1, IRGKangXi=0119.231, RSKangXi=9.13
203E2 CJK UNIFIED IDEOGRAPH-#203E2, IRGKangXi=0119.231, RSKangXi=9.13
203E3 CJK UNIFIED IDEOGRAPH-#203E3, IRGKangXi=0119.231, RSKangXi=9.13
203E4 CJK UNIFIED IDEOGRAPH-#203E4, IRGKangXi=0119.231, RSKangXi=9.13
203E5 CJK UNIFIED IDEOGRAPH-#203E5, IRGKangXi=0119.231, RSKangXi=9.13
203E6 CJK UNIFIED IDEOGRAPH-#203E6, IRGKangXi=0119.231, RSKangXi=9.13
203E7 CJK UNIFIED IDEOGRAPH-#203E7, IRGKangXi=0119.231, RSKangXi=30.12
203E8 CJK UNIFIED IDEOGRAPH-#203E8, IRGKangXi=0119.270, RSKangXi=9.14
203E9 CJK UNIFIED IDEOGRAPH-#203E9, IRGKangXi=0119.280, RSKangXi=9.14
203EA CJK UNIFIED IDEOGRAPH-#203EA, IRGKangXi=0119.290, RSKangXi=9.14
203EB CJK UNIFIED IDEOGRAPH-#203EB, IRGKangXi=0119.310, RSKangXi=9.14
203EC CJK UNIFIED IDEOGRAPH-#203EC, IRGKangXi=0119.370, RSKangXi=9.14
203ED CJK UNIFIED IDEOGRAPH-#203ED, IRGKangXi=0119.390, RSKangXi=9.14
203EE CJK UNIFIED IDEOGRAPH-#203EE, IRGKangXi=0120.020, RSKangXi=9.14
203EF CJK UNIFIED IDEOGRAPH-#203EF, IRGKangXi=0120.030, RSKangXi=9.14
203F0 CJK UNIFIED IDEOGRAPH-#203F0, IRGKangXi=0120.110, RSKangXi=9.14
203F1 CJK UNIFIED IDEOGRAPH-#203F1, IRGKangXi=0120.111, RSKangXi=9.14
203F2 CJK UNIFIED IDEOGRAPH-#203F2, IRGKangXi=0120.111, RSKangXi=9.14
203F3 CJK UNIFIED IDEOGRAPH-#203F3, IRGKangXi=0120.111, RSKangXi=9.14
203F4 CJK UNIFIED IDEOGRAPH-#203F4, IRGKangXi=0120.111, RSKangXi=9.14
203F5 CJK UNIFIED IDEOGRAPH-#203F5, IRGKangXi=0120.111, RSKangXi=9.14
203F6 CJK UNIFIED IDEOGRAPH-#203F6, IRGKangXi=0120.111, RSKangXi=9.14
203F7 CJK UNIFIED IDEOGRAPH-#203F7, IRGKangXi=0120.111, RSKangXi=9.14
203F8 CJK UNIFIED IDEOGRAPH-#203F8, IRGKangXi=0120.111, RSKangXi=9.14
203F9 CJK UNIFIED IDEOGRAPH-#203F9, IRGKangXi=0120.111, RSKangXi=9.14
203FA CJK UNIFIED IDEOGRAPH-#203FA, IRGKangXi=0120.111, RSKangXi=9.14
203FB CJK UNIFIED IDEOGRAPH-#203FB, IRGKangXi=0120.111, RSKangXi=9.14
203FC CJK UNIFIED IDEOGRAPH-#203FC, IRGKangXi=0120.111, RSKangXi=9.14
203FD CJK UNIFIED IDEOGRAPH-#203FD, IRGKangXi=0120.111, RSKangXi=9.14
203FE CJK UNIFIED IDEOGRAPH-#203FE, IRGKangXi=0120.111, RSKangXi=9.14
203FF CJK UNIFIED IDEOGRAPH-#203FF, IRGKangXi=0120.111, RSKangXi=9.14
20400 CJK UNIFIED IDEOGRAPH-#20400, IRGKangXi=0120.111, RSKangXi=9.14
20401 CJK UNIFIED IDEOGRAPH-#20401, IRGKangXi=0120.111, RSKangXi=9.14
20402 CJK UNIFIED IDEOGRAPH-#20402, IRGKangXi=0120.111, RSKangXi=9.14
20403 CJK UNIFIED IDEOGRAPH-#20403, IRGKangXi=0120.111, RSKangXi=9.14
20404 CJK UNIFIED IDEOGRAPH-#20404, IRGKangXi=0120.111, RSKangXi=9.14
20405 CJK UNIFIED IDEOGRAPH-#20405, IRGKangXi=0120.111, RSKangXi=9.14
20406 CJK UNIFIED IDEOGRAPH-#20406, IRGKangXi=0120.111, RSKangXi=9.14
20407 CJK UNIFIED IDEOGRAPH-#20407, IRGKangXi=0120.111, RSKangXi=9.14
20408 CJK UNIFIED IDEOGRAPH-#20408, IRGKangXi=0120.140, RSKangXi=9.15
20409 CJK UNIFIED IDEOGRAPH-#20409, IRGKangXi=0120.170, RSKangXi=9.15
2040A CJK UNIFIED IDEOGRAPH-#2040A, IRGKangXi=0120.230, RSKangXi=9.15
2040B CJK UNIFIED IDEOGRAPH-#2040B, IRGKangXi=0121.010, RSKangXi=9.15
2040C CJK UNIFIED IDEOGRAPH-#2040C, IRGKangXi=0121.020, RSKangXi=9.15
2040D CJK UNIFIED IDEOGRAPH-#2040D, IRGKangXi=0121.030, RSKangXi=9.15
2040E CJK UNIFIED IDEOGRAPH-#2040E, IRGKangXi=0121.050, RSKangXi=9.15
2040F CJK UNIFIED IDEOGRAPH-#2040F, IRGKangXi=0121.060, RSKangXi=9.15
20410 CJK UNIFIED IDEOGRAPH-#20410, IRGKangXi=0121.061, RSKangXi=9.15
20411 CJK UNIFIED IDEOGRAPH-#20411, IRGKangXi=0121.061, RSKangXi=9.15
20412 CJK UNIFIED IDEOGRAPH-#20412, IRGKangXi=0121.061, RSKangXi=9.15
20413 CJK UNIFIED IDEOGRAPH-#20413, IRGKangXi=0121.061, RSKangXi=9.15
20414 CJK UNIFIED IDEOGRAPH-#20414, IRGKangXi=0121.061, RSKangXi=9.15
20415 CJK UNIFIED IDEOGRAPH-#20415, IRGKangXi=0121.061, RSKangXi=9.15
20416 CJK UNIFIED IDEOGRAPH-#20416, IRGKangXi=0121.061, RSKangXi=9.15
20417 CJK UNIFIED IDEOGRAPH-#20417, IRGKangXi=0121.061, RSKangXi=9.15
20418 CJK UNIFIED IDEOGRAPH-#20418, IRGKangXi=0121.061, RSKangXi=9.15
20419 CJK UNIFIED IDEOGRAPH-#20419, IRGKangXi=0121.061, RSKangXi=9.15
2041A CJK UNIFIED IDEOGRAPH-#2041A, IRGKangXi=0121.061, RSKangXi=9.15
2041B CJK UNIFIED IDEOGRAPH-#2041B, IRGKangXi=0121.061, RSKangXi=9.15
2041C CJK UNIFIED IDEOGRAPH-#2041C, IRGKangXi=0121.061, RSKangXi=149.10
2041D CJK UNIFIED IDEOGRAPH-#2041D, IRGKangXi=0121.061, RSKangXi=9.15
2041E CJK UNIFIED IDEOGRAPH-#2041E, IRGKangXi=0121.061, RSKangXi=9.15
2041F CJK UNIFIED IDEOGRAPH-#2041F, IRGKangXi=0121.061, RSKangXi=9.15
20420 CJK UNIFIED IDEOGRAPH-#20420, IRGKangXi=0121.061, RSKangXi=9.15
20421 CJK UNIFIED IDEOGRAPH-#20421, IRGKangXi=0121.061, RSKangXi=9.15
20422 CJK UNIFIED IDEOGRAPH-#20422, IRGKangXi=0121.080, RSKangXi=9.15
20423 CJK UNIFIED IDEOGRAPH-#20423, IRGKangXi=0121.090, RSKangXi=9.16
20424 CJK UNIFIED IDEOGRAPH-#20424, IRGKangXi=0121.120, RSKangXi=9.16
20425 CJK UNIFIED IDEOGRAPH-#20425, IRGKangXi=0121.150, RSKangXi=9.16
20426 CJK UNIFIED IDEOGRAPH-#20426, IRGKangXi=0121.180, RSKangXi=9.16
20427 CJK UNIFIED IDEOGRAPH-#20427, IRGKangXi=0121.190, RSKangXi=9.16
20428 CJK UNIFIED IDEOGRAPH-#20428, IRGKangXi=0121.210, RSKangXi=9.16
20429 CJK UNIFIED IDEOGRAPH-#20429, IRGKangXi=0121.211, RSKangXi=9.16
2042A CJK UNIFIED IDEOGRAPH-#2042A, IRGKangXi=0121.211, RSKangXi=9.16
2042B CJK UNIFIED IDEOGRAPH-#2042B, IRGKangXi=0121.211, RSKangXi=9.16
2042C CJK UNIFIED IDEOGRAPH-#2042C, IRGKangXi=0121.211, RSKangXi=9.16
2042D CJK UNIFIED IDEOGRAPH-#2042D, IRGKangXi=0121.211, RSKangXi=9.16
2042E CJK UNIFIED IDEOGRAPH-#2042E, IRGKangXi=0121.211, RSKangXi=9.16
2042F CJK UNIFIED IDEOGRAPH-#2042F, IRGKangXi=0121.211, RSKangXi=9.16
20430 CJK UNIFIED IDEOGRAPH-#20430, IRGKangXi=0121.211, RSKangXi=9.16
20431 CJK UNIFIED IDEOGRAPH-#20431, IRGKangXi=0121.211, RSKangXi=9.16
20432 CJK UNIFIED IDEOGRAPH-#20432, IRGKangXi=0121.211, RSKangXi=9.16
20433 CJK UNIFIED IDEOGRAPH-#20433, IRGKangXi=0121.211, RSKangXi=9.16
20434 CJK UNIFIED IDEOGRAPH-#20434, IRGKangXi=0121.211, RSKangXi=9.16
20435 CJK UNIFIED IDEOGRAPH-#20435, IRGKangXi=0121.211, RSKangXi=9.16
20436 CJK UNIFIED IDEOGRAPH-#20436, IRGKangXi=0121.211, RSKangXi=9.16
20437 CJK UNIFIED IDEOGRAPH-#20437, IRGKangXi=0121.211, RSKangXi=9.16
20438 CJK UNIFIED IDEOGRAPH-#20438, IRGKangXi=0121.211, RSKangXi=9.16
20439 CJK UNIFIED IDEOGRAPH-#20439, IRGKangXi=0121.211, RSKangXi=9.16
2043A CJK UNIFIED IDEOGRAPH-#2043A, IRGKangXi=0121.211, RSKangXi=9.16
2043B CJK UNIFIED IDEOGRAPH-#2043B, IRGKangXi=0121.220, RSKangXi=9.17
2043C CJK UNIFIED IDEOGRAPH-#2043C, IRGKangXi=0121.230, RSKangXi=9.17
2043D CJK UNIFIED IDEOGRAPH-#2043D, IRGKangXi=0121.240, RSKangXi=9.17
2043E CJK UNIFIED IDEOGRAPH-#2043E, IRGKangXi=0121.250, RSKangXi=9.17
2043F CJK UNIFIED IDEOGRAPH-#2043F, IRGKangXi=0121.280, RSKangXi=9.17
20440 CJK UNIFIED IDEOGRAPH-#20440, IRGKangXi=0121.291, RSKangXi=9.17
20441 CJK UNIFIED IDEOGRAPH-#20441, IRGKangXi=0121.291, RSKangXi=9.17
20442 CJK UNIFIED IDEOGRAPH-#20442, IRGKangXi=0121.291, RSKangXi=89.15
20443 CJK UNIFIED IDEOGRAPH-#20443, IRGKangXi=0121.291, RSKangXi=9.17
20444 CJK UNIFIED IDEOGRAPH-#20444, IRGKangXi=0121.291, RSKangXi=9.17
20445 CJK UNIFIED IDEOGRAPH-#20445, IRGKangXi=0121.291, RSKangXi=9.17
20446 CJK UNIFIED IDEOGRAPH-#20446, IRGKangXi=0121.291, RSKangXi=9.17
20447 CJK UNIFIED IDEOGRAPH-#20447, IRGKangXi=0121.291, RSKangXi=9.17
20448 CJK UNIFIED IDEOGRAPH-#20448, IRGKangXi=0121.291, RSKangXi=9.17
20449 CJK UNIFIED IDEOGRAPH-#20449, IRGKangXi=0121.291, RSKangXi=9.17
2044A CJK UNIFIED IDEOGRAPH-#2044A, IRGKangXi=0121.291, RSKangXi=9.17
2044B CJK UNIFIED IDEOGRAPH-#2044B, IRGKangXi=0121.291, RSKangXi=9.17
2044C CJK UNIFIED IDEOGRAPH-#2044C, IRGKangXi=0121.291, RSKangXi=9.17
2044D CJK UNIFIED IDEOGRAPH-#2044D, IRGKangXi=0121.300, RSKangXi=9.18
2044E CJK UNIFIED IDEOGRAPH-#2044E, IRGKangXi=0121.350, RSKangXi=9.18
2044F CJK UNIFIED IDEOGRAPH-#2044F, IRGKangXi=0121.351, RSKangXi=9.18
20450 CJK UNIFIED IDEOGRAPH-#20450, IRGKangXi=0121.351, RSKangXi=9.18
20451 CJK UNIFIED IDEOGRAPH-#20451, IRGKangXi=0121.351, RSKangXi=9.18
20452 CJK UNIFIED IDEOGRAPH-#20452, IRGKangXi=0121.351, RSKangXi=9.18
20453 CJK UNIFIED IDEOGRAPH-#20453, IRGKangXi=0121.351, RSKangXi=9.18
20454 CJK UNIFIED IDEOGRAPH-#20454, IRGKangXi=0121.351, RSKangXi=9.18
20455 CJK UNIFIED IDEOGRAPH-#20455, IRGKangXi=0121.351, RSKangXi=9.18
20456 CJK UNIFIED IDEOGRAPH-#20456, IRGKangXi=0121.351, RSKangXi=9.18
20457 CJK UNIFIED IDEOGRAPH-#20457, IRGKangXi=0121.390, RSKangXi=9.19
20458 CJK UNIFIED IDEOGRAPH-#20458, IRGKangXi=0121.410, RSKangXi=9.19
20459 CJK UNIFIED IDEOGRAPH-#20459, IRGKangXi=0122.010, RSKangXi=9.19
2045A CJK UNIFIED IDEOGRAPH-#2045A, IRGKangXi=0122.020, RSKangXi=9.19
2045B CJK UNIFIED IDEOGRAPH-#2045B, IRGKangXi=0122.030, RSKangXi=9.19
2045C CJK UNIFIED IDEOGRAPH-#2045C, IRGKangXi=0122.031, RSKangXi=9.19
2045D CJK UNIFIED IDEOGRAPH-#2045D, IRGKangXi=0122.031, RSKangXi=9.19
2045E CJK UNIFIED IDEOGRAPH-#2045E, IRGKangXi=0122.031, RSKangXi=9.18
2045F CJK UNIFIED IDEOGRAPH-#2045F, IRGKangXi=0122.031, RSKangXi=9.19
20460 CJK UNIFIED IDEOGRAPH-#20460, IRGKangXi=0122.031, RSKangXi=9.19
20461 CJK UNIFIED IDEOGRAPH-#20461, IRGKangXi=0122.031, RSKangXi=9.19
20462 CJK UNIFIED IDEOGRAPH-#20462, IRGKangXi=0122.031, RSKangXi=9.19
20463 CJK UNIFIED IDEOGRAPH-#20463, IRGKangXi=0122.031, RSKangXi=9.19
20464 CJK UNIFIED IDEOGRAPH-#20464, IRGKangXi=0122.061, RSKangXi=9.20
20465 CJK UNIFIED IDEOGRAPH-#20465, IRGKangXi=0122.061, RSKangXi=9.20
20466 CJK UNIFIED IDEOGRAPH-#20466, IRGKangXi=0122.061, RSKangXi=9.20
20467 CJK UNIFIED IDEOGRAPH-#20467, IRGKangXi=0122.061, RSKangXi=9.20
20468 CJK UNIFIED IDEOGRAPH-#20468, IRGKangXi=0122.061, RSKangXi=9.20
20469 CJK UNIFIED IDEOGRAPH-#20469, IRGKangXi=0122.061, RSKangXi=9.20
2046A CJK UNIFIED IDEOGRAPH-#2046A, IRGKangXi=0122.070, RSKangXi=9.21
2046B CJK UNIFIED IDEOGRAPH-#2046B, IRGKangXi=0122.090, RSKangXi=9.21
2046C CJK UNIFIED IDEOGRAPH-#2046C, IRGKangXi=0122.101, RSKangXi=9.21
2046D CJK UNIFIED IDEOGRAPH-#2046D, IRGKangXi=0122.101, RSKangXi=9.21
2046E CJK UNIFIED IDEOGRAPH-#2046E, IRGKangXi=0122.101, RSKangXi=9.21
2046F CJK UNIFIED IDEOGRAPH-#2046F, IRGKangXi=0122.101, RSKangXi=9.21
20470 CJK UNIFIED IDEOGRAPH-#20470, IRGKangXi=0122.111, RSKangXi=9.22
20471 CJK UNIFIED IDEOGRAPH-#20471, IRGKangXi=0122.111, RSKangXi=73.21
20472 CJK UNIFIED IDEOGRAPH-#20472, IRGKangXi=0122.130, RSKangXi=9.24
20473 CJK UNIFIED IDEOGRAPH-#20473, IRGKangXi=0122.131, RSKangXi=9.24
20474 CJK UNIFIED IDEOGRAPH-#20474, IRGKangXi=0122.131, RSKangXi=142.23
20475 CJK UNIFIED IDEOGRAPH-#20475, IRGKangXi=0122.131, RSKangXi=9.27
20476 CJK UNIFIED IDEOGRAPH-#20476, IRGKangXi=0123.070, RSKangXi=10.2
20477 CJK UNIFIED IDEOGRAPH-#20477, IRGKangXi=0123.080, RSKangXi=10.3
20478 CJK UNIFIED IDEOGRAPH-#20478, IRGKangXi=0123.101, RSKangXi=10.3
20479 CJK UNIFIED IDEOGRAPH-#20479, IRGKangXi=0124.020, RSKangXi=10.4
2047A CJK UNIFIED IDEOGRAPH-#2047A, IRGKangXi=0124.120, RSKangXi=10.4
2047B CJK UNIFIED IDEOGRAPH-#2047B, IRGKangXi=0124.130, RSKangXi=10.4
2047C CJK UNIFIED IDEOGRAPH-#2047C, IRGKangXi=0124.141, RSKangXi=10.4
2047D CJK UNIFIED IDEOGRAPH-#2047D, IRGKangXi=0124.220, RSKangXi=10.5
2047E CJK UNIFIED IDEOGRAPH-#2047E, IRGKangXi=0124.250, RSKangXi=10.5
2047F CJK UNIFIED IDEOGRAPH-#2047F, IRGKangXi=0124.260, RSKangXi=10.5
20480 CJK UNIFIED IDEOGRAPH-#20480, IRGKangXi=0125.020, RSKangXi=10.5
20481 CJK UNIFIED IDEOGRAPH-#20481, IRGKangXi=0125.021, RSKangXi=10.5
20482 CJK UNIFIED IDEOGRAPH-#20482, IRGKangXi=0125.021, RSKangXi=10.5
20483 CJK UNIFIED IDEOGRAPH-#20483, IRGKangXi=0125.100, RSKangXi=10.6
20484 CJK UNIFIED IDEOGRAPH-#20484, IRGKangXi=0125.110, RSKangXi=10.6
20485 CJK UNIFIED IDEOGRAPH-#20485, IRGKangXi=0125.120, RSKangXi=10.6
20486 CJK UNIFIED IDEOGRAPH-#20486, IRGKangXi=0125.130, RSKangXi=10.6
20487 CJK UNIFIED IDEOGRAPH-#20487, IRGKangXi=0125.131, RSKangXi=10.6
20488 CJK UNIFIED IDEOGRAPH-#20488, IRGKangXi=0125.131, RSKangXi=10.6
20489 CJK UNIFIED IDEOGRAPH-#20489, IRGKangXi=0125.131, RSKangXi=10.6
2048A CJK UNIFIED IDEOGRAPH-#2048A, IRGKangXi=0125.131, RSKangXi=10.6
2048B CJK UNIFIED IDEOGRAPH-#2048B, IRGKangXi=0125.131, RSKangXi=10.6
2048C CJK UNIFIED IDEOGRAPH-#2048C, IRGKangXi=0125.140, RSKangXi=10.7
2048D CJK UNIFIED IDEOGRAPH-#2048D, IRGKangXi=0125.160, RSKangXi=10.7
2048E CJK UNIFIED IDEOGRAPH-#2048E, IRGKangXi=0125.171, RSKangXi=10.7
2048F CJK UNIFIED IDEOGRAPH-#2048F, IRGKangXi=0125.171, RSKangXi=10.7
20490 CJK UNIFIED IDEOGRAPH-#20490, IRGKangXi=0125.191, RSKangXi=10.8
20491 CJK UNIFIED IDEOGRAPH-#20491, IRGKangXi=0125.191, RSKangXi=10.8
20492 CJK UNIFIED IDEOGRAPH-#20492, IRGKangXi=0125.191, RSKangXi=10.8
20493 CJK UNIFIED IDEOGRAPH-#20493, IRGKangXi=0125.191, RSKangXi=10.8
20494 CJK UNIFIED IDEOGRAPH-#20494, IRGKangXi=0125.191, RSKangXi=10.8
20495 CJK UNIFIED IDEOGRAPH-#20495, IRGKangXi=0125.191, RSKangXi=10.8
20496 CJK UNIFIED IDEOGRAPH-#20496, IRGKangXi=0125.191, RSKangXi=10.8
20497 CJK UNIFIED IDEOGRAPH-#20497, IRGKangXi=0125.201, RSKangXi=10.9
20498 CJK UNIFIED IDEOGRAPH-#20498, IRGKangXi=0125.201, RSKangXi=10.9
20499 CJK UNIFIED IDEOGRAPH-#20499, IRGKangXi=0125.201, RSKangXi=10.9
2049A CJK UNIFIED IDEOGRAPH-#2049A, IRGKangXi=0125.201, RSKangXi=10.9
2049B CJK UNIFIED IDEOGRAPH-#2049B, IRGKangXi=0125.201, RSKangXi=10.9
2049C CJK UNIFIED IDEOGRAPH-#2049C, IRGKangXi=0125.201, RSKangXi=10.9
2049D CJK UNIFIED IDEOGRAPH-#2049D, IRGKangXi=0125.201, RSKangXi=10.9
2049E CJK UNIFIED IDEOGRAPH-#2049E, IRGKangXi=0125.211, RSKangXi=10.10
2049F CJK UNIFIED IDEOGRAPH-#2049F, IRGKangXi=0125.211, RSKangXi=10.10
204A0 CJK UNIFIED IDEOGRAPH-#204A0, IRGKangXi=0125.211, RSKangXi=10.10
204A1 CJK UNIFIED IDEOGRAPH-#204A1, IRGKangXi=0125.211, RSKangXi=10.10
204A2 CJK UNIFIED IDEOGRAPH-#204A2, IRGKangXi=0125.211, RSKangXi=10.10
204A3 CJK UNIFIED IDEOGRAPH-#204A3, IRGKangXi=0125.211, RSKangXi=10.10
204A4 CJK UNIFIED IDEOGRAPH-#204A4, IRGKangXi=0125.211, RSKangXi=10.11
204A5 CJK UNIFIED IDEOGRAPH-#204A5, IRGKangXi=0125.211, RSKangXi=10.11
204A6 CJK UNIFIED IDEOGRAPH-#204A6, IRGKangXi=0125.211, RSKangXi=10.11
204A7 CJK UNIFIED IDEOGRAPH-#204A7, IRGKangXi=0125.240, RSKangXi=10.12
204A8 CJK UNIFIED IDEOGRAPH-#204A8, IRGKangXi=0125.250, RSKangXi=10.12
204A9 CJK UNIFIED IDEOGRAPH-#204A9, IRGKangXi=0125.251, RSKangXi=10.12
204AA CJK UNIFIED IDEOGRAPH-#204AA, IRGKangXi=0125.251, RSKangXi=10.12
204AB CJK UNIFIED IDEOGRAPH-#204AB, IRGKangXi=0125.251, RSKangXi=10.12
204AC CJK UNIFIED IDEOGRAPH-#204AC, IRGKangXi=0125.251, RSKangXi=10.12
204AD CJK UNIFIED IDEOGRAPH-#204AD, IRGKangXi=0125.251, RSKangXi=10.12
204AE CJK UNIFIED IDEOGRAPH-#204AE, IRGKangXi=0125.251, RSKangXi=10.12
204AF CJK UNIFIED IDEOGRAPH-#204AF, IRGKangXi=0125.251, RSKangXi=10.12
204B0 CJK UNIFIED IDEOGRAPH-#204B0, IRGKangXi=0125.260, RSKangXi=10.13
204B1 CJK UNIFIED IDEOGRAPH-#204B1, IRGKangXi=0125.270, RSKangXi=10.13
204B2 CJK UNIFIED IDEOGRAPH-#204B2, IRGKangXi=0125.271, RSKangXi=10.13
204B3 CJK UNIFIED IDEOGRAPH-#204B3, IRGKangXi=0125.271, RSKangXi=10.14
204B4 CJK UNIFIED IDEOGRAPH-#204B4, IRGKangXi=0125.271, RSKangXi=10.13
204B5 CJK UNIFIED IDEOGRAPH-#204B5, IRGKangXi=0125.271, RSKangXi=10.13
204B6 CJK UNIFIED IDEOGRAPH-#204B6, IRGKangXi=0125.271, RSKangXi=10.13
204B7 CJK UNIFIED IDEOGRAPH-#204B7, IRGKangXi=0125.271, RSKangXi=10.13
204B8 CJK UNIFIED IDEOGRAPH-#204B8, IRGKangXi=0125.280, RSKangXi=10.14
204B9 CJK UNIFIED IDEOGRAPH-#204B9, IRGKangXi=0125.281, RSKangXi=10.14
204BA CJK UNIFIED IDEOGRAPH-#204BA, IRGKangXi=0125.281, RSKangXi=10.14
204BB CJK UNIFIED IDEOGRAPH-#204BB, IRGKangXi=0125.281, RSKangXi=10.14
204BC CJK UNIFIED IDEOGRAPH-#204BC, IRGKangXi=0125.281, RSKangXi=10.14
204BD CJK UNIFIED IDEOGRAPH-#204BD, IRGKangXi=0125.281, RSKangXi=10.14
204BE CJK UNIFIED IDEOGRAPH-#204BE, IRGKangXi=0125.281, RSKangXi=10.14
204BF CJK UNIFIED IDEOGRAPH-#204BF, IRGKangXi=0125.281, RSKangXi=10.15
204C0 CJK UNIFIED IDEOGRAPH-#204C0, IRGKangXi=0125.281, RSKangXi=10.15
204C1 CJK UNIFIED IDEOGRAPH-#204C1, IRGKangXi=0125.281, RSKangXi=10.15
204C2 CJK UNIFIED IDEOGRAPH-#204C2, IRGKangXi=0125.281, RSKangXi=10.15
204C3 CJK UNIFIED IDEOGRAPH-#204C3, IRGKangXi=0125.281, RSKangXi=10.15
204C4 CJK UNIFIED IDEOGRAPH-#204C4, IRGKangXi=0125.281, RSKangXi=10.15
204C5 CJK UNIFIED IDEOGRAPH-#204C5, IRGKangXi=0125.281, RSKangXi=10.15
204C6 CJK UNIFIED IDEOGRAPH-#204C6, IRGKangXi=0125.290, RSKangXi=10.16
204C7 CJK UNIFIED IDEOGRAPH-#204C7, IRGKangXi=0125.291, RSKangXi=10.15
204C8 CJK UNIFIED IDEOGRAPH-#204C8, IRGKangXi=0125.291, RSKangXi=10.16
204C9 CJK UNIFIED IDEOGRAPH-#204C9, IRGKangXi=0125.291, RSKangXi=10.16
204CA CJK UNIFIED IDEOGRAPH-#204CA, IRGKangXi=0125.291, RSKangXi=10.16
204CB CJK UNIFIED IDEOGRAPH-#204CB, IRGKangXi=0125.291, RSKangXi=10.17
204CC CJK UNIFIED IDEOGRAPH-#204CC, IRGKangXi=0125.291, RSKangXi=53.16
204CD CJK UNIFIED IDEOGRAPH-#204CD, IRGKangXi=0125.291, RSKangXi=10.18
204CE CJK UNIFIED IDEOGRAPH-#204CE, IRGKangXi=0125.291, RSKangXi=10.17
204CF CJK UNIFIED IDEOGRAPH-#204CF, IRGKangXi=0125.291, RSKangXi=10.18
204D0 CJK UNIFIED IDEOGRAPH-#204D0, IRGKangXi=0125.291, RSKangXi=10.18
204D1 CJK UNIFIED IDEOGRAPH-#204D1, IRGKangXi=0125.301, RSKangXi=10.19
204D2 CJK UNIFIED IDEOGRAPH-#204D2, IRGKangXi=0125.301, RSKangXi=10.19
204D3 CJK UNIFIED IDEOGRAPH-#204D3, IRGKangXi=0125.301, RSKangXi=10.20
204D4 CJK UNIFIED IDEOGRAPH-#204D4, IRGKangXi=0125.301, RSKangXi=10.20
204D5 CJK UNIFIED IDEOGRAPH-#204D5, IRGKangXi=0125.301, RSKangXi=10.21
204D6 CJK UNIFIED IDEOGRAPH-#204D6, IRGKangXi=0125.301, RSKangXi=10.21
204D7 CJK UNIFIED IDEOGRAPH-#204D7, IRGKangXi=0125.310, RSKangXi=10.22
204D8 CJK UNIFIED IDEOGRAPH-#204D8, IRGKangXi=0125.311, RSKangXi=10.22
204D9 CJK UNIFIED IDEOGRAPH-#204D9, IRGKangXi=0125.311, RSKangXi=10.22
204DA CJK UNIFIED IDEOGRAPH-#204DA, IRGKangXi=0125.311, RSKangXi=10.24
204DB CJK UNIFIED IDEOGRAPH-#204DB, IRGKangXi=0125.330, RSKangXi=11.1
204DC CJK UNIFIED IDEOGRAPH-#204DC, IRGKangXi=0126.010, RSKangXi=11.2
204DD CJK UNIFIED IDEOGRAPH-#204DD, IRGKangXi=0126.020, RSKangXi=11.2
204DE CJK UNIFIED IDEOGRAPH-#204DE, IRGKangXi=0126.021, RSKangXi=11.2
204DF CJK UNIFIED IDEOGRAPH-#204DF, IRGKangXi=0126.040, RSKangXi=11.3
204E0 CJK UNIFIED IDEOGRAPH-#204E0, IRGKangXi=0126.070, RSKangXi=11.4
204E1 CJK UNIFIED IDEOGRAPH-#204E1, IRGKangXi=0126.090, RSKangXi=11.4
204E2 CJK UNIFIED IDEOGRAPH-#204E2, IRGKangXi=0126.091, RSKangXi=11.4
204E3 CJK UNIFIED IDEOGRAPH-#204E3, IRGKangXi=0126.091, RSKangXi=11.4
204E4 CJK UNIFIED IDEOGRAPH-#204E4, IRGKangXi=0126.110, RSKangXi=11.5
204E5 CJK UNIFIED IDEOGRAPH-#204E5, IRGKangXi=0126.121, RSKangXi=11.5
204E6 CJK UNIFIED IDEOGRAPH-#204E6, IRGKangXi=0126.121, RSKangXi=11.5
204E7 CJK UNIFIED IDEOGRAPH-#204E7, IRGKangXi=0126.121, RSKangXi=11.5
204E8 CJK UNIFIED IDEOGRAPH-#204E8, IRGKangXi=0126.121, RSKangXi=11.5
204E9 CJK UNIFIED IDEOGRAPH-#204E9, IRGKangXi=0126.141, RSKangXi=11.6
204EA CJK UNIFIED IDEOGRAPH-#204EA, IRGKangXi=0126.160, RSKangXi=11.7
204EB CJK UNIFIED IDEOGRAPH-#204EB, IRGKangXi=0126.170, RSKangXi=11.7
204EC CJK UNIFIED IDEOGRAPH-#204EC, IRGKangXi=0126.171, RSKangXi=11.7
204ED CJK UNIFIED IDEOGRAPH-#204ED, IRGKangXi=0126.180, RSKangXi=11.8
204EE CJK UNIFIED IDEOGRAPH-#204EE, IRGKangXi=0126.190, RSKangXi=11.8
204EF CJK UNIFIED IDEOGRAPH-#204EF, IRGKangXi=0126.191, RSKangXi=11.8
204F0 CJK UNIFIED IDEOGRAPH-#204F0, IRGKangXi=0126.191, RSKangXi=11.8
204F1 CJK UNIFIED IDEOGRAPH-#204F1, IRGKangXi=0126.200, RSKangXi=11.9
204F2 CJK UNIFIED IDEOGRAPH-#204F2, IRGKangXi=0126.201, RSKangXi=11.10
204F3 CJK UNIFIED IDEOGRAPH-#204F3, IRGKangXi=0126.201, RSKangXi=11.10
204F4 CJK UNIFIED IDEOGRAPH-#204F4, IRGKangXi=0126.210, RSKangXi=11.11
204F5 CJK UNIFIED IDEOGRAPH-#204F5, IRGKangXi=0126.220, RSKangXi=11.11
204F6 CJK UNIFIED IDEOGRAPH-#204F6, IRGKangXi=0126.230, RSKangXi=11.11
204F7 CJK UNIFIED IDEOGRAPH-#204F7, IRGKangXi=0126.231, RSKangXi=11.11
204F8 CJK UNIFIED IDEOGRAPH-#204F8, IRGKangXi=0126.240, RSKangXi=11.12
204F9 CJK UNIFIED IDEOGRAPH-#204F9, IRGKangXi=0126.241, RSKangXi=11.12
204FA CJK UNIFIED IDEOGRAPH-#204FA, IRGKangXi=0126.241, RSKangXi=11.12
204FB CJK UNIFIED IDEOGRAPH-#204FB, IRGKangXi=0126.241, RSKangXi=11.12
204FC CJK UNIFIED IDEOGRAPH-#204FC, IRGKangXi=0126.241, RSKangXi=11.14, Def{(Cant.) a wedge; to thrust in}
204FD CJK UNIFIED IDEOGRAPH-#204FD, IRGKangXi=0126.250, RSKangXi=11.15
204FE CJK UNIFIED IDEOGRAPH-#204FE, IRGKangXi=0126.251, RSKangXi=11.16
204FF CJK UNIFIED IDEOGRAPH-#204FF, IRGKangXi=0126.251, RSKangXi=11.18
20500 CJK UNIFIED IDEOGRAPH-#20500, IRGKangXi=0126.270, RSKangXi=12.1
20501 CJK UNIFIED IDEOGRAPH-#20501, IRGKangXi=0127.020, RSKangXi=12.2
20502 CJK UNIFIED IDEOGRAPH-#20502, IRGKangXi=0127.031, RSKangXi=12.2
20503 CJK UNIFIED IDEOGRAPH-#20503, IRGKangXi=0127.031, RSKangXi=12.2, Def{an interjection of doubt or inquiry}
20504 CJK UNIFIED IDEOGRAPH-#20504, IRGKangXi=0127.031, RSKangXi=12.2
20505 CJK UNIFIED IDEOGRAPH-#20505, IRGKangXi=0127.040, RSKangXi=12.3
20506 CJK UNIFIED IDEOGRAPH-#20506, IRGKangXi=0127.041, RSKangXi=12.3
20507 CJK UNIFIED IDEOGRAPH-#20507, IRGKangXi=0127.041, RSKangXi=162.0
20508 CJK UNIFIED IDEOGRAPH-#20508, IRGKangXi=0127.080, RSKangXi=12.4
20509 CJK UNIFIED IDEOGRAPH-#20509, IRGKangXi=0127.091, RSKangXi=12.4, Def{a roll}
2050A CJK UNIFIED IDEOGRAPH-#2050A, IRGKangXi=0127.130, RSKangXi=12.5
2050B CJK UNIFIED IDEOGRAPH-#2050B, IRGKangXi=0127.140, RSKangXi=12.5
2050C CJK UNIFIED IDEOGRAPH-#2050C, IRGKangXi=0127.150, RSKangXi=12.5
2050D CJK UNIFIED IDEOGRAPH-#2050D, IRGKangXi=0127.171, RSKangXi=12.5
2050E CJK UNIFIED IDEOGRAPH-#2050E, IRGKangXi=0127.171, RSKangXi=12.5
2050F CJK UNIFIED IDEOGRAPH-#2050F, IRGKangXi=0127.171, RSKangXi=12.5
20510 CJK UNIFIED IDEOGRAPH-#20510, IRGKangXi=0128.040, RSKangXi=12.6
20511 CJK UNIFIED IDEOGRAPH-#20511, IRGKangXi=0128.041, RSKangXi=12.6
20512 CJK UNIFIED IDEOGRAPH-#20512, IRGKangXi=0128.060, RSKangXi=12.7
20513 CJK UNIFIED IDEOGRAPH-#20513, IRGKangXi=0128.070, RSKangXi=12.7
20514 CJK UNIFIED IDEOGRAPH-#20514, IRGKangXi=0128.080, RSKangXi=12.7
20515 CJK UNIFIED IDEOGRAPH-#20515, IRGKangXi=0128.090, RSKangXi=12.7
20516 CJK UNIFIED IDEOGRAPH-#20516, IRGKangXi=0128.100, RSKangXi=12.7
20517 CJK UNIFIED IDEOGRAPH-#20517, IRGKangXi=0128.101, RSKangXi=12.7
20518 CJK UNIFIED IDEOGRAPH-#20518, IRGKangXi=0128.101, RSKangXi=57.6
20519 CJK UNIFIED IDEOGRAPH-#20519, IRGKangXi=0128.130, RSKangXi=12.8
2051A CJK UNIFIED IDEOGRAPH-#2051A, IRGKangXi=0128.140, RSKangXi=12.8
2051B CJK UNIFIED IDEOGRAPH-#2051B, IRGKangXi=0128.150, RSKangXi=12.8
2051C CJK UNIFIED IDEOGRAPH-#2051C, IRGKangXi=0128.160, RSKangXi=12.9
2051D CJK UNIFIED IDEOGRAPH-#2051D, IRGKangXi=0128.161, RSKangXi=12.9
2051E CJK UNIFIED IDEOGRAPH-#2051E, IRGKangXi=0128.170, RSKangXi=12.10
2051F CJK UNIFIED IDEOGRAPH-#2051F, IRGKangXi=0128.180, RSKangXi=12.10
20520 CJK UNIFIED IDEOGRAPH-#20520, IRGKangXi=0128.190, RSKangXi=12.10
20521 CJK UNIFIED IDEOGRAPH-#20521, IRGKangXi=0128.191, RSKangXi=12.10
20522 CJK UNIFIED IDEOGRAPH-#20522, IRGKangXi=0128.191, RSKangXi=12.10
20523 CJK UNIFIED IDEOGRAPH-#20523, IRGKangXi=0128.191, RSKangXi=12.10
20524 CJK UNIFIED IDEOGRAPH-#20524, IRGKangXi=0128.191, RSKangXi=12.10
20525 CJK UNIFIED IDEOGRAPH-#20525, IRGKangXi=0128.191, RSKangXi=12.10
20526 CJK UNIFIED IDEOGRAPH-#20526, IRGKangXi=0128.191, RSKangXi=12.10
20527 CJK UNIFIED IDEOGRAPH-#20527, IRGKangXi=0128.191, RSKangXi=12.10
20528 CJK UNIFIED IDEOGRAPH-#20528, IRGKangXi=0128.210, RSKangXi=12.11
20529 CJK UNIFIED IDEOGRAPH-#20529, IRGKangXi=0128.211, RSKangXi=12.11
2052A CJK UNIFIED IDEOGRAPH-#2052A, IRGKangXi=0128.211, RSKangXi=12.11
2052B CJK UNIFIED IDEOGRAPH-#2052B, IRGKangXi=0128.211, RSKangXi=12.11
2052C CJK UNIFIED IDEOGRAPH-#2052C, IRGKangXi=0128.211, RSKangXi=12.11
2052D CJK UNIFIED IDEOGRAPH-#2052D, IRGKangXi=0128.211, RSKangXi=12.11
2052E CJK UNIFIED IDEOGRAPH-#2052E, IRGKangXi=0128.211, RSKangXi=12.11
2052F CJK UNIFIED IDEOGRAPH-#2052F, IRGKangXi=0128.220, RSKangXi=12.12
20530 CJK UNIFIED IDEOGRAPH-#20530, IRGKangXi=0128.230, RSKangXi=12.12
20531 CJK UNIFIED IDEOGRAPH-#20531, IRGKangXi=0128.231, RSKangXi=12.12
20532 CJK UNIFIED IDEOGRAPH-#20532, IRGKangXi=0128.231, RSKangXi=28.12
20533 CJK UNIFIED IDEOGRAPH-#20533, IRGKangXi=0128.241, RSKangXi=12.14
20534 CJK UNIFIED IDEOGRAPH-#20534, IRGKangXi=0128.241, RSKangXi=12.14
20535 CJK UNIFIED IDEOGRAPH-#20535, IRGKangXi=0128.241, RSKangXi=12.14
20536 CJK UNIFIED IDEOGRAPH-#20536, IRGKangXi=0128.250, RSKangXi=12.16
20537 CJK UNIFIED IDEOGRAPH-#20537, IRGKangXi=0128.251, RSKangXi=12.16
20538 CJK UNIFIED IDEOGRAPH-#20538, IRGKangXi=0128.260, RSKangXi=12.17
20539 CJK UNIFIED IDEOGRAPH-#20539, IRGKangXi=0128.270, RSKangXi=12.17
2053A CJK UNIFIED IDEOGRAPH-#2053A, IRGKangXi=0128.271, RSKangXi=12.17
2053B CJK UNIFIED IDEOGRAPH-#2053B, IRGKangXi=0128.291, RSKangXi=12.62
2053C CJK UNIFIED IDEOGRAPH-#2053C, IRGKangXi=0128.310, RSKangXi=13.1
2053D CJK UNIFIED IDEOGRAPH-#2053D, IRGKangXi=0128.340, RSKangXi=13.2
2053E CJK UNIFIED IDEOGRAPH-#2053E, IRGKangXi=0128.350, RSKangXi=13.2
2053F CJK UNIFIED IDEOGRAPH-#2053F, IRGKangXi=0128.351, RSKangXi=13.2
20540 CJK UNIFIED IDEOGRAPH-#20540, IRGKangXi=0128.351, RSKangXi=13.2
20541 CJK UNIFIED IDEOGRAPH-#20541, IRGKangXi=0129.010, RSKangXi=13.3
20542 CJK UNIFIED IDEOGRAPH-#20542, IRGKangXi=0129.030, RSKangXi=13.3
20543 CJK UNIFIED IDEOGRAPH-#20543, IRGKangXi=0129.040, RSKangXi=13.3
20544 CJK UNIFIED IDEOGRAPH-#20544, IRGKangXi=0129.050, RSKangXi=13.3, Def{(Cant.) 酒𠕄, a dimple}
20545 CJK UNIFIED IDEOGRAPH-#20545, IRGKangXi=0129.051, RSKangXi=13.3
20546 CJK UNIFIED IDEOGRAPH-#20546, IRGKangXi=0129.051, RSKangXi=13.3
20547 CJK UNIFIED IDEOGRAPH-#20547, IRGKangXi=0129.051, RSKangXi=13.3
20548 CJK UNIFIED IDEOGRAPH-#20548, IRGKangXi=0129.051, RSKangXi=13.3
20549 CJK UNIFIED IDEOGRAPH-#20549, IRGKangXi=0129.051, RSKangXi=13.3
2054A CJK UNIFIED IDEOGRAPH-#2054A, IRGKangXi=0129.051, RSKangXi=13.3
2054B CJK UNIFIED IDEOGRAPH-#2054B, IRGKangXi=0129.060, RSKangXi=13.4
2054C CJK UNIFIED IDEOGRAPH-#2054C, IRGKangXi=0129.100, RSKangXi=13.4
2054D CJK UNIFIED IDEOGRAPH-#2054D, IRGKangXi=0129.110, RSKangXi=13.4
2054E CJK UNIFIED IDEOGRAPH-#2054E, IRGKangXi=0129.111, RSKangXi=13.4
2054F CJK UNIFIED IDEOGRAPH-#2054F, IRGKangXi=0129.111, RSKangXi=13.4
20550 CJK UNIFIED IDEOGRAPH-#20550, IRGKangXi=0129.130, RSKangXi=13.5
20551 CJK UNIFIED IDEOGRAPH-#20551, IRGKangXi=0129.140, RSKangXi=13.5
20552 CJK UNIFIED IDEOGRAPH-#20552, IRGKangXi=0129.150, RSKangXi=13.5
20553 CJK UNIFIED IDEOGRAPH-#20553, IRGKangXi=0129.151, RSKangXi=13.5
20554 CJK UNIFIED IDEOGRAPH-#20554, IRGKangXi=0129.151, RSKangXi=13.5
20555 CJK UNIFIED IDEOGRAPH-#20555, IRGKangXi=0129.151, RSKangXi=13.5
20556 CJK UNIFIED IDEOGRAPH-#20556, IRGKangXi=0129.160, RSKangXi=13.6
20557 CJK UNIFIED IDEOGRAPH-#20557, IRGKangXi=0129.180, RSKangXi=13.6
20558 CJK UNIFIED IDEOGRAPH-#20558, IRGKangXi=0129.190, RSKangXi=13.6
20559 CJK UNIFIED IDEOGRAPH-#20559, IRGKangXi=0129.191, RSKangXi=13.6
2055A CJK UNIFIED IDEOGRAPH-#2055A, IRGKangXi=0129.191, RSKangXi=13.6
2055B CJK UNIFIED IDEOGRAPH-#2055B, IRGKangXi=0129.240, RSKangXi=13.7
2055C CJK UNIFIED IDEOGRAPH-#2055C, IRGKangXi=0129.241, RSKangXi=13.7
2055D CJK UNIFIED IDEOGRAPH-#2055D, IRGKangXi=0129.260, RSKangXi=13.8
2055E CJK UNIFIED IDEOGRAPH-#2055E, IRGKangXi=0129.280, RSKangXi=13.8
2055F CJK UNIFIED IDEOGRAPH-#2055F, IRGKangXi=0129.281, RSKangXi=13.8
20560 CJK UNIFIED IDEOGRAPH-#20560, IRGKangXi=0129.310, RSKangXi=13.9
20561 CJK UNIFIED IDEOGRAPH-#20561, IRGKangXi=0129.330, RSKangXi=13.9
20562 CJK UNIFIED IDEOGRAPH-#20562, IRGKangXi=0129.331, RSKangXi=13.9
20563 CJK UNIFIED IDEOGRAPH-#20563, IRGKangXi=0129.340, RSKangXi=13.10
20564 CJK UNIFIED IDEOGRAPH-#20564, IRGKangXi=0129.360, RSKangXi=13.10
20565 CJK UNIFIED IDEOGRAPH-#20565, IRGKangXi=0130.010, RSKangXi=13.10
20566 CJK UNIFIED IDEOGRAPH-#20566, IRGKangXi=0130.030, RSKangXi=13.11
20567 CJK UNIFIED IDEOGRAPH-#20567, IRGKangXi=0130.040, RSKangXi=13.11
20568 CJK UNIFIED IDEOGRAPH-#20568, IRGKangXi=0130.050, RSKangXi=13.12
20569 CJK UNIFIED IDEOGRAPH-#20569, IRGKangXi=0130.051, RSKangXi=13.12
2056A CJK UNIFIED IDEOGRAPH-#2056A, IRGKangXi=0130.051, RSKangXi=13.13
2056B CJK UNIFIED IDEOGRAPH-#2056B, IRGKangXi=0130.060, RSKangXi=13.13
2056C CJK UNIFIED IDEOGRAPH-#2056C, IRGKangXi=0130.061, RSKangXi=13.13
2056D CJK UNIFIED IDEOGRAPH-#2056D, IRGKangXi=0130.070, RSKangXi=13.14
2056E CJK UNIFIED IDEOGRAPH-#2056E, IRGKangXi=0130.080, RSKangXi=13.14
2056F CJK UNIFIED IDEOGRAPH-#2056F, IRGKangXi=0130.081, RSKangXi=13.16
20570 CJK UNIFIED IDEOGRAPH-#20570, IRGKangXi=0130.090, RSKangXi=13.16
20571 CJK UNIFIED IDEOGRAPH-#20571, IRGKangXi=0130.091, RSKangXi=13.18
20572 CJK UNIFIED IDEOGRAPH-#20572, IRGKangXi=0130.110, RSKangXi=13.20
20573 CJK UNIFIED IDEOGRAPH-#20573, IRGKangXi=0130.150, RSKangXi=14.2
20574 CJK UNIFIED IDEOGRAPH-#20574, IRGKangXi=0130.151, RSKangXi=14.2
20575 CJK UNIFIED IDEOGRAPH-#20575, IRGKangXi=0130.160, RSKangXi=14.3
20576 CJK UNIFIED IDEOGRAPH-#20576, IRGKangXi=0130.161, RSKangXi=14.3
20577 CJK UNIFIED IDEOGRAPH-#20577, IRGKangXi=0130.161, RSKangXi=14.3
20578 CJK UNIFIED IDEOGRAPH-#20578, IRGKangXi=0130.161, RSKangXi=14.3
20579 CJK UNIFIED IDEOGRAPH-#20579, IRGKangXi=0130.170, RSKangXi=14.4
2057A CJK UNIFIED IDEOGRAPH-#2057A, IRGKangXi=0130.180, RSKangXi=14.4
2057B CJK UNIFIED IDEOGRAPH-#2057B, IRGKangXi=0130.190, RSKangXi=14.4
2057C CJK UNIFIED IDEOGRAPH-#2057C, IRGKangXi=0130.191, RSKangXi=14.4
2057D CJK UNIFIED IDEOGRAPH-#2057D, IRGKangXi=0130.191, RSKangXi=14.4
2057E CJK UNIFIED IDEOGRAPH-#2057E, IRGKangXi=0130.191, RSKangXi=14.4
2057F CJK UNIFIED IDEOGRAPH-#2057F, IRGKangXi=0130.191, RSKangXi=14.4
20580 CJK UNIFIED IDEOGRAPH-#20580, IRGKangXi=0130.191, RSKangXi=14.4
20581 CJK UNIFIED IDEOGRAPH-#20581, IRGKangXi=0130.191, RSKangXi=14.4
20582 CJK UNIFIED IDEOGRAPH-#20582, IRGKangXi=0130.191, RSKangXi=14.5
20583 CJK UNIFIED IDEOGRAPH-#20583, IRGKangXi=0130.191, RSKangXi=14.4
20584 CJK UNIFIED IDEOGRAPH-#20584, IRGKangXi=0130.200, RSKangXi=14.6
20585 CJK UNIFIED IDEOGRAPH-#20585, IRGKangXi=0130.211, RSKangXi=14.6
20586 CJK UNIFIED IDEOGRAPH-#20586, IRGKangXi=0130.211, RSKangXi=14.6
20587 CJK UNIFIED IDEOGRAPH-#20587, IRGKangXi=0130.231, RSKangXi=14.7
20588 CJK UNIFIED IDEOGRAPH-#20588, IRGKangXi=0130.231, RSKangXi=14.7
20589 CJK UNIFIED IDEOGRAPH-#20589, IRGKangXi=0130.231, RSKangXi=14.7
2058A CJK UNIFIED IDEOGRAPH-#2058A, IRGKangXi=0130.231, RSKangXi=14.7
2058B CJK UNIFIED IDEOGRAPH-#2058B, IRGKangXi=0130.231, RSKangXi=14.7
2058C CJK UNIFIED IDEOGRAPH-#2058C, IRGKangXi=0131.010, RSKangXi=14.8
2058D CJK UNIFIED IDEOGRAPH-#2058D, IRGKangXi=0131.011, RSKangXi=14.8
2058E CJK UNIFIED IDEOGRAPH-#2058E, IRGKangXi=0131.011, RSKangXi=14.8
2058F CJK UNIFIED IDEOGRAPH-#2058F, IRGKangXi=0131.011, RSKangXi=14.8
20590 CJK UNIFIED IDEOGRAPH-#20590, IRGKangXi=0131.011, RSKangXi=14.8
20591 CJK UNIFIED IDEOGRAPH-#20591, IRGKangXi=0131.011, RSKangXi=14.8
20592 CJK UNIFIED IDEOGRAPH-#20592, IRGKangXi=0131.011, RSKangXi=14.8
20593 CJK UNIFIED IDEOGRAPH-#20593, IRGKangXi=0131.020, RSKangXi=14.9
20594 CJK UNIFIED IDEOGRAPH-#20594, IRGKangXi=0131.050, RSKangXi=14.10
20595 CJK UNIFIED IDEOGRAPH-#20595, IRGKangXi=0131.051, RSKangXi=14.10
20596 CJK UNIFIED IDEOGRAPH-#20596, IRGKangXi=0131.051, RSKangXi=14.10
20597 CJK UNIFIED IDEOGRAPH-#20597, IRGKangXi=0131.051, RSKangXi=14.10
20598 CJK UNIFIED IDEOGRAPH-#20598, IRGKangXi=0131.051, RSKangXi=14.10
20599 CJK UNIFIED IDEOGRAPH-#20599, IRGKangXi=0131.051, RSKangXi=14.10
2059A CJK UNIFIED IDEOGRAPH-#2059A, IRGKangXi=0131.060, RSKangXi=14.11
2059B CJK UNIFIED IDEOGRAPH-#2059B, IRGKangXi=0131.061, RSKangXi=14.11
2059C CJK UNIFIED IDEOGRAPH-#2059C, IRGKangXi=0131.070, RSKangXi=14.12
2059D CJK UNIFIED IDEOGRAPH-#2059D, IRGKangXi=0131.071, RSKangXi=14.12
2059E CJK UNIFIED IDEOGRAPH-#2059E, IRGKangXi=0131.071, RSKangXi=14.12
2059F CJK UNIFIED IDEOGRAPH-#2059F, IRGKangXi=0131.081, RSKangXi=113.10
205A0 CJK UNIFIED IDEOGRAPH-#205A0, IRGKangXi=0131.100, RSKangXi=14.14
205A1 CJK UNIFIED IDEOGRAPH-#205A1, IRGKangXi=0131.101, RSKangXi=14.14
205A2 CJK UNIFIED IDEOGRAPH-#205A2, IRGKangXi=0131.101, RSKangXi=14.15
205A3 CJK UNIFIED IDEOGRAPH-#205A3, IRGKangXi=0131.110, RSKangXi=14.16
205A4 CJK UNIFIED IDEOGRAPH-#205A4, IRGKangXi=0131.111, RSKangXi=14.16
205A5 CJK UNIFIED IDEOGRAPH-#205A5, IRGKangXi=0131.111, RSKangXi=14.16, Def{kindness, grace, esteem}
205A6 CJK UNIFIED IDEOGRAPH-#205A6, IRGKangXi=0131.120, RSKangXi=14.18
205A7 CJK UNIFIED IDEOGRAPH-#205A7, IRGKangXi=0131.130, RSKangXi=14.18
205A8 CJK UNIFIED IDEOGRAPH-#205A8, IRGKangXi=0131.131, RSKangXi=14.18
205A9 CJK UNIFIED IDEOGRAPH-#205A9, IRGKangXi=0131.140, RSKangXi=14.19
205AA CJK UNIFIED IDEOGRAPH-#205AA, IRGKangXi=0131.141, RSKangXi=14.20
205AB CJK UNIFIED IDEOGRAPH-#205AB, IRGKangXi=0131.141, RSKangXi=14.21
205AC CJK UNIFIED IDEOGRAPH-#205AC, IRGKangXi=0131.151, RSKangXi=15.1
205AD CJK UNIFIED IDEOGRAPH-#205AD, IRGKangXi=0131.161, RSKangXi=15.2
205AE CJK UNIFIED IDEOGRAPH-#205AE, IRGKangXi=0131.231, RSKangXi=15.3
205AF CJK UNIFIED IDEOGRAPH-#205AF, IRGKangXi=0131.231, RSKangXi=15.3
205B0 CJK UNIFIED IDEOGRAPH-#205B0, IRGKangXi=0131.231, RSKangXi=15.3
205B1 CJK UNIFIED IDEOGRAPH-#205B1, IRGKangXi=0131.270, RSKangXi=15.4
205B2 CJK UNIFIED IDEOGRAPH-#205B2, IRGKangXi=0131.291, RSKangXi=15.4
205B3 CJK UNIFIED IDEOGRAPH-#205B3, IRGKangXi=0131.291, RSKangXi=15.4
205B4 CJK UNIFIED IDEOGRAPH-#205B4, IRGKangXi=0131.291, RSKangXi=15.4
205B5 CJK UNIFIED IDEOGRAPH-#205B5, IRGKangXi=0131.291, RSKangXi=15.4
205B6 CJK UNIFIED IDEOGRAPH-#205B6, IRGKangXi=0131.291, RSKangXi=15.4
205B7 CJK UNIFIED IDEOGRAPH-#205B7, IRGKangXi=0132.050, RSKangXi=15.5
205B8 CJK UNIFIED IDEOGRAPH-#205B8, IRGKangXi=0132.060, RSKangXi=15.5
205B9 CJK UNIFIED IDEOGRAPH-#205B9, IRGKangXi=0132.070, RSKangXi=15.5
205BA CJK UNIFIED IDEOGRAPH-#205BA, IRGKangXi=0132.071, RSKangXi=15.5
205BB CJK UNIFIED IDEOGRAPH-#205BB, IRGKangXi=0132.071, RSKangXi=15.5
205BC CJK UNIFIED IDEOGRAPH-#205BC, IRGKangXi=0132.071, RSKangXi=15.5
205BD CJK UNIFIED IDEOGRAPH-#205BD, IRGKangXi=0132.071, RSKangXi=15.5
205BE CJK UNIFIED IDEOGRAPH-#205BE, IRGKangXi=0132.071, RSKangXi=15.5
205BF CJK UNIFIED IDEOGRAPH-#205BF, IRGKangXi=0132.071, RSKangXi=15.5
205C0 CJK UNIFIED IDEOGRAPH-#205C0, IRGKangXi=0132.071, RSKangXi=15.6
205C1 CJK UNIFIED IDEOGRAPH-#205C1, IRGKangXi=0132.071, RSKangXi=15.5
205C2 CJK UNIFIED IDEOGRAPH-#205C2, IRGKangXi=0132.100, RSKangXi=15.6
205C3 CJK UNIFIED IDEOGRAPH-#205C3, IRGKangXi=0132.120, RSKangXi=15.6
205C4 CJK UNIFIED IDEOGRAPH-#205C4, IRGKangXi=0132.140, RSKangXi=15.6
205C5 CJK UNIFIED IDEOGRAPH-#205C5, IRGKangXi=0132.160, RSKangXi=15.6
205C6 CJK UNIFIED IDEOGRAPH-#205C6, IRGKangXi=0132.200, RSKangXi=15.6
205C7 CJK UNIFIED IDEOGRAPH-#205C7, IRGKangXi=0132.201, RSKangXi=15.6
205C8 CJK UNIFIED IDEOGRAPH-#205C8, IRGKangXi=0132.210, RSKangXi=15.7
205C9 CJK UNIFIED IDEOGRAPH-#205C9, IRGKangXi=0132.230, RSKangXi=15.7
205CA CJK UNIFIED IDEOGRAPH-#205CA, IRGKangXi=0132.240, RSKangXi=15.7
205CB CJK UNIFIED IDEOGRAPH-#205CB, IRGKangXi=0132.250, RSKangXi=15.7
205CC CJK UNIFIED IDEOGRAPH-#205CC, IRGKangXi=0132.260, RSKangXi=15.7
205CD CJK UNIFIED IDEOGRAPH-#205CD, IRGKangXi=0132.270, RSKangXi=15.7
205CE CJK UNIFIED IDEOGRAPH-#205CE, IRGKangXi=0132.300, RSKangXi=15.7
205CF CJK UNIFIED IDEOGRAPH-#205CF, IRGKangXi=0132.310, RSKangXi=15.7
205D0 CJK UNIFIED IDEOGRAPH-#205D0, IRGKangXi=0132.311, RSKangXi=15.7
205D1 CJK UNIFIED IDEOGRAPH-#205D1, IRGKangXi=0132.311, RSKangXi=15.7
205D2 CJK UNIFIED IDEOGRAPH-#205D2, IRGKangXi=0132.311, RSKangXi=15.7
205D3 CJK UNIFIED IDEOGRAPH-#205D3, IRGKangXi=0132.311, RSKangXi=15.7
205D4 CJK UNIFIED IDEOGRAPH-#205D4, IRGKangXi=0132.311, RSKangXi=15.7
205D5 CJK UNIFIED IDEOGRAPH-#205D5, IRGKangXi=0132.311, RSKangXi=15.7
205D6 CJK UNIFIED IDEOGRAPH-#205D6, IRGKangXi=0132.311, RSKangXi=15.7
205D7 CJK UNIFIED IDEOGRAPH-#205D7, IRGKangXi=0132.311, RSKangXi=15.7
205D8 CJK UNIFIED IDEOGRAPH-#205D8, IRGKangXi=0132.320, RSKangXi=15.8
205D9 CJK UNIFIED IDEOGRAPH-#205D9, IRGKangXi=0132.380, RSKangXi=15.8
205DA CJK UNIFIED IDEOGRAPH-#205DA, IRGKangXi=0132.430, RSKangXi=15.8
205DB CJK UNIFIED IDEOGRAPH-#205DB, IRGKangXi=0132.470, RSKangXi=15.8
205DC CJK UNIFIED IDEOGRAPH-#205DC, IRGKangXi=0132.480, RSKangXi=15.8
205DD CJK UNIFIED IDEOGRAPH-#205DD, IRGKangXi=0133.010, RSKangXi=15.8
205DE CJK UNIFIED IDEOGRAPH-#205DE, IRGKangXi=0133.011, RSKangXi=15.8
205DF CJK UNIFIED IDEOGRAPH-#205DF, IRGKangXi=0133.011, RSKangXi=15.8
205E0 CJK UNIFIED IDEOGRAPH-#205E0, IRGKangXi=0133.011, RSKangXi=15.8
205E1 CJK UNIFIED IDEOGRAPH-#205E1, IRGKangXi=0133.011, RSKangXi=15.8
205E2 CJK UNIFIED IDEOGRAPH-#205E2, IRGKangXi=0133.011, RSKangXi=15.8
205E3 CJK UNIFIED IDEOGRAPH-#205E3, IRGKangXi=0133.011, RSKangXi=15.8
205E4 CJK UNIFIED IDEOGRAPH-#205E4, IRGKangXi=0133.011, RSKangXi=15.8
205E5 CJK UNIFIED IDEOGRAPH-#205E5, IRGKangXi=0133.030, RSKangXi=15.9
205E6 CJK UNIFIED IDEOGRAPH-#205E6, IRGKangXi=0133.040, RSKangXi=15.9, Def{to lean on; to trust in}
205E7 CJK UNIFIED IDEOGRAPH-#205E7, IRGKangXi=0133.060, RSKangXi=15.9
205E8 CJK UNIFIED IDEOGRAPH-#205E8, IRGKangXi=0133.080, RSKangXi=15.9
205E9 CJK UNIFIED IDEOGRAPH-#205E9, IRGKangXi=0133.090, RSKangXi=15.9
205EA CJK UNIFIED IDEOGRAPH-#205EA, IRGKangXi=0133.091, RSKangXi=15.9
205EB CJK UNIFIED IDEOGRAPH-#205EB, IRGKangXi=0133.091, RSKangXi=15.9
205EC CJK UNIFIED IDEOGRAPH-#205EC, IRGKangXi=0133.091, RSKangXi=15.9
205ED CJK UNIFIED IDEOGRAPH-#205ED, IRGKangXi=0133.091, RSKangXi=15.9
205EE CJK UNIFIED IDEOGRAPH-#205EE, IRGKangXi=0133.091, RSKangXi=15.9
205EF CJK UNIFIED IDEOGRAPH-#205EF, IRGKangXi=0133.091, RSKangXi=15.9
205F0 CJK UNIFIED IDEOGRAPH-#205F0, IRGKangXi=0133.091, RSKangXi=15.9
205F1 CJK UNIFIED IDEOGRAPH-#205F1, IRGKangXi=0133.110, RSKangXi=15.10
205F2 CJK UNIFIED IDEOGRAPH-#205F2, IRGKangXi=0133.160, RSKangXi=15.10
205F3 CJK UNIFIED IDEOGRAPH-#205F3, IRGKangXi=0133.170, RSKangXi=15.10
205F4 CJK UNIFIED IDEOGRAPH-#205F4, IRGKangXi=0133.180, RSKangXi=15.10
205F5 CJK UNIFIED IDEOGRAPH-#205F5, IRGKangXi=0133.200, RSKangXi=15.10
205F6 CJK UNIFIED IDEOGRAPH-#205F6, IRGKangXi=0133.210, RSKangXi=15.10
205F7 CJK UNIFIED IDEOGRAPH-#205F7, IRGKangXi=0133.211, RSKangXi=15.10
205F8 CJK UNIFIED IDEOGRAPH-#205F8, IRGKangXi=0133.211, RSKangXi=15.10
205F9 CJK UNIFIED IDEOGRAPH-#205F9, IRGKangXi=0133.211, RSKangXi=15.10
205FA CJK UNIFIED IDEOGRAPH-#205FA, IRGKangXi=0133.220, RSKangXi=15.11
205FB CJK UNIFIED IDEOGRAPH-#205FB, IRGKangXi=0133.230, RSKangXi=15.11
205FC CJK UNIFIED IDEOGRAPH-#205FC, IRGKangXi=0133.240, RSKangXi=15.11
205FD CJK UNIFIED IDEOGRAPH-#205FD, IRGKangXi=0133.260, RSKangXi=15.11
205FE CJK UNIFIED IDEOGRAPH-#205FE, IRGKangXi=0133.270, RSKangXi=15.11
205FF CJK UNIFIED IDEOGRAPH-#205FF, IRGKangXi=0133.290, RSKangXi=15.11
20600 CJK UNIFIED IDEOGRAPH-#20600, IRGKangXi=0133.300, RSKangXi=15.11
20601 CJK UNIFIED IDEOGRAPH-#20601, IRGKangXi=0133.301, RSKangXi=15.11
20602 CJK UNIFIED IDEOGRAPH-#20602, IRGKangXi=0133.301, RSKangXi=15.11
20603 CJK UNIFIED IDEOGRAPH-#20603, IRGKangXi=0133.301, RSKangXi=15.11
20604 CJK UNIFIED IDEOGRAPH-#20604, IRGKangXi=0133.340, RSKangXi=15.12
20605 CJK UNIFIED IDEOGRAPH-#20605, IRGKangXi=0133.350, RSKangXi=15.12
20606 CJK UNIFIED IDEOGRAPH-#20606, IRGKangXi=0133.360, RSKangXi=15.12
20607 CJK UNIFIED IDEOGRAPH-#20607, IRGKangXi=0133.370, RSKangXi=15.12
20608 CJK UNIFIED IDEOGRAPH-#20608, IRGKangXi=0133.371, RSKangXi=15.12
20609 CJK UNIFIED IDEOGRAPH-#20609, IRGKangXi=0133.371, RSKangXi=15.12
2060A CJK UNIFIED IDEOGRAPH-#2060A, IRGKangXi=0133.380, RSKangXi=15.13
2060B CJK UNIFIED IDEOGRAPH-#2060B, IRGKangXi=0133.390, RSKangXi=15.13
2060C CJK UNIFIED IDEOGRAPH-#2060C, IRGKangXi=0133.400, RSKangXi=15.13
2060D CJK UNIFIED IDEOGRAPH-#2060D, IRGKangXi=0133.440, RSKangXi=15.13
2060E CJK UNIFIED IDEOGRAPH-#2060E, IRGKangXi=0133.441, RSKangXi=15.13
2060F CJK UNIFIED IDEOGRAPH-#2060F, IRGKangXi=0133.441, RSKangXi=15.13
20610 CJK UNIFIED IDEOGRAPH-#20610, IRGKangXi=0133.441, RSKangXi=15.13
20611 CJK UNIFIED IDEOGRAPH-#20611, IRGKangXi=0133.441, RSKangXi=15.13
20612 CJK UNIFIED IDEOGRAPH-#20612, IRGKangXi=0133.461, RSKangXi=15.14
20613 CJK UNIFIED IDEOGRAPH-#20613, IRGKangXi=0133.461, RSKangXi=15.12
20614 CJK UNIFIED IDEOGRAPH-#20614, IRGKangXi=0133.461, RSKangXi=15.14
20615 CJK UNIFIED IDEOGRAPH-#20615, IRGKangXi=0133.461, RSKangXi=15.14
20616 CJK UNIFIED IDEOGRAPH-#20616, IRGKangXi=0133.470, RSKangXi=15.15
20617 CJK UNIFIED IDEOGRAPH-#20617, IRGKangXi=0133.480, RSKangXi=15.15
20618 CJK UNIFIED IDEOGRAPH-#20618, IRGKangXi=0133.490, RSKangXi=15.15
20619 CJK UNIFIED IDEOGRAPH-#20619, IRGKangXi=0133.491, RSKangXi=15.15
2061A CJK UNIFIED IDEOGRAPH-#2061A, IRGKangXi=0133.491, RSKangXi=15.15
2061B CJK UNIFIED IDEOGRAPH-#2061B, IRGKangXi=0133.491, RSKangXi=15.15
2061C CJK UNIFIED IDEOGRAPH-#2061C, IRGKangXi=0133.491, RSKangXi=15.15
2061D CJK UNIFIED IDEOGRAPH-#2061D, IRGKangXi=0133.500, RSKangXi=15.16
2061E CJK UNIFIED IDEOGRAPH-#2061E, IRGKangXi=0133.510, RSKangXi=15.16
2061F CJK UNIFIED IDEOGRAPH-#2061F, IRGKangXi=0133.520, RSKangXi=15.16
20620 CJK UNIFIED IDEOGRAPH-#20620, IRGKangXi=0133.521, RSKangXi=15.16
20621 CJK UNIFIED IDEOGRAPH-#20621, IRGKangXi=0133.521, RSKangXi=15.16
20622 CJK UNIFIED IDEOGRAPH-#20622, IRGKangXi=0133.530, RSKangXi=15.17
20623 CJK UNIFIED IDEOGRAPH-#20623, IRGKangXi=0133.540, RSKangXi=15.17
20624 CJK UNIFIED IDEOGRAPH-#20624, IRGKangXi=0133.550, RSKangXi=15.19
20625 CJK UNIFIED IDEOGRAPH-#20625, IRGKangXi=0133.560, RSKangXi=15.20
20626 CJK UNIFIED IDEOGRAPH-#20626, IRGKangXi=0133.561, RSKangXi=15.24
20627 CJK UNIFIED IDEOGRAPH-#20627, IRGKangXi=0134.010, RSKangXi=16.0
20628 CJK UNIFIED IDEOGRAPH-#20628, IRGKangXi=0134.011, RSKangXi=16.0
20629 CJK UNIFIED IDEOGRAPH-#20629, IRGKangXi=0134.030, RSKangXi=16.2
2062A CJK UNIFIED IDEOGRAPH-#2062A, IRGKangXi=0134.031, RSKangXi=16.2
2062B CJK UNIFIED IDEOGRAPH-#2062B, IRGKangXi=0134.031, RSKangXi=16.2
2062C CJK UNIFIED IDEOGRAPH-#2062C, IRGKangXi=0134.031, RSKangXi=16.2
2062D CJK UNIFIED IDEOGRAPH-#2062D, IRGKangXi=0134.031, RSKangXi=16.2
2062E CJK UNIFIED IDEOGRAPH-#2062E, IRGKangXi=0134.031, RSKangXi=16.2
2062F CJK UNIFIED IDEOGRAPH-#2062F, IRGKangXi=0134.031, RSKangXi=16.2
20630 CJK UNIFIED IDEOGRAPH-#20630, IRGKangXi=0134.031, RSKangXi=16.2
20631 CJK UNIFIED IDEOGRAPH-#20631, IRGKangXi=0134.060, RSKangXi=16.3
20632 CJK UNIFIED IDEOGRAPH-#20632, IRGKangXi=0134.070, RSKangXi=16.3
20633 CJK UNIFIED IDEOGRAPH-#20633, IRGKangXi=0134.080, RSKangXi=16.3
20634 CJK UNIFIED IDEOGRAPH-#20634, IRGKangXi=0134.081, RSKangXi=16.3
20635 CJK UNIFIED IDEOGRAPH-#20635, IRGKangXi=0134.090, RSKangXi=16.4
20636 CJK UNIFIED IDEOGRAPH-#20636, IRGKangXi=0134.100, RSKangXi=16.4
20637 CJK UNIFIED IDEOGRAPH-#20637, IRGKangXi=0134.110, RSKangXi=16.4
20638 CJK UNIFIED IDEOGRAPH-#20638, IRGKangXi=0134.120, RSKangXi=16.4
20639 CJK UNIFIED IDEOGRAPH-#20639, IRGKangXi=0134.121, RSKangXi=16.4
2063A CJK UNIFIED IDEOGRAPH-#2063A, IRGKangXi=0134.121, RSKangXi=16.4
2063B CJK UNIFIED IDEOGRAPH-#2063B, IRGKangXi=0134.121, RSKangXi=16.4
2063C CJK UNIFIED IDEOGRAPH-#2063C, IRGKangXi=0134.130, RSKangXi=16.5
2063D CJK UNIFIED IDEOGRAPH-#2063D, IRGKangXi=0134.140, RSKangXi=16.5
2063E CJK UNIFIED IDEOGRAPH-#2063E, IRGKangXi=0134.150, RSKangXi=16.5
2063F CJK UNIFIED IDEOGRAPH-#2063F, IRGKangXi=0134.151, RSKangXi=16.5
20640 CJK UNIFIED IDEOGRAPH-#20640, IRGKangXi=0134.151, RSKangXi=16.5
20641 CJK UNIFIED IDEOGRAPH-#20641, IRGKangXi=0134.151, RSKangXi=16.5
20642 CJK UNIFIED IDEOGRAPH-#20642, IRGKangXi=0134.151, RSKangXi=16.5
20643 CJK UNIFIED IDEOGRAPH-#20643, IRGKangXi=0134.151, RSKangXi=16.5
20644 CJK UNIFIED IDEOGRAPH-#20644, IRGKangXi=0134.151, RSKangXi=16.5
20645 CJK UNIFIED IDEOGRAPH-#20645, IRGKangXi=0134.151, RSKangXi=16.5
20646 CJK UNIFIED IDEOGRAPH-#20646, IRGKangXi=0134.170, RSKangXi=16.6
20647 CJK UNIFIED IDEOGRAPH-#20647, IRGKangXi=0134.180, RSKangXi=16.6
20648 CJK UNIFIED IDEOGRAPH-#20648, IRGKangXi=0134.190, RSKangXi=16.6
20649 CJK UNIFIED IDEOGRAPH-#20649, IRGKangXi=0134.200, RSKangXi=16.6
2064A CJK UNIFIED IDEOGRAPH-#2064A, IRGKangXi=0134.210, RSKangXi=16.6
2064B CJK UNIFIED IDEOGRAPH-#2064B, IRGKangXi=0134.220, RSKangXi=16.6
2064C CJK UNIFIED IDEOGRAPH-#2064C, IRGKangXi=0134.221, RSKangXi=16.6
2064D CJK UNIFIED IDEOGRAPH-#2064D, IRGKangXi=0134.221, RSKangXi=16.6
2064E CJK UNIFIED IDEOGRAPH-#2064E, IRGKangXi=0134.221, RSKangXi=16.6
2064F CJK UNIFIED IDEOGRAPH-#2064F, IRGKangXi=0134.230, RSKangXi=16.7
20650 CJK UNIFIED IDEOGRAPH-#20650, IRGKangXi=0134.240, RSKangXi=16.7
20651 CJK UNIFIED IDEOGRAPH-#20651, IRGKangXi=0134.250, RSKangXi=16.7
20652 CJK UNIFIED IDEOGRAPH-#20652, IRGKangXi=0134.260, RSKangXi=16.8
20653 CJK UNIFIED IDEOGRAPH-#20653, IRGKangXi=0134.261, RSKangXi=16.8
20654 CJK UNIFIED IDEOGRAPH-#20654, IRGKangXi=0134.261, RSKangXi=16.8
20655 CJK UNIFIED IDEOGRAPH-#20655, IRGKangXi=0134.261, RSKangXi=16.8
20656 CJK UNIFIED IDEOGRAPH-#20656, IRGKangXi=0134.261, RSKangXi=16.8
20657 CJK UNIFIED IDEOGRAPH-#20657, IRGKangXi=0134.261, RSKangXi=47.7
20658 CJK UNIFIED IDEOGRAPH-#20658, IRGKangXi=0134.280, RSKangXi=16.9
20659 CJK UNIFIED IDEOGRAPH-#20659, IRGKangXi=0134.300, RSKangXi=16.9
2065A CJK UNIFIED IDEOGRAPH-#2065A, IRGKangXi=0134.301, RSKangXi=34.8
2065B CJK UNIFIED IDEOGRAPH-#2065B, IRGKangXi=0134.301, RSKangXi=16.9
2065C CJK UNIFIED IDEOGRAPH-#2065C, IRGKangXi=0134.301, RSKangXi=16.9
2065D CJK UNIFIED IDEOGRAPH-#2065D, IRGKangXi=0134.301, RSKangXi=16.9
2065E CJK UNIFIED IDEOGRAPH-#2065E, IRGKangXi=0134.301, RSKangXi=16.9
2065F CJK UNIFIED IDEOGRAPH-#2065F, IRGKangXi=0134.320, RSKangXi=16.10
20660 CJK UNIFIED IDEOGRAPH-#20660, IRGKangXi=0134.340, RSKangXi=16.10
20661 CJK UNIFIED IDEOGRAPH-#20661, IRGKangXi=0134.341, RSKangXi=16.10
20662 CJK UNIFIED IDEOGRAPH-#20662, IRGKangXi=0134.350, RSKangXi=16.10
20663 CJK UNIFIED IDEOGRAPH-#20663, IRGKangXi=0134.351, RSKangXi=16.10
20664 CJK UNIFIED IDEOGRAPH-#20664, IRGKangXi=0134.351, RSKangXi=16.11
20665 CJK UNIFIED IDEOGRAPH-#20665, IRGKangXi=0134.351, RSKangXi=16.11
20666 CJK UNIFIED IDEOGRAPH-#20666, IRGKangXi=0134.351, RSKangXi=16.11
20667 CJK UNIFIED IDEOGRAPH-#20667, IRGKangXi=0134.351, RSKangXi=16.11
20668 CJK UNIFIED IDEOGRAPH-#20668, IRGKangXi=0134.371, RSKangXi=16.12
20669 CJK UNIFIED IDEOGRAPH-#20669, IRGKangXi=0134.371, RSKangXi=16.12
2066A CJK UNIFIED IDEOGRAPH-#2066A, IRGKangXi=0134.371, RSKangXi=16.12
2066B CJK UNIFIED IDEOGRAPH-#2066B, IRGKangXi=0134.371, RSKangXi=16.13
2066C CJK UNIFIED IDEOGRAPH-#2066C, IRGKangXi=0134.371, RSKangXi=182.6
2066D CJK UNIFIED IDEOGRAPH-#2066D, IRGKangXi=0134.380, RSKangXi=16.14
2066E CJK UNIFIED IDEOGRAPH-#2066E, IRGKangXi=0134.381, RSKangXi=16.14
2066F CJK UNIFIED IDEOGRAPH-#2066F, IRGKangXi=0134.381, RSKangXi=16.14
20670 CJK UNIFIED IDEOGRAPH-#20670, IRGKangXi=0134.381, RSKangXi=16.14
20671 CJK UNIFIED IDEOGRAPH-#20671, IRGKangXi=0134.381, RSKangXi=16.15
20672 CJK UNIFIED IDEOGRAPH-#20672, IRGKangXi=0134.381, RSKangXi=16.18
20673 CJK UNIFIED IDEOGRAPH-#20673, IRGKangXi=0134.381, RSKangXi=16.19
20674 CJK UNIFIED IDEOGRAPH-#20674, IRGKangXi=0134.400, RSKangXi=17.0
20675 CJK UNIFIED IDEOGRAPH-#20675, IRGKangXi=0135.010, RSKangXi=17.1
20676 CJK UNIFIED IDEOGRAPH-#20676, IRGKangXi=0135.040, RSKangXi=17.2
20677 CJK UNIFIED IDEOGRAPH-#20677, IRGKangXi=0135.050, RSKangXi=17.2
20678 CJK UNIFIED IDEOGRAPH-#20678, IRGKangXi=0135.060, RSKangXi=17.2
20679 CJK UNIFIED IDEOGRAPH-#20679, IRGKangXi=0135.080, RSKangXi=17.3
2067A CJK UNIFIED IDEOGRAPH-#2067A, IRGKangXi=0135.120, RSKangXi=17.3
2067B CJK UNIFIED IDEOGRAPH-#2067B, IRGKangXi=0135.121, RSKangXi=17.3
2067C CJK UNIFIED IDEOGRAPH-#2067C, IRGKangXi=0135.121, RSKangXi=30.2
2067D CJK UNIFIED IDEOGRAPH-#2067D, IRGKangXi=0135.121, RSKangXi=17.3
2067E CJK UNIFIED IDEOGRAPH-#2067E, IRGKangXi=0135.130, RSKangXi=17.4
2067F CJK UNIFIED IDEOGRAPH-#2067F, IRGKangXi=0135.140, RSKangXi=17.4
20680 CJK UNIFIED IDEOGRAPH-#20680, IRGKangXi=0135.150, RSKangXi=17.4
20681 CJK UNIFIED IDEOGRAPH-#20681, IRGKangXi=0135.151, RSKangXi=17.4
20682 CJK UNIFIED IDEOGRAPH-#20682, IRGKangXi=0135.151, RSKangXi=17.4
20683 CJK UNIFIED IDEOGRAPH-#20683, IRGKangXi=0135.151, RSKangXi=17.4
20684 CJK UNIFIED IDEOGRAPH-#20684, IRGKangXi=0135.151, RSKangXi=17.4
20685 CJK UNIFIED IDEOGRAPH-#20685, IRGKangXi=0135.151, RSKangXi=17.4
20686 CJK UNIFIED IDEOGRAPH-#20686, IRGKangXi=0135.151, RSKangXi=17.5
20687 CJK UNIFIED IDEOGRAPH-#20687, IRGKangXi=0135.151, RSKangXi=17.5
20688 CJK UNIFIED IDEOGRAPH-#20688, IRGKangXi=0135.151, RSKangXi=17.5
20689 CJK UNIFIED IDEOGRAPH-#20689, IRGKangXi=0135.151, RSKangXi=17.5
2068A CJK UNIFIED IDEOGRAPH-#2068A, IRGKangXi=0135.151, RSKangXi=17.5
2068B CJK UNIFIED IDEOGRAPH-#2068B, IRGKangXi=0135.161, RSKangXi=17.6
2068C CJK UNIFIED IDEOGRAPH-#2068C, IRGKangXi=0135.161, RSKangXi=17.6
2068D CJK UNIFIED IDEOGRAPH-#2068D, IRGKangXi=0135.161, RSKangXi=17.6
2068E CJK UNIFIED IDEOGRAPH-#2068E, IRGKangXi=0135.180, RSKangXi=17.7
2068F CJK UNIFIED IDEOGRAPH-#2068F, IRGKangXi=0135.190, RSKangXi=17.7
20690 CJK UNIFIED IDEOGRAPH-#20690, IRGKangXi=0135.191, RSKangXi=17.7
20691 CJK UNIFIED IDEOGRAPH-#20691, IRGKangXi=0135.191, RSKangXi=176.0
20692 CJK UNIFIED IDEOGRAPH-#20692, IRGKangXi=0135.200, RSKangXi=17.8
20693 CJK UNIFIED IDEOGRAPH-#20693, IRGKangXi=0135.201, RSKangXi=17.8
20694 CJK UNIFIED IDEOGRAPH-#20694, IRGKangXi=0135.201, RSKangXi=17.9
20695 CJK UNIFIED IDEOGRAPH-#20695, IRGKangXi=0135.201, RSKangXi=17.9
20696 CJK UNIFIED IDEOGRAPH-#20696, IRGKangXi=0135.201, RSKangXi=17.9
20697 CJK UNIFIED IDEOGRAPH-#20697, IRGKangXi=0135.201, RSKangXi=17.9
20698 CJK UNIFIED IDEOGRAPH-#20698, IRGKangXi=0135.210, RSKangXi=17.10
20699 CJK UNIFIED IDEOGRAPH-#20699, IRGKangXi=0135.220, RSKangXi=17.12
2069A CJK UNIFIED IDEOGRAPH-#2069A, IRGKangXi=0135.221, RSKangXi=17.12
2069B CJK UNIFIED IDEOGRAPH-#2069B, IRGKangXi=0135.221, RSKangXi=32.12
2069C CJK UNIFIED IDEOGRAPH-#2069C, IRGKangXi=0135.221, RSKangXi=17.13
2069D CJK UNIFIED IDEOGRAPH-#2069D, IRGKangXi=0135.230, RSKangXi=17.14
2069E CJK UNIFIED IDEOGRAPH-#2069E, IRGKangXi=0135.231, RSKangXi=17.15
2069F CJK UNIFIED IDEOGRAPH-#2069F, IRGKangXi=0135.231, RSKangXi=17.17
206A0 CJK UNIFIED IDEOGRAPH-#206A0, IRGKangXi=0135.231, RSKangXi=17.18
206A1 CJK UNIFIED IDEOGRAPH-#206A1, IRGKangXi=0135.231, RSKangXi=17.19
206A2 CJK UNIFIED IDEOGRAPH-#206A2, IRGKangXi=0135.231, RSKangXi=17.22
206A3 CJK UNIFIED IDEOGRAPH-#206A3, IRGKangXi=0136.011, RSKangXi=18.0
206A4 CJK UNIFIED IDEOGRAPH-#206A4, IRGKangXi=0136.021, RSKangXi=18.1
206A5 CJK UNIFIED IDEOGRAPH-#206A5, IRGKangXi=0136.050, RSKangXi=18.2
206A6 CJK UNIFIED IDEOGRAPH-#206A6, IRGKangXi=0136.060, RSKangXi=18.2
206A7 CJK UNIFIED IDEOGRAPH-#206A7, IRGKangXi=0136.070, RSKangXi=18.2
206A8 CJK UNIFIED IDEOGRAPH-#206A8, IRGKangXi=0136.080, RSKangXi=18.2
206A9 CJK UNIFIED IDEOGRAPH-#206A9, IRGKangXi=0136.120, RSKangXi=18.2
206AA CJK UNIFIED IDEOGRAPH-#206AA, IRGKangXi=0136.130, RSKangXi=18.2
206AB CJK UNIFIED IDEOGRAPH-#206AB, IRGKangXi=0136.131, RSKangXi=18.2
206AC CJK UNIFIED IDEOGRAPH-#206AC, IRGKangXi=0136.131, RSKangXi=18.2
206AD CJK UNIFIED IDEOGRAPH-#206AD, IRGKangXi=0136.180, RSKangXi=18.3
206AE CJK UNIFIED IDEOGRAPH-#206AE, IRGKangXi=0136.190, RSKangXi=18.3
206AF CJK UNIFIED IDEOGRAPH-#206AF, IRGKangXi=0136.200, RSKangXi=18.3
206B0 CJK UNIFIED IDEOGRAPH-#206B0, IRGKangXi=0137.010, RSKangXi=18.3
206B1 CJK UNIFIED IDEOGRAPH-#206B1, IRGKangXi=0137.020, RSKangXi=18.3
206B2 CJK UNIFIED IDEOGRAPH-#206B2, IRGKangXi=0137.021, RSKangXi=18.3
206B3 CJK UNIFIED IDEOGRAPH-#206B3, IRGKangXi=0137.021, RSKangXi=18.3
206B4 CJK UNIFIED IDEOGRAPH-#206B4, IRGKangXi=0137.021, RSKangXi=18.3
206B5 CJK UNIFIED IDEOGRAPH-#206B5, IRGKangXi=0137.021, RSKangXi=18.4
206B6 CJK UNIFIED IDEOGRAPH-#206B6, IRGKangXi=0137.021, RSKangXi=18.3
206B7 CJK UNIFIED IDEOGRAPH-#206B7, IRGKangXi=0137.040, RSKangXi=18.4
206B8 CJK UNIFIED IDEOGRAPH-#206B8, IRGKangXi=0137.050, RSKangXi=18.4
206B9 CJK UNIFIED IDEOGRAPH-#206B9, IRGKangXi=0137.080, RSKangXi=18.4, Def{to mow}
206BA CJK UNIFIED IDEOGRAPH-#206BA, IRGKangXi=0137.090, RSKangXi=18.4, Def{to make an eyelet hole}
206BB CJK UNIFIED IDEOGRAPH-#206BB, IRGKangXi=0137.140, RSKangXi=18.3
206BC CJK UNIFIED IDEOGRAPH-#206BC, IRGKangXi=0137.160, RSKangXi=18.4
206BD CJK UNIFIED IDEOGRAPH-#206BD, IRGKangXi=0137.170, RSKangXi=18.4
206BE CJK UNIFIED IDEOGRAPH-#206BE, IRGKangXi=0137.190, RSKangXi=18.4
206BF CJK UNIFIED IDEOGRAPH-#206BF, IRGKangXi=0137.210, RSKangXi=18.4
206C0 CJK UNIFIED IDEOGRAPH-#206C0, IRGKangXi=0137.230, RSKangXi=18.4
206C1 CJK UNIFIED IDEOGRAPH-#206C1, IRGKangXi=0137.270, RSKangXi=18.4
206C2 CJK UNIFIED IDEOGRAPH-#206C2, IRGKangXi=0137.280, RSKangXi=18.4
206C3 CJK UNIFIED IDEOGRAPH-#206C3, IRGKangXi=0137.290, RSKangXi=18.4
206C4 CJK UNIFIED IDEOGRAPH-#206C4, IRGKangXi=0137.300, RSKangXi=18.4
206C5 CJK UNIFIED IDEOGRAPH-#206C5, IRGKangXi=0137.301, RSKangXi=18.4
206C6 CJK UNIFIED IDEOGRAPH-#206C6, IRGKangXi=0137.301, RSKangXi=18.4
206C7 CJK UNIFIED IDEOGRAPH-#206C7, IRGKangXi=0137.301, RSKangXi=18.4
206C8 CJK UNIFIED IDEOGRAPH-#206C8, IRGKangXi=0137.301, RSKangXi=18.4
206C9 CJK UNIFIED IDEOGRAPH-#206C9, IRGKangXi=0137.301, RSKangXi=18.4
206CA CJK UNIFIED IDEOGRAPH-#206CA, IRGKangXi=0137.301, RSKangXi=18.4
206CB CJK UNIFIED IDEOGRAPH-#206CB, IRGKangXi=0137.301, RSKangXi=18.4
206CC CJK UNIFIED IDEOGRAPH-#206CC, IRGKangXi=0137.301, RSKangXi=18.4
206CD CJK UNIFIED IDEOGRAPH-#206CD, IRGKangXi=0137.301, RSKangXi=18.4
206CE CJK UNIFIED IDEOGRAPH-#206CE, IRGKangXi=0137.310, RSKangXi=18.5
206CF CJK UNIFIED IDEOGRAPH-#206CF, IRGKangXi=0138.010, RSKangXi=18.5
206D0 CJK UNIFIED IDEOGRAPH-#206D0, IRGKangXi=0138.020, RSKangXi=18.5
206D1 CJK UNIFIED IDEOGRAPH-#206D1, IRGKangXi=0138.080, RSKangXi=18.5
206D2 CJK UNIFIED IDEOGRAPH-#206D2, IRGKangXi=0138.090, RSKangXi=18.5, Def{to cut; to slice}
206D3 CJK UNIFIED IDEOGRAPH-#206D3, IRGKangXi=0138.170, RSKangXi=18.5
206D4 CJK UNIFIED IDEOGRAPH-#206D4, IRGKangXi=0138.210, RSKangXi=18.5
206D5 CJK UNIFIED IDEOGRAPH-#206D5, IRGKangXi=0138.220, RSKangXi=18.5
206D6 CJK UNIFIED IDEOGRAPH-#206D6, IRGKangXi=0138.230, RSKangXi=18.5
206D7 CJK UNIFIED IDEOGRAPH-#206D7, IRGKangXi=0138.240, RSKangXi=18.5
206D8 CJK UNIFIED IDEOGRAPH-#206D8, IRGKangXi=0138.250, RSKangXi=18.5
206D9 CJK UNIFIED IDEOGRAPH-#206D9, IRGKangXi=0138.260, RSKangXi=18.5
206DA CJK UNIFIED IDEOGRAPH-#206DA, IRGKangXi=0138.270, RSKangXi=18.5
206DB CJK UNIFIED IDEOGRAPH-#206DB, IRGKangXi=0138.280, RSKangXi=18.5
206DC CJK UNIFIED IDEOGRAPH-#206DC, IRGKangXi=0138.281, RSKangXi=18.5
206DD CJK UNIFIED IDEOGRAPH-#206DD, IRGKangXi=0138.281, RSKangXi=18.5
206DE CJK UNIFIED IDEOGRAPH-#206DE, IRGKangXi=0138.281, RSKangXi=18.5
206DF CJK UNIFIED IDEOGRAPH-#206DF, IRGKangXi=0138.281, RSKangXi=18.5
206E0 CJK UNIFIED IDEOGRAPH-#206E0, IRGKangXi=0138.281, RSKangXi=18.5
206E1 CJK UNIFIED IDEOGRAPH-#206E1, IRGKangXi=0138.281, RSKangXi=18.5
206E2 CJK UNIFIED IDEOGRAPH-#206E2, IRGKangXi=0138.281, RSKangXi=18.5
206E3 CJK UNIFIED IDEOGRAPH-#206E3, IRGKangXi=0138.281, RSKangXi=18.5
206E4 CJK UNIFIED IDEOGRAPH-#206E4, IRGKangXi=0138.281, RSKangXi=18.5
206E5 CJK UNIFIED IDEOGRAPH-#206E5, IRGKangXi=0138.281, RSKangXi=18.5
206E6 CJK UNIFIED IDEOGRAPH-#206E6, IRGKangXi=0138.281, RSKangXi=18.5
206E7 CJK UNIFIED IDEOGRAPH-#206E7, IRGKangXi=0138.300, RSKangXi=18.6
206E8 CJK UNIFIED IDEOGRAPH-#206E8, IRGKangXi=0138.310, RSKangXi=18.6
206E9 CJK UNIFIED IDEOGRAPH-#206E9, IRGKangXi=0138.320, RSKangXi=18.6
206EA CJK UNIFIED IDEOGRAPH-#206EA, IRGKangXi=0138.330, RSKangXi=18.6, Def{to cut open, sever}
206EB CJK UNIFIED IDEOGRAPH-#206EB, IRGKangXi=0138.340, RSKangXi=18.6
206EC CJK UNIFIED IDEOGRAPH-#206EC, IRGKangXi=0138.370, RSKangXi=18.6
206ED CJK UNIFIED IDEOGRAPH-#206ED, IRGKangXi=0138.400, RSKangXi=18.6
206EE CJK UNIFIED IDEOGRAPH-#206EE, IRGKangXi=0138.440, RSKangXi=18.6
206EF CJK UNIFIED IDEOGRAPH-#206EF, IRGKangXi=0139.070, RSKangXi=18.6
206F0 CJK UNIFIED IDEOGRAPH-#206F0, IRGKangXi=0139.100, RSKangXi=18.6
206F1 CJK UNIFIED IDEOGRAPH-#206F1, IRGKangXi=0139.160, RSKangXi=18.6
206F2 CJK UNIFIED IDEOGRAPH-#206F2, IRGKangXi=0139.170, RSKangXi=18.6
206F3 CJK UNIFIED IDEOGRAPH-#206F3, IRGKangXi=0139.190, RSKangXi=18.6
206F4 CJK UNIFIED IDEOGRAPH-#206F4, IRGKangXi=0139.200, RSKangXi=18.6
206F5 CJK UNIFIED IDEOGRAPH-#206F5, IRGKangXi=0139.210, RSKangXi=18.6
206F6 CJK UNIFIED IDEOGRAPH-#206F6, IRGKangXi=0139.220, RSKangXi=18.6
206F7 CJK UNIFIED IDEOGRAPH-#206F7, IRGKangXi=0139.230, RSKangXi=18.6
206F8 CJK UNIFIED IDEOGRAPH-#206F8, IRGKangXi=0139.240, RSKangXi=18.6
206F9 CJK UNIFIED IDEOGRAPH-#206F9, IRGKangXi=0139.250, RSKangXi=18.6
206FA CJK UNIFIED IDEOGRAPH-#206FA, IRGKangXi=0139.251, RSKangXi=18.6
206FB CJK UNIFIED IDEOGRAPH-#206FB, IRGKangXi=0139.251, RSKangXi=18.6
206FC CJK UNIFIED IDEOGRAPH-#206FC, IRGKangXi=0139.251, RSKangXi=18.6
206FD CJK UNIFIED IDEOGRAPH-#206FD, IRGKangXi=0139.251, RSKangXi=18.6
206FE CJK UNIFIED IDEOGRAPH-#206FE, IRGKangXi=0139.251, RSKangXi=18.6
206FF CJK UNIFIED IDEOGRAPH-#206FF, IRGKangXi=0139.251, RSKangXi=18.6
20700 CJK UNIFIED IDEOGRAPH-#20700, IRGKangXi=0139.251, RSKangXi=18.6
20701 CJK UNIFIED IDEOGRAPH-#20701, IRGKangXi=0139.251, RSKangXi=18.6
20702 CJK UNIFIED IDEOGRAPH-#20702, IRGKangXi=0139.251, RSKangXi=18.6
20703 CJK UNIFIED IDEOGRAPH-#20703, IRGKangXi=0139.251, RSKangXi=18.6
20704 CJK UNIFIED IDEOGRAPH-#20704, IRGKangXi=0139.251, RSKangXi=18.6
20705 CJK UNIFIED IDEOGRAPH-#20705, IRGKangXi=0139.251, RSKangXi=18.6
20706 CJK UNIFIED IDEOGRAPH-#20706, IRGKangXi=0139.251, RSKangXi=18.6
20707 CJK UNIFIED IDEOGRAPH-#20707, IRGKangXi=0139.251, RSKangXi=18.6
20708 CJK UNIFIED IDEOGRAPH-#20708, IRGKangXi=0139.251, RSKangXi=18.6
20709 CJK UNIFIED IDEOGRAPH-#20709, IRGKangXi=0139.251, RSKangXi=18.6
2070A CJK UNIFIED IDEOGRAPH-#2070A, IRGKangXi=0139.251, RSKangXi=18.6
2070B CJK UNIFIED IDEOGRAPH-#2070B, IRGKangXi=0139.251, RSKangXi=18.6
2070C CJK UNIFIED IDEOGRAPH-#2070C, IRGKangXi=0139.251, RSKangXi=18.6
2070D CJK UNIFIED IDEOGRAPH-#2070D, IRGKangXi=0139.251, RSKangXi=18.6
2070E CJK UNIFIED IDEOGRAPH-#2070E, IRGKangXi=0139.251, RSKangXi=18.6, Def{to castrate a fowl, a capon}
2070F CJK UNIFIED IDEOGRAPH-#2070F, IRGKangXi=0139.251, RSKangXi=18.6
20710 CJK UNIFIED IDEOGRAPH-#20710, IRGKangXi=0139.300, RSKangXi=18.7
20711 CJK UNIFIED IDEOGRAPH-#20711, IRGKangXi=0140.010, RSKangXi=18.7
20712 CJK UNIFIED IDEOGRAPH-#20712, IRGKangXi=0140.060, RSKangXi=18.7
20713 CJK UNIFIED IDEOGRAPH-#20713, IRGKangXi=0140.070, RSKangXi=18.7
20714 CJK UNIFIED IDEOGRAPH-#20714, IRGKangXi=0140.080, RSKangXi=18.7
20715 CJK UNIFIED IDEOGRAPH-#20715, IRGKangXi=0140.090, RSKangXi=18.7
20716 CJK UNIFIED IDEOGRAPH-#20716, IRGKangXi=0140.100, RSKangXi=18.7
20717 CJK UNIFIED IDEOGRAPH-#20717, IRGKangXi=0140.110, RSKangXi=18.7
20718 CJK UNIFIED IDEOGRAPH-#20718, IRGKangXi=0140.120, RSKangXi=18.7
20719 CJK UNIFIED IDEOGRAPH-#20719, IRGKangXi=0140.180, RSKangXi=18.7
2071A CJK UNIFIED IDEOGRAPH-#2071A, IRGKangXi=0140.190, RSKangXi=18.7
2071B CJK UNIFIED IDEOGRAPH-#2071B, IRGKangXi=0140.230, RSKangXi=18.7
2071C CJK UNIFIED IDEOGRAPH-#2071C, IRGKangXi=0140.240, RSKangXi=18.7
2071D CJK UNIFIED IDEOGRAPH-#2071D, IRGKangXi=0140.250, RSKangXi=18.7
2071E CJK UNIFIED IDEOGRAPH-#2071E, IRGKangXi=0140.260, RSKangXi=18.7
2071F CJK UNIFIED IDEOGRAPH-#2071F, IRGKangXi=0140.270, RSKangXi=18.7
20720 CJK UNIFIED IDEOGRAPH-#20720, IRGKangXi=0140.280, RSKangXi=18.7
20721 CJK UNIFIED IDEOGRAPH-#20721, IRGKangXi=0140.291, RSKangXi=18.7
20722 CJK UNIFIED IDEOGRAPH-#20722, IRGKangXi=0140.291, RSKangXi=18.7
20723 CJK UNIFIED IDEOGRAPH-#20723, IRGKangXi=0140.291, RSKangXi=18.7
20724 CJK UNIFIED IDEOGRAPH-#20724, IRGKangXi=0140.291, RSKangXi=18.7
20725 CJK UNIFIED IDEOGRAPH-#20725, IRGKangXi=0140.291, RSKangXi=18.7
20726 CJK UNIFIED IDEOGRAPH-#20726, IRGKangXi=0140.291, RSKangXi=18.7
20727 CJK UNIFIED IDEOGRAPH-#20727, IRGKangXi=0140.291, RSKangXi=18.7
20728 CJK UNIFIED IDEOGRAPH-#20728, IRGKangXi=0140.291, RSKangXi=18.7
20729 CJK UNIFIED IDEOGRAPH-#20729, IRGKangXi=0140.291, RSKangXi=18.7
2072A CJK UNIFIED IDEOGRAPH-#2072A, IRGKangXi=0140.291, RSKangXi=18.7
2072B CJK UNIFIED IDEOGRAPH-#2072B, IRGKangXi=0140.291, RSKangXi=18.7
2072C CJK UNIFIED IDEOGRAPH-#2072C, IRGKangXi=0140.291, RSKangXi=18.7
2072D CJK UNIFIED IDEOGRAPH-#2072D, IRGKangXi=0140.291, RSKangXi=18.7
2072E CJK UNIFIED IDEOGRAPH-#2072E, IRGKangXi=0140.291, RSKangXi=18.7
2072F CJK UNIFIED IDEOGRAPH-#2072F, IRGKangXi=0140.291, RSKangXi=18.7
20730 CJK UNIFIED IDEOGRAPH-#20730, IRGKangXi=0140.291, RSKangXi=18.7
20731 CJK UNIFIED IDEOGRAPH-#20731, IRGKangXi=0140.310, RSKangXi=18.8, Def{to peel, pare}
20732 CJK UNIFIED IDEOGRAPH-#20732, IRGKangXi=0140.330, RSKangXi=18.8
20733 CJK UNIFIED IDEOGRAPH-#20733, IRGKangXi=0140.340, RSKangXi=18.8
20734 CJK UNIFIED IDEOGRAPH-#20734, IRGKangXi=0141.010, RSKangXi=18.8
20735 CJK UNIFIED IDEOGRAPH-#20735, IRGKangXi=0141.070, RSKangXi=18.8
20736 CJK UNIFIED IDEOGRAPH-#20736, IRGKangXi=0141.080, RSKangXi=18.8
20737 CJK UNIFIED IDEOGRAPH-#20737, IRGKangXi=0141.170, RSKangXi=18.8
20738 CJK UNIFIED IDEOGRAPH-#20738, IRGKangXi=0141.180, RSKangXi=18.8
20739 CJK UNIFIED IDEOGRAPH-#20739, IRGKangXi=0141.190, RSKangXi=18.8
2073A CJK UNIFIED IDEOGRAPH-#2073A, IRGKangXi=0141.200, RSKangXi=18.8
2073B CJK UNIFIED IDEOGRAPH-#2073B, IRGKangXi=0141.230, RSKangXi=18.8
2073C CJK UNIFIED IDEOGRAPH-#2073C, IRGKangXi=0141.250, RSKangXi=18.8, Def{to claw; to pinch with the fingers}
2073D CJK UNIFIED IDEOGRAPH-#2073D, IRGKangXi=0141.260, RSKangXi=18.8
2073E CJK UNIFIED IDEOGRAPH-#2073E, IRGKangXi=0141.290, RSKangXi=18.8
2073F CJK UNIFIED IDEOGRAPH-#2073F, IRGKangXi=0141.300, RSKangXi=18.8
20740 CJK UNIFIED IDEOGRAPH-#20740, IRGKangXi=0141.360, RSKangXi=18.8
20741 CJK UNIFIED IDEOGRAPH-#20741, IRGKangXi=0141.370, RSKangXi=18.8
20742 CJK UNIFIED IDEOGRAPH-#20742, IRGKangXi=0141.380, RSKangXi=18.8
20743 CJK UNIFIED IDEOGRAPH-#20743, IRGKangXi=0141.390, RSKangXi=18.8
20744 CJK UNIFIED IDEOGRAPH-#20744, IRGKangXi=0141.400, RSKangXi=18.8
20745 CJK UNIFIED IDEOGRAPH-#20745, IRGKangXi=0141.410, RSKangXi=18.8
20746 CJK UNIFIED IDEOGRAPH-#20746, IRGKangXi=0141.411, RSKangXi=18.8
20747 CJK UNIFIED IDEOGRAPH-#20747, IRGKangXi=0141.411, RSKangXi=18.8
20748 CJK UNIFIED IDEOGRAPH-#20748, IRGKangXi=0141.411, RSKangXi=18.8
20749 CJK UNIFIED IDEOGRAPH-#20749, IRGKangXi=0141.411, RSKangXi=18.8
2074A CJK UNIFIED IDEOGRAPH-#2074A, IRGKangXi=0141.411, RSKangXi=18.8
2074B CJK UNIFIED IDEOGRAPH-#2074B, IRGKangXi=0141.411, RSKangXi=18.8
2074C CJK UNIFIED IDEOGRAPH-#2074C, IRGKangXi=0141.411, RSKangXi=18.8
2074D CJK UNIFIED IDEOGRAPH-#2074D, IRGKangXi=0141.411, RSKangXi=18.8
2074E CJK UNIFIED IDEOGRAPH-#2074E, IRGKangXi=0141.411, RSKangXi=18.8
2074F CJK UNIFIED IDEOGRAPH-#2074F, IRGKangXi=0141.411, RSKangXi=18.8
20750 CJK UNIFIED IDEOGRAPH-#20750, IRGKangXi=0141.411, RSKangXi=18.8
20751 CJK UNIFIED IDEOGRAPH-#20751, IRGKangXi=0141.411, RSKangXi=18.8
20752 CJK UNIFIED IDEOGRAPH-#20752, IRGKangXi=0141.411, RSKangXi=18.8
20753 CJK UNIFIED IDEOGRAPH-#20753, IRGKangXi=0141.411, RSKangXi=18.8
20754 CJK UNIFIED IDEOGRAPH-#20754, IRGKangXi=0141.411, RSKangXi=18.8
20755 CJK UNIFIED IDEOGRAPH-#20755, IRGKangXi=0141.411, RSKangXi=18.8
20756 CJK UNIFIED IDEOGRAPH-#20756, IRGKangXi=0141.411, RSKangXi=18.8
20757 CJK UNIFIED IDEOGRAPH-#20757, IRGKangXi=0141.411, RSKangXi=18.8
20758 CJK UNIFIED IDEOGRAPH-#20758, IRGKangXi=0141.411, RSKangXi=18.8
20759 CJK UNIFIED IDEOGRAPH-#20759, IRGKangXi=0141.411, RSKangXi=18.8
2075A CJK UNIFIED IDEOGRAPH-#2075A, IRGKangXi=0141.411, RSKangXi=18.8
2075B CJK UNIFIED IDEOGRAPH-#2075B, IRGKangXi=0141.411, RSKangXi=18.8
2075C CJK UNIFIED IDEOGRAPH-#2075C, IRGKangXi=0141.411, RSKangXi=18.8
2075D CJK UNIFIED IDEOGRAPH-#2075D, IRGKangXi=0142.010, RSKangXi=18.9
2075E CJK UNIFIED IDEOGRAPH-#2075E, IRGKangXi=0142.030, RSKangXi=18.9
2075F CJK UNIFIED IDEOGRAPH-#2075F, IRGKangXi=0142.060, RSKangXi=18.9
20760 CJK UNIFIED IDEOGRAPH-#20760, IRGKangXi=0142.070, RSKangXi=18.9
20761 CJK UNIFIED IDEOGRAPH-#20761, IRGKangXi=0142.080, RSKangXi=18.9
20762 CJK UNIFIED IDEOGRAPH-#20762, IRGKangXi=0142.110, RSKangXi=18.9
20763 CJK UNIFIED IDEOGRAPH-#20763, IRGKangXi=0142.140, RSKangXi=18.9
20764 CJK UNIFIED IDEOGRAPH-#20764, IRGKangXi=0142.150, RSKangXi=18.9
20765 CJK UNIFIED IDEOGRAPH-#20765, IRGKangXi=0142.190, RSKangXi=18.9
20766 CJK UNIFIED IDEOGRAPH-#20766, IRGKangXi=0142.240, RSKangXi=18.9
20767 CJK UNIFIED IDEOGRAPH-#20767, IRGKangXi=0142.250, RSKangXi=18.9
20768 CJK UNIFIED IDEOGRAPH-#20768, IRGKangXi=0142.260, RSKangXi=18.9
20769 CJK UNIFIED IDEOGRAPH-#20769, IRGKangXi=0142.270, RSKangXi=18.9
2076A CJK UNIFIED IDEOGRAPH-#2076A, IRGKangXi=0142.280, RSKangXi=18.9
2076B CJK UNIFIED IDEOGRAPH-#2076B, IRGKangXi=0142.281, RSKangXi=18.9
2076C CJK UNIFIED IDEOGRAPH-#2076C, IRGKangXi=0142.281, RSKangXi=18.9
2076D CJK UNIFIED IDEOGRAPH-#2076D, IRGKangXi=0142.281, RSKangXi=18.9, Def{(Cant.) to fell, cut; to sweep away}
2076E CJK UNIFIED IDEOGRAPH-#2076E, IRGKangXi=0142.281, RSKangXi=18.9
2076F CJK UNIFIED IDEOGRAPH-#2076F, IRGKangXi=0142.281, RSKangXi=18.9
20770 CJK UNIFIED IDEOGRAPH-#20770, IRGKangXi=0142.281, RSKangXi=18.9
20771 CJK UNIFIED IDEOGRAPH-#20771, IRGKangXi=0142.281, RSKangXi=18.9
20772 CJK UNIFIED IDEOGRAPH-#20772, IRGKangXi=0142.281, RSKangXi=18.9
20773 CJK UNIFIED IDEOGRAPH-#20773, IRGKangXi=0142.281, RSKangXi=18.9
20774 CJK UNIFIED IDEOGRAPH-#20774, IRGKangXi=0142.281, RSKangXi=18.9
20775 CJK UNIFIED IDEOGRAPH-#20775, IRGKangXi=0142.281, RSKangXi=18.9
20776 CJK UNIFIED IDEOGRAPH-#20776, IRGKangXi=0142.281, RSKangXi=18.8
20777 CJK UNIFIED IDEOGRAPH-#20777, IRGKangXi=0142.281, RSKangXi=18.9
20778 CJK UNIFIED IDEOGRAPH-#20778, IRGKangXi=0142.281, RSKangXi=18.9
20779 CJK UNIFIED IDEOGRAPH-#20779, IRGKangXi=0142.281, RSKangXi=18.9, Def{(Cant.) to cut with a knife or scissors}
2077A CJK UNIFIED IDEOGRAPH-#2077A, IRGKangXi=0142.281, RSKangXi=18.9
2077B CJK UNIFIED IDEOGRAPH-#2077B, IRGKangXi=0142.281, RSKangXi=18.9
2077C CJK UNIFIED IDEOGRAPH-#2077C, IRGKangXi=0142.281, RSKangXi=18.9
2077D CJK UNIFIED IDEOGRAPH-#2077D, IRGKangXi=0142.281, RSKangXi=18.9
2077E CJK UNIFIED IDEOGRAPH-#2077E, IRGKangXi=0142.281, RSKangXi=18.9
2077F CJK UNIFIED IDEOGRAPH-#2077F, IRGKangXi=0142.300, RSKangXi=18.10
20780 CJK UNIFIED IDEOGRAPH-#20780, IRGKangXi=0142.310, RSKangXi=18.10
20781 CJK UNIFIED IDEOGRAPH-#20781, IRGKangXi=0142.380, RSKangXi=18.10
20782 CJK UNIFIED IDEOGRAPH-#20782, IRGKangXi=0142.400, RSKangXi=18.10
20783 CJK UNIFIED IDEOGRAPH-#20783, IRGKangXi=0142.420, RSKangXi=18.10
20784 CJK UNIFIED IDEOGRAPH-#20784, IRGKangXi=0142.430, RSKangXi=18.10
20785 CJK UNIFIED IDEOGRAPH-#20785, IRGKangXi=0142.440, RSKangXi=18.10
20786 CJK UNIFIED IDEOGRAPH-#20786, IRGKangXi=0142.460, RSKangXi=18.10
20787 CJK UNIFIED IDEOGRAPH-#20787, IRGKangXi=0142.480, RSKangXi=18.10
20788 CJK UNIFIED IDEOGRAPH-#20788, IRGKangXi=0143.010, RSKangXi=18.10
20789 CJK UNIFIED IDEOGRAPH-#20789, IRGKangXi=0143.060, RSKangXi=18.10
2078A CJK UNIFIED IDEOGRAPH-#2078A, IRGKangXi=0143.070, RSKangXi=18.10
2078B CJK UNIFIED IDEOGRAPH-#2078B, IRGKangXi=0143.080, RSKangXi=18.10
2078C CJK UNIFIED IDEOGRAPH-#2078C, IRGKangXi=0143.090, RSKangXi=18.10
2078D CJK UNIFIED IDEOGRAPH-#2078D, IRGKangXi=0143.100, RSKangXi=18.10
2078E CJK UNIFIED IDEOGRAPH-#2078E, IRGKangXi=0143.110, RSKangXi=18.10
2078F CJK UNIFIED IDEOGRAPH-#2078F, IRGKangXi=0143.130, RSKangXi=18.10
20790 CJK UNIFIED IDEOGRAPH-#20790, IRGKangXi=0143.141, RSKangXi=18.10
20791 CJK UNIFIED IDEOGRAPH-#20791, IRGKangXi=0143.141, RSKangXi=18.10
20792 CJK UNIFIED IDEOGRAPH-#20792, IRGKangXi=0143.141, RSKangXi=18.10
20793 CJK UNIFIED IDEOGRAPH-#20793, IRGKangXi=0143.141, RSKangXi=18.10
20794 CJK UNIFIED IDEOGRAPH-#20794, IRGKangXi=0143.141, RSKangXi=18.10
20795 CJK UNIFIED IDEOGRAPH-#20795, IRGKangXi=0143.141, RSKangXi=18.10
20796 CJK UNIFIED IDEOGRAPH-#20796, IRGKangXi=0143.141, RSKangXi=18.10
20797 CJK UNIFIED IDEOGRAPH-#20797, IRGKangXi=0143.141, RSKangXi=18.10
20798 CJK UNIFIED IDEOGRAPH-#20798, IRGKangXi=0143.141, RSKangXi=18.10
20799 CJK UNIFIED IDEOGRAPH-#20799, IRGKangXi=0143.141, RSKangXi=18.10
2079A CJK UNIFIED IDEOGRAPH-#2079A, IRGKangXi=0143.141, RSKangXi=18.10
2079B CJK UNIFIED IDEOGRAPH-#2079B, IRGKangXi=0143.141, RSKangXi=18.10
2079C CJK UNIFIED IDEOGRAPH-#2079C, IRGKangXi=0143.141, RSKangXi=115.7
2079D CJK UNIFIED IDEOGRAPH-#2079D, IRGKangXi=0143.141, RSKangXi=18.10
2079E CJK UNIFIED IDEOGRAPH-#2079E, IRGKangXi=0143.141, RSKangXi=18.10
2079F CJK UNIFIED IDEOGRAPH-#2079F, IRGKangXi=0143.141, RSKangXi=18.10
207A0 CJK UNIFIED IDEOGRAPH-#207A0, IRGKangXi=0143.141, RSKangXi=18.10
207A1 CJK UNIFIED IDEOGRAPH-#207A1, IRGKangXi=0143.141, RSKangXi=18.10
207A2 CJK UNIFIED IDEOGRAPH-#207A2, IRGKangXi=0143.141, RSKangXi=18.10
207A3 CJK UNIFIED IDEOGRAPH-#207A3, IRGKangXi=0143.141, RSKangXi=18.10
207A4 CJK UNIFIED IDEOGRAPH-#207A4, IRGKangXi=0143.141, RSKangXi=18.10
207A5 CJK UNIFIED IDEOGRAPH-#207A5, IRGKangXi=0143.170, RSKangXi=18.11
207A6 CJK UNIFIED IDEOGRAPH-#207A6, IRGKangXi=0143.180, RSKangXi=18.11
207A7 CJK UNIFIED IDEOGRAPH-#207A7, IRGKangXi=0143.200, RSKangXi=18.11
207A8 CJK UNIFIED IDEOGRAPH-#207A8, IRGKangXi=0143.230, RSKangXi=18.11
207A9 CJK UNIFIED IDEOGRAPH-#207A9, IRGKangXi=0143.250, RSKangXi=18.11
207AA CJK UNIFIED IDEOGRAPH-#207AA, IRGKangXi=0143.260, RSKangXi=18.11
207AB CJK UNIFIED IDEOGRAPH-#207AB, IRGKangXi=0143.270, RSKangXi=18.11
207AC CJK UNIFIED IDEOGRAPH-#207AC, IRGKangXi=0143.280, RSKangXi=18.11
207AD CJK UNIFIED IDEOGRAPH-#207AD, IRGKangXi=0143.290, RSKangXi=18.11, Def{to carve; to hollow out}
207AE CJK UNIFIED IDEOGRAPH-#207AE, IRGKangXi=0143.340, RSKangXi=18.11
207AF CJK UNIFIED IDEOGRAPH-#207AF, IRGKangXi=0143.350, RSKangXi=18.11
207B0 CJK UNIFIED IDEOGRAPH-#207B0, IRGKangXi=0143.370, RSKangXi=18.11, Def{to attack, destroy; to fatigue}
207B1 CJK UNIFIED IDEOGRAPH-#207B1, IRGKangXi=0143.380, RSKangXi=18.11
207B2 CJK UNIFIED IDEOGRAPH-#207B2, IRGKangXi=0143.381, RSKangXi=18.11
207B3 CJK UNIFIED IDEOGRAPH-#207B3, IRGKangXi=0143.381, RSKangXi=18.11
207B4 CJK UNIFIED IDEOGRAPH-#207B4, IRGKangXi=0143.381, RSKangXi=18.11
207B5 CJK UNIFIED IDEOGRAPH-#207B5, IRGKangXi=0143.381, RSKangXi=18.11
207B6 CJK UNIFIED IDEOGRAPH-#207B6, IRGKangXi=0143.381, RSKangXi=18.11
207B7 CJK UNIFIED IDEOGRAPH-#207B7, IRGKangXi=0143.381, RSKangXi=18.11
207B8 CJK UNIFIED IDEOGRAPH-#207B8, IRGKangXi=0143.381, RSKangXi=18.11
207B9 CJK UNIFIED IDEOGRAPH-#207B9, IRGKangXi=0143.381, RSKangXi=18.11
207BA CJK UNIFIED IDEOGRAPH-#207BA, IRGKangXi=0143.381, RSKangXi=18.11
207BB CJK UNIFIED IDEOGRAPH-#207BB, IRGKangXi=0143.381, RSKangXi=18.11
207BC CJK UNIFIED IDEOGRAPH-#207BC, IRGKangXi=0143.381, RSKangXi=18.11
207BD CJK UNIFIED IDEOGRAPH-#207BD, IRGKangXi=0143.381, RSKangXi=18.11
207BE CJK UNIFIED IDEOGRAPH-#207BE, IRGKangXi=0143.381, RSKangXi=18.11
207BF CJK UNIFIED IDEOGRAPH-#207BF, IRGKangXi=0143.381, RSKangXi=18.11
207C0 CJK UNIFIED IDEOGRAPH-#207C0, IRGKangXi=0143.381, RSKangXi=18.11
207C1 CJK UNIFIED IDEOGRAPH-#207C1, IRGKangXi=0143.381, RSKangXi=18.11
207C2 CJK UNIFIED IDEOGRAPH-#207C2, IRGKangXi=0143.390, RSKangXi=18.12
207C3 CJK UNIFIED IDEOGRAPH-#207C3, IRGKangXi=0143.450, RSKangXi=18.12
207C4 CJK UNIFIED IDEOGRAPH-#207C4, IRGKangXi=0144.010, RSKangXi=18.12
207C5 CJK UNIFIED IDEOGRAPH-#207C5, IRGKangXi=0144.020, RSKangXi=18.12
207C6 CJK UNIFIED IDEOGRAPH-#207C6, IRGKangXi=0144.040, RSKangXi=18.12
207C7 CJK UNIFIED IDEOGRAPH-#207C7, IRGKangXi=0144.060, RSKangXi=18.12
207C8 CJK UNIFIED IDEOGRAPH-#207C8, IRGKangXi=0144.070, RSKangXi=18.12
207C9 CJK UNIFIED IDEOGRAPH-#207C9, IRGKangXi=0144.090, RSKangXi=18.12
207CA CJK UNIFIED IDEOGRAPH-#207CA, IRGKangXi=0144.120, RSKangXi=18.12
207CB CJK UNIFIED IDEOGRAPH-#207CB, IRGKangXi=0144.130, RSKangXi=18.12
207CC CJK UNIFIED IDEOGRAPH-#207CC, IRGKangXi=0144.140, RSKangXi=18.12
207CD CJK UNIFIED IDEOGRAPH-#207CD, IRGKangXi=0144.150, RSKangXi=18.12
207CE CJK UNIFIED IDEOGRAPH-#207CE, IRGKangXi=0144.160, RSKangXi=18.12
207CF CJK UNIFIED IDEOGRAPH-#207CF, IRGKangXi=0144.170, RSKangXi=18.12
207D0 CJK UNIFIED IDEOGRAPH-#207D0, IRGKangXi=0144.180, RSKangXi=18.12
207D1 CJK UNIFIED IDEOGRAPH-#207D1, IRGKangXi=0144.190, RSKangXi=18.12
207D2 CJK UNIFIED IDEOGRAPH-#207D2, IRGKangXi=0144.200, RSKangXi=18.12
207D3 CJK UNIFIED IDEOGRAPH-#207D3, IRGKangXi=0144.210, RSKangXi=18.12
207D4 CJK UNIFIED IDEOGRAPH-#207D4, IRGKangXi=0144.220, RSKangXi=18.12
207D5 CJK UNIFIED IDEOGRAPH-#207D5, IRGKangXi=0144.230, RSKangXi=18.12
207D6 CJK UNIFIED IDEOGRAPH-#207D6, IRGKangXi=0144.240, RSKangXi=18.12
207D7 CJK UNIFIED IDEOGRAPH-#207D7, IRGKangXi=0144.250, RSKangXi=18.12
207D8 CJK UNIFIED IDEOGRAPH-#207D8, IRGKangXi=0144.260, RSKangXi=18.12
207D9 CJK UNIFIED IDEOGRAPH-#207D9, IRGKangXi=0144.261, RSKangXi=18.12
207DA CJK UNIFIED IDEOGRAPH-#207DA, IRGKangXi=0144.261, RSKangXi=18.12
207DB CJK UNIFIED IDEOGRAPH-#207DB, IRGKangXi=0144.261, RSKangXi=18.12
207DC CJK UNIFIED IDEOGRAPH-#207DC, IRGKangXi=0144.261, RSKangXi=18.12
207DD CJK UNIFIED IDEOGRAPH-#207DD, IRGKangXi=0144.261, RSKangXi=18.12
207DE CJK UNIFIED IDEOGRAPH-#207DE, IRGKangXi=0144.261, RSKangXi=18.12
207DF CJK UNIFIED IDEOGRAPH-#207DF, IRGKangXi=0144.261, RSKangXi=18.12
207E0 CJK UNIFIED IDEOGRAPH-#207E0, IRGKangXi=0144.261, RSKangXi=18.13
207E1 CJK UNIFIED IDEOGRAPH-#207E1, IRGKangXi=0144.261, RSKangXi=18.12
207E2 CJK UNIFIED IDEOGRAPH-#207E2, IRGKangXi=0144.261, RSKangXi=18.12
207E3 CJK UNIFIED IDEOGRAPH-#207E3, IRGKangXi=0144.261, RSKangXi=18.12
207E4 CJK UNIFIED IDEOGRAPH-#207E4, IRGKangXi=0144.261, RSKangXi=18.12
207E5 CJK UNIFIED IDEOGRAPH-#207E5, IRGKangXi=0144.261, RSKangXi=18.12
207E6 CJK UNIFIED IDEOGRAPH-#207E6, IRGKangXi=0144.270, RSKangXi=18.13
207E7 CJK UNIFIED IDEOGRAPH-#207E7, IRGKangXi=0144.290, RSKangXi=18.13
207E8 CJK UNIFIED IDEOGRAPH-#207E8, IRGKangXi=0144.300, RSKangXi=18.13
207E9 CJK UNIFIED IDEOGRAPH-#207E9, IRGKangXi=0144.320, RSKangXi=18.13
207EA CJK UNIFIED IDEOGRAPH-#207EA, IRGKangXi=0144.330, RSKangXi=18.13
207EB CJK UNIFIED IDEOGRAPH-#207EB, IRGKangXi=0144.350, RSKangXi=18.13
207EC CJK UNIFIED IDEOGRAPH-#207EC, IRGKangXi=0144.370, RSKangXi=18.13
207ED CJK UNIFIED IDEOGRAPH-#207ED, IRGKangXi=0144.460, RSKangXi=18.13
207EE CJK UNIFIED IDEOGRAPH-#207EE, IRGKangXi=0144.470, RSKangXi=18.13
207EF CJK UNIFIED IDEOGRAPH-#207EF, IRGKangXi=0144.480, RSKangXi=18.13
207F0 CJK UNIFIED IDEOGRAPH-#207F0, IRGKangXi=0144.490, RSKangXi=18.13
207F1 CJK UNIFIED IDEOGRAPH-#207F1, IRGKangXi=0144.500, RSKangXi=18.13
207F2 CJK UNIFIED IDEOGRAPH-#207F2, IRGKangXi=0144.501, RSKangXi=18.13
207F3 CJK UNIFIED IDEOGRAPH-#207F3, IRGKangXi=0144.501, RSKangXi=18.13
207F4 CJK UNIFIED IDEOGRAPH-#207F4, IRGKangXi=0144.501, RSKangXi=18.13
207F5 CJK UNIFIED IDEOGRAPH-#207F5, IRGKangXi=0144.501, RSKangXi=18.13
207F6 CJK UNIFIED IDEOGRAPH-#207F6, IRGKangXi=0144.501, RSKangXi=18.13
207F7 CJK UNIFIED IDEOGRAPH-#207F7, IRGKangXi=0144.501, RSKangXi=18.13
207F8 CJK UNIFIED IDEOGRAPH-#207F8, IRGKangXi=0144.501, RSKangXi=18.13
207F9 CJK UNIFIED IDEOGRAPH-#207F9, IRGKangXi=0144.501, RSKangXi=18.13
207FA CJK UNIFIED IDEOGRAPH-#207FA, IRGKangXi=0144.510, RSKangXi=18.14
207FB CJK UNIFIED IDEOGRAPH-#207FB, IRGKangXi=0145.050, RSKangXi=18.14
207FC CJK UNIFIED IDEOGRAPH-#207FC, IRGKangXi=0145.080, RSKangXi=18.14
207FD CJK UNIFIED IDEOGRAPH-#207FD, IRGKangXi=0145.100, RSKangXi=18.14
207FE CJK UNIFIED IDEOGRAPH-#207FE, IRGKangXi=0145.110, RSKangXi=18.14
207FF CJK UNIFIED IDEOGRAPH-#207FF, IRGKangXi=0145.120, RSKangXi=18.14
20800 CJK UNIFIED IDEOGRAPH-#20800, IRGKangXi=0145.140, RSKangXi=18.14
20801 CJK UNIFIED IDEOGRAPH-#20801, IRGKangXi=0145.150, RSKangXi=18.14
20802 CJK UNIFIED IDEOGRAPH-#20802, IRGKangXi=0145.160, RSKangXi=18.14
20803 CJK UNIFIED IDEOGRAPH-#20803, IRGKangXi=0145.170, RSKangXi=18.14
20804 CJK UNIFIED IDEOGRAPH-#20804, IRGKangXi=0145.180, RSKangXi=18.14
20805 CJK UNIFIED IDEOGRAPH-#20805, IRGKangXi=0145.190, RSKangXi=18.14
20806 CJK UNIFIED IDEOGRAPH-#20806, IRGKangXi=0145.200, RSKangXi=18.14
20807 CJK UNIFIED IDEOGRAPH-#20807, IRGKangXi=0145.210, RSKangXi=18.14
20808 CJK UNIFIED IDEOGRAPH-#20808, IRGKangXi=0145.211, RSKangXi=18.14
20809 CJK UNIFIED IDEOGRAPH-#20809, IRGKangXi=0145.211, RSKangXi=18.14
2080A CJK UNIFIED IDEOGRAPH-#2080A, IRGKangXi=0145.211, RSKangXi=18.14
2080B CJK UNIFIED IDEOGRAPH-#2080B, IRGKangXi=0145.211, RSKangXi=154.9
2080C CJK UNIFIED IDEOGRAPH-#2080C, IRGKangXi=0145.220, RSKangXi=18.15
2080D CJK UNIFIED IDEOGRAPH-#2080D, IRGKangXi=0145.230, RSKangXi=18.15
2080E CJK UNIFIED IDEOGRAPH-#2080E, IRGKangXi=0145.240, RSKangXi=18.15
2080F CJK UNIFIED IDEOGRAPH-#2080F, IRGKangXi=0145.260, RSKangXi=18.15
20810 CJK UNIFIED IDEOGRAPH-#20810, IRGKangXi=0145.280, RSKangXi=18.15
20811 CJK UNIFIED IDEOGRAPH-#20811, IRGKangXi=0145.291, RSKangXi=18.15
20812 CJK UNIFIED IDEOGRAPH-#20812, IRGKangXi=0145.291, RSKangXi=18.15
20813 CJK UNIFIED IDEOGRAPH-#20813, IRGKangXi=0145.291, RSKangXi=18.15
20814 CJK UNIFIED IDEOGRAPH-#20814, IRGKangXi=0145.291, RSKangXi=18.15
20815 CJK UNIFIED IDEOGRAPH-#20815, IRGKangXi=0145.291, RSKangXi=18.15
20816 CJK UNIFIED IDEOGRAPH-#20816, IRGKangXi=0145.291, RSKangXi=18.15
20817 CJK UNIFIED IDEOGRAPH-#20817, IRGKangXi=0145.291, RSKangXi=18.15
20818 CJK UNIFIED IDEOGRAPH-#20818, IRGKangXi=0145.291, RSKangXi=18.15
20819 CJK UNIFIED IDEOGRAPH-#20819, IRGKangXi=0145.291, RSKangXi=18.15
2081A CJK UNIFIED IDEOGRAPH-#2081A, IRGKangXi=0145.291, RSKangXi=18.15
2081B CJK UNIFIED IDEOGRAPH-#2081B, IRGKangXi=0145.300, RSKangXi=18.16
2081C CJK UNIFIED IDEOGRAPH-#2081C, IRGKangXi=0145.320, RSKangXi=18.16
2081D CJK UNIFIED IDEOGRAPH-#2081D, IRGKangXi=0145.330, RSKangXi=18.16
2081E CJK UNIFIED IDEOGRAPH-#2081E, IRGKangXi=0145.340, RSKangXi=18.16
2081F CJK UNIFIED IDEOGRAPH-#2081F, IRGKangXi=0145.341, RSKangXi=18.16
20820 CJK UNIFIED IDEOGRAPH-#20820, IRGKangXi=0145.341, RSKangXi=18.16
20821 CJK UNIFIED IDEOGRAPH-#20821, IRGKangXi=0145.360, RSKangXi=18.17
20822 CJK UNIFIED IDEOGRAPH-#20822, IRGKangXi=0145.370, RSKangXi=18.17
20823 CJK UNIFIED IDEOGRAPH-#20823, IRGKangXi=0145.390, RSKangXi=18.17
20824 CJK UNIFIED IDEOGRAPH-#20824, IRGKangXi=0145.391, RSKangXi=18.18
20825 CJK UNIFIED IDEOGRAPH-#20825, IRGKangXi=0145.401, RSKangXi=18.19
20826 CJK UNIFIED IDEOGRAPH-#20826, IRGKangXi=0145.401, RSKangXi=18.18
20827 CJK UNIFIED IDEOGRAPH-#20827, IRGKangXi=0145.401, RSKangXi=18.18
20828 CJK UNIFIED IDEOGRAPH-#20828, IRGKangXi=0145.401, RSKangXi=18.18
20829 CJK UNIFIED IDEOGRAPH-#20829, IRGKangXi=0145.401, RSKangXi=18.18
2082A CJK UNIFIED IDEOGRAPH-#2082A, IRGKangXi=0145.410, RSKangXi=18.19
2082B CJK UNIFIED IDEOGRAPH-#2082B, IRGKangXi=0145.430, RSKangXi=18.19
2082C CJK UNIFIED IDEOGRAPH-#2082C, IRGKangXi=0145.441, RSKangXi=18.19
2082D CJK UNIFIED IDEOGRAPH-#2082D, IRGKangXi=0145.441, RSKangXi=18.19
2082E CJK UNIFIED IDEOGRAPH-#2082E, IRGKangXi=0145.450, RSKangXi=18.21
2082F CJK UNIFIED IDEOGRAPH-#2082F, IRGKangXi=0146.020, RSKangXi=18.22
20830 CJK UNIFIED IDEOGRAPH-#20830, IRGKangXi=0146.030, RSKangXi=18.24
20831 CJK UNIFIED IDEOGRAPH-#20831, IRGKangXi=0146.040, RSKangXi=18.24
20832 CJK UNIFIED IDEOGRAPH-#20832, IRGKangXi=0146.080, RSKangXi=19.1
20833 CJK UNIFIED IDEOGRAPH-#20833, IRGKangXi=0146.090, RSKangXi=19.2
20834 CJK UNIFIED IDEOGRAPH-#20834, IRGKangXi=0146.100, RSKangXi=19.2
20835 CJK UNIFIED IDEOGRAPH-#20835, IRGKangXi=0146.101, RSKangXi=19.2
20836 CJK UNIFIED IDEOGRAPH-#20836, IRGKangXi=0146.120, RSKangXi=19.3
20837 CJK UNIFIED IDEOGRAPH-#20837, IRGKangXi=0146.160, RSKangXi=19.3
20838 CJK UNIFIED IDEOGRAPH-#20838, IRGKangXi=0146.161, RSKangXi=19.3
20839 CJK UNIFIED IDEOGRAPH-#20839, IRGKangXi=0146.180, RSKangXi=19.4
2083A CJK UNIFIED IDEOGRAPH-#2083A, IRGKangXi=0146.241, RSKangXi=19.4
2083B CJK UNIFIED IDEOGRAPH-#2083B, IRGKangXi=0146.241, RSKangXi=19.4
2083C CJK UNIFIED IDEOGRAPH-#2083C, IRGKangXi=0146.241, RSKangXi=19.4
2083D CJK UNIFIED IDEOGRAPH-#2083D, IRGKangXi=0146.241, RSKangXi=19.4
2083E CJK UNIFIED IDEOGRAPH-#2083E, IRGKangXi=0146.241, RSKangXi=19.4
2083F CJK UNIFIED IDEOGRAPH-#2083F, IRGKangXi=0146.241, RSKangXi=19.4
20840 CJK UNIFIED IDEOGRAPH-#20840, IRGKangXi=0146.241, RSKangXi=19.4
20841 CJK UNIFIED IDEOGRAPH-#20841, IRGKangXi=0146.241, RSKangXi=19.4
20842 CJK UNIFIED IDEOGRAPH-#20842, IRGKangXi=0146.260, RSKangXi=19.5
20843 CJK UNIFIED IDEOGRAPH-#20843, IRGKangXi=0146.290, RSKangXi=19.5
20844 CJK UNIFIED IDEOGRAPH-#20844, IRGKangXi=0147.040, RSKangXi=19.5
20845 CJK UNIFIED IDEOGRAPH-#20845, IRGKangXi=0147.050, RSKangXi=19.5
20846 CJK UNIFIED IDEOGRAPH-#20846, IRGKangXi=0147.071, RSKangXi=19.5
20847 CJK UNIFIED IDEOGRAPH-#20847, IRGKangXi=0147.071, RSKangXi=19.5
20848 CJK UNIFIED IDEOGRAPH-#20848, IRGKangXi=0147.071, RSKangXi=19.5
20849 CJK UNIFIED IDEOGRAPH-#20849, IRGKangXi=0147.071, RSKangXi=19.5
2084A CJK UNIFIED IDEOGRAPH-#2084A, IRGKangXi=0147.071, RSKangXi=19.5
2084B CJK UNIFIED IDEOGRAPH-#2084B, IRGKangXi=0147.071, RSKangXi=19.5
2084C CJK UNIFIED IDEOGRAPH-#2084C, IRGKangXi=0147.071, RSKangXi=19.5
2084D CJK UNIFIED IDEOGRAPH-#2084D, IRGKangXi=0147.071, RSKangXi=19.5
2084E CJK UNIFIED IDEOGRAPH-#2084E, IRGKangXi=0147.071, RSKangXi=19.5
2084F CJK UNIFIED IDEOGRAPH-#2084F, IRGKangXi=0147.071, RSKangXi=19.5
20850 CJK UNIFIED IDEOGRAPH-#20850, IRGKangXi=0147.071, RSKangXi=19.5
20851 CJK UNIFIED IDEOGRAPH-#20851, IRGKangXi=0147.180, RSKangXi=19.6
20852 CJK UNIFIED IDEOGRAPH-#20852, IRGKangXi=0147.190, RSKangXi=19.6
20853 CJK UNIFIED IDEOGRAPH-#20853, IRGKangXi=0147.210, RSKangXi=19.6
20854 CJK UNIFIED IDEOGRAPH-#20854, IRGKangXi=0147.230, RSKangXi=19.6
20855 CJK UNIFIED IDEOGRAPH-#20855, IRGKangXi=0147.231, RSKangXi=19.6
20856 CJK UNIFIED IDEOGRAPH-#20856, IRGKangXi=0147.231, RSKangXi=19.6
20857 CJK UNIFIED IDEOGRAPH-#20857, IRGKangXi=0147.231, RSKangXi=19.6
20858 CJK UNIFIED IDEOGRAPH-#20858, IRGKangXi=0147.231, RSKangXi=19.6
20859 CJK UNIFIED IDEOGRAPH-#20859, IRGKangXi=0147.231, RSKangXi=19.6
2085A CJK UNIFIED IDEOGRAPH-#2085A, IRGKangXi=0147.231, RSKangXi=19.6
2085B CJK UNIFIED IDEOGRAPH-#2085B, IRGKangXi=0147.231, RSKangXi=19.6
2085C CJK UNIFIED IDEOGRAPH-#2085C, IRGKangXi=0147.231, RSKangXi=19.6
2085D CJK UNIFIED IDEOGRAPH-#2085D, IRGKangXi=0147.231, RSKangXi=19.6
2085E CJK UNIFIED IDEOGRAPH-#2085E, IRGKangXi=0147.300, RSKangXi=19.7
2085F CJK UNIFIED IDEOGRAPH-#2085F, IRGKangXi=0147.310, RSKangXi=19.7
20860 CJK UNIFIED IDEOGRAPH-#20860, IRGKangXi=0147.320, RSKangXi=19.7
20861 CJK UNIFIED IDEOGRAPH-#20861, IRGKangXi=0147.330, RSKangXi=19.7
20862 CJK UNIFIED IDEOGRAPH-#20862, IRGKangXi=0147.381
20863 CJK UNIFIED IDEOGRAPH-#20863, IRGKangXi=0147.381, RSKangXi=19.7
20864 CJK UNIFIED IDEOGRAPH-#20864, IRGKangXi=0147.381, RSKangXi=19.7
20865 CJK UNIFIED IDEOGRAPH-#20865, IRGKangXi=0147.381, RSKangXi=19.7
20866 CJK UNIFIED IDEOGRAPH-#20866, IRGKangXi=0147.381, RSKangXi=19.7
20867 CJK UNIFIED IDEOGRAPH-#20867, IRGKangXi=0147.381, RSKangXi=19.7
20868 CJK UNIFIED IDEOGRAPH-#20868, IRGKangXi=0147.381, RSKangXi=19.7
20869 CJK UNIFIED IDEOGRAPH-#20869, IRGKangXi=0147.381, RSKangXi=19.7
2086A CJK UNIFIED IDEOGRAPH-#2086A, IRGKangXi=0147.381, RSKangXi=19.7
2086B CJK UNIFIED IDEOGRAPH-#2086B, IRGKangXi=0147.400, RSKangXi=19.8
2086C CJK UNIFIED IDEOGRAPH-#2086C, IRGKangXi=0147.410, RSKangXi=19.8
2086D CJK UNIFIED IDEOGRAPH-#2086D, IRGKangXi=0147.420, RSKangXi=19.8
2086E CJK UNIFIED IDEOGRAPH-#2086E, IRGKangXi=0148.010, RSKangXi=19.8
2086F CJK UNIFIED IDEOGRAPH-#2086F, IRGKangXi=0148.020, RSKangXi=19.8
20870 CJK UNIFIED IDEOGRAPH-#20870, IRGKangXi=0148.050, RSKangXi=19.8
20871 CJK UNIFIED IDEOGRAPH-#20871, IRGKangXi=0148.080, RSKangXi=19.8
20872 CJK UNIFIED IDEOGRAPH-#20872, IRGKangXi=0148.081, RSKangXi=19.8
20873 CJK UNIFIED IDEOGRAPH-#20873, IRGKangXi=0148.081, RSKangXi=19.8
20874 CJK UNIFIED IDEOGRAPH-#20874, IRGKangXi=0148.081, RSKangXi=19.8
20875 CJK UNIFIED IDEOGRAPH-#20875, IRGKangXi=0148.081, RSKangXi=19.8
20876 CJK UNIFIED IDEOGRAPH-#20876, IRGKangXi=0148.081, RSKangXi=19.8
20877 CJK UNIFIED IDEOGRAPH-#20877, IRGKangXi=0148.081, RSKangXi=19.8
20878 CJK UNIFIED IDEOGRAPH-#20878, IRGKangXi=0148.081, RSKangXi=19.8
20879 CJK UNIFIED IDEOGRAPH-#20879, IRGKangXi=0148.081, RSKangXi=19.8
2087A CJK UNIFIED IDEOGRAPH-#2087A, IRGKangXi=0148.081, RSKangXi=19.8
2087B CJK UNIFIED IDEOGRAPH-#2087B, IRGKangXi=0148.130, RSKangXi=19.9
2087C CJK UNIFIED IDEOGRAPH-#2087C, IRGKangXi=0148.210, RSKangXi=19.9
2087D CJK UNIFIED IDEOGRAPH-#2087D, IRGKangXi=0148.220, RSKangXi=19.9
2087E CJK UNIFIED IDEOGRAPH-#2087E, IRGKangXi=0148.230, RSKangXi=19.9
2087F CJK UNIFIED IDEOGRAPH-#2087F, IRGKangXi=0148.240, RSKangXi=19.9
20880 CJK UNIFIED IDEOGRAPH-#20880, IRGKangXi=0148.241, RSKangXi=19.9
20881 CJK UNIFIED IDEOGRAPH-#20881, IRGKangXi=0148.241, RSKangXi=19.9
20882 CJK UNIFIED IDEOGRAPH-#20882, IRGKangXi=0148.241, RSKangXi=19.9
20883 CJK UNIFIED IDEOGRAPH-#20883, IRGKangXi=0148.241, RSKangXi=19.9
20884 CJK UNIFIED IDEOGRAPH-#20884, IRGKangXi=0148.241, RSKangXi=19.9
20885 CJK UNIFIED IDEOGRAPH-#20885, IRGKangXi=0148.260, RSKangXi=19.10
20886 CJK UNIFIED IDEOGRAPH-#20886, IRGKangXi=0148.270, RSKangXi=19.10
20887 CJK UNIFIED IDEOGRAPH-#20887, IRGKangXi=0148.290, RSKangXi=19.10
20888 CJK UNIFIED IDEOGRAPH-#20888, IRGKangXi=0148.380, RSKangXi=19.10
20889 CJK UNIFIED IDEOGRAPH-#20889, IRGKangXi=0148.390, RSKangXi=19.10
2088A CJK UNIFIED IDEOGRAPH-#2088A, IRGKangXi=0148.391, RSKangXi=19.10
2088B CJK UNIFIED IDEOGRAPH-#2088B, IRGKangXi=0148.391, RSKangXi=19.10
2088C CJK UNIFIED IDEOGRAPH-#2088C, IRGKangXi=0148.391, RSKangXi=19.10
2088D CJK UNIFIED IDEOGRAPH-#2088D, IRGKangXi=0148.391, RSKangXi=19.10
2088E CJK UNIFIED IDEOGRAPH-#2088E, IRGKangXi=0148.391, RSKangXi=19.10
2088F CJK UNIFIED IDEOGRAPH-#2088F, IRGKangXi=0148.391, RSKangXi=19.10
20890 CJK UNIFIED IDEOGRAPH-#20890, IRGKangXi=0148.391, RSKangXi=19.10
20891 CJK UNIFIED IDEOGRAPH-#20891, IRGKangXi=0148.391, RSKangXi=19.10
20892 CJK UNIFIED IDEOGRAPH-#20892, IRGKangXi=0148.391, RSKangXi=19.10
20893 CJK UNIFIED IDEOGRAPH-#20893, IRGKangXi=0148.410, RSKangXi=19.11
20894 CJK UNIFIED IDEOGRAPH-#20894, IRGKangXi=0149.010, RSKangXi=19.11
20895 CJK UNIFIED IDEOGRAPH-#20895, IRGKangXi=0149.020, RSKangXi=19.11
20896 CJK UNIFIED IDEOGRAPH-#20896, IRGKangXi=0149.100, RSKangXi=19.11
20897 CJK UNIFIED IDEOGRAPH-#20897, IRGKangXi=0149.110, RSKangXi=19.11
20898 CJK UNIFIED IDEOGRAPH-#20898, IRGKangXi=0149.111, RSKangXi=19.11
20899 CJK UNIFIED IDEOGRAPH-#20899, IRGKangXi=0149.111, RSKangXi=19.11
2089A CJK UNIFIED IDEOGRAPH-#2089A, IRGKangXi=0149.111, RSKangXi=19.11
2089B CJK UNIFIED IDEOGRAPH-#2089B, IRGKangXi=0149.111, RSKangXi=19.11
2089C CJK UNIFIED IDEOGRAPH-#2089C, IRGKangXi=0149.111, RSKangXi=19.11
2089D CJK UNIFIED IDEOGRAPH-#2089D, IRGKangXi=0149.111, RSKangXi=19.11
2089E CJK UNIFIED IDEOGRAPH-#2089E, IRGKangXi=0149.111, RSKangXi=19.11
2089F CJK UNIFIED IDEOGRAPH-#2089F, IRGKangXi=0149.111, RSKangXi=19.11
208A0 CJK UNIFIED IDEOGRAPH-#208A0, IRGKangXi=0149.120, RSKangXi=19.12
208A1 CJK UNIFIED IDEOGRAPH-#208A1, IRGKangXi=0149.130, RSKangXi=19.12
208A2 CJK UNIFIED IDEOGRAPH-#208A2, IRGKangXi=0149.140, RSKangXi=19.12
208A3 CJK UNIFIED IDEOGRAPH-#208A3, IRGKangXi=0149.150, RSKangXi=19.12
208A4 CJK UNIFIED IDEOGRAPH-#208A4, IRGKangXi=0149.170, RSKangXi=19.12, Def{to urge, compel}
208A5 CJK UNIFIED IDEOGRAPH-#208A5, IRGKangXi=0149.220, RSKangXi=19.12
208A6 CJK UNIFIED IDEOGRAPH-#208A6, IRGKangXi=0149.250, RSKangXi=19.12
208A7 CJK UNIFIED IDEOGRAPH-#208A7, IRGKangXi=0149.260, RSKangXi=19.12
208A8 CJK UNIFIED IDEOGRAPH-#208A8, IRGKangXi=0149.261, RSKangXi=19.12
208A9 CJK UNIFIED IDEOGRAPH-#208A9, IRGKangXi=0149.261, RSKangXi=19.12
208AA CJK UNIFIED IDEOGRAPH-#208AA, IRGKangXi=0149.261, RSKangXi=19.12
208AB CJK UNIFIED IDEOGRAPH-#208AB, IRGKangXi=0149.261, RSKangXi=19.12
208AC CJK UNIFIED IDEOGRAPH-#208AC, IRGKangXi=0149.261, RSKangXi=19.12
208AD CJK UNIFIED IDEOGRAPH-#208AD, IRGKangXi=0149.261, RSKangXi=19.12
208AE CJK UNIFIED IDEOGRAPH-#208AE, IRGKangXi=0149.261, RSKangXi=19.12
208AF CJK UNIFIED IDEOGRAPH-#208AF, IRGKangXi=0149.261, RSKangXi=19.12
208B0 CJK UNIFIED IDEOGRAPH-#208B0, IRGKangXi=0149.270, RSKangXi=19.13
208B1 CJK UNIFIED IDEOGRAPH-#208B1, IRGKangXi=0149.300, RSKangXi=19.13
208B2 CJK UNIFIED IDEOGRAPH-#208B2, IRGKangXi=0149.330, RSKangXi=19.13
208B3 CJK UNIFIED IDEOGRAPH-#208B3, IRGKangXi=0149.340, RSKangXi=19.13
208B4 CJK UNIFIED IDEOGRAPH-#208B4, IRGKangXi=0149.350, RSKangXi=19.13
208B5 CJK UNIFIED IDEOGRAPH-#208B5, IRGKangXi=0149.351, RSKangXi=19.13
208B6 CJK UNIFIED IDEOGRAPH-#208B6, IRGKangXi=0149.360, RSKangXi=19.14
208B7 CJK UNIFIED IDEOGRAPH-#208B7, IRGKangXi=0149.390, RSKangXi=19.14
208B8 CJK UNIFIED IDEOGRAPH-#208B8, IRGKangXi=0149.391, RSKangXi=19.14
208B9 CJK UNIFIED IDEOGRAPH-#208B9, IRGKangXi=0150.010, RSKangXi=19.15
208BA CJK UNIFIED IDEOGRAPH-#208BA, IRGKangXi=0150.040, RSKangXi=19.15
208BB CJK UNIFIED IDEOGRAPH-#208BB, IRGKangXi=0150.050, RSKangXi=19.15
208BC CJK UNIFIED IDEOGRAPH-#208BC, IRGKangXi=0150.060, RSKangXi=19.15
208BD CJK UNIFIED IDEOGRAPH-#208BD, IRGKangXi=0150.061, RSKangXi=19.15
208BE CJK UNIFIED IDEOGRAPH-#208BE, IRGKangXi=0150.061, RSKangXi=19.15
208BF CJK UNIFIED IDEOGRAPH-#208BF, IRGKangXi=0150.061, RSKangXi=19.15
208C0 CJK UNIFIED IDEOGRAPH-#208C0, IRGKangXi=0150.080, RSKangXi=19.16
208C1 CJK UNIFIED IDEOGRAPH-#208C1, IRGKangXi=0150.090, RSKangXi=19.16
208C2 CJK UNIFIED IDEOGRAPH-#208C2, IRGKangXi=0150.091, RSKangXi=19.16
208C3 CJK UNIFIED IDEOGRAPH-#208C3, IRGKangXi=0150.091, RSKangXi=19.16
208C4 CJK UNIFIED IDEOGRAPH-#208C4, IRGKangXi=0150.100, RSKangXi=19.17
208C5 CJK UNIFIED IDEOGRAPH-#208C5, IRGKangXi=0150.121, RSKangXi=19.17
208C6 CJK UNIFIED IDEOGRAPH-#208C6, IRGKangXi=0150.121, RSKangXi=19.18
208C7 CJK UNIFIED IDEOGRAPH-#208C7, IRGKangXi=0150.130, RSKangXi=19.19
208C8 CJK UNIFIED IDEOGRAPH-#208C8, IRGKangXi=0150.140, RSKangXi=19.21
208C9 CJK UNIFIED IDEOGRAPH-#208C9, IRGKangXi=0150.150, RSKangXi=19.21
208CA CJK UNIFIED IDEOGRAPH-#208CA, IRGKangXi=0150.160, RSKangXi=19.23
208CB CJK UNIFIED IDEOGRAPH-#208CB, IRGKangXi=0150.170, RSKangXi=19.32
208CC CJK UNIFIED IDEOGRAPH-#208CC, IRGKangXi=0150.241, RSKangXi=20.2
208CD CJK UNIFIED IDEOGRAPH-#208CD, IRGKangXi=0151.010, RSKangXi=20.3
208CE CJK UNIFIED IDEOGRAPH-#208CE, IRGKangXi=0151.020, RSKangXi=20.3
208CF CJK UNIFIED IDEOGRAPH-#208CF, IRGKangXi=0151.030, RSKangXi=20.3
208D0 CJK UNIFIED IDEOGRAPH-#208D0, IRGKangXi=0151.031, RSKangXi=20.3
208D1 CJK UNIFIED IDEOGRAPH-#208D1, IRGKangXi=0151.050, RSKangXi=20.4
208D2 CJK UNIFIED IDEOGRAPH-#208D2, IRGKangXi=0151.060, RSKangXi=20.4
208D3 CJK UNIFIED IDEOGRAPH-#208D3, IRGKangXi=0151.061, RSKangXi=20.4
208D4 CJK UNIFIED IDEOGRAPH-#208D4, IRGKangXi=0151.080, RSKangXi=20.5
208D5 CJK UNIFIED IDEOGRAPH-#208D5, IRGKangXi=0151.081, RSKangXi=20.5
208D6 CJK UNIFIED IDEOGRAPH-#208D6, IRGKangXi=0151.081, RSKangXi=20.5
208D7 CJK UNIFIED IDEOGRAPH-#208D7, IRGKangXi=0151.081, RSKangXi=20.5
208D8 CJK UNIFIED IDEOGRAPH-#208D8, IRGKangXi=0151.090, RSKangXi=20.6
208D9 CJK UNIFIED IDEOGRAPH-#208D9, IRGKangXi=0151.100, RSKangXi=20.6
208DA CJK UNIFIED IDEOGRAPH-#208DA, IRGKangXi=0151.110, RSKangXi=20.6
208DB CJK UNIFIED IDEOGRAPH-#208DB, IRGKangXi=0151.151, RSKangXi=20.6
208DC CJK UNIFIED IDEOGRAPH-#208DC, IRGKangXi=0151.151, RSKangXi=20.6
208DD CJK UNIFIED IDEOGRAPH-#208DD, IRGKangXi=0151.151, RSKangXi=20.6
208DE CJK UNIFIED IDEOGRAPH-#208DE, IRGKangXi=0151.160, RSKangXi=20.7
208DF CJK UNIFIED IDEOGRAPH-#208DF, IRGKangXi=0151.180, RSKangXi=20.7
208E0 CJK UNIFIED IDEOGRAPH-#208E0, IRGKangXi=0151.190, RSKangXi=20.7
208E1 CJK UNIFIED IDEOGRAPH-#208E1, IRGKangXi=0151.200, RSKangXi=20.7
208E2 CJK UNIFIED IDEOGRAPH-#208E2, IRGKangXi=0151.201, RSKangXi=20.7
208E3 CJK UNIFIED IDEOGRAPH-#208E3, IRGKangXi=0151.201, RSKangXi=20.7
208E4 CJK UNIFIED IDEOGRAPH-#208E4, IRGKangXi=0151.220, RSKangXi=20.8
208E5 CJK UNIFIED IDEOGRAPH-#208E5, IRGKangXi=0151.230, RSKangXi=20.8
208E6 CJK UNIFIED IDEOGRAPH-#208E6, IRGKangXi=0151.240, RSKangXi=20.8
208E7 CJK UNIFIED IDEOGRAPH-#208E7, IRGKangXi=0151.250, RSKangXi=20.8
208E8 CJK UNIFIED IDEOGRAPH-#208E8, IRGKangXi=0151.260, RSKangXi=20.8
208E9 CJK UNIFIED IDEOGRAPH-#208E9, IRGKangXi=0151.270, RSKangXi=20.8
208EA CJK UNIFIED IDEOGRAPH-#208EA, IRGKangXi=0151.280, RSKangXi=20.8
208EB CJK UNIFIED IDEOGRAPH-#208EB, IRGKangXi=0151.290, RSKangXi=20.8
208EC CJK UNIFIED IDEOGRAPH-#208EC, IRGKangXi=0151.291, RSKangXi=20.8
208ED CJK UNIFIED IDEOGRAPH-#208ED, IRGKangXi=0151.291, RSKangXi=20.8
208EE CJK UNIFIED IDEOGRAPH-#208EE, IRGKangXi=0151.300, RSKangXi=20.9
208EF CJK UNIFIED IDEOGRAPH-#208EF, IRGKangXi=0151.310, RSKangXi=20.9
208F0 CJK UNIFIED IDEOGRAPH-#208F0, IRGKangXi=0151.320, RSKangXi=20.9
208F1 CJK UNIFIED IDEOGRAPH-#208F1, IRGKangXi=0151.360, RSKangXi=20.9
208F2 CJK UNIFIED IDEOGRAPH-#208F2, IRGKangXi=0151.361, RSKangXi=20.9
208F3 CJK UNIFIED IDEOGRAPH-#208F3, IRGKangXi=0151.361, RSKangXi=20.9
208F4 CJK UNIFIED IDEOGRAPH-#208F4, IRGKangXi=0151.361, RSKangXi=20.9
208F5 CJK UNIFIED IDEOGRAPH-#208F5, IRGKangXi=0151.390, RSKangXi=20.10
208F6 CJK UNIFIED IDEOGRAPH-#208F6, IRGKangXi=0152.011, RSKangXi=20.10
208F7 CJK UNIFIED IDEOGRAPH-#208F7, IRGKangXi=0152.011, RSKangXi=20.10
208F8 CJK UNIFIED IDEOGRAPH-#208F8, IRGKangXi=0152.020, RSKangXi=20.11
208F9 CJK UNIFIED IDEOGRAPH-#208F9, IRGKangXi=0152.040, RSKangXi=20.11
208FA CJK UNIFIED IDEOGRAPH-#208FA, IRGKangXi=0152.060, RSKangXi=20.11
208FB CJK UNIFIED IDEOGRAPH-#208FB, IRGKangXi=0152.061, RSKangXi=20.11
208FC CJK UNIFIED IDEOGRAPH-#208FC, IRGKangXi=0152.061, RSKangXi=20.11
208FD CJK UNIFIED IDEOGRAPH-#208FD, IRGKangXi=0152.070, RSKangXi=20.12
208FE CJK UNIFIED IDEOGRAPH-#208FE, IRGKangXi=0152.080, RSKangXi=20.12
208FF CJK UNIFIED IDEOGRAPH-#208FF, IRGKangXi=0152.090, RSKangXi=20.12
20900 CJK UNIFIED IDEOGRAPH-#20900, IRGKangXi=0152.100, RSKangXi=20.12
20901 CJK UNIFIED IDEOGRAPH-#20901, IRGKangXi=0152.101, RSKangXi=20.12
20902 CJK UNIFIED IDEOGRAPH-#20902, IRGKangXi=0152.101, RSKangXi=20.12
20903 CJK UNIFIED IDEOGRAPH-#20903, IRGKangXi=0152.101, RSKangXi=20.13
20904 CJK UNIFIED IDEOGRAPH-#20904, IRGKangXi=0152.110, RSKangXi=20.14
20905 CJK UNIFIED IDEOGRAPH-#20905, IRGKangXi=0152.130, RSKangXi=20.14
20906 CJK UNIFIED IDEOGRAPH-#20906, IRGKangXi=0152.131, RSKangXi=20.14
20907 CJK UNIFIED IDEOGRAPH-#20907, IRGKangXi=0152.131, RSKangXi=20.14
20908 CJK UNIFIED IDEOGRAPH-#20908, IRGKangXi=0152.140, RSKangXi=20.15
20909 CJK UNIFIED IDEOGRAPH-#20909, IRGKangXi=0152.150, RSKangXi=20.15
2090A CJK UNIFIED IDEOGRAPH-#2090A, IRGKangXi=0152.160, RSKangXi=20.15
2090B CJK UNIFIED IDEOGRAPH-#2090B, IRGKangXi=0152.170, RSKangXi=20.18
2090C CJK UNIFIED IDEOGRAPH-#2090C, IRGKangXi=0152.171, RSKangXi=20.18
2090D CJK UNIFIED IDEOGRAPH-#2090D, IRGKangXi=0152.171, RSKangXi=20.18
2090E CJK UNIFIED IDEOGRAPH-#2090E, IRGKangXi=0152.190, RSKangXi=21.0
2090F CJK UNIFIED IDEOGRAPH-#2090F, IRGKangXi=0152.240, RSKangXi=21.2, Def{a tithing}
20910 CJK UNIFIED IDEOGRAPH-#20910, IRGKangXi=0152.270, RSKangXi=21.3
20911 CJK UNIFIED IDEOGRAPH-#20911, IRGKangXi=0152.280, RSKangXi=21.5
20912 CJK UNIFIED IDEOGRAPH-#20912, IRGKangXi=0152.290, RSKangXi=21.5
20913 CJK UNIFIED IDEOGRAPH-#20913, IRGKangXi=0152.300, RSKangXi=21.5
20914 CJK UNIFIED IDEOGRAPH-#20914, IRGKangXi=0152.301, RSKangXi=21.5
20915 CJK UNIFIED IDEOGRAPH-#20915, IRGKangXi=0152.301, RSKangXi=21.5
20916 CJK UNIFIED IDEOGRAPH-#20916, IRGKangXi=0152.311, RSKangXi=21.6
20917 CJK UNIFIED IDEOGRAPH-#20917, IRGKangXi=0152.320, RSKangXi=21.7
20918 CJK UNIFIED IDEOGRAPH-#20918, IRGKangXi=0152.330, RSKangXi=21.7
20919 CJK UNIFIED IDEOGRAPH-#20919, IRGKangXi=0152.340, RSKangXi=21.7
2091A CJK UNIFIED IDEOGRAPH-#2091A, IRGKangXi=0153.010, RSKangXi=21.7
2091B CJK UNIFIED IDEOGRAPH-#2091B, IRGKangXi=0153.011, RSKangXi=21.7
2091C CJK UNIFIED IDEOGRAPH-#2091C, IRGKangXi=0153.011, RSKangXi=21.7
2091D CJK UNIFIED IDEOGRAPH-#2091D, IRGKangXi=0153.011, RSKangXi=21.7
2091E CJK UNIFIED IDEOGRAPH-#2091E, IRGKangXi=0153.020, RSKangXi=21.8
2091F CJK UNIFIED IDEOGRAPH-#2091F, IRGKangXi=0153.030, RSKangXi=21.8
20920 CJK UNIFIED IDEOGRAPH-#20920, IRGKangXi=0153.031, RSKangXi=21.8
20921 CJK UNIFIED IDEOGRAPH-#20921, IRGKangXi=0153.031, RSKangXi=21.8
20922 CJK UNIFIED IDEOGRAPH-#20922, IRGKangXi=0153.031, RSKangXi=1.9
20923 CJK UNIFIED IDEOGRAPH-#20923, IRGKangXi=0153.070, RSKangXi=21.10
20924 CJK UNIFIED IDEOGRAPH-#20924, IRGKangXi=0153.071, RSKangXi=21.10
20925 CJK UNIFIED IDEOGRAPH-#20925, IRGKangXi=0153.071, RSKangXi=21.11
20926 CJK UNIFIED IDEOGRAPH-#20926, IRGKangXi=0153.080, RSKangXi=21.12
20927 CJK UNIFIED IDEOGRAPH-#20927, IRGKangXi=0153.081, RSKangXi=21.12
20928 CJK UNIFIED IDEOGRAPH-#20928, IRGKangXi=0153.081, RSKangXi=21.12
20929 CJK UNIFIED IDEOGRAPH-#20929, IRGKangXi=0153.081, RSKangXi=21.15
2092A CJK UNIFIED IDEOGRAPH-#2092A, IRGKangXi=0153.090, RSKangXi=21.16
2092B CJK UNIFIED IDEOGRAPH-#2092B, IRGKangXi=0153.091, RSKangXi=134.13
2092C CJK UNIFIED IDEOGRAPH-#2092C, IRGKangXi=0153.120, RSKangXi=22.0
2092D CJK UNIFIED IDEOGRAPH-#2092D, IRGKangXi=0153.121, RSKangXi=22.2
2092E CJK UNIFIED IDEOGRAPH-#2092E, IRGKangXi=0153.180, RSKangXi=22.4
2092F CJK UNIFIED IDEOGRAPH-#2092F, IRGKangXi=0153.190, RSKangXi=22.4
20930 CJK UNIFIED IDEOGRAPH-#20930, IRGKangXi=0153.210, RSKangXi=22.4
20931 CJK UNIFIED IDEOGRAPH-#20931, IRGKangXi=0153.240, RSKangXi=22.4
20932 CJK UNIFIED IDEOGRAPH-#20932, IRGKangXi=0153.251, RSKangXi=23.4
20933 CJK UNIFIED IDEOGRAPH-#20933, IRGKangXi=0153.260, RSKangXi=22.5
20934 CJK UNIFIED IDEOGRAPH-#20934, IRGKangXi=0153.290, RSKangXi=22.5
20935 CJK UNIFIED IDEOGRAPH-#20935, IRGKangXi=0153.320, RSKangXi=22.5
20936 CJK UNIFIED IDEOGRAPH-#20936, IRGKangXi=0153.321, RSKangXi=22.5
20937 CJK UNIFIED IDEOGRAPH-#20937, IRGKangXi=0153.321, RSKangXi=22.5
20938 CJK UNIFIED IDEOGRAPH-#20938, IRGKangXi=0153.330, RSKangXi=22.6
20939 CJK UNIFIED IDEOGRAPH-#20939, IRGKangXi=0153.340, RSKangXi=22.6
2093A CJK UNIFIED IDEOGRAPH-#2093A, IRGKangXi=0153.341, RSKangXi=22.6
2093B CJK UNIFIED IDEOGRAPH-#2093B, IRGKangXi=0153.341, RSKangXi=22.6
2093C CJK UNIFIED IDEOGRAPH-#2093C, IRGKangXi=0153.350, RSKangXi=22.7
2093D CJK UNIFIED IDEOGRAPH-#2093D, IRGKangXi=0153.360, RSKangXi=22.7
2093E CJK UNIFIED IDEOGRAPH-#2093E, IRGKangXi=0153.380, RSKangXi=22.7
2093F CJK UNIFIED IDEOGRAPH-#2093F, IRGKangXi=0153.390, RSKangXi=22.7
20940 CJK UNIFIED IDEOGRAPH-#20940, IRGKangXi=0153.410, RSKangXi=22.7
20941 CJK UNIFIED IDEOGRAPH-#20941, IRGKangXi=0153.430, RSKangXi=22.7
20942 CJK UNIFIED IDEOGRAPH-#20942, IRGKangXi=0153.440, RSKangXi=22.7
20943 CJK UNIFIED IDEOGRAPH-#20943, IRGKangXi=0153.441, RSKangXi=23.7
20944 CJK UNIFIED IDEOGRAPH-#20944, IRGKangXi=0153.441, RSKangXi=22.7
20945 CJK UNIFIED IDEOGRAPH-#20945, IRGKangXi=0153.441, RSKangXi=22.7
20946 CJK UNIFIED IDEOGRAPH-#20946, IRGKangXi=0153.441, RSKangXi=22.7
20947 CJK UNIFIED IDEOGRAPH-#20947, IRGKangXi=0153.441, RSKangXi=22.7
20948 CJK UNIFIED IDEOGRAPH-#20948, IRGKangXi=0153.441, RSKangXi=22.7
20949 CJK UNIFIED IDEOGRAPH-#20949, IRGKangXi=0154.010, RSKangXi=22.8
2094A CJK UNIFIED IDEOGRAPH-#2094A, IRGKangXi=0154.030, RSKangXi=22.8
2094B CJK UNIFIED IDEOGRAPH-#2094B, IRGKangXi=0154.040, RSKangXi=22.8
2094C CJK UNIFIED IDEOGRAPH-#2094C, IRGKangXi=0154.050, RSKangXi=22.8
2094D CJK UNIFIED IDEOGRAPH-#2094D, IRGKangXi=0154.051, RSKangXi=22.8
2094E CJK UNIFIED IDEOGRAPH-#2094E, IRGKangXi=0154.080, RSKangXi=22.9
2094F CJK UNIFIED IDEOGRAPH-#2094F, IRGKangXi=0154.091, RSKangXi=22.9
20950 CJK UNIFIED IDEOGRAPH-#20950, IRGKangXi=0154.100, RSKangXi=22.10
20951 CJK UNIFIED IDEOGRAPH-#20951, IRGKangXi=0154.110, RSKangXi=22.10
20952 CJK UNIFIED IDEOGRAPH-#20952, IRGKangXi=0154.120, RSKangXi=22.10
20953 CJK UNIFIED IDEOGRAPH-#20953, IRGKangXi=0154.121, RSKangXi=22.10
20954 CJK UNIFIED IDEOGRAPH-#20954, IRGKangXi=0154.121, RSKangXi=22.10
20955 CJK UNIFIED IDEOGRAPH-#20955, IRGKangXi=0154.121, RSKangXi=22.10
20956 CJK UNIFIED IDEOGRAPH-#20956, IRGKangXi=0154.160, RSKangXi=22.11
20957 CJK UNIFIED IDEOGRAPH-#20957, IRGKangXi=0154.161, RSKangXi=22.11
20958 CJK UNIFIED IDEOGRAPH-#20958, IRGKangXi=0154.161, RSKangXi=22.11
20959 CJK UNIFIED IDEOGRAPH-#20959, IRGKangXi=0154.170, RSKangXi=22.12
2095A CJK UNIFIED IDEOGRAPH-#2095A, IRGKangXi=0154.220, RSKangXi=22.12
2095B CJK UNIFIED IDEOGRAPH-#2095B, IRGKangXi=0154.221, RSKangXi=22.12
2095C CJK UNIFIED IDEOGRAPH-#2095C, IRGKangXi=0154.240, RSKangXi=22.13
2095D CJK UNIFIED IDEOGRAPH-#2095D, IRGKangXi=0154.250, RSKangXi=22.13
2095E CJK UNIFIED IDEOGRAPH-#2095E, IRGKangXi=0154.260, RSKangXi=22.13
2095F CJK UNIFIED IDEOGRAPH-#2095F, IRGKangXi=0154.261, RSKangXi=22.13
20960 CJK UNIFIED IDEOGRAPH-#20960, IRGKangXi=0154.261, RSKangXi=22.13
20961 CJK UNIFIED IDEOGRAPH-#20961, IRGKangXi=0154.261, RSKangXi=22.13
20962 CJK UNIFIED IDEOGRAPH-#20962, IRGKangXi=0154.280, RSKangXi=22.14
20963 CJK UNIFIED IDEOGRAPH-#20963, IRGKangXi=0154.290, RSKangXi=22.14
20964 CJK UNIFIED IDEOGRAPH-#20964, IRGKangXi=0154.301, RSKangXi=22.16
20965 CJK UNIFIED IDEOGRAPH-#20965, IRGKangXi=0154.301, RSKangXi=22.16
20966 CJK UNIFIED IDEOGRAPH-#20966, IRGKangXi=0154.320, RSKangXi=22.17
20967 CJK UNIFIED IDEOGRAPH-#20967, IRGKangXi=0154.321, RSKangXi=22.17
20968 CJK UNIFIED IDEOGRAPH-#20968, IRGKangXi=0154.341, RSKangXi=22.18
20969 CJK UNIFIED IDEOGRAPH-#20969, IRGKangXi=0154.341, RSKangXi=22.18
2096A CJK UNIFIED IDEOGRAPH-#2096A, IRGKangXi=0154.341, RSKangXi=22.20
2096B CJK UNIFIED IDEOGRAPH-#2096B, IRGKangXi=0154.341, RSKangXi=22.24
2096C CJK UNIFIED IDEOGRAPH-#2096C, IRGKangXi=0154.341, RSKangXi=22.28
2096D CJK UNIFIED IDEOGRAPH-#2096D, IRGKangXi=0154.361, RSKangXi=23.2
2096E CJK UNIFIED IDEOGRAPH-#2096E, IRGKangXi=0155.010, RSKangXi=23.4
2096F CJK UNIFIED IDEOGRAPH-#2096F, IRGKangXi=0155.020, RSKangXi=23.4
20970 CJK UNIFIED IDEOGRAPH-#20970, IRGKangXi=0155.040, RSKangXi=23.5
20971 CJK UNIFIED IDEOGRAPH-#20971, IRGKangXi=0155.060, RSKangXi=23.5
20972 CJK UNIFIED IDEOGRAPH-#20972, IRGKangXi=0155.061, RSKangXi=23.5
20973 CJK UNIFIED IDEOGRAPH-#20973, IRGKangXi=0155.071, RSKangXi=23.6
20974 CJK UNIFIED IDEOGRAPH-#20974, IRGKangXi=0155.090, RSKangXi=23.7
20975 CJK UNIFIED IDEOGRAPH-#20975, IRGKangXi=0155.091, RSKangXi=23.7
20976 CJK UNIFIED IDEOGRAPH-#20976, IRGKangXi=0155.100, RSKangXi=23.8
20977 CJK UNIFIED IDEOGRAPH-#20977, IRGKangXi=0155.141, RSKangXi=23.12
20978 CJK UNIFIED IDEOGRAPH-#20978, IRGKangXi=0155.150, RSKangXi=23.18
20979 CJK UNIFIED IDEOGRAPH-#20979, IRGKangXi=0155.151, RSKangXi=23.20
2097A CJK UNIFIED IDEOGRAPH-#2097A, IRGKangXi=0155.160, RSKangXi=23.20
2097B CJK UNIFIED IDEOGRAPH-#2097B, IRGKangXi=0156.050, RSKangXi=24.2
2097C CJK UNIFIED IDEOGRAPH-#2097C, IRGKangXi=0156.051, RSKangXi=24.2
2097D CJK UNIFIED IDEOGRAPH-#2097D, IRGKangXi=0156.080, RSKangXi=24.3
2097E CJK UNIFIED IDEOGRAPH-#2097E, IRGKangXi=0156.100, RSKangXi=24.3
2097F CJK UNIFIED IDEOGRAPH-#2097F, IRGKangXi=0156.101, RSKangXi=24.2
20980 CJK UNIFIED IDEOGRAPH-#20980, IRGKangXi=0156.101, RSKangXi=24.3
20981 CJK UNIFIED IDEOGRAPH-#20981, IRGKangXi=0156.101, RSKangXi=24.3
20982 CJK UNIFIED IDEOGRAPH-#20982, IRGKangXi=0156.130, RSKangXi=24.4
20983 CJK UNIFIED IDEOGRAPH-#20983, IRGKangXi=0156.150, RSKangXi=24.4
20984 CJK UNIFIED IDEOGRAPH-#20984, IRGKangXi=0156.160, RSKangXi=24.4
20985 CJK UNIFIED IDEOGRAPH-#20985, IRGKangXi=0156.180, RSKangXi=24.4
20986 CJK UNIFIED IDEOGRAPH-#20986, IRGKangXi=0156.190, RSKangXi=24.4
20987 CJK UNIFIED IDEOGRAPH-#20987, IRGKangXi=0156.200, RSKangXi=24.4
20988 CJK UNIFIED IDEOGRAPH-#20988, IRGKangXi=0156.220, RSKangXi=24.4
20989 CJK UNIFIED IDEOGRAPH-#20989, IRGKangXi=0156.221, RSKangXi=24.4
2098A CJK UNIFIED IDEOGRAPH-#2098A, IRGKangXi=0156.221, RSKangXi=24.4
2098B CJK UNIFIED IDEOGRAPH-#2098B, IRGKangXi=0156.221, RSKangXi=24.4
2098C CJK UNIFIED IDEOGRAPH-#2098C, IRGKangXi=0156.221, RSKangXi=24.4, Def{forty}
2098D CJK UNIFIED IDEOGRAPH-#2098D, IRGKangXi=0156.221, RSKangXi=24.4
2098E CJK UNIFIED IDEOGRAPH-#2098E, IRGKangXi=0156.221, RSKangXi=24.4
2098F CJK UNIFIED IDEOGRAPH-#2098F, IRGKangXi=0156.221, RSKangXi=24.4
20990 CJK UNIFIED IDEOGRAPH-#20990, IRGKangXi=0156.221, RSKangXi=24.4
20991 CJK UNIFIED IDEOGRAPH-#20991, IRGKangXi=0156.230, RSKangXi=24.5
20992 CJK UNIFIED IDEOGRAPH-#20992, IRGKangXi=0156.240, RSKangXi=24.5
20993 CJK UNIFIED IDEOGRAPH-#20993, IRGKangXi=0156.250, RSKangXi=24.5
20994 CJK UNIFIED IDEOGRAPH-#20994, IRGKangXi=0156.251, RSKangXi=24.5
20995 CJK UNIFIED IDEOGRAPH-#20995, IRGKangXi=0156.251, RSKangXi=24.5
20996 CJK UNIFIED IDEOGRAPH-#20996, IRGKangXi=0156.251, RSKangXi=24.5
20997 CJK UNIFIED IDEOGRAPH-#20997, IRGKangXi=0156.251, RSKangXi=24.5
20998 CJK UNIFIED IDEOGRAPH-#20998, IRGKangXi=0156.260, RSKangXi=24.6
20999 CJK UNIFIED IDEOGRAPH-#20999, IRGKangXi=0157.010, RSKangXi=24.6
2099A CJK UNIFIED IDEOGRAPH-#2099A, IRGKangXi=0157.020, RSKangXi=24.6
2099B CJK UNIFIED IDEOGRAPH-#2099B, IRGKangXi=0157.030, RSKangXi=24.6
2099C CJK UNIFIED IDEOGRAPH-#2099C, IRGKangXi=0157.040, RSKangXi=24.6, Def{forty}
2099D CJK UNIFIED IDEOGRAPH-#2099D, IRGKangXi=0157.041, RSKangXi=24.6
2099E CJK UNIFIED IDEOGRAPH-#2099E, IRGKangXi=0157.041, RSKangXi=24.6
2099F CJK UNIFIED IDEOGRAPH-#2099F, IRGKangXi=0157.041, RSKangXi=24.6
209A0 CJK UNIFIED IDEOGRAPH-#209A0, IRGKangXi=0157.041, RSKangXi=24.6
209A1 CJK UNIFIED IDEOGRAPH-#209A1, IRGKangXi=0157.041, RSKangXi=24.6
209A2 CJK UNIFIED IDEOGRAPH-#209A2, IRGKangXi=0157.041, RSKangXi=24.6
209A3 CJK UNIFIED IDEOGRAPH-#209A3, IRGKangXi=0157.080, RSKangXi=24.8
209A4 CJK UNIFIED IDEOGRAPH-#209A4, IRGKangXi=0157.081, RSKangXi=24.8
209A5 CJK UNIFIED IDEOGRAPH-#209A5, IRGKangXi=0157.081, RSKangXi=24.8
209A6 CJK UNIFIED IDEOGRAPH-#209A6, IRGKangXi=0157.081, RSKangXi=24.8
209A7 CJK UNIFIED IDEOGRAPH-#209A7, IRGKangXi=0157.081, RSKangXi=24.8
209A8 CJK UNIFIED IDEOGRAPH-#209A8, IRGKangXi=0157.081, RSKangXi=24.8
209A9 CJK UNIFIED IDEOGRAPH-#209A9, IRGKangXi=0157.081, RSKangXi=24.8
209AA CJK UNIFIED IDEOGRAPH-#209AA, IRGKangXi=0157.100, RSKangXi=24.9
209AB CJK UNIFIED IDEOGRAPH-#209AB, IRGKangXi=0157.110, RSKangXi=24.9
209AC CJK UNIFIED IDEOGRAPH-#209AC, IRGKangXi=0157.120, RSKangXi=24.9
209AD CJK UNIFIED IDEOGRAPH-#209AD, IRGKangXi=0157.121, RSKangXi=24.9
209AE CJK UNIFIED IDEOGRAPH-#209AE, IRGKangXi=0157.121, RSKangXi=24.9
209AF CJK UNIFIED IDEOGRAPH-#209AF, IRGKangXi=0157.121, RSKangXi=24.9
209B0 CJK UNIFIED IDEOGRAPH-#209B0, IRGKangXi=0157.131, RSKangXi=24.10
209B1 CJK UNIFIED IDEOGRAPH-#209B1, IRGKangXi=0157.131, RSKangXi=24.10
209B2 CJK UNIFIED IDEOGRAPH-#209B2, IRGKangXi=0157.131, RSKangXi=24.10
209B3 CJK UNIFIED IDEOGRAPH-#209B3, IRGKangXi=0157.131, RSKangXi=24.10
209B4 CJK UNIFIED IDEOGRAPH-#209B4, IRGKangXi=0157.150, RSKangXi=24.11
209B5 CJK UNIFIED IDEOGRAPH-#209B5, IRGKangXi=0157.160, RSKangXi=24.11
209B6 CJK UNIFIED IDEOGRAPH-#209B6, IRGKangXi=0157.170, RSKangXi=24.11
209B7 CJK UNIFIED IDEOGRAPH-#209B7, IRGKangXi=0157.180, RSKangXi=24.11
209B8 CJK UNIFIED IDEOGRAPH-#209B8, IRGKangXi=0157.181, RSKangXi=24.11
209B9 CJK UNIFIED IDEOGRAPH-#209B9, IRGKangXi=0157.181, RSKangXi=24.11
209BA CJK UNIFIED IDEOGRAPH-#209BA, IRGKangXi=0157.181, RSKangXi=24.11
209BB CJK UNIFIED IDEOGRAPH-#209BB, IRGKangXi=0157.181, RSKangXi=24.11
209BC CJK UNIFIED IDEOGRAPH-#209BC, IRGKangXi=0157.181, RSKangXi=24.11
209BD CJK UNIFIED IDEOGRAPH-#209BD, IRGKangXi=0157.181, RSKangXi=24.11
209BE CJK UNIFIED IDEOGRAPH-#209BE, IRGKangXi=0157.181, RSKangXi=24.11
209BF CJK UNIFIED IDEOGRAPH-#209BF, IRGKangXi=0157.181, RSKangXi=24.11
209C0 CJK UNIFIED IDEOGRAPH-#209C0, IRGKangXi=0157.190, RSKangXi=24.13
209C1 CJK UNIFIED IDEOGRAPH-#209C1, IRGKangXi=0157.191, RSKangXi=24.13
209C2 CJK UNIFIED IDEOGRAPH-#209C2, IRGKangXi=0157.191, RSKangXi=24.13
209C3 CJK UNIFIED IDEOGRAPH-#209C3, IRGKangXi=0157.191, RSKangXi=24.13
209C4 CJK UNIFIED IDEOGRAPH-#209C4, IRGKangXi=0157.191, RSKangXi=24.13
209C5 CJK UNIFIED IDEOGRAPH-#209C5, IRGKangXi=0157.191, RSKangXi=24.15
209C6 CJK UNIFIED IDEOGRAPH-#209C6, IRGKangXi=0157.191, RSKangXi=24.15
209C7 CJK UNIFIED IDEOGRAPH-#209C7, IRGKangXi=0157.191, RSKangXi=24.15
209C8 CJK UNIFIED IDEOGRAPH-#209C8, IRGKangXi=0157.191, RSKangXi=24.15
209C9 CJK UNIFIED IDEOGRAPH-#209C9, IRGKangXi=0157.200, RSKangXi=24.16
209CA CJK UNIFIED IDEOGRAPH-#209CA, IRGKangXi=0157.201, RSKangXi=24.16
209CB CJK UNIFIED IDEOGRAPH-#209CB, IRGKangXi=0157.201, RSKangXi=24.16
209CC CJK UNIFIED IDEOGRAPH-#209CC, IRGKangXi=0157.201, RSKangXi=24.16
209CD CJK UNIFIED IDEOGRAPH-#209CD, IRGKangXi=0157.201, RSKangXi=24.16
209CE CJK UNIFIED IDEOGRAPH-#209CE, IRGKangXi=0157.210, RSKangXi=24.17
209CF CJK UNIFIED IDEOGRAPH-#209CF, IRGKangXi=0157.220, RSKangXi=24.19
209D0 CJK UNIFIED IDEOGRAPH-#209D0, IRGKangXi=0157.231, RSKangXi=24.23
209D1 CJK UNIFIED IDEOGRAPH-#209D1, IRGKangXi=0157.240, RSKangXi=24.24
209D2 CJK UNIFIED IDEOGRAPH-#209D2, IRGKangXi=0157.261, RSKangXi=25.1
209D3 CJK UNIFIED IDEOGRAPH-#209D3, IRGKangXi=0158.020, RSKangXi=25.3
209D4 CJK UNIFIED IDEOGRAPH-#209D4, IRGKangXi=0158.030, RSKangXi=25.4
209D5 CJK UNIFIED IDEOGRAPH-#209D5, IRGKangXi=0158.031, RSKangXi=25.4
209D6 CJK UNIFIED IDEOGRAPH-#209D6, IRGKangXi=0158.031, RSKangXi=25.4
209D7 CJK UNIFIED IDEOGRAPH-#209D7, IRGKangXi=0158.031, RSKangXi=25.4
209D8 CJK UNIFIED IDEOGRAPH-#209D8, IRGKangXi=0158.031, RSKangXi=25.4
209D9 CJK UNIFIED IDEOGRAPH-#209D9, IRGKangXi=0158.040, RSKangXi=25.5
209DA CJK UNIFIED IDEOGRAPH-#209DA, IRGKangXi=0158.050, RSKangXi=25.5
209DB CJK UNIFIED IDEOGRAPH-#209DB, IRGKangXi=0158.080, RSKangXi=25.5
209DC CJK UNIFIED IDEOGRAPH-#209DC, IRGKangXi=0158.090, RSKangXi=25.5
209DD CJK UNIFIED IDEOGRAPH-#209DD, IRGKangXi=0158.101, RSKangXi=5.6
209DE CJK UNIFIED IDEOGRAPH-#209DE, IRGKangXi=0158.120, RSKangXi=25.6
209DF CJK UNIFIED IDEOGRAPH-#209DF, IRGKangXi=0158.140, RSKangXi=25.6
209E0 CJK UNIFIED IDEOGRAPH-#209E0, IRGKangXi=0158.160, RSKangXi=25.6
209E1 CJK UNIFIED IDEOGRAPH-#209E1, IRGKangXi=0158.170, RSKangXi=25.6
209E2 CJK UNIFIED IDEOGRAPH-#209E2, IRGKangXi=0158.180, RSKangXi=25.6
209E3 CJK UNIFIED IDEOGRAPH-#209E3, IRGKangXi=0158.200, RSKangXi=25.6
209E4 CJK UNIFIED IDEOGRAPH-#209E4, IRGKangXi=0158.210, RSKangXi=25.6
209E5 CJK UNIFIED IDEOGRAPH-#209E5, IRGKangXi=0158.220, RSKangXi=25.6
209E6 CJK UNIFIED IDEOGRAPH-#209E6, IRGKangXi=0158.221, RSKangXi=25.6
209E7 CJK UNIFIED IDEOGRAPH-#209E7, IRGKangXi=0158.221, RSKangXi=25.6
209E8 CJK UNIFIED IDEOGRAPH-#209E8, IRGKangXi=0158.221, RSKangXi=25.6
209E9 CJK UNIFIED IDEOGRAPH-#209E9, IRGKangXi=0158.230, RSKangXi=25.7, Def{an archaic form of U+6094 悔, to repent}
209EA CJK UNIFIED IDEOGRAPH-#209EA, IRGKangXi=0158.240, RSKangXi=25.7
209EB CJK UNIFIED IDEOGRAPH-#209EB, IRGKangXi=0158.250, RSKangXi=25.7
209EC CJK UNIFIED IDEOGRAPH-#209EC, IRGKangXi=0158.251, RSKangXi=25.7
209ED CJK UNIFIED IDEOGRAPH-#209ED, IRGKangXi=0158.251, RSKangXi=25.7
209EE CJK UNIFIED IDEOGRAPH-#209EE, IRGKangXi=0158.251, RSKangXi=25.7
209EF CJK UNIFIED IDEOGRAPH-#209EF, IRGKangXi=0158.251, RSKangXi=25.7
209F0 CJK UNIFIED IDEOGRAPH-#209F0, IRGKangXi=0158.251, RSKangXi=25.7
209F1 CJK UNIFIED IDEOGRAPH-#209F1, IRGKangXi=0158.251, RSKangXi=25.7
209F2 CJK UNIFIED IDEOGRAPH-#209F2, IRGKangXi=0158.251, RSKangXi=25.7
209F3 CJK UNIFIED IDEOGRAPH-#209F3, IRGKangXi=0158.260, RSKangXi=25.8
209F4 CJK UNIFIED IDEOGRAPH-#209F4, IRGKangXi=0158.270, RSKangXi=25.8
209F5 CJK UNIFIED IDEOGRAPH-#209F5, IRGKangXi=0158.290, RSKangXi=25.8
209F6 CJK UNIFIED IDEOGRAPH-#209F6, IRGKangXi=0158.300, RSKangXi=25.8
209F7 CJK UNIFIED IDEOGRAPH-#209F7, IRGKangXi=0158.310, RSKangXi=25.8
209F8 CJK UNIFIED IDEOGRAPH-#209F8, IRGKangXi=0158.311, RSKangXi=197.0
209F9 CJK UNIFIED IDEOGRAPH-#209F9, IRGKangXi=0158.311, RSKangXi=25.8
209FA CJK UNIFIED IDEOGRAPH-#209FA, IRGKangXi=0158.330, RSKangXi=25.9
209FB CJK UNIFIED IDEOGRAPH-#209FB, IRGKangXi=0158.340, RSKangXi=25.9
209FC CJK UNIFIED IDEOGRAPH-#209FC, IRGKangXi=0158.350, RSKangXi=25.9
209FD CJK UNIFIED IDEOGRAPH-#209FD, IRGKangXi=0158.360, RSKangXi=25.9
209FE CJK UNIFIED IDEOGRAPH-#209FE, IRGKangXi=0158.361, RSKangXi=25.9
209FF CJK UNIFIED IDEOGRAPH-#209FF, IRGKangXi=0158.361, RSKangXi=25.9
20A00 CJK UNIFIED IDEOGRAPH-#20A00, IRGKangXi=0158.370, RSKangXi=25.10
20A01 CJK UNIFIED IDEOGRAPH-#20A01, IRGKangXi=0158.380, RSKangXi=25.10
20A02 CJK UNIFIED IDEOGRAPH-#20A02, IRGKangXi=0158.390, RSKangXi=25.10
20A03 CJK UNIFIED IDEOGRAPH-#20A03, IRGKangXi=0158.391, RSKangXi=36.9
20A04 CJK UNIFIED IDEOGRAPH-#20A04, IRGKangXi=0158.391, RSKangXi=25.10
20A05 CJK UNIFIED IDEOGRAPH-#20A05, IRGKangXi=0158.400, RSKangXi=25.11
20A06 CJK UNIFIED IDEOGRAPH-#20A06, IRGKangXi=0158.410, RSKangXi=25.12
20A07 CJK UNIFIED IDEOGRAPH-#20A07, IRGKangXi=0158.420, RSKangXi=25.12
20A08 CJK UNIFIED IDEOGRAPH-#20A08, IRGKangXi=0158.430, RSKangXi=25.13
20A09 CJK UNIFIED IDEOGRAPH-#20A09, IRGKangXi=0158.431, RSKangXi=25.13
20A0A CJK UNIFIED IDEOGRAPH-#20A0A, IRGKangXi=0158.431, RSKangXi=25.13
20A0B CJK UNIFIED IDEOGRAPH-#20A0B, IRGKangXi=0158.440, RSKangXi=25.25
20A0C CJK UNIFIED IDEOGRAPH-#20A0C, IRGKangXi=0158.441, RSKangXi=25.31
20A0D CJK UNIFIED IDEOGRAPH-#20A0D, IRGKangXi=0159.010, RSKangXi=26.2
20A0E CJK UNIFIED IDEOGRAPH-#20A0E, IRGKangXi=0159.020, RSKangXi=26.2
20A0F CJK UNIFIED IDEOGRAPH-#20A0F, IRGKangXi=0159.021, RSKangXi=26.2
20A10 CJK UNIFIED IDEOGRAPH-#20A10, IRGKangXi=0159.021, RSKangXi=26.2
20A11 CJK UNIFIED IDEOGRAPH-#20A11, IRGKangXi=0159.091, RSKangXi=26.3
20A12 CJK UNIFIED IDEOGRAPH-#20A12, IRGKangXi=0159.140, RSKangXi=26.4
20A13 CJK UNIFIED IDEOGRAPH-#20A13, IRGKangXi=0159.150, RSKangXi=26.4
20A14 CJK UNIFIED IDEOGRAPH-#20A14, IRGKangXi=0159.160, RSKangXi=26.4
20A15 CJK UNIFIED IDEOGRAPH-#20A15, IRGKangXi=0159.161, RSKangXi=26.4
20A16 CJK UNIFIED IDEOGRAPH-#20A16, IRGKangXi=0159.161, RSKangXi=26.4
20A17 CJK UNIFIED IDEOGRAPH-#20A17, IRGKangXi=0159.161, RSKangXi=26.4
20A18 CJK UNIFIED IDEOGRAPH-#20A18, IRGKangXi=0159.210, RSKangXi=26.5
20A19 CJK UNIFIED IDEOGRAPH-#20A19, IRGKangXi=0160.010, RSKangXi=26.7
20A1A CJK UNIFIED IDEOGRAPH-#20A1A, IRGKangXi=0160.020, RSKangXi=26.7
20A1B CJK UNIFIED IDEOGRAPH-#20A1B, IRGKangXi=0160.050, RSKangXi=26.7
20A1C CJK UNIFIED IDEOGRAPH-#20A1C, IRGKangXi=0160.060, RSKangXi=26.7
20A1D CJK UNIFIED IDEOGRAPH-#20A1D, IRGKangXi=0160.061, RSKangXi=26.7
20A1E CJK UNIFIED IDEOGRAPH-#20A1E, IRGKangXi=0160.081, RSKangXi=26.8
20A1F CJK UNIFIED IDEOGRAPH-#20A1F, IRGKangXi=0160.090, RSKangXi=26.10
20A20 CJK UNIFIED IDEOGRAPH-#20A20, IRGKangXi=0160.100, RSKangXi=26.10
20A21 CJK UNIFIED IDEOGRAPH-#20A21, IRGKangXi=0160.101, RSKangXi=26.10
20A22 CJK UNIFIED IDEOGRAPH-#20A22, IRGKangXi=0160.120, RSKangXi=26.11
20A23 CJK UNIFIED IDEOGRAPH-#20A23, IRGKangXi=0160.121, RSKangXi=26.11
20A24 CJK UNIFIED IDEOGRAPH-#20A24, IRGKangXi=0160.121, RSKangXi=26.11
20A25 CJK UNIFIED IDEOGRAPH-#20A25, IRGKangXi=0160.130, RSKangXi=26.12
20A26 CJK UNIFIED IDEOGRAPH-#20A26, IRGKangXi=0160.131, RSKangXi=26.15
20A27 CJK UNIFIED IDEOGRAPH-#20A27, IRGKangXi=0160.140, RSKangXi=26.16
20A28 CJK UNIFIED IDEOGRAPH-#20A28, IRGKangXi=0160.141, RSKangXi=26.12
20A29 CJK UNIFIED IDEOGRAPH-#20A29, IRGKangXi=0160.141, RSKangXi=26.16
20A2A CJK UNIFIED IDEOGRAPH-#20A2A, IRGKangXi=0160.141, RSKangXi=26.16
20A2B CJK UNIFIED IDEOGRAPH-#20A2B, IRGKangXi=0160.141, RSKangXi=26.24
20A2C CJK UNIFIED IDEOGRAPH-#20A2C, IRGKangXi=0160.160, RSKangXi=27.2
20A2D CJK UNIFIED IDEOGRAPH-#20A2D, IRGKangXi=0160.190, RSKangXi=27.3
20A2E CJK UNIFIED IDEOGRAPH-#20A2E, IRGKangXi=0160.220, RSKangXi=27.3
20A2F CJK UNIFIED IDEOGRAPH-#20A2F, IRGKangXi=0160.230, RSKangXi=27.3
20A30 CJK UNIFIED IDEOGRAPH-#20A30, IRGKangXi=0160.240, RSKangXi=27.3
20A31 CJK UNIFIED IDEOGRAPH-#20A31, IRGKangXi=0160.250, RSKangXi=27.3
20A32 CJK UNIFIED IDEOGRAPH-#20A32, IRGKangXi=0160.251, RSKangXi=27.3
20A33 CJK UNIFIED IDEOGRAPH-#20A33, IRGKangXi=0160.251, RSKangXi=27.3
20A34 CJK UNIFIED IDEOGRAPH-#20A34, IRGKangXi=0160.270, RSKangXi=27.4
20A35 CJK UNIFIED IDEOGRAPH-#20A35, IRGKangXi=0160.290, RSKangXi=27.4
20A36 CJK UNIFIED IDEOGRAPH-#20A36, IRGKangXi=0160.310, RSKangXi=27.4
20A37 CJK UNIFIED IDEOGRAPH-#20A37, IRGKangXi=0160.320, RSKangXi=27.4
20A38 CJK UNIFIED IDEOGRAPH-#20A38, IRGKangXi=0160.330, RSKangXi=27.4
20A39 CJK UNIFIED IDEOGRAPH-#20A39, IRGKangXi=0160.340, RSKangXi=27.4
20A3A CJK UNIFIED IDEOGRAPH-#20A3A, IRGKangXi=0160.350, RSKangXi=27.4
20A3B CJK UNIFIED IDEOGRAPH-#20A3B, IRGKangXi=0160.370, RSKangXi=27.4
20A3C CJK UNIFIED IDEOGRAPH-#20A3C, IRGKangXi=0160.371, RSKangXi=27.4
20A3D CJK UNIFIED IDEOGRAPH-#20A3D, IRGKangXi=0160.371, RSKangXi=27.4
20A3E CJK UNIFIED IDEOGRAPH-#20A3E, IRGKangXi=0160.371, RSKangXi=27.4
20A3F CJK UNIFIED IDEOGRAPH-#20A3F, IRGKangXi=0160.371, RSKangXi=27.4
20A40 CJK UNIFIED IDEOGRAPH-#20A40, IRGKangXi=0160.380, RSKangXi=27.5
20A41 CJK UNIFIED IDEOGRAPH-#20A41, IRGKangXi=0161.040, RSKangXi=27.5
20A42 CJK UNIFIED IDEOGRAPH-#20A42, IRGKangXi=0161.050, RSKangXi=27.5
20A43 CJK UNIFIED IDEOGRAPH-#20A43, IRGKangXi=0161.060, RSKangXi=27.5
20A44 CJK UNIFIED IDEOGRAPH-#20A44, IRGKangXi=0161.061, RSKangXi=27.5
20A45 CJK UNIFIED IDEOGRAPH-#20A45, IRGKangXi=0161.061, RSKangXi=27.5
20A46 CJK UNIFIED IDEOGRAPH-#20A46, IRGKangXi=0161.061, RSKangXi=27.5
20A47 CJK UNIFIED IDEOGRAPH-#20A47, IRGKangXi=0161.061, RSKangXi=27.5
20A48 CJK UNIFIED IDEOGRAPH-#20A48, IRGKangXi=0161.061, RSKangXi=27.5
20A49 CJK UNIFIED IDEOGRAPH-#20A49, IRGKangXi=0161.061, RSKangXi=27.5
20A4A CJK UNIFIED IDEOGRAPH-#20A4A, IRGKangXi=0161.100, RSKangXi=27.6
20A4B CJK UNIFIED IDEOGRAPH-#20A4B, IRGKangXi=0161.120, RSKangXi=27.6
20A4C CJK UNIFIED IDEOGRAPH-#20A4C, IRGKangXi=0161.130, RSKangXi=27.6
20A4D CJK UNIFIED IDEOGRAPH-#20A4D, IRGKangXi=0161.150, RSKangXi=27.6
20A4E CJK UNIFIED IDEOGRAPH-#20A4E, IRGKangXi=0161.160, RSKangXi=27.6
20A4F CJK UNIFIED IDEOGRAPH-#20A4F, IRGKangXi=0161.170, RSKangXi=27.6
20A50 CJK UNIFIED IDEOGRAPH-#20A50, IRGKangXi=0161.171, RSKangXi=27.6
20A51 CJK UNIFIED IDEOGRAPH-#20A51, IRGKangXi=0161.171, RSKangXi=27.6
20A52 CJK UNIFIED IDEOGRAPH-#20A52, IRGKangXi=0161.171, RSKangXi=27.6
20A53 CJK UNIFIED IDEOGRAPH-#20A53, IRGKangXi=0161.171, RSKangXi=27.6
20A54 CJK UNIFIED IDEOGRAPH-#20A54, IRGKangXi=0161.171, RSKangXi=27.6
20A55 CJK UNIFIED IDEOGRAPH-#20A55, IRGKangXi=0161.171, RSKangXi=27.6
20A56 CJK UNIFIED IDEOGRAPH-#20A56, IRGKangXi=0161.171, RSKangXi=12.6
20A57 CJK UNIFIED IDEOGRAPH-#20A57, IRGKangXi=0161.180, RSKangXi=27.7
20A58 CJK UNIFIED IDEOGRAPH-#20A58, IRGKangXi=0161.210, RSKangXi=27.7
20A59 CJK UNIFIED IDEOGRAPH-#20A59, IRGKangXi=0161.220, RSKangXi=27.7
20A5A CJK UNIFIED IDEOGRAPH-#20A5A, IRGKangXi=0161.290, RSKangXi=27.7
20A5B CJK UNIFIED IDEOGRAPH-#20A5B, IRGKangXi=0161.300, RSKangXi=27.7
20A5C CJK UNIFIED IDEOGRAPH-#20A5C, IRGKangXi=0161.310, RSKangXi=27.7
20A5D CJK UNIFIED IDEOGRAPH-#20A5D, IRGKangXi=0161.320, RSKangXi=27.7
20A5E CJK UNIFIED IDEOGRAPH-#20A5E, IRGKangXi=0161.330, RSKangXi=27.7
20A5F CJK UNIFIED IDEOGRAPH-#20A5F, IRGKangXi=0161.340, RSKangXi=27.7
20A60 CJK UNIFIED IDEOGRAPH-#20A60, IRGKangXi=0161.350, RSKangXi=27.7
20A61 CJK UNIFIED IDEOGRAPH-#20A61, IRGKangXi=0161.351, RSKangXi=27.7
20A62 CJK UNIFIED IDEOGRAPH-#20A62, IRGKangXi=0161.351, RSKangXi=27.7
20A63 CJK UNIFIED IDEOGRAPH-#20A63, IRGKangXi=0161.351, RSKangXi=27.7
20A64 CJK UNIFIED IDEOGRAPH-#20A64, IRGKangXi=0161.351, RSKangXi=27.7
20A65 CJK UNIFIED IDEOGRAPH-#20A65, IRGKangXi=0161.351, RSKangXi=27.7
20A66 CJK UNIFIED IDEOGRAPH-#20A66, IRGKangXi=0161.351, RSKangXi=27.7
20A67 CJK UNIFIED IDEOGRAPH-#20A67, IRGKangXi=0161.390, RSKangXi=27.8
20A68 CJK UNIFIED IDEOGRAPH-#20A68, IRGKangXi=0161.400, RSKangXi=27.8
20A69 CJK UNIFIED IDEOGRAPH-#20A69, IRGKangXi=0161.420, RSKangXi=27.8
20A6A CJK UNIFIED IDEOGRAPH-#20A6A, IRGKangXi=0161.430, RSKangXi=27.8
20A6B CJK UNIFIED IDEOGRAPH-#20A6B, IRGKangXi=0161.440, RSKangXi=27.8
20A6C CJK UNIFIED IDEOGRAPH-#20A6C, IRGKangXi=0161.450, RSKangXi=27.8
20A6D CJK UNIFIED IDEOGRAPH-#20A6D, IRGKangXi=0162.010, RSKangXi=27.8
20A6E CJK UNIFIED IDEOGRAPH-#20A6E, IRGKangXi=0162.070, RSKangXi=27.8
20A6F CJK UNIFIED IDEOGRAPH-#20A6F, IRGKangXi=0162.080, RSKangXi=27.8
20A70 CJK UNIFIED IDEOGRAPH-#20A70, IRGKangXi=0162.090, RSKangXi=27.8
20A71 CJK UNIFIED IDEOGRAPH-#20A71, IRGKangXi=0162.100, RSKangXi=27.8
20A72 CJK UNIFIED IDEOGRAPH-#20A72, IRGKangXi=0162.101, RSKangXi=27.8
20A73 CJK UNIFIED IDEOGRAPH-#20A73, IRGKangXi=0162.101, RSKangXi=27.8
20A74 CJK UNIFIED IDEOGRAPH-#20A74, IRGKangXi=0162.101, RSKangXi=27.8
20A75 CJK UNIFIED IDEOGRAPH-#20A75, IRGKangXi=0162.101, RSKangXi=27.8
20A76 CJK UNIFIED IDEOGRAPH-#20A76, IRGKangXi=0162.101, RSKangXi=27.8
20A77 CJK UNIFIED IDEOGRAPH-#20A77, IRGKangXi=0162.101, RSKangXi=27.8
20A78 CJK UNIFIED IDEOGRAPH-#20A78, IRGKangXi=0162.110, RSKangXi=27.9
20A79 CJK UNIFIED IDEOGRAPH-#20A79, IRGKangXi=0162.120, RSKangXi=27.9
20A7A CJK UNIFIED IDEOGRAPH-#20A7A, IRGKangXi=0162.160, RSKangXi=27.9, Def{to split, rive, crack}
20A7B CJK UNIFIED IDEOGRAPH-#20A7B, IRGKangXi=0162.170, RSKangXi=27.9
20A7C CJK UNIFIED IDEOGRAPH-#20A7C, IRGKangXi=0162.180, RSKangXi=27.9
20A7D CJK UNIFIED IDEOGRAPH-#20A7D, IRGKangXi=0162.190, RSKangXi=27.9
20A7E CJK UNIFIED IDEOGRAPH-#20A7E, IRGKangXi=0162.191, RSKangXi=27.9
20A7F CJK UNIFIED IDEOGRAPH-#20A7F, IRGKangXi=0162.191, RSKangXi=27.11
20A80 CJK UNIFIED IDEOGRAPH-#20A80, IRGKangXi=0162.191, RSKangXi=27.9
20A81 CJK UNIFIED IDEOGRAPH-#20A81, IRGKangXi=0162.191, RSKangXi=27.9
20A82 CJK UNIFIED IDEOGRAPH-#20A82, IRGKangXi=0162.191, RSKangXi=27.9
20A83 CJK UNIFIED IDEOGRAPH-#20A83, IRGKangXi=0162.191, RSKangXi=27.9
20A84 CJK UNIFIED IDEOGRAPH-#20A84, IRGKangXi=0162.191, RSKangXi=27.9
20A85 CJK UNIFIED IDEOGRAPH-#20A85, IRGKangXi=0162.191, RSKangXi=27.9
20A86 CJK UNIFIED IDEOGRAPH-#20A86, IRGKangXi=0162.191, RSKangXi=27.9
20A87 CJK UNIFIED IDEOGRAPH-#20A87, IRGKangXi=0162.290, RSKangXi=27.10
20A88 CJK UNIFIED IDEOGRAPH-#20A88, IRGKangXi=0162.300, RSKangXi=27.10
20A89 CJK UNIFIED IDEOGRAPH-#20A89, IRGKangXi=0162.320, RSKangXi=27.10
20A8A CJK UNIFIED IDEOGRAPH-#20A8A, IRGKangXi=0162.340, RSKangXi=27.10
20A8B CJK UNIFIED IDEOGRAPH-#20A8B, IRGKangXi=0162.350, RSKangXi=27.10
20A8C CJK UNIFIED IDEOGRAPH-#20A8C, IRGKangXi=0162.360, RSKangXi=27.10
20A8D CJK UNIFIED IDEOGRAPH-#20A8D, IRGKangXi=0162.370, RSKangXi=27.10
20A8E CJK UNIFIED IDEOGRAPH-#20A8E, IRGKangXi=0162.371, RSKangXi=27.10
20A8F CJK UNIFIED IDEOGRAPH-#20A8F, IRGKangXi=0162.371, RSKangXi=27.10
20A90 CJK UNIFIED IDEOGRAPH-#20A90, IRGKangXi=0162.371, RSKangXi=27.10
20A91 CJK UNIFIED IDEOGRAPH-#20A91, IRGKangXi=0162.410, RSKangXi=27.11
20A92 CJK UNIFIED IDEOGRAPH-#20A92, IRGKangXi=0162.420, RSKangXi=27.11
20A93 CJK UNIFIED IDEOGRAPH-#20A93, IRGKangXi=0162.430, RSKangXi=27.11
20A94 CJK UNIFIED IDEOGRAPH-#20A94, IRGKangXi=0162.440, RSKangXi=27.11
20A95 CJK UNIFIED IDEOGRAPH-#20A95, IRGKangXi=0162.441, RSKangXi=27.11
20A96 CJK UNIFIED IDEOGRAPH-#20A96, IRGKangXi=0162.441, RSKangXi=27.11
20A97 CJK UNIFIED IDEOGRAPH-#20A97, IRGKangXi=0162.441, RSKangXi=27.11
20A98 CJK UNIFIED IDEOGRAPH-#20A98, IRGKangXi=0162.441, RSKangXi=27.11
20A99 CJK UNIFIED IDEOGRAPH-#20A99, IRGKangXi=0162.450, RSKangXi=27.12
20A9A CJK UNIFIED IDEOGRAPH-#20A9A, IRGKangXi=0162.460, RSKangXi=27.12
20A9B CJK UNIFIED IDEOGRAPH-#20A9B, IRGKangXi=0162.480, RSKangXi=27.12
20A9C CJK UNIFIED IDEOGRAPH-#20A9C, IRGKangXi=0162.490, RSKangXi=27.12
20A9D CJK UNIFIED IDEOGRAPH-#20A9D, IRGKangXi=0163.020, RSKangXi=27.12
20A9E CJK UNIFIED IDEOGRAPH-#20A9E, IRGKangXi=0163.030, RSKangXi=27.12
20A9F CJK UNIFIED IDEOGRAPH-#20A9F, IRGKangXi=0163.040, RSKangXi=27.12
20AA0 CJK UNIFIED IDEOGRAPH-#20AA0, IRGKangXi=0163.041, RSKangXi=27.12
20AA1 CJK UNIFIED IDEOGRAPH-#20AA1, IRGKangXi=0163.041, RSKangXi=27.12
20AA2 CJK UNIFIED IDEOGRAPH-#20AA2, IRGKangXi=0163.041, RSKangXi=27.12
20AA3 CJK UNIFIED IDEOGRAPH-#20AA3, IRGKangXi=0163.041, RSKangXi=27.12
20AA4 CJK UNIFIED IDEOGRAPH-#20AA4, IRGKangXi=0163.041, RSKangXi=27.12
20AA5 CJK UNIFIED IDEOGRAPH-#20AA5, IRGKangXi=0163.041, RSKangXi=27.12
20AA6 CJK UNIFIED IDEOGRAPH-#20AA6, IRGKangXi=0163.041, RSKangXi=27.12
20AA7 CJK UNIFIED IDEOGRAPH-#20AA7, IRGKangXi=0163.041, RSKangXi=27.12
20AA8 CJK UNIFIED IDEOGRAPH-#20AA8, IRGKangXi=0163.041, RSKangXi=27.12
20AA9 CJK UNIFIED IDEOGRAPH-#20AA9, IRGKangXi=0163.041, RSKangXi=27.12
20AAA CJK UNIFIED IDEOGRAPH-#20AAA, IRGKangXi=0163.041, RSKangXi=27.12
20AAB CJK UNIFIED IDEOGRAPH-#20AAB, IRGKangXi=0163.041, RSKangXi=27.12
20AAC CJK UNIFIED IDEOGRAPH-#20AAC, IRGKangXi=0163.041, RSKangXi=27.12
20AAD CJK UNIFIED IDEOGRAPH-#20AAD, IRGKangXi=0163.060, RSKangXi=27.13
20AAE CJK UNIFIED IDEOGRAPH-#20AAE, IRGKangXi=0163.070, RSKangXi=27.13
20AAF CJK UNIFIED IDEOGRAPH-#20AAF, IRGKangXi=0163.100, RSKangXi=27.13
20AB0 CJK UNIFIED IDEOGRAPH-#20AB0, IRGKangXi=0163.110, RSKangXi=27.13
20AB1 CJK UNIFIED IDEOGRAPH-#20AB1, IRGKangXi=0163.111, RSKangXi=27.13
20AB2 CJK UNIFIED IDEOGRAPH-#20AB2, IRGKangXi=0163.111, RSKangXi=27.13
20AB3 CJK UNIFIED IDEOGRAPH-#20AB3, IRGKangXi=0163.111, RSKangXi=27.13
20AB4 CJK UNIFIED IDEOGRAPH-#20AB4, IRGKangXi=0163.111, RSKangXi=27.13
20AB5 CJK UNIFIED IDEOGRAPH-#20AB5, IRGKangXi=0163.111, RSKangXi=27.13
20AB6 CJK UNIFIED IDEOGRAPH-#20AB6, IRGKangXi=0163.111, RSKangXi=27.13
20AB7 CJK UNIFIED IDEOGRAPH-#20AB7, IRGKangXi=0163.111, RSKangXi=27.13
20AB8 CJK UNIFIED IDEOGRAPH-#20AB8, IRGKangXi=0163.111, RSKangXi=27.13
20AB9 CJK UNIFIED IDEOGRAPH-#20AB9, IRGKangXi=0163.111, RSKangXi=98.10
20ABA CJK UNIFIED IDEOGRAPH-#20ABA, IRGKangXi=0163.120, RSKangXi=27.14
20ABB CJK UNIFIED IDEOGRAPH-#20ABB, IRGKangXi=0163.130, RSKangXi=27.14
20ABC CJK UNIFIED IDEOGRAPH-#20ABC, IRGKangXi=0163.131, RSKangXi=27.14
20ABD CJK UNIFIED IDEOGRAPH-#20ABD, IRGKangXi=0163.131, RSKangXi=27.14
20ABE CJK UNIFIED IDEOGRAPH-#20ABE, IRGKangXi=0163.131, RSKangXi=27.14
20ABF CJK UNIFIED IDEOGRAPH-#20ABF, IRGKangXi=0163.131, RSKangXi=27.15
20AC0 CJK UNIFIED IDEOGRAPH-#20AC0, IRGKangXi=0163.131, RSKangXi=27.16
20AC1 CJK UNIFIED IDEOGRAPH-#20AC1, IRGKangXi=0163.131, RSKangXi=27.16
20AC2 CJK UNIFIED IDEOGRAPH-#20AC2, IRGKangXi=0163.131, RSKangXi=27.16
20AC3 CJK UNIFIED IDEOGRAPH-#20AC3, IRGKangXi=0163.131, RSKangXi=27.16
20AC4 CJK UNIFIED IDEOGRAPH-#20AC4, IRGKangXi=0163.131, RSKangXi=27.16
20AC5 CJK UNIFIED IDEOGRAPH-#20AC5, IRGKangXi=0163.131, RSKangXi=27.16
20AC6 CJK UNIFIED IDEOGRAPH-#20AC6, IRGKangXi=0163.131, RSKangXi=27.16
20AC7 CJK UNIFIED IDEOGRAPH-#20AC7, IRGKangXi=0163.141, RSKangXi=27.18
20AC8 CJK UNIFIED IDEOGRAPH-#20AC8, IRGKangXi=0163.141, RSKangXi=82.16
20AC9 CJK UNIFIED IDEOGRAPH-#20AC9, IRGKangXi=0163.150, RSKangXi=27.19
20ACA CJK UNIFIED IDEOGRAPH-#20ACA, IRGKangXi=0163.151, RSKangXi=27.19
20ACB CJK UNIFIED IDEOGRAPH-#20ACB, IRGKangXi=0163.151, RSKangXi=27.20
20ACC CJK UNIFIED IDEOGRAPH-#20ACC, IRGKangXi=0163.160, RSKangXi=27.21
20ACD CJK UNIFIED IDEOGRAPH-#20ACD, IRGKangXi=0163.161, RSKangXi=27.21
20ACE CJK UNIFIED IDEOGRAPH-#20ACE, IRGKangXi=0163.170, RSKangXi=27.21
20ACF CJK UNIFIED IDEOGRAPH-#20ACF, IRGKangXi=0163.171, RSKangXi=27.22
20AD0 CJK UNIFIED IDEOGRAPH-#20AD0, IRGKangXi=0163.180, RSKangXi=27.27
20AD1 CJK UNIFIED IDEOGRAPH-#20AD1, IRGKangXi=0163.191, RSKangXi=27.30
20AD2 CJK UNIFIED IDEOGRAPH-#20AD2, IRGKangXi=0163.191, RSKangXi=27.31
20AD3 CJK UNIFIED IDEOGRAPH-#20AD3, IRGKangXi=0164.010, RSKangXi=28.1
20AD4 CJK UNIFIED IDEOGRAPH-#20AD4, IRGKangXi=0164.020, RSKangXi=28.1
20AD5 CJK UNIFIED IDEOGRAPH-#20AD5, IRGKangXi=0164.030, RSKangXi=28.1
20AD6 CJK UNIFIED IDEOGRAPH-#20AD6, IRGKangXi=0164.031, RSKangXi=28.1
20AD7 CJK UNIFIED IDEOGRAPH-#20AD7, IRGKangXi=0164.080, RSKangXi=28.2
20AD8 CJK UNIFIED IDEOGRAPH-#20AD8, IRGKangXi=0164.081, RSKangXi=28.2
20AD9 CJK UNIFIED IDEOGRAPH-#20AD9, IRGKangXi=0164.110, RSKangXi=28.3
20ADA CJK UNIFIED IDEOGRAPH-#20ADA, IRGKangXi=0164.111, RSKangXi=28.3
20ADB CJK UNIFIED IDEOGRAPH-#20ADB, IRGKangXi=0164.111, RSKangXi=28.3
20ADC CJK UNIFIED IDEOGRAPH-#20ADC, IRGKangXi=0164.111, RSKangXi=28.3
20ADD CJK UNIFIED IDEOGRAPH-#20ADD, IRGKangXi=0164.111, RSKangXi=28.3
20ADE CJK UNIFIED IDEOGRAPH-#20ADE, IRGKangXi=0164.120, RSKangXi=28.4
20ADF CJK UNIFIED IDEOGRAPH-#20ADF, IRGKangXi=0164.140, RSKangXi=28.4
20AE0 CJK UNIFIED IDEOGRAPH-#20AE0, IRGKangXi=0164.150, RSKangXi=28.4
20AE1 CJK UNIFIED IDEOGRAPH-#20AE1, IRGKangXi=0164.151, RSKangXi=28.4
20AE2 CJK UNIFIED IDEOGRAPH-#20AE2, IRGKangXi=0164.151, RSKangXi=28.4
20AE3 CJK UNIFIED IDEOGRAPH-#20AE3, IRGKangXi=0164.151, RSKangXi=28.4
20AE4 CJK UNIFIED IDEOGRAPH-#20AE4, IRGKangXi=0164.151, RSKangXi=28.4
20AE5 CJK UNIFIED IDEOGRAPH-#20AE5, IRGKangXi=0164.151, RSKangXi=28.4
20AE6 CJK UNIFIED IDEOGRAPH-#20AE6, IRGKangXi=0164.160, RSKangXi=28.5
20AE7 CJK UNIFIED IDEOGRAPH-#20AE7, IRGKangXi=0164.161, RSKangXi=28.5
20AE8 CJK UNIFIED IDEOGRAPH-#20AE8, IRGKangXi=0164.161, RSKangXi=28.5
20AE9 CJK UNIFIED IDEOGRAPH-#20AE9, IRGKangXi=0164.180, RSKangXi=28.6
20AEA CJK UNIFIED IDEOGRAPH-#20AEA, IRGKangXi=0164.190, RSKangXi=28.6
20AEB CJK UNIFIED IDEOGRAPH-#20AEB, IRGKangXi=0164.200, RSKangXi=28.6
20AEC CJK UNIFIED IDEOGRAPH-#20AEC, IRGKangXi=0164.210, RSKangXi=28.6
20AED CJK UNIFIED IDEOGRAPH-#20AED, IRGKangXi=0164.211, RSKangXi=28.6
20AEE CJK UNIFIED IDEOGRAPH-#20AEE, IRGKangXi=0164.211, RSKangXi=16.6
20AEF CJK UNIFIED IDEOGRAPH-#20AEF, IRGKangXi=0164.211, RSKangXi=28.6
20AF0 CJK UNIFIED IDEOGRAPH-#20AF0, IRGKangXi=0164.220, RSKangXi=28.7
20AF1 CJK UNIFIED IDEOGRAPH-#20AF1, IRGKangXi=0164.230, RSKangXi=28.7
20AF2 CJK UNIFIED IDEOGRAPH-#20AF2, IRGKangXi=0164.231, RSKangXi=28.7
20AF3 CJK UNIFIED IDEOGRAPH-#20AF3, IRGKangXi=0164.231, RSKangXi=29.7
20AF4 CJK UNIFIED IDEOGRAPH-#20AF4, IRGKangXi=0164.231, RSKangXi=28.7
20AF5 CJK UNIFIED IDEOGRAPH-#20AF5, IRGKangXi=0164.231, RSKangXi=28.7
20AF6 CJK UNIFIED IDEOGRAPH-#20AF6, IRGKangXi=0164.231, RSKangXi=28.7
20AF7 CJK UNIFIED IDEOGRAPH-#20AF7, IRGKangXi=0164.231, RSKangXi=28.7
20AF8 CJK UNIFIED IDEOGRAPH-#20AF8, IRGKangXi=0164.231, RSKangXi=28.7
20AF9 CJK UNIFIED IDEOGRAPH-#20AF9, IRGKangXi=0164.240, RSKangXi=28.8
20AFA CJK UNIFIED IDEOGRAPH-#20AFA, IRGKangXi=0164.250, RSKangXi=28.8
20AFB CJK UNIFIED IDEOGRAPH-#20AFB, IRGKangXi=0164.261, RSKangXi=28.8
20AFC CJK UNIFIED IDEOGRAPH-#20AFC, IRGKangXi=0164.261, RSKangXi=28.8
20AFD CJK UNIFIED IDEOGRAPH-#20AFD, IRGKangXi=0164.301, RSKangXi=28.9
20AFE CJK UNIFIED IDEOGRAPH-#20AFE, IRGKangXi=0164.301, RSKangXi=28.9
20AFF CJK UNIFIED IDEOGRAPH-#20AFF, IRGKangXi=0164.320, RSKangXi=28.10
20B00 CJK UNIFIED IDEOGRAPH-#20B00, IRGKangXi=0164.330, RSKangXi=28.10
20B01 CJK UNIFIED IDEOGRAPH-#20B01, IRGKangXi=0164.340, RSKangXi=28.10
20B02 CJK UNIFIED IDEOGRAPH-#20B02, IRGKangXi=0164.350, RSKangXi=28.10
20B03 CJK UNIFIED IDEOGRAPH-#20B03, IRGKangXi=0164.351, RSKangXi=28.10
20B04 CJK UNIFIED IDEOGRAPH-#20B04, IRGKangXi=0164.351, RSKangXi=28.10
20B05 CJK UNIFIED IDEOGRAPH-#20B05, IRGKangXi=0164.351, RSKangXi=28.10
20B06 CJK UNIFIED IDEOGRAPH-#20B06, IRGKangXi=0164.360, RSKangXi=28.11
20B07 CJK UNIFIED IDEOGRAPH-#20B07, IRGKangXi=0164.370, RSKangXi=28.11
20B08 CJK UNIFIED IDEOGRAPH-#20B08, IRGKangXi=0164.380, RSKangXi=28.11
20B09 CJK UNIFIED IDEOGRAPH-#20B09, IRGKangXi=0164.381, RSKangXi=28.11
20B0A CJK UNIFIED IDEOGRAPH-#20B0A, IRGKangXi=0164.381, RSKangXi=28.11
20B0B CJK UNIFIED IDEOGRAPH-#20B0B, IRGKangXi=0164.381, RSKangXi=28.11
20B0C CJK UNIFIED IDEOGRAPH-#20B0C, IRGKangXi=0164.381, RSKangXi=28.11
20B0D CJK UNIFIED IDEOGRAPH-#20B0D, IRGKangXi=0164.381, RSKangXi=28.12
20B0E CJK UNIFIED IDEOGRAPH-#20B0E, IRGKangXi=0164.400, RSKangXi=28.12
20B0F CJK UNIFIED IDEOGRAPH-#20B0F, IRGKangXi=0164.401, RSKangXi=28.12
20B10 CJK UNIFIED IDEOGRAPH-#20B10, IRGKangXi=0164.401, RSKangXi=28.12
20B11 CJK UNIFIED IDEOGRAPH-#20B11, IRGKangXi=0164.410, RSKangXi=28.13
20B12 CJK UNIFIED IDEOGRAPH-#20B12, IRGKangXi=0164.411, RSKangXi=28.13
20B13 CJK UNIFIED IDEOGRAPH-#20B13, IRGKangXi=0164.420, RSKangXi=28.14
20B14 CJK UNIFIED IDEOGRAPH-#20B14, IRGKangXi=0164.421, RSKangXi=28.17
20B15 CJK UNIFIED IDEOGRAPH-#20B15, IRGKangXi=0164.421, RSKangXi=28.15
20B16 CJK UNIFIED IDEOGRAPH-#20B16, IRGKangXi=0164.421, RSKangXi=28.15
20B17 CJK UNIFIED IDEOGRAPH-#20B17, IRGKangXi=0164.421, RSKangXi=28.15
20B18 CJK UNIFIED IDEOGRAPH-#20B18, IRGKangXi=0164.421, RSKangXi=28.17
20B19 CJK UNIFIED IDEOGRAPH-#20B19, IRGKangXi=0164.421, RSKangXi=28.17
20B1A CJK UNIFIED IDEOGRAPH-#20B1A, IRGKangXi=0165.130, RSKangXi=29.2
20B1B CJK UNIFIED IDEOGRAPH-#20B1B, IRGKangXi=0165.140, RSKangXi=29.2, Def{to dive under water}
20B1C CJK UNIFIED IDEOGRAPH-#20B1C, IRGKangXi=0165.150, RSKangXi=29.2
20B1D CJK UNIFIED IDEOGRAPH-#20B1D, IRGKangXi=0165.160, RSKangXi=29.2
20B1E CJK UNIFIED IDEOGRAPH-#20B1E, IRGKangXi=0165.180, RSKangXi=29.2
20B1F CJK UNIFIED IDEOGRAPH-#20B1F, IRGKangXi=0165.220, RSKangXi=29.2
20B20 CJK UNIFIED IDEOGRAPH-#20B20, IRGKangXi=0165.221, RSKangXi=29.2
20B21 CJK UNIFIED IDEOGRAPH-#20B21, IRGKangXi=0165.240, RSKangXi=29.3
20B22 CJK UNIFIED IDEOGRAPH-#20B22, IRGKangXi=0165.260, RSKangXi=29.3
20B23 CJK UNIFIED IDEOGRAPH-#20B23, IRGKangXi=0165.270, RSKangXi=29.3
20B24 CJK UNIFIED IDEOGRAPH-#20B24, IRGKangXi=0165.271, RSKangXi=29.3
20B25 CJK UNIFIED IDEOGRAPH-#20B25, IRGKangXi=0165.271, RSKangXi=29.3
20B26 CJK UNIFIED IDEOGRAPH-#20B26, IRGKangXi=0165.271, RSKangXi=29.3
20B27 CJK UNIFIED IDEOGRAPH-#20B27, IRGKangXi=0165.271, RSKangXi=29.3
20B28 CJK UNIFIED IDEOGRAPH-#20B28, IRGKangXi=0165.271, RSKangXi=29.3
20B29 CJK UNIFIED IDEOGRAPH-#20B29, IRGKangXi=0165.280, RSKangXi=29.4
20B2A CJK UNIFIED IDEOGRAPH-#20B2A, IRGKangXi=0165.310, RSKangXi=29.4
20B2B CJK UNIFIED IDEOGRAPH-#20B2B, IRGKangXi=0165.320, RSKangXi=29.4
20B2C CJK UNIFIED IDEOGRAPH-#20B2C, IRGKangXi=0165.330, RSKangXi=29.4
20B2D CJK UNIFIED IDEOGRAPH-#20B2D, IRGKangXi=0165.340, RSKangXi=29.4
20B2E CJK UNIFIED IDEOGRAPH-#20B2E, IRGKangXi=0165.350, RSKangXi=29.4
20B2F CJK UNIFIED IDEOGRAPH-#20B2F, IRGKangXi=0165.351, RSKangXi=29.4
20B30 CJK UNIFIED IDEOGRAPH-#20B30, IRGKangXi=0165.351, RSKangXi=29.4
20B31 CJK UNIFIED IDEOGRAPH-#20B31, IRGKangXi=0165.370, RSKangXi=29.5
20B32 CJK UNIFIED IDEOGRAPH-#20B32, IRGKangXi=0165.380, RSKangXi=29.5
20B33 CJK UNIFIED IDEOGRAPH-#20B33, IRGKangXi=0165.390, RSKangXi=29.5
20B34 CJK UNIFIED IDEOGRAPH-#20B34, IRGKangXi=0165.391, RSKangXi=29.5
20B35 CJK UNIFIED IDEOGRAPH-#20B35, IRGKangXi=0165.391, RSKangXi=29.5
20B36 CJK UNIFIED IDEOGRAPH-#20B36, IRGKangXi=0165.391, RSKangXi=29.5, Def{to invade}
20B37 CJK UNIFIED IDEOGRAPH-#20B37, IRGKangXi=0165.391, RSKangXi=29.5
20B38 CJK UNIFIED IDEOGRAPH-#20B38, IRGKangXi=0165.391, RSKangXi=29.5
20B39 CJK UNIFIED IDEOGRAPH-#20B39, IRGKangXi=0165.400, RSKangXi=29.6
20B3A CJK UNIFIED IDEOGRAPH-#20B3A, IRGKangXi=0165.410, RSKangXi=29.6
20B3B CJK UNIFIED IDEOGRAPH-#20B3B, IRGKangXi=0166.010, RSKangXi=29.6
20B3C CJK UNIFIED IDEOGRAPH-#20B3C, IRGKangXi=0166.070, RSKangXi=29.6
20B3D CJK UNIFIED IDEOGRAPH-#20B3D, IRGKangXi=0166.071, RSKangXi=29.6
20B3E CJK UNIFIED IDEOGRAPH-#20B3E, IRGKangXi=0166.071, RSKangXi=29.6
20B3F CJK UNIFIED IDEOGRAPH-#20B3F, IRGKangXi=0166.100, RSKangXi=29.7
20B40 CJK UNIFIED IDEOGRAPH-#20B40, IRGKangXi=0166.140, RSKangXi=29.7
20B41 CJK UNIFIED IDEOGRAPH-#20B41, IRGKangXi=0166.150, RSKangXi=29.7
20B42 CJK UNIFIED IDEOGRAPH-#20B42, IRGKangXi=0166.170, RSKangXi=29.7
20B43 CJK UNIFIED IDEOGRAPH-#20B43, IRGKangXi=0166.171, RSKangXi=29.7
20B44 CJK UNIFIED IDEOGRAPH-#20B44, IRGKangXi=0166.171, RSKangXi=29.7
20B45 CJK UNIFIED IDEOGRAPH-#20B45, IRGKangXi=0166.171, RSKangXi=29.7
20B46 CJK UNIFIED IDEOGRAPH-#20B46, IRGKangXi=0166.171, RSKangXi=29.7
20B47 CJK UNIFIED IDEOGRAPH-#20B47, IRGKangXi=0166.171, RSKangXi=29.7
20B48 CJK UNIFIED IDEOGRAPH-#20B48, IRGKangXi=0166.171, RSKangXi=29.7
20B49 CJK UNIFIED IDEOGRAPH-#20B49, IRGKangXi=0166.171, RSKangXi=25.7
20B4A CJK UNIFIED IDEOGRAPH-#20B4A, IRGKangXi=0166.190, RSKangXi=29.8
20B4B CJK UNIFIED IDEOGRAPH-#20B4B, IRGKangXi=0166.200, RSKangXi=29.8
20B4C CJK UNIFIED IDEOGRAPH-#20B4C, IRGKangXi=0166.230, RSKangXi=29.8
20B4D CJK UNIFIED IDEOGRAPH-#20B4D, IRGKangXi=0166.240, RSKangXi=29.8
20B4E CJK UNIFIED IDEOGRAPH-#20B4E, IRGKangXi=0166.250, RSKangXi=29.8
20B4F CJK UNIFIED IDEOGRAPH-#20B4F, IRGKangXi=0166.260, RSKangXi=29.8
20B50 CJK UNIFIED IDEOGRAPH-#20B50, IRGKangXi=0166.261, RSKangXi=29.8
20B51 CJK UNIFIED IDEOGRAPH-#20B51, IRGKangXi=0166.261, RSKangXi=29.8
20B52 CJK UNIFIED IDEOGRAPH-#20B52, IRGKangXi=0166.261, RSKangXi=29.8
20B53 CJK UNIFIED IDEOGRAPH-#20B53, IRGKangXi=0166.261, RSKangXi=29.8
20B54 CJK UNIFIED IDEOGRAPH-#20B54, IRGKangXi=0166.261, RSKangXi=29.8
20B55 CJK UNIFIED IDEOGRAPH-#20B55, IRGKangXi=0166.270, RSKangXi=29.9
20B56 CJK UNIFIED IDEOGRAPH-#20B56, IRGKangXi=0166.280, RSKangXi=29.9
20B57 CJK UNIFIED IDEOGRAPH-#20B57, IRGKangXi=0166.290, RSKangXi=29.9
20B58 CJK UNIFIED IDEOGRAPH-#20B58, IRGKangXi=0166.300, RSKangXi=29.9
20B59 CJK UNIFIED IDEOGRAPH-#20B59, IRGKangXi=0166.310, RSKangXi=29.9
20B5A CJK UNIFIED IDEOGRAPH-#20B5A, IRGKangXi=0166.320, RSKangXi=29.9
20B5B CJK UNIFIED IDEOGRAPH-#20B5B, IRGKangXi=0166.330, RSKangXi=29.9
20B5C CJK UNIFIED IDEOGRAPH-#20B5C, IRGKangXi=0166.340, RSKangXi=29.9
20B5D CJK UNIFIED IDEOGRAPH-#20B5D, IRGKangXi=0166.350, RSKangXi=29.9
20B5E CJK UNIFIED IDEOGRAPH-#20B5E, IRGKangXi=0166.351, RSKangXi=29.9
20B5F CJK UNIFIED IDEOGRAPH-#20B5F, IRGKangXi=0166.351, RSKangXi=29.9
20B60 CJK UNIFIED IDEOGRAPH-#20B60, IRGKangXi=0166.351, RSKangXi=29.9
20B61 CJK UNIFIED IDEOGRAPH-#20B61, IRGKangXi=0166.351, RSKangXi=29.9
20B62 CJK UNIFIED IDEOGRAPH-#20B62, IRGKangXi=0166.351, RSKangXi=29.9
20B63 CJK UNIFIED IDEOGRAPH-#20B63, IRGKangXi=0166.351, RSKangXi=29.9
20B64 CJK UNIFIED IDEOGRAPH-#20B64, IRGKangXi=0166.351, RSKangXi=29.9
20B65 CJK UNIFIED IDEOGRAPH-#20B65, IRGKangXi=0166.360, RSKangXi=29.10
20B66 CJK UNIFIED IDEOGRAPH-#20B66, IRGKangXi=0166.370, RSKangXi=29.10
20B67 CJK UNIFIED IDEOGRAPH-#20B67, IRGKangXi=0166.380, RSKangXi=29.10
20B68 CJK UNIFIED IDEOGRAPH-#20B68, IRGKangXi=0166.390, RSKangXi=29.10
20B69 CJK UNIFIED IDEOGRAPH-#20B69, IRGKangXi=0166.391, RSKangXi=29.10
20B6A CJK UNIFIED IDEOGRAPH-#20B6A, IRGKangXi=0166.391, RSKangXi=29.10
20B6B CJK UNIFIED IDEOGRAPH-#20B6B, IRGKangXi=0166.391, RSKangXi=29.10
20B6C CJK UNIFIED IDEOGRAPH-#20B6C, IRGKangXi=0166.391, RSKangXi=29.10
20B6D CJK UNIFIED IDEOGRAPH-#20B6D, IRGKangXi=0166.391, RSKangXi=29.10
20B6E CJK UNIFIED IDEOGRAPH-#20B6E, IRGKangXi=0166.391, RSKangXi=29.10
20B6F CJK UNIFIED IDEOGRAPH-#20B6F, IRGKangXi=0166.400, RSKangXi=29.11
20B70 CJK UNIFIED IDEOGRAPH-#20B70, IRGKangXi=0166.410, RSKangXi=29.11
20B71 CJK UNIFIED IDEOGRAPH-#20B71, IRGKangXi=0166.420, RSKangXi=19.11
20B72 CJK UNIFIED IDEOGRAPH-#20B72, IRGKangXi=0166.430, RSKangXi=29.11
20B73 CJK UNIFIED IDEOGRAPH-#20B73, IRGKangXi=0166.440, RSKangXi=29.11
20B74 CJK UNIFIED IDEOGRAPH-#20B74, IRGKangXi=0166.450, RSKangXi=29.11, Def{(same as U+3441 㑁) short; of short stature}
20B75 CJK UNIFIED IDEOGRAPH-#20B75, IRGKangXi=0166.460, RSKangXi=29.11
20B76 CJK UNIFIED IDEOGRAPH-#20B76, IRGKangXi=0166.461, RSKangXi=35.10
20B77 CJK UNIFIED IDEOGRAPH-#20B77, IRGKangXi=0166.461, RSKangXi=29.11
20B78 CJK UNIFIED IDEOGRAPH-#20B78, IRGKangXi=0166.461, RSKangXi=29.11
20B79 CJK UNIFIED IDEOGRAPH-#20B79, IRGKangXi=0166.461, RSKangXi=29.11
20B7A CJK UNIFIED IDEOGRAPH-#20B7A, IRGKangXi=0166.461, RSKangXi=29.11
20B7B CJK UNIFIED IDEOGRAPH-#20B7B, IRGKangXi=0167.011, RSKangXi=12.12
20B7C CJK UNIFIED IDEOGRAPH-#20B7C, IRGKangXi=0167.011, RSKangXi=29.12
20B7D CJK UNIFIED IDEOGRAPH-#20B7D, IRGKangXi=0167.011, RSKangXi=29.12
20B7E CJK UNIFIED IDEOGRAPH-#20B7E, IRGKangXi=0167.011, RSKangXi=29.12
20B7F CJK UNIFIED IDEOGRAPH-#20B7F, IRGKangXi=0167.011, RSKangXi=29.12
20B80 CJK UNIFIED IDEOGRAPH-#20B80, IRGKangXi=0167.011, RSKangXi=29.12
20B81 CJK UNIFIED IDEOGRAPH-#20B81, IRGKangXi=0167.011, RSKangXi=29.12
20B82 CJK UNIFIED IDEOGRAPH-#20B82, IRGKangXi=0167.011, RSKangXi=29.12
20B83 CJK UNIFIED IDEOGRAPH-#20B83, IRGKangXi=0167.020, RSKangXi=29.13
20B84 CJK UNIFIED IDEOGRAPH-#20B84, IRGKangXi=0167.030, RSKangXi=29.13
20B85 CJK UNIFIED IDEOGRAPH-#20B85, IRGKangXi=0167.031, RSKangXi=29.13
20B86 CJK UNIFIED IDEOGRAPH-#20B86, IRGKangXi=0167.031, RSKangXi=29.13
20B87 CJK UNIFIED IDEOGRAPH-#20B87, IRGKangXi=0167.080, RSKangXi=29.14
20B88 CJK UNIFIED IDEOGRAPH-#20B88, IRGKangXi=0167.081, RSKangXi=29.14
20B89 CJK UNIFIED IDEOGRAPH-#20B89, IRGKangXi=0167.081, RSKangXi=29.14
20B8A CJK UNIFIED IDEOGRAPH-#20B8A, IRGKangXi=0167.081, RSKangXi=29.14
20B8B CJK UNIFIED IDEOGRAPH-#20B8B, IRGKangXi=0167.081, RSKangXi=29.14
20B8C CJK UNIFIED IDEOGRAPH-#20B8C, IRGKangXi=0167.081, RSKangXi=29.14
20B8D CJK UNIFIED IDEOGRAPH-#20B8D, IRGKangXi=0167.090, RSKangXi=29.15
20B8E CJK UNIFIED IDEOGRAPH-#20B8E, IRGKangXi=0167.100, RSKangXi=29.15
20B8F CJK UNIFIED IDEOGRAPH-#20B8F, IRGKangXi=0167.101, RSKangXi=29.15
20B90 CJK UNIFIED IDEOGRAPH-#20B90, IRGKangXi=0167.110, RSKangXi=29.16
20B91 CJK UNIFIED IDEOGRAPH-#20B91, IRGKangXi=0167.130, RSKangXi=29.17
20B92 CJK UNIFIED IDEOGRAPH-#20B92, IRGKangXi=0167.131, RSKangXi=29.17
20B93 CJK UNIFIED IDEOGRAPH-#20B93, IRGKangXi=0167.131, RSKangXi=29.19
20B94 CJK UNIFIED IDEOGRAPH-#20B94, IRGKangXi=0167.131, RSKangXi=29.19
20B95 CJK UNIFIED IDEOGRAPH-#20B95, IRGKangXi=0167.140, RSKangXi=29.20
20B96 CJK UNIFIED IDEOGRAPH-#20B96, IRGKangXi=0167.141, RSKangXi=29.19
20B97 CJK UNIFIED IDEOGRAPH-#20B97, IRGKangXi=0167.150, RSKangXi=29.22
20B98 CJK UNIFIED IDEOGRAPH-#20B98, IRGKangXi=0167.160, RSKangXi=29.22
20B99 CJK UNIFIED IDEOGRAPH-#20B99, IRGKangXi=0171.040, RSKangXi=30.1
20B9A CJK UNIFIED IDEOGRAPH-#20B9A, IRGKangXi=0171.050, RSKangXi=30.1
20B9B CJK UNIFIED IDEOGRAPH-#20B9B, IRGKangXi=0171.060, RSKangXi=30.1
20B9C CJK UNIFIED IDEOGRAPH-#20B9C, IRGKangXi=0171.070, RSKangXi=30.1
20B9D CJK UNIFIED IDEOGRAPH-#20B9D, IRGKangXi=0171.071, RSKangXi=30.1
20B9E CJK UNIFIED IDEOGRAPH-#20B9E, IRGKangXi=0171.071, RSKangXi=30.1
20B9F CJK UNIFIED IDEOGRAPH-#20B9F, IRGKangXi=0173.010, RSKangXi=30.2
20BA0 CJK UNIFIED IDEOGRAPH-#20BA0, IRGKangXi=0174.050, RSKangXi=30.2
20BA1 CJK UNIFIED IDEOGRAPH-#20BA1, IRGKangXi=0174.060, RSKangXi=30.2
20BA2 CJK UNIFIED IDEOGRAPH-#20BA2, IRGKangXi=0174.070, RSKangXi=30.2
20BA3 CJK UNIFIED IDEOGRAPH-#20BA3, IRGKangXi=0174.080, RSKangXi=30.2
20BA4 CJK UNIFIED IDEOGRAPH-#20BA4, IRGKangXi=0174.090, RSKangXi=30.2
20BA5 CJK UNIFIED IDEOGRAPH-#20BA5, IRGKangXi=0174.091, RSKangXi=30.2
20BA6 CJK UNIFIED IDEOGRAPH-#20BA6, IRGKangXi=0174.091, RSKangXi=30.2
20BA7 CJK UNIFIED IDEOGRAPH-#20BA7, IRGKangXi=0174.091, RSKangXi=30.2
20BA8 CJK UNIFIED IDEOGRAPH-#20BA8, IRGKangXi=0174.091, RSKangXi=30.2, Def{(Cant.) to tie, tow; bring along}
20BA9 CJK UNIFIED IDEOGRAPH-#20BA9, IRGKangXi=0174.091, RSKangXi=30.2, Def{(Cant.) an interjection; rare, specialized}
20BAA CJK UNIFIED IDEOGRAPH-#20BAA, IRGKangXi=0174.091, RSKangXi=30.2
20BAB CJK UNIFIED IDEOGRAPH-#20BAB, IRGKangXi=0174.110, RSKangXi=30.3
20BAC CJK UNIFIED IDEOGRAPH-#20BAC, IRGKangXi=0174.120, RSKangXi=30.3
20BAD CJK UNIFIED IDEOGRAPH-#20BAD, IRGKangXi=0174.210, RSKangXi=30.3
20BAE CJK UNIFIED IDEOGRAPH-#20BAE, IRGKangXi=0174.230, RSKangXi=30.3
20BAF CJK UNIFIED IDEOGRAPH-#20BAF, IRGKangXi=0175.050, RSKangXi=30.3
20BB0 CJK UNIFIED IDEOGRAPH-#20BB0, IRGKangXi=0175.070, RSKangXi=30.3
20BB1 CJK UNIFIED IDEOGRAPH-#20BB1, IRGKangXi=0176.060, RSKangXi=30.3
20BB2 CJK UNIFIED IDEOGRAPH-#20BB2, IRGKangXi=0176.070, RSKangXi=30.3
20BB3 CJK UNIFIED IDEOGRAPH-#20BB3, IRGKangXi=0176.080, RSKangXi=30.3
20BB4 CJK UNIFIED IDEOGRAPH-#20BB4, IRGKangXi=0177.010, RSKangXi=30.3
20BB5 CJK UNIFIED IDEOGRAPH-#20BB5, IRGKangXi=0177.020, RSKangXi=30.3
20BB6 CJK UNIFIED IDEOGRAPH-#20BB6, IRGKangXi=0177.021, RSKangXi=30.3
20BB7 CJK UNIFIED IDEOGRAPH-#20BB7, IRGKangXi=0177.021, RSKangXi=30.3
20BB8 CJK UNIFIED IDEOGRAPH-#20BB8, IRGKangXi=0177.021, RSKangXi=30.3
20BB9 CJK UNIFIED IDEOGRAPH-#20BB9, IRGKangXi=0177.021, RSKangXi=30.3
20BBA CJK UNIFIED IDEOGRAPH-#20BBA, IRGKangXi=0177.021, RSKangXi=30.3
20BBB CJK UNIFIED IDEOGRAPH-#20BBB, IRGKangXi=0177.021, RSKangXi=30.3
20BBC CJK UNIFIED IDEOGRAPH-#20BBC, IRGKangXi=0177.021, RSKangXi=30.3
20BBD CJK UNIFIED IDEOGRAPH-#20BBD, IRGKangXi=0177.021, RSKangXi=30.3
20BBE CJK UNIFIED IDEOGRAPH-#20BBE, IRGKangXi=0177.021, RSKangXi=30.3
20BBF CJK UNIFIED IDEOGRAPH-#20BBF, IRGKangXi=0177.021, RSKangXi=30.3
20BC0 CJK UNIFIED IDEOGRAPH-#20BC0, IRGKangXi=0177.021, RSKangXi=30.3
20BC1 CJK UNIFIED IDEOGRAPH-#20BC1, IRGKangXi=0177.021, RSKangXi=30.3
20BC2 CJK UNIFIED IDEOGRAPH-#20BC2, IRGKangXi=0177.021, RSKangXi=30.3
20BC3 CJK UNIFIED IDEOGRAPH-#20BC3, IRGKangXi=0177.021, RSKangXi=30.3
20BC4 CJK UNIFIED IDEOGRAPH-#20BC4, IRGKangXi=0177.021, RSKangXi=30.3
20BC5 CJK UNIFIED IDEOGRAPH-#20BC5, IRGKangXi=0177.021, RSKangXi=30.3
20BC6 CJK UNIFIED IDEOGRAPH-#20BC6, IRGKangXi=0177.021, RSKangXi=30.3
20BC7 CJK UNIFIED IDEOGRAPH-#20BC7, IRGKangXi=0177.021, RSKangXi=30.3
20BC8 CJK UNIFIED IDEOGRAPH-#20BC8, IRGKangXi=0177.021, RSKangXi=30.3
20BC9 CJK UNIFIED IDEOGRAPH-#20BC9, IRGKangXi=0177.021, RSKangXi=30.3
20BCA CJK UNIFIED IDEOGRAPH-#20BCA, IRGKangXi=0177.021, RSKangXi=30.3
20BCB CJK UNIFIED IDEOGRAPH-#20BCB, IRGKangXi=0177.040, RSKangXi=30.4, Def{(Cant.) naughty, inferior}
20BCC CJK UNIFIED IDEOGRAPH-#20BCC, IRGKangXi=0177.170, RSKangXi=30.4
20BCD CJK UNIFIED IDEOGRAPH-#20BCD, IRGKangXi=0177.250, RSKangXi=30.4
20BCE CJK UNIFIED IDEOGRAPH-#20BCE, IRGKangXi=0178.010, RSKangXi=30.4
20BCF CJK UNIFIED IDEOGRAPH-#20BCF, IRGKangXi=0178.050, RSKangXi=30.4
20BD0 CJK UNIFIED IDEOGRAPH-#20BD0, IRGKangXi=0178.070, RSKangXi=30.4
20BD1 CJK UNIFIED IDEOGRAPH-#20BD1, IRGKangXi=0178.080, RSKangXi=30.4
20BD2 CJK UNIFIED IDEOGRAPH-#20BD2, IRGKangXi=0178.130, RSKangXi=30.4
20BD3 CJK UNIFIED IDEOGRAPH-#20BD3, IRGKangXi=0178.150, RSKangXi=30.4
20BD4 CJK UNIFIED IDEOGRAPH-#20BD4, IRGKangXi=0178.180, RSKangXi=30.4
20BD5 CJK UNIFIED IDEOGRAPH-#20BD5, IRGKangXi=0178.190, RSKangXi=30.4
20BD6 CJK UNIFIED IDEOGRAPH-#20BD6, IRGKangXi=0178.220, RSKangXi=30.4
20BD7 CJK UNIFIED IDEOGRAPH-#20BD7, IRGKangXi=0180.070, RSKangXi=30.4, Def{nipple; to suck}
20BD8 CJK UNIFIED IDEOGRAPH-#20BD8, IRGKangXi=0181.050, RSKangXi=30.4
20BD9 CJK UNIFIED IDEOGRAPH-#20BD9, IRGKangXi=0181.090, RSKangXi=30.4
20BDA CJK UNIFIED IDEOGRAPH-#20BDA, IRGKangXi=0181.100, RSKangXi=30.4
20BDB CJK UNIFIED IDEOGRAPH-#20BDB, IRGKangXi=0181.120, RSKangXi=30.4
20BDC CJK UNIFIED IDEOGRAPH-#20BDC, IRGKangXi=0181.140, RSKangXi=30.4
20BDD CJK UNIFIED IDEOGRAPH-#20BDD, IRGKangXi=0181.150, RSKangXi=30.4
20BDE CJK UNIFIED IDEOGRAPH-#20BDE, IRGKangXi=0181.180, RSKangXi=30.4
20BDF CJK UNIFIED IDEOGRAPH-#20BDF, IRGKangXi=0181.191, RSKangXi=30.4
20BE0 CJK UNIFIED IDEOGRAPH-#20BE0, IRGKangXi=0181.191, RSKangXi=30.4
20BE1 CJK UNIFIED IDEOGRAPH-#20BE1, IRGKangXi=0181.191, RSKangXi=30.4
20BE2 CJK UNIFIED IDEOGRAPH-#20BE2, IRGKangXi=0181.191, RSKangXi=30.4
20BE3 CJK UNIFIED IDEOGRAPH-#20BE3, IRGKangXi=0181.191, RSKangXi=30.4
20BE4 CJK UNIFIED IDEOGRAPH-#20BE4, IRGKangXi=0181.191, RSKangXi=30.4
20BE5 CJK UNIFIED IDEOGRAPH-#20BE5, IRGKangXi=0181.191, RSKangXi=30.4
20BE6 CJK UNIFIED IDEOGRAPH-#20BE6, IRGKangXi=0181.191, RSKangXi=30.4, Def{(Cant.) to eat, take a meal}
20BE7 CJK UNIFIED IDEOGRAPH-#20BE7, IRGKangXi=0181.191, RSKangXi=30.4
20BE8 CJK UNIFIED IDEOGRAPH-#20BE8, IRGKangXi=0181.191, RSKangXi=30.4
20BE9 CJK UNIFIED IDEOGRAPH-#20BE9, IRGKangXi=0181.191, RSKangXi=30.4
20BEA CJK UNIFIED IDEOGRAPH-#20BEA, IRGKangXi=0181.191, RSKangXi=30.4
20BEB CJK UNIFIED IDEOGRAPH-#20BEB, IRGKangXi=0181.191, RSKangXi=30.4
20BEC CJK UNIFIED IDEOGRAPH-#20BEC, IRGKangXi=0181.191, RSKangXi=30.4
20BED CJK UNIFIED IDEOGRAPH-#20BED, IRGKangXi=0181.191, RSKangXi=30.4
20BEE CJK UNIFIED IDEOGRAPH-#20BEE, IRGKangXi=0181.191, RSKangXi=30.4, Def{(J) nonstandard variant of 品 U+54C1, an article, product, commodity}
20BEF CJK UNIFIED IDEOGRAPH-#20BEF, IRGKangXi=0181.191, RSKangXi=30.4
20BF0 CJK UNIFIED IDEOGRAPH-#20BF0, IRGKangXi=0181.191, RSKangXi=30.4
20BF1 CJK UNIFIED IDEOGRAPH-#20BF1, IRGKangXi=0181.191, RSKangXi=30.4
20BF2 CJK UNIFIED IDEOGRAPH-#20BF2, IRGKangXi=0181.191, RSKangXi=30.4
20BF3 CJK UNIFIED IDEOGRAPH-#20BF3, IRGKangXi=0181.191, RSKangXi=30.4
20BF4 CJK UNIFIED IDEOGRAPH-#20BF4, IRGKangXi=0181.191, RSKangXi=30.4
20BF5 CJK UNIFIED IDEOGRAPH-#20BF5, IRGKangXi=0181.191, RSKangXi=30.4
20BF6 CJK UNIFIED IDEOGRAPH-#20BF6, IRGKangXi=0181.191, RSKangXi=30.4
20BF7 CJK UNIFIED IDEOGRAPH-#20BF7, IRGKangXi=0181.191, RSKangXi=30.4
20BF8 CJK UNIFIED IDEOGRAPH-#20BF8, IRGKangXi=0181.191, RSKangXi=30.4
20BF9 CJK UNIFIED IDEOGRAPH-#20BF9, IRGKangXi=0181.191, RSKangXi=30.4
20BFA CJK UNIFIED IDEOGRAPH-#20BFA, IRGKangXi=0181.191, RSKangXi=30.4
20BFB CJK UNIFIED IDEOGRAPH-#20BFB, IRGKangXi=0181.191, RSKangXi=30.4
20BFC CJK UNIFIED IDEOGRAPH-#20BFC, IRGKangXi=0181.191, RSKangXi=30.4
20BFD CJK UNIFIED IDEOGRAPH-#20BFD, IRGKangXi=0181.191, RSKangXi=30.4, Def{(Cant.) a final particle indicating affirmation}
20BFE CJK UNIFIED IDEOGRAPH-#20BFE, IRGKangXi=0181.191, RSKangXi=30.4
20BFF CJK UNIFIED IDEOGRAPH-#20BFF, IRGKangXi=0181.191, RSKangXi=30.4
20C00 CJK UNIFIED IDEOGRAPH-#20C00, IRGKangXi=0181.191, RSKangXi=30.4
20C01 CJK UNIFIED IDEOGRAPH-#20C01, IRGKangXi=0181.191, RSKangXi=30.4
20C02 CJK UNIFIED IDEOGRAPH-#20C02, IRGKangXi=0181.191, RSKangXi=30.4
20C03 CJK UNIFIED IDEOGRAPH-#20C03, IRGKangXi=0181.191, RSKangXi=30.4
20C04 CJK UNIFIED IDEOGRAPH-#20C04, IRGKangXi=0181.191, RSKangXi=30.4
20C05 CJK UNIFIED IDEOGRAPH-#20C05, IRGKangXi=0181.191, RSKangXi=30.4
20C06 CJK UNIFIED IDEOGRAPH-#20C06, IRGKangXi=0181.191, RSKangXi=60.4
20C07 CJK UNIFIED IDEOGRAPH-#20C07, IRGKangXi=0181.191, RSKangXi=30.4
20C08 CJK UNIFIED IDEOGRAPH-#20C08, IRGKangXi=0181.260, RSKangXi=30.5
20C09 CJK UNIFIED IDEOGRAPH-#20C09, IRGKangXi=0181.340, RSKangXi=30.5
20C0A CJK UNIFIED IDEOGRAPH-#20C0A, IRGKangXi=0181.350, RSKangXi=30.5
20C0B CJK UNIFIED IDEOGRAPH-#20C0B, IRGKangXi=0182.030, RSKangXi=30.5, Def{(Cant.) left-handed}
20C0C CJK UNIFIED IDEOGRAPH-#20C0C, IRGKangXi=0182.120, RSKangXi=30.5, Def{to compress the lips}
20C0D CJK UNIFIED IDEOGRAPH-#20C0D, IRGKangXi=0183.060, RSKangXi=30.5
20C0E CJK UNIFIED IDEOGRAPH-#20C0E, IRGKangXi=0183.070, RSKangXi=30.5
20C0F CJK UNIFIED IDEOGRAPH-#20C0F, IRGKangXi=0183.110, RSKangXi=30.5
20C10 CJK UNIFIED IDEOGRAPH-#20C10, IRGKangXi=0183.120, RSKangXi=30.5
20C11 CJK UNIFIED IDEOGRAPH-#20C11, IRGKangXi=0183.170, RSKangXi=30.5
20C12 CJK UNIFIED IDEOGRAPH-#20C12, IRGKangXi=0184.080, RSKangXi=30.5
20C13 CJK UNIFIED IDEOGRAPH-#20C13, IRGKangXi=0185.040, RSKangXi=30.5
20C14 CJK UNIFIED IDEOGRAPH-#20C14, IRGKangXi=0185.090, RSKangXi=30.5
20C15 CJK UNIFIED IDEOGRAPH-#20C15, IRGKangXi=0185.110, RSKangXi=30.5
20C16 CJK UNIFIED IDEOGRAPH-#20C16, IRGKangXi=0185.120, RSKangXi=30.5
20C17 CJK UNIFIED IDEOGRAPH-#20C17, IRGKangXi=0185.130, RSKangXi=30.5
20C18 CJK UNIFIED IDEOGRAPH-#20C18, IRGKangXi=0185.140, RSKangXi=30.5
20C19 CJK UNIFIED IDEOGRAPH-#20C19, IRGKangXi=0185.150, RSKangXi=30.5
20C1A CJK UNIFIED IDEOGRAPH-#20C1A, IRGKangXi=0185.170, RSKangXi=30.5
20C1B CJK UNIFIED IDEOGRAPH-#20C1B, IRGKangXi=0185.180, RSKangXi=30.5
20C1C CJK UNIFIED IDEOGRAPH-#20C1C, IRGKangXi=0185.190, RSKangXi=30.5
20C1D CJK UNIFIED IDEOGRAPH-#20C1D, IRGKangXi=0185.200, RSKangXi=30.5
20C1E CJK UNIFIED IDEOGRAPH-#20C1E, IRGKangXi=0185.210, RSKangXi=30.5
20C1F CJK UNIFIED IDEOGRAPH-#20C1F, IRGKangXi=0185.211, RSKangXi=30.5
20C20 CJK UNIFIED IDEOGRAPH-#20C20, IRGKangXi=0185.211, RSKangXi=30.5
20C21 CJK UNIFIED IDEOGRAPH-#20C21, IRGKangXi=0185.211, RSKangXi=30.5
20C22 CJK UNIFIED IDEOGRAPH-#20C22, IRGKangXi=0185.211, RSKangXi=30.5
20C23 CJK UNIFIED IDEOGRAPH-#20C23, IRGKangXi=0185.211, RSKangXi=30.5
20C24 CJK UNIFIED IDEOGRAPH-#20C24, IRGKangXi=0185.211, RSKangXi=30.5
20C25 CJK UNIFIED IDEOGRAPH-#20C25, IRGKangXi=0185.211, RSKangXi=30.5
20C26 CJK UNIFIED IDEOGRAPH-#20C26, IRGKangXi=0185.211, RSKangXi=30.5
20C27 CJK UNIFIED IDEOGRAPH-#20C27, IRGKangXi=0185.211, RSKangXi=30.5
20C28 CJK UNIFIED IDEOGRAPH-#20C28, IRGKangXi=0185.211, RSKangXi=30.5
20C29 CJK UNIFIED IDEOGRAPH-#20C29, IRGKangXi=0185.211, RSKangXi=30.5
20C2A CJK UNIFIED IDEOGRAPH-#20C2A, IRGKangXi=0185.211, RSKangXi=30.5
20C2B CJK UNIFIED IDEOGRAPH-#20C2B, IRGKangXi=0185.211, RSKangXi=30.5
20C2C CJK UNIFIED IDEOGRAPH-#20C2C, IRGKangXi=0185.211, RSKangXi=30.5
20C2D CJK UNIFIED IDEOGRAPH-#20C2D, IRGKangXi=0185.211, RSKangXi=30.5
20C2E CJK UNIFIED IDEOGRAPH-#20C2E, IRGKangXi=0185.211, RSKangXi=30.5
20C2F CJK UNIFIED IDEOGRAPH-#20C2F, IRGKangXi=0185.211, RSKangXi=30.5
20C30 CJK UNIFIED IDEOGRAPH-#20C30, IRGKangXi=0185.211, RSKangXi=30.5
20C31 CJK UNIFIED IDEOGRAPH-#20C31, IRGKangXi=0185.211, RSKangXi=30.5
20C32 CJK UNIFIED IDEOGRAPH-#20C32, IRGKangXi=0185.211, RSKangXi=30.5, Def{(Cant.) to belch}
20C33 CJK UNIFIED IDEOGRAPH-#20C33, IRGKangXi=0185.211, RSKangXi=30.5
20C34 CJK UNIFIED IDEOGRAPH-#20C34, IRGKangXi=0185.211, RSKangXi=30.5
20C35 CJK UNIFIED IDEOGRAPH-#20C35, IRGKangXi=0185.211, RSKangXi=30.5
20C36 CJK UNIFIED IDEOGRAPH-#20C36, IRGKangXi=0185.211, RSKangXi=30.5
20C37 CJK UNIFIED IDEOGRAPH-#20C37, IRGKangXi=0185.211, RSKangXi=30.5
20C38 CJK UNIFIED IDEOGRAPH-#20C38, IRGKangXi=0185.211, RSKangXi=30.5
20C39 CJK UNIFIED IDEOGRAPH-#20C39, IRGKangXi=0185.211, RSKangXi=30.5
20C3A CJK UNIFIED IDEOGRAPH-#20C3A, IRGKangXi=0185.211, RSKangXi=30.5
20C3B CJK UNIFIED IDEOGRAPH-#20C3B, IRGKangXi=0185.211, RSKangXi=30.5
20C3C CJK UNIFIED IDEOGRAPH-#20C3C, IRGKangXi=0185.211, RSKangXi=30.5
20C3D CJK UNIFIED IDEOGRAPH-#20C3D, IRGKangXi=0185.211, RSKangXi=30.5
20C3E CJK UNIFIED IDEOGRAPH-#20C3E, IRGKangXi=0185.211, RSKangXi=30.5
20C3F CJK UNIFIED IDEOGRAPH-#20C3F, IRGKangXi=0185.211, RSKangXi=30.5
20C40 CJK UNIFIED IDEOGRAPH-#20C40, IRGKangXi=0185.211, RSKangXi=30.5
20C41 CJK UNIFIED IDEOGRAPH-#20C41, IRGKangXi=0185.211, RSKangXi=30.5, Def{(Cant.) to fool, trick, cheat}
20C42 CJK UNIFIED IDEOGRAPH-#20C42, IRGKangXi=0185.211, RSKangXi=30.5, Def{(Cant.) to put something or sit wherever one wishes; to rebuke, reproach}
20C43 CJK UNIFIED IDEOGRAPH-#20C43, IRGKangXi=0185.211, RSKangXi=30.5, Def{(Cant.) thin, flat; poor}
20C44 CJK UNIFIED IDEOGRAPH-#20C44, IRGKangXi=0185.211, RSKangXi=30.5
20C45 CJK UNIFIED IDEOGRAPH-#20C45, IRGKangXi=0185.211, RSKangXi=30.5
20C46 CJK UNIFIED IDEOGRAPH-#20C46, IRGKangXi=0185.211, RSKangXi=30.5
20C47 CJK UNIFIED IDEOGRAPH-#20C47, IRGKangXi=0185.211, RSKangXi=30.5
20C48 CJK UNIFIED IDEOGRAPH-#20C48, IRGKangXi=0185.211, RSKangXi=30.5
20C49 CJK UNIFIED IDEOGRAPH-#20C49, IRGKangXi=0185.211, RSKangXi=30.5
20C4A CJK UNIFIED IDEOGRAPH-#20C4A, IRGKangXi=0185.211, RSKangXi=30.5
20C4B CJK UNIFIED IDEOGRAPH-#20C4B, IRGKangXi=0185.211, RSKangXi=30.5
20C4C CJK UNIFIED IDEOGRAPH-#20C4C, IRGKangXi=0185.211, RSKangXi=30.5
20C4D CJK UNIFIED IDEOGRAPH-#20C4D, IRGKangXi=0185.211, RSKangXi=30.5
20C4E CJK UNIFIED IDEOGRAPH-#20C4E, IRGKangXi=0185.211, RSKangXi=30.5
20C4F CJK UNIFIED IDEOGRAPH-#20C4F, IRGKangXi=0185.211, RSKangXi=30.5
20C50 CJK UNIFIED IDEOGRAPH-#20C50, IRGKangXi=0186.040, RSKangXi=30.6
20C51 CJK UNIFIED IDEOGRAPH-#20C51, IRGKangXi=0186.050, RSKangXi=30.6
20C52 CJK UNIFIED IDEOGRAPH-#20C52, IRGKangXi=0187.020, RSKangXi=30.6
20C53 CJK UNIFIED IDEOGRAPH-#20C53, IRGKangXi=0187.030, RSKangXi=30.6, Def{(Cant.) to importune, beg}
20C54 CJK UNIFIED IDEOGRAPH-#20C54, IRGKangXi=0187.040, RSKangXi=30.6
20C55 CJK UNIFIED IDEOGRAPH-#20C55, IRGKangXi=0187.160, RSKangXi=30.6
20C56 CJK UNIFIED IDEOGRAPH-#20C56, IRGKangXi=0187.170, RSKangXi=30.6
20C57 CJK UNIFIED IDEOGRAPH-#20C57, IRGKangXi=0187.180, RSKangXi=30.6
20C58 CJK UNIFIED IDEOGRAPH-#20C58, IRGKangXi=0187.210, RSKangXi=30.6, Def{(Cant.) contrary, opposing, against; disobedient}
20C59 CJK UNIFIED IDEOGRAPH-#20C59, IRGKangXi=0187.230, RSKangXi=30.6
20C5A CJK UNIFIED IDEOGRAPH-#20C5A, IRGKangXi=0187.240, RSKangXi=30.6
20C5B CJK UNIFIED IDEOGRAPH-#20C5B, IRGKangXi=0188.020, RSKangXi=30.6
20C5C CJK UNIFIED IDEOGRAPH-#20C5C, IRGKangXi=0188.030, RSKangXi=30.6
20C5D CJK UNIFIED IDEOGRAPH-#20C5D, IRGKangXi=0188.050, RSKangXi=30.6
20C5E CJK UNIFIED IDEOGRAPH-#20C5E, IRGKangXi=0188.060, RSKangXi=30.6
20C5F CJK UNIFIED IDEOGRAPH-#20C5F, IRGKangXi=0188.070, RSKangXi=30.6
20C60 CJK UNIFIED IDEOGRAPH-#20C60, IRGKangXi=0188.130, RSKangXi=30.6
20C61 CJK UNIFIED IDEOGRAPH-#20C61, IRGKangXi=0188.190, RSKangXi=30.6
20C62 CJK UNIFIED IDEOGRAPH-#20C62, IRGKangXi=0189.030, RSKangXi=30.6
20C63 CJK UNIFIED IDEOGRAPH-#20C63, IRGKangXi=0189.040, RSKangXi=30.6
20C64 CJK UNIFIED IDEOGRAPH-#20C64, IRGKangXi=0189.070, RSKangXi=30.6
20C65 CJK UNIFIED IDEOGRAPH-#20C65, IRGKangXi=0189.110, RSKangXi=30.6, Def{(Cant.) wrangling, a noise; fitful; a soft fabric with no body}
20C66 CJK UNIFIED IDEOGRAPH-#20C66, IRGKangXi=0189.120, RSKangXi=30.6
20C67 CJK UNIFIED IDEOGRAPH-#20C67, IRGKangXi=0189.140, RSKangXi=30.6
20C68 CJK UNIFIED IDEOGRAPH-#20C68, IRGKangXi=0189.150, RSKangXi=30.6
20C69 CJK UNIFIED IDEOGRAPH-#20C69, IRGKangXi=0189.160, RSKangXi=30.6
20C6A CJK UNIFIED IDEOGRAPH-#20C6A, IRGKangXi=0189.170, RSKangXi=30.6
20C6B CJK UNIFIED IDEOGRAPH-#20C6B, IRGKangXi=0189.180, RSKangXi=30.6
20C6C CJK UNIFIED IDEOGRAPH-#20C6C, IRGKangXi=0189.190, RSKangXi=30.6
20C6D CJK UNIFIED IDEOGRAPH-#20C6D, IRGKangXi=0189.200, RSKangXi=30.6
20C6E CJK UNIFIED IDEOGRAPH-#20C6E, IRGKangXi=0189.210, RSKangXi=30.6
20C6F CJK UNIFIED IDEOGRAPH-#20C6F, IRGKangXi=0189.220, RSKangXi=30.6
20C70 CJK UNIFIED IDEOGRAPH-#20C70, IRGKangXi=0189.230, RSKangXi=30.6
20C71 CJK UNIFIED IDEOGRAPH-#20C71, IRGKangXi=0189.240, RSKangXi=30.6
20C72 CJK UNIFIED IDEOGRAPH-#20C72, IRGKangXi=0189.250, RSKangXi=30.6
20C73 CJK UNIFIED IDEOGRAPH-#20C73, IRGKangXi=0189.260, RSKangXi=30.6
20C74 CJK UNIFIED IDEOGRAPH-#20C74, IRGKangXi=0189.270, RSKangXi=30.6
20C75 CJK UNIFIED IDEOGRAPH-#20C75, IRGKangXi=0189.271, RSKangXi=30.6
20C76 CJK UNIFIED IDEOGRAPH-#20C76, IRGKangXi=0189.271, RSKangXi=30.6
20C77 CJK UNIFIED IDEOGRAPH-#20C77, IRGKangXi=0189.271, RSKangXi=30.6, Def{(Cant.) small}
20C78 CJK UNIFIED IDEOGRAPH-#20C78, IRGKangXi=0189.271, RSKangXi=30.6, Def{(Cant.) phonetic}
20C79 CJK UNIFIED IDEOGRAPH-#20C79, IRGKangXi=0189.271, RSKangXi=30.6
20C7A CJK UNIFIED IDEOGRAPH-#20C7A, IRGKangXi=0189.271, RSKangXi=30.6
20C7B CJK UNIFIED IDEOGRAPH-#20C7B, IRGKangXi=0189.271, RSKangXi=30.6
20C7C CJK UNIFIED IDEOGRAPH-#20C7C, IRGKangXi=0189.271, RSKangXi=30.6
20C7D CJK UNIFIED IDEOGRAPH-#20C7D, IRGKangXi=0189.271, RSKangXi=30.6
20C7E CJK UNIFIED IDEOGRAPH-#20C7E, IRGKangXi=0189.271, RSKangXi=30.6
20C7F CJK UNIFIED IDEOGRAPH-#20C7F, IRGKangXi=0189.271, RSKangXi=30.6
20C80 CJK UNIFIED IDEOGRAPH-#20C80, IRGKangXi=0189.271, RSKangXi=30.6
20C81 CJK UNIFIED IDEOGRAPH-#20C81, IRGKangXi=0189.271, RSKangXi=30.6
20C82 CJK UNIFIED IDEOGRAPH-#20C82, IRGKangXi=0189.271, RSKangXi=30.6
20C83 CJK UNIFIED IDEOGRAPH-#20C83, IRGKangXi=0189.271, RSKangXi=30.6
20C84 CJK UNIFIED IDEOGRAPH-#20C84, IRGKangXi=0189.271, RSKangXi=30.6
20C85 CJK UNIFIED IDEOGRAPH-#20C85, IRGKangXi=0189.271, RSKangXi=30.6
20C86 CJK UNIFIED IDEOGRAPH-#20C86, IRGKangXi=0189.271, RSKangXi=30.6
20C87 CJK UNIFIED IDEOGRAPH-#20C87, IRGKangXi=0189.271, RSKangXi=30.6
20C88 CJK UNIFIED IDEOGRAPH-#20C88, IRGKangXi=0189.271, RSKangXi=30.6
20C89 CJK UNIFIED IDEOGRAPH-#20C89, IRGKangXi=0189.271, RSKangXi=30.6
20C8A CJK UNIFIED IDEOGRAPH-#20C8A, IRGKangXi=0189.271, RSKangXi=30.6
20C8B CJK UNIFIED IDEOGRAPH-#20C8B, IRGKangXi=0189.271, RSKangXi=30.6
20C8C CJK UNIFIED IDEOGRAPH-#20C8C, IRGKangXi=0189.271, RSKangXi=30.6
20C8D CJK UNIFIED IDEOGRAPH-#20C8D, IRGKangXi=0189.271, RSKangXi=30.6
20C8E CJK UNIFIED IDEOGRAPH-#20C8E, IRGKangXi=0189.271, RSKangXi=30.6
20C8F CJK UNIFIED IDEOGRAPH-#20C8F, IRGKangXi=0189.271, RSKangXi=30.6
20C90 CJK UNIFIED IDEOGRAPH-#20C90, IRGKangXi=0189.271, RSKangXi=30.6
20C91 CJK UNIFIED IDEOGRAPH-#20C91, IRGKangXi=0189.271, RSKangXi=30.6
20C92 CJK UNIFIED IDEOGRAPH-#20C92, IRGKangXi=0189.271, RSKangXi=30.6
20C93 CJK UNIFIED IDEOGRAPH-#20C93, IRGKangXi=0189.271, RSKangXi=30.6
20C94 CJK UNIFIED IDEOGRAPH-#20C94, IRGKangXi=0189.271, RSKangXi=30.6
20C95 CJK UNIFIED IDEOGRAPH-#20C95, IRGKangXi=0189.271, RSKangXi=30.6
20C96 CJK UNIFIED IDEOGRAPH-#20C96, IRGKangXi=0189.271, RSKangXi=30.6, Def{to grin, laugh}
20C97 CJK UNIFIED IDEOGRAPH-#20C97, IRGKangXi=0189.271, RSKangXi=30.6
20C98 CJK UNIFIED IDEOGRAPH-#20C98, IRGKangXi=0189.271, RSKangXi=30.6
20C99 CJK UNIFIED IDEOGRAPH-#20C99, IRGKangXi=0189.271, RSKangXi=30.6
20C9A CJK UNIFIED IDEOGRAPH-#20C9A, IRGKangXi=0189.271, RSKangXi=30.6
20C9B CJK UNIFIED IDEOGRAPH-#20C9B, IRGKangXi=0189.271, RSKangXi=30.6
20C9C CJK UNIFIED IDEOGRAPH-#20C9C, IRGKangXi=0189.271, RSKangXi=30.6, Def{(Cant.) to owe}
20C9D CJK UNIFIED IDEOGRAPH-#20C9D, IRGKangXi=0189.271, RSKangXi=30.6
20C9E CJK UNIFIED IDEOGRAPH-#20C9E, IRGKangXi=0189.271, RSKangXi=30.6
20C9F CJK UNIFIED IDEOGRAPH-#20C9F, IRGKangXi=0189.271, RSKangXi=30.6
20CA0 CJK UNIFIED IDEOGRAPH-#20CA0, IRGKangXi=0189.271, RSKangXi=30.6
20CA1 CJK UNIFIED IDEOGRAPH-#20CA1, IRGKangXi=0189.271, RSKangXi=30.6
20CA2 CJK UNIFIED IDEOGRAPH-#20CA2, IRGKangXi=0189.271, RSKangXi=30.6
20CA3 CJK UNIFIED IDEOGRAPH-#20CA3, IRGKangXi=0189.271, RSKangXi=30.6
20CA4 CJK UNIFIED IDEOGRAPH-#20CA4, IRGKangXi=0189.271, RSKangXi=30.6
20CA5 CJK UNIFIED IDEOGRAPH-#20CA5, IRGKangXi=0189.271, RSKangXi=30.6
20CA6 CJK UNIFIED IDEOGRAPH-#20CA6, IRGKangXi=0189.271, RSKangXi=30.6
20CA7 CJK UNIFIED IDEOGRAPH-#20CA7, IRGKangXi=0189.271, RSKangXi=30.6
20CA8 CJK UNIFIED IDEOGRAPH-#20CA8, IRGKangXi=0189.271, RSKangXi=30.6
20CA9 CJK UNIFIED IDEOGRAPH-#20CA9, IRGKangXi=0189.271, RSKangXi=30.6
20CAA CJK UNIFIED IDEOGRAPH-#20CAA, IRGKangXi=0189.271, RSKangXi=30.6
20CAB CJK UNIFIED IDEOGRAPH-#20CAB, IRGKangXi=0189.271, RSKangXi=30.6
20CAC CJK UNIFIED IDEOGRAPH-#20CAC, IRGKangXi=0189.271, RSKangXi=30.6
20CAD CJK UNIFIED IDEOGRAPH-#20CAD, IRGKangXi=0189.300, RSKangXi=30.7
20CAE CJK UNIFIED IDEOGRAPH-#20CAE, IRGKangXi=0190.010, RSKangXi=30.7
20CAF CJK UNIFIED IDEOGRAPH-#20CAF, IRGKangXi=0190.030, RSKangXi=30.7
20CB0 CJK UNIFIED IDEOGRAPH-#20CB0, IRGKangXi=0190.040, RSKangXi=30.7
20CB1 CJK UNIFIED IDEOGRAPH-#20CB1, IRGKangXi=0190.100, RSKangXi=30.7
20CB2 CJK UNIFIED IDEOGRAPH-#20CB2, IRGKangXi=0190.110, RSKangXi=30.7
20CB3 CJK UNIFIED IDEOGRAPH-#20CB3, IRGKangXi=0190.170, RSKangXi=30.7
20CB4 CJK UNIFIED IDEOGRAPH-#20CB4, IRGKangXi=0190.190, RSKangXi=30.7
20CB5 CJK UNIFIED IDEOGRAPH-#20CB5, IRGKangXi=0190.210, RSKangXi=30.7
20CB6 CJK UNIFIED IDEOGRAPH-#20CB6, IRGKangXi=0190.220, RSKangXi=30.7
20CB7 CJK UNIFIED IDEOGRAPH-#20CB7, IRGKangXi=0190.230, RSKangXi=30.7
20CB8 CJK UNIFIED IDEOGRAPH-#20CB8, IRGKangXi=0190.270, RSKangXi=30.7
20CB9 CJK UNIFIED IDEOGRAPH-#20CB9, IRGKangXi=0190.300, RSKangXi=30.7
20CBA CJK UNIFIED IDEOGRAPH-#20CBA, IRGKangXi=0190.320, RSKangXi=30.7
20CBB CJK UNIFIED IDEOGRAPH-#20CBB, IRGKangXi=0190.330, RSKangXi=30.7
20CBC CJK UNIFIED IDEOGRAPH-#20CBC, IRGKangXi=0191.040, RSKangXi=30.7
20CBD CJK UNIFIED IDEOGRAPH-#20CBD, IRGKangXi=0191.160, RSKangXi=30.7
20CBE CJK UNIFIED IDEOGRAPH-#20CBE, IRGKangXi=0191.170, RSKangXi=30.7
20CBF CJK UNIFIED IDEOGRAPH-#20CBF, IRGKangXi=0191.220, RSKangXi=30.7, Def{to suck in}
20CC0 CJK UNIFIED IDEOGRAPH-#20CC0, IRGKangXi=0191.260, RSKangXi=30.7
20CC1 CJK UNIFIED IDEOGRAPH-#20CC1, IRGKangXi=0192.010, RSKangXi=30.7
20CC2 CJK UNIFIED IDEOGRAPH-#20CC2, IRGKangXi=0192.020, RSKangXi=30.7
20CC3 CJK UNIFIED IDEOGRAPH-#20CC3, IRGKangXi=0192.110, RSKangXi=30.7
20CC4 CJK UNIFIED IDEOGRAPH-#20CC4, IRGKangXi=0192.160, RSKangXi=30.7
20CC5 CJK UNIFIED IDEOGRAPH-#20CC5, IRGKangXi=0192.170, RSKangXi=30.7
20CC6 CJK UNIFIED IDEOGRAPH-#20CC6, IRGKangXi=0192.190, RSKangXi=30.7
20CC7 CJK UNIFIED IDEOGRAPH-#20CC7, IRGKangXi=0192.200, RSKangXi=30.7
20CC8 CJK UNIFIED IDEOGRAPH-#20CC8, IRGKangXi=0192.210, RSKangXi=30.7
20CC9 CJK UNIFIED IDEOGRAPH-#20CC9, IRGKangXi=0192.220, RSKangXi=30.7
20CCA CJK UNIFIED IDEOGRAPH-#20CCA, IRGKangXi=0193.010, RSKangXi=30.7
20CCB CJK UNIFIED IDEOGRAPH-#20CCB, IRGKangXi=0193.020, RSKangXi=30.7
20CCC CJK UNIFIED IDEOGRAPH-#20CCC, IRGKangXi=0193.030, RSKangXi=30.7
20CCD CJK UNIFIED IDEOGRAPH-#20CCD, IRGKangXi=0193.040, RSKangXi=30.7
20CCE CJK UNIFIED IDEOGRAPH-#20CCE, IRGKangXi=0193.050, RSKangXi=30.7
20CCF CJK UNIFIED IDEOGRAPH-#20CCF, IRGKangXi=0193.051, RSKangXi=30.7, Def{(Cant.) interjection}
20CD0 CJK UNIFIED IDEOGRAPH-#20CD0, IRGKangXi=0193.051, RSKangXi=30.7
20CD1 CJK UNIFIED IDEOGRAPH-#20CD1, IRGKangXi=0193.051, RSKangXi=30.7
20CD2 CJK UNIFIED IDEOGRAPH-#20CD2, IRGKangXi=0193.051, RSKangXi=30.7
20CD3 CJK UNIFIED IDEOGRAPH-#20CD3, IRGKangXi=0193.051, RSKangXi=30.7
20CD4 CJK UNIFIED IDEOGRAPH-#20CD4, IRGKangXi=0193.051, RSKangXi=30.7
20CD5 CJK UNIFIED IDEOGRAPH-#20CD5, IRGKangXi=0193.051, RSKangXi=30.7, Def{(Cant.) to search}
20CD6 CJK UNIFIED IDEOGRAPH-#20CD6, IRGKangXi=0193.051, RSKangXi=30.7, Def{(Cant.) to strike, pound}
20CD7 CJK UNIFIED IDEOGRAPH-#20CD7, IRGKangXi=0193.051, RSKangXi=30.7
20CD8 CJK UNIFIED IDEOGRAPH-#20CD8, IRGKangXi=0193.051, RSKangXi=30.7
20CD9 CJK UNIFIED IDEOGRAPH-#20CD9, IRGKangXi=0193.051, RSKangXi=30.7
20CDA CJK UNIFIED IDEOGRAPH-#20CDA, IRGKangXi=0193.051, RSKangXi=30.7
20CDB CJK UNIFIED IDEOGRAPH-#20CDB, IRGKangXi=0193.051, RSKangXi=30.7
20CDC CJK UNIFIED IDEOGRAPH-#20CDC, IRGKangXi=0193.051, RSKangXi=30.7
20CDD CJK UNIFIED IDEOGRAPH-#20CDD, IRGKangXi=0193.051, RSKangXi=30.7
20CDE CJK UNIFIED IDEOGRAPH-#20CDE, IRGKangXi=0193.051, RSKangXi=30.7
20CDF CJK UNIFIED IDEOGRAPH-#20CDF, IRGKangXi=0193.051, RSKangXi=30.7
20CE0 CJK UNIFIED IDEOGRAPH-#20CE0, IRGKangXi=0193.051, RSKangXi=30.7
20CE1 CJK UNIFIED IDEOGRAPH-#20CE1, IRGKangXi=0193.051, RSKangXi=30.7
20CE2 CJK UNIFIED IDEOGRAPH-#20CE2, IRGKangXi=0193.051, RSKangXi=30.7
20CE3 CJK UNIFIED IDEOGRAPH-#20CE3, IRGKangXi=0193.051, RSKangXi=30.7
20CE4 CJK UNIFIED IDEOGRAPH-#20CE4, IRGKangXi=0193.051, RSKangXi=30.7
20CE5 CJK UNIFIED IDEOGRAPH-#20CE5, IRGKangXi=0193.051, RSKangXi=30.7
20CE6 CJK UNIFIED IDEOGRAPH-#20CE6, IRGKangXi=0193.051, RSKangXi=30.7
20CE7 CJK UNIFIED IDEOGRAPH-#20CE7, IRGKangXi=0193.051, RSKangXi=30.7
20CE8 CJK UNIFIED IDEOGRAPH-#20CE8, IRGKangXi=0193.051, RSKangXi=30.7
20CE9 CJK UNIFIED IDEOGRAPH-#20CE9, IRGKangXi=0193.051, RSKangXi=30.7
20CEA CJK UNIFIED IDEOGRAPH-#20CEA, IRGKangXi=0193.051, RSKangXi=30.7
20CEB CJK UNIFIED IDEOGRAPH-#20CEB, IRGKangXi=0193.051, RSKangXi=101.5
20CEC CJK UNIFIED IDEOGRAPH-#20CEC, IRGKangXi=0193.051, RSKangXi=30.7
20CED CJK UNIFIED IDEOGRAPH-#20CED, IRGKangXi=0193.051, RSKangXi=30.7
20CEE CJK UNIFIED IDEOGRAPH-#20CEE, IRGKangXi=0193.051, RSKangXi=30.7
20CEF CJK UNIFIED IDEOGRAPH-#20CEF, IRGKangXi=0193.051, RSKangXi=30.7
20CF0 CJK UNIFIED IDEOGRAPH-#20CF0, IRGKangXi=0193.051, RSKangXi=30.7
20CF1 CJK UNIFIED IDEOGRAPH-#20CF1, IRGKangXi=0193.051, RSKangXi=30.7
20CF2 CJK UNIFIED IDEOGRAPH-#20CF2, IRGKangXi=0193.051, RSKangXi=30.7
20CF3 CJK UNIFIED IDEOGRAPH-#20CF3, IRGKangXi=0193.051, RSKangXi=30.7
20CF4 CJK UNIFIED IDEOGRAPH-#20CF4, IRGKangXi=0193.051, RSKangXi=30.7
20CF5 CJK UNIFIED IDEOGRAPH-#20CF5, IRGKangXi=0193.051, RSKangXi=30.7
20CF6 CJK UNIFIED IDEOGRAPH-#20CF6, IRGKangXi=0193.051, RSKangXi=30.7, Def{tongue-tied; to lisp}
20CF7 CJK UNIFIED IDEOGRAPH-#20CF7, IRGKangXi=0193.051, RSKangXi=30.7
20CF8 CJK UNIFIED IDEOGRAPH-#20CF8, IRGKangXi=0193.051, RSKangXi=30.7
20CF9 CJK UNIFIED IDEOGRAPH-#20CF9, IRGKangXi=0193.051, RSKangXi=30.7
20CFA CJK UNIFIED IDEOGRAPH-#20CFA, IRGKangXi=0193.051, RSKangXi=30.7
20CFB CJK UNIFIED IDEOGRAPH-#20CFB, IRGKangXi=0193.051, RSKangXi=30.7
20CFC CJK UNIFIED IDEOGRAPH-#20CFC, IRGKangXi=0193.051, RSKangXi=30.7
20CFD CJK UNIFIED IDEOGRAPH-#20CFD, IRGKangXi=0193.051, RSKangXi=30.7
20CFE CJK UNIFIED IDEOGRAPH-#20CFE, IRGKangXi=0193.051, RSKangXi=30.7
20CFF CJK UNIFIED IDEOGRAPH-#20CFF, IRGKangXi=0193.051, RSKangXi=30.7
20D00 CJK UNIFIED IDEOGRAPH-#20D00, IRGKangXi=0193.051, RSKangXi=30.7
20D01 CJK UNIFIED IDEOGRAPH-#20D01, IRGKangXi=0193.051, RSKangXi=30.7
20D02 CJK UNIFIED IDEOGRAPH-#20D02, IRGKangXi=0193.051, RSKangXi=30.7
20D03 CJK UNIFIED IDEOGRAPH-#20D03, IRGKangXi=0193.051, RSKangXi=30.7
20D04 CJK UNIFIED IDEOGRAPH-#20D04, IRGKangXi=0193.051, RSKangXi=30.7
20D05 CJK UNIFIED IDEOGRAPH-#20D05, IRGKangXi=0193.051, RSKangXi=30.7
20D06 CJK UNIFIED IDEOGRAPH-#20D06, IRGKangXi=0193.051, RSKangXi=30.7
20D07 CJK UNIFIED IDEOGRAPH-#20D07, IRGKangXi=0193.051, RSKangXi=30.7
20D08 CJK UNIFIED IDEOGRAPH-#20D08, IRGKangXi=0193.051, RSKangXi=30.7
20D09 CJK UNIFIED IDEOGRAPH-#20D09, IRGKangXi=0193.051, RSKangXi=30.7
20D0A CJK UNIFIED IDEOGRAPH-#20D0A, IRGKangXi=0193.051, RSKangXi=30.7
20D0B CJK UNIFIED IDEOGRAPH-#20D0B, IRGKangXi=0193.051, RSKangXi=30.7
20D0C CJK UNIFIED IDEOGRAPH-#20D0C, IRGKangXi=0193.051, RSKangXi=30.7
20D0D CJK UNIFIED IDEOGRAPH-#20D0D, IRGKangXi=0193.051, RSKangXi=30.7
20D0E CJK UNIFIED IDEOGRAPH-#20D0E, IRGKangXi=0193.051, RSKangXi=30.7
20D0F CJK UNIFIED IDEOGRAPH-#20D0F, IRGKangXi=0193.051, RSKangXi=30.7
20D10 CJK UNIFIED IDEOGRAPH-#20D10, IRGKangXi=0193.051, RSKangXi=30.7
20D11 CJK UNIFIED IDEOGRAPH-#20D11, IRGKangXi=0193.051, RSKangXi=30.7
20D12 CJK UNIFIED IDEOGRAPH-#20D12, IRGKangXi=0193.051, RSKangXi=30.7
20D13 CJK UNIFIED IDEOGRAPH-#20D13, IRGKangXi=0193.051, RSKangXi=30.7
20D14 CJK UNIFIED IDEOGRAPH-#20D14, IRGKangXi=0193.051, RSKangXi=30.7
20D15 CJK UNIFIED IDEOGRAPH-#20D15, IRGKangXi=0193.051, RSKangXi=30.7, Def{(Cant.) to purse the lips; to wriggle}
20D16 CJK UNIFIED IDEOGRAPH-#20D16, IRGKangXi=0193.051, RSKangXi=30.7
20D17 CJK UNIFIED IDEOGRAPH-#20D17, IRGKangXi=0193.051, RSKangXi=30.7
20D18 CJK UNIFIED IDEOGRAPH-#20D18, IRGKangXi=0193.051, RSKangXi=30.7
20D19 CJK UNIFIED IDEOGRAPH-#20D19, IRGKangXi=0193.051, RSKangXi=30.7
20D1A CJK UNIFIED IDEOGRAPH-#20D1A, IRGKangXi=0193.051, RSKangXi=30.7
20D1B CJK UNIFIED IDEOGRAPH-#20D1B, IRGKangXi=0193.051, RSKangXi=30.7
20D1C CJK UNIFIED IDEOGRAPH-#20D1C, IRGKangXi=0193.051, RSKangXi=30.7
20D1D CJK UNIFIED IDEOGRAPH-#20D1D, IRGKangXi=0193.051, RSKangXi=30.7
20D1E CJK UNIFIED IDEOGRAPH-#20D1E, IRGKangXi=0193.051, RSKangXi=30.7
20D1F CJK UNIFIED IDEOGRAPH-#20D1F, IRGKangXi=0193.051, RSKangXi=30.7
20D20 CJK UNIFIED IDEOGRAPH-#20D20, IRGKangXi=0193.051, RSKangXi=30.7
20D21 CJK UNIFIED IDEOGRAPH-#20D21, IRGKangXi=0193.051, RSKangXi=30.7
20D22 CJK UNIFIED IDEOGRAPH-#20D22, IRGKangXi=0193.051, RSKangXi=30.7
20D23 CJK UNIFIED IDEOGRAPH-#20D23, IRGKangXi=0193.051, RSKangXi=30.7
20D24 CJK UNIFIED IDEOGRAPH-#20D24, IRGKangXi=0193.051, RSKangXi=30.7
20D25 CJK UNIFIED IDEOGRAPH-#20D25, IRGKangXi=0193.051, RSKangXi=30.7
20D26 CJK UNIFIED IDEOGRAPH-#20D26, IRGKangXi=0193.051, RSKangXi=96.6
20D27 CJK UNIFIED IDEOGRAPH-#20D27, IRGKangXi=0193.060, RSKangXi=30.8
20D28 CJK UNIFIED IDEOGRAPH-#20D28, IRGKangXi=0193.070, RSKangXi=30.8
20D29 CJK UNIFIED IDEOGRAPH-#20D29, IRGKangXi=0193.160, RSKangXi=30.8
20D2A CJK UNIFIED IDEOGRAPH-#20D2A, IRGKangXi=0193.190, RSKangXi=30.8
20D2B CJK UNIFIED IDEOGRAPH-#20D2B, IRGKangXi=0193.200, RSKangXi=30.8
20D2C CJK UNIFIED IDEOGRAPH-#20D2C, IRGKangXi=0193.250, RSKangXi=30.8
20D2D CJK UNIFIED IDEOGRAPH-#20D2D, IRGKangXi=0194.100, RSKangXi=30.8
20D2E CJK UNIFIED IDEOGRAPH-#20D2E, IRGKangXi=0194.120, RSKangXi=30.8
20D2F CJK UNIFIED IDEOGRAPH-#20D2F, IRGKangXi=0194.150, RSKangXi=30.8
20D30 CJK UNIFIED IDEOGRAPH-#20D30, IRGKangXi=0194.160, RSKangXi=30.8, Def{(Cant.) classifier for a piece or lump of something}
20D31 CJK UNIFIED IDEOGRAPH-#20D31, IRGKangXi=0194.200, RSKangXi=30.8
20D32 CJK UNIFIED IDEOGRAPH-#20D32, IRGKangXi=0194.230, RSKangXi=30.8
20D33 CJK UNIFIED IDEOGRAPH-#20D33, IRGKangXi=0194.240, RSKangXi=30.8, Def{(Cant.) a tiger or demon's howl; to argue, quarrel}
20D34 CJK UNIFIED IDEOGRAPH-#20D34, IRGKangXi=0194.250, RSKangXi=30.8
20D35 CJK UNIFIED IDEOGRAPH-#20D35, IRGKangXi=0194.280, RSKangXi=30.8
20D36 CJK UNIFIED IDEOGRAPH-#20D36, IRGKangXi=0194.290, RSKangXi=30.8
20D37 CJK UNIFIED IDEOGRAPH-#20D37, IRGKangXi=0195.120, RSKangXi=30.8
20D38 CJK UNIFIED IDEOGRAPH-#20D38, IRGKangXi=0196.060, RSKangXi=30.8
20D39 CJK UNIFIED IDEOGRAPH-#20D39, IRGKangXi=0196.110, RSKangXi=30.8
20D3A CJK UNIFIED IDEOGRAPH-#20D3A, IRGKangXi=0196.170, RSKangXi=30.8
20D3B CJK UNIFIED IDEOGRAPH-#20D3B, IRGKangXi=0196.180, RSKangXi=30.8
20D3C CJK UNIFIED IDEOGRAPH-#20D3C, IRGKangXi=0196.190, RSKangXi=30.8
20D3D CJK UNIFIED IDEOGRAPH-#20D3D, IRGKangXi=0196.200, RSKangXi=30.8
20D3E CJK UNIFIED IDEOGRAPH-#20D3E, IRGKangXi=0196.210, RSKangXi=30.8
20D3F CJK UNIFIED IDEOGRAPH-#20D3F, IRGKangXi=0196.220, RSKangXi=30.8
20D40 CJK UNIFIED IDEOGRAPH-#20D40, IRGKangXi=0196.230, RSKangXi=30.8
20D41 CJK UNIFIED IDEOGRAPH-#20D41, IRGKangXi=0196.240, RSKangXi=30.8
20D42 CJK UNIFIED IDEOGRAPH-#20D42, IRGKangXi=0196.250, RSKangXi=30.8
20D43 CJK UNIFIED IDEOGRAPH-#20D43, IRGKangXi=0196.260, RSKangXi=30.8
20D44 CJK UNIFIED IDEOGRAPH-#20D44, IRGKangXi=0196.261, RSKangXi=30.8
20D45 CJK UNIFIED IDEOGRAPH-#20D45, IRGKangXi=0196.261, RSKangXi=30.8
20D46 CJK UNIFIED IDEOGRAPH-#20D46, IRGKangXi=0196.261, RSKangXi=30.8
20D47 CJK UNIFIED IDEOGRAPH-#20D47, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) peculiar, strange}
20D48 CJK UNIFIED IDEOGRAPH-#20D48, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) to suck or chew without using the teeth}
20D49 CJK UNIFIED IDEOGRAPH-#20D49, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) hope}
20D4A CJK UNIFIED IDEOGRAPH-#20D4A, IRGKangXi=0196.261, RSKangXi=30.8
20D4B CJK UNIFIED IDEOGRAPH-#20D4B, IRGKangXi=0196.261, RSKangXi=30.8
20D4C CJK UNIFIED IDEOGRAPH-#20D4C, IRGKangXi=0196.261, RSKangXi=30.8
20D4D CJK UNIFIED IDEOGRAPH-#20D4D, IRGKangXi=0196.261, RSKangXi=30.8
20D4E CJK UNIFIED IDEOGRAPH-#20D4E, IRGKangXi=0196.261, RSKangXi=30.8
20D4F CJK UNIFIED IDEOGRAPH-#20D4F, IRGKangXi=0196.261, RSKangXi=30.8
20D50 CJK UNIFIED IDEOGRAPH-#20D50, IRGKangXi=0196.261, RSKangXi=30.8
20D51 CJK UNIFIED IDEOGRAPH-#20D51, IRGKangXi=0196.261, RSKangXi=30.8
20D52 CJK UNIFIED IDEOGRAPH-#20D52, IRGKangXi=0196.261, RSKangXi=30.8
20D53 CJK UNIFIED IDEOGRAPH-#20D53, IRGKangXi=0196.261, RSKangXi=30.8
20D54 CJK UNIFIED IDEOGRAPH-#20D54, IRGKangXi=0196.261, RSKangXi=30.8
20D55 CJK UNIFIED IDEOGRAPH-#20D55, IRGKangXi=0196.261, RSKangXi=30.8
20D56 CJK UNIFIED IDEOGRAPH-#20D56, IRGKangXi=0196.261, RSKangXi=30.8
20D57 CJK UNIFIED IDEOGRAPH-#20D57, IRGKangXi=0196.261, RSKangXi=30.8
20D58 CJK UNIFIED IDEOGRAPH-#20D58, IRGKangXi=0196.261, RSKangXi=30.8, Def{phonetic}
20D59 CJK UNIFIED IDEOGRAPH-#20D59, IRGKangXi=0196.261, RSKangXi=30.8
20D5A CJK UNIFIED IDEOGRAPH-#20D5A, IRGKangXi=0196.261, RSKangXi=30.8
20D5B CJK UNIFIED IDEOGRAPH-#20D5B, IRGKangXi=0196.261, RSKangXi=30.8
20D5C CJK UNIFIED IDEOGRAPH-#20D5C, IRGKangXi=0196.261, RSKangXi=30.8
20D5D CJK UNIFIED IDEOGRAPH-#20D5D, IRGKangXi=0196.261, RSKangXi=30.8
20D5E CJK UNIFIED IDEOGRAPH-#20D5E, IRGKangXi=0196.261, RSKangXi=30.8
20D5F CJK UNIFIED IDEOGRAPH-#20D5F, IRGKangXi=0196.261, RSKangXi=30.8
20D60 CJK UNIFIED IDEOGRAPH-#20D60, IRGKangXi=0196.261, RSKangXi=30.8
20D61 CJK UNIFIED IDEOGRAPH-#20D61, IRGKangXi=0196.261, RSKangXi=30.8
20D62 CJK UNIFIED IDEOGRAPH-#20D62, IRGKangXi=0196.261, RSKangXi=30.8
20D63 CJK UNIFIED IDEOGRAPH-#20D63, IRGKangXi=0196.261, RSKangXi=30.8
20D64 CJK UNIFIED IDEOGRAPH-#20D64, IRGKangXi=0196.261, RSKangXi=30.8
20D65 CJK UNIFIED IDEOGRAPH-#20D65, IRGKangXi=0196.261, RSKangXi=30.8
20D66 CJK UNIFIED IDEOGRAPH-#20D66, IRGKangXi=0196.261, RSKangXi=30.8
20D67 CJK UNIFIED IDEOGRAPH-#20D67, IRGKangXi=0196.261, RSKangXi=30.8
20D68 CJK UNIFIED IDEOGRAPH-#20D68, IRGKangXi=0196.261, RSKangXi=30.8
20D69 CJK UNIFIED IDEOGRAPH-#20D69, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) that}
20D6A CJK UNIFIED IDEOGRAPH-#20D6A, IRGKangXi=0196.261, RSKangXi=30.8
20D6B CJK UNIFIED IDEOGRAPH-#20D6B, IRGKangXi=0196.261, RSKangXi=30.8
20D6C CJK UNIFIED IDEOGRAPH-#20D6C, IRGKangXi=0196.261, RSKangXi=30.8
20D6D CJK UNIFIED IDEOGRAPH-#20D6D, IRGKangXi=0196.261, RSKangXi=30.8
20D6E CJK UNIFIED IDEOGRAPH-#20D6E, IRGKangXi=0196.261, RSKangXi=30.8
20D6F CJK UNIFIED IDEOGRAPH-#20D6F, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) onomatopoetic}
20D70 CJK UNIFIED IDEOGRAPH-#20D70, IRGKangXi=0196.261, RSKangXi=30.8
20D71 CJK UNIFIED IDEOGRAPH-#20D71, IRGKangXi=0196.261, RSKangXi=30.8
20D72 CJK UNIFIED IDEOGRAPH-#20D72, IRGKangXi=0196.261, RSKangXi=30.8
20D73 CJK UNIFIED IDEOGRAPH-#20D73, IRGKangXi=0196.261, RSKangXi=30.8
20D74 CJK UNIFIED IDEOGRAPH-#20D74, IRGKangXi=0196.261, RSKangXi=30.8
20D75 CJK UNIFIED IDEOGRAPH-#20D75, IRGKangXi=0196.261, RSKangXi=30.9
20D76 CJK UNIFIED IDEOGRAPH-#20D76, IRGKangXi=0196.261, RSKangXi=30.8
20D77 CJK UNIFIED IDEOGRAPH-#20D77, IRGKangXi=0196.261, RSKangXi=30.8
20D78 CJK UNIFIED IDEOGRAPH-#20D78, IRGKangXi=0196.261, RSKangXi=30.8
20D79 CJK UNIFIED IDEOGRAPH-#20D79, IRGKangXi=0196.261, RSKangXi=30.8
20D7A CJK UNIFIED IDEOGRAPH-#20D7A, IRGKangXi=0196.261, RSKangXi=30.8
20D7B CJK UNIFIED IDEOGRAPH-#20D7B, IRGKangXi=0196.261, RSKangXi=30.8
20D7C CJK UNIFIED IDEOGRAPH-#20D7C, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) scars on the eyelid; phonetic}
20D7D CJK UNIFIED IDEOGRAPH-#20D7D, IRGKangXi=0196.261, RSKangXi=30.8
20D7E CJK UNIFIED IDEOGRAPH-#20D7E, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) eloquent, sharp-tongued}
20D7F CJK UNIFIED IDEOGRAPH-#20D7F, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) a pair (from the Engl.); to stagger}
20D80 CJK UNIFIED IDEOGRAPH-#20D80, IRGKangXi=0196.261, RSKangXi=30.8
20D81 CJK UNIFIED IDEOGRAPH-#20D81, IRGKangXi=0196.261, RSKangXi=30.8
20D82 CJK UNIFIED IDEOGRAPH-#20D82, IRGKangXi=0196.261, RSKangXi=30.8
20D83 CJK UNIFIED IDEOGRAPH-#20D83, IRGKangXi=0196.261, RSKangXi=30.8
20D84 CJK UNIFIED IDEOGRAPH-#20D84, IRGKangXi=0196.261, RSKangXi=30.8
20D85 CJK UNIFIED IDEOGRAPH-#20D85, IRGKangXi=0196.261, RSKangXi=30.8
20D86 CJK UNIFIED IDEOGRAPH-#20D86, IRGKangXi=0196.261, RSKangXi=30.8
20D87 CJK UNIFIED IDEOGRAPH-#20D87, IRGKangXi=0196.261, RSKangXi=30.8
20D88 CJK UNIFIED IDEOGRAPH-#20D88, IRGKangXi=0196.261, RSKangXi=30.8
20D89 CJK UNIFIED IDEOGRAPH-#20D89, IRGKangXi=0196.261, RSKangXi=30.8
20D8A CJK UNIFIED IDEOGRAPH-#20D8A, IRGKangXi=0196.261, RSKangXi=30.8
20D8B CJK UNIFIED IDEOGRAPH-#20D8B, IRGKangXi=0196.261, RSKangXi=30.8
20D8C CJK UNIFIED IDEOGRAPH-#20D8C, IRGKangXi=0196.261, RSKangXi=30.8
20D8D CJK UNIFIED IDEOGRAPH-#20D8D, IRGKangXi=0196.261, RSKangXi=30.8
20D8E CJK UNIFIED IDEOGRAPH-#20D8E, IRGKangXi=0196.261, RSKangXi=30.8
20D8F CJK UNIFIED IDEOGRAPH-#20D8F, IRGKangXi=0196.261, RSKangXi=30.8
20D90 CJK UNIFIED IDEOGRAPH-#20D90, IRGKangXi=0196.261, RSKangXi=30.8
20D91 CJK UNIFIED IDEOGRAPH-#20D91, IRGKangXi=0196.261, RSKangXi=30.8
20D92 CJK UNIFIED IDEOGRAPH-#20D92, IRGKangXi=0196.261, RSKangXi=30.8
20D93 CJK UNIFIED IDEOGRAPH-#20D93, IRGKangXi=0196.261, RSKangXi=30.8
20D94 CJK UNIFIED IDEOGRAPH-#20D94, IRGKangXi=0196.261, RSKangXi=30.8
20D95 CJK UNIFIED IDEOGRAPH-#20D95, IRGKangXi=0196.261, RSKangXi=30.8
20D96 CJK UNIFIED IDEOGRAPH-#20D96, IRGKangXi=0196.261, RSKangXi=30.8
20D97 CJK UNIFIED IDEOGRAPH-#20D97, IRGKangXi=0196.261, RSKangXi=30.8
20D98 CJK UNIFIED IDEOGRAPH-#20D98, IRGKangXi=0196.261, RSKangXi=30.8
20D99 CJK UNIFIED IDEOGRAPH-#20D99, IRGKangXi=0196.261, RSKangXi=30.8
20D9A CJK UNIFIED IDEOGRAPH-#20D9A, IRGKangXi=0196.261, RSKangXi=30.8
20D9B CJK UNIFIED IDEOGRAPH-#20D9B, IRGKangXi=0196.261, RSKangXi=30.8
20D9C CJK UNIFIED IDEOGRAPH-#20D9C, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) to do, work; to be willing}
20D9D CJK UNIFIED IDEOGRAPH-#20D9D, IRGKangXi=0196.261, RSKangXi=30.8
20D9E CJK UNIFIED IDEOGRAPH-#20D9E, IRGKangXi=0196.261, RSKangXi=30.8
20D9F CJK UNIFIED IDEOGRAPH-#20D9F, IRGKangXi=0196.261, RSKangXi=30.8
20DA0 CJK UNIFIED IDEOGRAPH-#20DA0, IRGKangXi=0196.261, RSKangXi=30.8
20DA1 CJK UNIFIED IDEOGRAPH-#20DA1, IRGKangXi=0196.261, RSKangXi=30.8
20DA2 CJK UNIFIED IDEOGRAPH-#20DA2, IRGKangXi=0196.261, RSKangXi=30.8
20DA3 CJK UNIFIED IDEOGRAPH-#20DA3, IRGKangXi=0196.261, RSKangXi=30.8
20DA4 CJK UNIFIED IDEOGRAPH-#20DA4, IRGKangXi=0196.261, RSKangXi=30.8
20DA5 CJK UNIFIED IDEOGRAPH-#20DA5, IRGKangXi=0196.261, RSKangXi=30.8
20DA6 CJK UNIFIED IDEOGRAPH-#20DA6, IRGKangXi=0196.261, RSKangXi=30.8
20DA7 CJK UNIFIED IDEOGRAPH-#20DA7, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) straight, vertical; OK; to pick up with the fingers; verbal aspect marker of successful completion}
20DA8 CJK UNIFIED IDEOGRAPH-#20DA8, IRGKangXi=0196.261, RSKangXi=30.8
20DA9 CJK UNIFIED IDEOGRAPH-#20DA9, IRGKangXi=0196.261, RSKangXi=30.8
20DAA CJK UNIFIED IDEOGRAPH-#20DAA, IRGKangXi=0196.261, RSKangXi=30.8
20DAB CJK UNIFIED IDEOGRAPH-#20DAB, IRGKangXi=0196.261, RSKangXi=30.8
20DAC CJK UNIFIED IDEOGRAPH-#20DAC, IRGKangXi=0196.261, RSKangXi=30.8
20DAD CJK UNIFIED IDEOGRAPH-#20DAD, IRGKangXi=0196.261, RSKangXi=30.8
20DAE CJK UNIFIED IDEOGRAPH-#20DAE, IRGKangXi=0196.261, RSKangXi=30.8
20DAF CJK UNIFIED IDEOGRAPH-#20DAF, IRGKangXi=0196.261, RSKangXi=30.8
20DB0 CJK UNIFIED IDEOGRAPH-#20DB0, IRGKangXi=0196.261, RSKangXi=30.8
20DB1 CJK UNIFIED IDEOGRAPH-#20DB1, IRGKangXi=0196.261, RSKangXi=30.8
20DB2 CJK UNIFIED IDEOGRAPH-#20DB2, IRGKangXi=0196.261, RSKangXi=30.8, Def{(Cant.) to stare at; to take a big bite}
20DB3 CJK UNIFIED IDEOGRAPH-#20DB3, IRGKangXi=0196.261, RSKangXi=30.8
20DB4 CJK UNIFIED IDEOGRAPH-#20DB4, IRGKangXi=0196.261, RSKangXi=30.8
20DB5 CJK UNIFIED IDEOGRAPH-#20DB5, IRGKangXi=0196.261, RSKangXi=30.8
20DB6 CJK UNIFIED IDEOGRAPH-#20DB6, IRGKangXi=0196.261, RSKangXi=30.8
20DB7 CJK UNIFIED IDEOGRAPH-#20DB7, IRGKangXi=0197.050, RSKangXi=30.9
20DB8 CJK UNIFIED IDEOGRAPH-#20DB8, IRGKangXi=0197.060, RSKangXi=30.9
20DB9 CJK UNIFIED IDEOGRAPH-#20DB9, IRGKangXi=0197.110, RSKangXi=30.9
20DBA CJK UNIFIED IDEOGRAPH-#20DBA, IRGKangXi=0197.130, RSKangXi=30.9
20DBB CJK UNIFIED IDEOGRAPH-#20DBB, IRGKangXi=0197.250, RSKangXi=30.9
20DBC CJK UNIFIED IDEOGRAPH-#20DBC, IRGKangXi=0197.290, RSKangXi=30.9
20DBD CJK UNIFIED IDEOGRAPH-#20DBD, IRGKangXi=0197.300, RSKangXi=30.9
20DBE CJK UNIFIED IDEOGRAPH-#20DBE, IRGKangXi=0197.320, RSKangXi=30.9
20DBF CJK UNIFIED IDEOGRAPH-#20DBF, IRGKangXi=0198.050, RSKangXi=30.9
20DC0 CJK UNIFIED IDEOGRAPH-#20DC0, IRGKangXi=0198.070, RSKangXi=30.9
20DC1 CJK UNIFIED IDEOGRAPH-#20DC1, IRGKangXi=0198.080, RSKangXi=30.9
20DC2 CJK UNIFIED IDEOGRAPH-#20DC2, IRGKangXi=0198.110, RSKangXi=30.9
20DC3 CJK UNIFIED IDEOGRAPH-#20DC3, IRGKangXi=0198.160, RSKangXi=30.9
20DC4 CJK UNIFIED IDEOGRAPH-#20DC4, IRGKangXi=0198.170, RSKangXi=30.9
20DC5 CJK UNIFIED IDEOGRAPH-#20DC5, IRGKangXi=0198.210, RSKangXi=30.9
20DC6 CJK UNIFIED IDEOGRAPH-#20DC6, IRGKangXi=0198.220, RSKangXi=30.9
20DC7 CJK UNIFIED IDEOGRAPH-#20DC7, IRGKangXi=0198.250, RSKangXi=30.9
20DC8 CJK UNIFIED IDEOGRAPH-#20DC8, IRGKangXi=0198.270, RSKangXi=30.9
20DC9 CJK UNIFIED IDEOGRAPH-#20DC9, IRGKangXi=0198.330, RSKangXi=30.9
20DCA CJK UNIFIED IDEOGRAPH-#20DCA, IRGKangXi=0199.030, RSKangXi=30.9
20DCB CJK UNIFIED IDEOGRAPH-#20DCB, IRGKangXi=0199.100, RSKangXi=30.9
20DCC CJK UNIFIED IDEOGRAPH-#20DCC, IRGKangXi=0199.130, RSKangXi=30.9
20DCD CJK UNIFIED IDEOGRAPH-#20DCD, IRGKangXi=0199.170, RSKangXi=30.9
20DCE CJK UNIFIED IDEOGRAPH-#20DCE, IRGKangXi=0199.180, RSKangXi=30.9
20DCF CJK UNIFIED IDEOGRAPH-#20DCF, IRGKangXi=0200.040, RSKangXi=30.9
20DD0 CJK UNIFIED IDEOGRAPH-#20DD0, IRGKangXi=0200.070, RSKangXi=30.9
20DD1 CJK UNIFIED IDEOGRAPH-#20DD1, IRGKangXi=0200.080, RSKangXi=30.9
20DD2 CJK UNIFIED IDEOGRAPH-#20DD2, IRGKangXi=0200.090, RSKangXi=30.9
20DD3 CJK UNIFIED IDEOGRAPH-#20DD3, IRGKangXi=0200.110, RSKangXi=30.9
20DD4 CJK UNIFIED IDEOGRAPH-#20DD4, IRGKangXi=0200.180, RSKangXi=30.9
20DD5 CJK UNIFIED IDEOGRAPH-#20DD5, IRGKangXi=0200.200, RSKangXi=30.9
20DD6 CJK UNIFIED IDEOGRAPH-#20DD6, IRGKangXi=0201.020, RSKangXi=30.9
20DD7 CJK UNIFIED IDEOGRAPH-#20DD7, IRGKangXi=0201.040, RSKangXi=30.9
20DD8 CJK UNIFIED IDEOGRAPH-#20DD8, IRGKangXi=0201.050, RSKangXi=30.9
20DD9 CJK UNIFIED IDEOGRAPH-#20DD9, IRGKangXi=0201.060, RSKangXi=30.9
20DDA CJK UNIFIED IDEOGRAPH-#20DDA, IRGKangXi=0201.070, RSKangXi=30.9
20DDB CJK UNIFIED IDEOGRAPH-#20DDB, IRGKangXi=0201.080, RSKangXi=30.9
20DDC CJK UNIFIED IDEOGRAPH-#20DDC, IRGKangXi=0201.090, RSKangXi=30.9
20DDD CJK UNIFIED IDEOGRAPH-#20DDD, IRGKangXi=0201.100, RSKangXi=30.9
20DDE CJK UNIFIED IDEOGRAPH-#20DDE, IRGKangXi=0201.110, RSKangXi=30.9
20DDF CJK UNIFIED IDEOGRAPH-#20DDF, IRGKangXi=0201.120, RSKangXi=30.9
20DE0 CJK UNIFIED IDEOGRAPH-#20DE0, IRGKangXi=0201.121, RSKangXi=30.9
20DE1 CJK UNIFIED IDEOGRAPH-#20DE1, IRGKangXi=0201.121, RSKangXi=30.9
20DE2 CJK UNIFIED IDEOGRAPH-#20DE2, IRGKangXi=0201.121, RSKangXi=30.9
20DE3 CJK UNIFIED IDEOGRAPH-#20DE3, IRGKangXi=0201.121, RSKangXi=30.9
20DE4 CJK UNIFIED IDEOGRAPH-#20DE4, IRGKangXi=0201.121, RSKangXi=30.9
20DE5 CJK UNIFIED IDEOGRAPH-#20DE5, IRGKangXi=0201.121, RSKangXi=30.9
20DE6 CJK UNIFIED IDEOGRAPH-#20DE6, IRGKangXi=0201.121, RSKangXi=30.9
20DE7 CJK UNIFIED IDEOGRAPH-#20DE7, IRGKangXi=0201.121, RSKangXi=30.9
20DE8 CJK UNIFIED IDEOGRAPH-#20DE8, IRGKangXi=0201.121, RSKangXi=30.9
20DE9 CJK UNIFIED IDEOGRAPH-#20DE9, IRGKangXi=0201.121, RSKangXi=30.9
20DEA CJK UNIFIED IDEOGRAPH-#20DEA, IRGKangXi=0201.121, RSKangXi=30.9
20DEB CJK UNIFIED IDEOGRAPH-#20DEB, IRGKangXi=0201.121, RSKangXi=30.9
20DEC CJK UNIFIED IDEOGRAPH-#20DEC, IRGKangXi=0201.121, RSKangXi=30.9
20DED CJK UNIFIED IDEOGRAPH-#20DED, IRGKangXi=0201.121, RSKangXi=30.9
20DEE CJK UNIFIED IDEOGRAPH-#20DEE, IRGKangXi=0201.121, RSKangXi=30.9
20DEF CJK UNIFIED IDEOGRAPH-#20DEF, IRGKangXi=0201.121, RSKangXi=30.9
20DF0 CJK UNIFIED IDEOGRAPH-#20DF0, IRGKangXi=0201.121, RSKangXi=30.9
20DF1 CJK UNIFIED IDEOGRAPH-#20DF1, IRGKangXi=0201.121, RSKangXi=30.9
20DF2 CJK UNIFIED IDEOGRAPH-#20DF2, IRGKangXi=0201.121, RSKangXi=30.9
20DF3 CJK UNIFIED IDEOGRAPH-#20DF3, IRGKangXi=0201.121, RSKangXi=30.9
20DF4 CJK UNIFIED IDEOGRAPH-#20DF4, IRGKangXi=0201.121, RSKangXi=30.9
20DF5 CJK UNIFIED IDEOGRAPH-#20DF5, IRGKangXi=0201.121, RSKangXi=30.9
20DF6 CJK UNIFIED IDEOGRAPH-#20DF6, IRGKangXi=0201.121, RSKangXi=30.9
20DF7 CJK UNIFIED IDEOGRAPH-#20DF7, IRGKangXi=0201.121, RSKangXi=30.9
20DF8 CJK UNIFIED IDEOGRAPH-#20DF8, IRGKangXi=0201.121, RSKangXi=30.9
20DF9 CJK UNIFIED IDEOGRAPH-#20DF9, IRGKangXi=0201.121, RSKangXi=30.9
20DFA CJK UNIFIED IDEOGRAPH-#20DFA, IRGKangXi=0201.121, RSKangXi=30.9
20DFB CJK UNIFIED IDEOGRAPH-#20DFB, IRGKangXi=0201.121, RSKangXi=30.9
20DFC CJK UNIFIED IDEOGRAPH-#20DFC, IRGKangXi=0201.121, RSKangXi=30.9
20DFD CJK UNIFIED IDEOGRAPH-#20DFD, IRGKangXi=0201.121, RSKangXi=30.9
20DFE CJK UNIFIED IDEOGRAPH-#20DFE, IRGKangXi=0201.121, RSKangXi=30.9
20DFF CJK UNIFIED IDEOGRAPH-#20DFF, IRGKangXi=0201.121, RSKangXi=30.9
20E00 CJK UNIFIED IDEOGRAPH-#20E00, IRGKangXi=0201.121, RSKangXi=30.9
20E01 CJK UNIFIED IDEOGRAPH-#20E01, IRGKangXi=0201.121, RSKangXi=30.9
20E02 CJK UNIFIED IDEOGRAPH-#20E02, IRGKangXi=0201.121, RSKangXi=30.9
20E03 CJK UNIFIED IDEOGRAPH-#20E03, IRGKangXi=0201.121, RSKangXi=30.9
20E04 CJK UNIFIED IDEOGRAPH-#20E04, IRGKangXi=0201.121, RSKangXi=30.9
20E05 CJK UNIFIED IDEOGRAPH-#20E05, IRGKangXi=0201.121, RSKangXi=30.9
20E06 CJK UNIFIED IDEOGRAPH-#20E06, IRGKangXi=0201.121, RSKangXi=30.9
20E07 CJK UNIFIED IDEOGRAPH-#20E07, IRGKangXi=0201.121, RSKangXi=30.9
20E08 CJK UNIFIED IDEOGRAPH-#20E08, IRGKangXi=0201.121, RSKangXi=30.9
20E09 CJK UNIFIED IDEOGRAPH-#20E09, IRGKangXi=0201.121, RSKangXi=30.9, Def{(Cant.) to block, obstruct}
20E0A CJK UNIFIED IDEOGRAPH-#20E0A, IRGKangXi=0201.121, RSKangXi=30.9, Def{(Cant.) an intensifying particle}
20E0B CJK UNIFIED IDEOGRAPH-#20E0B, IRGKangXi=0201.121, RSKangXi=30.9
20E0C CJK UNIFIED IDEOGRAPH-#20E0C, IRGKangXi=0201.121, RSKangXi=30.9
20E0D CJK UNIFIED IDEOGRAPH-#20E0D, IRGKangXi=0201.121, RSKangXi=30.9
20E0E CJK UNIFIED IDEOGRAPH-#20E0E, IRGKangXi=0201.121, RSKangXi=30.9, Def{(Cant.) and, with}
20E0F CJK UNIFIED IDEOGRAPH-#20E0F, IRGKangXi=0201.121, RSKangXi=30.9, Def{(Cant.) final particle}
20E10 CJK UNIFIED IDEOGRAPH-#20E10, IRGKangXi=0201.121, RSKangXi=30.9, Def{(Cant.) to endure, last}
20E11 CJK UNIFIED IDEOGRAPH-#20E11, IRGKangXi=0201.121, RSKangXi=30.9, Def{(Cant.) soft, sodden}
20E12 CJK UNIFIED IDEOGRAPH-#20E12, IRGKangXi=0201.121, RSKangXi=30.9, Def{(Cant.) 生𠸒人, a stranger}
20E13 CJK UNIFIED IDEOGRAPH-#20E13, IRGKangXi=0201.121, RSKangXi=30.9
20E14 CJK UNIFIED IDEOGRAPH-#20E14, IRGKangXi=0201.121, RSKangXi=30.9
20E15 CJK UNIFIED IDEOGRAPH-#20E15, IRGKangXi=0201.121, RSKangXi=30.9
20E16 CJK UNIFIED IDEOGRAPH-#20E16, IRGKangXi=0201.121, RSKangXi=30.9
20E17 CJK UNIFIED IDEOGRAPH-#20E17, IRGKangXi=0201.121, RSKangXi=30.9
20E18 CJK UNIFIED IDEOGRAPH-#20E18, IRGKangXi=0201.121, RSKangXi=30.9
20E19 CJK UNIFIED IDEOGRAPH-#20E19, IRGKangXi=0201.121, RSKangXi=30.9
20E1A CJK UNIFIED IDEOGRAPH-#20E1A, IRGKangXi=0201.121, RSKangXi=30.9
20E1B CJK UNIFIED IDEOGRAPH-#20E1B, IRGKangXi=0201.121, RSKangXi=30.9
20E1C CJK UNIFIED IDEOGRAPH-#20E1C, IRGKangXi=0201.121, RSKangXi=30.9
20E1D CJK UNIFIED IDEOGRAPH-#20E1D, IRGKangXi=0201.121, RSKangXi=30.9
20E1E CJK UNIFIED IDEOGRAPH-#20E1E, IRGKangXi=0201.121, RSKangXi=30.9
20E1F CJK UNIFIED IDEOGRAPH-#20E1F, IRGKangXi=0201.121, RSKangXi=30.9
20E20 CJK UNIFIED IDEOGRAPH-#20E20, IRGKangXi=0201.121, RSKangXi=30.9
20E21 CJK UNIFIED IDEOGRAPH-#20E21, IRGKangXi=0201.121, RSKangXi=30.9
20E22 CJK UNIFIED IDEOGRAPH-#20E22, IRGKangXi=0201.121, RSKangXi=30.9
20E23 CJK UNIFIED IDEOGRAPH-#20E23, IRGKangXi=0201.121, RSKangXi=30.9
20E24 CJK UNIFIED IDEOGRAPH-#20E24, IRGKangXi=0201.121, RSKangXi=30.9
20E25 CJK UNIFIED IDEOGRAPH-#20E25, IRGKangXi=0201.121, RSKangXi=30.9
20E26 CJK UNIFIED IDEOGRAPH-#20E26, IRGKangXi=0201.121, RSKangXi=30.9
20E27 CJK UNIFIED IDEOGRAPH-#20E27, IRGKangXi=0201.121, RSKangXi=30.9
20E28 CJK UNIFIED IDEOGRAPH-#20E28, IRGKangXi=0201.121, RSKangXi=30.9
20E29 CJK UNIFIED IDEOGRAPH-#20E29, IRGKangXi=0201.121, RSKangXi=30.9
20E2A CJK UNIFIED IDEOGRAPH-#20E2A, IRGKangXi=0201.121, RSKangXi=30.9
20E2B CJK UNIFIED IDEOGRAPH-#20E2B, IRGKangXi=0201.121, RSKangXi=30.9
20E2C CJK UNIFIED IDEOGRAPH-#20E2C, IRGKangXi=0201.121, RSKangXi=30.9
20E2D CJK UNIFIED IDEOGRAPH-#20E2D, IRGKangXi=0201.121, RSKangXi=30.9
20E2E CJK UNIFIED IDEOGRAPH-#20E2E, IRGKangXi=0201.121, RSKangXi=30.9
20E2F CJK UNIFIED IDEOGRAPH-#20E2F, IRGKangXi=0201.121, RSKangXi=30.9
20E30 CJK UNIFIED IDEOGRAPH-#20E30, IRGKangXi=0201.121, RSKangXi=30.9
20E31 CJK UNIFIED IDEOGRAPH-#20E31, IRGKangXi=0201.121, RSKangXi=30.9
20E32 CJK UNIFIED IDEOGRAPH-#20E32, IRGKangXi=0201.121, RSKangXi=30.9
20E33 CJK UNIFIED IDEOGRAPH-#20E33, IRGKangXi=0201.121, RSKangXi=30.9
20E34 CJK UNIFIED IDEOGRAPH-#20E34, IRGKangXi=0201.121, RSKangXi=30.9
20E35 CJK UNIFIED IDEOGRAPH-#20E35, IRGKangXi=0201.121, RSKangXi=30.9
20E36 CJK UNIFIED IDEOGRAPH-#20E36, IRGKangXi=0201.130, RSKangXi=30.10
20E37 CJK UNIFIED IDEOGRAPH-#20E37, IRGKangXi=0201.140, RSKangXi=30.10
20E38 CJK UNIFIED IDEOGRAPH-#20E38, IRGKangXi=0201.150, RSKangXi=30.10
20E39 CJK UNIFIED IDEOGRAPH-#20E39, IRGKangXi=0201.190, RSKangXi=30.10
20E3A CJK UNIFIED IDEOGRAPH-#20E3A, IRGKangXi=0201.210, RSKangXi=30.10, Def{(Cant.) contrary, opposing}
20E3B CJK UNIFIED IDEOGRAPH-#20E3B, IRGKangXi=0201.211, RSKangXi=30.9
20E3C CJK UNIFIED IDEOGRAPH-#20E3C, IRGKangXi=0201.211, RSKangXi=30.9
20E3D CJK UNIFIED IDEOGRAPH-#20E3D, IRGKangXi=0201.211, RSKangXi=30.9
20E3E CJK UNIFIED IDEOGRAPH-#20E3E, IRGKangXi=0201.211, RSKangXi=30.9
20E3F CJK UNIFIED IDEOGRAPH-#20E3F, IRGKangXi=0201.230, RSKangXi=30.10
20E40 CJK UNIFIED IDEOGRAPH-#20E40, IRGKangXi=0201.250, RSKangXi=30.10
20E41 CJK UNIFIED IDEOGRAPH-#20E41, IRGKangXi=0201.260, RSKangXi=30.10
20E42 CJK UNIFIED IDEOGRAPH-#20E42, IRGKangXi=0201.270, RSKangXi=30.10
20E43 CJK UNIFIED IDEOGRAPH-#20E43, IRGKangXi=0201.290, RSKangXi=30.10
20E44 CJK UNIFIED IDEOGRAPH-#20E44, IRGKangXi=0201.300, RSKangXi=30.10
20E45 CJK UNIFIED IDEOGRAPH-#20E45, IRGKangXi=0201.310, RSKangXi=30.10
20E46 CJK UNIFIED IDEOGRAPH-#20E46, IRGKangXi=0201.320, RSKangXi=30.10
20E47 CJK UNIFIED IDEOGRAPH-#20E47, IRGKangXi=0201.330, RSKangXi=30.10
20E48 CJK UNIFIED IDEOGRAPH-#20E48, IRGKangXi=0202.010, RSKangXi=30.10
20E49 CJK UNIFIED IDEOGRAPH-#20E49, IRGKangXi=0202.020, RSKangXi=30.10
20E4A CJK UNIFIED IDEOGRAPH-#20E4A, IRGKangXi=0202.110, RSKangXi=30.10
20E4B CJK UNIFIED IDEOGRAPH-#20E4B, IRGKangXi=0202.120, RSKangXi=30.10
20E4C CJK UNIFIED IDEOGRAPH-#20E4C, IRGKangXi=0202.170, RSKangXi=30.10, Def{(Cant.) uncommon, rare; penis (vulg.)}
20E4D CJK UNIFIED IDEOGRAPH-#20E4D, IRGKangXi=0202.180, RSKangXi=30.10
20E4E CJK UNIFIED IDEOGRAPH-#20E4E, IRGKangXi=0202.270, RSKangXi=30.10
20E4F CJK UNIFIED IDEOGRAPH-#20E4F, IRGKangXi=0202.280, RSKangXi=30.10
20E50 CJK UNIFIED IDEOGRAPH-#20E50, IRGKangXi=0202.290, RSKangXi=30.10
20E51 CJK UNIFIED IDEOGRAPH-#20E51, IRGKangXi=0202.320, RSKangXi=30.10
20E52 CJK UNIFIED IDEOGRAPH-#20E52, IRGKangXi=0202.330, RSKangXi=30.10
20E53 CJK UNIFIED IDEOGRAPH-#20E53, IRGKangXi=0202.340, RSKangXi=30.10
20E54 CJK UNIFIED IDEOGRAPH-#20E54, IRGKangXi=0203.040, RSKangXi=30.10
20E55 CJK UNIFIED IDEOGRAPH-#20E55, IRGKangXi=0203.080, RSKangXi=30.10
20E56 CJK UNIFIED IDEOGRAPH-#20E56, IRGKangXi=0203.090, RSKangXi=30.10
20E57 CJK UNIFIED IDEOGRAPH-#20E57, IRGKangXi=0203.100, RSKangXi=30.10
20E58 CJK UNIFIED IDEOGRAPH-#20E58, IRGKangXi=0203.110, RSKangXi=30.10
20E59 CJK UNIFIED IDEOGRAPH-#20E59, IRGKangXi=0203.120, RSKangXi=30.10
20E5A CJK UNIFIED IDEOGRAPH-#20E5A, IRGKangXi=0203.130, RSKangXi=30.10
20E5B CJK UNIFIED IDEOGRAPH-#20E5B, IRGKangXi=0203.140, RSKangXi=30.10
20E5C CJK UNIFIED IDEOGRAPH-#20E5C, IRGKangXi=0203.160, RSKangXi=30.10
20E5D CJK UNIFIED IDEOGRAPH-#20E5D, IRGKangXi=0203.170, RSKangXi=30.10
20E5E CJK UNIFIED IDEOGRAPH-#20E5E, IRGKangXi=0203.240, RSKangXi=30.10
20E5F CJK UNIFIED IDEOGRAPH-#20E5F, IRGKangXi=0203.260, RSKangXi=30.10
20E60 CJK UNIFIED IDEOGRAPH-#20E60, IRGKangXi=0203.290, RSKangXi=30.10
20E61 CJK UNIFIED IDEOGRAPH-#20E61, IRGKangXi=0204.010, RSKangXi=30.10
20E62 CJK UNIFIED IDEOGRAPH-#20E62, IRGKangXi=0204.020, RSKangXi=30.10
20E63 CJK UNIFIED IDEOGRAPH-#20E63, IRGKangXi=0204.040, RSKangXi=30.10
20E64 CJK UNIFIED IDEOGRAPH-#20E64, IRGKangXi=0204.050, RSKangXi=30.10
20E65 CJK UNIFIED IDEOGRAPH-#20E65, IRGKangXi=0204.060, RSKangXi=30.10
20E66 CJK UNIFIED IDEOGRAPH-#20E66, IRGKangXi=0204.070, RSKangXi=30.10
20E67 CJK UNIFIED IDEOGRAPH-#20E67, IRGKangXi=0204.080, RSKangXi=30.10
20E68 CJK UNIFIED IDEOGRAPH-#20E68, IRGKangXi=0204.090, RSKangXi=30.10
20E69 CJK UNIFIED IDEOGRAPH-#20E69, IRGKangXi=0204.100, RSKangXi=30.10
20E6A CJK UNIFIED IDEOGRAPH-#20E6A, IRGKangXi=0204.110, RSKangXi=30.10
20E6B CJK UNIFIED IDEOGRAPH-#20E6B, IRGKangXi=0204.111, RSKangXi=30.10
20E6C CJK UNIFIED IDEOGRAPH-#20E6C, IRGKangXi=0204.111, RSKangXi=30.10
20E6D CJK UNIFIED IDEOGRAPH-#20E6D, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) to call (Engl. loan-word)}
20E6E CJK UNIFIED IDEOGRAPH-#20E6E, IRGKangXi=0204.111, RSKangXi=30.10
20E6F CJK UNIFIED IDEOGRAPH-#20E6F, IRGKangXi=0204.111, RSKangXi=30.10
20E70 CJK UNIFIED IDEOGRAPH-#20E70, IRGKangXi=0204.111, RSKangXi=30.12
20E71 CJK UNIFIED IDEOGRAPH-#20E71, IRGKangXi=0204.111, RSKangXi=30.12
20E72 CJK UNIFIED IDEOGRAPH-#20E72, IRGKangXi=0204.111, RSKangXi=30.12
20E73 CJK UNIFIED IDEOGRAPH-#20E73, IRGKangXi=0204.111, RSKangXi=30.12, Def{(Cant.) thick, viscous, dense}
20E74 CJK UNIFIED IDEOGRAPH-#20E74, IRGKangXi=0204.111, RSKangXi=30.10
20E75 CJK UNIFIED IDEOGRAPH-#20E75, IRGKangXi=0204.111, RSKangXi=30.10
20E76 CJK UNIFIED IDEOGRAPH-#20E76, IRGKangXi=0204.111, RSKangXi=30.10
20E77 CJK UNIFIED IDEOGRAPH-#20E77, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) to speak tirelessly}
20E78 CJK UNIFIED IDEOGRAPH-#20E78, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) to cover, close up}
20E79 CJK UNIFIED IDEOGRAPH-#20E79, IRGKangXi=0204.111, RSKangXi=30.10, Def{to hurry}
20E7A CJK UNIFIED IDEOGRAPH-#20E7A, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) verbal aspect marker for comletion or movement towards}
20E7B CJK UNIFIED IDEOGRAPH-#20E7B, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) classifier for smells}
20E7C CJK UNIFIED IDEOGRAPH-#20E7C, IRGKangXi=0204.111, RSKangXi=30.10
20E7D CJK UNIFIED IDEOGRAPH-#20E7D, IRGKangXi=0204.111, RSKangXi=30.10
20E7E CJK UNIFIED IDEOGRAPH-#20E7E, IRGKangXi=0204.111, RSKangXi=30.10
20E7F CJK UNIFIED IDEOGRAPH-#20E7F, IRGKangXi=0204.111, RSKangXi=30.10
20E80 CJK UNIFIED IDEOGRAPH-#20E80, IRGKangXi=0204.111, RSKangXi=30.10
20E81 CJK UNIFIED IDEOGRAPH-#20E81, IRGKangXi=0204.111, RSKangXi=30.10
20E82 CJK UNIFIED IDEOGRAPH-#20E82, IRGKangXi=0204.111, RSKangXi=30.10
20E83 CJK UNIFIED IDEOGRAPH-#20E83, IRGKangXi=0204.111, RSKangXi=30.10
20E84 CJK UNIFIED IDEOGRAPH-#20E84, IRGKangXi=0204.111, RSKangXi=30.10
20E85 CJK UNIFIED IDEOGRAPH-#20E85, IRGKangXi=0204.111, RSKangXi=30.10
20E86 CJK UNIFIED IDEOGRAPH-#20E86, IRGKangXi=0204.111, RSKangXi=30.10
20E87 CJK UNIFIED IDEOGRAPH-#20E87, IRGKangXi=0204.111, RSKangXi=30.10
20E88 CJK UNIFIED IDEOGRAPH-#20E88, IRGKangXi=0204.111, RSKangXi=30.10
20E89 CJK UNIFIED IDEOGRAPH-#20E89, IRGKangXi=0204.111, RSKangXi=30.10
20E8A CJK UNIFIED IDEOGRAPH-#20E8A, IRGKangXi=0204.111, RSKangXi=30.10
20E8B CJK UNIFIED IDEOGRAPH-#20E8B, IRGKangXi=0204.111, RSKangXi=30.10
20E8C CJK UNIFIED IDEOGRAPH-#20E8C, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) timid}
20E8D CJK UNIFIED IDEOGRAPH-#20E8D, IRGKangXi=0204.111, RSKangXi=30.10
20E8E CJK UNIFIED IDEOGRAPH-#20E8E, IRGKangXi=0204.111, RSKangXi=30.10
20E8F CJK UNIFIED IDEOGRAPH-#20E8F, IRGKangXi=0204.111, RSKangXi=30.10
20E90 CJK UNIFIED IDEOGRAPH-#20E90, IRGKangXi=0204.111, RSKangXi=30.10
20E91 CJK UNIFIED IDEOGRAPH-#20E91, IRGKangXi=0204.111, RSKangXi=30.10
20E92 CJK UNIFIED IDEOGRAPH-#20E92, IRGKangXi=0204.111, RSKangXi=30.10
20E93 CJK UNIFIED IDEOGRAPH-#20E93, IRGKangXi=0204.111, RSKangXi=30.10
20E94 CJK UNIFIED IDEOGRAPH-#20E94, IRGKangXi=0204.111, RSKangXi=30.10
20E95 CJK UNIFIED IDEOGRAPH-#20E95, IRGKangXi=0204.111, RSKangXi=30.10
20E96 CJK UNIFIED IDEOGRAPH-#20E96, IRGKangXi=0204.111, RSKangXi=30.10
20E97 CJK UNIFIED IDEOGRAPH-#20E97, IRGKangXi=0204.111, RSKangXi=30.10
20E98 CJK UNIFIED IDEOGRAPH-#20E98, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) hard to get along with; to rinse, spread thin}
20E99 CJK UNIFIED IDEOGRAPH-#20E99, IRGKangXi=0204.111, RSKangXi=30.10
20E9A CJK UNIFIED IDEOGRAPH-#20E9A, IRGKangXi=0204.111, RSKangXi=30.10
20E9B CJK UNIFIED IDEOGRAPH-#20E9B, IRGKangXi=0204.111, RSKangXi=30.10
20E9C CJK UNIFIED IDEOGRAPH-#20E9C, IRGKangXi=0204.111, RSKangXi=30.10
20E9D CJK UNIFIED IDEOGRAPH-#20E9D, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) final particle}
20E9E CJK UNIFIED IDEOGRAPH-#20E9E, IRGKangXi=0204.111, RSKangXi=30.10
20E9F CJK UNIFIED IDEOGRAPH-#20E9F, IRGKangXi=0204.111, RSKangXi=30.10
20EA0 CJK UNIFIED IDEOGRAPH-#20EA0, IRGKangXi=0204.111, RSKangXi=30.10
20EA1 CJK UNIFIED IDEOGRAPH-#20EA1, IRGKangXi=0204.111, RSKangXi=30.10
20EA2 CJK UNIFIED IDEOGRAPH-#20EA2, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) final particle}
20EA3 CJK UNIFIED IDEOGRAPH-#20EA3, IRGKangXi=0204.111, RSKangXi=30.10
20EA4 CJK UNIFIED IDEOGRAPH-#20EA4, IRGKangXi=0204.111, RSKangXi=30.10
20EA5 CJK UNIFIED IDEOGRAPH-#20EA5, IRGKangXi=0204.111, RSKangXi=30.10
20EA6 CJK UNIFIED IDEOGRAPH-#20EA6, IRGKangXi=0204.111, RSKangXi=30.10
20EA7 CJK UNIFIED IDEOGRAPH-#20EA7, IRGKangXi=0204.111, RSKangXi=30.10
20EA8 CJK UNIFIED IDEOGRAPH-#20EA8, IRGKangXi=0204.111, RSKangXi=30.10
20EA9 CJK UNIFIED IDEOGRAPH-#20EA9, IRGKangXi=0204.111, RSKangXi=30.10
20EAA CJK UNIFIED IDEOGRAPH-#20EAA, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) in a rush; slovenly}
20EAB CJK UNIFIED IDEOGRAPH-#20EAB, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) strange, peculiar}
20EAC CJK UNIFIED IDEOGRAPH-#20EAC, IRGKangXi=0204.111, RSKangXi=30.10, Def{(Cant.) final particle}
20EAD CJK UNIFIED IDEOGRAPH-#20EAD, IRGKangXi=0204.111, RSKangXi=30.10
20EAE CJK UNIFIED IDEOGRAPH-#20EAE, IRGKangXi=0204.111, RSKangXi=30.10
20EAF CJK UNIFIED IDEOGRAPH-#20EAF, IRGKangXi=0204.111, RSKangXi=30.10
20EB0 CJK UNIFIED IDEOGRAPH-#20EB0, IRGKangXi=0204.111, RSKangXi=30.10
20EB1 CJK UNIFIED IDEOGRAPH-#20EB1, IRGKangXi=0204.111, RSKangXi=30.10
20EB2 CJK UNIFIED IDEOGRAPH-#20EB2, IRGKangXi=0204.111, RSKangXi=30.10
20EB3 CJK UNIFIED IDEOGRAPH-#20EB3, IRGKangXi=0204.111, RSKangXi=30.10
20EB4 CJK UNIFIED IDEOGRAPH-#20EB4, IRGKangXi=0204.111, RSKangXi=30.10
20EB5 CJK UNIFIED IDEOGRAPH-#20EB5, IRGKangXi=0204.111, RSKangXi=30.10
20EB6 CJK UNIFIED IDEOGRAPH-#20EB6, IRGKangXi=0204.111, RSKangXi=30.10
20EB7 CJK UNIFIED IDEOGRAPH-#20EB7, IRGKangXi=0204.111, RSKangXi=30.10
20EB8 CJK UNIFIED IDEOGRAPH-#20EB8, IRGKangXi=0204.111, RSKangXi=30.10
20EB9 CJK UNIFIED IDEOGRAPH-#20EB9, IRGKangXi=0204.111, RSKangXi=30.10
20EBA CJK UNIFIED IDEOGRAPH-#20EBA, IRGKangXi=0204.111, RSKangXi=30.10
20EBB CJK UNIFIED IDEOGRAPH-#20EBB, IRGKangXi=0204.111, RSKangXi=30.10
20EBC CJK UNIFIED IDEOGRAPH-#20EBC, IRGKangXi=0204.111, RSKangXi=30.10
20EBD CJK UNIFIED IDEOGRAPH-#20EBD, IRGKangXi=0204.111, RSKangXi=30.10
20EBE CJK UNIFIED IDEOGRAPH-#20EBE, IRGKangXi=0204.111, RSKangXi=30.10
20EBF CJK UNIFIED IDEOGRAPH-#20EBF, IRGKangXi=0204.111, RSKangXi=30.10
20EC0 CJK UNIFIED IDEOGRAPH-#20EC0, IRGKangXi=0204.111, RSKangXi=30.10
20EC1 CJK UNIFIED IDEOGRAPH-#20EC1, IRGKangXi=0204.111, RSKangXi=30.10
20EC2 CJK UNIFIED IDEOGRAPH-#20EC2, IRGKangXi=0204.111, RSKangXi=30.10
20EC3 CJK UNIFIED IDEOGRAPH-#20EC3, IRGKangXi=0204.111, RSKangXi=30.10
20EC4 CJK UNIFIED IDEOGRAPH-#20EC4, IRGKangXi=0204.111, RSKangXi=30.10
20EC5 CJK UNIFIED IDEOGRAPH-#20EC5, IRGKangXi=0204.111, RSKangXi=30.10
20EC6 CJK UNIFIED IDEOGRAPH-#20EC6, IRGKangXi=0204.111, RSKangXi=30.10
20EC7 CJK UNIFIED IDEOGRAPH-#20EC7, IRGKangXi=0204.111, RSKangXi=30.10
20EC8 CJK UNIFIED IDEOGRAPH-#20EC8, IRGKangXi=0204.111, RSKangXi=30.10
20EC9 CJK UNIFIED IDEOGRAPH-#20EC9, IRGKangXi=0204.111, RSKangXi=30.10
20ECA CJK UNIFIED IDEOGRAPH-#20ECA, IRGKangXi=0204.111, RSKangXi=30.10
20ECB CJK UNIFIED IDEOGRAPH-#20ECB, IRGKangXi=0204.111, RSKangXi=30.10
20ECC CJK UNIFIED IDEOGRAPH-#20ECC, IRGKangXi=0204.111, RSKangXi=30.10
20ECD CJK UNIFIED IDEOGRAPH-#20ECD, IRGKangXi=0204.111, RSKangXi=30.10
20ECE CJK UNIFIED IDEOGRAPH-#20ECE, IRGKangXi=0204.111, RSKangXi=30.10
20ECF CJK UNIFIED IDEOGRAPH-#20ECF, IRGKangXi=0204.111, RSKangXi=30.10
20ED0 CJK UNIFIED IDEOGRAPH-#20ED0, IRGKangXi=0204.111, RSKangXi=30.10
20ED1 CJK UNIFIED IDEOGRAPH-#20ED1, IRGKangXi=0204.111, RSKangXi=30.10
20ED2 CJK UNIFIED IDEOGRAPH-#20ED2, IRGKangXi=0204.111, RSKangXi=30.10
20ED3 CJK UNIFIED IDEOGRAPH-#20ED3, IRGKangXi=0204.111, RSKangXi=30.10
20ED4 CJK UNIFIED IDEOGRAPH-#20ED4, IRGKangXi=0204.130, RSKangXi=30.11
20ED5 CJK UNIFIED IDEOGRAPH-#20ED5, IRGKangXi=0204.140, RSKangXi=30.11
20ED6 CJK UNIFIED IDEOGRAPH-#20ED6, IRGKangXi=0204.170, RSKangXi=30.11
20ED7 CJK UNIFIED IDEOGRAPH-#20ED7, IRGKangXi=0204.190, RSKangXi=30.11, Def{(Cant.) imperative final particle}
20ED8 CJK UNIFIED IDEOGRAPH-#20ED8, IRGKangXi=0204.200, RSKangXi=30.11, Def{(Cant.) sound of eating (onomatopoetic)}
20ED9 CJK UNIFIED IDEOGRAPH-#20ED9, IRGKangXi=0204.230, RSKangXi=30.11
20EDA CJK UNIFIED IDEOGRAPH-#20EDA, IRGKangXi=0204.260, RSKangXi=30.11
20EDB CJK UNIFIED IDEOGRAPH-#20EDB, IRGKangXi=0204.300, RSKangXi=30.11
20EDC CJK UNIFIED IDEOGRAPH-#20EDC, IRGKangXi=0204.310, RSKangXi=30.11
20EDD CJK UNIFIED IDEOGRAPH-#20EDD, IRGKangXi=0204.320, RSKangXi=30.11
20EDE CJK UNIFIED IDEOGRAPH-#20EDE, IRGKangXi=0204.340, RSKangXi=30.11
20EDF CJK UNIFIED IDEOGRAPH-#20EDF, IRGKangXi=0204.350, RSKangXi=30.11
20EE0 CJK UNIFIED IDEOGRAPH-#20EE0, IRGKangXi=0204.420, RSKangXi=30.11
20EE1 CJK UNIFIED IDEOGRAPH-#20EE1, IRGKangXi=0205.050, RSKangXi=30.11
20EE2 CJK UNIFIED IDEOGRAPH-#20EE2, IRGKangXi=0205.100, RSKangXi=30.11
20EE3 CJK UNIFIED IDEOGRAPH-#20EE3, IRGKangXi=0205.160, RSKangXi=30.11
20EE4 CJK UNIFIED IDEOGRAPH-#20EE4, IRGKangXi=0205.170, RSKangXi=30.11
20EE5 CJK UNIFIED IDEOGRAPH-#20EE5, IRGKangXi=0205.180, RSKangXi=30.11
20EE6 CJK UNIFIED IDEOGRAPH-#20EE6, IRGKangXi=0205.200, RSKangXi=30.11
20EE7 CJK UNIFIED IDEOGRAPH-#20EE7, IRGKangXi=0205.230, RSKangXi=30.11
20EE8 CJK UNIFIED IDEOGRAPH-#20EE8, IRGKangXi=0206.030, RSKangXi=30.11
20EE9 CJK UNIFIED IDEOGRAPH-#20EE9, IRGKangXi=0206.050, RSKangXi=30.11
20EEA CJK UNIFIED IDEOGRAPH-#20EEA, IRGKangXi=0206.070, RSKangXi=30.11
20EEB CJK UNIFIED IDEOGRAPH-#20EEB, IRGKangXi=0206.120, RSKangXi=30.11
20EEC CJK UNIFIED IDEOGRAPH-#20EEC, IRGKangXi=0206.130, RSKangXi=30.11
20EED CJK UNIFIED IDEOGRAPH-#20EED, IRGKangXi=0206.150, RSKangXi=30.11
20EEE CJK UNIFIED IDEOGRAPH-#20EEE, IRGKangXi=0206.160, RSKangXi=30.11
20EEF CJK UNIFIED IDEOGRAPH-#20EEF, IRGKangXi=0206.170, RSKangXi=30.11
20EF0 CJK UNIFIED IDEOGRAPH-#20EF0, IRGKangXi=0206.180, RSKangXi=30.11
20EF1 CJK UNIFIED IDEOGRAPH-#20EF1, IRGKangXi=0206.200, RSKangXi=30.11
20EF2 CJK UNIFIED IDEOGRAPH-#20EF2, IRGKangXi=0206.201, RSKangXi=30.11
20EF3 CJK UNIFIED IDEOGRAPH-#20EF3, IRGKangXi=0206.201, RSKangXi=30.11
20EF4 CJK UNIFIED IDEOGRAPH-#20EF4, IRGKangXi=0206.201, RSKangXi=30.11, Def{(Cant.) to rinse}
20EF5 CJK UNIFIED IDEOGRAPH-#20EF5, IRGKangXi=0206.201, RSKangXi=30.11
20EF6 CJK UNIFIED IDEOGRAPH-#20EF6, IRGKangXi=0206.201, RSKangXi=30.11
20EF7 CJK UNIFIED IDEOGRAPH-#20EF7, IRGKangXi=0206.201, RSKangXi=30.11
20EF8 CJK UNIFIED IDEOGRAPH-#20EF8, IRGKangXi=0206.201, RSKangXi=30.11
20EF9 CJK UNIFIED IDEOGRAPH-#20EF9, IRGKangXi=0206.201, RSKangXi=30.11
20EFA CJK UNIFIED IDEOGRAPH-#20EFA, IRGKangXi=0206.201, RSKangXi=30.11, Def{(Cant.) final particle}
20EFB CJK UNIFIED IDEOGRAPH-#20EFB, IRGKangXi=0206.201, RSKangXi=30.11, Def{(Cant.) noise, clamor}
20EFC CJK UNIFIED IDEOGRAPH-#20EFC, IRGKangXi=0206.201, RSKangXi=30.11
20EFD CJK UNIFIED IDEOGRAPH-#20EFD, IRGKangXi=0206.201, RSKangXi=30.11
20EFE CJK UNIFIED IDEOGRAPH-#20EFE, IRGKangXi=0206.201, RSKangXi=30.11
20EFF CJK UNIFIED IDEOGRAPH-#20EFF, IRGKangXi=0206.201, RSKangXi=30.11
20F00 CJK UNIFIED IDEOGRAPH-#20F00, IRGKangXi=0206.201, RSKangXi=30.11
20F01 CJK UNIFIED IDEOGRAPH-#20F01, IRGKangXi=0206.201, RSKangXi=30.11
20F02 CJK UNIFIED IDEOGRAPH-#20F02, IRGKangXi=0206.201, RSKangXi=30.11
20F03 CJK UNIFIED IDEOGRAPH-#20F03, IRGKangXi=0206.201, RSKangXi=30.11
20F04 CJK UNIFIED IDEOGRAPH-#20F04, IRGKangXi=0206.201, RSKangXi=30.11
20F05 CJK UNIFIED IDEOGRAPH-#20F05, IRGKangXi=0206.201, RSKangXi=30.11
20F06 CJK UNIFIED IDEOGRAPH-#20F06, IRGKangXi=0206.201, RSKangXi=30.11
20F07 CJK UNIFIED IDEOGRAPH-#20F07, IRGKangXi=0206.201, RSKangXi=30.11
20F08 CJK UNIFIED IDEOGRAPH-#20F08, IRGKangXi=0206.201, RSKangXi=30.11
20F09 CJK UNIFIED IDEOGRAPH-#20F09, IRGKangXi=0206.201, RSKangXi=30.11
20F0A CJK UNIFIED IDEOGRAPH-#20F0A, IRGKangXi=0206.201, RSKangXi=30.11
20F0B CJK UNIFIED IDEOGRAPH-#20F0B, IRGKangXi=0206.201, RSKangXi=30.11
20F0C CJK UNIFIED IDEOGRAPH-#20F0C, IRGKangXi=0206.201, RSKangXi=30.11
20F0D CJK UNIFIED IDEOGRAPH-#20F0D, IRGKangXi=0206.201, RSKangXi=30.11
20F0E CJK UNIFIED IDEOGRAPH-#20F0E, IRGKangXi=0206.201, RSKangXi=30.11
20F0F CJK UNIFIED IDEOGRAPH-#20F0F, IRGKangXi=0206.201, RSKangXi=30.11
20F10 CJK UNIFIED IDEOGRAPH-#20F10, IRGKangXi=0206.201, RSKangXi=30.11
20F11 CJK UNIFIED IDEOGRAPH-#20F11, IRGKangXi=0206.201, RSKangXi=30.11
20F12 CJK UNIFIED IDEOGRAPH-#20F12, IRGKangXi=0206.201, RSKangXi=30.11
20F13 CJK UNIFIED IDEOGRAPH-#20F13, IRGKangXi=0206.201, RSKangXi=30.11
20F14 CJK UNIFIED IDEOGRAPH-#20F14, IRGKangXi=0206.201, RSKangXi=30.11
20F15 CJK UNIFIED IDEOGRAPH-#20F15, IRGKangXi=0206.201, RSKangXi=30.11, Def{(Cant.) a suffix indicating time}
20F16 CJK UNIFIED IDEOGRAPH-#20F16, IRGKangXi=0206.201, RSKangXi=30.11
20F17 CJK UNIFIED IDEOGRAPH-#20F17, IRGKangXi=0206.201, RSKangXi=30.11, Def{to blink}
20F18 CJK UNIFIED IDEOGRAPH-#20F18, IRGKangXi=0206.201, RSKangXi=30.11
20F19 CJK UNIFIED IDEOGRAPH-#20F19, IRGKangXi=0206.201, RSKangXi=30.11
20F1A CJK UNIFIED IDEOGRAPH-#20F1A, IRGKangXi=0206.201, RSKangXi=30.11
20F1B CJK UNIFIED IDEOGRAPH-#20F1B, IRGKangXi=0206.201, RSKangXi=30.11
20F1C CJK UNIFIED IDEOGRAPH-#20F1C, IRGKangXi=0206.201, RSKangXi=30.11
20F1D CJK UNIFIED IDEOGRAPH-#20F1D, IRGKangXi=0206.201, RSKangXi=30.11
20F1E CJK UNIFIED IDEOGRAPH-#20F1E, IRGKangXi=0206.201, RSKangXi=30.11, Def{ammonia (obsolete)}
20F1F CJK UNIFIED IDEOGRAPH-#20F1F, IRGKangXi=0206.201, RSKangXi=30.11
20F20 CJK UNIFIED IDEOGRAPH-#20F20, IRGKangXi=0206.201, RSKangXi=30.11
20F21 CJK UNIFIED IDEOGRAPH-#20F21, IRGKangXi=0206.201, RSKangXi=30.11
20F22 CJK UNIFIED IDEOGRAPH-#20F22, IRGKangXi=0206.201, RSKangXi=30.11
20F23 CJK UNIFIED IDEOGRAPH-#20F23, IRGKangXi=0206.201, RSKangXi=30.11
20F24 CJK UNIFIED IDEOGRAPH-#20F24, IRGKangXi=0206.201, RSKangXi=30.11
20F25 CJK UNIFIED IDEOGRAPH-#20F25, IRGKangXi=0206.201, RSKangXi=30.11
20F26 CJK UNIFIED IDEOGRAPH-#20F26, IRGKangXi=0206.201, RSKangXi=30.11
20F27 CJK UNIFIED IDEOGRAPH-#20F27, IRGKangXi=0206.201, RSKangXi=30.11
20F28 CJK UNIFIED IDEOGRAPH-#20F28, IRGKangXi=0206.201, RSKangXi=30.11
20F29 CJK UNIFIED IDEOGRAPH-#20F29, IRGKangXi=0206.201, RSKangXi=30.11
20F2A CJK UNIFIED IDEOGRAPH-#20F2A, IRGKangXi=0206.201, RSKangXi=30.11
20F2B CJK UNIFIED IDEOGRAPH-#20F2B, IRGKangXi=0206.201, RSKangXi=30.11
20F2C CJK UNIFIED IDEOGRAPH-#20F2C, IRGKangXi=0206.201, RSKangXi=30.11
20F2D CJK UNIFIED IDEOGRAPH-#20F2D, IRGKangXi=0206.201, RSKangXi=30.11, Def{(Cant.) sound of a car-horn (onomatopoetic)}
20F2E CJK UNIFIED IDEOGRAPH-#20F2E, IRGKangXi=0206.201, RSKangXi=30.11, Def{(Cant.) to urge, importune; a lie, fib}
20F2F CJK UNIFIED IDEOGRAPH-#20F2F, IRGKangXi=0206.201, RSKangXi=30.11
20F30 CJK UNIFIED IDEOGRAPH-#20F30, IRGKangXi=0206.201, RSKangXi=30.11
20F31 CJK UNIFIED IDEOGRAPH-#20F31, IRGKangXi=0206.201, RSKangXi=30.11, Def{(Cant.) to spit out; to pester, nag}
20F32 CJK UNIFIED IDEOGRAPH-#20F32, IRGKangXi=0206.201, RSKangXi=30.11
20F33 CJK UNIFIED IDEOGRAPH-#20F33, IRGKangXi=0206.201, RSKangXi=30.11
20F34 CJK UNIFIED IDEOGRAPH-#20F34, IRGKangXi=0206.201, RSKangXi=30.11
20F35 CJK UNIFIED IDEOGRAPH-#20F35, IRGKangXi=0206.201, RSKangXi=30.11
20F36 CJK UNIFIED IDEOGRAPH-#20F36, IRGKangXi=0206.201, RSKangXi=30.11
20F37 CJK UNIFIED IDEOGRAPH-#20F37, IRGKangXi=0206.201, RSKangXi=30.11
20F38 CJK UNIFIED IDEOGRAPH-#20F38, IRGKangXi=0206.201, RSKangXi=30.11
20F39 CJK UNIFIED IDEOGRAPH-#20F39, IRGKangXi=0206.201, RSKangXi=30.11
20F3A CJK UNIFIED IDEOGRAPH-#20F3A, IRGKangXi=0206.201, RSKangXi=30.11
20F3B CJK UNIFIED IDEOGRAPH-#20F3B, IRGKangXi=0206.201, RSKangXi=30.11, Def{a particle used in transliteration}
20F3C CJK UNIFIED IDEOGRAPH-#20F3C, IRGKangXi=0206.201, RSKangXi=30.11
20F3D CJK UNIFIED IDEOGRAPH-#20F3D, IRGKangXi=0206.201, RSKangXi=30.11
20F3E CJK UNIFIED IDEOGRAPH-#20F3E, IRGKangXi=0206.201, RSKangXi=30.11
20F3F CJK UNIFIED IDEOGRAPH-#20F3F, IRGKangXi=0206.201, RSKangXi=30.11
20F40 CJK UNIFIED IDEOGRAPH-#20F40, IRGKangXi=0206.201, RSKangXi=30.11
20F41 CJK UNIFIED IDEOGRAPH-#20F41, IRGKangXi=0206.201, RSKangXi=30.11
20F42 CJK UNIFIED IDEOGRAPH-#20F42, IRGKangXi=0206.201, RSKangXi=30.11
20F43 CJK UNIFIED IDEOGRAPH-#20F43, IRGKangXi=0206.201, RSKangXi=30.11, Def{a handful, tuft}
20F44 CJK UNIFIED IDEOGRAPH-#20F44, IRGKangXi=0206.201, RSKangXi=30.11
20F45 CJK UNIFIED IDEOGRAPH-#20F45, IRGKangXi=0206.201, RSKangXi=30.11
20F46 CJK UNIFIED IDEOGRAPH-#20F46, IRGKangXi=0206.201, RSKangXi=30.11
20F47 CJK UNIFIED IDEOGRAPH-#20F47, IRGKangXi=0206.201, RSKangXi=30.11
20F48 CJK UNIFIED IDEOGRAPH-#20F48, IRGKangXi=0206.201, RSKangXi=30.11
20F49 CJK UNIFIED IDEOGRAPH-#20F49, IRGKangXi=0206.201, RSKangXi=30.11
20F4A CJK UNIFIED IDEOGRAPH-#20F4A, IRGKangXi=0206.201, RSKangXi=30.11
20F4B CJK UNIFIED IDEOGRAPH-#20F4B, IRGKangXi=0206.201, RSKangXi=30.11
20F4C CJK UNIFIED IDEOGRAPH-#20F4C, IRGKangXi=0206.201, RSKangXi=30.11, Def{(Cant.) sound of something rushing by}
20F4D CJK UNIFIED IDEOGRAPH-#20F4D, IRGKangXi=0206.201, RSKangXi=30.11
20F4E CJK UNIFIED IDEOGRAPH-#20F4E, IRGKangXi=0206.201, RSKangXi=30.11
20F4F CJK UNIFIED IDEOGRAPH-#20F4F, IRGKangXi=0206.201, RSKangXi=30.11
20F50 CJK UNIFIED IDEOGRAPH-#20F50, IRGKangXi=0206.201, RSKangXi=30.11
20F51 CJK UNIFIED IDEOGRAPH-#20F51, IRGKangXi=0206.201, RSKangXi=30.11
20F52 CJK UNIFIED IDEOGRAPH-#20F52, IRGKangXi=0206.201, RSKangXi=30.11, Def{(Cant.) classifier for hats}
20F53 CJK UNIFIED IDEOGRAPH-#20F53, IRGKangXi=0206.201, RSKangXi=30.11
20F54 CJK UNIFIED IDEOGRAPH-#20F54, IRGKangXi=0206.201, RSKangXi=30.11
20F55 CJK UNIFIED IDEOGRAPH-#20F55, IRGKangXi=0206.201, RSKangXi=30.11
20F56 CJK UNIFIED IDEOGRAPH-#20F56, IRGKangXi=0206.201, RSKangXi=30.11
20F57 CJK UNIFIED IDEOGRAPH-#20F57, IRGKangXi=0206.201, RSKangXi=30.11
20F58 CJK UNIFIED IDEOGRAPH-#20F58, IRGKangXi=0206.201, RSKangXi=30.11
20F59 CJK UNIFIED IDEOGRAPH-#20F59, IRGKangXi=0206.201, RSKangXi=30.11
20F5A CJK UNIFIED IDEOGRAPH-#20F5A, IRGKangXi=0206.201, RSKangXi=30.11
20F5B CJK UNIFIED IDEOGRAPH-#20F5B, IRGKangXi=0206.201, RSKangXi=30.11
20F5C CJK UNIFIED IDEOGRAPH-#20F5C, IRGKangXi=0206.201, RSKangXi=30.11
20F5D CJK UNIFIED IDEOGRAPH-#20F5D, IRGKangXi=0206.201, RSKangXi=30.11
20F5E CJK UNIFIED IDEOGRAPH-#20F5E, IRGKangXi=0206.201, RSKangXi=30.11
20F5F CJK UNIFIED IDEOGRAPH-#20F5F, IRGKangXi=0206.201, RSKangXi=30.11
20F60 CJK UNIFIED IDEOGRAPH-#20F60, IRGKangXi=0206.201, RSKangXi=30.11
20F61 CJK UNIFIED IDEOGRAPH-#20F61, IRGKangXi=0206.250, RSKangXi=30.12
20F62 CJK UNIFIED IDEOGRAPH-#20F62, IRGKangXi=0206.260, RSKangXi=30.12
20F63 CJK UNIFIED IDEOGRAPH-#20F63, IRGKangXi=0206.290, RSKangXi=30.12
20F64 CJK UNIFIED IDEOGRAPH-#20F64, IRGKangXi=0206.310, RSKangXi=30.12, Def{(Cant.) to block, obstruct; head; phonetic}
20F65 CJK UNIFIED IDEOGRAPH-#20F65, IRGKangXi=0207.020, RSKangXi=30.12
20F66 CJK UNIFIED IDEOGRAPH-#20F66, IRGKangXi=0207.040, RSKangXi=30.12
20F67 CJK UNIFIED IDEOGRAPH-#20F67, IRGKangXi=0207.050, RSKangXi=30.12
20F68 CJK UNIFIED IDEOGRAPH-#20F68, IRGKangXi=0207.070, RSKangXi=30.12
20F69 CJK UNIFIED IDEOGRAPH-#20F69, IRGKangXi=0207.110, RSKangXi=30.12
20F6A CJK UNIFIED IDEOGRAPH-#20F6A, IRGKangXi=0207.120, RSKangXi=30.12
20F6B CJK UNIFIED IDEOGRAPH-#20F6B, IRGKangXi=0207.150, RSKangXi=30.12
20F6C CJK UNIFIED IDEOGRAPH-#20F6C, IRGKangXi=0207.160, RSKangXi=30.12
20F6D CJK UNIFIED IDEOGRAPH-#20F6D, IRGKangXi=0207.190, RSKangXi=30.12
20F6E CJK UNIFIED IDEOGRAPH-#20F6E, IRGKangXi=0207.200, RSKangXi=30.12
20F6F CJK UNIFIED IDEOGRAPH-#20F6F, IRGKangXi=0207.210, RSKangXi=30.12
20F70 CJK UNIFIED IDEOGRAPH-#20F70, IRGKangXi=0207.220, RSKangXi=30.12
20F71 CJK UNIFIED IDEOGRAPH-#20F71, IRGKangXi=0207.250, RSKangXi=30.12
20F72 CJK UNIFIED IDEOGRAPH-#20F72, IRGKangXi=0207.260, RSKangXi=30.12
20F73 CJK UNIFIED IDEOGRAPH-#20F73, IRGKangXi=0207.270, RSKangXi=30.12
20F74 CJK UNIFIED IDEOGRAPH-#20F74, IRGKangXi=0207.280, RSKangXi=30.12
20F75 CJK UNIFIED IDEOGRAPH-#20F75, IRGKangXi=0207.320, RSKangXi=30.12
20F76 CJK UNIFIED IDEOGRAPH-#20F76, IRGKangXi=0208.020, RSKangXi=30.12
20F77 CJK UNIFIED IDEOGRAPH-#20F77, IRGKangXi=0208.080, RSKangXi=30.12
20F78 CJK UNIFIED IDEOGRAPH-#20F78, IRGKangXi=0208.090, RSKangXi=30.12
20F79 CJK UNIFIED IDEOGRAPH-#20F79, IRGKangXi=0208.110, RSKangXi=30.12
20F7A CJK UNIFIED IDEOGRAPH-#20F7A, IRGKangXi=0208.120, RSKangXi=30.12
20F7B CJK UNIFIED IDEOGRAPH-#20F7B, IRGKangXi=0208.130, RSKangXi=30.12
20F7C CJK UNIFIED IDEOGRAPH-#20F7C, IRGKangXi=0208.220, RSKangXi=30.12
20F7D CJK UNIFIED IDEOGRAPH-#20F7D, IRGKangXi=0208.230, RSKangXi=30.12
20F7E CJK UNIFIED IDEOGRAPH-#20F7E, IRGKangXi=0208.250, RSKangXi=30.12
20F7F CJK UNIFIED IDEOGRAPH-#20F7F, IRGKangXi=0208.290, RSKangXi=30.12
20F80 CJK UNIFIED IDEOGRAPH-#20F80, IRGKangXi=0208.300, RSKangXi=30.12
20F81 CJK UNIFIED IDEOGRAPH-#20F81, IRGKangXi=0209.020, RSKangXi=30.12
20F82 CJK UNIFIED IDEOGRAPH-#20F82, IRGKangXi=0209.030, RSKangXi=30.12
20F83 CJK UNIFIED IDEOGRAPH-#20F83, IRGKangXi=0209.040, RSKangXi=30.12
20F84 CJK UNIFIED IDEOGRAPH-#20F84, IRGKangXi=0209.050, RSKangXi=30.12
20F85 CJK UNIFIED IDEOGRAPH-#20F85, IRGKangXi=0209.060, RSKangXi=30.12
20F86 CJK UNIFIED IDEOGRAPH-#20F86, IRGKangXi=0209.070, RSKangXi=30.12
20F87 CJK UNIFIED IDEOGRAPH-#20F87, IRGKangXi=0209.080, RSKangXi=30.12
20F88 CJK UNIFIED IDEOGRAPH-#20F88, IRGKangXi=0209.090, RSKangXi=30.12
20F89 CJK UNIFIED IDEOGRAPH-#20F89, IRGKangXi=0209.100, RSKangXi=30.12
20F8A CJK UNIFIED IDEOGRAPH-#20F8A, IRGKangXi=0209.110, RSKangXi=30.12
20F8B CJK UNIFIED IDEOGRAPH-#20F8B, IRGKangXi=0209.130, RSKangXi=30.12
20F8C CJK UNIFIED IDEOGRAPH-#20F8C, IRGKangXi=0209.150, RSKangXi=30.12
20F8D CJK UNIFIED IDEOGRAPH-#20F8D, IRGKangXi=0209.151, RSKangXi=30.12, Def{(Cant.) to flick something off in a disorderly way}
20F8E CJK UNIFIED IDEOGRAPH-#20F8E, IRGKangXi=0209.151, RSKangXi=30.12
20F8F CJK UNIFIED IDEOGRAPH-#20F8F, IRGKangXi=0209.151, RSKangXi=30.12, Def{(Cant.) interjection}
20F90 CJK UNIFIED IDEOGRAPH-#20F90, IRGKangXi=0209.151, RSKangXi=30.12
20F91 CJK UNIFIED IDEOGRAPH-#20F91, IRGKangXi=0209.151, RSKangXi=30.12
20F92 CJK UNIFIED IDEOGRAPH-#20F92, IRGKangXi=0209.151, RSKangXi=30.12
20F93 CJK UNIFIED IDEOGRAPH-#20F93, IRGKangXi=0209.151, RSKangXi=30.12
20F94 CJK UNIFIED IDEOGRAPH-#20F94, IRGKangXi=0209.151, RSKangXi=30.12
20F95 CJK UNIFIED IDEOGRAPH-#20F95, IRGKangXi=0209.151, RSKangXi=30.12
20F96 CJK UNIFIED IDEOGRAPH-#20F96, IRGKangXi=0209.151, RSKangXi=30.12
20F97 CJK UNIFIED IDEOGRAPH-#20F97, IRGKangXi=0209.151, RSKangXi=30.12
20F98 CJK UNIFIED IDEOGRAPH-#20F98, IRGKangXi=0209.151, RSKangXi=30.12
20F99 CJK UNIFIED IDEOGRAPH-#20F99, IRGKangXi=0209.151, RSKangXi=30.12
20F9A CJK UNIFIED IDEOGRAPH-#20F9A, IRGKangXi=0209.151, RSKangXi=30.12
20F9B CJK UNIFIED IDEOGRAPH-#20F9B, IRGKangXi=0209.151, RSKangXi=30.12
20F9C CJK UNIFIED IDEOGRAPH-#20F9C, IRGKangXi=0209.151, RSKangXi=30.12
20F9D CJK UNIFIED IDEOGRAPH-#20F9D, IRGKangXi=0209.151, RSKangXi=30.12
20F9E CJK UNIFIED IDEOGRAPH-#20F9E, IRGKangXi=0209.151, RSKangXi=30.12
20F9F CJK UNIFIED IDEOGRAPH-#20F9F, IRGKangXi=0209.151, RSKangXi=30.12
20FA0 CJK UNIFIED IDEOGRAPH-#20FA0, IRGKangXi=0209.151, RSKangXi=30.12
20FA1 CJK UNIFIED IDEOGRAPH-#20FA1, IRGKangXi=0209.151, RSKangXi=30.12
20FA2 CJK UNIFIED IDEOGRAPH-#20FA2, IRGKangXi=0209.151, RSKangXi=30.12
20FA3 CJK UNIFIED IDEOGRAPH-#20FA3, IRGKangXi=0209.151, RSKangXi=30.12
20FA4 CJK UNIFIED IDEOGRAPH-#20FA4, IRGKangXi=0209.151, RSKangXi=30.12
20FA5 CJK UNIFIED IDEOGRAPH-#20FA5, IRGKangXi=0209.151, RSKangXi=30.12
20FA6 CJK UNIFIED IDEOGRAPH-#20FA6, IRGKangXi=0209.151, RSKangXi=30.12
20FA7 CJK UNIFIED IDEOGRAPH-#20FA7, IRGKangXi=0209.151, RSKangXi=114.10
20FA8 CJK UNIFIED IDEOGRAPH-#20FA8, IRGKangXi=0209.151, RSKangXi=30.12
20FA9 CJK UNIFIED IDEOGRAPH-#20FA9, IRGKangXi=0209.151, RSKangXi=30.12
20FAA CJK UNIFIED IDEOGRAPH-#20FAA, IRGKangXi=0209.151, RSKangXi=30.12
20FAB CJK UNIFIED IDEOGRAPH-#20FAB, IRGKangXi=0209.151, RSKangXi=30.12
20FAC CJK UNIFIED IDEOGRAPH-#20FAC, IRGKangXi=0209.151, RSKangXi=30.12
20FAD CJK UNIFIED IDEOGRAPH-#20FAD, IRGKangXi=0209.151, RSKangXi=30.12, Def{(Cant.) soft fabric with no body}
20FAE CJK UNIFIED IDEOGRAPH-#20FAE, IRGKangXi=0209.151, RSKangXi=30.12
20FAF CJK UNIFIED IDEOGRAPH-#20FAF, IRGKangXi=0209.151, RSKangXi=30.12
20FB0 CJK UNIFIED IDEOGRAPH-#20FB0, IRGKangXi=0209.151, RSKangXi=30.12
20FB1 CJK UNIFIED IDEOGRAPH-#20FB1, IRGKangXi=0209.151, RSKangXi=30.12
20FB2 CJK UNIFIED IDEOGRAPH-#20FB2, IRGKangXi=0209.151, RSKangXi=30.12
20FB3 CJK UNIFIED IDEOGRAPH-#20FB3, IRGKangXi=0209.151, RSKangXi=30.12
20FB4 CJK UNIFIED IDEOGRAPH-#20FB4, IRGKangXi=0209.151, RSKangXi=30.12, Def{(Cant.) phonetic}
20FB5 CJK UNIFIED IDEOGRAPH-#20FB5, IRGKangXi=0209.151, RSKangXi=30.12, Def{(Cant.) final particle}
20FB6 CJK UNIFIED IDEOGRAPH-#20FB6, IRGKangXi=0209.151, RSKangXi=30.12
20FB7 CJK UNIFIED IDEOGRAPH-#20FB7, IRGKangXi=0209.151, RSKangXi=30.12
20FB8 CJK UNIFIED IDEOGRAPH-#20FB8, IRGKangXi=0209.151, RSKangXi=30.12
20FB9 CJK UNIFIED IDEOGRAPH-#20FB9, IRGKangXi=0209.151, RSKangXi=30.12
20FBA CJK UNIFIED IDEOGRAPH-#20FBA, IRGKangXi=0209.151, RSKangXi=30.12
20FBB CJK UNIFIED IDEOGRAPH-#20FBB, IRGKangXi=0209.151, RSKangXi=30.12
20FBC CJK UNIFIED IDEOGRAPH-#20FBC, IRGKangXi=0209.151, RSKangXi=30.12, Def{(Cant.) phonetic}
20FBD CJK UNIFIED IDEOGRAPH-#20FBD, IRGKangXi=0209.151, RSKangXi=30.12
20FBE CJK UNIFIED IDEOGRAPH-#20FBE, IRGKangXi=0209.151, RSKangXi=30.12
20FBF CJK UNIFIED IDEOGRAPH-#20FBF, IRGKangXi=0209.151, RSKangXi=30.12
20FC0 CJK UNIFIED IDEOGRAPH-#20FC0, IRGKangXi=0209.151, RSKangXi=30.12
20FC1 CJK UNIFIED IDEOGRAPH-#20FC1, IRGKangXi=0209.151, RSKangXi=30.12
20FC2 CJK UNIFIED IDEOGRAPH-#20FC2, IRGKangXi=0209.151, RSKangXi=30.12
20FC3 CJK UNIFIED IDEOGRAPH-#20FC3, IRGKangXi=0209.151, RSKangXi=30.12
20FC4 CJK UNIFIED IDEOGRAPH-#20FC4, IRGKangXi=0209.151, RSKangXi=30.12
20FC5 CJK UNIFIED IDEOGRAPH-#20FC5, IRGKangXi=0209.151, RSKangXi=30.12
20FC6 CJK UNIFIED IDEOGRAPH-#20FC6, IRGKangXi=0209.151, RSKangXi=30.12
20FC7 CJK UNIFIED IDEOGRAPH-#20FC7, IRGKangXi=0209.170, RSKangXi=30.13
20FC8 CJK UNIFIED IDEOGRAPH-#20FC8, IRGKangXi=0209.200, RSKangXi=30.13
20FC9 CJK UNIFIED IDEOGRAPH-#20FC9, IRGKangXi=0209.230, RSKangXi=30.13
20FCA CJK UNIFIED IDEOGRAPH-#20FCA, IRGKangXi=0209.240, RSKangXi=30.13
20FCB CJK UNIFIED IDEOGRAPH-#20FCB, IRGKangXi=0209.260, RSKangXi=30.13
20FCC CJK UNIFIED IDEOGRAPH-#20FCC, IRGKangXi=0209.270, RSKangXi=30.13
20FCD CJK UNIFIED IDEOGRAPH-#20FCD, IRGKangXi=0209.280, RSKangXi=30.13
20FCE CJK UNIFIED IDEOGRAPH-#20FCE, IRGKangXi=0209.310, RSKangXi=30.13
20FCF CJK UNIFIED IDEOGRAPH-#20FCF, IRGKangXi=0209.320, RSKangXi=30.13
20FD0 CJK UNIFIED IDEOGRAPH-#20FD0, IRGKangXi=0209.330, RSKangXi=30.13
20FD1 CJK UNIFIED IDEOGRAPH-#20FD1, IRGKangXi=0209.350, RSKangXi=30.13
20FD2 CJK UNIFIED IDEOGRAPH-#20FD2, IRGKangXi=0209.390, RSKangXi=30.13
20FD3 CJK UNIFIED IDEOGRAPH-#20FD3, IRGKangXi=0210.010, RSKangXi=30.13
20FD4 CJK UNIFIED IDEOGRAPH-#20FD4, IRGKangXi=0210.050, RSKangXi=30.13
20FD5 CJK UNIFIED IDEOGRAPH-#20FD5, IRGKangXi=0210.060, RSKangXi=30.13
20FD6 CJK UNIFIED IDEOGRAPH-#20FD6, IRGKangXi=0210.110, RSKangXi=30.13
20FD7 CJK UNIFIED IDEOGRAPH-#20FD7, IRGKangXi=0210.120, RSKangXi=30.13
20FD8 CJK UNIFIED IDEOGRAPH-#20FD8, IRGKangXi=0210.140, RSKangXi=30.13
20FD9 CJK UNIFIED IDEOGRAPH-#20FD9, IRGKangXi=0210.150, RSKangXi=30.13
20FDA CJK UNIFIED IDEOGRAPH-#20FDA, IRGKangXi=0210.160, RSKangXi=30.13
20FDB CJK UNIFIED IDEOGRAPH-#20FDB, IRGKangXi=0210.170, RSKangXi=30.13, Def{cry used in calling pigs}
20FDC CJK UNIFIED IDEOGRAPH-#20FDC, IRGKangXi=0210.180, RSKangXi=30.13
20FDD CJK UNIFIED IDEOGRAPH-#20FDD, IRGKangXi=0210.190, RSKangXi=30.13
20FDE CJK UNIFIED IDEOGRAPH-#20FDE, IRGKangXi=0210.240, RSKangXi=30.13
20FDF CJK UNIFIED IDEOGRAPH-#20FDF, IRGKangXi=0210.260, RSKangXi=30.13
20FE0 CJK UNIFIED IDEOGRAPH-#20FE0, IRGKangXi=0210.270, RSKangXi=30.13
20FE1 CJK UNIFIED IDEOGRAPH-#20FE1, IRGKangXi=0210.290, RSKangXi=30.13
20FE2 CJK UNIFIED IDEOGRAPH-#20FE2, IRGKangXi=0210.300, RSKangXi=30.13
20FE3 CJK UNIFIED IDEOGRAPH-#20FE3, IRGKangXi=0211.030, RSKangXi=30.13
20FE4 CJK UNIFIED IDEOGRAPH-#20FE4, IRGKangXi=0211.070, RSKangXi=30.13
20FE5 CJK UNIFIED IDEOGRAPH-#20FE5, IRGKangXi=0211.080, RSKangXi=30.13
20FE6 CJK UNIFIED IDEOGRAPH-#20FE6, IRGKangXi=0211.090, RSKangXi=30.13
20FE7 CJK UNIFIED IDEOGRAPH-#20FE7, IRGKangXi=0211.100, RSKangXi=30.13
20FE8 CJK UNIFIED IDEOGRAPH-#20FE8, IRGKangXi=0211.120, RSKangXi=30.13
20FE9 CJK UNIFIED IDEOGRAPH-#20FE9, IRGKangXi=0211.121, RSKangXi=30.13
20FEA CJK UNIFIED IDEOGRAPH-#20FEA, IRGKangXi=0211.121, RSKangXi=30.13, Def{(Cant.) final particle}
20FEB CJK UNIFIED IDEOGRAPH-#20FEB, IRGKangXi=0211.121, RSKangXi=30.13, Def{(Cant.) shabby}
20FEC CJK UNIFIED IDEOGRAPH-#20FEC, IRGKangXi=0211.121, RSKangXi=30.13, Def{(Cant.) ignorant}
20FED CJK UNIFIED IDEOGRAPH-#20FED, IRGKangXi=0211.121, RSKangXi=30.13, Def{(Cant.) to go somewhere to have a good time}
20FEE CJK UNIFIED IDEOGRAPH-#20FEE, IRGKangXi=0211.121, RSKangXi=30.13
20FEF CJK UNIFIED IDEOGRAPH-#20FEF, IRGKangXi=0211.121, RSKangXi=30.13
20FF0 CJK UNIFIED IDEOGRAPH-#20FF0, IRGKangXi=0211.121, RSKangXi=30.13
20FF1 CJK UNIFIED IDEOGRAPH-#20FF1, IRGKangXi=0211.121, RSKangXi=30.13
20FF2 CJK UNIFIED IDEOGRAPH-#20FF2, IRGKangXi=0211.121, RSKangXi=30.13
20FF3 CJK UNIFIED IDEOGRAPH-#20FF3, IRGKangXi=0211.121, RSKangXi=30.13
20FF4 CJK UNIFIED IDEOGRAPH-#20FF4, IRGKangXi=0211.121, RSKangXi=30.13
20FF5 CJK UNIFIED IDEOGRAPH-#20FF5, IRGKangXi=0211.121, RSKangXi=30.13
20FF6 CJK UNIFIED IDEOGRAPH-#20FF6, IRGKangXi=0211.121, RSKangXi=30.13
20FF7 CJK UNIFIED IDEOGRAPH-#20FF7, IRGKangXi=0211.121, RSKangXi=30.13
20FF8 CJK UNIFIED IDEOGRAPH-#20FF8, IRGKangXi=0211.121, RSKangXi=30.13
20FF9 CJK UNIFIED IDEOGRAPH-#20FF9, IRGKangXi=0211.121, RSKangXi=30.13
20FFA CJK UNIFIED IDEOGRAPH-#20FFA, IRGKangXi=0211.121, RSKangXi=30.13
20FFB CJK UNIFIED IDEOGRAPH-#20FFB, IRGKangXi=0211.121, RSKangXi=30.13
20FFC CJK UNIFIED IDEOGRAPH-#20FFC, IRGKangXi=0211.121, RSKangXi=30.13
20FFD CJK UNIFIED IDEOGRAPH-#20FFD, IRGKangXi=0211.121, RSKangXi=30.13
20FFE CJK UNIFIED IDEOGRAPH-#20FFE, IRGKangXi=0211.121, RSKangXi=30.13
20FFF CJK UNIFIED IDEOGRAPH-#20FFF, IRGKangXi=0211.121, RSKangXi=30.13
21000 CJK UNIFIED IDEOGRAPH-#21000, IRGKangXi=0211.121, RSKangXi=30.13
21001 CJK UNIFIED IDEOGRAPH-#21001, IRGKangXi=0211.121, RSKangXi=30.13
21002 CJK UNIFIED IDEOGRAPH-#21002, IRGKangXi=0211.121, RSKangXi=30.13
21003 CJK UNIFIED IDEOGRAPH-#21003, IRGKangXi=0211.121, RSKangXi=30.13
21004 CJK UNIFIED IDEOGRAPH-#21004, IRGKangXi=0211.121, RSKangXi=30.13
21005 CJK UNIFIED IDEOGRAPH-#21005, IRGKangXi=0211.121, RSKangXi=30.13
21006 CJK UNIFIED IDEOGRAPH-#21006, IRGKangXi=0211.121, RSKangXi=30.13
21007 CJK UNIFIED IDEOGRAPH-#21007, IRGKangXi=0211.121, RSKangXi=30.13
21008 CJK UNIFIED IDEOGRAPH-#21008, IRGKangXi=0211.121, RSKangXi=30.13
21009 CJK UNIFIED IDEOGRAPH-#21009, IRGKangXi=0211.121, RSKangXi=30.13
2100A CJK UNIFIED IDEOGRAPH-#2100A, IRGKangXi=0211.121, RSKangXi=30.13
2100B CJK UNIFIED IDEOGRAPH-#2100B, IRGKangXi=0211.121, RSKangXi=30.13
2100C CJK UNIFIED IDEOGRAPH-#2100C, IRGKangXi=0211.121, RSKangXi=30.13
2100D CJK UNIFIED IDEOGRAPH-#2100D, IRGKangXi=0211.121, RSKangXi=30.13
2100E CJK UNIFIED IDEOGRAPH-#2100E, IRGKangXi=0211.121, RSKangXi=30.13
2100F CJK UNIFIED IDEOGRAPH-#2100F, IRGKangXi=0211.121, RSKangXi=30.13
21010 CJK UNIFIED IDEOGRAPH-#21010, IRGKangXi=0211.121, RSKangXi=30.13
21011 CJK UNIFIED IDEOGRAPH-#21011, IRGKangXi=0211.121, RSKangXi=30.13
21012 CJK UNIFIED IDEOGRAPH-#21012, IRGKangXi=0211.121, RSKangXi=30.13
21013 CJK UNIFIED IDEOGRAPH-#21013, IRGKangXi=0211.121, RSKangXi=30.13
21014 CJK UNIFIED IDEOGRAPH-#21014, IRGKangXi=0211.121, RSKangXi=30.13, Def{used in transliteration}
21015 CJK UNIFIED IDEOGRAPH-#21015, IRGKangXi=0211.121, RSKangXi=30.13
21016 CJK UNIFIED IDEOGRAPH-#21016, IRGKangXi=0211.121, RSKangXi=30.13
21017 CJK UNIFIED IDEOGRAPH-#21017, IRGKangXi=0211.121, RSKangXi=30.13
21018 CJK UNIFIED IDEOGRAPH-#21018, IRGKangXi=0211.121, RSKangXi=30.13
21019 CJK UNIFIED IDEOGRAPH-#21019, IRGKangXi=0211.121, RSKangXi=30.13
2101A CJK UNIFIED IDEOGRAPH-#2101A, IRGKangXi=0211.121, RSKangXi=30.13
2101B CJK UNIFIED IDEOGRAPH-#2101B, IRGKangXi=0211.121, RSKangXi=30.13
2101C CJK UNIFIED IDEOGRAPH-#2101C, IRGKangXi=0211.121, RSKangXi=30.13
2101D CJK UNIFIED IDEOGRAPH-#2101D, IRGKangXi=0211.121, RSKangXi=30.13, Def{(Cant.) sound asleep}
2101E CJK UNIFIED IDEOGRAPH-#2101E, IRGKangXi=0211.121, RSKangXi=30.13, Def{(Cant.) a Jeep; to wave, beckon}
2101F CJK UNIFIED IDEOGRAPH-#2101F, IRGKangXi=0211.121, RSKangXi=30.13
21020 CJK UNIFIED IDEOGRAPH-#21020, IRGKangXi=0211.121, RSKangXi=30.13, Def{or; emphatic particle; (Cant.) particle implying doubt}
21021 CJK UNIFIED IDEOGRAPH-#21021, IRGKangXi=0211.121, RSKangXi=30.13
21022 CJK UNIFIED IDEOGRAPH-#21022, IRGKangXi=0211.121, RSKangXi=30.13
21023 CJK UNIFIED IDEOGRAPH-#21023, IRGKangXi=0211.121, RSKangXi=30.13
21024 CJK UNIFIED IDEOGRAPH-#21024, IRGKangXi=0211.121, RSKangXi=30.13
21025 CJK UNIFIED IDEOGRAPH-#21025, IRGKangXi=0211.121, RSKangXi=30.13
21026 CJK UNIFIED IDEOGRAPH-#21026, IRGKangXi=0211.121, RSKangXi=30.12
21027 CJK UNIFIED IDEOGRAPH-#21027, IRGKangXi=0211.121, RSKangXi=30.13
21028 CJK UNIFIED IDEOGRAPH-#21028, IRGKangXi=0211.121, RSKangXi=30.13
21029 CJK UNIFIED IDEOGRAPH-#21029, IRGKangXi=0211.121, RSKangXi=30.13, Def{(Cant.) onomatopoetic}
2102A CJK UNIFIED IDEOGRAPH-#2102A, IRGKangXi=0211.121, RSKangXi=30.13
2102B CJK UNIFIED IDEOGRAPH-#2102B, IRGKangXi=0211.121, RSKangXi=30.13
2102C CJK UNIFIED IDEOGRAPH-#2102C, IRGKangXi=0211.121, RSKangXi=30.13
2102D CJK UNIFIED IDEOGRAPH-#2102D, IRGKangXi=0211.121, RSKangXi=30.13
2102E CJK UNIFIED IDEOGRAPH-#2102E, IRGKangXi=0211.121, RSKangXi=30.13
2102F CJK UNIFIED IDEOGRAPH-#2102F, IRGKangXi=0211.121, RSKangXi=30.13
21030 CJK UNIFIED IDEOGRAPH-#21030, IRGKangXi=0211.121, RSKangXi=30.13
21031 CJK UNIFIED IDEOGRAPH-#21031, IRGKangXi=0211.121, RSKangXi=30.13
21032 CJK UNIFIED IDEOGRAPH-#21032, IRGKangXi=0211.121, RSKangXi=30.13
21033 CJK UNIFIED IDEOGRAPH-#21033, IRGKangXi=0211.121, RSKangXi=30.13
21034 CJK UNIFIED IDEOGRAPH-#21034, IRGKangXi=0211.121, RSKangXi=30.13
21035 CJK UNIFIED IDEOGRAPH-#21035, IRGKangXi=0211.121, RSKangXi=30.13
21036 CJK UNIFIED IDEOGRAPH-#21036, IRGKangXi=0211.121, RSKangXi=30.13
21037 CJK UNIFIED IDEOGRAPH-#21037, IRGKangXi=0211.121, RSKangXi=30.13
21038 CJK UNIFIED IDEOGRAPH-#21038, IRGKangXi=0211.121, RSKangXi=30.13
21039 CJK UNIFIED IDEOGRAPH-#21039, IRGKangXi=0211.121, RSKangXi=30.13
2103A CJK UNIFIED IDEOGRAPH-#2103A, IRGKangXi=0211.121, RSKangXi=30.13
2103B CJK UNIFIED IDEOGRAPH-#2103B, IRGKangXi=0211.121, RSKangXi=30.13
2103C CJK UNIFIED IDEOGRAPH-#2103C, IRGKangXi=0211.121, RSKangXi=30.13
2103D CJK UNIFIED IDEOGRAPH-#2103D, IRGKangXi=0211.130, RSKangXi=30.14
2103E CJK UNIFIED IDEOGRAPH-#2103E, IRGKangXi=0211.140, RSKangXi=30.14
2103F CJK UNIFIED IDEOGRAPH-#2103F, IRGKangXi=0211.150, RSKangXi=30.14
21040 CJK UNIFIED IDEOGRAPH-#21040, IRGKangXi=0211.170, RSKangXi=30.14
21041 CJK UNIFIED IDEOGRAPH-#21041, IRGKangXi=0211.180, RSKangXi=30.14
21042 CJK UNIFIED IDEOGRAPH-#21042, IRGKangXi=0211.190, RSKangXi=30.14
21043 CJK UNIFIED IDEOGRAPH-#21043, IRGKangXi=0211.210, RSKangXi=30.14
21044 CJK UNIFIED IDEOGRAPH-#21044, IRGKangXi=0211.260, RSKangXi=30.14
21045 CJK UNIFIED IDEOGRAPH-#21045, IRGKangXi=0211.310, RSKangXi=30.14
21046 CJK UNIFIED IDEOGRAPH-#21046, IRGKangXi=0211.320, RSKangXi=30.14
21047 CJK UNIFIED IDEOGRAPH-#21047, IRGKangXi=0211.340, RSKangXi=30.14
21048 CJK UNIFIED IDEOGRAPH-#21048, IRGKangXi=0211.350, RSKangXi=30.14
21049 CJK UNIFIED IDEOGRAPH-#21049, IRGKangXi=0211.390, RSKangXi=30.14
2104A CJK UNIFIED IDEOGRAPH-#2104A, IRGKangXi=0211.400, RSKangXi=30.14
2104B CJK UNIFIED IDEOGRAPH-#2104B, IRGKangXi=0211.420, RSKangXi=30.14
2104C CJK UNIFIED IDEOGRAPH-#2104C, IRGKangXi=0212.030, RSKangXi=30.14
2104D CJK UNIFIED IDEOGRAPH-#2104D, IRGKangXi=0212.060, RSKangXi=30.14
2104E CJK UNIFIED IDEOGRAPH-#2104E, IRGKangXi=0212.070, RSKangXi=30.14
2104F CJK UNIFIED IDEOGRAPH-#2104F, IRGKangXi=0212.080, RSKangXi=30.14, Def{(Cant.) soft rice or food for a baby}
21050 CJK UNIFIED IDEOGRAPH-#21050, IRGKangXi=0212.110, RSKangXi=30.14
21051 CJK UNIFIED IDEOGRAPH-#21051, IRGKangXi=0212.120, RSKangXi=30.14
21052 CJK UNIFIED IDEOGRAPH-#21052, IRGKangXi=0212.130, RSKangXi=30.14
21053 CJK UNIFIED IDEOGRAPH-#21053, IRGKangXi=0212.150, RSKangXi=30.14
21054 CJK UNIFIED IDEOGRAPH-#21054, IRGKangXi=0212.160, RSKangXi=30.14
21055 CJK UNIFIED IDEOGRAPH-#21055, IRGKangXi=0212.180, RSKangXi=30.14
21056 CJK UNIFIED IDEOGRAPH-#21056, IRGKangXi=0212.190, RSKangXi=30.14
21057 CJK UNIFIED IDEOGRAPH-#21057, IRGKangXi=0212.191, RSKangXi=30.14
21058 CJK UNIFIED IDEOGRAPH-#21058, IRGKangXi=0212.191, RSKangXi=30.14
21059 CJK UNIFIED IDEOGRAPH-#21059, IRGKangXi=0212.191, RSKangXi=30.14
2105A CJK UNIFIED IDEOGRAPH-#2105A, IRGKangXi=0212.191, RSKangXi=30.14
2105B CJK UNIFIED IDEOGRAPH-#2105B, IRGKangXi=0212.191, RSKangXi=30.14
2105C CJK UNIFIED IDEOGRAPH-#2105C, IRGKangXi=0212.191, RSKangXi=30.14, Def{(Cant.) particle to close a quote}
2105D CJK UNIFIED IDEOGRAPH-#2105D, IRGKangXi=0212.191, RSKangXi=30.14
2105E CJK UNIFIED IDEOGRAPH-#2105E, IRGKangXi=0212.191, RSKangXi=30.14
2105F CJK UNIFIED IDEOGRAPH-#2105F, IRGKangXi=0212.191, RSKangXi=30.14
21060 CJK UNIFIED IDEOGRAPH-#21060, IRGKangXi=0212.191, RSKangXi=30.14
21061 CJK UNIFIED IDEOGRAPH-#21061, IRGKangXi=0212.191, RSKangXi=30.14
21062 CJK UNIFIED IDEOGRAPH-#21062, IRGKangXi=0212.191, RSKangXi=30.14
21063 CJK UNIFIED IDEOGRAPH-#21063, IRGKangXi=0212.191, RSKangXi=30.14
21064 CJK UNIFIED IDEOGRAPH-#21064, IRGKangXi=0212.191, RSKangXi=30.14
21065 CJK UNIFIED IDEOGRAPH-#21065, IRGKangXi=0212.191, RSKangXi=30.14
21066 CJK UNIFIED IDEOGRAPH-#21066, IRGKangXi=0212.191, RSKangXi=30.14
21067 CJK UNIFIED IDEOGRAPH-#21067, IRGKangXi=0212.191, RSKangXi=30.14
21068 CJK UNIFIED IDEOGRAPH-#21068, IRGKangXi=0212.191, RSKangXi=30.14
21069 CJK UNIFIED IDEOGRAPH-#21069, IRGKangXi=0212.191, RSKangXi=30.14
2106A CJK UNIFIED IDEOGRAPH-#2106A, IRGKangXi=0212.191, RSKangXi=30.14
2106B CJK UNIFIED IDEOGRAPH-#2106B, IRGKangXi=0212.191, RSKangXi=30.14
2106C CJK UNIFIED IDEOGRAPH-#2106C, IRGKangXi=0212.191, RSKangXi=30.14
2106D CJK UNIFIED IDEOGRAPH-#2106D, IRGKangXi=0212.191, RSKangXi=30.14
2106E CJK UNIFIED IDEOGRAPH-#2106E, IRGKangXi=0212.191, RSKangXi=30.14
2106F CJK UNIFIED IDEOGRAPH-#2106F, IRGKangXi=0212.191, RSKangXi=30.14, Def{(Cant.) to pout}
21070 CJK UNIFIED IDEOGRAPH-#21070, IRGKangXi=0212.191, RSKangXi=30.14
21071 CJK UNIFIED IDEOGRAPH-#21071, IRGKangXi=0212.191, RSKangXi=30.14
21072 CJK UNIFIED IDEOGRAPH-#21072, IRGKangXi=0212.191, RSKangXi=30.14
21073 CJK UNIFIED IDEOGRAPH-#21073, IRGKangXi=0212.191, RSKangXi=30.14
21074 CJK UNIFIED IDEOGRAPH-#21074, IRGKangXi=0212.191, RSKangXi=30.14
21075 CJK UNIFIED IDEOGRAPH-#21075, IRGKangXi=0212.191, RSKangXi=30.14, Def{(Cant.) aspect marker for continuous action}
21076 CJK UNIFIED IDEOGRAPH-#21076, IRGKangXi=0212.191, RSKangXi=30.14, Def{(Cant.) to scratch an itch}
21077 CJK UNIFIED IDEOGRAPH-#21077, IRGKangXi=0212.191, RSKangXi=30.14, Def{(Cant.) a sharp point; to peck}
21078 CJK UNIFIED IDEOGRAPH-#21078, IRGKangXi=0212.191, RSKangXi=30.14, Def{(Cant.) a circle, ring}
21079 CJK UNIFIED IDEOGRAPH-#21079, IRGKangXi=0212.191, RSKangXi=30.14
2107A CJK UNIFIED IDEOGRAPH-#2107A, IRGKangXi=0212.191, RSKangXi=30.14
2107B CJK UNIFIED IDEOGRAPH-#2107B, IRGKangXi=0212.191, RSKangXi=30.14, Def{(Cant.) to beat someone up}
2107C CJK UNIFIED IDEOGRAPH-#2107C, IRGKangXi=0212.191, RSKangXi=30.14
2107D CJK UNIFIED IDEOGRAPH-#2107D, IRGKangXi=0212.191, RSKangXi=30.14
2107E CJK UNIFIED IDEOGRAPH-#2107E, IRGKangXi=0212.191, RSKangXi=30.14
2107F CJK UNIFIED IDEOGRAPH-#2107F, IRGKangXi=0212.191, RSKangXi=30.14
21080 CJK UNIFIED IDEOGRAPH-#21080, IRGKangXi=0212.191, RSKangXi=30.14
21081 CJK UNIFIED IDEOGRAPH-#21081, IRGKangXi=0212.191, RSKangXi=30.14
21082 CJK UNIFIED IDEOGRAPH-#21082, IRGKangXi=0212.191, RSKangXi=30.14
21083 CJK UNIFIED IDEOGRAPH-#21083, IRGKangXi=0212.191, RSKangXi=30.14
21084 CJK UNIFIED IDEOGRAPH-#21084, IRGKangXi=0212.191, RSKangXi=30.14
21085 CJK UNIFIED IDEOGRAPH-#21085, IRGKangXi=0212.191, RSKangXi=30.14
21086 CJK UNIFIED IDEOGRAPH-#21086, IRGKangXi=0212.191, RSKangXi=30.14
21087 CJK UNIFIED IDEOGRAPH-#21087, IRGKangXi=0212.191, RSKangXi=30.14
21088 CJK UNIFIED IDEOGRAPH-#21088, IRGKangXi=0212.191, RSKangXi=30.14, Def{(Cant.) to lie prone; to bend over}
21089 CJK UNIFIED IDEOGRAPH-#21089, IRGKangXi=0212.191, RSKangXi=30.14
2108A CJK UNIFIED IDEOGRAPH-#2108A, IRGKangXi=0212.191, RSKangXi=30.14
2108B CJK UNIFIED IDEOGRAPH-#2108B, IRGKangXi=0212.191, RSKangXi=30.14
2108C CJK UNIFIED IDEOGRAPH-#2108C, IRGKangXi=0212.191, RSKangXi=30.14
2108D CJK UNIFIED IDEOGRAPH-#2108D, IRGKangXi=0212.191, RSKangXi=30.14
2108E CJK UNIFIED IDEOGRAPH-#2108E, IRGKangXi=0212.191, RSKangXi=30.14
2108F CJK UNIFIED IDEOGRAPH-#2108F, IRGKangXi=0212.200, RSKangXi=30.15
21090 CJK UNIFIED IDEOGRAPH-#21090, IRGKangXi=0212.220, RSKangXi=30.15
21091 CJK UNIFIED IDEOGRAPH-#21091, IRGKangXi=0212.230, RSKangXi=30.15
21092 CJK UNIFIED IDEOGRAPH-#21092, IRGKangXi=0212.240, RSKangXi=30.15
21093 CJK UNIFIED IDEOGRAPH-#21093, IRGKangXi=0212.250, RSKangXi=30.15
21094 CJK UNIFIED IDEOGRAPH-#21094, IRGKangXi=0212.290, RSKangXi=30.15
21095 CJK UNIFIED IDEOGRAPH-#21095, IRGKangXi=0212.310, RSKangXi=30.15
21096 CJK UNIFIED IDEOGRAPH-#21096, IRGKangXi=0212.320, RSKangXi=30.15, Def{(Cant.) unrestrained}
21097 CJK UNIFIED IDEOGRAPH-#21097, IRGKangXi=0212.340, RSKangXi=30.15
21098 CJK UNIFIED IDEOGRAPH-#21098, IRGKangXi=0212.380, RSKangXi=30.15
21099 CJK UNIFIED IDEOGRAPH-#21099, IRGKangXi=0212.390, RSKangXi=30.15
2109A CJK UNIFIED IDEOGRAPH-#2109A, IRGKangXi=0212.420, RSKangXi=30.15
2109B CJK UNIFIED IDEOGRAPH-#2109B, IRGKangXi=0212.480, RSKangXi=30.15
2109C CJK UNIFIED IDEOGRAPH-#2109C, IRGKangXi=0212.490, RSKangXi=30.15
2109D CJK UNIFIED IDEOGRAPH-#2109D, IRGKangXi=0212.500, RSKangXi=30.15, Def{(Cant.) to choke and cough}
2109E CJK UNIFIED IDEOGRAPH-#2109E, IRGKangXi=0213.010, RSKangXi=30.15
2109F CJK UNIFIED IDEOGRAPH-#2109F, IRGKangXi=0213.030, RSKangXi=30.15
210A0 CJK UNIFIED IDEOGRAPH-#210A0, IRGKangXi=0213.070, RSKangXi=30.15
210A1 CJK UNIFIED IDEOGRAPH-#210A1, IRGKangXi=0213.080, RSKangXi=30.15
210A2 CJK UNIFIED IDEOGRAPH-#210A2, IRGKangXi=0213.090, RSKangXi=30.15
210A3 CJK UNIFIED IDEOGRAPH-#210A3, IRGKangXi=0213.100, RSKangXi=30.15
210A4 CJK UNIFIED IDEOGRAPH-#210A4, IRGKangXi=0213.120, RSKangXi=30.15
210A5 CJK UNIFIED IDEOGRAPH-#210A5, IRGKangXi=0213.130, RSKangXi=30.15
210A6 CJK UNIFIED IDEOGRAPH-#210A6, IRGKangXi=0213.140, RSKangXi=30.15
210A7 CJK UNIFIED IDEOGRAPH-#210A7, IRGKangXi=0213.150, RSKangXi=30.15
210A8 CJK UNIFIED IDEOGRAPH-#210A8, IRGKangXi=0213.160, RSKangXi=30.15
210A9 CJK UNIFIED IDEOGRAPH-#210A9, IRGKangXi=0213.170, RSKangXi=30.15
210AA CJK UNIFIED IDEOGRAPH-#210AA, IRGKangXi=0213.171, RSKangXi=30.15
210AB CJK UNIFIED IDEOGRAPH-#210AB, IRGKangXi=0213.171, RSKangXi=30.15
210AC CJK UNIFIED IDEOGRAPH-#210AC, IRGKangXi=0213.171, RSKangXi=30.15
210AD CJK UNIFIED IDEOGRAPH-#210AD, IRGKangXi=0213.171, RSKangXi=30.15
210AE CJK UNIFIED IDEOGRAPH-#210AE, IRGKangXi=0213.171, RSKangXi=30.15
210AF CJK UNIFIED IDEOGRAPH-#210AF, IRGKangXi=0213.171, RSKangXi=30.15
210B0 CJK UNIFIED IDEOGRAPH-#210B0, IRGKangXi=0213.171, RSKangXi=30.15
210B1 CJK UNIFIED IDEOGRAPH-#210B1, IRGKangXi=0213.171, RSKangXi=30.15
210B2 CJK UNIFIED IDEOGRAPH-#210B2, IRGKangXi=0213.171, RSKangXi=30.15
210B3 CJK UNIFIED IDEOGRAPH-#210B3, IRGKangXi=0213.171, RSKangXi=30.15
210B4 CJK UNIFIED IDEOGRAPH-#210B4, IRGKangXi=0213.171, RSKangXi=30.15
210B5 CJK UNIFIED IDEOGRAPH-#210B5, IRGKangXi=0213.171, RSKangXi=30.15
210B6 CJK UNIFIED IDEOGRAPH-#210B6, IRGKangXi=0213.171, RSKangXi=30.15
210B7 CJK UNIFIED IDEOGRAPH-#210B7, IRGKangXi=0213.171, RSKangXi=30.15
210B8 CJK UNIFIED IDEOGRAPH-#210B8, IRGKangXi=0213.171, RSKangXi=30.15
210B9 CJK UNIFIED IDEOGRAPH-#210B9, IRGKangXi=0213.171, RSKangXi=30.15
210BA CJK UNIFIED IDEOGRAPH-#210BA, IRGKangXi=0213.171, RSKangXi=30.15
210BB CJK UNIFIED IDEOGRAPH-#210BB, IRGKangXi=0213.171, RSKangXi=30.15
210BC CJK UNIFIED IDEOGRAPH-#210BC, IRGKangXi=0213.171, RSKangXi=30.15
210BD CJK UNIFIED IDEOGRAPH-#210BD, IRGKangXi=0213.171, RSKangXi=30.15
210BE CJK UNIFIED IDEOGRAPH-#210BE, IRGKangXi=0213.171, RSKangXi=30.15
210BF CJK UNIFIED IDEOGRAPH-#210BF, IRGKangXi=0213.171, RSKangXi=30.15
210C0 CJK UNIFIED IDEOGRAPH-#210C0, IRGKangXi=0213.171, RSKangXi=30.15, Def{(Cant.) a musical instrument}
210C1 CJK UNIFIED IDEOGRAPH-#210C1, IRGKangXi=0213.171, RSKangXi=30.15, Def{(Cant.) member of a triad; young}
210C2 CJK UNIFIED IDEOGRAPH-#210C2, IRGKangXi=0213.171, RSKangXi=30.15
210C3 CJK UNIFIED IDEOGRAPH-#210C3, IRGKangXi=0213.171, RSKangXi=30.15
210C4 CJK UNIFIED IDEOGRAPH-#210C4, IRGKangXi=0213.171, RSKangXi=30.15
210C5 CJK UNIFIED IDEOGRAPH-#210C5, IRGKangXi=0213.171, RSKangXi=30.15
210C6 CJK UNIFIED IDEOGRAPH-#210C6, IRGKangXi=0213.171, RSKangXi=30.15
210C7 CJK UNIFIED IDEOGRAPH-#210C7, IRGKangXi=0213.171, RSKangXi=30.15, Def{(Cant.) exclamation}
210C8 CJK UNIFIED IDEOGRAPH-#210C8, IRGKangXi=0213.171, RSKangXi=30.15, Def{(Cant.) a lasso; a circle, frame}
210C9 CJK UNIFIED IDEOGRAPH-#210C9, IRGKangXi=0213.171, RSKangXi=30.15, Def{(Cant.) final particle}
210CA CJK UNIFIED IDEOGRAPH-#210CA, IRGKangXi=0213.171, RSKangXi=30.15
210CB CJK UNIFIED IDEOGRAPH-#210CB, IRGKangXi=0213.171, RSKangXi=30.15
210CC CJK UNIFIED IDEOGRAPH-#210CC, IRGKangXi=0213.171, RSKangXi=30.15
210CD CJK UNIFIED IDEOGRAPH-#210CD, IRGKangXi=0213.171, RSKangXi=30.15
210CE CJK UNIFIED IDEOGRAPH-#210CE, IRGKangXi=0213.171, RSKangXi=30.15
210CF CJK UNIFIED IDEOGRAPH-#210CF, IRGKangXi=0213.171, RSKangXi=30.15, Def{(Cant.) to droop, hang down}
210D0 CJK UNIFIED IDEOGRAPH-#210D0, IRGKangXi=0213.171, RSKangXi=30.15
210D1 CJK UNIFIED IDEOGRAPH-#210D1, IRGKangXi=0213.171, RSKangXi=30.15
210D2 CJK UNIFIED IDEOGRAPH-#210D2, IRGKangXi=0213.171, RSKangXi=30.15
210D3 CJK UNIFIED IDEOGRAPH-#210D3, IRGKangXi=0213.171, RSKangXi=30.15, Def{(Cant.) final particle for emphasis}
210D4 CJK UNIFIED IDEOGRAPH-#210D4, IRGKangXi=0213.171, RSKangXi=30.15
210D5 CJK UNIFIED IDEOGRAPH-#210D5, IRGKangXi=0213.171, RSKangXi=30.15
210D6 CJK UNIFIED IDEOGRAPH-#210D6, IRGKangXi=0213.171, RSKangXi=30.15, Def{call for pigs}
210D7 CJK UNIFIED IDEOGRAPH-#210D7, IRGKangXi=0213.171, RSKangXi=30.15
210D8 CJK UNIFIED IDEOGRAPH-#210D8, IRGKangXi=0213.171, RSKangXi=30.15
210D9 CJK UNIFIED IDEOGRAPH-#210D9, IRGKangXi=0213.171, RSKangXi=30.15
210DA CJK UNIFIED IDEOGRAPH-#210DA, IRGKangXi=0213.171, RSKangXi=30.15
210DB CJK UNIFIED IDEOGRAPH-#210DB, IRGKangXi=0213.171, RSKangXi=30.15
210DC CJK UNIFIED IDEOGRAPH-#210DC, IRGKangXi=0213.171, RSKangXi=30.15
210DD CJK UNIFIED IDEOGRAPH-#210DD, IRGKangXi=0213.171, RSKangXi=30.15
210DE CJK UNIFIED IDEOGRAPH-#210DE, IRGKangXi=0213.171, RSKangXi=30.15
210DF CJK UNIFIED IDEOGRAPH-#210DF, IRGKangXi=0213.171, RSKangXi=30.15
210E0 CJK UNIFIED IDEOGRAPH-#210E0, IRGKangXi=0213.171, RSKangXi=30.16
210E1 CJK UNIFIED IDEOGRAPH-#210E1, IRGKangXi=0213.240, RSKangXi=30.16
210E2 CJK UNIFIED IDEOGRAPH-#210E2, IRGKangXi=0213.250, RSKangXi=30.16
210E3 CJK UNIFIED IDEOGRAPH-#210E3, IRGKangXi=0213.260, RSKangXi=30.16
210E4 CJK UNIFIED IDEOGRAPH-#210E4, IRGKangXi=0213.270, RSKangXi=30.16, Def{(Cant.) to leave behind, omit}
210E5 CJK UNIFIED IDEOGRAPH-#210E5, IRGKangXi=0213.290, RSKangXi=30.16
210E6 CJK UNIFIED IDEOGRAPH-#210E6, IRGKangXi=0213.300, RSKangXi=30.16
210E7 CJK UNIFIED IDEOGRAPH-#210E7, IRGKangXi=0213.320, RSKangXi=30.16
210E8 CJK UNIFIED IDEOGRAPH-#210E8, IRGKangXi=0213.330, RSKangXi=30.16
210E9 CJK UNIFIED IDEOGRAPH-#210E9, IRGKangXi=0213.360, RSKangXi=30.16
210EA CJK UNIFIED IDEOGRAPH-#210EA, IRGKangXi=0213.420, RSKangXi=30.16
210EB CJK UNIFIED IDEOGRAPH-#210EB, IRGKangXi=0213.430, RSKangXi=30.16
210EC CJK UNIFIED IDEOGRAPH-#210EC, IRGKangXi=0213.440, RSKangXi=30.16
210ED CJK UNIFIED IDEOGRAPH-#210ED, IRGKangXi=0213.450, RSKangXi=30.16
210EE CJK UNIFIED IDEOGRAPH-#210EE, IRGKangXi=0213.460, RSKangXi=30.16
210EF CJK UNIFIED IDEOGRAPH-#210EF, IRGKangXi=0213.470, RSKangXi=30.16
210F0 CJK UNIFIED IDEOGRAPH-#210F0, IRGKangXi=0213.471, RSKangXi=30.15
210F1 CJK UNIFIED IDEOGRAPH-#210F1, IRGKangXi=0213.471, RSKangXi=30.16
210F2 CJK UNIFIED IDEOGRAPH-#210F2, IRGKangXi=0213.471, RSKangXi=30.16
210F3 CJK UNIFIED IDEOGRAPH-#210F3, IRGKangXi=0213.471, RSKangXi=30.16
210F4 CJK UNIFIED IDEOGRAPH-#210F4, IRGKangXi=0213.471, RSKangXi=30.16, Def{(Cant.) smell, odor}
210F5 CJK UNIFIED IDEOGRAPH-#210F5, IRGKangXi=0213.471, RSKangXi=30.16, Def{(Cant.) to cover, bury; push from behind}
210F6 CJK UNIFIED IDEOGRAPH-#210F6, IRGKangXi=0213.471, RSKangXi=30.16, Def{(Cant.) to like, love; to kiss}
210F7 CJK UNIFIED IDEOGRAPH-#210F7, IRGKangXi=0213.471, RSKangXi=30.16
210F8 CJK UNIFIED IDEOGRAPH-#210F8, IRGKangXi=0213.471, RSKangXi=30.16
210F9 CJK UNIFIED IDEOGRAPH-#210F9, IRGKangXi=0213.471, RSKangXi=30.16
210FA CJK UNIFIED IDEOGRAPH-#210FA, IRGKangXi=0213.471, RSKangXi=30.16
210FB CJK UNIFIED IDEOGRAPH-#210FB, IRGKangXi=0213.471, RSKangXi=30.16
210FC CJK UNIFIED IDEOGRAPH-#210FC, IRGKangXi=0213.471, RSKangXi=30.16
210FD CJK UNIFIED IDEOGRAPH-#210FD, IRGKangXi=0213.471, RSKangXi=30.16
210FE CJK UNIFIED IDEOGRAPH-#210FE, IRGKangXi=0213.471, RSKangXi=30.16
210FF CJK UNIFIED IDEOGRAPH-#210FF, IRGKangXi=0213.471, RSKangXi=30.16
21100 CJK UNIFIED IDEOGRAPH-#21100, IRGKangXi=0213.471, RSKangXi=30.16
21101 CJK UNIFIED IDEOGRAPH-#21101, IRGKangXi=0213.471, RSKangXi=30.16
21102 CJK UNIFIED IDEOGRAPH-#21102, IRGKangXi=0213.471, RSKangXi=30.16
21103 CJK UNIFIED IDEOGRAPH-#21103, IRGKangXi=0213.471, RSKangXi=30.16
21104 CJK UNIFIED IDEOGRAPH-#21104, IRGKangXi=0213.471, RSKangXi=30.16
21105 CJK UNIFIED IDEOGRAPH-#21105, IRGKangXi=0213.471, RSKangXi=30.16
21106 CJK UNIFIED IDEOGRAPH-#21106, IRGKangXi=0213.471, RSKangXi=30.16
21107 CJK UNIFIED IDEOGRAPH-#21107, IRGKangXi=0213.471, RSKangXi=30.16
21108 CJK UNIFIED IDEOGRAPH-#21108, IRGKangXi=0213.471, RSKangXi=30.16
21109 CJK UNIFIED IDEOGRAPH-#21109, IRGKangXi=0213.471, RSKangXi=89.15
2110A CJK UNIFIED IDEOGRAPH-#2110A, IRGKangXi=0213.471, RSKangXi=30.16
2110B CJK UNIFIED IDEOGRAPH-#2110B, IRGKangXi=0213.471, RSKangXi=30.16
2110C CJK UNIFIED IDEOGRAPH-#2110C, IRGKangXi=0213.471, RSKangXi=30.16
2110D CJK UNIFIED IDEOGRAPH-#2110D, IRGKangXi=0213.471, RSKangXi=30.16
2110E CJK UNIFIED IDEOGRAPH-#2110E, IRGKangXi=0213.471, RSKangXi=30.16
2110F CJK UNIFIED IDEOGRAPH-#2110F, IRGKangXi=0213.471, RSKangXi=30.16
21110 CJK UNIFIED IDEOGRAPH-#21110, IRGKangXi=0213.471, RSKangXi=30.16
21111 CJK UNIFIED IDEOGRAPH-#21111, IRGKangXi=0213.490, RSKangXi=30.17
21112 CJK UNIFIED IDEOGRAPH-#21112, IRGKangXi=0213.500, RSKangXi=30.17
21113 CJK UNIFIED IDEOGRAPH-#21113, IRGKangXi=0213.510, RSKangXi=30.17
21114 CJK UNIFIED IDEOGRAPH-#21114, IRGKangXi=0214.010, RSKangXi=30.17
21115 CJK UNIFIED IDEOGRAPH-#21115, IRGKangXi=0214.020, RSKangXi=30.17
21116 CJK UNIFIED IDEOGRAPH-#21116, IRGKangXi=0214.050, RSKangXi=30.17
21117 CJK UNIFIED IDEOGRAPH-#21117, IRGKangXi=0214.090, RSKangXi=30.17
21118 CJK UNIFIED IDEOGRAPH-#21118, IRGKangXi=0214.120, RSKangXi=30.17
21119 CJK UNIFIED IDEOGRAPH-#21119, IRGKangXi=0214.130, RSKangXi=30.17
2111A CJK UNIFIED IDEOGRAPH-#2111A, IRGKangXi=0214.140, RSKangXi=30.17
2111B CJK UNIFIED IDEOGRAPH-#2111B, IRGKangXi=0214.150, RSKangXi=30.17
2111C CJK UNIFIED IDEOGRAPH-#2111C, IRGKangXi=0214.151, RSKangXi=30.17
2111D CJK UNIFIED IDEOGRAPH-#2111D, IRGKangXi=0214.151, RSKangXi=30.17
2111E CJK UNIFIED IDEOGRAPH-#2111E, IRGKangXi=0214.151, RSKangXi=30.17
2111F CJK UNIFIED IDEOGRAPH-#2111F, IRGKangXi=0214.151, RSKangXi=30.17, Def{(Cant.) onomatopoetic, the sound of panting}
21120 CJK UNIFIED IDEOGRAPH-#21120, IRGKangXi=0214.151, RSKangXi=30.17
21121 CJK UNIFIED IDEOGRAPH-#21121, IRGKangXi=0214.151, RSKangXi=30.17
21122 CJK UNIFIED IDEOGRAPH-#21122, IRGKangXi=0214.151, RSKangXi=30.17
21123 CJK UNIFIED IDEOGRAPH-#21123, IRGKangXi=0214.151, RSKangXi=30.17
21124 CJK UNIFIED IDEOGRAPH-#21124, IRGKangXi=0214.151, RSKangXi=30.17
21125 CJK UNIFIED IDEOGRAPH-#21125, IRGKangXi=0214.151, RSKangXi=30.17
21126 CJK UNIFIED IDEOGRAPH-#21126, IRGKangXi=0214.151, RSKangXi=30.17
21127 CJK UNIFIED IDEOGRAPH-#21127, IRGKangXi=0214.151, RSKangXi=30.17
21128 CJK UNIFIED IDEOGRAPH-#21128, IRGKangXi=0214.151, RSKangXi=30.17
21129 CJK UNIFIED IDEOGRAPH-#21129, IRGKangXi=0214.151, RSKangXi=30.17
2112A CJK UNIFIED IDEOGRAPH-#2112A, IRGKangXi=0214.151, RSKangXi=30.17
2112B CJK UNIFIED IDEOGRAPH-#2112B, IRGKangXi=0214.151, RSKangXi=30.17
2112C CJK UNIFIED IDEOGRAPH-#2112C, IRGKangXi=0214.151, RSKangXi=30.17
2112D CJK UNIFIED IDEOGRAPH-#2112D, IRGKangXi=0214.151, RSKangXi=30.17
2112E CJK UNIFIED IDEOGRAPH-#2112E, IRGKangXi=0214.151, RSKangXi=30.17
2112F CJK UNIFIED IDEOGRAPH-#2112F, IRGKangXi=0214.151, RSKangXi=30.17, Def{(Cant.) hiccough}
21130 CJK UNIFIED IDEOGRAPH-#21130, IRGKangXi=0214.151, RSKangXi=30.17
21131 CJK UNIFIED IDEOGRAPH-#21131, IRGKangXi=0214.170, RSKangXi=30.18
21132 CJK UNIFIED IDEOGRAPH-#21132, IRGKangXi=0214.200, RSKangXi=30.18
21133 CJK UNIFIED IDEOGRAPH-#21133, IRGKangXi=0214.210, RSKangXi=30.18
21134 CJK UNIFIED IDEOGRAPH-#21134, IRGKangXi=0214.220, RSKangXi=30.18
21135 CJK UNIFIED IDEOGRAPH-#21135, IRGKangXi=0214.230, RSKangXi=30.18, Def{(Cant.) to grin, laugh}
21136 CJK UNIFIED IDEOGRAPH-#21136, IRGKangXi=0214.260, RSKangXi=30.18
21137 CJK UNIFIED IDEOGRAPH-#21137, IRGKangXi=0214.290, RSKangXi=30.18
21138 CJK UNIFIED IDEOGRAPH-#21138, IRGKangXi=0215.010, RSKangXi=30.18
21139 CJK UNIFIED IDEOGRAPH-#21139, IRGKangXi=0215.030, RSKangXi=30.18
2113A CJK UNIFIED IDEOGRAPH-#2113A, IRGKangXi=0215.040, RSKangXi=30.18
2113B CJK UNIFIED IDEOGRAPH-#2113B, IRGKangXi=0215.050, RSKangXi=30.18
2113C CJK UNIFIED IDEOGRAPH-#2113C, IRGKangXi=0215.051, RSKangXi=30.18
2113D CJK UNIFIED IDEOGRAPH-#2113D, IRGKangXi=0215.051, RSKangXi=30.18, Def{(Cant.) to slide down}
2113E CJK UNIFIED IDEOGRAPH-#2113E, IRGKangXi=0215.051, RSKangXi=30.18
2113F CJK UNIFIED IDEOGRAPH-#2113F, IRGKangXi=0215.051, RSKangXi=30.18
21140 CJK UNIFIED IDEOGRAPH-#21140, IRGKangXi=0215.051, RSKangXi=30.18
21141 CJK UNIFIED IDEOGRAPH-#21141, IRGKangXi=0215.051, RSKangXi=30.18
21142 CJK UNIFIED IDEOGRAPH-#21142, IRGKangXi=0215.051, RSKangXi=30.18
21143 CJK UNIFIED IDEOGRAPH-#21143, IRGKangXi=0215.051, RSKangXi=30.18
21144 CJK UNIFIED IDEOGRAPH-#21144, IRGKangXi=0215.051, RSKangXi=30.18
21145 CJK UNIFIED IDEOGRAPH-#21145, IRGKangXi=0215.051, RSKangXi=30.18
21146 CJK UNIFIED IDEOGRAPH-#21146, IRGKangXi=0215.051, RSKangXi=30.18
21147 CJK UNIFIED IDEOGRAPH-#21147, IRGKangXi=0215.051, RSKangXi=30.18
21148 CJK UNIFIED IDEOGRAPH-#21148, IRGKangXi=0215.051, RSKangXi=30.18, Def{(Cant.) a particle implying completion, certainty, or urgency}
21149 CJK UNIFIED IDEOGRAPH-#21149, IRGKangXi=0215.051, RSKangXi=30.18
2114A CJK UNIFIED IDEOGRAPH-#2114A, IRGKangXi=0215.051, RSKangXi=30.18
2114B CJK UNIFIED IDEOGRAPH-#2114B, IRGKangXi=0215.051, RSKangXi=30.18
2114C CJK UNIFIED IDEOGRAPH-#2114C, IRGKangXi=0215.051, RSKangXi=30.18
2114D CJK UNIFIED IDEOGRAPH-#2114D, IRGKangXi=0215.051, RSKangXi=30.18
2114E CJK UNIFIED IDEOGRAPH-#2114E, IRGKangXi=0215.051, RSKangXi=30.18
2114F CJK UNIFIED IDEOGRAPH-#2114F, IRGKangXi=0215.051, RSKangXi=30.18, Def{(Cant.) to accuse, slander; to turn, sprain}
21150 CJK UNIFIED IDEOGRAPH-#21150, IRGKangXi=0215.051, RSKangXi=30.18
21151 CJK UNIFIED IDEOGRAPH-#21151, IRGKangXi=0215.051, RSKangXi=30.18
21152 CJK UNIFIED IDEOGRAPH-#21152, IRGKangXi=0215.051, RSKangXi=30.18
21153 CJK UNIFIED IDEOGRAPH-#21153, IRGKangXi=0215.051, RSKangXi=30.18
21154 CJK UNIFIED IDEOGRAPH-#21154, IRGKangXi=0215.051, RSKangXi=30.18
21155 CJK UNIFIED IDEOGRAPH-#21155, IRGKangXi=0215.051, RSKangXi=33.18
21156 CJK UNIFIED IDEOGRAPH-#21156, IRGKangXi=0215.051, RSKangXi=123.15
21157 CJK UNIFIED IDEOGRAPH-#21157, IRGKangXi=0215.080, RSKangXi=30.19
21158 CJK UNIFIED IDEOGRAPH-#21158, IRGKangXi=0215.110, RSKangXi=30.19
21159 CJK UNIFIED IDEOGRAPH-#21159, IRGKangXi=0215.130, RSKangXi=30.19
2115A CJK UNIFIED IDEOGRAPH-#2115A, IRGKangXi=0215.170, RSKangXi=30.19
2115B CJK UNIFIED IDEOGRAPH-#2115B, IRGKangXi=0215.180, RSKangXi=30.19
2115C CJK UNIFIED IDEOGRAPH-#2115C, IRGKangXi=0215.190, RSKangXi=30.19
2115D CJK UNIFIED IDEOGRAPH-#2115D, IRGKangXi=0215.200, RSKangXi=30.19
2115E CJK UNIFIED IDEOGRAPH-#2115E, IRGKangXi=0215.210, RSKangXi=30.19
2115F CJK UNIFIED IDEOGRAPH-#2115F, IRGKangXi=0215.220, RSKangXi=30.19
21160 CJK UNIFIED IDEOGRAPH-#21160, IRGKangXi=0215.221, RSKangXi=30.19
21161 CJK UNIFIED IDEOGRAPH-#21161, IRGKangXi=0215.221, RSKangXi=30.19
21162 CJK UNIFIED IDEOGRAPH-#21162, IRGKangXi=0215.221, RSKangXi=30.19
21163 CJK UNIFIED IDEOGRAPH-#21163, IRGKangXi=0215.221, RSKangXi=30.18
21164 CJK UNIFIED IDEOGRAPH-#21164, IRGKangXi=0215.221, RSKangXi=30.19
21165 CJK UNIFIED IDEOGRAPH-#21165, IRGKangXi=0215.221, RSKangXi=30.19
21166 CJK UNIFIED IDEOGRAPH-#21166, IRGKangXi=0215.221, RSKangXi=30.19
21167 CJK UNIFIED IDEOGRAPH-#21167, IRGKangXi=0215.221, RSKangXi=30.19
21168 CJK UNIFIED IDEOGRAPH-#21168, IRGKangXi=0215.221, RSKangXi=30.19
21169 CJK UNIFIED IDEOGRAPH-#21169, IRGKangXi=0215.221, RSKangXi=30.19
2116A CJK UNIFIED IDEOGRAPH-#2116A, IRGKangXi=0215.221, RSKangXi=30.19
2116B CJK UNIFIED IDEOGRAPH-#2116B, IRGKangXi=0215.221, RSKangXi=30.19
2116C CJK UNIFIED IDEOGRAPH-#2116C, IRGKangXi=0215.221, RSKangXi=30.19
2116D CJK UNIFIED IDEOGRAPH-#2116D, IRGKangXi=0215.221, RSKangXi=30.19
2116E CJK UNIFIED IDEOGRAPH-#2116E, IRGKangXi=0215.221, RSKangXi=30.19
2116F CJK UNIFIED IDEOGRAPH-#2116F, IRGKangXi=0215.221, RSKangXi=30.19
21170 CJK UNIFIED IDEOGRAPH-#21170, IRGKangXi=0215.260, RSKangXi=30.20
21171 CJK UNIFIED IDEOGRAPH-#21171, IRGKangXi=0215.270, RSKangXi=30.20
21172 CJK UNIFIED IDEOGRAPH-#21172, IRGKangXi=0215.271, RSKangXi=30.20
21173 CJK UNIFIED IDEOGRAPH-#21173, IRGKangXi=0215.271, RSKangXi=30.20
21174 CJK UNIFIED IDEOGRAPH-#21174, IRGKangXi=0215.271, RSKangXi=30.20
21175 CJK UNIFIED IDEOGRAPH-#21175, IRGKangXi=0215.271, RSKangXi=30.20
21176 CJK UNIFIED IDEOGRAPH-#21176, IRGKangXi=0215.271, RSKangXi=30.20
21177 CJK UNIFIED IDEOGRAPH-#21177, IRGKangXi=0215.271, RSKangXi=30.20
21178 CJK UNIFIED IDEOGRAPH-#21178, IRGKangXi=0215.271, RSKangXi=30.20
21179 CJK UNIFIED IDEOGRAPH-#21179, IRGKangXi=0215.280, RSKangXi=30.21
2117A CJK UNIFIED IDEOGRAPH-#2117A, IRGKangXi=0215.300, RSKangXi=30.21
2117B CJK UNIFIED IDEOGRAPH-#2117B, IRGKangXi=0215.310, RSKangXi=30.21
2117C CJK UNIFIED IDEOGRAPH-#2117C, IRGKangXi=0216.020, RSKangXi=30.21
2117D CJK UNIFIED IDEOGRAPH-#2117D, IRGKangXi=0216.030, RSKangXi=30.21
2117E CJK UNIFIED IDEOGRAPH-#2117E, IRGKangXi=0216.040, RSKangXi=30.21
2117F CJK UNIFIED IDEOGRAPH-#2117F, IRGKangXi=0216.050, RSKangXi=30.21
21180 CJK UNIFIED IDEOGRAPH-#21180, IRGKangXi=0216.051, RSKangXi=30.21, Def{(Cant.) special relationship}
21181 CJK UNIFIED IDEOGRAPH-#21181, IRGKangXi=0216.051, RSKangXi=30.21
21182 CJK UNIFIED IDEOGRAPH-#21182, IRGKangXi=0216.051, RSKangXi=30.21
21183 CJK UNIFIED IDEOGRAPH-#21183, IRGKangXi=0216.051, RSKangXi=30.21
21184 CJK UNIFIED IDEOGRAPH-#21184, IRGKangXi=0216.051, RSKangXi=30.21
21185 CJK UNIFIED IDEOGRAPH-#21185, IRGKangXi=0216.051, RSKangXi=30.21
21186 CJK UNIFIED IDEOGRAPH-#21186, IRGKangXi=0216.060, RSKangXi=30.22
21187 CJK UNIFIED IDEOGRAPH-#21187, IRGKangXi=0216.071, RSKangXi=30.22, Def{(Cant.) a watt (Engl. loan-word)}
21188 CJK UNIFIED IDEOGRAPH-#21188, IRGKangXi=0216.071, RSKangXi=30.22
21189 CJK UNIFIED IDEOGRAPH-#21189, IRGKangXi=0216.071, RSKangXi=30.22
2118A CJK UNIFIED IDEOGRAPH-#2118A, IRGKangXi=0216.071, RSKangXi=30.22
2118B CJK UNIFIED IDEOGRAPH-#2118B, IRGKangXi=0216.071, RSKangXi=30.22
2118C CJK UNIFIED IDEOGRAPH-#2118C, IRGKangXi=0216.071, RSKangXi=30.22
2118D CJK UNIFIED IDEOGRAPH-#2118D, IRGKangXi=0216.071, RSKangXi=30.22
2118E CJK UNIFIED IDEOGRAPH-#2118E, IRGKangXi=0216.071, RSKangXi=30.22
2118F CJK UNIFIED IDEOGRAPH-#2118F, IRGKangXi=0216.080, RSKangXi=30.23
21190 CJK UNIFIED IDEOGRAPH-#21190, IRGKangXi=0216.090, RSKangXi=30.23
21191 CJK UNIFIED IDEOGRAPH-#21191, IRGKangXi=0216.100, RSKangXi=30.23
21192 CJK UNIFIED IDEOGRAPH-#21192, IRGKangXi=0216.120, RSKangXi=30.23
21193 CJK UNIFIED IDEOGRAPH-#21193, IRGKangXi=0216.130, RSKangXi=30.23
21194 CJK UNIFIED IDEOGRAPH-#21194, IRGKangXi=0216.131, RSKangXi=30.23
21195 CJK UNIFIED IDEOGRAPH-#21195, IRGKangXi=0216.131, RSKangXi=30.23
21196 CJK UNIFIED IDEOGRAPH-#21196, IRGKangXi=0216.131, RSKangXi=30.23
21197 CJK UNIFIED IDEOGRAPH-#21197, IRGKangXi=0216.131, RSKangXi=30.23
21198 CJK UNIFIED IDEOGRAPH-#21198, IRGKangXi=0216.131, RSKangXi=30.23
21199 CJK UNIFIED IDEOGRAPH-#21199, IRGKangXi=0216.131, RSKangXi=30.24
2119A CJK UNIFIED IDEOGRAPH-#2119A, IRGKangXi=0216.131, RSKangXi=30.24
2119B CJK UNIFIED IDEOGRAPH-#2119B, IRGKangXi=0216.131, RSKangXi=30.25
2119C CJK UNIFIED IDEOGRAPH-#2119C, IRGKangXi=0216.131, RSKangXi=30.25
2119D CJK UNIFIED IDEOGRAPH-#2119D, IRGKangXi=0216.131, RSKangXi=30.25
2119E CJK UNIFIED IDEOGRAPH-#2119E, IRGKangXi=0216.131, RSKangXi=30.24
2119F CJK UNIFIED IDEOGRAPH-#2119F, IRGKangXi=0216.131, RSKangXi=30.28
211A0 CJK UNIFIED IDEOGRAPH-#211A0, IRGKangXi=0216.150, RSKangXi=31.1
211A1 CJK UNIFIED IDEOGRAPH-#211A1, IRGKangXi=0216.160, RSKangXi=31.1
211A2 CJK UNIFIED IDEOGRAPH-#211A2, IRGKangXi=0216.161, RSKangXi=31.1
211A3 CJK UNIFIED IDEOGRAPH-#211A3, IRGKangXi=0216.210, RSKangXi=31.2
211A4 CJK UNIFIED IDEOGRAPH-#211A4, IRGKangXi=0216.231, RSKangXi=31.2
211A5 CJK UNIFIED IDEOGRAPH-#211A5, IRGKangXi=0216.231, RSKangXi=31.2
211A6 CJK UNIFIED IDEOGRAPH-#211A6, IRGKangXi=0216.231, RSKangXi=31.2
211A7 CJK UNIFIED IDEOGRAPH-#211A7, IRGKangXi=0216.250, RSKangXi=31.3
211A8 CJK UNIFIED IDEOGRAPH-#211A8, IRGKangXi=0217.010, RSKangXi=31.3
211A9 CJK UNIFIED IDEOGRAPH-#211A9, IRGKangXi=0217.040, RSKangXi=31.3
211AA CJK UNIFIED IDEOGRAPH-#211AA, IRGKangXi=0217.050, RSKangXi=31.3
211AB CJK UNIFIED IDEOGRAPH-#211AB, IRGKangXi=0217.061, RSKangXi=31.3
211AC CJK UNIFIED IDEOGRAPH-#211AC, IRGKangXi=0217.061, RSKangXi=31.3
211AD CJK UNIFIED IDEOGRAPH-#211AD, IRGKangXi=0217.061, RSKangXi=31.3
211AE CJK UNIFIED IDEOGRAPH-#211AE, IRGKangXi=0217.061, RSKangXi=31.3
211AF CJK UNIFIED IDEOGRAPH-#211AF, IRGKangXi=0217.061, RSKangXi=31.3
211B0 CJK UNIFIED IDEOGRAPH-#211B0, IRGKangXi=0217.061, RSKangXi=31.3
211B1 CJK UNIFIED IDEOGRAPH-#211B1, IRGKangXi=0217.061, RSKangXi=31.3
211B2 CJK UNIFIED IDEOGRAPH-#211B2, IRGKangXi=0217.061, RSKangXi=31.3
211B3 CJK UNIFIED IDEOGRAPH-#211B3, IRGKangXi=0217.061, RSKangXi=31.3
211B4 CJK UNIFIED IDEOGRAPH-#211B4, IRGKangXi=0217.150, RSKangXi=31.4
211B5 CJK UNIFIED IDEOGRAPH-#211B5, IRGKangXi=0217.220, RSKangXi=31.4
211B6 CJK UNIFIED IDEOGRAPH-#211B6, IRGKangXi=0217.230, RSKangXi=31.4
211B7 CJK UNIFIED IDEOGRAPH-#211B7, IRGKangXi=0217.240, RSKangXi=31.4
211B8 CJK UNIFIED IDEOGRAPH-#211B8, IRGKangXi=0217.250, RSKangXi=31.4
211B9 CJK UNIFIED IDEOGRAPH-#211B9, IRGKangXi=0217.251, RSKangXi=31.4
211BA CJK UNIFIED IDEOGRAPH-#211BA, IRGKangXi=0217.251, RSKangXi=31.4
211BB CJK UNIFIED IDEOGRAPH-#211BB, IRGKangXi=0217.251, RSKangXi=31.4
211BC CJK UNIFIED IDEOGRAPH-#211BC, IRGKangXi=0217.251, RSKangXi=31.4
211BD CJK UNIFIED IDEOGRAPH-#211BD, IRGKangXi=0217.251, RSKangXi=31.4
211BE CJK UNIFIED IDEOGRAPH-#211BE, IRGKangXi=0217.251, RSKangXi=31.4
211BF CJK UNIFIED IDEOGRAPH-#211BF, IRGKangXi=0217.251, RSKangXi=31.4
211C0 CJK UNIFIED IDEOGRAPH-#211C0, IRGKangXi=0217.251, RSKangXi=31.4
211C1 CJK UNIFIED IDEOGRAPH-#211C1, IRGKangXi=0217.251, RSKangXi=31.4
211C2 CJK UNIFIED IDEOGRAPH-#211C2, IRGKangXi=0217.251, RSKangXi=31.4
211C3 CJK UNIFIED IDEOGRAPH-#211C3, IRGKangXi=0217.251, RSKangXi=31.4
211C4 CJK UNIFIED IDEOGRAPH-#211C4, IRGKangXi=0217.251, RSKangXi=31.4
211C5 CJK UNIFIED IDEOGRAPH-#211C5, IRGKangXi=0217.251, RSKangXi=31.4
211C6 CJK UNIFIED IDEOGRAPH-#211C6, IRGKangXi=0217.251, RSKangXi=31.4
211C7 CJK UNIFIED IDEOGRAPH-#211C7, IRGKangXi=0217.251, RSKangXi=31.4
211C8 CJK UNIFIED IDEOGRAPH-#211C8, IRGKangXi=0217.270, RSKangXi=31.5
211C9 CJK UNIFIED IDEOGRAPH-#211C9, IRGKangXi=0217.280, RSKangXi=31.5
211CA CJK UNIFIED IDEOGRAPH-#211CA, IRGKangXi=0217.300, RSKangXi=31.5
211CB CJK UNIFIED IDEOGRAPH-#211CB, IRGKangXi=0218.041, RSKangXi=31.5
211CC CJK UNIFIED IDEOGRAPH-#211CC, IRGKangXi=0218.041, RSKangXi=31.5
211CD CJK UNIFIED IDEOGRAPH-#211CD, IRGKangXi=0218.041, RSKangXi=102.3
211CE CJK UNIFIED IDEOGRAPH-#211CE, IRGKangXi=0218.041, RSKangXi=31.5
211CF CJK UNIFIED IDEOGRAPH-#211CF, IRGKangXi=0218.041, RSKangXi=31.5
211D0 CJK UNIFIED IDEOGRAPH-#211D0, IRGKangXi=0218.041, RSKangXi=31.5
211D1 CJK UNIFIED IDEOGRAPH-#211D1, IRGKangXi=0218.041, RSKangXi=31.5
211D2 CJK UNIFIED IDEOGRAPH-#211D2, IRGKangXi=0218.060, RSKangXi=31.6
211D3 CJK UNIFIED IDEOGRAPH-#211D3, IRGKangXi=0218.070, RSKangXi=31.6
211D4 CJK UNIFIED IDEOGRAPH-#211D4, IRGKangXi=0218.090, RSKangXi=31.6
211D5 CJK UNIFIED IDEOGRAPH-#211D5, IRGKangXi=0218.100, RSKangXi=31.6
211D6 CJK UNIFIED IDEOGRAPH-#211D6, IRGKangXi=0218.120, RSKangXi=31.6
211D7 CJK UNIFIED IDEOGRAPH-#211D7, IRGKangXi=0218.130, RSKangXi=31.6
211D8 CJK UNIFIED IDEOGRAPH-#211D8, IRGKangXi=0218.140, RSKangXi=31.6
211D9 CJK UNIFIED IDEOGRAPH-#211D9, IRGKangXi=0218.141, RSKangXi=31.6, Def{(Cant.) round and full}
211DA CJK UNIFIED IDEOGRAPH-#211DA, IRGKangXi=0218.141, RSKangXi=31.6
211DB CJK UNIFIED IDEOGRAPH-#211DB, IRGKangXi=0218.141, RSKangXi=31.6
211DC CJK UNIFIED IDEOGRAPH-#211DC, IRGKangXi=0218.141, RSKangXi=31.6
211DD CJK UNIFIED IDEOGRAPH-#211DD, IRGKangXi=0218.141, RSKangXi=31.6
211DE CJK UNIFIED IDEOGRAPH-#211DE, IRGKangXi=0218.141, RSKangXi=31.6
211DF CJK UNIFIED IDEOGRAPH-#211DF, IRGKangXi=0218.141, RSKangXi=31.6
211E0 CJK UNIFIED IDEOGRAPH-#211E0, IRGKangXi=0218.150, RSKangXi=31.7
211E1 CJK UNIFIED IDEOGRAPH-#211E1, IRGKangXi=0218.160, RSKangXi=31.7
211E2 CJK UNIFIED IDEOGRAPH-#211E2, IRGKangXi=0218.190, RSKangXi=31.7
211E3 CJK UNIFIED IDEOGRAPH-#211E3, IRGKangXi=0219.030, RSKangXi=31.7
211E4 CJK UNIFIED IDEOGRAPH-#211E4, IRGKangXi=0219.040, RSKangXi=31.7
211E5 CJK UNIFIED IDEOGRAPH-#211E5, IRGKangXi=0219.041, RSKangXi=31.7
211E6 CJK UNIFIED IDEOGRAPH-#211E6, IRGKangXi=0219.041, RSKangXi=31.7
211E7 CJK UNIFIED IDEOGRAPH-#211E7, IRGKangXi=0219.041, RSKangXi=31.7
211E8 CJK UNIFIED IDEOGRAPH-#211E8, IRGKangXi=0219.041, RSKangXi=31.7
211E9 CJK UNIFIED IDEOGRAPH-#211E9, IRGKangXi=0219.041, RSKangXi=31.7
211EA CJK UNIFIED IDEOGRAPH-#211EA, IRGKangXi=0219.041, RSKangXi=31.7
211EB CJK UNIFIED IDEOGRAPH-#211EB, IRGKangXi=0219.041, RSKangXi=31.7
211EC CJK UNIFIED IDEOGRAPH-#211EC, IRGKangXi=0219.041, RSKangXi=31.7
211ED CJK UNIFIED IDEOGRAPH-#211ED, IRGKangXi=0219.041, RSKangXi=31.7
211EE CJK UNIFIED IDEOGRAPH-#211EE, IRGKangXi=0219.041, RSKangXi=31.7
211EF CJK UNIFIED IDEOGRAPH-#211EF, IRGKangXi=0219.041, RSKangXi=31.7
211F0 CJK UNIFIED IDEOGRAPH-#211F0, IRGKangXi=0219.050, RSKangXi=31.8
211F1 CJK UNIFIED IDEOGRAPH-#211F1, IRGKangXi=0219.080, RSKangXi=31.8
211F2 CJK UNIFIED IDEOGRAPH-#211F2, IRGKangXi=0219.090, RSKangXi=31.8
211F3 CJK UNIFIED IDEOGRAPH-#211F3, IRGKangXi=0219.100, RSKangXi=31.8
211F4 CJK UNIFIED IDEOGRAPH-#211F4, IRGKangXi=0219.120, RSKangXi=31.8
211F5 CJK UNIFIED IDEOGRAPH-#211F5, IRGKangXi=0219.130, RSKangXi=31.8
211F6 CJK UNIFIED IDEOGRAPH-#211F6, IRGKangXi=0219.140, RSKangXi=31.8
211F7 CJK UNIFIED IDEOGRAPH-#211F7, IRGKangXi=0219.220, RSKangXi=31.8
211F8 CJK UNIFIED IDEOGRAPH-#211F8, IRGKangXi=0219.221, RSKangXi=31.8
211F9 CJK UNIFIED IDEOGRAPH-#211F9, IRGKangXi=0219.221, RSKangXi=31.8
211FA CJK UNIFIED IDEOGRAPH-#211FA, IRGKangXi=0219.221, RSKangXi=31.8
211FB CJK UNIFIED IDEOGRAPH-#211FB, IRGKangXi=0219.221, RSKangXi=31.8
211FC CJK UNIFIED IDEOGRAPH-#211FC, IRGKangXi=0219.230, RSKangXi=31.9
211FD CJK UNIFIED IDEOGRAPH-#211FD, IRGKangXi=0219.250, RSKangXi=31.9
211FE CJK UNIFIED IDEOGRAPH-#211FE, IRGKangXi=0220.030, RSKangXi=31.9
211FF CJK UNIFIED IDEOGRAPH-#211FF, IRGKangXi=0220.040, RSKangXi=31.9
21200 CJK UNIFIED IDEOGRAPH-#21200, IRGKangXi=0220.050, RSKangXi=31.8
21201 CJK UNIFIED IDEOGRAPH-#21201, IRGKangXi=0220.051, RSKangXi=31.9
21202 CJK UNIFIED IDEOGRAPH-#21202, IRGKangXi=0220.051, RSKangXi=31.9
21203 CJK UNIFIED IDEOGRAPH-#21203, IRGKangXi=0220.051, RSKangXi=31.9
21204 CJK UNIFIED IDEOGRAPH-#21204, IRGKangXi=0220.051, RSKangXi=31.9
21205 CJK UNIFIED IDEOGRAPH-#21205, IRGKangXi=0220.051, RSKangXi=31.9
21206 CJK UNIFIED IDEOGRAPH-#21206, IRGKangXi=0220.051, RSKangXi=31.9
21207 CJK UNIFIED IDEOGRAPH-#21207, IRGKangXi=0220.051, RSKangXi=31.9
21208 CJK UNIFIED IDEOGRAPH-#21208, IRGKangXi=0220.051, RSKangXi=31.9
21209 CJK UNIFIED IDEOGRAPH-#21209, IRGKangXi=0220.051, RSKangXi=31.9
2120A CJK UNIFIED IDEOGRAPH-#2120A, IRGKangXi=0220.070, RSKangXi=31.10
2120B CJK UNIFIED IDEOGRAPH-#2120B, IRGKangXi=0220.110, RSKangXi=31.10
2120C CJK UNIFIED IDEOGRAPH-#2120C, IRGKangXi=0220.120, RSKangXi=31.10
2120D CJK UNIFIED IDEOGRAPH-#2120D, IRGKangXi=0220.130, RSKangXi=31.10
2120E CJK UNIFIED IDEOGRAPH-#2120E, IRGKangXi=0220.140, RSKangXi=31.10, Def{a decoy; to inveigle}
2120F CJK UNIFIED IDEOGRAPH-#2120F, IRGKangXi=0220.150, RSKangXi=31.10
21210 CJK UNIFIED IDEOGRAPH-#21210, IRGKangXi=0220.151, RSKangXi=31.10
21211 CJK UNIFIED IDEOGRAPH-#21211, IRGKangXi=0220.151, RSKangXi=31.10
21212 CJK UNIFIED IDEOGRAPH-#21212, IRGKangXi=0220.151, RSKangXi=31.10
21213 CJK UNIFIED IDEOGRAPH-#21213, IRGKangXi=0220.151, RSKangXi=31.10
21214 CJK UNIFIED IDEOGRAPH-#21214, IRGKangXi=0220.151, RSKangXi=31.10
21215 CJK UNIFIED IDEOGRAPH-#21215, IRGKangXi=0220.170, RSKangXi=31.11
21216 CJK UNIFIED IDEOGRAPH-#21216, IRGKangXi=0221.030, RSKangXi=31.11
21217 CJK UNIFIED IDEOGRAPH-#21217, IRGKangXi=0221.040, RSKangXi=31.11
21218 CJK UNIFIED IDEOGRAPH-#21218, IRGKangXi=0221.050, RSKangXi=31.11
21219 CJK UNIFIED IDEOGRAPH-#21219, IRGKangXi=0221.060, RSKangXi=31.11, Def{decoy}
2121A CJK UNIFIED IDEOGRAPH-#2121A, IRGKangXi=0221.070, RSKangXi=31.11
2121B CJK UNIFIED IDEOGRAPH-#2121B, IRGKangXi=0221.071, RSKangXi=31.11
2121C CJK UNIFIED IDEOGRAPH-#2121C, IRGKangXi=0221.071, RSKangXi=31.11
2121D CJK UNIFIED IDEOGRAPH-#2121D, IRGKangXi=0221.071, RSKangXi=31.11
2121E CJK UNIFIED IDEOGRAPH-#2121E, IRGKangXi=0221.071, RSKangXi=31.11
2121F CJK UNIFIED IDEOGRAPH-#2121F, IRGKangXi=0221.071, RSKangXi=31.11
21220 CJK UNIFIED IDEOGRAPH-#21220, IRGKangXi=0221.071, RSKangXi=31.11
21221 CJK UNIFIED IDEOGRAPH-#21221, IRGKangXi=0221.071, RSKangXi=31.11
21222 CJK UNIFIED IDEOGRAPH-#21222, IRGKangXi=0221.090, RSKangXi=31.12
21223 CJK UNIFIED IDEOGRAPH-#21223, IRGKangXi=0221.100, RSKangXi=31.12
21224 CJK UNIFIED IDEOGRAPH-#21224, IRGKangXi=0221.101, RSKangXi=31.12
21225 CJK UNIFIED IDEOGRAPH-#21225, IRGKangXi=0221.101, RSKangXi=31.13
21226 CJK UNIFIED IDEOGRAPH-#21226, IRGKangXi=0221.101, RSKangXi=31.12
21227 CJK UNIFIED IDEOGRAPH-#21227, IRGKangXi=0221.101, RSKangXi=31.12
21228 CJK UNIFIED IDEOGRAPH-#21228, IRGKangXi=0221.101, RSKangXi=31.12
21229 CJK UNIFIED IDEOGRAPH-#21229, IRGKangXi=0221.101, RSKangXi=31.12
2122A CJK UNIFIED IDEOGRAPH-#2122A, IRGKangXi=0221.130, RSKangXi=31.13
2122B CJK UNIFIED IDEOGRAPH-#2122B, IRGKangXi=0221.131, RSKangXi=31.13
2122C CJK UNIFIED IDEOGRAPH-#2122C, IRGKangXi=0221.131, RSKangXi=31.13
2122D CJK UNIFIED IDEOGRAPH-#2122D, IRGKangXi=0221.140, RSKangXi=31.14
2122E CJK UNIFIED IDEOGRAPH-#2122E, IRGKangXi=0221.141, RSKangXi=31.14
2122F CJK UNIFIED IDEOGRAPH-#2122F, IRGKangXi=0221.141, RSKangXi=31.14
21230 CJK UNIFIED IDEOGRAPH-#21230, IRGKangXi=0221.141, RSKangXi=31.14
21231 CJK UNIFIED IDEOGRAPH-#21231, IRGKangXi=0221.141, RSKangXi=31.14
21232 CJK UNIFIED IDEOGRAPH-#21232, IRGKangXi=0221.141, RSKangXi=31.15
21233 CJK UNIFIED IDEOGRAPH-#21233, IRGKangXi=0221.150, RSKangXi=31.16
21234 CJK UNIFIED IDEOGRAPH-#21234, IRGKangXi=0221.151, RSKangXi=31.16
21235 CJK UNIFIED IDEOGRAPH-#21235, IRGKangXi=0221.161, RSKangXi=31.17
21236 CJK UNIFIED IDEOGRAPH-#21236, IRGKangXi=0221.161, RSKangXi=31.17
21237 CJK UNIFIED IDEOGRAPH-#21237, IRGKangXi=0221.161, RSKangXi=31.17
21238 CJK UNIFIED IDEOGRAPH-#21238, IRGKangXi=0221.170, RSKangXi=31.18
21239 CJK UNIFIED IDEOGRAPH-#21239, IRGKangXi=0221.180, RSKangXi=31.18
2123A CJK UNIFIED IDEOGRAPH-#2123A, IRGKangXi=0221.181, RSKangXi=31.18
2123B CJK UNIFIED IDEOGRAPH-#2123B, IRGKangXi=0221.191, RSKangXi=31.23
2123C CJK UNIFIED IDEOGRAPH-#2123C, IRGKangXi=0223.030, RSKangXi=32.1
2123D CJK UNIFIED IDEOGRAPH-#2123D, IRGKangXi=0223.031, RSKangXi=32.1, Def{Variant of U+571F 土}
2123E CJK UNIFIED IDEOGRAPH-#2123E, IRGKangXi=0223.031, RSKangXi=32.1
2123F CJK UNIFIED IDEOGRAPH-#2123F, IRGKangXi=0223.070, RSKangXi=32.2
21240 CJK UNIFIED IDEOGRAPH-#21240, IRGKangXi=0223.091, RSKangXi=32.2
21241 CJK UNIFIED IDEOGRAPH-#21241, IRGKangXi=0223.091, RSKangXi=32.2
21242 CJK UNIFIED IDEOGRAPH-#21242, IRGKangXi=0223.091, RSKangXi=32.2
21243 CJK UNIFIED IDEOGRAPH-#21243, IRGKangXi=0223.091, RSKangXi=32.2
21244 CJK UNIFIED IDEOGRAPH-#21244, IRGKangXi=0223.091, RSKangXi=32.2
21245 CJK UNIFIED IDEOGRAPH-#21245, IRGKangXi=0223.091, RSKangXi=32.2
21246 CJK UNIFIED IDEOGRAPH-#21246, IRGKangXi=0223.091, RSKangXi=32.2
21247 CJK UNIFIED IDEOGRAPH-#21247, IRGKangXi=0223.091, RSKangXi=32.2
21248 CJK UNIFIED IDEOGRAPH-#21248, IRGKangXi=0223.100, RSKangXi=32.3
21249 CJK UNIFIED IDEOGRAPH-#21249, IRGKangXi=0224.010, RSKangXi=32.3
2124A CJK UNIFIED IDEOGRAPH-#2124A, IRGKangXi=0224.140, RSKangXi=32.3
2124B CJK UNIFIED IDEOGRAPH-#2124B, IRGKangXi=0224.181, RSKangXi=32.3
2124C CJK UNIFIED IDEOGRAPH-#2124C, IRGKangXi=0224.181, RSKangXi=32.3
2124D CJK UNIFIED IDEOGRAPH-#2124D, IRGKangXi=0224.181, RSKangXi=32.3
2124E CJK UNIFIED IDEOGRAPH-#2124E, IRGKangXi=0224.181, RSKangXi=32.3
2124F CJK UNIFIED IDEOGRAPH-#2124F, IRGKangXi=0224.181, RSKangXi=32.3
21250 CJK UNIFIED IDEOGRAPH-#21250, IRGKangXi=0224.181, RSKangXi=32.3
21251 CJK UNIFIED IDEOGRAPH-#21251, IRGKangXi=0224.181, RSKangXi=32.3
21252 CJK UNIFIED IDEOGRAPH-#21252, IRGKangXi=0224.181, RSKangXi=32.3
21253 CJK UNIFIED IDEOGRAPH-#21253, IRGKangXi=0224.181, RSKangXi=32.3
21254 CJK UNIFIED IDEOGRAPH-#21254, IRGKangXi=0224.181, RSKangXi=32.3
21255 CJK UNIFIED IDEOGRAPH-#21255, IRGKangXi=0224.181, RSKangXi=32.3
21256 CJK UNIFIED IDEOGRAPH-#21256, IRGKangXi=0224.181, RSKangXi=32.3
21257 CJK UNIFIED IDEOGRAPH-#21257, IRGKangXi=0224.181, RSKangXi=39.3
21258 CJK UNIFIED IDEOGRAPH-#21258, IRGKangXi=0225.010, RSKangXi=32.4
21259 CJK UNIFIED IDEOGRAPH-#21259, IRGKangXi=0225.030, RSKangXi=32.4
2125A CJK UNIFIED IDEOGRAPH-#2125A, IRGKangXi=0225.130, RSKangXi=32.4
2125B CJK UNIFIED IDEOGRAPH-#2125B, IRGKangXi=0226.030, RSKangXi=32.4
2125C CJK UNIFIED IDEOGRAPH-#2125C, IRGKangXi=0226.040, RSKangXi=32.4
2125D CJK UNIFIED IDEOGRAPH-#2125D, IRGKangXi=0226.060, RSKangXi=32.4
2125E CJK UNIFIED IDEOGRAPH-#2125E, IRGKangXi=0226.101, RSKangXi=32.4
2125F CJK UNIFIED IDEOGRAPH-#2125F, IRGKangXi=0226.101, RSKangXi=32.4
21260 CJK UNIFIED IDEOGRAPH-#21260, IRGKangXi=0226.101, RSKangXi=32.4
21261 CJK UNIFIED IDEOGRAPH-#21261, IRGKangXi=0226.101, RSKangXi=32.4
21262 CJK UNIFIED IDEOGRAPH-#21262, IRGKangXi=0226.101, RSKangXi=32.4
21263 CJK UNIFIED IDEOGRAPH-#21263, IRGKangXi=0226.101, RSKangXi=32.4
21264 CJK UNIFIED IDEOGRAPH-#21264, IRGKangXi=0226.101, RSKangXi=32.4
21265 CJK UNIFIED IDEOGRAPH-#21265, IRGKangXi=0226.101, RSKangXi=32.4
21266 CJK UNIFIED IDEOGRAPH-#21266, IRGKangXi=0226.101, RSKangXi=32.4
21267 CJK UNIFIED IDEOGRAPH-#21267, IRGKangXi=0226.101, RSKangXi=32.4
21268 CJK UNIFIED IDEOGRAPH-#21268, IRGKangXi=0226.101, RSKangXi=32.4
21269 CJK UNIFIED IDEOGRAPH-#21269, IRGKangXi=0226.101, RSKangXi=32.4
2126A CJK UNIFIED IDEOGRAPH-#2126A, IRGKangXi=0226.101, RSKangXi=32.4
2126B CJK UNIFIED IDEOGRAPH-#2126B, IRGKangXi=0226.101, RSKangXi=32.4
2126C CJK UNIFIED IDEOGRAPH-#2126C, IRGKangXi=0226.101, RSKangXi=32.4
2126D CJK UNIFIED IDEOGRAPH-#2126D, IRGKangXi=0226.101, RSKangXi=32.4
2126E CJK UNIFIED IDEOGRAPH-#2126E, IRGKangXi=0226.101, RSKangXi=32.4
2126F CJK UNIFIED IDEOGRAPH-#2126F, IRGKangXi=0226.101, RSKangXi=32.4
21270 CJK UNIFIED IDEOGRAPH-#21270, IRGKangXi=0226.101, RSKangXi=32.4
21271 CJK UNIFIED IDEOGRAPH-#21271, IRGKangXi=0226.101, RSKangXi=32.4
21272 CJK UNIFIED IDEOGRAPH-#21272, IRGKangXi=0226.101, RSKangXi=32.4
21273 CJK UNIFIED IDEOGRAPH-#21273, IRGKangXi=0226.101, RSKangXi=32.4
21274 CJK UNIFIED IDEOGRAPH-#21274, IRGKangXi=0226.101, RSKangXi=32.4
21275 CJK UNIFIED IDEOGRAPH-#21275, IRGKangXi=0226.101, RSKangXi=32.4
21276 CJK UNIFIED IDEOGRAPH-#21276, IRGKangXi=0226.101, RSKangXi=32.4
21277 CJK UNIFIED IDEOGRAPH-#21277, IRGKangXi=0226.101, RSKangXi=32.4
21278 CJK UNIFIED IDEOGRAPH-#21278, IRGKangXi=0226.101, RSKangXi=32.4
21279 CJK UNIFIED IDEOGRAPH-#21279, IRGKangXi=0226.101, RSKangXi=32.4
2127A CJK UNIFIED IDEOGRAPH-#2127A, IRGKangXi=0226.101, RSKangXi=32.4
2127B CJK UNIFIED IDEOGRAPH-#2127B, IRGKangXi=0226.101, RSKangXi=32.4
2127C CJK UNIFIED IDEOGRAPH-#2127C, IRGKangXi=0226.101, RSKangXi=32.4
2127D CJK UNIFIED IDEOGRAPH-#2127D, IRGKangXi=0226.101, RSKangXi=32.4
2127E CJK UNIFIED IDEOGRAPH-#2127E, IRGKangXi=0226.101, RSKangXi=32.4
2127F CJK UNIFIED IDEOGRAPH-#2127F, IRGKangXi=0226.101, RSKangXi=32.4
21280 CJK UNIFIED IDEOGRAPH-#21280, IRGKangXi=0226.101, RSKangXi=32.4
21281 CJK UNIFIED IDEOGRAPH-#21281, IRGKangXi=0226.101, RSKangXi=32.4
21282 CJK UNIFIED IDEOGRAPH-#21282, IRGKangXi=0226.101, RSKangXi=32.4
21283 CJK UNIFIED IDEOGRAPH-#21283, IRGKangXi=0226.101, RSKangXi=32.4
21284 CJK UNIFIED IDEOGRAPH-#21284, IRGKangXi=0226.390, RSKangXi=32.5
21285 CJK UNIFIED IDEOGRAPH-#21285, IRGKangXi=0227.010, RSKangXi=32.5
21286 CJK UNIFIED IDEOGRAPH-#21286, IRGKangXi=0227.060, RSKangXi=32.5
21287 CJK UNIFIED IDEOGRAPH-#21287, IRGKangXi=0227.070, RSKangXi=32.5
21288 CJK UNIFIED IDEOGRAPH-#21288, IRGKangXi=0227.080, RSKangXi=32.5
21289 CJK UNIFIED IDEOGRAPH-#21289, IRGKangXi=0227.090, RSKangXi=32.5
2128A CJK UNIFIED IDEOGRAPH-#2128A, IRGKangXi=0227.210, RSKangXi=32.5
2128B CJK UNIFIED IDEOGRAPH-#2128B, IRGKangXi=0227.220, RSKangXi=32.5
2128C CJK UNIFIED IDEOGRAPH-#2128C, IRGKangXi=0227.240, RSKangXi=32.5
2128D CJK UNIFIED IDEOGRAPH-#2128D, IRGKangXi=0227.250, RSKangXi=32.5
2128E CJK UNIFIED IDEOGRAPH-#2128E, IRGKangXi=0227.260, RSKangXi=32.5
2128F CJK UNIFIED IDEOGRAPH-#2128F, IRGKangXi=0227.270, RSKangXi=32.5
21290 CJK UNIFIED IDEOGRAPH-#21290, IRGKangXi=0227.271, RSKangXi=32.5
21291 CJK UNIFIED IDEOGRAPH-#21291, IRGKangXi=0227.271, RSKangXi=32.5
21292 CJK UNIFIED IDEOGRAPH-#21292, IRGKangXi=0227.271, RSKangXi=32.5
21293 CJK UNIFIED IDEOGRAPH-#21293, IRGKangXi=0227.271, RSKangXi=32.5
21294 CJK UNIFIED IDEOGRAPH-#21294, IRGKangXi=0227.271, RSKangXi=32.5
21295 CJK UNIFIED IDEOGRAPH-#21295, IRGKangXi=0227.271, RSKangXi=32.5
21296 CJK UNIFIED IDEOGRAPH-#21296, IRGKangXi=0227.271, RSKangXi=32.5
21297 CJK UNIFIED IDEOGRAPH-#21297, IRGKangXi=0227.271, RSKangXi=32.5
21298 CJK UNIFIED IDEOGRAPH-#21298, IRGKangXi=0227.271, RSKangXi=32.5
21299 CJK UNIFIED IDEOGRAPH-#21299, IRGKangXi=0227.271, RSKangXi=32.5
2129A CJK UNIFIED IDEOGRAPH-#2129A, IRGKangXi=0227.271, RSKangXi=32.5
2129B CJK UNIFIED IDEOGRAPH-#2129B, IRGKangXi=0227.271, RSKangXi=32.5
2129C CJK UNIFIED IDEOGRAPH-#2129C, IRGKangXi=0227.271, RSKangXi=32.5
2129D CJK UNIFIED IDEOGRAPH-#2129D, IRGKangXi=0227.271, RSKangXi=32.5
2129E CJK UNIFIED IDEOGRAPH-#2129E, IRGKangXi=0227.271, RSKangXi=32.5
2129F CJK UNIFIED IDEOGRAPH-#2129F, IRGKangXi=0227.271, RSKangXi=32.5
212A0 CJK UNIFIED IDEOGRAPH-#212A0, IRGKangXi=0227.271, RSKangXi=32.5
212A1 CJK UNIFIED IDEOGRAPH-#212A1, IRGKangXi=0227.271, RSKangXi=32.5
212A2 CJK UNIFIED IDEOGRAPH-#212A2, IRGKangXi=0227.271, RSKangXi=32.5
212A3 CJK UNIFIED IDEOGRAPH-#212A3, IRGKangXi=0227.271, RSKangXi=32.5
212A4 CJK UNIFIED IDEOGRAPH-#212A4, IRGKangXi=0227.271, RSKangXi=32.5
212A5 CJK UNIFIED IDEOGRAPH-#212A5, IRGKangXi=0227.271, RSKangXi=32.5
212A6 CJK UNIFIED IDEOGRAPH-#212A6, IRGKangXi=0227.271, RSKangXi=32.5
212A7 CJK UNIFIED IDEOGRAPH-#212A7, IRGKangXi=0227.271, RSKangXi=32.5
212A8 CJK UNIFIED IDEOGRAPH-#212A8, IRGKangXi=0227.271, RSKangXi=32.5
212A9 CJK UNIFIED IDEOGRAPH-#212A9, IRGKangXi=0227.271, RSKangXi=32.5
212AA CJK UNIFIED IDEOGRAPH-#212AA, IRGKangXi=0227.271, RSKangXi=32.5
212AB CJK UNIFIED IDEOGRAPH-#212AB, IRGKangXi=0227.271, RSKangXi=32.5
212AC CJK UNIFIED IDEOGRAPH-#212AC, IRGKangXi=0227.271, RSKangXi=32.5
212AD CJK UNIFIED IDEOGRAPH-#212AD, IRGKangXi=0227.271, RSKangXi=32.5
212AE CJK UNIFIED IDEOGRAPH-#212AE, IRGKangXi=0227.271, RSKangXi=32.5
212AF CJK UNIFIED IDEOGRAPH-#212AF, IRGKangXi=0227.271, RSKangXi=32.5
212B0 CJK UNIFIED IDEOGRAPH-#212B0, IRGKangXi=0227.271, RSKangXi=32.5
212B1 CJK UNIFIED IDEOGRAPH-#212B1, IRGKangXi=0227.271, RSKangXi=32.5
212B2 CJK UNIFIED IDEOGRAPH-#212B2, IRGKangXi=0227.271, RSKangXi=32.5
212B3 CJK UNIFIED IDEOGRAPH-#212B3, IRGKangXi=0227.271, RSKangXi=32.5
212B4 CJK UNIFIED IDEOGRAPH-#212B4, IRGKangXi=0227.271, RSKangXi=32.5
212B5 CJK UNIFIED IDEOGRAPH-#212B5, IRGKangXi=0227.271, RSKangXi=32.5
212B6 CJK UNIFIED IDEOGRAPH-#212B6, IRGKangXi=0227.271, RSKangXi=32.5
212B7 CJK UNIFIED IDEOGRAPH-#212B7, IRGKangXi=0227.340, RSKangXi=32.6
212B8 CJK UNIFIED IDEOGRAPH-#212B8, IRGKangXi=0227.350, RSKangXi=32.6
212B9 CJK UNIFIED IDEOGRAPH-#212B9, IRGKangXi=0227.410, RSKangXi=32.6
212BA CJK UNIFIED IDEOGRAPH-#212BA, IRGKangXi=0228.120, RSKangXi=32.6
212BB CJK UNIFIED IDEOGRAPH-#212BB, IRGKangXi=0228.250, RSKangXi=32.6
212BC CJK UNIFIED IDEOGRAPH-#212BC, IRGKangXi=0228.260, RSKangXi=32.6
212BD CJK UNIFIED IDEOGRAPH-#212BD, IRGKangXi=0228.270, RSKangXi=32.6
212BE CJK UNIFIED IDEOGRAPH-#212BE, IRGKangXi=0228.280, RSKangXi=32.6
212BF CJK UNIFIED IDEOGRAPH-#212BF, IRGKangXi=0228.291, RSKangXi=32.6
212C0 CJK UNIFIED IDEOGRAPH-#212C0, IRGKangXi=0228.291, RSKangXi=32.6
212C1 CJK UNIFIED IDEOGRAPH-#212C1, IRGKangXi=0228.291, RSKangXi=32.6
212C2 CJK UNIFIED IDEOGRAPH-#212C2, IRGKangXi=0228.291, RSKangXi=32.6
212C3 CJK UNIFIED IDEOGRAPH-#212C3, IRGKangXi=0228.291, RSKangXi=32.6
212C4 CJK UNIFIED IDEOGRAPH-#212C4, IRGKangXi=0228.291, RSKangXi=32.6
212C5 CJK UNIFIED IDEOGRAPH-#212C5, IRGKangXi=0228.291, RSKangXi=32.6
212C6 CJK UNIFIED IDEOGRAPH-#212C6, IRGKangXi=0228.291, RSKangXi=32.6
212C7 CJK UNIFIED IDEOGRAPH-#212C7, IRGKangXi=0228.291, RSKangXi=32.6
212C8 CJK UNIFIED IDEOGRAPH-#212C8, IRGKangXi=0228.291, RSKangXi=32.6
212C9 CJK UNIFIED IDEOGRAPH-#212C9, IRGKangXi=0228.291, RSKangXi=32.6
212CA CJK UNIFIED IDEOGRAPH-#212CA, IRGKangXi=0228.291, RSKangXi=32.6
212CB CJK UNIFIED IDEOGRAPH-#212CB, IRGKangXi=0228.291, RSKangXi=32.6
212CC CJK UNIFIED IDEOGRAPH-#212CC, IRGKangXi=0228.291, RSKangXi=32.6
212CD CJK UNIFIED IDEOGRAPH-#212CD, IRGKangXi=0228.291, RSKangXi=32.6
212CE CJK UNIFIED IDEOGRAPH-#212CE, IRGKangXi=0228.291, RSKangXi=32.6
212CF CJK UNIFIED IDEOGRAPH-#212CF, IRGKangXi=0228.291, RSKangXi=32.6
212D0 CJK UNIFIED IDEOGRAPH-#212D0, IRGKangXi=0228.291, RSKangXi=32.6
212D1 CJK UNIFIED IDEOGRAPH-#212D1, IRGKangXi=0228.291, RSKangXi=32.6
212D2 CJK UNIFIED IDEOGRAPH-#212D2, IRGKangXi=0228.291, RSKangXi=32.6
212D3 CJK UNIFIED IDEOGRAPH-#212D3, IRGKangXi=0228.291, RSKangXi=32.6
212D4 CJK UNIFIED IDEOGRAPH-#212D4, IRGKangXi=0228.291, RSKangXi=32.6
212D5 CJK UNIFIED IDEOGRAPH-#212D5, IRGKangXi=0228.291, RSKangXi=32.6
212D6 CJK UNIFIED IDEOGRAPH-#212D6, IRGKangXi=0228.291, RSKangXi=32.6
212D7 CJK UNIFIED IDEOGRAPH-#212D7, IRGKangXi=0228.291, RSKangXi=32.6
212D8 CJK UNIFIED IDEOGRAPH-#212D8, IRGKangXi=0228.291, RSKangXi=32.6
212D9 CJK UNIFIED IDEOGRAPH-#212D9, IRGKangXi=0228.291, RSKangXi=32.6
212DA CJK UNIFIED IDEOGRAPH-#212DA, IRGKangXi=0228.291, RSKangXi=32.6
212DB CJK UNIFIED IDEOGRAPH-#212DB, IRGKangXi=0228.291, RSKangXi=32.6
212DC CJK UNIFIED IDEOGRAPH-#212DC, IRGKangXi=0228.291, RSKangXi=130.5
212DD CJK UNIFIED IDEOGRAPH-#212DD, IRGKangXi=0228.291, RSKangXi=32.6
212DE CJK UNIFIED IDEOGRAPH-#212DE, IRGKangXi=0228.291, RSKangXi=32.6
212DF CJK UNIFIED IDEOGRAPH-#212DF, IRGKangXi=0228.291, RSKangXi=32.6
212E0 CJK UNIFIED IDEOGRAPH-#212E0, IRGKangXi=0228.291, RSKangXi=32.6
212E1 CJK UNIFIED IDEOGRAPH-#212E1, IRGKangXi=0228.291, RSKangXi=32.6
212E2 CJK UNIFIED IDEOGRAPH-#212E2, IRGKangXi=0228.291, RSKangXi=32.6
212E3 CJK UNIFIED IDEOGRAPH-#212E3, IRGKangXi=0228.291, RSKangXi=32.6
212E4 CJK UNIFIED IDEOGRAPH-#212E4, IRGKangXi=0228.291, RSKangXi=32.6
212E5 CJK UNIFIED IDEOGRAPH-#212E5, IRGKangXi=0228.291, RSKangXi=32.6
212E6 CJK UNIFIED IDEOGRAPH-#212E6, IRGKangXi=0228.291, RSKangXi=32.6
212E7 CJK UNIFIED IDEOGRAPH-#212E7, IRGKangXi=0228.291, RSKangXi=32.6
212E8 CJK UNIFIED IDEOGRAPH-#212E8, IRGKangXi=0228.291, RSKangXi=32.6
212E9 CJK UNIFIED IDEOGRAPH-#212E9, IRGKangXi=0228.291, RSKangXi=32.6
212EA CJK UNIFIED IDEOGRAPH-#212EA, IRGKangXi=0228.291, RSKangXi=32.6
212EB CJK UNIFIED IDEOGRAPH-#212EB, IRGKangXi=0228.291, RSKangXi=32.6
212EC CJK UNIFIED IDEOGRAPH-#212EC, IRGKangXi=0228.291, RSKangXi=32.6
212ED CJK UNIFIED IDEOGRAPH-#212ED, IRGKangXi=0229.040, RSKangXi=32.7
212EE CJK UNIFIED IDEOGRAPH-#212EE, IRGKangXi=0229.050, RSKangXi=32.7
212EF CJK UNIFIED IDEOGRAPH-#212EF, IRGKangXi=0229.070, RSKangXi=32.7
212F0 CJK UNIFIED IDEOGRAPH-#212F0, IRGKangXi=0229.090, RSKangXi=32.7
212F1 CJK UNIFIED IDEOGRAPH-#212F1, IRGKangXi=0229.220, RSKangXi=32.7
212F2 CJK UNIFIED IDEOGRAPH-#212F2, IRGKangXi=0229.300, RSKangXi=32.7
212F3 CJK UNIFIED IDEOGRAPH-#212F3, IRGKangXi=0230.040, RSKangXi=32.7
212F4 CJK UNIFIED IDEOGRAPH-#212F4, IRGKangXi=0230.050, RSKangXi=32.7
212F5 CJK UNIFIED IDEOGRAPH-#212F5, IRGKangXi=0230.060, RSKangXi=32.7
212F6 CJK UNIFIED IDEOGRAPH-#212F6, IRGKangXi=0230.070, RSKangXi=32.7
212F7 CJK UNIFIED IDEOGRAPH-#212F7, IRGKangXi=0230.090, RSKangXi=32.7
212F8 CJK UNIFIED IDEOGRAPH-#212F8, IRGKangXi=0230.120, RSKangXi=32.7
212F9 CJK UNIFIED IDEOGRAPH-#212F9, IRGKangXi=0230.121, RSKangXi=32.7
212FA CJK UNIFIED IDEOGRAPH-#212FA, IRGKangXi=0230.121, RSKangXi=32.7
212FB CJK UNIFIED IDEOGRAPH-#212FB, IRGKangXi=0230.121, RSKangXi=32.7
212FC CJK UNIFIED IDEOGRAPH-#212FC, IRGKangXi=0230.121, RSKangXi=32.7
212FD CJK UNIFIED IDEOGRAPH-#212FD, IRGKangXi=0230.121, RSKangXi=32.7
212FE CJK UNIFIED IDEOGRAPH-#212FE, IRGKangXi=0230.121, RSKangXi=32.7
212FF CJK UNIFIED IDEOGRAPH-#212FF, IRGKangXi=0230.121, RSKangXi=32.7
21300 CJK UNIFIED IDEOGRAPH-#21300, IRGKangXi=0230.121, RSKangXi=32.7
21301 CJK UNIFIED IDEOGRAPH-#21301, IRGKangXi=0230.121, RSKangXi=32.7
21302 CJK UNIFIED IDEOGRAPH-#21302, IRGKangXi=0230.121, RSKangXi=32.7
21303 CJK UNIFIED IDEOGRAPH-#21303, IRGKangXi=0230.121, RSKangXi=32.7
21304 CJK UNIFIED IDEOGRAPH-#21304, IRGKangXi=0230.121, RSKangXi=32.7
21305 CJK UNIFIED IDEOGRAPH-#21305, IRGKangXi=0230.121, RSKangXi=32.7
21306 CJK UNIFIED IDEOGRAPH-#21306, IRGKangXi=0230.121, RSKangXi=32.7
21307 CJK UNIFIED IDEOGRAPH-#21307, IRGKangXi=0230.121, RSKangXi=32.7
21308 CJK UNIFIED IDEOGRAPH-#21308, IRGKangXi=0230.121, RSKangXi=32.7
21309 CJK UNIFIED IDEOGRAPH-#21309, IRGKangXi=0230.121, RSKangXi=32.7
2130A CJK UNIFIED IDEOGRAPH-#2130A, IRGKangXi=0230.121, RSKangXi=32.7
2130B CJK UNIFIED IDEOGRAPH-#2130B, IRGKangXi=0230.121, RSKangXi=32.7
2130C CJK UNIFIED IDEOGRAPH-#2130C, IRGKangXi=0230.121, RSKangXi=32.7
2130D CJK UNIFIED IDEOGRAPH-#2130D, IRGKangXi=0230.121, RSKangXi=32.7
2130E CJK UNIFIED IDEOGRAPH-#2130E, IRGKangXi=0230.121, RSKangXi=32.7
2130F CJK UNIFIED IDEOGRAPH-#2130F, IRGKangXi=0230.121, RSKangXi=32.7
21310 CJK UNIFIED IDEOGRAPH-#21310, IRGKangXi=0230.121, RSKangXi=32.7
21311 CJK UNIFIED IDEOGRAPH-#21311, IRGKangXi=0230.121, RSKangXi=32.7
21312 CJK UNIFIED IDEOGRAPH-#21312, IRGKangXi=0230.121, RSKangXi=32.7
21313 CJK UNIFIED IDEOGRAPH-#21313, IRGKangXi=0230.121, RSKangXi=32.7
21314 CJK UNIFIED IDEOGRAPH-#21314, IRGKangXi=0230.121, RSKangXi=32.7
21315 CJK UNIFIED IDEOGRAPH-#21315, IRGKangXi=0230.121, RSKangXi=32.7
21316 CJK UNIFIED IDEOGRAPH-#21316, IRGKangXi=0230.121, RSKangXi=32.7
21317 CJK UNIFIED IDEOGRAPH-#21317, IRGKangXi=0230.121, RSKangXi=32.7
21318 CJK UNIFIED IDEOGRAPH-#21318, IRGKangXi=0230.121, RSKangXi=32.7
21319 CJK UNIFIED IDEOGRAPH-#21319, IRGKangXi=0230.121, RSKangXi=32.7
2131A CJK UNIFIED IDEOGRAPH-#2131A, IRGKangXi=0230.121, RSKangXi=32.7
2131B CJK UNIFIED IDEOGRAPH-#2131B, IRGKangXi=0230.121, RSKangXi=32.7
2131C CJK UNIFIED IDEOGRAPH-#2131C, IRGKangXi=0230.121, RSKangXi=32.7
2131D CJK UNIFIED IDEOGRAPH-#2131D, IRGKangXi=0230.121, RSKangXi=32.7
2131E CJK UNIFIED IDEOGRAPH-#2131E, IRGKangXi=0230.121, RSKangXi=32.7
2131F CJK UNIFIED IDEOGRAPH-#2131F, IRGKangXi=0230.121, RSKangXi=32.7
21320 CJK UNIFIED IDEOGRAPH-#21320, IRGKangXi=0230.121, RSKangXi=32.7
21321 CJK UNIFIED IDEOGRAPH-#21321, IRGKangXi=0230.121, RSKangXi=32.7
21322 CJK UNIFIED IDEOGRAPH-#21322, IRGKangXi=0230.121, RSKangXi=32.7
21323 CJK UNIFIED IDEOGRAPH-#21323, IRGKangXi=0230.121, RSKangXi=32.7
21324 CJK UNIFIED IDEOGRAPH-#21324, IRGKangXi=0230.121, RSKangXi=32.7
21325 CJK UNIFIED IDEOGRAPH-#21325, IRGKangXi=0230.121, RSKangXi=32.7
21326 CJK UNIFIED IDEOGRAPH-#21326, IRGKangXi=0230.140, RSKangXi=32.8
21327 CJK UNIFIED IDEOGRAPH-#21327, IRGKangXi=0230.230, RSKangXi=32.8
21328 CJK UNIFIED IDEOGRAPH-#21328, IRGKangXi=0230.370, RSKangXi=32.8
21329 CJK UNIFIED IDEOGRAPH-#21329, IRGKangXi=0230.380, RSKangXi=32.8
2132A CJK UNIFIED IDEOGRAPH-#2132A, IRGKangXi=0231.070, RSKangXi=32.8
2132B CJK UNIFIED IDEOGRAPH-#2132B, IRGKangXi=0231.140, RSKangXi=32.8
2132C CJK UNIFIED IDEOGRAPH-#2132C, IRGKangXi=0231.150, RSKangXi=32.8
2132D CJK UNIFIED IDEOGRAPH-#2132D, IRGKangXi=0232.110, RSKangXi=32.8
2132E CJK UNIFIED IDEOGRAPH-#2132E, IRGKangXi=0232.120, RSKangXi=32.8
2132F CJK UNIFIED IDEOGRAPH-#2132F, IRGKangXi=0232.130, RSKangXi=32.8
21330 CJK UNIFIED IDEOGRAPH-#21330, IRGKangXi=0232.140, RSKangXi=32.8
21331 CJK UNIFIED IDEOGRAPH-#21331, IRGKangXi=0232.150, RSKangXi=32.8
21332 CJK UNIFIED IDEOGRAPH-#21332, IRGKangXi=0232.160, RSKangXi=32.8
21333 CJK UNIFIED IDEOGRAPH-#21333, IRGKangXi=0232.170, RSKangXi=32.8
21334 CJK UNIFIED IDEOGRAPH-#21334, IRGKangXi=0232.180, RSKangXi=32.8
21335 CJK UNIFIED IDEOGRAPH-#21335, IRGKangXi=0232.181, RSKangXi=32.8
21336 CJK UNIFIED IDEOGRAPH-#21336, IRGKangXi=0232.181, RSKangXi=32.8
21337 CJK UNIFIED IDEOGRAPH-#21337, IRGKangXi=0232.181, RSKangXi=32.8
21338 CJK UNIFIED IDEOGRAPH-#21338, IRGKangXi=0232.181, RSKangXi=32.8
21339 CJK UNIFIED IDEOGRAPH-#21339, IRGKangXi=0232.181, RSKangXi=32.8
2133A CJK UNIFIED IDEOGRAPH-#2133A, IRGKangXi=0232.181, RSKangXi=32.8
2133B CJK UNIFIED IDEOGRAPH-#2133B, IRGKangXi=0232.181, RSKangXi=32.8
2133C CJK UNIFIED IDEOGRAPH-#2133C, IRGKangXi=0232.181, RSKangXi=32.8
2133D CJK UNIFIED IDEOGRAPH-#2133D, IRGKangXi=0232.181, RSKangXi=32.8
2133E CJK UNIFIED IDEOGRAPH-#2133E, IRGKangXi=0232.181, RSKangXi=32.8
2133F CJK UNIFIED IDEOGRAPH-#2133F, IRGKangXi=0232.181, RSKangXi=32.8
21340 CJK UNIFIED IDEOGRAPH-#21340, IRGKangXi=0232.181, RSKangXi=32.8
21341 CJK UNIFIED IDEOGRAPH-#21341, IRGKangXi=0232.181, RSKangXi=32.8
21342 CJK UNIFIED IDEOGRAPH-#21342, IRGKangXi=0232.181, RSKangXi=32.8
21343 CJK UNIFIED IDEOGRAPH-#21343, IRGKangXi=0232.181, RSKangXi=32.8
21344 CJK UNIFIED IDEOGRAPH-#21344, IRGKangXi=0232.181, RSKangXi=32.8
21345 CJK UNIFIED IDEOGRAPH-#21345, IRGKangXi=0232.181, RSKangXi=32.8
21346 CJK UNIFIED IDEOGRAPH-#21346, IRGKangXi=0232.181, RSKangXi=32.8
21347 CJK UNIFIED IDEOGRAPH-#21347, IRGKangXi=0232.181, RSKangXi=32.8
21348 CJK UNIFIED IDEOGRAPH-#21348, IRGKangXi=0232.181, RSKangXi=32.8
21349 CJK UNIFIED IDEOGRAPH-#21349, IRGKangXi=0232.181, RSKangXi=32.8
2134A CJK UNIFIED IDEOGRAPH-#2134A, IRGKangXi=0232.181, RSKangXi=32.8
2134B CJK UNIFIED IDEOGRAPH-#2134B, IRGKangXi=0232.181, RSKangXi=32.8
2134C CJK UNIFIED IDEOGRAPH-#2134C, IRGKangXi=0232.181, RSKangXi=32.8
2134D CJK UNIFIED IDEOGRAPH-#2134D, IRGKangXi=0232.181, RSKangXi=32.8
2134E CJK UNIFIED IDEOGRAPH-#2134E, IRGKangXi=0232.181, RSKangXi=32.8
2134F CJK UNIFIED IDEOGRAPH-#2134F, IRGKangXi=0232.181, RSKangXi=32.8
21350 CJK UNIFIED IDEOGRAPH-#21350, IRGKangXi=0232.181, RSKangXi=32.8
21351 CJK UNIFIED IDEOGRAPH-#21351, IRGKangXi=0232.181, RSKangXi=32.8
21352 CJK UNIFIED IDEOGRAPH-#21352, IRGKangXi=0232.181, RSKangXi=32.8
21353 CJK UNIFIED IDEOGRAPH-#21353, IRGKangXi=0232.181, RSKangXi=32.8
21354 CJK UNIFIED IDEOGRAPH-#21354, IRGKangXi=0232.181, RSKangXi=32.8
21355 CJK UNIFIED IDEOGRAPH-#21355, IRGKangXi=0232.181, RSKangXi=32.8
21356 CJK UNIFIED IDEOGRAPH-#21356, IRGKangXi=0232.181, RSKangXi=32.8
21357 CJK UNIFIED IDEOGRAPH-#21357, IRGKangXi=0232.181, RSKangXi=32.8
21358 CJK UNIFIED IDEOGRAPH-#21358, IRGKangXi=0232.181, RSKangXi=32.8
21359 CJK UNIFIED IDEOGRAPH-#21359, IRGKangXi=0232.181, RSKangXi=32.8
2135A CJK UNIFIED IDEOGRAPH-#2135A, IRGKangXi=0232.181, RSKangXi=32.8
2135B CJK UNIFIED IDEOGRAPH-#2135B, IRGKangXi=0232.181, RSKangXi=32.8
2135C CJK UNIFIED IDEOGRAPH-#2135C, IRGKangXi=0232.181, RSKangXi=32.8
2135D CJK UNIFIED IDEOGRAPH-#2135D, IRGKangXi=0232.181, RSKangXi=32.8
2135E CJK UNIFIED IDEOGRAPH-#2135E, IRGKangXi=0232.181, RSKangXi=32.8
2135F CJK UNIFIED IDEOGRAPH-#2135F, IRGKangXi=0232.181, RSKangXi=32.8
21360 CJK UNIFIED IDEOGRAPH-#21360, IRGKangXi=0232.181, RSKangXi=32.8
21361 CJK UNIFIED IDEOGRAPH-#21361, IRGKangXi=0232.181, RSKangXi=32.8
21362 CJK UNIFIED IDEOGRAPH-#21362, IRGKangXi=0232.181, RSKangXi=32.8
21363 CJK UNIFIED IDEOGRAPH-#21363, IRGKangXi=0232.181, RSKangXi=32.8
21364 CJK UNIFIED IDEOGRAPH-#21364, IRGKangXi=0232.200, RSKangXi=32.9
21365 CJK UNIFIED IDEOGRAPH-#21365, IRGKangXi=0232.220, RSKangXi=32.9
21366 CJK UNIFIED IDEOGRAPH-#21366, IRGKangXi=0233.020, RSKangXi=32.9
21367 CJK UNIFIED IDEOGRAPH-#21367, IRGKangXi=0233.040, RSKangXi=32.9
21368 CJK UNIFIED IDEOGRAPH-#21368, IRGKangXi=0233.050, RSKangXi=32.9
21369 CJK UNIFIED IDEOGRAPH-#21369, IRGKangXi=0233.070, RSKangXi=32.9
2136A CJK UNIFIED IDEOGRAPH-#2136A, IRGKangXi=0233.110, RSKangXi=32.9
2136B CJK UNIFIED IDEOGRAPH-#2136B, IRGKangXi=0233.120, RSKangXi=32.9
2136C CJK UNIFIED IDEOGRAPH-#2136C, IRGKangXi=0233.190, RSKangXi=32.9
2136D CJK UNIFIED IDEOGRAPH-#2136D, IRGKangXi=0233.290, RSKangXi=32.9
2136E CJK UNIFIED IDEOGRAPH-#2136E, IRGKangXi=0234.030, RSKangXi=32.9
2136F CJK UNIFIED IDEOGRAPH-#2136F, IRGKangXi=0234.110, RSKangXi=32.9
21370 CJK UNIFIED IDEOGRAPH-#21370, IRGKangXi=0234.140, RSKangXi=32.9
21371 CJK UNIFIED IDEOGRAPH-#21371, IRGKangXi=0234.150, RSKangXi=32.9
21372 CJK UNIFIED IDEOGRAPH-#21372, IRGKangXi=0234.180, RSKangXi=32.9
21373 CJK UNIFIED IDEOGRAPH-#21373, IRGKangXi=0234.210, RSKangXi=32.9
21374 CJK UNIFIED IDEOGRAPH-#21374, IRGKangXi=0234.230, RSKangXi=32.9
21375 CJK UNIFIED IDEOGRAPH-#21375, IRGKangXi=0234.250, RSKangXi=32.9
21376 CJK UNIFIED IDEOGRAPH-#21376, IRGKangXi=0234.260, RSKangXi=32.9
21377 CJK UNIFIED IDEOGRAPH-#21377, IRGKangXi=0234.271, RSKangXi=32.9
21378 CJK UNIFIED IDEOGRAPH-#21378, IRGKangXi=0234.271, RSKangXi=32.9
21379 CJK UNIFIED IDEOGRAPH-#21379, IRGKangXi=0234.271, RSKangXi=32.9
2137A CJK UNIFIED IDEOGRAPH-#2137A, IRGKangXi=0234.271, RSKangXi=32.9
2137B CJK UNIFIED IDEOGRAPH-#2137B, IRGKangXi=0234.271, RSKangXi=32.9
2137C CJK UNIFIED IDEOGRAPH-#2137C, IRGKangXi=0234.271, RSKangXi=32.9
2137D CJK UNIFIED IDEOGRAPH-#2137D, IRGKangXi=0234.271, RSKangXi=32.9
2137E CJK UNIFIED IDEOGRAPH-#2137E, IRGKangXi=0234.271, RSKangXi=32.9
2137F CJK UNIFIED IDEOGRAPH-#2137F, IRGKangXi=0234.271, RSKangXi=32.9
21380 CJK UNIFIED IDEOGRAPH-#21380, IRGKangXi=0234.271, RSKangXi=32.9
21381 CJK UNIFIED IDEOGRAPH-#21381, IRGKangXi=0234.271, RSKangXi=32.9
21382 CJK UNIFIED IDEOGRAPH-#21382, IRGKangXi=0234.271, RSKangXi=32.9
21383 CJK UNIFIED IDEOGRAPH-#21383, IRGKangXi=0234.271, RSKangXi=32.9
21384 CJK UNIFIED IDEOGRAPH-#21384, IRGKangXi=0234.271, RSKangXi=32.9
21385 CJK UNIFIED IDEOGRAPH-#21385, IRGKangXi=0234.271, RSKangXi=32.9
21386 CJK UNIFIED IDEOGRAPH-#21386, IRGKangXi=0234.271, RSKangXi=32.9
21387 CJK UNIFIED IDEOGRAPH-#21387, IRGKangXi=0234.271, RSKangXi=32.9
21388 CJK UNIFIED IDEOGRAPH-#21388, IRGKangXi=0234.271, RSKangXi=32.9
21389 CJK UNIFIED IDEOGRAPH-#21389, IRGKangXi=0234.271, RSKangXi=32.9
2138A CJK UNIFIED IDEOGRAPH-#2138A, IRGKangXi=0234.271, RSKangXi=32.9
2138B CJK UNIFIED IDEOGRAPH-#2138B, IRGKangXi=0234.271, RSKangXi=32.9
2138C CJK UNIFIED IDEOGRAPH-#2138C, IRGKangXi=0234.271, RSKangXi=32.9
2138D CJK UNIFIED IDEOGRAPH-#2138D, IRGKangXi=0234.271, RSKangXi=32.9
2138E CJK UNIFIED IDEOGRAPH-#2138E, IRGKangXi=0234.271, RSKangXi=32.9
2138F CJK UNIFIED IDEOGRAPH-#2138F, IRGKangXi=0234.271, RSKangXi=32.9
21390 CJK UNIFIED IDEOGRAPH-#21390, IRGKangXi=0234.271, RSKangXi=32.9
21391 CJK UNIFIED IDEOGRAPH-#21391, IRGKangXi=0234.271, RSKangXi=32.9
21392 CJK UNIFIED IDEOGRAPH-#21392, IRGKangXi=0234.271, RSKangXi=32.9
21393 CJK UNIFIED IDEOGRAPH-#21393, IRGKangXi=0234.271, RSKangXi=32.9
21394 CJK UNIFIED IDEOGRAPH-#21394, IRGKangXi=0234.271, RSKangXi=32.9
21395 CJK UNIFIED IDEOGRAPH-#21395, IRGKangXi=0234.271, RSKangXi=32.9
21396 CJK UNIFIED IDEOGRAPH-#21396, IRGKangXi=0234.271, RSKangXi=32.9
21397 CJK UNIFIED IDEOGRAPH-#21397, IRGKangXi=0234.271, RSKangXi=32.9
21398 CJK UNIFIED IDEOGRAPH-#21398, IRGKangXi=0234.271, RSKangXi=32.9
21399 CJK UNIFIED IDEOGRAPH-#21399, IRGKangXi=0234.271, RSKangXi=32.9
2139A CJK UNIFIED IDEOGRAPH-#2139A, IRGKangXi=0234.271, RSKangXi=32.9
2139B CJK UNIFIED IDEOGRAPH-#2139B, IRGKangXi=0234.271, RSKangXi=32.9
2139C CJK UNIFIED IDEOGRAPH-#2139C, IRGKangXi=0234.271, RSKangXi=32.9
2139D CJK UNIFIED IDEOGRAPH-#2139D, IRGKangXi=0234.271, RSKangXi=32.9
2139E CJK UNIFIED IDEOGRAPH-#2139E, IRGKangXi=0234.271, RSKangXi=32.9
2139F CJK UNIFIED IDEOGRAPH-#2139F, IRGKangXi=0234.271, RSKangXi=32.9
213A0 CJK UNIFIED IDEOGRAPH-#213A0, IRGKangXi=0234.271, RSKangXi=32.9
213A1 CJK UNIFIED IDEOGRAPH-#213A1, IRGKangXi=0234.271, RSKangXi=32.9
213A2 CJK UNIFIED IDEOGRAPH-#213A2, IRGKangXi=0234.271, RSKangXi=32.9
213A3 CJK UNIFIED IDEOGRAPH-#213A3, IRGKangXi=0234.271, RSKangXi=32.9
213A4 CJK UNIFIED IDEOGRAPH-#213A4, IRGKangXi=0234.271, RSKangXi=32.9
213A5 CJK UNIFIED IDEOGRAPH-#213A5, IRGKangXi=0234.271, RSKangXi=32.9
213A6 CJK UNIFIED IDEOGRAPH-#213A6, IRGKangXi=0234.271, RSKangXi=32.9
213A7 CJK UNIFIED IDEOGRAPH-#213A7, IRGKangXi=0234.271, RSKangXi=32.9
213A8 CJK UNIFIED IDEOGRAPH-#213A8, IRGKangXi=0234.271, RSKangXi=32.9
213A9 CJK UNIFIED IDEOGRAPH-#213A9, IRGKangXi=0234.271, RSKangXi=32.9
213AA CJK UNIFIED IDEOGRAPH-#213AA, IRGKangXi=0234.271, RSKangXi=32.9
213AB CJK UNIFIED IDEOGRAPH-#213AB, IRGKangXi=0234.271, RSKangXi=32.9
213AC CJK UNIFIED IDEOGRAPH-#213AC, IRGKangXi=0234.271, RSKangXi=32.9
213AD CJK UNIFIED IDEOGRAPH-#213AD, IRGKangXi=0234.271, RSKangXi=32.9
213AE CJK UNIFIED IDEOGRAPH-#213AE, IRGKangXi=0235.060, RSKangXi=32.10
213AF CJK UNIFIED IDEOGRAPH-#213AF, IRGKangXi=0235.130, RSKangXi=32.10
213B0 CJK UNIFIED IDEOGRAPH-#213B0, IRGKangXi=0235.160, RSKangXi=32.10
213B1 CJK UNIFIED IDEOGRAPH-#213B1, IRGKangXi=0235.180, RSKangXi=32.10
213B2 CJK UNIFIED IDEOGRAPH-#213B2, IRGKangXi=0235.210, RSKangXi=32.10
213B3 CJK UNIFIED IDEOGRAPH-#213B3, IRGKangXi=0236.040, RSKangXi=32.10
213B4 CJK UNIFIED IDEOGRAPH-#213B4, IRGKangXi=0236.060, RSKangXi=32.10
213B5 CJK UNIFIED IDEOGRAPH-#213B5, IRGKangXi=0236.080, RSKangXi=32.10
213B6 CJK UNIFIED IDEOGRAPH-#213B6, IRGKangXi=0236.120, RSKangXi=32.10
213B7 CJK UNIFIED IDEOGRAPH-#213B7, IRGKangXi=0236.170, RSKangXi=32.10
213B8 CJK UNIFIED IDEOGRAPH-#213B8, IRGKangXi=0236.200, RSKangXi=32.10
213B9 CJK UNIFIED IDEOGRAPH-#213B9, IRGKangXi=0236.220, RSKangXi=32.10
213BA CJK UNIFIED IDEOGRAPH-#213BA, IRGKangXi=0236.240, RSKangXi=32.10
213BB CJK UNIFIED IDEOGRAPH-#213BB, IRGKangXi=0236.250, RSKangXi=32.10
213BC CJK UNIFIED IDEOGRAPH-#213BC, IRGKangXi=0236.270, RSKangXi=32.10
213BD CJK UNIFIED IDEOGRAPH-#213BD, IRGKangXi=0236.280, RSKangXi=32.10
213BE CJK UNIFIED IDEOGRAPH-#213BE, IRGKangXi=0236.290, RSKangXi=32.10
213BF CJK UNIFIED IDEOGRAPH-#213BF, IRGKangXi=0236.300, RSKangXi=32.10
213C0 CJK UNIFIED IDEOGRAPH-#213C0, IRGKangXi=0236.310, RSKangXi=32.10
213C1 CJK UNIFIED IDEOGRAPH-#213C1, IRGKangXi=0236.320, RSKangXi=32.10
213C2 CJK UNIFIED IDEOGRAPH-#213C2, IRGKangXi=0236.330, RSKangXi=32.10
213C3 CJK UNIFIED IDEOGRAPH-#213C3, IRGKangXi=0236.340, RSKangXi=32.10
213C4 CJK UNIFIED IDEOGRAPH-#213C4, IRGKangXi=0236.341, RSKangXi=32.10
213C5 CJK UNIFIED IDEOGRAPH-#213C5, IRGKangXi=0236.341, RSKangXi=32.10
213C6 CJK UNIFIED IDEOGRAPH-#213C6, IRGKangXi=0236.341, RSKangXi=32.10
213C7 CJK UNIFIED IDEOGRAPH-#213C7, IRGKangXi=0236.341, RSKangXi=32.10
213C8 CJK UNIFIED IDEOGRAPH-#213C8, IRGKangXi=0236.341, RSKangXi=32.10
213C9 CJK UNIFIED IDEOGRAPH-#213C9, IRGKangXi=0236.341, RSKangXi=32.10
213CA CJK UNIFIED IDEOGRAPH-#213CA, IRGKangXi=0236.341, RSKangXi=32.10
213CB CJK UNIFIED IDEOGRAPH-#213CB, IRGKangXi=0236.341, RSKangXi=32.10
213CC CJK UNIFIED IDEOGRAPH-#213CC, IRGKangXi=0236.341, RSKangXi=32.10
213CD CJK UNIFIED IDEOGRAPH-#213CD, IRGKangXi=0236.341, RSKangXi=32.10
213CE CJK UNIFIED IDEOGRAPH-#213CE, IRGKangXi=0236.341, RSKangXi=32.10
213CF CJK UNIFIED IDEOGRAPH-#213CF, IRGKangXi=0236.341, RSKangXi=32.10
213D0 CJK UNIFIED IDEOGRAPH-#213D0, IRGKangXi=0236.341, RSKangXi=32.10
213D1 CJK UNIFIED IDEOGRAPH-#213D1, IRGKangXi=0236.341, RSKangXi=32.10
213D2 CJK UNIFIED IDEOGRAPH-#213D2, IRGKangXi=0236.341, RSKangXi=32.10
213D3 CJK UNIFIED IDEOGRAPH-#213D3, IRGKangXi=0236.341, RSKangXi=32.10
213D4 CJK UNIFIED IDEOGRAPH-#213D4, IRGKangXi=0236.341, RSKangXi=32.10
213D5 CJK UNIFIED IDEOGRAPH-#213D5, IRGKangXi=0236.341, RSKangXi=32.10
213D6 CJK UNIFIED IDEOGRAPH-#213D6, IRGKangXi=0236.341, RSKangXi=32.10
213D7 CJK UNIFIED IDEOGRAPH-#213D7, IRGKangXi=0236.341, RSKangXi=32.10
213D8 CJK UNIFIED IDEOGRAPH-#213D8, IRGKangXi=0236.341, RSKangXi=32.10
213D9 CJK UNIFIED IDEOGRAPH-#213D9, IRGKangXi=0236.341, RSKangXi=32.10
213DA CJK UNIFIED IDEOGRAPH-#213DA, IRGKangXi=0236.341, RSKangXi=32.10
213DB CJK UNIFIED IDEOGRAPH-#213DB, IRGKangXi=0236.341, RSKangXi=32.10
213DC CJK UNIFIED IDEOGRAPH-#213DC, IRGKangXi=0236.341, RSKangXi=32.10
213DD CJK UNIFIED IDEOGRAPH-#213DD, IRGKangXi=0236.341, RSKangXi=32.10
213DE CJK UNIFIED IDEOGRAPH-#213DE, IRGKangXi=0236.341, RSKangXi=32.10
213DF CJK UNIFIED IDEOGRAPH-#213DF, IRGKangXi=0236.341, RSKangXi=32.10
213E0 CJK UNIFIED IDEOGRAPH-#213E0, IRGKangXi=0236.341, RSKangXi=32.10
213E1 CJK UNIFIED IDEOGRAPH-#213E1, IRGKangXi=0236.341, RSKangXi=32.10
213E2 CJK UNIFIED IDEOGRAPH-#213E2, IRGKangXi=0236.341, RSKangXi=32.10
213E3 CJK UNIFIED IDEOGRAPH-#213E3, IRGKangXi=0236.341, RSKangXi=32.10
213E4 CJK UNIFIED IDEOGRAPH-#213E4, IRGKangXi=0236.341, RSKangXi=32.10
213E5 CJK UNIFIED IDEOGRAPH-#213E5, IRGKangXi=0236.341, RSKangXi=32.10
213E6 CJK UNIFIED IDEOGRAPH-#213E6, IRGKangXi=0236.341, RSKangXi=32.10
213E7 CJK UNIFIED IDEOGRAPH-#213E7, IRGKangXi=0236.341, RSKangXi=32.10
213E8 CJK UNIFIED IDEOGRAPH-#213E8, IRGKangXi=0236.341, RSKangXi=32.10
213E9 CJK UNIFIED IDEOGRAPH-#213E9, IRGKangXi=0236.341, RSKangXi=32.10
213EA CJK UNIFIED IDEOGRAPH-#213EA, IRGKangXi=0236.341, RSKangXi=32.10
213EB CJK UNIFIED IDEOGRAPH-#213EB, IRGKangXi=0236.341, RSKangXi=32.10
213EC CJK UNIFIED IDEOGRAPH-#213EC, IRGKangXi=0236.341, RSKangXi=32.10
213ED CJK UNIFIED IDEOGRAPH-#213ED, IRGKangXi=0236.440, RSKangXi=32.11
213EE CJK UNIFIED IDEOGRAPH-#213EE, IRGKangXi=0237.150, RSKangXi=32.11
213EF CJK UNIFIED IDEOGRAPH-#213EF, IRGKangXi=0237.160, RSKangXi=32.11
213F0 CJK UNIFIED IDEOGRAPH-#213F0, IRGKangXi=0237.210, RSKangXi=32.11
213F1 CJK UNIFIED IDEOGRAPH-#213F1, IRGKangXi=0237.250, RSKangXi=32.11
213F2 CJK UNIFIED IDEOGRAPH-#213F2, IRGKangXi=0238.050, RSKangXi=32.11
213F3 CJK UNIFIED IDEOGRAPH-#213F3, IRGKangXi=0238.090, RSKangXi=32.11
213F4 CJK UNIFIED IDEOGRAPH-#213F4, IRGKangXi=0238.130, RSKangXi=32.11
213F5 CJK UNIFIED IDEOGRAPH-#213F5, IRGKangXi=0238.150, RSKangXi=32.11
213F6 CJK UNIFIED IDEOGRAPH-#213F6, IRGKangXi=0238.160, RSKangXi=32.11
213F7 CJK UNIFIED IDEOGRAPH-#213F7, IRGKangXi=0238.170, RSKangXi=32.11
213F8 CJK UNIFIED IDEOGRAPH-#213F8, IRGKangXi=0238.180, RSKangXi=32.11
213F9 CJK UNIFIED IDEOGRAPH-#213F9, IRGKangXi=0238.191, RSKangXi=32.11
213FA CJK UNIFIED IDEOGRAPH-#213FA, IRGKangXi=0238.191, RSKangXi=32.11
213FB CJK UNIFIED IDEOGRAPH-#213FB, IRGKangXi=0238.191, RSKangXi=32.11
213FC CJK UNIFIED IDEOGRAPH-#213FC, IRGKangXi=0238.191, RSKangXi=32.11
213FD CJK UNIFIED IDEOGRAPH-#213FD, IRGKangXi=0238.191, RSKangXi=32.11
213FE CJK UNIFIED IDEOGRAPH-#213FE, IRGKangXi=0238.191, RSKangXi=32.11
213FF CJK UNIFIED IDEOGRAPH-#213FF, IRGKangXi=0238.191, RSKangXi=32.11
21400 CJK UNIFIED IDEOGRAPH-#21400, IRGKangXi=0238.191, RSKangXi=32.11
21401 CJK UNIFIED IDEOGRAPH-#21401, IRGKangXi=0238.191, RSKangXi=32.11
21402 CJK UNIFIED IDEOGRAPH-#21402, IRGKangXi=0238.191, RSKangXi=32.11
21403 CJK UNIFIED IDEOGRAPH-#21403, IRGKangXi=0238.191, RSKangXi=32.11
21404 CJK UNIFIED IDEOGRAPH-#21404, IRGKangXi=0238.191, RSKangXi=32.11
21405 CJK UNIFIED IDEOGRAPH-#21405, IRGKangXi=0238.191, RSKangXi=32.11
21406 CJK UNIFIED IDEOGRAPH-#21406, IRGKangXi=0238.191, RSKangXi=32.11
21407 CJK UNIFIED IDEOGRAPH-#21407, IRGKangXi=0238.191, RSKangXi=32.11
21408 CJK UNIFIED IDEOGRAPH-#21408, IRGKangXi=0238.191, RSKangXi=32.11
21409 CJK UNIFIED IDEOGRAPH-#21409, IRGKangXi=0238.191, RSKangXi=32.11
2140A CJK UNIFIED IDEOGRAPH-#2140A, IRGKangXi=0238.191, RSKangXi=32.11
2140B CJK UNIFIED IDEOGRAPH-#2140B, IRGKangXi=0238.191, RSKangXi=32.11
2140C CJK UNIFIED IDEOGRAPH-#2140C, IRGKangXi=0238.191, RSKangXi=32.11
2140D CJK UNIFIED IDEOGRAPH-#2140D, IRGKangXi=0238.191, RSKangXi=32.11
2140E CJK UNIFIED IDEOGRAPH-#2140E, IRGKangXi=0238.191, RSKangXi=32.11
2140F CJK UNIFIED IDEOGRAPH-#2140F, IRGKangXi=0238.191, RSKangXi=32.11
21410 CJK UNIFIED IDEOGRAPH-#21410, IRGKangXi=0238.191, RSKangXi=32.11
21411 CJK UNIFIED IDEOGRAPH-#21411, IRGKangXi=0238.191, RSKangXi=32.11
21412 CJK UNIFIED IDEOGRAPH-#21412, IRGKangXi=0238.191, RSKangXi=32.11
21413 CJK UNIFIED IDEOGRAPH-#21413, IRGKangXi=0238.191, RSKangXi=32.11
21414 CJK UNIFIED IDEOGRAPH-#21414, IRGKangXi=0238.191, RSKangXi=32.11
21415 CJK UNIFIED IDEOGRAPH-#21415, IRGKangXi=0238.191, RSKangXi=32.11
21416 CJK UNIFIED IDEOGRAPH-#21416, IRGKangXi=0238.191, RSKangXi=32.11
21417 CJK UNIFIED IDEOGRAPH-#21417, IRGKangXi=0238.191, RSKangXi=32.11
21418 CJK UNIFIED IDEOGRAPH-#21418, IRGKangXi=0238.191, RSKangXi=32.11
21419 CJK UNIFIED IDEOGRAPH-#21419, IRGKangXi=0238.191, RSKangXi=32.11
2141A CJK UNIFIED IDEOGRAPH-#2141A, IRGKangXi=0238.191, RSKangXi=32.11
2141B CJK UNIFIED IDEOGRAPH-#2141B, IRGKangXi=0238.191, RSKangXi=32.11
2141C CJK UNIFIED IDEOGRAPH-#2141C, IRGKangXi=0238.191, RSKangXi=32.11
2141D CJK UNIFIED IDEOGRAPH-#2141D, IRGKangXi=0238.191, RSKangXi=32.11
2141E CJK UNIFIED IDEOGRAPH-#2141E, IRGKangXi=0238.200, RSKangXi=32.12
2141F CJK UNIFIED IDEOGRAPH-#2141F, IRGKangXi=0238.260, RSKangXi=32.12
21420 CJK UNIFIED IDEOGRAPH-#21420, IRGKangXi=0238.310, RSKangXi=32.12
21421 CJK UNIFIED IDEOGRAPH-#21421, IRGKangXi=0238.330, RSKangXi=32.12
21422 CJK UNIFIED IDEOGRAPH-#21422, IRGKangXi=0239.060, RSKangXi=32.12
21423 CJK UNIFIED IDEOGRAPH-#21423, IRGKangXi=0239.070, RSKangXi=32.12
21424 CJK UNIFIED IDEOGRAPH-#21424, IRGKangXi=0239.080, RSKangXi=32.12
21425 CJK UNIFIED IDEOGRAPH-#21425, IRGKangXi=0239.100, RSKangXi=32.12
21426 CJK UNIFIED IDEOGRAPH-#21426, IRGKangXi=0239.120, RSKangXi=32.12
21427 CJK UNIFIED IDEOGRAPH-#21427, IRGKangXi=0239.140, RSKangXi=32.12
21428 CJK UNIFIED IDEOGRAPH-#21428, IRGKangXi=0239.200, RSKangXi=32.12
21429 CJK UNIFIED IDEOGRAPH-#21429, IRGKangXi=0239.210, RSKangXi=32.12
2142A CJK UNIFIED IDEOGRAPH-#2142A, IRGKangXi=0239.230, RSKangXi=32.12
2142B CJK UNIFIED IDEOGRAPH-#2142B, IRGKangXi=0239.240, RSKangXi=32.12
2142C CJK UNIFIED IDEOGRAPH-#2142C, IRGKangXi=0239.241, RSKangXi=32.12
2142D CJK UNIFIED IDEOGRAPH-#2142D, IRGKangXi=0239.241, RSKangXi=32.12
2142E CJK UNIFIED IDEOGRAPH-#2142E, IRGKangXi=0239.241, RSKangXi=32.12
2142F CJK UNIFIED IDEOGRAPH-#2142F, IRGKangXi=0239.241, RSKangXi=32.12
21430 CJK UNIFIED IDEOGRAPH-#21430, IRGKangXi=0239.241, RSKangXi=32.12
21431 CJK UNIFIED IDEOGRAPH-#21431, IRGKangXi=0239.241, RSKangXi=32.12
21432 CJK UNIFIED IDEOGRAPH-#21432, IRGKangXi=0239.241, RSKangXi=32.12
21433 CJK UNIFIED IDEOGRAPH-#21433, IRGKangXi=0239.241, RSKangXi=32.12
21434 CJK UNIFIED IDEOGRAPH-#21434, IRGKangXi=0239.241, RSKangXi=32.12
21435 CJK UNIFIED IDEOGRAPH-#21435, IRGKangXi=0239.241, RSKangXi=32.12
21436 CJK UNIFIED IDEOGRAPH-#21436, IRGKangXi=0239.241, RSKangXi=32.12
21437 CJK UNIFIED IDEOGRAPH-#21437, IRGKangXi=0239.241, RSKangXi=32.12
21438 CJK UNIFIED IDEOGRAPH-#21438, IRGKangXi=0239.241, RSKangXi=32.12
21439 CJK UNIFIED IDEOGRAPH-#21439, IRGKangXi=0239.241, RSKangXi=32.12
2143A CJK UNIFIED IDEOGRAPH-#2143A, IRGKangXi=0239.241, RSKangXi=32.12
2143B CJK UNIFIED IDEOGRAPH-#2143B, IRGKangXi=0239.241, RSKangXi=32.12
2143C CJK UNIFIED IDEOGRAPH-#2143C, IRGKangXi=0239.241, RSKangXi=32.12
2143D CJK UNIFIED IDEOGRAPH-#2143D, IRGKangXi=0239.241, RSKangXi=32.12
2143E CJK UNIFIED IDEOGRAPH-#2143E, IRGKangXi=0239.241, RSKangXi=32.12
2143F CJK UNIFIED IDEOGRAPH-#2143F, IRGKangXi=0239.241, RSKangXi=32.12
21440 CJK UNIFIED IDEOGRAPH-#21440, IRGKangXi=0239.241, RSKangXi=32.12
21441 CJK UNIFIED IDEOGRAPH-#21441, IRGKangXi=0239.241, RSKangXi=32.12
21442 CJK UNIFIED IDEOGRAPH-#21442, IRGKangXi=0239.241, RSKangXi=32.12
21443 CJK UNIFIED IDEOGRAPH-#21443, IRGKangXi=0239.241, RSKangXi=32.12
21444 CJK UNIFIED IDEOGRAPH-#21444, IRGKangXi=0239.241, RSKangXi=32.12
21445 CJK UNIFIED IDEOGRAPH-#21445, IRGKangXi=0239.241, RSKangXi=32.12
21446 CJK UNIFIED IDEOGRAPH-#21446, IRGKangXi=0239.241, RSKangXi=32.12
21447 CJK UNIFIED IDEOGRAPH-#21447, IRGKangXi=0239.241, RSKangXi=32.12
21448 CJK UNIFIED IDEOGRAPH-#21448, IRGKangXi=0239.241, RSKangXi=32.12
21449 CJK UNIFIED IDEOGRAPH-#21449, IRGKangXi=0239.241, RSKangXi=32.12
2144A CJK UNIFIED IDEOGRAPH-#2144A, IRGKangXi=0239.241, RSKangXi=32.12
2144B CJK UNIFIED IDEOGRAPH-#2144B, IRGKangXi=0239.241, RSKangXi=32.12
2144C CJK UNIFIED IDEOGRAPH-#2144C, IRGKangXi=0239.241, RSKangXi=32.12
2144D CJK UNIFIED IDEOGRAPH-#2144D, IRGKangXi=0239.241, RSKangXi=32.12
2144E CJK UNIFIED IDEOGRAPH-#2144E, IRGKangXi=0239.241, RSKangXi=32.12
2144F CJK UNIFIED IDEOGRAPH-#2144F, IRGKangXi=0239.241, RSKangXi=32.12
21450 CJK UNIFIED IDEOGRAPH-#21450, IRGKangXi=0239.241, RSKangXi=32.12
21451 CJK UNIFIED IDEOGRAPH-#21451, IRGKangXi=0239.241, RSKangXi=32.12
21452 CJK UNIFIED IDEOGRAPH-#21452, IRGKangXi=0239.241, RSKangXi=32.12
21453 CJK UNIFIED IDEOGRAPH-#21453, IRGKangXi=0239.241, RSKangXi=32.12
21454 CJK UNIFIED IDEOGRAPH-#21454, IRGKangXi=0239.241, RSKangXi=32.12
21455 CJK UNIFIED IDEOGRAPH-#21455, IRGKangXi=0239.241, RSKangXi=32.12
21456 CJK UNIFIED IDEOGRAPH-#21456, IRGKangXi=0239.241, RSKangXi=32.12
21457 CJK UNIFIED IDEOGRAPH-#21457, IRGKangXi=0239.241, RSKangXi=32.12
21458 CJK UNIFIED IDEOGRAPH-#21458, IRGKangXi=0239.241, RSKangXi=32.12
21459 CJK UNIFIED IDEOGRAPH-#21459, IRGKangXi=0239.241, RSKangXi=32.12
2145A CJK UNIFIED IDEOGRAPH-#2145A, IRGKangXi=0239.241, RSKangXi=32.12
2145B CJK UNIFIED IDEOGRAPH-#2145B, IRGKangXi=0239.241, RSKangXi=32.12
2145C CJK UNIFIED IDEOGRAPH-#2145C, IRGKangXi=0239.241, RSKangXi=32.12
2145D CJK UNIFIED IDEOGRAPH-#2145D, IRGKangXi=0239.241, RSKangXi=32.12
2145E CJK UNIFIED IDEOGRAPH-#2145E, IRGKangXi=0240.010, RSKangXi=32.13, Def{tunnel, underground passage}
2145F CJK UNIFIED IDEOGRAPH-#2145F, IRGKangXi=0240.040, RSKangXi=32.13
21460 CJK UNIFIED IDEOGRAPH-#21460, IRGKangXi=0240.080, RSKangXi=32.13
21461 CJK UNIFIED IDEOGRAPH-#21461, IRGKangXi=0240.120, RSKangXi=32.13
21462 CJK UNIFIED IDEOGRAPH-#21462, IRGKangXi=0240.130, RSKangXi=32.13
21463 CJK UNIFIED IDEOGRAPH-#21463, IRGKangXi=0240.150, RSKangXi=32.13
21464 CJK UNIFIED IDEOGRAPH-#21464, IRGKangXi=0240.160, RSKangXi=32.13
21465 CJK UNIFIED IDEOGRAPH-#21465, IRGKangXi=0240.240, RSKangXi=32.13
21466 CJK UNIFIED IDEOGRAPH-#21466, IRGKangXi=0240.260, RSKangXi=32.13
21467 CJK UNIFIED IDEOGRAPH-#21467, IRGKangXi=0240.270, RSKangXi=32.13
21468 CJK UNIFIED IDEOGRAPH-#21468, IRGKangXi=0240.301, RSKangXi=32.13
21469 CJK UNIFIED IDEOGRAPH-#21469, IRGKangXi=0240.301, RSKangXi=32.13
2146A CJK UNIFIED IDEOGRAPH-#2146A, IRGKangXi=0240.301, RSKangXi=32.13
2146B CJK UNIFIED IDEOGRAPH-#2146B, IRGKangXi=0240.301, RSKangXi=32.13
2146C CJK UNIFIED IDEOGRAPH-#2146C, IRGKangXi=0240.301, RSKangXi=32.13
2146D CJK UNIFIED IDEOGRAPH-#2146D, IRGKangXi=0240.301, RSKangXi=32.13
2146E CJK UNIFIED IDEOGRAPH-#2146E, IRGKangXi=0240.301, RSKangXi=32.13
2146F CJK UNIFIED IDEOGRAPH-#2146F, IRGKangXi=0240.301, RSKangXi=32.13
21470 CJK UNIFIED IDEOGRAPH-#21470, IRGKangXi=0240.301, RSKangXi=32.13
21471 CJK UNIFIED IDEOGRAPH-#21471, IRGKangXi=0240.301, RSKangXi=32.13
21472 CJK UNIFIED IDEOGRAPH-#21472, IRGKangXi=0240.301, RSKangXi=32.13
21473 CJK UNIFIED IDEOGRAPH-#21473, IRGKangXi=0240.301, RSKangXi=32.13
21474 CJK UNIFIED IDEOGRAPH-#21474, IRGKangXi=0240.301, RSKangXi=32.13
21475 CJK UNIFIED IDEOGRAPH-#21475, IRGKangXi=0240.301, RSKangXi=32.13
21476 CJK UNIFIED IDEOGRAPH-#21476, IRGKangXi=0240.301, RSKangXi=32.13
21477 CJK UNIFIED IDEOGRAPH-#21477, IRGKangXi=0240.301, RSKangXi=32.13
21478 CJK UNIFIED IDEOGRAPH-#21478, IRGKangXi=0240.301, RSKangXi=32.13
21479 CJK UNIFIED IDEOGRAPH-#21479, IRGKangXi=0240.301, RSKangXi=32.13
2147A CJK UNIFIED IDEOGRAPH-#2147A, IRGKangXi=0240.301, RSKangXi=168.9
2147B CJK UNIFIED IDEOGRAPH-#2147B, IRGKangXi=0240.301, RSKangXi=32.13
2147C CJK UNIFIED IDEOGRAPH-#2147C, IRGKangXi=0240.301, RSKangXi=32.13
2147D CJK UNIFIED IDEOGRAPH-#2147D, IRGKangXi=0240.301, RSKangXi=32.13
2147E CJK UNIFIED IDEOGRAPH-#2147E, IRGKangXi=0240.301, RSKangXi=32.13
2147F CJK UNIFIED IDEOGRAPH-#2147F, IRGKangXi=0240.301, RSKangXi=32.13
21480 CJK UNIFIED IDEOGRAPH-#21480, IRGKangXi=0240.301, RSKangXi=32.13
21481 CJK UNIFIED IDEOGRAPH-#21481, IRGKangXi=0240.301, RSKangXi=32.13
21482 CJK UNIFIED IDEOGRAPH-#21482, IRGKangXi=0240.301, RSKangXi=32.13
21483 CJK UNIFIED IDEOGRAPH-#21483, IRGKangXi=0240.301, RSKangXi=32.13, Def{a shore, bay; winter quarters}
21484 CJK UNIFIED IDEOGRAPH-#21484, IRGKangXi=0240.301, RSKangXi=32.13, Def{disappointed}
21485 CJK UNIFIED IDEOGRAPH-#21485, IRGKangXi=0240.301, RSKangXi=32.13
21486 CJK UNIFIED IDEOGRAPH-#21486, IRGKangXi=0240.301, RSKangXi=32.13
21487 CJK UNIFIED IDEOGRAPH-#21487, IRGKangXi=0240.301, RSKangXi=32.13
21488 CJK UNIFIED IDEOGRAPH-#21488, IRGKangXi=0240.301, RSKangXi=32.13
21489 CJK UNIFIED IDEOGRAPH-#21489, IRGKangXi=0240.330, RSKangXi=32.14
2148A CJK UNIFIED IDEOGRAPH-#2148A, IRGKangXi=0241.010, RSKangXi=32.14
2148B CJK UNIFIED IDEOGRAPH-#2148B, IRGKangXi=0241.030, RSKangXi=32.14
2148C CJK UNIFIED IDEOGRAPH-#2148C, IRGKangXi=0241.060, RSKangXi=32.14
2148D CJK UNIFIED IDEOGRAPH-#2148D, IRGKangXi=0241.090, RSKangXi=32.14
2148E CJK UNIFIED IDEOGRAPH-#2148E, IRGKangXi=0241.140, RSKangXi=32.14
2148F CJK UNIFIED IDEOGRAPH-#2148F, IRGKangXi=0241.170, RSKangXi=32.14
21490 CJK UNIFIED IDEOGRAPH-#21490, IRGKangXi=0241.180, RSKangXi=32.14
21491 CJK UNIFIED IDEOGRAPH-#21491, IRGKangXi=0241.190, RSKangXi=32.14
21492 CJK UNIFIED IDEOGRAPH-#21492, IRGKangXi=0241.200, RSKangXi=32.14
21493 CJK UNIFIED IDEOGRAPH-#21493, IRGKangXi=0241.210, RSKangXi=32.14
21494 CJK UNIFIED IDEOGRAPH-#21494, IRGKangXi=0241.211, RSKangXi=32.14
21495 CJK UNIFIED IDEOGRAPH-#21495, IRGKangXi=0241.211, RSKangXi=32.14
21496 CJK UNIFIED IDEOGRAPH-#21496, IRGKangXi=0241.211, RSKangXi=32.14
21497 CJK UNIFIED IDEOGRAPH-#21497, IRGKangXi=0241.211, RSKangXi=32.14
21498 CJK UNIFIED IDEOGRAPH-#21498, IRGKangXi=0241.211, RSKangXi=32.14
21499 CJK UNIFIED IDEOGRAPH-#21499, IRGKangXi=0241.211, RSKangXi=32.14
2149A CJK UNIFIED IDEOGRAPH-#2149A, IRGKangXi=0241.211, RSKangXi=32.14
2149B CJK UNIFIED IDEOGRAPH-#2149B, IRGKangXi=0241.211, RSKangXi=32.14
2149C CJK UNIFIED IDEOGRAPH-#2149C, IRGKangXi=0241.211, RSKangXi=32.14
2149D CJK UNIFIED IDEOGRAPH-#2149D, IRGKangXi=0241.211, RSKangXi=32.14
2149E CJK UNIFIED IDEOGRAPH-#2149E, IRGKangXi=0241.211, RSKangXi=32.14
2149F CJK UNIFIED IDEOGRAPH-#2149F, IRGKangXi=0241.211, RSKangXi=32.14
214A0 CJK UNIFIED IDEOGRAPH-#214A0, IRGKangXi=0241.211, RSKangXi=32.14
214A1 CJK UNIFIED IDEOGRAPH-#214A1, IRGKangXi=0241.211, RSKangXi=207.4
214A2 CJK UNIFIED IDEOGRAPH-#214A2, IRGKangXi=0241.211, RSKangXi=32.14
214A3 CJK UNIFIED IDEOGRAPH-#214A3, IRGKangXi=0241.211, RSKangXi=32.14
214A4 CJK UNIFIED IDEOGRAPH-#214A4, IRGKangXi=0241.211, RSKangXi=32.14
214A5 CJK UNIFIED IDEOGRAPH-#214A5, IRGKangXi=0241.211, RSKangXi=32.14
214A6 CJK UNIFIED IDEOGRAPH-#214A6, IRGKangXi=0241.211, RSKangXi=32.14
214A7 CJK UNIFIED IDEOGRAPH-#214A7, IRGKangXi=0241.211, RSKangXi=32.14
214A8 CJK UNIFIED IDEOGRAPH-#214A8, IRGKangXi=0241.211, RSKangXi=32.14
214A9 CJK UNIFIED IDEOGRAPH-#214A9, IRGKangXi=0241.211, RSKangXi=32.14
214AA CJK UNIFIED IDEOGRAPH-#214AA, IRGKangXi=0241.211, RSKangXi=32.14
214AB CJK UNIFIED IDEOGRAPH-#214AB, IRGKangXi=0241.211, RSKangXi=32.14
214AC CJK UNIFIED IDEOGRAPH-#214AC, IRGKangXi=0241.211, RSKangXi=32.14
214AD CJK UNIFIED IDEOGRAPH-#214AD, IRGKangXi=0241.211, RSKangXi=32.14
214AE CJK UNIFIED IDEOGRAPH-#214AE, IRGKangXi=0241.211, RSKangXi=32.14
214AF CJK UNIFIED IDEOGRAPH-#214AF, IRGKangXi=0241.211, RSKangXi=32.14
214B0 CJK UNIFIED IDEOGRAPH-#214B0, IRGKangXi=0241.230, RSKangXi=32.15
214B1 CJK UNIFIED IDEOGRAPH-#214B1, IRGKangXi=0241.260, RSKangXi=32.15
214B2 CJK UNIFIED IDEOGRAPH-#214B2, IRGKangXi=0241.270, RSKangXi=32.15
214B3 CJK UNIFIED IDEOGRAPH-#214B3, IRGKangXi=0241.280, RSKangXi=32.15
214B4 CJK UNIFIED IDEOGRAPH-#214B4, IRGKangXi=0241.281, RSKangXi=32.15
214B5 CJK UNIFIED IDEOGRAPH-#214B5, IRGKangXi=0241.281, RSKangXi=32.15
214B6 CJK UNIFIED IDEOGRAPH-#214B6, IRGKangXi=0241.281, RSKangXi=32.15
214B7 CJK UNIFIED IDEOGRAPH-#214B7, IRGKangXi=0241.281, RSKangXi=32.15
214B8 CJK UNIFIED IDEOGRAPH-#214B8, IRGKangXi=0241.281, RSKangXi=32.15
214B9 CJK UNIFIED IDEOGRAPH-#214B9, IRGKangXi=0241.281, RSKangXi=32.15
214BA CJK UNIFIED IDEOGRAPH-#214BA, IRGKangXi=0241.281, RSKangXi=32.15
214BB CJK UNIFIED IDEOGRAPH-#214BB, IRGKangXi=0241.281, RSKangXi=32.15
214BC CJK UNIFIED IDEOGRAPH-#214BC, IRGKangXi=0241.281, RSKangXi=32.15
214BD CJK UNIFIED IDEOGRAPH-#214BD, IRGKangXi=0241.281, RSKangXi=32.15
214BE CJK UNIFIED IDEOGRAPH-#214BE, IRGKangXi=0241.281, RSKangXi=32.15
214BF CJK UNIFIED IDEOGRAPH-#214BF, IRGKangXi=0241.281, RSKangXi=32.15
214C0 CJK UNIFIED IDEOGRAPH-#214C0, IRGKangXi=0241.281, RSKangXi=32.16
214C1 CJK UNIFIED IDEOGRAPH-#214C1, IRGKangXi=0241.281, RSKangXi=32.15
214C2 CJK UNIFIED IDEOGRAPH-#214C2, IRGKangXi=0241.281, RSKangXi=32.15
214C3 CJK UNIFIED IDEOGRAPH-#214C3, IRGKangXi=0241.281, RSKangXi=32.15
214C4 CJK UNIFIED IDEOGRAPH-#214C4, IRGKangXi=0241.281, RSKangXi=32.15
214C5 CJK UNIFIED IDEOGRAPH-#214C5, IRGKangXi=0241.281, RSKangXi=32.15
214C6 CJK UNIFIED IDEOGRAPH-#214C6, IRGKangXi=0241.281, RSKangXi=32.15
214C7 CJK UNIFIED IDEOGRAPH-#214C7, IRGKangXi=0241.281, RSKangXi=32.15
214C8 CJK UNIFIED IDEOGRAPH-#214C8, IRGKangXi=0241.281, RSKangXi=32.15
214C9 CJK UNIFIED IDEOGRAPH-#214C9, IRGKangXi=0241.281, RSKangXi=32.15
214CA CJK UNIFIED IDEOGRAPH-#214CA, IRGKangXi=0241.281, RSKangXi=32.15
214CB CJK UNIFIED IDEOGRAPH-#214CB, IRGKangXi=0241.281, RSKangXi=32.15
214CC CJK UNIFIED IDEOGRAPH-#214CC, IRGKangXi=0241.281, RSKangXi=32.15
214CD CJK UNIFIED IDEOGRAPH-#214CD, IRGKangXi=0241.281, RSKangXi=32.15
214CE CJK UNIFIED IDEOGRAPH-#214CE, IRGKangXi=0241.281, RSKangXi=32.15
214CF CJK UNIFIED IDEOGRAPH-#214CF, IRGKangXi=0241.281, RSKangXi=32.15
214D0 CJK UNIFIED IDEOGRAPH-#214D0, IRGKangXi=0242.070, RSKangXi=32.16
214D1 CJK UNIFIED IDEOGRAPH-#214D1, IRGKangXi=0242.080, RSKangXi=32.16
214D2 CJK UNIFIED IDEOGRAPH-#214D2, IRGKangXi=0242.100, RSKangXi=32.16
214D3 CJK UNIFIED IDEOGRAPH-#214D3, IRGKangXi=0242.120, RSKangXi=32.16
214D4 CJK UNIFIED IDEOGRAPH-#214D4, IRGKangXi=0242.140, RSKangXi=32.16
214D5 CJK UNIFIED IDEOGRAPH-#214D5, IRGKangXi=0242.141, RSKangXi=32.16
214D6 CJK UNIFIED IDEOGRAPH-#214D6, IRGKangXi=0242.141, RSKangXi=32.16
214D7 CJK UNIFIED IDEOGRAPH-#214D7, IRGKangXi=0242.141, RSKangXi=32.16
214D8 CJK UNIFIED IDEOGRAPH-#214D8, IRGKangXi=0242.141, RSKangXi=32.16
214D9 CJK UNIFIED IDEOGRAPH-#214D9, IRGKangXi=0242.141, RSKangXi=32.16
214DA CJK UNIFIED IDEOGRAPH-#214DA, IRGKangXi=0242.141, RSKangXi=32.16
214DB CJK UNIFIED IDEOGRAPH-#214DB, IRGKangXi=0242.141, RSKangXi=150.12
214DC CJK UNIFIED IDEOGRAPH-#214DC, IRGKangXi=0242.141, RSKangXi=32.16
214DD CJK UNIFIED IDEOGRAPH-#214DD, IRGKangXi=0242.141, RSKangXi=32.16
214DE CJK UNIFIED IDEOGRAPH-#214DE, IRGKangXi=0242.141, RSKangXi=32.16
214DF CJK UNIFIED IDEOGRAPH-#214DF, IRGKangXi=0242.141, RSKangXi=32.16
214E0 CJK UNIFIED IDEOGRAPH-#214E0, IRGKangXi=0242.141, RSKangXi=32.16
214E1 CJK UNIFIED IDEOGRAPH-#214E1, IRGKangXi=0242.141, RSKangXi=32.16
214E2 CJK UNIFIED IDEOGRAPH-#214E2, IRGKangXi=0242.141, RSKangXi=32.16
214E3 CJK UNIFIED IDEOGRAPH-#214E3, IRGKangXi=0242.141, RSKangXi=32.16
214E4 CJK UNIFIED IDEOGRAPH-#214E4, IRGKangXi=0242.141, RSKangXi=32.16
214E5 CJK UNIFIED IDEOGRAPH-#214E5, IRGKangXi=0242.141, RSKangXi=32.16
214E6 CJK UNIFIED IDEOGRAPH-#214E6, IRGKangXi=0242.190, RSKangXi=32.17
214E7 CJK UNIFIED IDEOGRAPH-#214E7, IRGKangXi=0242.191, RSKangXi=32.17
214E8 CJK UNIFIED IDEOGRAPH-#214E8, IRGKangXi=0242.191, RSKangXi=32.17
214E9 CJK UNIFIED IDEOGRAPH-#214E9, IRGKangXi=0242.191, RSKangXi=32.17
214EA CJK UNIFIED IDEOGRAPH-#214EA, IRGKangXi=0242.191, RSKangXi=32.17
214EB CJK UNIFIED IDEOGRAPH-#214EB, IRGKangXi=0242.191, RSKangXi=32.17
214EC CJK UNIFIED IDEOGRAPH-#214EC, IRGKangXi=0242.191, RSKangXi=32.17
214ED CJK UNIFIED IDEOGRAPH-#214ED, IRGKangXi=0242.191, RSKangXi=32.17
214EE CJK UNIFIED IDEOGRAPH-#214EE, IRGKangXi=0242.191, RSKangXi=32.17
214EF CJK UNIFIED IDEOGRAPH-#214EF, IRGKangXi=0242.191, RSKangXi=32.17
214F0 CJK UNIFIED IDEOGRAPH-#214F0, IRGKangXi=0242.191, RSKangXi=32.17
214F1 CJK UNIFIED IDEOGRAPH-#214F1, IRGKangXi=0242.200, RSKangXi=32.18
214F2 CJK UNIFIED IDEOGRAPH-#214F2, IRGKangXi=0242.210, RSKangXi=32.18
214F3 CJK UNIFIED IDEOGRAPH-#214F3, IRGKangXi=0242.230, RSKangXi=32.18
214F4 CJK UNIFIED IDEOGRAPH-#214F4, IRGKangXi=0242.250, RSKangXi=32.18
214F5 CJK UNIFIED IDEOGRAPH-#214F5, IRGKangXi=0242.260, RSKangXi=32.18
214F6 CJK UNIFIED IDEOGRAPH-#214F6, IRGKangXi=0242.270, RSKangXi=32.18
214F7 CJK UNIFIED IDEOGRAPH-#214F7, IRGKangXi=0242.271, RSKangXi=184.12
214F8 CJK UNIFIED IDEOGRAPH-#214F8, IRGKangXi=0242.271, RSKangXi=32.18
214F9 CJK UNIFIED IDEOGRAPH-#214F9, IRGKangXi=0242.271, RSKangXi=32.18
214FA CJK UNIFIED IDEOGRAPH-#214FA, IRGKangXi=0242.271, RSKangXi=32.19
214FB CJK UNIFIED IDEOGRAPH-#214FB, IRGKangXi=0242.271, RSKangXi=32.18
214FC CJK UNIFIED IDEOGRAPH-#214FC, IRGKangXi=0242.271, RSKangXi=32.18
214FD CJK UNIFIED IDEOGRAPH-#214FD, IRGKangXi=0242.271, RSKangXi=32.18
214FE CJK UNIFIED IDEOGRAPH-#214FE, IRGKangXi=0242.271, RSKangXi=32.18
214FF CJK UNIFIED IDEOGRAPH-#214FF, IRGKangXi=0242.271, RSKangXi=32.18
21500 CJK UNIFIED IDEOGRAPH-#21500, IRGKangXi=0242.271, RSKangXi=32.18
21501 CJK UNIFIED IDEOGRAPH-#21501, IRGKangXi=0242.271, RSKangXi=32.18
21502 CJK UNIFIED IDEOGRAPH-#21502, IRGKangXi=0242.280, RSKangXi=32.19
21503 CJK UNIFIED IDEOGRAPH-#21503, IRGKangXi=0242.281, RSKangXi=32.19
21504 CJK UNIFIED IDEOGRAPH-#21504, IRGKangXi=0242.281, RSKangXi=32.19
21505 CJK UNIFIED IDEOGRAPH-#21505, IRGKangXi=0242.281, RSKangXi=32.19
21506 CJK UNIFIED IDEOGRAPH-#21506, IRGKangXi=0242.281, RSKangXi=32.19
21507 CJK UNIFIED IDEOGRAPH-#21507, IRGKangXi=0242.281, RSKangXi=32.19
21508 CJK UNIFIED IDEOGRAPH-#21508, IRGKangXi=0242.281, RSKangXi=32.19
21509 CJK UNIFIED IDEOGRAPH-#21509, IRGKangXi=0242.281, RSKangXi=32.19
2150A CJK UNIFIED IDEOGRAPH-#2150A, IRGKangXi=0242.300, RSKangXi=32.20
2150B CJK UNIFIED IDEOGRAPH-#2150B, IRGKangXi=0242.310, RSKangXi=32.20
2150C CJK UNIFIED IDEOGRAPH-#2150C, IRGKangXi=0242.321, RSKangXi=32.20
2150D CJK UNIFIED IDEOGRAPH-#2150D, IRGKangXi=0242.321, RSKangXi=32.20
2150E CJK UNIFIED IDEOGRAPH-#2150E, IRGKangXi=0242.321, RSKangXi=32.20
2150F CJK UNIFIED IDEOGRAPH-#2150F, IRGKangXi=0242.340, RSKangXi=32.21
21510 CJK UNIFIED IDEOGRAPH-#21510, IRGKangXi=0242.351, RSKangXi=32.21
21511 CJK UNIFIED IDEOGRAPH-#21511, IRGKangXi=0242.351, RSKangXi=32.21
21512 CJK UNIFIED IDEOGRAPH-#21512, IRGKangXi=0242.351, RSKangXi=32.21
21513 CJK UNIFIED IDEOGRAPH-#21513, IRGKangXi=0242.351, RSKangXi=32.21
21514 CJK UNIFIED IDEOGRAPH-#21514, IRGKangXi=0242.351, RSKangXi=32.21
21515 CJK UNIFIED IDEOGRAPH-#21515, IRGKangXi=0242.351, RSKangXi=32.21
21516 CJK UNIFIED IDEOGRAPH-#21516, IRGKangXi=0242.361, RSKangXi=32.23
21517 CJK UNIFIED IDEOGRAPH-#21517, IRGKangXi=0242.361, RSKangXi=32.26
21518 CJK UNIFIED IDEOGRAPH-#21518, IRGKangXi=0242.361, RSKangXi=32.27
21519 CJK UNIFIED IDEOGRAPH-#21519, IRGKangXi=0242.361, RSKangXi=32.33
2151A CJK UNIFIED IDEOGRAPH-#2151A, IRGKangXi=0242.370, RSKangXi=32.36
2151B CJK UNIFIED IDEOGRAPH-#2151B, IRGKangXi=0243.011, RSKangXi=33.2
2151C CJK UNIFIED IDEOGRAPH-#2151C, IRGKangXi=0243.011, RSKangXi=33.3
2151D CJK UNIFIED IDEOGRAPH-#2151D, IRGKangXi=0243.030, RSKangXi=33.4
2151E CJK UNIFIED IDEOGRAPH-#2151E, IRGKangXi=0243.041, RSKangXi=33.4
2151F CJK UNIFIED IDEOGRAPH-#2151F, IRGKangXi=0243.041, RSKangXi=33.5
21520 CJK UNIFIED IDEOGRAPH-#21520, IRGKangXi=0243.051, RSKangXi=33.6
21521 CJK UNIFIED IDEOGRAPH-#21521, IRGKangXi=0243.051, RSKangXi=33.6
21522 CJK UNIFIED IDEOGRAPH-#21522, IRGKangXi=0243.051, RSKangXi=33.6
21523 CJK UNIFIED IDEOGRAPH-#21523, IRGKangXi=0243.060, RSKangXi=33.7
21524 CJK UNIFIED IDEOGRAPH-#21524, IRGKangXi=0243.070, RSKangXi=33.7
21525 CJK UNIFIED IDEOGRAPH-#21525, IRGKangXi=0243.071, RSKangXi=33.7
21526 CJK UNIFIED IDEOGRAPH-#21526, IRGKangXi=0243.071, RSKangXi=33.7
21527 CJK UNIFIED IDEOGRAPH-#21527, IRGKangXi=0243.071, RSKangXi=33.7
21528 CJK UNIFIED IDEOGRAPH-#21528, IRGKangXi=0243.071, RSKangXi=33.7
21529 CJK UNIFIED IDEOGRAPH-#21529, IRGKangXi=0243.071, RSKangXi=33.7
2152A CJK UNIFIED IDEOGRAPH-#2152A, IRGKangXi=0243.091, RSKangXi=33.8
2152B CJK UNIFIED IDEOGRAPH-#2152B, IRGKangXi=0243.091, RSKangXi=33.8
2152C CJK UNIFIED IDEOGRAPH-#2152C, IRGKangXi=0243.091, RSKangXi=33.8
2152D CJK UNIFIED IDEOGRAPH-#2152D, IRGKangXi=0243.091, RSKangXi=33.8
2152E CJK UNIFIED IDEOGRAPH-#2152E, IRGKangXi=0243.171, RSKangXi=33.9
2152F CJK UNIFIED IDEOGRAPH-#2152F, IRGKangXi=0243.171, RSKangXi=33.9
21530 CJK UNIFIED IDEOGRAPH-#21530, IRGKangXi=0244.020, RSKangXi=33.10
21531 CJK UNIFIED IDEOGRAPH-#21531, IRGKangXi=0244.021, RSKangXi=37.9
21532 CJK UNIFIED IDEOGRAPH-#21532, IRGKangXi=0244.021, RSKangXi=33.10
21533 CJK UNIFIED IDEOGRAPH-#21533, IRGKangXi=0244.021, RSKangXi=33.10
21534 CJK UNIFIED IDEOGRAPH-#21534, IRGKangXi=0244.021, RSKangXi=33.10
21535 CJK UNIFIED IDEOGRAPH-#21535, IRGKangXi=0244.021, RSKangXi=33.10
21536 CJK UNIFIED IDEOGRAPH-#21536, IRGKangXi=0244.030, RSKangXi=33.11
21537 CJK UNIFIED IDEOGRAPH-#21537, IRGKangXi=0244.091, RSKangXi=207.0
21538 CJK UNIFIED IDEOGRAPH-#21538, IRGKangXi=0244.091, RSKangXi=33.11
21539 CJK UNIFIED IDEOGRAPH-#21539, IRGKangXi=0244.091, RSKangXi=33.11
2153A CJK UNIFIED IDEOGRAPH-#2153A, IRGKangXi=0244.091, RSKangXi=33.11
2153B CJK UNIFIED IDEOGRAPH-#2153B, IRGKangXi=0244.091, RSKangXi=33.11
2153C CJK UNIFIED IDEOGRAPH-#2153C, IRGKangXi=0244.110, RSKangXi=33.12
2153D CJK UNIFIED IDEOGRAPH-#2153D, IRGKangXi=0244.111, RSKangXi=33.11
2153E CJK UNIFIED IDEOGRAPH-#2153E, IRGKangXi=0244.130, RSKangXi=33.13
2153F CJK UNIFIED IDEOGRAPH-#2153F, IRGKangXi=0244.131, RSKangXi=33.11
21540 CJK UNIFIED IDEOGRAPH-#21540, IRGKangXi=0244.131, RSKangXi=33.13
21541 CJK UNIFIED IDEOGRAPH-#21541, IRGKangXi=0244.131, RSKangXi=33.14
21542 CJK UNIFIED IDEOGRAPH-#21542, IRGKangXi=0244.131, RSKangXi=33.14
21543 CJK UNIFIED IDEOGRAPH-#21543, IRGKangXi=0244.131, RSKangXi=33.14
21544 CJK UNIFIED IDEOGRAPH-#21544, IRGKangXi=0244.131, RSKangXi=33.14
21545 CJK UNIFIED IDEOGRAPH-#21545, IRGKangXi=0244.140, RSKangXi=33.15
21546 CJK UNIFIED IDEOGRAPH-#21546, IRGKangXi=0244.141, RSKangXi=151.11
21547 CJK UNIFIED IDEOGRAPH-#21547, IRGKangXi=0244.141, RSKangXi=33.15
21548 CJK UNIFIED IDEOGRAPH-#21548, IRGKangXi=0244.141, RSKangXi=33.15
21549 CJK UNIFIED IDEOGRAPH-#21549, IRGKangXi=0244.141, RSKangXi=33.15
2154A CJK UNIFIED IDEOGRAPH-#2154A, IRGKangXi=0244.141, RSKangXi=33.15
2154B CJK UNIFIED IDEOGRAPH-#2154B, IRGKangXi=0244.150, RSKangXi=33.16
2154C CJK UNIFIED IDEOGRAPH-#2154C, IRGKangXi=0244.151, RSKangXi=33.16
2154D CJK UNIFIED IDEOGRAPH-#2154D, IRGKangXi=0244.160, RSKangXi=33.17
2154E CJK UNIFIED IDEOGRAPH-#2154E, IRGKangXi=0244.160, RSKangXi=112.15
2154F CJK UNIFIED IDEOGRAPH-#2154F, IRGKangXi=0244.161, RSKangXi=33.19
21550 CJK UNIFIED IDEOGRAPH-#21550, IRGKangXi=0244.161, RSKangXi=33.19
21551 CJK UNIFIED IDEOGRAPH-#21551, IRGKangXi=0244.161, RSKangXi=33.19
21552 CJK UNIFIED IDEOGRAPH-#21552, IRGKangXi=0244.180, RSKangXi=34.0
21553 CJK UNIFIED IDEOGRAPH-#21553, IRGKangXi=0244.191, RSKangXi=34.2
21554 CJK UNIFIED IDEOGRAPH-#21554, IRGKangXi=0244.191, RSKangXi=34.2
21555 CJK UNIFIED IDEOGRAPH-#21555, IRGKangXi=0244.210, RSKangXi=34.3
21556 CJK UNIFIED IDEOGRAPH-#21556, IRGKangXi=0244.211, RSKangXi=34.3
21557 CJK UNIFIED IDEOGRAPH-#21557, IRGKangXi=0244.230, RSKangXi=34.4
21558 CJK UNIFIED IDEOGRAPH-#21558, IRGKangXi=0244.231, RSKangXi=34.4
21559 CJK UNIFIED IDEOGRAPH-#21559, IRGKangXi=0244.231, RSKangXi=34.4
2155A CJK UNIFIED IDEOGRAPH-#2155A, IRGKangXi=0244.250, RSKangXi=34.7
2155B CJK UNIFIED IDEOGRAPH-#2155B, IRGKangXi=0244.260, RSKangXi=34.8
2155C CJK UNIFIED IDEOGRAPH-#2155C, IRGKangXi=0244.270, RSKangXi=34.8
2155D CJK UNIFIED IDEOGRAPH-#2155D, IRGKangXi=0244.280, RSKangXi=34.10
2155E CJK UNIFIED IDEOGRAPH-#2155E, IRGKangXi=0245.020, RSKangXi=35.3
2155F CJK UNIFIED IDEOGRAPH-#2155F, IRGKangXi=0245.021, RSKangXi=35.3
21560 CJK UNIFIED IDEOGRAPH-#21560, IRGKangXi=0245.040, RSKangXi=35.4
21561 CJK UNIFIED IDEOGRAPH-#21561, IRGKangXi=0245.041, RSKangXi=35.4
21562 CJK UNIFIED IDEOGRAPH-#21562, IRGKangXi=0245.060, RSKangXi=35.5
21563 CJK UNIFIED IDEOGRAPH-#21563, IRGKangXi=0245.070, RSKangXi=35.5
21564 CJK UNIFIED IDEOGRAPH-#21564, IRGKangXi=0245.071, RSKangXi=35.5
21565 CJK UNIFIED IDEOGRAPH-#21565, IRGKangXi=0245.071, RSKangXi=35.5
21566 CJK UNIFIED IDEOGRAPH-#21566, IRGKangXi=0245.161, RSKangXi=35.7
21567 CJK UNIFIED IDEOGRAPH-#21567, IRGKangXi=0245.170, RSKangXi=35.8
21568 CJK UNIFIED IDEOGRAPH-#21568, IRGKangXi=0245.180, RSKangXi=35.8
21569 CJK UNIFIED IDEOGRAPH-#21569, IRGKangXi=0245.190, RSKangXi=35.8
2156A CJK UNIFIED IDEOGRAPH-#2156A, IRGKangXi=0245.200, RSKangXi=35.8
2156B CJK UNIFIED IDEOGRAPH-#2156B, IRGKangXi=0245.201, RSKangXi=35.8
2156C CJK UNIFIED IDEOGRAPH-#2156C, IRGKangXi=0245.201, RSKangXi=35.8
2156D CJK UNIFIED IDEOGRAPH-#2156D, IRGKangXi=0245.201, RSKangXi=35.9
2156E CJK UNIFIED IDEOGRAPH-#2156E, IRGKangXi=0245.210, RSKangXi=35.10
2156F CJK UNIFIED IDEOGRAPH-#2156F, IRGKangXi=0245.211, RSKangXi=35.10
21570 CJK UNIFIED IDEOGRAPH-#21570, IRGKangXi=0245.211, RSKangXi=35.10
21571 CJK UNIFIED IDEOGRAPH-#21571, IRGKangXi=0245.211, RSKangXi=35.10
21572 CJK UNIFIED IDEOGRAPH-#21572, IRGKangXi=0245.230, RSKangXi=35.11
21573 CJK UNIFIED IDEOGRAPH-#21573, IRGKangXi=0245.231, RSKangXi=35.11
21574 CJK UNIFIED IDEOGRAPH-#21574, IRGKangXi=0245.231, RSKangXi=35.11
21575 CJK UNIFIED IDEOGRAPH-#21575, IRGKangXi=0245.231, RSKangXi=35.11
21576 CJK UNIFIED IDEOGRAPH-#21576, IRGKangXi=0245.240, RSKangXi=35.12
21577 CJK UNIFIED IDEOGRAPH-#21577, IRGKangXi=0245.241, RSKangXi=35.12
21578 CJK UNIFIED IDEOGRAPH-#21578, IRGKangXi=0245.241, RSKangXi=35.13
21579 CJK UNIFIED IDEOGRAPH-#21579, IRGKangXi=0245.241, RSKangXi=35.13
2157A CJK UNIFIED IDEOGRAPH-#2157A, IRGKangXi=0245.241, RSKangXi=35.13
2157B CJK UNIFIED IDEOGRAPH-#2157B, IRGKangXi=0245.241, RSKangXi=35.14
2157C CJK UNIFIED IDEOGRAPH-#2157C, IRGKangXi=0245.250, RSKangXi=35.15
2157D CJK UNIFIED IDEOGRAPH-#2157D, IRGKangXi=0245.260, RSKangXi=35.15
2157E CJK UNIFIED IDEOGRAPH-#2157E, IRGKangXi=0245.270, RSKangXi=35.15
2157F CJK UNIFIED IDEOGRAPH-#2157F, IRGKangXi=0245.271, RSKangXi=35.15
21580 CJK UNIFIED IDEOGRAPH-#21580, IRGKangXi=0245.281, RSKangXi=35.16
21581 CJK UNIFIED IDEOGRAPH-#21581, IRGKangXi=0245.281, RSKangXi=35.17
21582 CJK UNIFIED IDEOGRAPH-#21582, IRGKangXi=0245.290, RSKangXi=35.20
21583 CJK UNIFIED IDEOGRAPH-#21583, IRGKangXi=0245.291, RSKangXi=35.27
21584 CJK UNIFIED IDEOGRAPH-#21584, IRGKangXi=0246.060, RSKangXi=36.2
21585 CJK UNIFIED IDEOGRAPH-#21585, IRGKangXi=0246.061, RSKangXi=36.2
21586 CJK UNIFIED IDEOGRAPH-#21586, IRGKangXi=0246.061, RSKangXi=36.2
21587 CJK UNIFIED IDEOGRAPH-#21587, IRGKangXi=0246.140, RSKangXi=36.3
21588 CJK UNIFIED IDEOGRAPH-#21588, IRGKangXi=0246.150, RSKangXi=36.3
21589 CJK UNIFIED IDEOGRAPH-#21589, IRGKangXi=0246.151, RSKangXi=36.3
2158A CJK UNIFIED IDEOGRAPH-#2158A, IRGKangXi=0246.160, RSKangXi=36.4
2158B CJK UNIFIED IDEOGRAPH-#2158B, IRGKangXi=0246.170, RSKangXi=36.4
2158C CJK UNIFIED IDEOGRAPH-#2158C, IRGKangXi=0246.171, RSKangXi=36.4
2158D CJK UNIFIED IDEOGRAPH-#2158D, IRGKangXi=0247.030, RSKangXi=36.5
2158E CJK UNIFIED IDEOGRAPH-#2158E, IRGKangXi=0247.031, RSKangXi=36.5
2158F CJK UNIFIED IDEOGRAPH-#2158F, IRGKangXi=0247.031, RSKangXi=36.5
21590 CJK UNIFIED IDEOGRAPH-#21590, IRGKangXi=0247.031, RSKangXi=36.6
21591 CJK UNIFIED IDEOGRAPH-#21591, IRGKangXi=0247.031, RSKangXi=36.6
21592 CJK UNIFIED IDEOGRAPH-#21592, IRGKangXi=0247.040, RSKangXi=36.7
21593 CJK UNIFIED IDEOGRAPH-#21593, IRGKangXi=0247.050, RSKangXi=36.7
21594 CJK UNIFIED IDEOGRAPH-#21594, IRGKangXi=0247.060, RSKangXi=36.7
21595 CJK UNIFIED IDEOGRAPH-#21595, IRGKangXi=0247.070, RSKangXi=36.7
21596 CJK UNIFIED IDEOGRAPH-#21596, IRGKangXi=0247.071, RSKangXi=36.7
21597 CJK UNIFIED IDEOGRAPH-#21597, IRGKangXi=0247.071, RSKangXi=36.7
21598 CJK UNIFIED IDEOGRAPH-#21598, IRGKangXi=0247.071, RSKangXi=36.7
21599 CJK UNIFIED IDEOGRAPH-#21599, IRGKangXi=0247.071, RSKangXi=36.7
2159A CJK UNIFIED IDEOGRAPH-#2159A, IRGKangXi=0247.071, RSKangXi=36.7
2159B CJK UNIFIED IDEOGRAPH-#2159B, IRGKangXi=0247.071, RSKangXi=36.7
2159C CJK UNIFIED IDEOGRAPH-#2159C, IRGKangXi=0247.071, RSKangXi=36.7
2159D CJK UNIFIED IDEOGRAPH-#2159D, IRGKangXi=0247.080, RSKangXi=36.8
2159E CJK UNIFIED IDEOGRAPH-#2159E, IRGKangXi=0247.110, RSKangXi=36.8
2159F CJK UNIFIED IDEOGRAPH-#2159F, IRGKangXi=0247.120, RSKangXi=36.8
215A0 CJK UNIFIED IDEOGRAPH-#215A0, IRGKangXi=0247.121, RSKangXi=36.8
215A1 CJK UNIFIED IDEOGRAPH-#215A1, IRGKangXi=0247.121, RSKangXi=36.8
215A2 CJK UNIFIED IDEOGRAPH-#215A2, IRGKangXi=0247.121, RSKangXi=36.8
215A3 CJK UNIFIED IDEOGRAPH-#215A3, IRGKangXi=0247.121, RSKangXi=36.8
215A4 CJK UNIFIED IDEOGRAPH-#215A4, IRGKangXi=0247.121, RSKangXi=36.8
215A5 CJK UNIFIED IDEOGRAPH-#215A5, IRGKangXi=0247.121, RSKangXi=36.8
215A6 CJK UNIFIED IDEOGRAPH-#215A6, IRGKangXi=0247.141, RSKangXi=36.9
215A7 CJK UNIFIED IDEOGRAPH-#215A7, IRGKangXi=0247.141, RSKangXi=36.9
215A8 CJK UNIFIED IDEOGRAPH-#215A8, IRGKangXi=0247.141, RSKangXi=36.9
215A9 CJK UNIFIED IDEOGRAPH-#215A9, IRGKangXi=0247.141, RSKangXi=36.9
215AA CJK UNIFIED IDEOGRAPH-#215AA, IRGKangXi=0247.141, RSKangXi=36.9
215AB CJK UNIFIED IDEOGRAPH-#215AB, IRGKangXi=0247.141, RSKangXi=36.9
215AC CJK UNIFIED IDEOGRAPH-#215AC, IRGKangXi=0247.141, RSKangXi=36.9
215AD CJK UNIFIED IDEOGRAPH-#215AD, IRGKangXi=0247.141, RSKangXi=36.9
215AE CJK UNIFIED IDEOGRAPH-#215AE, IRGKangXi=0247.141, RSKangXi=36.9
215AF CJK UNIFIED IDEOGRAPH-#215AF, IRGKangXi=0247.150, RSKangXi=36.10
215B0 CJK UNIFIED IDEOGRAPH-#215B0, IRGKangXi=0247.151, RSKangXi=36.9
215B1 CJK UNIFIED IDEOGRAPH-#215B1, IRGKangXi=0247.151, RSKangXi=36.10
215B2 CJK UNIFIED IDEOGRAPH-#215B2, IRGKangXi=0247.151, RSKangXi=36.10
215B3 CJK UNIFIED IDEOGRAPH-#215B3, IRGKangXi=0247.151, RSKangXi=36.10
215B4 CJK UNIFIED IDEOGRAPH-#215B4, IRGKangXi=0247.151, RSKangXi=36.10
215B5 CJK UNIFIED IDEOGRAPH-#215B5, IRGKangXi=0247.151, RSKangXi=36.10
215B6 CJK UNIFIED IDEOGRAPH-#215B6, IRGKangXi=0247.180, RSKangXi=36.11
215B7 CJK UNIFIED IDEOGRAPH-#215B7, IRGKangXi=0247.200, RSKangXi=36.11
215B8 CJK UNIFIED IDEOGRAPH-#215B8, IRGKangXi=0247.231, RSKangXi=36.11
215B9 CJK UNIFIED IDEOGRAPH-#215B9, IRGKangXi=0247.231, RSKangXi=36.11
215BA CJK UNIFIED IDEOGRAPH-#215BA, IRGKangXi=0247.231, RSKangXi=36.11
215BB CJK UNIFIED IDEOGRAPH-#215BB, IRGKangXi=0247.231, RSKangXi=36.11
215BC CJK UNIFIED IDEOGRAPH-#215BC, IRGKangXi=0247.231, RSKangXi=36.11
215BD CJK UNIFIED IDEOGRAPH-#215BD, IRGKangXi=0247.231, RSKangXi=36.11
215BE CJK UNIFIED IDEOGRAPH-#215BE, IRGKangXi=0247.231, RSKangXi=36.11
215BF CJK UNIFIED IDEOGRAPH-#215BF, IRGKangXi=0247.240, RSKangXi=36.12
215C0 CJK UNIFIED IDEOGRAPH-#215C0, IRGKangXi=0247.241, RSKangXi=36.12
215C1 CJK UNIFIED IDEOGRAPH-#215C1, IRGKangXi=0247.241, RSKangXi=36.12
215C2 CJK UNIFIED IDEOGRAPH-#215C2, IRGKangXi=0247.241, RSKangXi=36.13
215C3 CJK UNIFIED IDEOGRAPH-#215C3, IRGKangXi=0247.241, RSKangXi=36.13
215C4 CJK UNIFIED IDEOGRAPH-#215C4, IRGKangXi=0247.241, RSKangXi=36.13
215C5 CJK UNIFIED IDEOGRAPH-#215C5, IRGKangXi=0247.241, RSKangXi=36.13
215C6 CJK UNIFIED IDEOGRAPH-#215C6, IRGKangXi=0247.250, RSKangXi=36.14
215C7 CJK UNIFIED IDEOGRAPH-#215C7, IRGKangXi=0247.251, RSKangXi=36.14
215C8 CJK UNIFIED IDEOGRAPH-#215C8, IRGKangXi=0247.251, RSKangXi=36.14
215C9 CJK UNIFIED IDEOGRAPH-#215C9, IRGKangXi=0247.261, RSKangXi=36.15
215CA CJK UNIFIED IDEOGRAPH-#215CA, IRGKangXi=0247.261, RSKangXi=36.15
215CB CJK UNIFIED IDEOGRAPH-#215CB, IRGKangXi=0247.261, RSKangXi=36.16
215CC CJK UNIFIED IDEOGRAPH-#215CC, IRGKangXi=0247.261, RSKangXi=36.16
215CD CJK UNIFIED IDEOGRAPH-#215CD, IRGKangXi=0247.261, RSKangXi=36.18
215CE CJK UNIFIED IDEOGRAPH-#215CE, IRGKangXi=0247.261, RSKangXi=36.18
215CF CJK UNIFIED IDEOGRAPH-#215CF, IRGKangXi=0247.261, RSKangXi=36.23
215D0 CJK UNIFIED IDEOGRAPH-#215D0, IRGKangXi=0247.261, RSKangXi=36.16
215D1 CJK UNIFIED IDEOGRAPH-#215D1, IRGKangXi=0247.261, RSKangXi=36.28
215D2 CJK UNIFIED IDEOGRAPH-#215D2, IRGKangXi=0249.020, RSKangXi=37.1
215D3 CJK UNIFIED IDEOGRAPH-#215D3, IRGKangXi=0249.040, RSKangXi=37.1
215D4 CJK UNIFIED IDEOGRAPH-#215D4, IRGKangXi=0249.041, RSKangXi=37.1
215D5 CJK UNIFIED IDEOGRAPH-#215D5, IRGKangXi=0249.070, RSKangXi=37.2
215D6 CJK UNIFIED IDEOGRAPH-#215D6, IRGKangXi=0249.111, RSKangXi=37.2
215D7 CJK UNIFIED IDEOGRAPH-#215D7, IRGKangXi=0249.111, RSKangXi=37.2, Def{folded hands}
215D8 CJK UNIFIED IDEOGRAPH-#215D8, IRGKangXi=0249.111, RSKangXi=37.2
215D9 CJK UNIFIED IDEOGRAPH-#215D9, IRGKangXi=0249.111, RSKangXi=37.2
215DA CJK UNIFIED IDEOGRAPH-#215DA, IRGKangXi=0249.111, RSKangXi=37.2
215DB CJK UNIFIED IDEOGRAPH-#215DB, IRGKangXi=0249.111, RSKangXi=37.2
215DC CJK UNIFIED IDEOGRAPH-#215DC, IRGKangXi=0249.111, RSKangXi=94.1
215DD CJK UNIFIED IDEOGRAPH-#215DD, IRGKangXi=0250.010, RSKangXi=37.3
215DE CJK UNIFIED IDEOGRAPH-#215DE, IRGKangXi=0250.030, RSKangXi=37.3
215DF CJK UNIFIED IDEOGRAPH-#215DF, IRGKangXi=0250.040, RSKangXi=37.3
215E0 CJK UNIFIED IDEOGRAPH-#215E0, IRGKangXi=0250.050, RSKangXi=37.3
215E1 CJK UNIFIED IDEOGRAPH-#215E1, IRGKangXi=0250.060, RSKangXi=37.3
215E2 CJK UNIFIED IDEOGRAPH-#215E2, IRGKangXi=0250.070, RSKangXi=37.3
215E3 CJK UNIFIED IDEOGRAPH-#215E3, IRGKangXi=0250.071, RSKangXi=37.3
215E4 CJK UNIFIED IDEOGRAPH-#215E4, IRGKangXi=0250.071, RSKangXi=37.3
215E5 CJK UNIFIED IDEOGRAPH-#215E5, IRGKangXi=0250.090, RSKangXi=37.4
215E6 CJK UNIFIED IDEOGRAPH-#215E6, IRGKangXi=0250.110, RSKangXi=37.4
215E7 CJK UNIFIED IDEOGRAPH-#215E7, IRGKangXi=0250.150, RSKangXi=37.4
215E8 CJK UNIFIED IDEOGRAPH-#215E8, IRGKangXi=0250.160, RSKangXi=37.4
215E9 CJK UNIFIED IDEOGRAPH-#215E9, IRGKangXi=0250.161, RSKangXi=37.4
215EA CJK UNIFIED IDEOGRAPH-#215EA, IRGKangXi=0250.161, RSKangXi=37.4
215EB CJK UNIFIED IDEOGRAPH-#215EB, IRGKangXi=0250.161, RSKangXi=37.4
215EC CJK UNIFIED IDEOGRAPH-#215EC, IRGKangXi=0250.161, RSKangXi=37.4
215ED CJK UNIFIED IDEOGRAPH-#215ED, IRGKangXi=0250.161, RSKangXi=37.4
215EE CJK UNIFIED IDEOGRAPH-#215EE, IRGKangXi=0250.161, RSKangXi=37.4
215EF CJK UNIFIED IDEOGRAPH-#215EF, IRGKangXi=0250.161, RSKangXi=37.4
215F0 CJK UNIFIED IDEOGRAPH-#215F0, IRGKangXi=0250.161, RSKangXi=37.4
215F1 CJK UNIFIED IDEOGRAPH-#215F1, IRGKangXi=0250.161, RSKangXi=37.4
215F2 CJK UNIFIED IDEOGRAPH-#215F2, IRGKangXi=0250.161, RSKangXi=37.4
215F3 CJK UNIFIED IDEOGRAPH-#215F3, IRGKangXi=0250.161, RSKangXi=37.4
215F4 CJK UNIFIED IDEOGRAPH-#215F4, IRGKangXi=0250.161, RSKangXi=37.4
215F5 CJK UNIFIED IDEOGRAPH-#215F5, IRGKangXi=0250.161, RSKangXi=37.4
215F6 CJK UNIFIED IDEOGRAPH-#215F6, IRGKangXi=0250.161, RSKangXi=37.4
215F7 CJK UNIFIED IDEOGRAPH-#215F7, IRGKangXi=0250.170, RSKangXi=37.5
215F8 CJK UNIFIED IDEOGRAPH-#215F8, IRGKangXi=0250.180, RSKangXi=37.5
215F9 CJK UNIFIED IDEOGRAPH-#215F9, IRGKangXi=0250.190, RSKangXi=37.5
215FA CJK UNIFIED IDEOGRAPH-#215FA, IRGKangXi=0250.220, RSKangXi=37.5
215FB CJK UNIFIED IDEOGRAPH-#215FB, IRGKangXi=0250.260, RSKangXi=37.5
215FC CJK UNIFIED IDEOGRAPH-#215FC, IRGKangXi=0251.050, RSKangXi=37.5
215FD CJK UNIFIED IDEOGRAPH-#215FD, IRGKangXi=0251.070, RSKangXi=37.5
215FE CJK UNIFIED IDEOGRAPH-#215FE, IRGKangXi=0251.080, RSKangXi=37.5
215FF CJK UNIFIED IDEOGRAPH-#215FF, IRGKangXi=0251.090, RSKangXi=37.5
21600 CJK UNIFIED IDEOGRAPH-#21600, IRGKangXi=0251.091, RSKangXi=37.5
21601 CJK UNIFIED IDEOGRAPH-#21601, IRGKangXi=0251.091, RSKangXi=37.5
21602 CJK UNIFIED IDEOGRAPH-#21602, IRGKangXi=0251.091, RSKangXi=37.5
21603 CJK UNIFIED IDEOGRAPH-#21603, IRGKangXi=0251.091, RSKangXi=37.5
21604 CJK UNIFIED IDEOGRAPH-#21604, IRGKangXi=0251.091, RSKangXi=37.5
21605 CJK UNIFIED IDEOGRAPH-#21605, IRGKangXi=0251.091, RSKangXi=37.5
21606 CJK UNIFIED IDEOGRAPH-#21606, IRGKangXi=0251.091, RSKangXi=37.5
21607 CJK UNIFIED IDEOGRAPH-#21607, IRGKangXi=0251.091, RSKangXi=37.5
21608 CJK UNIFIED IDEOGRAPH-#21608, IRGKangXi=0251.091, RSKangXi=37.5
21609 CJK UNIFIED IDEOGRAPH-#21609, IRGKangXi=0251.091, RSKangXi=37.5
2160A CJK UNIFIED IDEOGRAPH-#2160A, IRGKangXi=0251.091, RSKangXi=37.5
2160B CJK UNIFIED IDEOGRAPH-#2160B, IRGKangXi=0251.091, RSKangXi=37.5
2160C CJK UNIFIED IDEOGRAPH-#2160C, IRGKangXi=0251.091, RSKangXi=37.5
2160D CJK UNIFIED IDEOGRAPH-#2160D, IRGKangXi=0251.100, RSKangXi=37.6
2160E CJK UNIFIED IDEOGRAPH-#2160E, IRGKangXi=0251.120, RSKangXi=37.6
2160F CJK UNIFIED IDEOGRAPH-#2160F, IRGKangXi=0251.130, RSKangXi=37.6
21610 CJK UNIFIED IDEOGRAPH-#21610, IRGKangXi=0252.010, RSKangXi=37.6
21611 CJK UNIFIED IDEOGRAPH-#21611, IRGKangXi=0252.051, RSKangXi=37.6
21612 CJK UNIFIED IDEOGRAPH-#21612, IRGKangXi=0252.051, RSKangXi=37.6
21613 CJK UNIFIED IDEOGRAPH-#21613, IRGKangXi=0252.051, RSKangXi=37.6
21614 CJK UNIFIED IDEOGRAPH-#21614, IRGKangXi=0252.051, RSKangXi=37.6
21615 CJK UNIFIED IDEOGRAPH-#21615, IRGKangXi=0252.051, RSKangXi=37.6
21616 CJK UNIFIED IDEOGRAPH-#21616, IRGKangXi=0252.051, RSKangXi=37.6
21617 CJK UNIFIED IDEOGRAPH-#21617, IRGKangXi=0252.051, RSKangXi=37.6
21618 CJK UNIFIED IDEOGRAPH-#21618, IRGKangXi=0252.051, RSKangXi=37.6
21619 CJK UNIFIED IDEOGRAPH-#21619, IRGKangXi=0252.051, RSKangXi=37.6
2161A CJK UNIFIED IDEOGRAPH-#2161A, IRGKangXi=0252.051, RSKangXi=37.6
2161B CJK UNIFIED IDEOGRAPH-#2161B, IRGKangXi=0252.051, RSKangXi=37.6
2161C CJK UNIFIED IDEOGRAPH-#2161C, IRGKangXi=0252.051, RSKangXi=37.6
2161D CJK UNIFIED IDEOGRAPH-#2161D, IRGKangXi=0252.070, RSKangXi=37.7
2161E CJK UNIFIED IDEOGRAPH-#2161E, IRGKangXi=0252.110, RSKangXi=37.7
2161F CJK UNIFIED IDEOGRAPH-#2161F, IRGKangXi=0252.120, RSKangXi=37.7
21620 CJK UNIFIED IDEOGRAPH-#21620, IRGKangXi=0252.130, RSKangXi=37.7
21621 CJK UNIFIED IDEOGRAPH-#21621, IRGKangXi=0252.131, RSKangXi=37.7
21622 CJK UNIFIED IDEOGRAPH-#21622, IRGKangXi=0252.131, RSKangXi=37.7
21623 CJK UNIFIED IDEOGRAPH-#21623, IRGKangXi=0252.131, RSKangXi=37.7
21624 CJK UNIFIED IDEOGRAPH-#21624, IRGKangXi=0252.131, RSKangXi=37.7
21625 CJK UNIFIED IDEOGRAPH-#21625, IRGKangXi=0252.131, RSKangXi=37.7
21626 CJK UNIFIED IDEOGRAPH-#21626, IRGKangXi=0252.131, RSKangXi=37.7
21627 CJK UNIFIED IDEOGRAPH-#21627, IRGKangXi=0252.131, RSKangXi=37.7
21628 CJK UNIFIED IDEOGRAPH-#21628, IRGKangXi=0252.131, RSKangXi=37.7
21629 CJK UNIFIED IDEOGRAPH-#21629, IRGKangXi=0252.131, RSKangXi=37.7
2162A CJK UNIFIED IDEOGRAPH-#2162A, IRGKangXi=0252.131, RSKangXi=37.7
2162B CJK UNIFIED IDEOGRAPH-#2162B, IRGKangXi=0252.131, RSKangXi=37.7
2162C CJK UNIFIED IDEOGRAPH-#2162C, IRGKangXi=0252.131, RSKangXi=37.7
2162D CJK UNIFIED IDEOGRAPH-#2162D, IRGKangXi=0252.131, RSKangXi=37.7
2162E CJK UNIFIED IDEOGRAPH-#2162E, IRGKangXi=0252.131, RSKangXi=37.7
2162F CJK UNIFIED IDEOGRAPH-#2162F, IRGKangXi=0252.131, RSKangXi=37.7
21630 CJK UNIFIED IDEOGRAPH-#21630, IRGKangXi=0252.131, RSKangXi=37.7
21631 CJK UNIFIED IDEOGRAPH-#21631, IRGKangXi=0252.131, RSKangXi=37.7
21632 CJK UNIFIED IDEOGRAPH-#21632, IRGKangXi=0252.131, RSKangXi=37.7
21633 CJK UNIFIED IDEOGRAPH-#21633, IRGKangXi=0252.131, RSKangXi=37.7
21634 CJK UNIFIED IDEOGRAPH-#21634, IRGKangXi=0252.150, RSKangXi=37.8
21635 CJK UNIFIED IDEOGRAPH-#21635, IRGKangXi=0252.160, RSKangXi=37.8
21636 CJK UNIFIED IDEOGRAPH-#21636, IRGKangXi=0252.170, RSKangXi=37.8
21637 CJK UNIFIED IDEOGRAPH-#21637, IRGKangXi=0252.220, RSKangXi=37.8
21638 CJK UNIFIED IDEOGRAPH-#21638, IRGKangXi=0252.230, RSKangXi=37.8
21639 CJK UNIFIED IDEOGRAPH-#21639, IRGKangXi=0252.240, RSKangXi=37.8
2163A CJK UNIFIED IDEOGRAPH-#2163A, IRGKangXi=0252.250, RSKangXi=37.8
2163B CJK UNIFIED IDEOGRAPH-#2163B, IRGKangXi=0253.020, RSKangXi=37.8
2163C CJK UNIFIED IDEOGRAPH-#2163C, IRGKangXi=0253.030, RSKangXi=37.8
2163D CJK UNIFIED IDEOGRAPH-#2163D, IRGKangXi=0253.041, RSKangXi=37.8
2163E CJK UNIFIED IDEOGRAPH-#2163E, IRGKangXi=0253.041, RSKangXi=37.8
2163F CJK UNIFIED IDEOGRAPH-#2163F, IRGKangXi=0253.041, RSKangXi=37.8
21640 CJK UNIFIED IDEOGRAPH-#21640, IRGKangXi=0253.041, RSKangXi=37.8
21641 CJK UNIFIED IDEOGRAPH-#21641, IRGKangXi=0253.041, RSKangXi=37.8
21642 CJK UNIFIED IDEOGRAPH-#21642, IRGKangXi=0253.041, RSKangXi=37.8
21643 CJK UNIFIED IDEOGRAPH-#21643, IRGKangXi=0253.041, RSKangXi=37.8
21644 CJK UNIFIED IDEOGRAPH-#21644, IRGKangXi=0253.041, RSKangXi=37.8
21645 CJK UNIFIED IDEOGRAPH-#21645, IRGKangXi=0253.041, RSKangXi=37.8
21646 CJK UNIFIED IDEOGRAPH-#21646, IRGKangXi=0253.041, RSKangXi=37.8
21647 CJK UNIFIED IDEOGRAPH-#21647, IRGKangXi=0253.080, RSKangXi=37.9
21648 CJK UNIFIED IDEOGRAPH-#21648, IRGKangXi=0253.100, RSKangXi=37.9
21649 CJK UNIFIED IDEOGRAPH-#21649, IRGKangXi=0253.120, RSKangXi=37.9
2164A CJK UNIFIED IDEOGRAPH-#2164A, IRGKangXi=0253.130, RSKangXi=37.9
2164B CJK UNIFIED IDEOGRAPH-#2164B, IRGKangXi=0253.140, RSKangXi=37.9
2164C CJK UNIFIED IDEOGRAPH-#2164C, IRGKangXi=0253.151, RSKangXi=37.9
2164D CJK UNIFIED IDEOGRAPH-#2164D, IRGKangXi=0253.151, RSKangXi=37.9
2164E CJK UNIFIED IDEOGRAPH-#2164E, IRGKangXi=0253.151, RSKangXi=37.9
2164F CJK UNIFIED IDEOGRAPH-#2164F, IRGKangXi=0253.151, RSKangXi=37.9
21650 CJK UNIFIED IDEOGRAPH-#21650, IRGKangXi=0253.151, RSKangXi=37.9
21651 CJK UNIFIED IDEOGRAPH-#21651, IRGKangXi=0253.151, RSKangXi=37.9
21652 CJK UNIFIED IDEOGRAPH-#21652, IRGKangXi=0253.151, RSKangXi=37.9
21653 CJK UNIFIED IDEOGRAPH-#21653, IRGKangXi=0253.151, RSKangXi=37.9
21654 CJK UNIFIED IDEOGRAPH-#21654, IRGKangXi=0253.151, RSKangXi=37.9
21655 CJK UNIFIED IDEOGRAPH-#21655, IRGKangXi=0253.151, RSKangXi=37.9
21656 CJK UNIFIED IDEOGRAPH-#21656, IRGKangXi=0253.151, RSKangXi=37.9
21657 CJK UNIFIED IDEOGRAPH-#21657, IRGKangXi=0253.151, RSKangXi=37.9
21658 CJK UNIFIED IDEOGRAPH-#21658, IRGKangXi=0253.151, RSKangXi=37.9
21659 CJK UNIFIED IDEOGRAPH-#21659, IRGKangXi=0253.151, RSKangXi=37.9
2165A CJK UNIFIED IDEOGRAPH-#2165A, IRGKangXi=0253.151, RSKangXi=37.9
2165B CJK UNIFIED IDEOGRAPH-#2165B, IRGKangXi=0253.170, RSKangXi=37.10
2165C CJK UNIFIED IDEOGRAPH-#2165C, IRGKangXi=0253.200, RSKangXi=37.10
2165D CJK UNIFIED IDEOGRAPH-#2165D, IRGKangXi=0253.210, RSKangXi=37.10
2165E CJK UNIFIED IDEOGRAPH-#2165E, IRGKangXi=0253.211, RSKangXi=37.10
2165F CJK UNIFIED IDEOGRAPH-#2165F, IRGKangXi=0253.211, RSKangXi=37.10
21660 CJK UNIFIED IDEOGRAPH-#21660, IRGKangXi=0253.211, RSKangXi=37.10
21661 CJK UNIFIED IDEOGRAPH-#21661, IRGKangXi=0253.211, RSKangXi=37.10
21662 CJK UNIFIED IDEOGRAPH-#21662, IRGKangXi=0253.211, RSKangXi=37.10
21663 CJK UNIFIED IDEOGRAPH-#21663, IRGKangXi=0253.211, RSKangXi=37.10
21664 CJK UNIFIED IDEOGRAPH-#21664, IRGKangXi=0253.211, RSKangXi=37.10
21665 CJK UNIFIED IDEOGRAPH-#21665, IRGKangXi=0253.211, RSKangXi=37.10
21666 CJK UNIFIED IDEOGRAPH-#21666, IRGKangXi=0253.211, RSKangXi=37.10
21667 CJK UNIFIED IDEOGRAPH-#21667, IRGKangXi=0253.211, RSKangXi=37.10
21668 CJK UNIFIED IDEOGRAPH-#21668, IRGKangXi=0253.211, RSKangXi=37.10
21669 CJK UNIFIED IDEOGRAPH-#21669, IRGKangXi=0253.211, RSKangXi=37.10
2166A CJK UNIFIED IDEOGRAPH-#2166A, IRGKangXi=0253.211, RSKangXi=37.10
2166B CJK UNIFIED IDEOGRAPH-#2166B, IRGKangXi=0253.211, RSKangXi=37.10
2166C CJK UNIFIED IDEOGRAPH-#2166C, IRGKangXi=0253.230, RSKangXi=37.11
2166D CJK UNIFIED IDEOGRAPH-#2166D, IRGKangXi=0253.240, RSKangXi=37.11
2166E CJK UNIFIED IDEOGRAPH-#2166E, IRGKangXi=0253.290, RSKangXi=37.11
2166F CJK UNIFIED IDEOGRAPH-#2166F, IRGKangXi=0254.011, RSKangXi=37.11
21670 CJK UNIFIED IDEOGRAPH-#21670, IRGKangXi=0254.011, RSKangXi=37.11
21671 CJK UNIFIED IDEOGRAPH-#21671, IRGKangXi=0254.011, RSKangXi=37.11
21672 CJK UNIFIED IDEOGRAPH-#21672, IRGKangXi=0254.011, RSKangXi=37.11
21673 CJK UNIFIED IDEOGRAPH-#21673, IRGKangXi=0254.011, RSKangXi=37.11
21674 CJK UNIFIED IDEOGRAPH-#21674, IRGKangXi=0254.011, RSKangXi=37.11
21675 CJK UNIFIED IDEOGRAPH-#21675, IRGKangXi=0254.011, RSKangXi=37.11
21676 CJK UNIFIED IDEOGRAPH-#21676, IRGKangXi=0254.011, RSKangXi=37.11
21677 CJK UNIFIED IDEOGRAPH-#21677, IRGKangXi=0254.040, RSKangXi=37.12
21678 CJK UNIFIED IDEOGRAPH-#21678, IRGKangXi=0254.050, RSKangXi=37.12
21679 CJK UNIFIED IDEOGRAPH-#21679, IRGKangXi=0254.060, RSKangXi=37.12
2167A CJK UNIFIED IDEOGRAPH-#2167A, IRGKangXi=0254.070, RSKangXi=37.12
2167B CJK UNIFIED IDEOGRAPH-#2167B, IRGKangXi=0254.080, RSKangXi=37.12
2167C CJK UNIFIED IDEOGRAPH-#2167C, IRGKangXi=0254.081, RSKangXi=37.12
2167D CJK UNIFIED IDEOGRAPH-#2167D, IRGKangXi=0254.081, RSKangXi=37.12
2167E CJK UNIFIED IDEOGRAPH-#2167E, IRGKangXi=0254.081, RSKangXi=37.12
2167F CJK UNIFIED IDEOGRAPH-#2167F, IRGKangXi=0254.081, RSKangXi=37.12
21680 CJK UNIFIED IDEOGRAPH-#21680, IRGKangXi=0254.081, RSKangXi=37.12
21681 CJK UNIFIED IDEOGRAPH-#21681, IRGKangXi=0254.081, RSKangXi=37.12, Def{used-up, malpractices; (Cant.) bad, vile, corrupt}
21682 CJK UNIFIED IDEOGRAPH-#21682, IRGKangXi=0254.081, RSKangXi=37.12
21683 CJK UNIFIED IDEOGRAPH-#21683, IRGKangXi=0254.081, RSKangXi=37.12
21684 CJK UNIFIED IDEOGRAPH-#21684, IRGKangXi=0254.081, RSKangXi=37.12
21685 CJK UNIFIED IDEOGRAPH-#21685, IRGKangXi=0254.081, RSKangXi=37.12
21686 CJK UNIFIED IDEOGRAPH-#21686, IRGKangXi=0254.110, RSKangXi=37.13
21687 CJK UNIFIED IDEOGRAPH-#21687, IRGKangXi=0254.120, RSKangXi=37.13
21688 CJK UNIFIED IDEOGRAPH-#21688, IRGKangXi=0254.130, RSKangXi=37.13
21689 CJK UNIFIED IDEOGRAPH-#21689, IRGKangXi=0254.140, RSKangXi=37.13
2168A CJK UNIFIED IDEOGRAPH-#2168A, IRGKangXi=0254.150, RSKangXi=37.13
2168B CJK UNIFIED IDEOGRAPH-#2168B, IRGKangXi=0254.151, RSKangXi=37.13
2168C CJK UNIFIED IDEOGRAPH-#2168C, IRGKangXi=0254.151, RSKangXi=37.13
2168D CJK UNIFIED IDEOGRAPH-#2168D, IRGKangXi=0254.151, RSKangXi=37.13
2168E CJK UNIFIED IDEOGRAPH-#2168E, IRGKangXi=0254.151, RSKangXi=37.13
2168F CJK UNIFIED IDEOGRAPH-#2168F, IRGKangXi=0254.160, RSKangXi=37.14
21690 CJK UNIFIED IDEOGRAPH-#21690, IRGKangXi=0254.170, RSKangXi=37.14
21691 CJK UNIFIED IDEOGRAPH-#21691, IRGKangXi=0254.171, RSKangXi=37.14
21692 CJK UNIFIED IDEOGRAPH-#21692, IRGKangXi=0254.171, RSKangXi=37.14
21693 CJK UNIFIED IDEOGRAPH-#21693, IRGKangXi=0254.171, RSKangXi=37.14
21694 CJK UNIFIED IDEOGRAPH-#21694, IRGKangXi=0254.171, RSKangXi=37.14
21695 CJK UNIFIED IDEOGRAPH-#21695, IRGKangXi=0254.171, RSKangXi=37.14
21696 CJK UNIFIED IDEOGRAPH-#21696, IRGKangXi=0254.171, RSKangXi=37.14
21697 CJK UNIFIED IDEOGRAPH-#21697, IRGKangXi=0254.190, RSKangXi=37.15
21698 CJK UNIFIED IDEOGRAPH-#21698, IRGKangXi=0254.191, RSKangXi=37.16
21699 CJK UNIFIED IDEOGRAPH-#21699, IRGKangXi=0254.191, RSKangXi=37.16
2169A CJK UNIFIED IDEOGRAPH-#2169A, IRGKangXi=0254.191, RSKangXi=37.16
2169B CJK UNIFIED IDEOGRAPH-#2169B, IRGKangXi=0254.191, RSKangXi=37.17
2169C CJK UNIFIED IDEOGRAPH-#2169C, IRGKangXi=0254.191, RSKangXi=37.18
2169D CJK UNIFIED IDEOGRAPH-#2169D, IRGKangXi=0254.191, RSKangXi=37.18
2169E CJK UNIFIED IDEOGRAPH-#2169E, IRGKangXi=0254.191, RSKangXi=37.19
2169F CJK UNIFIED IDEOGRAPH-#2169F, IRGKangXi=0254.191, RSKangXi=37.19
216A0 CJK UNIFIED IDEOGRAPH-#216A0, IRGKangXi=0254.200, RSKangXi=37.20
216A1 CJK UNIFIED IDEOGRAPH-#216A1, IRGKangXi=0254.201, RSKangXi=37.20
216A2 CJK UNIFIED IDEOGRAPH-#216A2, IRGKangXi=0254.201, RSKangXi=37.20
216A3 CJK UNIFIED IDEOGRAPH-#216A3, IRGKangXi=0254.201, RSKangXi=37.21
216A4 CJK UNIFIED IDEOGRAPH-#216A4, IRGKangXi=0254.201, RSKangXi=37.21
216A5 CJK UNIFIED IDEOGRAPH-#216A5, IRGKangXi=0254.211, RSKangXi=37.24
216A6 CJK UNIFIED IDEOGRAPH-#216A6, IRGKangXi=0254.231, RSKangXi=38.1, Def{(Cant.) vulgar term for female sex organ}
216A7 CJK UNIFIED IDEOGRAPH-#216A7, IRGKangXi=0254.240, RSKangXi=38.2
216A8 CJK UNIFIED IDEOGRAPH-#216A8, IRGKangXi=0254.250, RSKangXi=38.2
216A9 CJK UNIFIED IDEOGRAPH-#216A9, IRGKangXi=0255.021, RSKangXi=38.2
216AA CJK UNIFIED IDEOGRAPH-#216AA, IRGKangXi=0255.021, RSKangXi=38.2
216AB CJK UNIFIED IDEOGRAPH-#216AB, IRGKangXi=0255.021, RSKangXi=38.2
216AC CJK UNIFIED IDEOGRAPH-#216AC, IRGKangXi=0255.021, RSKangXi=38.2
216AD CJK UNIFIED IDEOGRAPH-#216AD, IRGKangXi=0255.021, RSKangXi=38.2
216AE CJK UNIFIED IDEOGRAPH-#216AE, IRGKangXi=0255.070, RSKangXi=38.3
216AF CJK UNIFIED IDEOGRAPH-#216AF, IRGKangXi=0255.180, RSKangXi=38.3
216B0 CJK UNIFIED IDEOGRAPH-#216B0, IRGKangXi=0256.041, RSKangXi=38.3
216B1 CJK UNIFIED IDEOGRAPH-#216B1, IRGKangXi=0256.041, RSKangXi=38.3
216B2 CJK UNIFIED IDEOGRAPH-#216B2, IRGKangXi=0256.041, RSKangXi=38.3
216B3 CJK UNIFIED IDEOGRAPH-#216B3, IRGKangXi=0256.041, RSKangXi=38.3
216B4 CJK UNIFIED IDEOGRAPH-#216B4, IRGKangXi=0256.041, RSKangXi=38.3
216B5 CJK UNIFIED IDEOGRAPH-#216B5, IRGKangXi=0256.041, RSKangXi=38.3
216B6 CJK UNIFIED IDEOGRAPH-#216B6, IRGKangXi=0256.041, RSKangXi=38.3
216B7 CJK UNIFIED IDEOGRAPH-#216B7, IRGKangXi=0256.041, RSKangXi=38.3
216B8 CJK UNIFIED IDEOGRAPH-#216B8, IRGKangXi=0256.041, RSKangXi=38.3
216B9 CJK UNIFIED IDEOGRAPH-#216B9, IRGKangXi=0256.041, RSKangXi=38.3
216BA CJK UNIFIED IDEOGRAPH-#216BA, IRGKangXi=0256.041, RSKangXi=38.3
216BB CJK UNIFIED IDEOGRAPH-#216BB, IRGKangXi=0256.041, RSKangXi=38.3
216BC CJK UNIFIED IDEOGRAPH-#216BC, IRGKangXi=0256.270, RSKangXi=38.4
216BD CJK UNIFIED IDEOGRAPH-#216BD, IRGKangXi=0256.310, RSKangXi=38.4
216BE CJK UNIFIED IDEOGRAPH-#216BE, IRGKangXi=0257.090, RSKangXi=38.4
216BF CJK UNIFIED IDEOGRAPH-#216BF, IRGKangXi=0257.101, RSKangXi=38.4
216C0 CJK UNIFIED IDEOGRAPH-#216C0, IRGKangXi=0257.101, RSKangXi=38.4
216C1 CJK UNIFIED IDEOGRAPH-#216C1, IRGKangXi=0257.101, RSKangXi=38.4
216C2 CJK UNIFIED IDEOGRAPH-#216C2, IRGKangXi=0257.101, RSKangXi=38.4
216C3 CJK UNIFIED IDEOGRAPH-#216C3, IRGKangXi=0257.101, RSKangXi=38.4
216C4 CJK UNIFIED IDEOGRAPH-#216C4, IRGKangXi=0257.101, RSKangXi=38.4
216C5 CJK UNIFIED IDEOGRAPH-#216C5, IRGKangXi=0257.101, RSKangXi=38.4
216C6 CJK UNIFIED IDEOGRAPH-#216C6, IRGKangXi=0257.101, RSKangXi=38.4
216C7 CJK UNIFIED IDEOGRAPH-#216C7, IRGKangXi=0257.101, RSKangXi=38.4
216C8 CJK UNIFIED IDEOGRAPH-#216C8, IRGKangXi=0257.101, RSKangXi=38.4
216C9 CJK UNIFIED IDEOGRAPH-#216C9, IRGKangXi=0257.101, RSKangXi=38.4
216CA CJK UNIFIED IDEOGRAPH-#216CA, IRGKangXi=0257.101, RSKangXi=38.4
216CB CJK UNIFIED IDEOGRAPH-#216CB, IRGKangXi=0257.101, RSKangXi=38.4
216CC CJK UNIFIED IDEOGRAPH-#216CC, IRGKangXi=0257.101, RSKangXi=38.4
216CD CJK UNIFIED IDEOGRAPH-#216CD, IRGKangXi=0257.101, RSKangXi=38.4
216CE CJK UNIFIED IDEOGRAPH-#216CE, IRGKangXi=0257.101, RSKangXi=38.4
216CF CJK UNIFIED IDEOGRAPH-#216CF, IRGKangXi=0257.101, RSKangXi=38.4
216D0 CJK UNIFIED IDEOGRAPH-#216D0, IRGKangXi=0257.101, RSKangXi=38.4
216D1 CJK UNIFIED IDEOGRAPH-#216D1, IRGKangXi=0257.101, RSKangXi=38.4
216D2 CJK UNIFIED IDEOGRAPH-#216D2, IRGKangXi=0257.101, RSKangXi=38.4
216D3 CJK UNIFIED IDEOGRAPH-#216D3, IRGKangXi=0257.101, RSKangXi=38.4
216D4 CJK UNIFIED IDEOGRAPH-#216D4, IRGKangXi=0257.101, RSKangXi=38.4
216D5 CJK UNIFIED IDEOGRAPH-#216D5, IRGKangXi=0257.101, RSKangXi=38.4
216D6 CJK UNIFIED IDEOGRAPH-#216D6, IRGKangXi=0257.101, RSKangXi=38.4
216D7 CJK UNIFIED IDEOGRAPH-#216D7, IRGKangXi=0257.101, RSKangXi=38.4
216D8 CJK UNIFIED IDEOGRAPH-#216D8, IRGKangXi=0257.101, RSKangXi=38.4
216D9 CJK UNIFIED IDEOGRAPH-#216D9, IRGKangXi=0257.150, RSKangXi=38.5
216DA CJK UNIFIED IDEOGRAPH-#216DA, IRGKangXi=0257.220, RSKangXi=38.5
216DB CJK UNIFIED IDEOGRAPH-#216DB, IRGKangXi=0257.340, RSKangXi=38.5
216DC CJK UNIFIED IDEOGRAPH-#216DC, IRGKangXi=0257.360, RSKangXi=38.5
216DD CJK UNIFIED IDEOGRAPH-#216DD, IRGKangXi=0257.370, RSKangXi=38.5
216DE CJK UNIFIED IDEOGRAPH-#216DE, IRGKangXi=0258.220, RSKangXi=38.5
216DF CJK UNIFIED IDEOGRAPH-#216DF, IRGKangXi=0258.300, RSKangXi=38.5
216E0 CJK UNIFIED IDEOGRAPH-#216E0, IRGKangXi=0259.020, RSKangXi=38.5
216E1 CJK UNIFIED IDEOGRAPH-#216E1, IRGKangXi=0259.080, RSKangXi=38.5
216E2 CJK UNIFIED IDEOGRAPH-#216E2, IRGKangXi=0259.130, RSKangXi=38.5
216E3 CJK UNIFIED IDEOGRAPH-#216E3, IRGKangXi=0259.151, RSKangXi=38.5
216E4 CJK UNIFIED IDEOGRAPH-#216E4, IRGKangXi=0259.151, RSKangXi=38.5
216E5 CJK UNIFIED IDEOGRAPH-#216E5, IRGKangXi=0259.151, RSKangXi=38.5
216E6 CJK UNIFIED IDEOGRAPH-#216E6, IRGKangXi=0259.151, RSKangXi=38.5
216E7 CJK UNIFIED IDEOGRAPH-#216E7, IRGKangXi=0259.151, RSKangXi=38.5
216E8 CJK UNIFIED IDEOGRAPH-#216E8, IRGKangXi=0259.151, RSKangXi=38.5
216E9 CJK UNIFIED IDEOGRAPH-#216E9, IRGKangXi=0259.151, RSKangXi=38.5
216EA CJK UNIFIED IDEOGRAPH-#216EA, IRGKangXi=0259.151, RSKangXi=38.5
216EB CJK UNIFIED IDEOGRAPH-#216EB, IRGKangXi=0259.151, RSKangXi=38.5
216EC CJK UNIFIED IDEOGRAPH-#216EC, IRGKangXi=0259.151, RSKangXi=38.5
216ED CJK UNIFIED IDEOGRAPH-#216ED, IRGKangXi=0259.151, RSKangXi=38.5
216EE CJK UNIFIED IDEOGRAPH-#216EE, IRGKangXi=0259.151, RSKangXi=38.5
216EF CJK UNIFIED IDEOGRAPH-#216EF, IRGKangXi=0259.151, RSKangXi=38.5
216F0 CJK UNIFIED IDEOGRAPH-#216F0, IRGKangXi=0259.151, RSKangXi=38.5
216F1 CJK UNIFIED IDEOGRAPH-#216F1, IRGKangXi=0259.151, RSKangXi=38.5
216F2 CJK UNIFIED IDEOGRAPH-#216F2, IRGKangXi=0259.151, RSKangXi=38.5
216F3 CJK UNIFIED IDEOGRAPH-#216F3, IRGKangXi=0259.151, RSKangXi=38.5
216F4 CJK UNIFIED IDEOGRAPH-#216F4, IRGKangXi=0259.151, RSKangXi=38.5
216F5 CJK UNIFIED IDEOGRAPH-#216F5, IRGKangXi=0259.151, RSKangXi=38.5
216F6 CJK UNIFIED IDEOGRAPH-#216F6, IRGKangXi=0259.151, RSKangXi=38.5
216F7 CJK UNIFIED IDEOGRAPH-#216F7, IRGKangXi=0259.151, RSKangXi=38.5
216F8 CJK UNIFIED IDEOGRAPH-#216F8, IRGKangXi=0259.151, RSKangXi=38.5
216F9 CJK UNIFIED IDEOGRAPH-#216F9, IRGKangXi=0259.151, RSKangXi=38.5
216FA CJK UNIFIED IDEOGRAPH-#216FA, IRGKangXi=0259.151, RSKangXi=38.5
216FB CJK UNIFIED IDEOGRAPH-#216FB, IRGKangXi=0259.151, RSKangXi=38.5
216FC CJK UNIFIED IDEOGRAPH-#216FC, IRGKangXi=0259.151, RSKangXi=38.5
216FD CJK UNIFIED IDEOGRAPH-#216FD, IRGKangXi=0259.151, RSKangXi=38.5
216FE CJK UNIFIED IDEOGRAPH-#216FE, IRGKangXi=0259.151, RSKangXi=38.5
216FF CJK UNIFIED IDEOGRAPH-#216FF, IRGKangXi=0259.151, RSKangXi=38.5
21700 CJK UNIFIED IDEOGRAPH-#21700, IRGKangXi=0259.151, RSKangXi=38.5
21701 CJK UNIFIED IDEOGRAPH-#21701, IRGKangXi=0259.151, RSKangXi=38.5
21702 CJK UNIFIED IDEOGRAPH-#21702, IRGKangXi=0260.130, RSKangXi=38.6
21703 CJK UNIFIED IDEOGRAPH-#21703, IRGKangXi=0260.170, RSKangXi=38.6
21704 CJK UNIFIED IDEOGRAPH-#21704, IRGKangXi=0260.200, RSKangXi=38.6
21705 CJK UNIFIED IDEOGRAPH-#21705, IRGKangXi=0260.210, RSKangXi=38.6
21706 CJK UNIFIED IDEOGRAPH-#21706, IRGKangXi=0261.030, RSKangXi=38.6
21707 CJK UNIFIED IDEOGRAPH-#21707, IRGKangXi=0261.100, RSKangXi=38.6
21708 CJK UNIFIED IDEOGRAPH-#21708, IRGKangXi=0261.110, RSKangXi=38.6
21709 CJK UNIFIED IDEOGRAPH-#21709, IRGKangXi=0261.120, RSKangXi=38.6
2170A CJK UNIFIED IDEOGRAPH-#2170A, IRGKangXi=0261.170, RSKangXi=38.6
2170B CJK UNIFIED IDEOGRAPH-#2170B, IRGKangXi=0261.210, RSKangXi=38.6
2170C CJK UNIFIED IDEOGRAPH-#2170C, IRGKangXi=0261.300, RSKangXi=38.6
2170D CJK UNIFIED IDEOGRAPH-#2170D, IRGKangXi=0261.310, RSKangXi=38.6
2170E CJK UNIFIED IDEOGRAPH-#2170E, IRGKangXi=0261.320, RSKangXi=38.6
2170F CJK UNIFIED IDEOGRAPH-#2170F, IRGKangXi=0261.321, RSKangXi=38.6
21710 CJK UNIFIED IDEOGRAPH-#21710, IRGKangXi=0261.321, RSKangXi=38.6
21711 CJK UNIFIED IDEOGRAPH-#21711, IRGKangXi=0261.321, RSKangXi=38.6
21712 CJK UNIFIED IDEOGRAPH-#21712, IRGKangXi=0261.321, RSKangXi=38.6
21713 CJK UNIFIED IDEOGRAPH-#21713, IRGKangXi=0261.321, RSKangXi=38.6
21714 CJK UNIFIED IDEOGRAPH-#21714, IRGKangXi=0261.321, RSKangXi=38.6
21715 CJK UNIFIED IDEOGRAPH-#21715, IRGKangXi=0261.321, RSKangXi=38.6
21716 CJK UNIFIED IDEOGRAPH-#21716, IRGKangXi=0261.321, RSKangXi=38.6
21717 CJK UNIFIED IDEOGRAPH-#21717, IRGKangXi=0261.321, RSKangXi=38.6
21718 CJK UNIFIED IDEOGRAPH-#21718, IRGKangXi=0261.321, RSKangXi=38.6
21719 CJK UNIFIED IDEOGRAPH-#21719, IRGKangXi=0261.321, RSKangXi=38.6
2171A CJK UNIFIED IDEOGRAPH-#2171A, IRGKangXi=0261.321, RSKangXi=38.6
2171B CJK UNIFIED IDEOGRAPH-#2171B, IRGKangXi=0261.321, RSKangXi=38.6
2171C CJK UNIFIED IDEOGRAPH-#2171C, IRGKangXi=0261.321, RSKangXi=38.6
2171D CJK UNIFIED IDEOGRAPH-#2171D, IRGKangXi=0261.321, RSKangXi=38.6
2171E CJK UNIFIED IDEOGRAPH-#2171E, IRGKangXi=0261.321, RSKangXi=38.6
2171F CJK UNIFIED IDEOGRAPH-#2171F, IRGKangXi=0261.321, RSKangXi=38.6
21720 CJK UNIFIED IDEOGRAPH-#21720, IRGKangXi=0261.321, RSKangXi=38.6
21721 CJK UNIFIED IDEOGRAPH-#21721, IRGKangXi=0261.321, RSKangXi=38.6
21722 CJK UNIFIED IDEOGRAPH-#21722, IRGKangXi=0261.321, RSKangXi=38.6
21723 CJK UNIFIED IDEOGRAPH-#21723, IRGKangXi=0261.321, RSKangXi=38.6
21724 CJK UNIFIED IDEOGRAPH-#21724, IRGKangXi=0261.321, RSKangXi=38.6
21725 CJK UNIFIED IDEOGRAPH-#21725, IRGKangXi=0261.321, RSKangXi=38.6
21726 CJK UNIFIED IDEOGRAPH-#21726, IRGKangXi=0261.321, RSKangXi=38.6
21727 CJK UNIFIED IDEOGRAPH-#21727, IRGKangXi=0261.321, RSKangXi=38.6
21728 CJK UNIFIED IDEOGRAPH-#21728, IRGKangXi=0261.321, RSKangXi=38.6
21729 CJK UNIFIED IDEOGRAPH-#21729, IRGKangXi=0261.321, RSKangXi=38.6
2172A CJK UNIFIED IDEOGRAPH-#2172A, IRGKangXi=0261.321, RSKangXi=38.6
2172B CJK UNIFIED IDEOGRAPH-#2172B, IRGKangXi=0261.321, RSKangXi=38.6
2172C CJK UNIFIED IDEOGRAPH-#2172C, IRGKangXi=0261.321, RSKangXi=38.6
2172D CJK UNIFIED IDEOGRAPH-#2172D, IRGKangXi=0261.321, RSKangXi=38.6
2172E CJK UNIFIED IDEOGRAPH-#2172E, IRGKangXi=0261.330, RSKangXi=38.7
2172F CJK UNIFIED IDEOGRAPH-#2172F, IRGKangXi=0261.400, RSKangXi=38.7
21730 CJK UNIFIED IDEOGRAPH-#21730, IRGKangXi=0262.070, RSKangXi=38.7
21731 CJK UNIFIED IDEOGRAPH-#21731, IRGKangXi=0262.210, RSKangXi=38.7, Def{to envy, to be angry with; (Cant.) pregnant}
21732 CJK UNIFIED IDEOGRAPH-#21732, IRGKangXi=0262.260, RSKangXi=38.7
21733 CJK UNIFIED IDEOGRAPH-#21733, IRGKangXi=0263.050, RSKangXi=38.7
21734 CJK UNIFIED IDEOGRAPH-#21734, IRGKangXi=0263.070, RSKangXi=38.7
21735 CJK UNIFIED IDEOGRAPH-#21735, IRGKangXi=0263.140, RSKangXi=38.7
21736 CJK UNIFIED IDEOGRAPH-#21736, IRGKangXi=0263.190, RSKangXi=38.7
21737 CJK UNIFIED IDEOGRAPH-#21737, IRGKangXi=0263.240, RSKangXi=38.7
21738 CJK UNIFIED IDEOGRAPH-#21738, IRGKangXi=0263.250, RSKangXi=38.7
21739 CJK UNIFIED IDEOGRAPH-#21739, IRGKangXi=0263.251, RSKangXi=38.7
2173A CJK UNIFIED IDEOGRAPH-#2173A, IRGKangXi=0263.251, RSKangXi=38.7
2173B CJK UNIFIED IDEOGRAPH-#2173B, IRGKangXi=0263.251, RSKangXi=38.7
2173C CJK UNIFIED IDEOGRAPH-#2173C, IRGKangXi=0263.251, RSKangXi=38.7
2173D CJK UNIFIED IDEOGRAPH-#2173D, IRGKangXi=0263.251, RSKangXi=38.7
2173E CJK UNIFIED IDEOGRAPH-#2173E, IRGKangXi=0263.251, RSKangXi=38.7
2173F CJK UNIFIED IDEOGRAPH-#2173F, IRGKangXi=0263.251, RSKangXi=38.7
21740 CJK UNIFIED IDEOGRAPH-#21740, IRGKangXi=0263.251, RSKangXi=38.7
21741 CJK UNIFIED IDEOGRAPH-#21741, IRGKangXi=0263.251, RSKangXi=38.7
21742 CJK UNIFIED IDEOGRAPH-#21742, IRGKangXi=0263.251, RSKangXi=38.7
21743 CJK UNIFIED IDEOGRAPH-#21743, IRGKangXi=0263.251, RSKangXi=38.7
21744 CJK UNIFIED IDEOGRAPH-#21744, IRGKangXi=0263.251, RSKangXi=38.7
21745 CJK UNIFIED IDEOGRAPH-#21745, IRGKangXi=0263.251, RSKangXi=38.7
21746 CJK UNIFIED IDEOGRAPH-#21746, IRGKangXi=0263.251, RSKangXi=38.7
21747 CJK UNIFIED IDEOGRAPH-#21747, IRGKangXi=0263.251, RSKangXi=38.7
21748 CJK UNIFIED IDEOGRAPH-#21748, IRGKangXi=0263.251, RSKangXi=38.7
21749 CJK UNIFIED IDEOGRAPH-#21749, IRGKangXi=0263.251, RSKangXi=38.7
2174A CJK UNIFIED IDEOGRAPH-#2174A, IRGKangXi=0263.251, RSKangXi=38.7
2174B CJK UNIFIED IDEOGRAPH-#2174B, IRGKangXi=0263.251, RSKangXi=38.7
2174C CJK UNIFIED IDEOGRAPH-#2174C, IRGKangXi=0263.251, RSKangXi=38.7
2174D CJK UNIFIED IDEOGRAPH-#2174D, IRGKangXi=0263.251, RSKangXi=38.7
2174E CJK UNIFIED IDEOGRAPH-#2174E, IRGKangXi=0263.251, RSKangXi=38.7
2174F CJK UNIFIED IDEOGRAPH-#2174F, IRGKangXi=0263.251, RSKangXi=38.7
21750 CJK UNIFIED IDEOGRAPH-#21750, IRGKangXi=0263.251, RSKangXi=38.7
21751 CJK UNIFIED IDEOGRAPH-#21751, IRGKangXi=0263.251, RSKangXi=38.7
21752 CJK UNIFIED IDEOGRAPH-#21752, IRGKangXi=0263.251, RSKangXi=38.7
21753 CJK UNIFIED IDEOGRAPH-#21753, IRGKangXi=0263.251, RSKangXi=38.7
21754 CJK UNIFIED IDEOGRAPH-#21754, IRGKangXi=0263.251, RSKangXi=38.7
21755 CJK UNIFIED IDEOGRAPH-#21755, IRGKangXi=0263.251, RSKangXi=38.7
21756 CJK UNIFIED IDEOGRAPH-#21756, IRGKangXi=0263.251, RSKangXi=38.7
21757 CJK UNIFIED IDEOGRAPH-#21757, IRGKangXi=0263.251, RSKangXi=38.7
21758 CJK UNIFIED IDEOGRAPH-#21758, IRGKangXi=0263.251, RSKangXi=38.7
21759 CJK UNIFIED IDEOGRAPH-#21759, IRGKangXi=0263.251, RSKangXi=38.7
2175A CJK UNIFIED IDEOGRAPH-#2175A, IRGKangXi=0263.251, RSKangXi=38.7
2175B CJK UNIFIED IDEOGRAPH-#2175B, IRGKangXi=0263.251, RSKangXi=38.7
2175C CJK UNIFIED IDEOGRAPH-#2175C, IRGKangXi=0263.251, RSKangXi=38.7
2175D CJK UNIFIED IDEOGRAPH-#2175D, IRGKangXi=0263.251, RSKangXi=38.7
2175E CJK UNIFIED IDEOGRAPH-#2175E, IRGKangXi=0263.260, RSKangXi=38.8
2175F CJK UNIFIED IDEOGRAPH-#2175F, IRGKangXi=0263.270, RSKangXi=38.8
21760 CJK UNIFIED IDEOGRAPH-#21760, IRGKangXi=0263.350, RSKangXi=38.8
21761 CJK UNIFIED IDEOGRAPH-#21761, IRGKangXi=0263.360, RSKangXi=38.8
21762 CJK UNIFIED IDEOGRAPH-#21762, IRGKangXi=0263.380, RSKangXi=38.8
21763 CJK UNIFIED IDEOGRAPH-#21763, IRGKangXi=0263.440, RSKangXi=38.8
21764 CJK UNIFIED IDEOGRAPH-#21764, IRGKangXi=0264.010, RSKangXi=38.8
21765 CJK UNIFIED IDEOGRAPH-#21765, IRGKangXi=0264.070, RSKangXi=38.8
21766 CJK UNIFIED IDEOGRAPH-#21766, IRGKangXi=0264.150, RSKangXi=38.8
21767 CJK UNIFIED IDEOGRAPH-#21767, IRGKangXi=0264.230, RSKangXi=38.8
21768 CJK UNIFIED IDEOGRAPH-#21768, IRGKangXi=0264.240, RSKangXi=38.8
21769 CJK UNIFIED IDEOGRAPH-#21769, IRGKangXi=0264.250, RSKangXi=38.8
2176A CJK UNIFIED IDEOGRAPH-#2176A, IRGKangXi=0265.010, RSKangXi=38.8
2176B CJK UNIFIED IDEOGRAPH-#2176B, IRGKangXi=0265.080, RSKangXi=38.8
2176C CJK UNIFIED IDEOGRAPH-#2176C, IRGKangXi=0265.281, RSKangXi=38.8
2176D CJK UNIFIED IDEOGRAPH-#2176D, IRGKangXi=0265.281, RSKangXi=38.8
2176E CJK UNIFIED IDEOGRAPH-#2176E, IRGKangXi=0265.281, RSKangXi=38.8
2176F CJK UNIFIED IDEOGRAPH-#2176F, IRGKangXi=0265.281, RSKangXi=38.8
21770 CJK UNIFIED IDEOGRAPH-#21770, IRGKangXi=0265.281, RSKangXi=38.8
21771 CJK UNIFIED IDEOGRAPH-#21771, IRGKangXi=0265.281, RSKangXi=38.8
21772 CJK UNIFIED IDEOGRAPH-#21772, IRGKangXi=0265.281, RSKangXi=38.8
21773 CJK UNIFIED IDEOGRAPH-#21773, IRGKangXi=0265.281, RSKangXi=38.8
21774 CJK UNIFIED IDEOGRAPH-#21774, IRGKangXi=0265.281, RSKangXi=38.8
21775 CJK UNIFIED IDEOGRAPH-#21775, IRGKangXi=0265.281, RSKangXi=38.8
21776 CJK UNIFIED IDEOGRAPH-#21776, IRGKangXi=0265.281, RSKangXi=38.8
21777 CJK UNIFIED IDEOGRAPH-#21777, IRGKangXi=0265.281, RSKangXi=38.8
21778 CJK UNIFIED IDEOGRAPH-#21778, IRGKangXi=0265.281, RSKangXi=38.8
21779 CJK UNIFIED IDEOGRAPH-#21779, IRGKangXi=0265.281, RSKangXi=38.8
2177A CJK UNIFIED IDEOGRAPH-#2177A, IRGKangXi=0265.281, RSKangXi=38.8
2177B CJK UNIFIED IDEOGRAPH-#2177B, IRGKangXi=0265.281, RSKangXi=38.8
2177C CJK UNIFIED IDEOGRAPH-#2177C, IRGKangXi=0265.281, RSKangXi=38.8
2177D CJK UNIFIED IDEOGRAPH-#2177D, IRGKangXi=0265.281, RSKangXi=38.8
2177E CJK UNIFIED IDEOGRAPH-#2177E, IRGKangXi=0265.281, RSKangXi=38.8
2177F CJK UNIFIED IDEOGRAPH-#2177F, IRGKangXi=0265.281, RSKangXi=38.8
21780 CJK UNIFIED IDEOGRAPH-#21780, IRGKangXi=0265.281, RSKangXi=38.8
21781 CJK UNIFIED IDEOGRAPH-#21781, IRGKangXi=0265.281, RSKangXi=38.8
21782 CJK UNIFIED IDEOGRAPH-#21782, IRGKangXi=0265.281, RSKangXi=38.8
21783 CJK UNIFIED IDEOGRAPH-#21783, IRGKangXi=0265.281, RSKangXi=38.8
21784 CJK UNIFIED IDEOGRAPH-#21784, IRGKangXi=0265.281, RSKangXi=38.8
21785 CJK UNIFIED IDEOGRAPH-#21785, IRGKangXi=0265.281, RSKangXi=38.8
21786 CJK UNIFIED IDEOGRAPH-#21786, IRGKangXi=0265.281, RSKangXi=38.8
21787 CJK UNIFIED IDEOGRAPH-#21787, IRGKangXi=0265.281, RSKangXi=38.8
21788 CJK UNIFIED IDEOGRAPH-#21788, IRGKangXi=0265.281, RSKangXi=38.8
21789 CJK UNIFIED IDEOGRAPH-#21789, IRGKangXi=0265.281, RSKangXi=38.8
2178A CJK UNIFIED IDEOGRAPH-#2178A, IRGKangXi=0265.281, RSKangXi=38.8
2178B CJK UNIFIED IDEOGRAPH-#2178B, IRGKangXi=0265.281, RSKangXi=38.8
2178C CJK UNIFIED IDEOGRAPH-#2178C, IRGKangXi=0265.281, RSKangXi=38.8
2178D CJK UNIFIED IDEOGRAPH-#2178D, IRGKangXi=0265.281, RSKangXi=38.8
2178E CJK UNIFIED IDEOGRAPH-#2178E, IRGKangXi=0265.281, RSKangXi=38.8
2178F CJK UNIFIED IDEOGRAPH-#2178F, IRGKangXi=0265.281, RSKangXi=38.8
21790 CJK UNIFIED IDEOGRAPH-#21790, IRGKangXi=0265.281, RSKangXi=38.8
21791 CJK UNIFIED IDEOGRAPH-#21791, IRGKangXi=0265.281, RSKangXi=38.8
21792 CJK UNIFIED IDEOGRAPH-#21792, IRGKangXi=0265.281, RSKangXi=38.8
21793 CJK UNIFIED IDEOGRAPH-#21793, IRGKangXi=0265.281, RSKangXi=38.8
21794 CJK UNIFIED IDEOGRAPH-#21794, IRGKangXi=0265.281, RSKangXi=38.8
21795 CJK UNIFIED IDEOGRAPH-#21795, IRGKangXi=0265.281, RSKangXi=38.8
21796 CJK UNIFIED IDEOGRAPH-#21796, IRGKangXi=0265.281, RSKangXi=38.8
21797 CJK UNIFIED IDEOGRAPH-#21797, IRGKangXi=0265.281, RSKangXi=38.8
21798 CJK UNIFIED IDEOGRAPH-#21798, IRGKangXi=0265.281, RSKangXi=38.8
21799 CJK UNIFIED IDEOGRAPH-#21799, IRGKangXi=0265.281, RSKangXi=38.8
2179A CJK UNIFIED IDEOGRAPH-#2179A, IRGKangXi=0265.281, RSKangXi=38.8
2179B CJK UNIFIED IDEOGRAPH-#2179B, IRGKangXi=0265.281, RSKangXi=38.8
2179C CJK UNIFIED IDEOGRAPH-#2179C, IRGKangXi=0265.310, RSKangXi=38.9
2179D CJK UNIFIED IDEOGRAPH-#2179D, IRGKangXi=0266.110, RSKangXi=38.9
2179E CJK UNIFIED IDEOGRAPH-#2179E, IRGKangXi=0266.280, RSKangXi=38.9
2179F CJK UNIFIED IDEOGRAPH-#2179F, IRGKangXi=0266.330, RSKangXi=38.9
217A0 CJK UNIFIED IDEOGRAPH-#217A0, IRGKangXi=0266.350, RSKangXi=38.9
217A1 CJK UNIFIED IDEOGRAPH-#217A1, IRGKangXi=0266.380, RSKangXi=38.9
217A2 CJK UNIFIED IDEOGRAPH-#217A2, IRGKangXi=0266.410, RSKangXi=38.9
217A3 CJK UNIFIED IDEOGRAPH-#217A3, IRGKangXi=0267.030, RSKangXi=38.9
217A4 CJK UNIFIED IDEOGRAPH-#217A4, IRGKangXi=0267.060, RSKangXi=38.9
217A5 CJK UNIFIED IDEOGRAPH-#217A5, IRGKangXi=0267.090, RSKangXi=38.9
217A6 CJK UNIFIED IDEOGRAPH-#217A6, IRGKangXi=0267.100, RSKangXi=38.9
217A7 CJK UNIFIED IDEOGRAPH-#217A7, IRGKangXi=0267.130, RSKangXi=38.9
217A8 CJK UNIFIED IDEOGRAPH-#217A8, IRGKangXi=0267.290, RSKangXi=38.9
217A9 CJK UNIFIED IDEOGRAPH-#217A9, IRGKangXi=0267.310, RSKangXi=38.9
217AA CJK UNIFIED IDEOGRAPH-#217AA, IRGKangXi=0267.320, RSKangXi=38.9
217AB CJK UNIFIED IDEOGRAPH-#217AB, IRGKangXi=0267.330, RSKangXi=38.9
217AC CJK UNIFIED IDEOGRAPH-#217AC, IRGKangXi=0267.340, RSKangXi=38.9
217AD CJK UNIFIED IDEOGRAPH-#217AD, IRGKangXi=0267.360, RSKangXi=38.9
217AE CJK UNIFIED IDEOGRAPH-#217AE, IRGKangXi=0267.361, RSKangXi=38.9
217AF CJK UNIFIED IDEOGRAPH-#217AF, IRGKangXi=0267.361, RSKangXi=38.9
217B0 CJK UNIFIED IDEOGRAPH-#217B0, IRGKangXi=0267.361, RSKangXi=38.9
217B1 CJK UNIFIED IDEOGRAPH-#217B1, IRGKangXi=0267.361, RSKangXi=38.9
217B2 CJK UNIFIED IDEOGRAPH-#217B2, IRGKangXi=0267.361, RSKangXi=38.9
217B3 CJK UNIFIED IDEOGRAPH-#217B3, IRGKangXi=0267.361, RSKangXi=38.9
217B4 CJK UNIFIED IDEOGRAPH-#217B4, IRGKangXi=0267.361, RSKangXi=38.9
217B5 CJK UNIFIED IDEOGRAPH-#217B5, IRGKangXi=0267.361, RSKangXi=38.9
217B6 CJK UNIFIED IDEOGRAPH-#217B6, IRGKangXi=0267.361, RSKangXi=38.9
217B7 CJK UNIFIED IDEOGRAPH-#217B7, IRGKangXi=0267.361, RSKangXi=38.9
217B8 CJK UNIFIED IDEOGRAPH-#217B8, IRGKangXi=0267.361, RSKangXi=38.9
217B9 CJK UNIFIED IDEOGRAPH-#217B9, IRGKangXi=0267.361, RSKangXi=38.9
217BA CJK UNIFIED IDEOGRAPH-#217BA, IRGKangXi=0267.361, RSKangXi=38.9
217BB CJK UNIFIED IDEOGRAPH-#217BB, IRGKangXi=0267.361, RSKangXi=38.9
217BC CJK UNIFIED IDEOGRAPH-#217BC, IRGKangXi=0267.361, RSKangXi=38.9
217BD CJK UNIFIED IDEOGRAPH-#217BD, IRGKangXi=0267.361, RSKangXi=38.9
217BE CJK UNIFIED IDEOGRAPH-#217BE, IRGKangXi=0267.361, RSKangXi=38.9, Def{soft, delicate}
217BF CJK UNIFIED IDEOGRAPH-#217BF, IRGKangXi=0267.361, RSKangXi=38.9
217C0 CJK UNIFIED IDEOGRAPH-#217C0, IRGKangXi=0267.361, RSKangXi=38.9
217C1 CJK UNIFIED IDEOGRAPH-#217C1, IRGKangXi=0267.361, RSKangXi=38.9
217C2 CJK UNIFIED IDEOGRAPH-#217C2, IRGKangXi=0267.361, RSKangXi=38.9
217C3 CJK UNIFIED IDEOGRAPH-#217C3, IRGKangXi=0267.361, RSKangXi=38.9
217C4 CJK UNIFIED IDEOGRAPH-#217C4, IRGKangXi=0267.361, RSKangXi=38.9
217C5 CJK UNIFIED IDEOGRAPH-#217C5, IRGKangXi=0267.361, RSKangXi=38.9
217C6 CJK UNIFIED IDEOGRAPH-#217C6, IRGKangXi=0267.361, RSKangXi=38.9
217C7 CJK UNIFIED IDEOGRAPH-#217C7, IRGKangXi=0267.361, RSKangXi=38.9
217C8 CJK UNIFIED IDEOGRAPH-#217C8, IRGKangXi=0267.361, RSKangXi=38.9
217C9 CJK UNIFIED IDEOGRAPH-#217C9, IRGKangXi=0267.361, RSKangXi=38.9
217CA CJK UNIFIED IDEOGRAPH-#217CA, IRGKangXi=0267.361, RSKangXi=38.9
217CB CJK UNIFIED IDEOGRAPH-#217CB, IRGKangXi=0267.361, RSKangXi=38.9
217CC CJK UNIFIED IDEOGRAPH-#217CC, IRGKangXi=0267.361, RSKangXi=38.9
217CD CJK UNIFIED IDEOGRAPH-#217CD, IRGKangXi=0267.361, RSKangXi=38.9
217CE CJK UNIFIED IDEOGRAPH-#217CE, IRGKangXi=0267.361, RSKangXi=38.9
217CF CJK UNIFIED IDEOGRAPH-#217CF, IRGKangXi=0267.361, RSKangXi=38.9
217D0 CJK UNIFIED IDEOGRAPH-#217D0, IRGKangXi=0267.361, RSKangXi=38.9
217D1 CJK UNIFIED IDEOGRAPH-#217D1, IRGKangXi=0267.361, RSKangXi=38.9
217D2 CJK UNIFIED IDEOGRAPH-#217D2, IRGKangXi=0267.361, RSKangXi=38.9
217D3 CJK UNIFIED IDEOGRAPH-#217D3, IRGKangXi=0267.361, RSKangXi=38.9
217D4 CJK UNIFIED IDEOGRAPH-#217D4, IRGKangXi=0267.361, RSKangXi=38.9
217D5 CJK UNIFIED IDEOGRAPH-#217D5, IRGKangXi=0267.361, RSKangXi=38.9
217D6 CJK UNIFIED IDEOGRAPH-#217D6, IRGKangXi=0267.361, RSKangXi=38.9
217D7 CJK UNIFIED IDEOGRAPH-#217D7, IRGKangXi=0267.361, RSKangXi=38.9
217D8 CJK UNIFIED IDEOGRAPH-#217D8, IRGKangXi=0267.361, RSKangXi=38.9
217D9 CJK UNIFIED IDEOGRAPH-#217D9, IRGKangXi=0267.361, RSKangXi=38.9
217DA CJK UNIFIED IDEOGRAPH-#217DA, IRGKangXi=0267.361, RSKangXi=38.9
217DB CJK UNIFIED IDEOGRAPH-#217DB, IRGKangXi=0267.361, RSKangXi=38.9
217DC CJK UNIFIED IDEOGRAPH-#217DC, IRGKangXi=0267.361, RSKangXi=38.9
217DD CJK UNIFIED IDEOGRAPH-#217DD, IRGKangXi=0267.361, RSKangXi=38.9
217DE CJK UNIFIED IDEOGRAPH-#217DE, IRGKangXi=0267.361, RSKangXi=38.9
217DF CJK UNIFIED IDEOGRAPH-#217DF, IRGKangXi=0267.361, RSKangXi=38.9
217E0 CJK UNIFIED IDEOGRAPH-#217E0, IRGKangXi=0267.361, RSKangXi=38.9
217E1 CJK UNIFIED IDEOGRAPH-#217E1, IRGKangXi=0267.361, RSKangXi=38.9
217E2 CJK UNIFIED IDEOGRAPH-#217E2, IRGKangXi=0267.361, RSKangXi=38.9
217E3 CJK UNIFIED IDEOGRAPH-#217E3, IRGKangXi=0267.361, RSKangXi=38.9
217E4 CJK UNIFIED IDEOGRAPH-#217E4, IRGKangXi=0267.361, RSKangXi=38.9
217E5 CJK UNIFIED IDEOGRAPH-#217E5, IRGKangXi=0267.361, RSKangXi=38.9
217E6 CJK UNIFIED IDEOGRAPH-#217E6, IRGKangXi=0267.361, RSKangXi=38.9
217E7 CJK UNIFIED IDEOGRAPH-#217E7, IRGKangXi=0267.361, RSKangXi=38.9
217E8 CJK UNIFIED IDEOGRAPH-#217E8, IRGKangXi=0268.090, RSKangXi=38.10
217E9 CJK UNIFIED IDEOGRAPH-#217E9, IRGKangXi=0268.160, RSKangXi=38.10
217EA CJK UNIFIED IDEOGRAPH-#217EA, IRGKangXi=0268.170, RSKangXi=38.10
217EB CJK UNIFIED IDEOGRAPH-#217EB, IRGKangXi=0268.180, RSKangXi=38.10
217EC CJK UNIFIED IDEOGRAPH-#217EC, IRGKangXi=0268.200, RSKangXi=38.10
217ED CJK UNIFIED IDEOGRAPH-#217ED, IRGKangXi=0268.220, RSKangXi=38.10
217EE CJK UNIFIED IDEOGRAPH-#217EE, IRGKangXi=0268.230, RSKangXi=38.10
217EF CJK UNIFIED IDEOGRAPH-#217EF, IRGKangXi=0268.260, RSKangXi=38.10
217F0 CJK UNIFIED IDEOGRAPH-#217F0, IRGKangXi=0268.270, RSKangXi=38.10
217F1 CJK UNIFIED IDEOGRAPH-#217F1, IRGKangXi=0268.290, RSKangXi=38.10
217F2 CJK UNIFIED IDEOGRAPH-#217F2, IRGKangXi=0268.360, RSKangXi=38.10
217F3 CJK UNIFIED IDEOGRAPH-#217F3, IRGKangXi=0269.060, RSKangXi=38.10
217F4 CJK UNIFIED IDEOGRAPH-#217F4, IRGKangXi=0269.140, RSKangXi=38.10
217F5 CJK UNIFIED IDEOGRAPH-#217F5, IRGKangXi=0269.181, RSKangXi=38.10
217F6 CJK UNIFIED IDEOGRAPH-#217F6, IRGKangXi=0269.181, RSKangXi=38.10
217F7 CJK UNIFIED IDEOGRAPH-#217F7, IRGKangXi=0269.181, RSKangXi=38.10
217F8 CJK UNIFIED IDEOGRAPH-#217F8, IRGKangXi=0269.181, RSKangXi=38.10
217F9 CJK UNIFIED IDEOGRAPH-#217F9, IRGKangXi=0269.181, RSKangXi=38.10
217FA CJK UNIFIED IDEOGRAPH-#217FA, IRGKangXi=0269.181, RSKangXi=38.10
217FB CJK UNIFIED IDEOGRAPH-#217FB, IRGKangXi=0269.181, RSKangXi=38.10
217FC CJK UNIFIED IDEOGRAPH-#217FC, IRGKangXi=0269.181, RSKangXi=38.10
217FD CJK UNIFIED IDEOGRAPH-#217FD, IRGKangXi=0269.181, RSKangXi=38.10
217FE CJK UNIFIED IDEOGRAPH-#217FE, IRGKangXi=0269.181, RSKangXi=38.10
217FF CJK UNIFIED IDEOGRAPH-#217FF, IRGKangXi=0269.181, RSKangXi=38.10
21800 CJK UNIFIED IDEOGRAPH-#21800, IRGKangXi=0269.181, RSKangXi=38.10
21801 CJK UNIFIED IDEOGRAPH-#21801, IRGKangXi=0269.181, RSKangXi=38.10
21802 CJK UNIFIED IDEOGRAPH-#21802, IRGKangXi=0269.181, RSKangXi=38.10
21803 CJK UNIFIED IDEOGRAPH-#21803, IRGKangXi=0269.181, RSKangXi=38.10
21804 CJK UNIFIED IDEOGRAPH-#21804, IRGKangXi=0269.181, RSKangXi=38.10
21805 CJK UNIFIED IDEOGRAPH-#21805, IRGKangXi=0269.181, RSKangXi=38.10
21806 CJK UNIFIED IDEOGRAPH-#21806, IRGKangXi=0269.181, RSKangXi=38.10
21807 CJK UNIFIED IDEOGRAPH-#21807, IRGKangXi=0269.181, RSKangXi=38.10
21808 CJK UNIFIED IDEOGRAPH-#21808, IRGKangXi=0269.181, RSKangXi=38.10
21809 CJK UNIFIED IDEOGRAPH-#21809, IRGKangXi=0269.181, RSKangXi=38.10
2180A CJK UNIFIED IDEOGRAPH-#2180A, IRGKangXi=0269.181, RSKangXi=38.10
2180B CJK UNIFIED IDEOGRAPH-#2180B, IRGKangXi=0269.181, RSKangXi=38.10
2180C CJK UNIFIED IDEOGRAPH-#2180C, IRGKangXi=0269.181, RSKangXi=38.10
2180D CJK UNIFIED IDEOGRAPH-#2180D, IRGKangXi=0269.181, RSKangXi=38.10
2180E CJK UNIFIED IDEOGRAPH-#2180E, IRGKangXi=0269.181, RSKangXi=38.10
2180F CJK UNIFIED IDEOGRAPH-#2180F, IRGKangXi=0269.181, RSKangXi=38.10
21810 CJK UNIFIED IDEOGRAPH-#21810, IRGKangXi=0269.181, RSKangXi=38.10
21811 CJK UNIFIED IDEOGRAPH-#21811, IRGKangXi=0269.181, RSKangXi=38.10
21812 CJK UNIFIED IDEOGRAPH-#21812, IRGKangXi=0269.181, RSKangXi=38.10
21813 CJK UNIFIED IDEOGRAPH-#21813, IRGKangXi=0269.181, RSKangXi=38.10
21814 CJK UNIFIED IDEOGRAPH-#21814, IRGKangXi=0269.181, RSKangXi=38.10
21815 CJK UNIFIED IDEOGRAPH-#21815, IRGKangXi=0269.181, RSKangXi=38.10
21816 CJK UNIFIED IDEOGRAPH-#21816, IRGKangXi=0269.190, RSKangXi=38.12
21817 CJK UNIFIED IDEOGRAPH-#21817, IRGKangXi=0269.220, RSKangXi=38.11
21818 CJK UNIFIED IDEOGRAPH-#21818, IRGKangXi=0269.270, RSKangXi=38.12
21819 CJK UNIFIED IDEOGRAPH-#21819, IRGKangXi=0269.280, RSKangXi=38.11
2181A CJK UNIFIED IDEOGRAPH-#2181A, IRGKangXi=0270.060, RSKangXi=38.11
2181B CJK UNIFIED IDEOGRAPH-#2181B, IRGKangXi=0270.150, RSKangXi=38.11
2181C CJK UNIFIED IDEOGRAPH-#2181C, IRGKangXi=0270.170, RSKangXi=38.11
2181D CJK UNIFIED IDEOGRAPH-#2181D, IRGKangXi=0270.200, RSKangXi=38.11
2181E CJK UNIFIED IDEOGRAPH-#2181E, IRGKangXi=0270.210, RSKangXi=38.11
2181F CJK UNIFIED IDEOGRAPH-#2181F, IRGKangXi=0270.270, RSKangXi=38.11
21820 CJK UNIFIED IDEOGRAPH-#21820, IRGKangXi=0270.280, RSKangXi=38.11
21821 CJK UNIFIED IDEOGRAPH-#21821, IRGKangXi=0270.300, RSKangXi=38.11
21822 CJK UNIFIED IDEOGRAPH-#21822, IRGKangXi=0270.310, RSKangXi=38.11
21823 CJK UNIFIED IDEOGRAPH-#21823, IRGKangXi=0270.311, RSKangXi=38.9
21824 CJK UNIFIED IDEOGRAPH-#21824, IRGKangXi=0270.311, RSKangXi=38.11
21825 CJK UNIFIED IDEOGRAPH-#21825, IRGKangXi=0270.311, RSKangXi=38.11
21826 CJK UNIFIED IDEOGRAPH-#21826, IRGKangXi=0270.311, RSKangXi=38.11
21827 CJK UNIFIED IDEOGRAPH-#21827, IRGKangXi=0270.311, RSKangXi=38.11
21828 CJK UNIFIED IDEOGRAPH-#21828, IRGKangXi=0270.311, RSKangXi=38.11
21829 CJK UNIFIED IDEOGRAPH-#21829, IRGKangXi=0270.311, RSKangXi=38.11
2182A CJK UNIFIED IDEOGRAPH-#2182A, IRGKangXi=0270.311, RSKangXi=38.11
2182B CJK UNIFIED IDEOGRAPH-#2182B, IRGKangXi=0270.311, RSKangXi=38.11
2182C CJK UNIFIED IDEOGRAPH-#2182C, IRGKangXi=0270.311, RSKangXi=38.11
2182D CJK UNIFIED IDEOGRAPH-#2182D, IRGKangXi=0270.311, RSKangXi=38.11
2182E CJK UNIFIED IDEOGRAPH-#2182E, IRGKangXi=0270.311, RSKangXi=38.11
2182F CJK UNIFIED IDEOGRAPH-#2182F, IRGKangXi=0270.311, RSKangXi=38.11
21830 CJK UNIFIED IDEOGRAPH-#21830, IRGKangXi=0270.311, RSKangXi=38.11
21831 CJK UNIFIED IDEOGRAPH-#21831, IRGKangXi=0270.311, RSKangXi=38.11
21832 CJK UNIFIED IDEOGRAPH-#21832, IRGKangXi=0270.311, RSKangXi=38.11
21833 CJK UNIFIED IDEOGRAPH-#21833, IRGKangXi=0270.311, RSKangXi=38.11
21834 CJK UNIFIED IDEOGRAPH-#21834, IRGKangXi=0270.311, RSKangXi=38.11
21835 CJK UNIFIED IDEOGRAPH-#21835, IRGKangXi=0270.311, RSKangXi=38.11
21836 CJK UNIFIED IDEOGRAPH-#21836, IRGKangXi=0270.311, RSKangXi=38.11
21837 CJK UNIFIED IDEOGRAPH-#21837, IRGKangXi=0270.311, RSKangXi=38.11
21838 CJK UNIFIED IDEOGRAPH-#21838, IRGKangXi=0270.311, RSKangXi=38.11
21839 CJK UNIFIED IDEOGRAPH-#21839, IRGKangXi=0270.311, RSKangXi=38.11, Def{cunning; wicked, spoiled; coddled}
2183A CJK UNIFIED IDEOGRAPH-#2183A, IRGKangXi=0270.311, RSKangXi=38.11
2183B CJK UNIFIED IDEOGRAPH-#2183B, IRGKangXi=0270.311, RSKangXi=38.11
2183C CJK UNIFIED IDEOGRAPH-#2183C, IRGKangXi=0270.311, RSKangXi=38.11
2183D CJK UNIFIED IDEOGRAPH-#2183D, IRGKangXi=0270.311, RSKangXi=38.11
2183E CJK UNIFIED IDEOGRAPH-#2183E, IRGKangXi=0270.311, RSKangXi=38.11
2183F CJK UNIFIED IDEOGRAPH-#2183F, IRGKangXi=0270.311, RSKangXi=38.11
21840 CJK UNIFIED IDEOGRAPH-#21840, IRGKangXi=0270.311, RSKangXi=38.11
21841 CJK UNIFIED IDEOGRAPH-#21841, IRGKangXi=0270.311, RSKangXi=38.11
21842 CJK UNIFIED IDEOGRAPH-#21842, IRGKangXi=0270.311, RSKangXi=38.11
21843 CJK UNIFIED IDEOGRAPH-#21843, IRGKangXi=0270.311, RSKangXi=38.11
21844 CJK UNIFIED IDEOGRAPH-#21844, IRGKangXi=0270.311, RSKangXi=38.11
21845 CJK UNIFIED IDEOGRAPH-#21845, IRGKangXi=0270.311, RSKangXi=38.11
21846 CJK UNIFIED IDEOGRAPH-#21846, IRGKangXi=0270.311, RSKangXi=38.11
21847 CJK UNIFIED IDEOGRAPH-#21847, IRGKangXi=0270.311, RSKangXi=38.11
21848 CJK UNIFIED IDEOGRAPH-#21848, IRGKangXi=0270.311, RSKangXi=38.11
21849 CJK UNIFIED IDEOGRAPH-#21849, IRGKangXi=0270.311, RSKangXi=38.11
2184A CJK UNIFIED IDEOGRAPH-#2184A, IRGKangXi=0270.311, RSKangXi=38.11
2184B CJK UNIFIED IDEOGRAPH-#2184B, IRGKangXi=0270.311, RSKangXi=38.11
2184C CJK UNIFIED IDEOGRAPH-#2184C, IRGKangXi=0270.311, RSKangXi=38.11
2184D CJK UNIFIED IDEOGRAPH-#2184D, IRGKangXi=0270.311, RSKangXi=38.11
2184E CJK UNIFIED IDEOGRAPH-#2184E, IRGKangXi=0270.311, RSKangXi=38.11
2184F CJK UNIFIED IDEOGRAPH-#2184F, IRGKangXi=0270.350, RSKangXi=38.12
21850 CJK UNIFIED IDEOGRAPH-#21850, IRGKangXi=0271.060, RSKangXi=38.12
21851 CJK UNIFIED IDEOGRAPH-#21851, IRGKangXi=0271.070, RSKangXi=38.12
21852 CJK UNIFIED IDEOGRAPH-#21852, IRGKangXi=0271.080, RSKangXi=38.12
21853 CJK UNIFIED IDEOGRAPH-#21853, IRGKangXi=0271.170, RSKangXi=38.12
21854 CJK UNIFIED IDEOGRAPH-#21854, IRGKangXi=0271.180, RSKangXi=38.12
21855 CJK UNIFIED IDEOGRAPH-#21855, IRGKangXi=0271.200, RSKangXi=38.12
21856 CJK UNIFIED IDEOGRAPH-#21856, IRGKangXi=0271.210, RSKangXi=38.12
21857 CJK UNIFIED IDEOGRAPH-#21857, IRGKangXi=0271.270, RSKangXi=38.12
21858 CJK UNIFIED IDEOGRAPH-#21858, IRGKangXi=0271.320, RSKangXi=38.12
21859 CJK UNIFIED IDEOGRAPH-#21859, IRGKangXi=0271.340, RSKangXi=38.12
2185A CJK UNIFIED IDEOGRAPH-#2185A, IRGKangXi=0271.350, RSKangXi=38.12
2185B CJK UNIFIED IDEOGRAPH-#2185B, IRGKangXi=0271.351, RSKangXi=38.12
2185C CJK UNIFIED IDEOGRAPH-#2185C, IRGKangXi=0271.351, RSKangXi=38.12
2185D CJK UNIFIED IDEOGRAPH-#2185D, IRGKangXi=0271.351, RSKangXi=38.12
2185E CJK UNIFIED IDEOGRAPH-#2185E, IRGKangXi=0271.351, RSKangXi=38.12
2185F CJK UNIFIED IDEOGRAPH-#2185F, IRGKangXi=0271.351, RSKangXi=38.12
21860 CJK UNIFIED IDEOGRAPH-#21860, IRGKangXi=0271.351, RSKangXi=38.12
21861 CJK UNIFIED IDEOGRAPH-#21861, IRGKangXi=0271.351, RSKangXi=38.12
21862 CJK UNIFIED IDEOGRAPH-#21862, IRGKangXi=0271.351, RSKangXi=38.12
21863 CJK UNIFIED IDEOGRAPH-#21863, IRGKangXi=0271.351, RSKangXi=38.12
21864 CJK UNIFIED IDEOGRAPH-#21864, IRGKangXi=0271.351, RSKangXi=38.12
21865 CJK UNIFIED IDEOGRAPH-#21865, IRGKangXi=0271.351, RSKangXi=38.12
21866 CJK UNIFIED IDEOGRAPH-#21866, IRGKangXi=0271.351, RSKangXi=38.12
21867 CJK UNIFIED IDEOGRAPH-#21867, IRGKangXi=0271.351, RSKangXi=38.12
21868 CJK UNIFIED IDEOGRAPH-#21868, IRGKangXi=0271.351, RSKangXi=38.12
21869 CJK UNIFIED IDEOGRAPH-#21869, IRGKangXi=0271.351, RSKangXi=38.12
2186A CJK UNIFIED IDEOGRAPH-#2186A, IRGKangXi=0271.351, RSKangXi=38.12
2186B CJK UNIFIED IDEOGRAPH-#2186B, IRGKangXi=0271.351, RSKangXi=38.12
2186C CJK UNIFIED IDEOGRAPH-#2186C, IRGKangXi=0271.351, RSKangXi=38.12
2186D CJK UNIFIED IDEOGRAPH-#2186D, IRGKangXi=0271.351, RSKangXi=38.12
2186E CJK UNIFIED IDEOGRAPH-#2186E, IRGKangXi=0271.351, RSKangXi=38.12
2186F CJK UNIFIED IDEOGRAPH-#2186F, IRGKangXi=0271.351, RSKangXi=38.12
21870 CJK UNIFIED IDEOGRAPH-#21870, IRGKangXi=0271.351, RSKangXi=38.12
21871 CJK UNIFIED IDEOGRAPH-#21871, IRGKangXi=0271.351, RSKangXi=38.12
21872 CJK UNIFIED IDEOGRAPH-#21872, IRGKangXi=0271.351, RSKangXi=38.12
21873 CJK UNIFIED IDEOGRAPH-#21873, IRGKangXi=0271.351, RSKangXi=38.12
21874 CJK UNIFIED IDEOGRAPH-#21874, IRGKangXi=0271.351, RSKangXi=38.12
21875 CJK UNIFIED IDEOGRAPH-#21875, IRGKangXi=0271.351, RSKangXi=38.12
21876 CJK UNIFIED IDEOGRAPH-#21876, IRGKangXi=0271.351, RSKangXi=38.12
21877 CJK UNIFIED IDEOGRAPH-#21877, IRGKangXi=0271.351, RSKangXi=38.12
21878 CJK UNIFIED IDEOGRAPH-#21878, IRGKangXi=0271.351, RSKangXi=38.12
21879 CJK UNIFIED IDEOGRAPH-#21879, IRGKangXi=0271.351, RSKangXi=38.12
2187A CJK UNIFIED IDEOGRAPH-#2187A, IRGKangXi=0271.351, RSKangXi=38.12
2187B CJK UNIFIED IDEOGRAPH-#2187B, IRGKangXi=0271.351, RSKangXi=38.12
2187C CJK UNIFIED IDEOGRAPH-#2187C, IRGKangXi=0271.351, RSKangXi=38.12
2187D CJK UNIFIED IDEOGRAPH-#2187D, IRGKangXi=0271.351, RSKangXi=38.12
2187E CJK UNIFIED IDEOGRAPH-#2187E, IRGKangXi=0271.351, RSKangXi=38.12
2187F CJK UNIFIED IDEOGRAPH-#2187F, IRGKangXi=0271.351, RSKangXi=38.12
21880 CJK UNIFIED IDEOGRAPH-#21880, IRGKangXi=0271.351, RSKangXi=38.12
21881 CJK UNIFIED IDEOGRAPH-#21881, IRGKangXi=0271.351, RSKangXi=38.12
21882 CJK UNIFIED IDEOGRAPH-#21882, IRGKangXi=0271.351, RSKangXi=38.12
21883 CJK UNIFIED IDEOGRAPH-#21883, IRGKangXi=0271.351, RSKangXi=38.12
21884 CJK UNIFIED IDEOGRAPH-#21884, IRGKangXi=0271.351, RSKangXi=38.12
21885 CJK UNIFIED IDEOGRAPH-#21885, IRGKangXi=0271.351, RSKangXi=38.12
21886 CJK UNIFIED IDEOGRAPH-#21886, IRGKangXi=0271.351, RSKangXi=38.12
21887 CJK UNIFIED IDEOGRAPH-#21887, IRGKangXi=0271.351, RSKangXi=38.12
21888 CJK UNIFIED IDEOGRAPH-#21888, IRGKangXi=0271.351, RSKangXi=38.12
21889 CJK UNIFIED IDEOGRAPH-#21889, IRGKangXi=0271.351, RSKangXi=38.12
2188A CJK UNIFIED IDEOGRAPH-#2188A, IRGKangXi=0271.351, RSKangXi=38.12
2188B CJK UNIFIED IDEOGRAPH-#2188B, IRGKangXi=0271.351, RSKangXi=38.12
2188C CJK UNIFIED IDEOGRAPH-#2188C, IRGKangXi=0271.351, RSKangXi=38.12
2188D CJK UNIFIED IDEOGRAPH-#2188D, IRGKangXi=0271.351, RSKangXi=38.12
2188E CJK UNIFIED IDEOGRAPH-#2188E, IRGKangXi=0271.351, RSKangXi=38.13
2188F CJK UNIFIED IDEOGRAPH-#2188F, IRGKangXi=0271.351, RSKangXi=119.9
21890 CJK UNIFIED IDEOGRAPH-#21890, IRGKangXi=0271.351, RSKangXi=38.12
21891 CJK UNIFIED IDEOGRAPH-#21891, IRGKangXi=0271.360, RSKangXi=38.13
21892 CJK UNIFIED IDEOGRAPH-#21892, IRGKangXi=0272.100, RSKangXi=38.13
21893 CJK UNIFIED IDEOGRAPH-#21893, IRGKangXi=0272.110, RSKangXi=38.13
21894 CJK UNIFIED IDEOGRAPH-#21894, IRGKangXi=0272.120, RSKangXi=38.13
21895 CJK UNIFIED IDEOGRAPH-#21895, IRGKangXi=0272.140, RSKangXi=38.13
21896 CJK UNIFIED IDEOGRAPH-#21896, IRGKangXi=0272.180, RSKangXi=38.13
21897 CJK UNIFIED IDEOGRAPH-#21897, IRGKangXi=0272.190, RSKangXi=38.13
21898 CJK UNIFIED IDEOGRAPH-#21898, IRGKangXi=0272.210, RSKangXi=38.13
21899 CJK UNIFIED IDEOGRAPH-#21899, IRGKangXi=0272.230, RSKangXi=38.13
2189A CJK UNIFIED IDEOGRAPH-#2189A, IRGKangXi=0272.240, RSKangXi=38.13
2189B CJK UNIFIED IDEOGRAPH-#2189B, IRGKangXi=0272.250, RSKangXi=38.13
2189C CJK UNIFIED IDEOGRAPH-#2189C, IRGKangXi=0272.251, RSKangXi=38.13
2189D CJK UNIFIED IDEOGRAPH-#2189D, IRGKangXi=0272.251, RSKangXi=38.13
2189E CJK UNIFIED IDEOGRAPH-#2189E, IRGKangXi=0272.251, RSKangXi=38.13
2189F CJK UNIFIED IDEOGRAPH-#2189F, IRGKangXi=0272.251, RSKangXi=38.13
218A0 CJK UNIFIED IDEOGRAPH-#218A0, IRGKangXi=0272.251, RSKangXi=38.13
218A1 CJK UNIFIED IDEOGRAPH-#218A1, IRGKangXi=0272.251, RSKangXi=38.13
218A2 CJK UNIFIED IDEOGRAPH-#218A2, IRGKangXi=0272.251, RSKangXi=38.13
218A3 CJK UNIFIED IDEOGRAPH-#218A3, IRGKangXi=0272.251, RSKangXi=38.13
218A4 CJK UNIFIED IDEOGRAPH-#218A4, IRGKangXi=0272.251, RSKangXi=38.13
218A5 CJK UNIFIED IDEOGRAPH-#218A5, IRGKangXi=0272.251, RSKangXi=38.13
218A6 CJK UNIFIED IDEOGRAPH-#218A6, IRGKangXi=0272.251, RSKangXi=38.13
218A7 CJK UNIFIED IDEOGRAPH-#218A7, IRGKangXi=0272.251, RSKangXi=38.13
218A8 CJK UNIFIED IDEOGRAPH-#218A8, IRGKangXi=0272.251, RSKangXi=38.13
218A9 CJK UNIFIED IDEOGRAPH-#218A9, IRGKangXi=0272.251, RSKangXi=38.13
218AA CJK UNIFIED IDEOGRAPH-#218AA, IRGKangXi=0272.251, RSKangXi=38.13
218AB CJK UNIFIED IDEOGRAPH-#218AB, IRGKangXi=0272.251, RSKangXi=38.13
218AC CJK UNIFIED IDEOGRAPH-#218AC, IRGKangXi=0272.251, RSKangXi=38.13
218AD CJK UNIFIED IDEOGRAPH-#218AD, IRGKangXi=0272.251, RSKangXi=38.13
218AE CJK UNIFIED IDEOGRAPH-#218AE, IRGKangXi=0272.251, RSKangXi=38.13
218AF CJK UNIFIED IDEOGRAPH-#218AF, IRGKangXi=0272.251, RSKangXi=38.13
218B0 CJK UNIFIED IDEOGRAPH-#218B0, IRGKangXi=0272.251, RSKangXi=38.13
218B1 CJK UNIFIED IDEOGRAPH-#218B1, IRGKangXi=0272.251, RSKangXi=38.13
218B2 CJK UNIFIED IDEOGRAPH-#218B2, IRGKangXi=0272.251, RSKangXi=38.13
218B3 CJK UNIFIED IDEOGRAPH-#218B3, IRGKangXi=0272.251, RSKangXi=38.13
218B4 CJK UNIFIED IDEOGRAPH-#218B4, IRGKangXi=0272.251, RSKangXi=38.13
218B5 CJK UNIFIED IDEOGRAPH-#218B5, IRGKangXi=0272.251, RSKangXi=38.13
218B6 CJK UNIFIED IDEOGRAPH-#218B6, IRGKangXi=0272.251, RSKangXi=38.13
218B7 CJK UNIFIED IDEOGRAPH-#218B7, IRGKangXi=0272.251, RSKangXi=38.13
218B8 CJK UNIFIED IDEOGRAPH-#218B8, IRGKangXi=0272.251, RSKangXi=38.13
218B9 CJK UNIFIED IDEOGRAPH-#218B9, IRGKangXi=0272.251, RSKangXi=38.13
218BA CJK UNIFIED IDEOGRAPH-#218BA, IRGKangXi=0272.251, RSKangXi=38.13
218BB CJK UNIFIED IDEOGRAPH-#218BB, IRGKangXi=0272.251, RSKangXi=38.13
218BC CJK UNIFIED IDEOGRAPH-#218BC, IRGKangXi=0272.251, RSKangXi=38.13
218BD CJK UNIFIED IDEOGRAPH-#218BD, IRGKangXi=0272.251, RSKangXi=38.13
218BE CJK UNIFIED IDEOGRAPH-#218BE, IRGKangXi=0272.251, RSKangXi=38.13
218BF CJK UNIFIED IDEOGRAPH-#218BF, IRGKangXi=0272.251, RSKangXi=38.13
218C0 CJK UNIFIED IDEOGRAPH-#218C0, IRGKangXi=0272.251, RSKangXi=38.13
218C1 CJK UNIFIED IDEOGRAPH-#218C1, IRGKangXi=0272.251, RSKangXi=38.13
218C2 CJK UNIFIED IDEOGRAPH-#218C2, IRGKangXi=0272.251, RSKangXi=38.13
218C3 CJK UNIFIED IDEOGRAPH-#218C3, IRGKangXi=0272.251, RSKangXi=38.13
218C4 CJK UNIFIED IDEOGRAPH-#218C4, IRGKangXi=0272.251, RSKangXi=38.13
218C5 CJK UNIFIED IDEOGRAPH-#218C5, IRGKangXi=0272.280, RSKangXi=38.14
218C6 CJK UNIFIED IDEOGRAPH-#218C6, IRGKangXi=0272.290, RSKangXi=38.14
218C7 CJK UNIFIED IDEOGRAPH-#218C7, IRGKangXi=0272.300, RSKangXi=38.14
218C8 CJK UNIFIED IDEOGRAPH-#218C8, IRGKangXi=0272.360, RSKangXi=38.14
218C9 CJK UNIFIED IDEOGRAPH-#218C9, IRGKangXi=0272.460, RSKangXi=38.14
218CA CJK UNIFIED IDEOGRAPH-#218CA, IRGKangXi=0273.020, RSKangXi=38.14
218CB CJK UNIFIED IDEOGRAPH-#218CB, IRGKangXi=0273.050, RSKangXi=38.14
218CC CJK UNIFIED IDEOGRAPH-#218CC, IRGKangXi=0273.090, RSKangXi=38.14
218CD CJK UNIFIED IDEOGRAPH-#218CD, IRGKangXi=0273.100, RSKangXi=38.14
218CE CJK UNIFIED IDEOGRAPH-#218CE, IRGKangXi=0273.110, RSKangXi=38.14
218CF CJK UNIFIED IDEOGRAPH-#218CF, IRGKangXi=0273.120, RSKangXi=38.14
218D0 CJK UNIFIED IDEOGRAPH-#218D0, IRGKangXi=0273.140, RSKangXi=38.14
218D1 CJK UNIFIED IDEOGRAPH-#218D1, IRGKangXi=0273.160, RSKangXi=38.14
218D2 CJK UNIFIED IDEOGRAPH-#218D2, IRGKangXi=0273.170, RSKangXi=38.14
218D3 CJK UNIFIED IDEOGRAPH-#218D3, IRGKangXi=0273.171, RSKangXi=38.14
218D4 CJK UNIFIED IDEOGRAPH-#218D4, IRGKangXi=0273.171, RSKangXi=38.14
218D5 CJK UNIFIED IDEOGRAPH-#218D5, IRGKangXi=0273.171, RSKangXi=38.14, Def{a concubine, wife}
218D6 CJK UNIFIED IDEOGRAPH-#218D6, IRGKangXi=0273.171, RSKangXi=38.14
218D7 CJK UNIFIED IDEOGRAPH-#218D7, IRGKangXi=0273.171, RSKangXi=38.14
218D8 CJK UNIFIED IDEOGRAPH-#218D8, IRGKangXi=0273.171, RSKangXi=38.14
218D9 CJK UNIFIED IDEOGRAPH-#218D9, IRGKangXi=0273.171, RSKangXi=38.14
218DA CJK UNIFIED IDEOGRAPH-#218DA, IRGKangXi=0273.171, RSKangXi=38.14
218DB CJK UNIFIED IDEOGRAPH-#218DB, IRGKangXi=0273.171, RSKangXi=38.14
218DC CJK UNIFIED IDEOGRAPH-#218DC, IRGKangXi=0273.171, RSKangXi=38.14
218DD CJK UNIFIED IDEOGRAPH-#218DD, IRGKangXi=0273.171, RSKangXi=38.14
218DE CJK UNIFIED IDEOGRAPH-#218DE, IRGKangXi=0273.171, RSKangXi=38.14
218DF CJK UNIFIED IDEOGRAPH-#218DF, IRGKangXi=0273.171, RSKangXi=38.14
218E0 CJK UNIFIED IDEOGRAPH-#218E0, IRGKangXi=0273.171, RSKangXi=38.14
218E1 CJK UNIFIED IDEOGRAPH-#218E1, IRGKangXi=0273.171, RSKangXi=38.14
218E2 CJK UNIFIED IDEOGRAPH-#218E2, IRGKangXi=0273.171, RSKangXi=166.10
218E3 CJK UNIFIED IDEOGRAPH-#218E3, IRGKangXi=0273.171, RSKangXi=38.14
218E4 CJK UNIFIED IDEOGRAPH-#218E4, IRGKangXi=0273.171, RSKangXi=38.14
218E5 CJK UNIFIED IDEOGRAPH-#218E5, IRGKangXi=0273.171, RSKangXi=38.14
218E6 CJK UNIFIED IDEOGRAPH-#218E6, IRGKangXi=0273.171, RSKangXi=38.14
218E7 CJK UNIFIED IDEOGRAPH-#218E7, IRGKangXi=0273.171, RSKangXi=38.14
218E8 CJK UNIFIED IDEOGRAPH-#218E8, IRGKangXi=0273.171, RSKangXi=38.14
218E9 CJK UNIFIED IDEOGRAPH-#218E9, IRGKangXi=0273.171, RSKangXi=38.14
218EA CJK UNIFIED IDEOGRAPH-#218EA, IRGKangXi=0273.180, RSKangXi=38.15
218EB CJK UNIFIED IDEOGRAPH-#218EB, IRGKangXi=0273.230, RSKangXi=38.15
218EC CJK UNIFIED IDEOGRAPH-#218EC, IRGKangXi=0273.240, RSKangXi=38.15
218ED CJK UNIFIED IDEOGRAPH-#218ED, IRGKangXi=0273.250, RSKangXi=38.15
218EE CJK UNIFIED IDEOGRAPH-#218EE, IRGKangXi=0273.260, RSKangXi=38.15
218EF CJK UNIFIED IDEOGRAPH-#218EF, IRGKangXi=0273.270, RSKangXi=38.15
218F0 CJK UNIFIED IDEOGRAPH-#218F0, IRGKangXi=0273.310, RSKangXi=38.15
218F1 CJK UNIFIED IDEOGRAPH-#218F1, IRGKangXi=0273.320, RSKangXi=38.15
218F2 CJK UNIFIED IDEOGRAPH-#218F2, IRGKangXi=0273.321, RSKangXi=38.15
218F3 CJK UNIFIED IDEOGRAPH-#218F3, IRGKangXi=0273.321, RSKangXi=38.15
218F4 CJK UNIFIED IDEOGRAPH-#218F4, IRGKangXi=0273.321, RSKangXi=38.15
218F5 CJK UNIFIED IDEOGRAPH-#218F5, IRGKangXi=0273.321, RSKangXi=38.15
218F6 CJK UNIFIED IDEOGRAPH-#218F6, IRGKangXi=0273.321, RSKangXi=38.15
218F7 CJK UNIFIED IDEOGRAPH-#218F7, IRGKangXi=0273.321, RSKangXi=38.15
218F8 CJK UNIFIED IDEOGRAPH-#218F8, IRGKangXi=0273.321, RSKangXi=38.15
218F9 CJK UNIFIED IDEOGRAPH-#218F9, IRGKangXi=0273.321, RSKangXi=38.15
218FA CJK UNIFIED IDEOGRAPH-#218FA, IRGKangXi=0273.321, RSKangXi=38.15
218FB CJK UNIFIED IDEOGRAPH-#218FB, IRGKangXi=0273.321, RSKangXi=38.15
218FC CJK UNIFIED IDEOGRAPH-#218FC, IRGKangXi=0273.321, RSKangXi=38.15
218FD CJK UNIFIED IDEOGRAPH-#218FD, IRGKangXi=0273.340, RSKangXi=38.16
218FE CJK UNIFIED IDEOGRAPH-#218FE, IRGKangXi=0273.370, RSKangXi=38.16
218FF CJK UNIFIED IDEOGRAPH-#218FF, IRGKangXi=0273.400, RSKangXi=38.16
21900 CJK UNIFIED IDEOGRAPH-#21900, IRGKangXi=0273.410, RSKangXi=38.16
21901 CJK UNIFIED IDEOGRAPH-#21901, IRGKangXi=0273.420, RSKangXi=38.16
21902 CJK UNIFIED IDEOGRAPH-#21902, IRGKangXi=0273.421, RSKangXi=38.16
21903 CJK UNIFIED IDEOGRAPH-#21903, IRGKangXi=0273.421, RSKangXi=38.16
21904 CJK UNIFIED IDEOGRAPH-#21904, IRGKangXi=0273.421, RSKangXi=38.16
21905 CJK UNIFIED IDEOGRAPH-#21905, IRGKangXi=0273.421, RSKangXi=38.16
21906 CJK UNIFIED IDEOGRAPH-#21906, IRGKangXi=0273.421, RSKangXi=38.16
21907 CJK UNIFIED IDEOGRAPH-#21907, IRGKangXi=0273.421, RSKangXi=38.16
21908 CJK UNIFIED IDEOGRAPH-#21908, IRGKangXi=0273.421, RSKangXi=38.16
21909 CJK UNIFIED IDEOGRAPH-#21909, IRGKangXi=0273.421, RSKangXi=38.16
2190A CJK UNIFIED IDEOGRAPH-#2190A, IRGKangXi=0273.421, RSKangXi=38.16
2190B CJK UNIFIED IDEOGRAPH-#2190B, IRGKangXi=0273.421, RSKangXi=38.16
2190C CJK UNIFIED IDEOGRAPH-#2190C, IRGKangXi=0273.421, RSKangXi=38.16
2190D CJK UNIFIED IDEOGRAPH-#2190D, IRGKangXi=0273.421, RSKangXi=38.16
2190E CJK UNIFIED IDEOGRAPH-#2190E, IRGKangXi=0274.010, RSKangXi=38.17
2190F CJK UNIFIED IDEOGRAPH-#2190F, IRGKangXi=0274.040, RSKangXi=38.17
21910 CJK UNIFIED IDEOGRAPH-#21910, IRGKangXi=0274.091, RSKangXi=38.17
21911 CJK UNIFIED IDEOGRAPH-#21911, IRGKangXi=0274.091, RSKangXi=38.17
21912 CJK UNIFIED IDEOGRAPH-#21912, IRGKangXi=0274.091, RSKangXi=38.17
21913 CJK UNIFIED IDEOGRAPH-#21913, IRGKangXi=0274.091, RSKangXi=38.17
21914 CJK UNIFIED IDEOGRAPH-#21914, IRGKangXi=0274.091, RSKangXi=38.17
21915 CJK UNIFIED IDEOGRAPH-#21915, IRGKangXi=0274.091, RSKangXi=38.17
21916 CJK UNIFIED IDEOGRAPH-#21916, IRGKangXi=0274.091, RSKangXi=38.17
21917 CJK UNIFIED IDEOGRAPH-#21917, IRGKangXi=0274.091, RSKangXi=38.17
21918 CJK UNIFIED IDEOGRAPH-#21918, IRGKangXi=0274.100, RSKangXi=38.18
21919 CJK UNIFIED IDEOGRAPH-#21919, IRGKangXi=0274.130, RSKangXi=38.18
2191A CJK UNIFIED IDEOGRAPH-#2191A, IRGKangXi=0274.160, RSKangXi=38.18
2191B CJK UNIFIED IDEOGRAPH-#2191B, IRGKangXi=0274.170, RSKangXi=38.18
2191C CJK UNIFIED IDEOGRAPH-#2191C, IRGKangXi=0274.171, RSKangXi=38.18
2191D CJK UNIFIED IDEOGRAPH-#2191D, IRGKangXi=0274.171, RSKangXi=38.18
2191E CJK UNIFIED IDEOGRAPH-#2191E, IRGKangXi=0274.171, RSKangXi=38.16
2191F CJK UNIFIED IDEOGRAPH-#2191F, IRGKangXi=0274.171, RSKangXi=38.18
21920 CJK UNIFIED IDEOGRAPH-#21920, IRGKangXi=0274.171, RSKangXi=38.18
21921 CJK UNIFIED IDEOGRAPH-#21921, IRGKangXi=0274.180, RSKangXi=38.19
21922 CJK UNIFIED IDEOGRAPH-#21922, IRGKangXi=0274.200, RSKangXi=38.19
21923 CJK UNIFIED IDEOGRAPH-#21923, IRGKangXi=0274.250, RSKangXi=38.19
21924 CJK UNIFIED IDEOGRAPH-#21924, IRGKangXi=0274.260, RSKangXi=38.19
21925 CJK UNIFIED IDEOGRAPH-#21925, IRGKangXi=0274.261, RSKangXi=38.19
21926 CJK UNIFIED IDEOGRAPH-#21926, IRGKangXi=0274.261, RSKangXi=38.19
21927 CJK UNIFIED IDEOGRAPH-#21927, IRGKangXi=0274.261, RSKangXi=38.19
21928 CJK UNIFIED IDEOGRAPH-#21928, IRGKangXi=0274.261, RSKangXi=38.19
21929 CJK UNIFIED IDEOGRAPH-#21929, IRGKangXi=0274.261, RSKangXi=38.19
2192A CJK UNIFIED IDEOGRAPH-#2192A, IRGKangXi=0274.261, RSKangXi=38.19
2192B CJK UNIFIED IDEOGRAPH-#2192B, IRGKangXi=0274.280, RSKangXi=38.20
2192C CJK UNIFIED IDEOGRAPH-#2192C, IRGKangXi=0274.290, RSKangXi=38.20
2192D CJK UNIFIED IDEOGRAPH-#2192D, IRGKangXi=0274.291, RSKangXi=38.20
2192E CJK UNIFIED IDEOGRAPH-#2192E, IRGKangXi=0274.320, RSKangXi=38.21
2192F CJK UNIFIED IDEOGRAPH-#2192F, IRGKangXi=0274.330, RSKangXi=38.21
21930 CJK UNIFIED IDEOGRAPH-#21930, IRGKangXi=0274.331, RSKangXi=38.21
21931 CJK UNIFIED IDEOGRAPH-#21931, IRGKangXi=0274.331, RSKangXi=38.31
21932 CJK UNIFIED IDEOGRAPH-#21932, IRGKangXi=0274.331, RSKangXi=38.21
21933 CJK UNIFIED IDEOGRAPH-#21933, IRGKangXi=0274.331, RSKangXi=38.21
21934 CJK UNIFIED IDEOGRAPH-#21934, IRGKangXi=0274.331, RSKangXi=38.22
21935 CJK UNIFIED IDEOGRAPH-#21935, IRGKangXi=0274.331, RSKangXi=38.22
21936 CJK UNIFIED IDEOGRAPH-#21936, IRGKangXi=0274.331, RSKangXi=38.22
21937 CJK UNIFIED IDEOGRAPH-#21937, IRGKangXi=0274.351, RSKangXi=38.24
21938 CJK UNIFIED IDEOGRAPH-#21938, IRGKangXi=0274.351, RSKangXi=38.24
21939 CJK UNIFIED IDEOGRAPH-#21939, IRGKangXi=0274.351, RSKangXi=38.24
2193A CJK UNIFIED IDEOGRAPH-#2193A, IRGKangXi=0274.351, RSKangXi=38.24
2193B CJK UNIFIED IDEOGRAPH-#2193B, IRGKangXi=0274.351, RSKangXi=38.30
2193C CJK UNIFIED IDEOGRAPH-#2193C, IRGKangXi=0277.081, RSKangXi=39.0
2193D CJK UNIFIED IDEOGRAPH-#2193D, IRGKangXi=0277.091, RSKangXi=39.1
2193E CJK UNIFIED IDEOGRAPH-#2193E, IRGKangXi=0277.110, RSKangXi=39.2
2193F CJK UNIFIED IDEOGRAPH-#2193F, IRGKangXi=0277.120, RSKangXi=39.2
21940 CJK UNIFIED IDEOGRAPH-#21940, IRGKangXi=0277.130, RSKangXi=39.2
21941 CJK UNIFIED IDEOGRAPH-#21941, IRGKangXi=0277.151, RSKangXi=39.2
21942 CJK UNIFIED IDEOGRAPH-#21942, IRGKangXi=0277.151, RSKangXi=39.2
21943 CJK UNIFIED IDEOGRAPH-#21943, IRGKangXi=0278.040, RSKangXi=39.3
21944 CJK UNIFIED IDEOGRAPH-#21944, IRGKangXi=0278.041, RSKangXi=39.3
21945 CJK UNIFIED IDEOGRAPH-#21945, IRGKangXi=0278.041, RSKangXi=39.3
21946 CJK UNIFIED IDEOGRAPH-#21946, IRGKangXi=0278.050, RSKangXi=39.4
21947 CJK UNIFIED IDEOGRAPH-#21947, IRGKangXi=0278.090, RSKangXi=39.4
21948 CJK UNIFIED IDEOGRAPH-#21948, IRGKangXi=0278.120, RSKangXi=39.4
21949 CJK UNIFIED IDEOGRAPH-#21949, IRGKangXi=0278.140, RSKangXi=39.4
2194A CJK UNIFIED IDEOGRAPH-#2194A, IRGKangXi=0278.151, RSKangXi=39.4
2194B CJK UNIFIED IDEOGRAPH-#2194B, IRGKangXi=0278.151, RSKangXi=25.5
2194C CJK UNIFIED IDEOGRAPH-#2194C, IRGKangXi=0278.151, RSKangXi=39.4
2194D CJK UNIFIED IDEOGRAPH-#2194D, IRGKangXi=0278.151, RSKangXi=39.4
2194E CJK UNIFIED IDEOGRAPH-#2194E, IRGKangXi=0279.010, RSKangXi=39.5
2194F CJK UNIFIED IDEOGRAPH-#2194F, IRGKangXi=0279.100, RSKangXi=39.5
21950 CJK UNIFIED IDEOGRAPH-#21950, IRGKangXi=0279.110, RSKangXi=39.5
21951 CJK UNIFIED IDEOGRAPH-#21951, IRGKangXi=0279.120, RSKangXi=39.5
21952 CJK UNIFIED IDEOGRAPH-#21952, IRGKangXi=0279.121, RSKangXi=39.5
21953 CJK UNIFIED IDEOGRAPH-#21953, IRGKangXi=0279.121, RSKangXi=39.5
21954 CJK UNIFIED IDEOGRAPH-#21954, IRGKangXi=0279.121, RSKangXi=39.5
21955 CJK UNIFIED IDEOGRAPH-#21955, IRGKangXi=0279.121, RSKangXi=39.5
21956 CJK UNIFIED IDEOGRAPH-#21956, IRGKangXi=0279.121, RSKangXi=39.5
21957 CJK UNIFIED IDEOGRAPH-#21957, IRGKangXi=0279.121, RSKangXi=39.5
21958 CJK UNIFIED IDEOGRAPH-#21958, IRGKangXi=0279.121, RSKangXi=39.5
21959 CJK UNIFIED IDEOGRAPH-#21959, IRGKangXi=0279.121, RSKangXi=39.5
2195A CJK UNIFIED IDEOGRAPH-#2195A, IRGKangXi=0279.121, RSKangXi=39.5
2195B CJK UNIFIED IDEOGRAPH-#2195B, IRGKangXi=0279.130, RSKangXi=39.6
2195C CJK UNIFIED IDEOGRAPH-#2195C, IRGKangXi=0279.160, RSKangXi=39.6
2195D CJK UNIFIED IDEOGRAPH-#2195D, IRGKangXi=0279.180, RSKangXi=39.6
2195E CJK UNIFIED IDEOGRAPH-#2195E, IRGKangXi=0279.190, RSKangXi=39.6
2195F CJK UNIFIED IDEOGRAPH-#2195F, IRGKangXi=0279.191, RSKangXi=39.6
21960 CJK UNIFIED IDEOGRAPH-#21960, IRGKangXi=0279.191, RSKangXi=39.6
21961 CJK UNIFIED IDEOGRAPH-#21961, IRGKangXi=0279.191, RSKangXi=39.6
21962 CJK UNIFIED IDEOGRAPH-#21962, IRGKangXi=0279.191, RSKangXi=39.6
21963 CJK UNIFIED IDEOGRAPH-#21963, IRGKangXi=0279.191, RSKangXi=39.6
21964 CJK UNIFIED IDEOGRAPH-#21964, IRGKangXi=0279.191, RSKangXi=39.6
21965 CJK UNIFIED IDEOGRAPH-#21965, IRGKangXi=0279.191, RSKangXi=39.6
21966 CJK UNIFIED IDEOGRAPH-#21966, IRGKangXi=0279.191, RSKangXi=39.6
21967 CJK UNIFIED IDEOGRAPH-#21967, IRGKangXi=0279.191, RSKangXi=39.6
21968 CJK UNIFIED IDEOGRAPH-#21968, IRGKangXi=0279.200, RSKangXi=39.7
21969 CJK UNIFIED IDEOGRAPH-#21969, IRGKangXi=0279.210, RSKangXi=39.7
2196A CJK UNIFIED IDEOGRAPH-#2196A, IRGKangXi=0280.020, RSKangXi=39.7
2196B CJK UNIFIED IDEOGRAPH-#2196B, IRGKangXi=0280.021, RSKangXi=39.7
2196C CJK UNIFIED IDEOGRAPH-#2196C, IRGKangXi=0280.021, RSKangXi=39.7
2196D CJK UNIFIED IDEOGRAPH-#2196D, IRGKangXi=0280.021, RSKangXi=39.7
2196E CJK UNIFIED IDEOGRAPH-#2196E, IRGKangXi=0280.051, RSKangXi=39.8
2196F CJK UNIFIED IDEOGRAPH-#2196F, IRGKangXi=0280.051, RSKangXi=39.8
21970 CJK UNIFIED IDEOGRAPH-#21970, IRGKangXi=0280.051, RSKangXi=39.8
21971 CJK UNIFIED IDEOGRAPH-#21971, IRGKangXi=0280.051, RSKangXi=39.8
21972 CJK UNIFIED IDEOGRAPH-#21972, IRGKangXi=0280.051, RSKangXi=39.8
21973 CJK UNIFIED IDEOGRAPH-#21973, IRGKangXi=0280.051, RSKangXi=39.8
21974 CJK UNIFIED IDEOGRAPH-#21974, IRGKangXi=0280.051, RSKangXi=39.8
21975 CJK UNIFIED IDEOGRAPH-#21975, IRGKangXi=0280.051, RSKangXi=39.8
21976 CJK UNIFIED IDEOGRAPH-#21976, IRGKangXi=0280.060, RSKangXi=39.9
21977 CJK UNIFIED IDEOGRAPH-#21977, IRGKangXi=0280.070, RSKangXi=39.9
21978 CJK UNIFIED IDEOGRAPH-#21978, IRGKangXi=0280.090, RSKangXi=39.9
21979 CJK UNIFIED IDEOGRAPH-#21979, IRGKangXi=0280.120, RSKangXi=39.9
2197A CJK UNIFIED IDEOGRAPH-#2197A, IRGKangXi=0280.130, RSKangXi=39.9
2197B CJK UNIFIED IDEOGRAPH-#2197B, IRGKangXi=0280.131, RSKangXi=39.9
2197C CJK UNIFIED IDEOGRAPH-#2197C, IRGKangXi=0280.131, RSKangXi=39.9, Def{(Cant.) to carry on the back}
2197D CJK UNIFIED IDEOGRAPH-#2197D, IRGKangXi=0280.131, RSKangXi=39.9
2197E CJK UNIFIED IDEOGRAPH-#2197E, IRGKangXi=0280.131, RSKangXi=39.9
2197F CJK UNIFIED IDEOGRAPH-#2197F, IRGKangXi=0280.131, RSKangXi=39.9
21980 CJK UNIFIED IDEOGRAPH-#21980, IRGKangXi=0280.131, RSKangXi=39.9
21981 CJK UNIFIED IDEOGRAPH-#21981, IRGKangXi=0280.131, RSKangXi=39.9
21982 CJK UNIFIED IDEOGRAPH-#21982, IRGKangXi=0280.131, RSKangXi=39.9
21983 CJK UNIFIED IDEOGRAPH-#21983, IRGKangXi=0280.140, RSKangXi=39.10
21984 CJK UNIFIED IDEOGRAPH-#21984, IRGKangXi=0280.150, RSKangXi=39.10
21985 CJK UNIFIED IDEOGRAPH-#21985, IRGKangXi=0280.160, RSKangXi=39.10
21986 CJK UNIFIED IDEOGRAPH-#21986, IRGKangXi=0280.211, RSKangXi=39.10
21987 CJK UNIFIED IDEOGRAPH-#21987, IRGKangXi=0280.211, RSKangXi=39.10
21988 CJK UNIFIED IDEOGRAPH-#21988, IRGKangXi=0280.211, RSKangXi=39.10
21989 CJK UNIFIED IDEOGRAPH-#21989, IRGKangXi=0280.211, RSKangXi=39.10
2198A CJK UNIFIED IDEOGRAPH-#2198A, IRGKangXi=0280.211, RSKangXi=39.10
2198B CJK UNIFIED IDEOGRAPH-#2198B, IRGKangXi=0280.211, RSKangXi=39.10
2198C CJK UNIFIED IDEOGRAPH-#2198C, IRGKangXi=0280.211, RSKangXi=39.10
2198D CJK UNIFIED IDEOGRAPH-#2198D, IRGKangXi=0280.211, RSKangXi=39.10
2198E CJK UNIFIED IDEOGRAPH-#2198E, IRGKangXi=0280.211, RSKangXi=39.10
2198F CJK UNIFIED IDEOGRAPH-#2198F, IRGKangXi=0280.211, RSKangXi=39.10
21990 CJK UNIFIED IDEOGRAPH-#21990, IRGKangXi=0280.211, RSKangXi=39.10
21991 CJK UNIFIED IDEOGRAPH-#21991, IRGKangXi=0280.230, RSKangXi=39.11
21992 CJK UNIFIED IDEOGRAPH-#21992, IRGKangXi=0280.231, RSKangXi=39.11
21993 CJK UNIFIED IDEOGRAPH-#21993, IRGKangXi=0280.231, RSKangXi=39.11
21994 CJK UNIFIED IDEOGRAPH-#21994, IRGKangXi=0280.231, RSKangXi=39.11
21995 CJK UNIFIED IDEOGRAPH-#21995, IRGKangXi=0280.231, RSKangXi=39.11
21996 CJK UNIFIED IDEOGRAPH-#21996, IRGKangXi=0280.231, RSKangXi=39.11
21997 CJK UNIFIED IDEOGRAPH-#21997, IRGKangXi=0280.240, RSKangXi=39.12
21998 CJK UNIFIED IDEOGRAPH-#21998, IRGKangXi=0280.250, RSKangXi=39.12
21999 CJK UNIFIED IDEOGRAPH-#21999, IRGKangXi=0280.260, RSKangXi=39.12
2199A CJK UNIFIED IDEOGRAPH-#2199A, IRGKangXi=0280.261, RSKangXi=39.12
2199B CJK UNIFIED IDEOGRAPH-#2199B, IRGKangXi=0280.261, RSKangXi=39.12
2199C CJK UNIFIED IDEOGRAPH-#2199C, IRGKangXi=0280.261, RSKangXi=39.12
2199D CJK UNIFIED IDEOGRAPH-#2199D, IRGKangXi=0280.261, RSKangXi=39.12
2199E CJK UNIFIED IDEOGRAPH-#2199E, IRGKangXi=0280.270, RSKangXi=39.13
2199F CJK UNIFIED IDEOGRAPH-#2199F, IRGKangXi=0280.290, RSKangXi=39.13
219A0 CJK UNIFIED IDEOGRAPH-#219A0, IRGKangXi=0280.300, RSKangXi=39.13
219A1 CJK UNIFIED IDEOGRAPH-#219A1, IRGKangXi=0280.310, RSKangXi=39.13
219A2 CJK UNIFIED IDEOGRAPH-#219A2, IRGKangXi=0281.010, RSKangXi=39.13
219A3 CJK UNIFIED IDEOGRAPH-#219A3, IRGKangXi=0281.011, RSKangXi=39.13
219A4 CJK UNIFIED IDEOGRAPH-#219A4, IRGKangXi=0281.011, RSKangXi=39.13
219A5 CJK UNIFIED IDEOGRAPH-#219A5, IRGKangXi=0281.011, RSKangXi=39.13
219A6 CJK UNIFIED IDEOGRAPH-#219A6, IRGKangXi=0281.011, RSKangXi=39.13
219A7 CJK UNIFIED IDEOGRAPH-#219A7, IRGKangXi=0281.011, RSKangXi=39.13
219A8 CJK UNIFIED IDEOGRAPH-#219A8, IRGKangXi=0281.011, RSKangXi=39.13
219A9 CJK UNIFIED IDEOGRAPH-#219A9, IRGKangXi=0281.040, RSKangXi=39.14
219AA CJK UNIFIED IDEOGRAPH-#219AA, IRGKangXi=0281.041, RSKangXi=39.15
219AB CJK UNIFIED IDEOGRAPH-#219AB, IRGKangXi=0281.041, RSKangXi=39.15
219AC CJK UNIFIED IDEOGRAPH-#219AC, IRGKangXi=0281.041, RSKangXi=39.15
219AD CJK UNIFIED IDEOGRAPH-#219AD, IRGKangXi=0281.051, RSKangXi=39.16
219AE CJK UNIFIED IDEOGRAPH-#219AE, IRGKangXi=0281.051, RSKangXi=39.16
219AF CJK UNIFIED IDEOGRAPH-#219AF, IRGKangXi=0281.051, RSKangXi=39.16
219B0 CJK UNIFIED IDEOGRAPH-#219B0, IRGKangXi=0281.051, RSKangXi=39.16
219B1 CJK UNIFIED IDEOGRAPH-#219B1, IRGKangXi=0281.080, RSKangXi=39.17
219B2 CJK UNIFIED IDEOGRAPH-#219B2, IRGKangXi=0281.081, RSKangXi=39.17
219B3 CJK UNIFIED IDEOGRAPH-#219B3, IRGKangXi=0281.081, RSKangXi=39.17
219B4 CJK UNIFIED IDEOGRAPH-#219B4, IRGKangXi=0281.081, RSKangXi=39.17
219B5 CJK UNIFIED IDEOGRAPH-#219B5, IRGKangXi=0281.081, RSKangXi=39.17
219B6 CJK UNIFIED IDEOGRAPH-#219B6, IRGKangXi=0281.081, RSKangXi=39.17
219B7 CJK UNIFIED IDEOGRAPH-#219B7, IRGKangXi=0281.091, RSKangXi=39.19
219B8 CJK UNIFIED IDEOGRAPH-#219B8, IRGKangXi=0281.101, RSKangXi=39.24
219B9 CJK UNIFIED IDEOGRAPH-#219B9, IRGKangXi=0281.111, RSKangXi=40.1
219BA CJK UNIFIED IDEOGRAPH-#219BA, IRGKangXi=0281.191, RSKangXi=40.2
219BB CJK UNIFIED IDEOGRAPH-#219BB, IRGKangXi=0281.191, RSKangXi=40.2
219BC CJK UNIFIED IDEOGRAPH-#219BC, IRGKangXi=0281.191, RSKangXi=40.2
219BD CJK UNIFIED IDEOGRAPH-#219BD, IRGKangXi=0282.040, RSKangXi=40.3
219BE CJK UNIFIED IDEOGRAPH-#219BE, IRGKangXi=0282.090, RSKangXi=40.3
219BF CJK UNIFIED IDEOGRAPH-#219BF, IRGKangXi=0282.100, RSKangXi=40.3
219C0 CJK UNIFIED IDEOGRAPH-#219C0, IRGKangXi=0282.101, RSKangXi=40.3
219C1 CJK UNIFIED IDEOGRAPH-#219C1, IRGKangXi=0282.101, RSKangXi=40.3
219C2 CJK UNIFIED IDEOGRAPH-#219C2, IRGKangXi=0282.101, RSKangXi=40.3
219C3 CJK UNIFIED IDEOGRAPH-#219C3, IRGKangXi=0282.101, RSKangXi=40.3
219C4 CJK UNIFIED IDEOGRAPH-#219C4, IRGKangXi=0282.101, RSKangXi=40.3
219C5 CJK UNIFIED IDEOGRAPH-#219C5, IRGKangXi=0282.101, RSKangXi=40.3
219C6 CJK UNIFIED IDEOGRAPH-#219C6, IRGKangXi=0282.101, RSKangXi=40.3
219C7 CJK UNIFIED IDEOGRAPH-#219C7, IRGKangXi=0282.101, RSKangXi=40.3
219C8 CJK UNIFIED IDEOGRAPH-#219C8, IRGKangXi=0282.101, RSKangXi=40.3
219C9 CJK UNIFIED IDEOGRAPH-#219C9, IRGKangXi=0282.101, RSKangXi=40.3
219CA CJK UNIFIED IDEOGRAPH-#219CA, IRGKangXi=0282.101, RSKangXi=40.3
219CB CJK UNIFIED IDEOGRAPH-#219CB, IRGKangXi=0282.140, RSKangXi=40.4
219CC CJK UNIFIED IDEOGRAPH-#219CC, IRGKangXi=0282.170, RSKangXi=40.4
219CD CJK UNIFIED IDEOGRAPH-#219CD, IRGKangXi=0283.010, RSKangXi=40.4
219CE CJK UNIFIED IDEOGRAPH-#219CE, IRGKangXi=0283.030, RSKangXi=40.4
219CF CJK UNIFIED IDEOGRAPH-#219CF, IRGKangXi=0283.040, RSKangXi=40.4
219D0 CJK UNIFIED IDEOGRAPH-#219D0, IRGKangXi=0283.051, RSKangXi=40.4
219D1 CJK UNIFIED IDEOGRAPH-#219D1, IRGKangXi=0283.051, RSKangXi=40.4
219D2 CJK UNIFIED IDEOGRAPH-#219D2, IRGKangXi=0283.051, RSKangXi=40.4
219D3 CJK UNIFIED IDEOGRAPH-#219D3, IRGKangXi=0283.051, RSKangXi=40.4
219D4 CJK UNIFIED IDEOGRAPH-#219D4, IRGKangXi=0283.051, RSKangXi=40.4
219D5 CJK UNIFIED IDEOGRAPH-#219D5, IRGKangXi=0283.051, RSKangXi=40.4
219D6 CJK UNIFIED IDEOGRAPH-#219D6, IRGKangXi=0283.070, RSKangXi=40.5
219D7 CJK UNIFIED IDEOGRAPH-#219D7, IRGKangXi=0283.080, RSKangXi=40.5
219D8 CJK UNIFIED IDEOGRAPH-#219D8, IRGKangXi=0283.090, RSKangXi=40.5
219D9 CJK UNIFIED IDEOGRAPH-#219D9, IRGKangXi=0283.130, RSKangXi=40.5
219DA CJK UNIFIED IDEOGRAPH-#219DA, IRGKangXi=0284.080, RSKangXi=40.5
219DB CJK UNIFIED IDEOGRAPH-#219DB, IRGKangXi=0284.081, RSKangXi=40.5
219DC CJK UNIFIED IDEOGRAPH-#219DC, IRGKangXi=0284.081, RSKangXi=40.5
219DD CJK UNIFIED IDEOGRAPH-#219DD, IRGKangXi=0284.081, RSKangXi=40.5
219DE CJK UNIFIED IDEOGRAPH-#219DE, IRGKangXi=0284.081, RSKangXi=40.5
219DF CJK UNIFIED IDEOGRAPH-#219DF, IRGKangXi=0284.081, RSKangXi=40.5
219E0 CJK UNIFIED IDEOGRAPH-#219E0, IRGKangXi=0284.081, RSKangXi=40.5
219E1 CJK UNIFIED IDEOGRAPH-#219E1, IRGKangXi=0284.081, RSKangXi=40.5
219E2 CJK UNIFIED IDEOGRAPH-#219E2, IRGKangXi=0284.081, RSKangXi=40.5
219E3 CJK UNIFIED IDEOGRAPH-#219E3, IRGKangXi=0284.081, RSKangXi=40.5
219E4 CJK UNIFIED IDEOGRAPH-#219E4, IRGKangXi=0284.081, RSKangXi=40.5
219E5 CJK UNIFIED IDEOGRAPH-#219E5, IRGKangXi=0284.081, RSKangXi=40.5
219E6 CJK UNIFIED IDEOGRAPH-#219E6, IRGKangXi=0284.081, RSKangXi=40.5
219E7 CJK UNIFIED IDEOGRAPH-#219E7, IRGKangXi=0284.081, RSKangXi=40.5
219E8 CJK UNIFIED IDEOGRAPH-#219E8, IRGKangXi=0284.081, RSKangXi=40.5
219E9 CJK UNIFIED IDEOGRAPH-#219E9, IRGKangXi=0284.090, RSKangXi=40.6
219EA CJK UNIFIED IDEOGRAPH-#219EA, IRGKangXi=0284.110, RSKangXi=40.6
219EB CJK UNIFIED IDEOGRAPH-#219EB, IRGKangXi=0284.130, RSKangXi=40.6
219EC CJK UNIFIED IDEOGRAPH-#219EC, IRGKangXi=0284.140, RSKangXi=40.6
219ED CJK UNIFIED IDEOGRAPH-#219ED, IRGKangXi=0284.150, RSKangXi=40.6
219EE CJK UNIFIED IDEOGRAPH-#219EE, IRGKangXi=0284.180, RSKangXi=40.6
219EF CJK UNIFIED IDEOGRAPH-#219EF, IRGKangXi=0285.010, RSKangXi=40.6
219F0 CJK UNIFIED IDEOGRAPH-#219F0, IRGKangXi=0285.070, RSKangXi=40.6
219F1 CJK UNIFIED IDEOGRAPH-#219F1, IRGKangXi=0285.090, RSKangXi=40.6
219F2 CJK UNIFIED IDEOGRAPH-#219F2, IRGKangXi=0285.101, RSKangXi=40.6
219F3 CJK UNIFIED IDEOGRAPH-#219F3, IRGKangXi=0285.101, RSKangXi=40.6
219F4 CJK UNIFIED IDEOGRAPH-#219F4, IRGKangXi=0285.101, RSKangXi=40.6
219F5 CJK UNIFIED IDEOGRAPH-#219F5, IRGKangXi=0285.101, RSKangXi=40.6
219F6 CJK UNIFIED IDEOGRAPH-#219F6, IRGKangXi=0285.101, RSKangXi=40.6
219F7 CJK UNIFIED IDEOGRAPH-#219F7, IRGKangXi=0285.101, RSKangXi=40.6
219F8 CJK UNIFIED IDEOGRAPH-#219F8, IRGKangXi=0285.101, RSKangXi=40.6
219F9 CJK UNIFIED IDEOGRAPH-#219F9, IRGKangXi=0285.101, RSKangXi=40.6
219FA CJK UNIFIED IDEOGRAPH-#219FA, IRGKangXi=0285.101, RSKangXi=40.6
219FB CJK UNIFIED IDEOGRAPH-#219FB, IRGKangXi=0285.101, RSKangXi=40.6
219FC CJK UNIFIED IDEOGRAPH-#219FC, IRGKangXi=0285.101, RSKangXi=40.6
219FD CJK UNIFIED IDEOGRAPH-#219FD, IRGKangXi=0285.101, RSKangXi=40.6
219FE CJK UNIFIED IDEOGRAPH-#219FE, IRGKangXi=0285.101, RSKangXi=40.6
219FF CJK UNIFIED IDEOGRAPH-#219FF, IRGKangXi=0285.101, RSKangXi=40.6
21A00 CJK UNIFIED IDEOGRAPH-#21A00, IRGKangXi=0285.120, RSKangXi=40.7
21A01 CJK UNIFIED IDEOGRAPH-#21A01, IRGKangXi=0285.140, RSKangXi=40.7
21A02 CJK UNIFIED IDEOGRAPH-#21A02, IRGKangXi=0286.010, RSKangXi=40.7
21A03 CJK UNIFIED IDEOGRAPH-#21A03, IRGKangXi=0286.080, RSKangXi=40.7
21A04 CJK UNIFIED IDEOGRAPH-#21A04, IRGKangXi=0286.100, RSKangXi=40.7, Def{to stop up}
21A05 CJK UNIFIED IDEOGRAPH-#21A05, IRGKangXi=0286.140, RSKangXi=40.7
21A06 CJK UNIFIED IDEOGRAPH-#21A06, IRGKangXi=0287.050, RSKangXi=40.7
21A07 CJK UNIFIED IDEOGRAPH-#21A07, IRGKangXi=0287.060, RSKangXi=40.7
21A08 CJK UNIFIED IDEOGRAPH-#21A08, IRGKangXi=0287.070, RSKangXi=40.7
21A09 CJK UNIFIED IDEOGRAPH-#21A09, IRGKangXi=0287.080, RSKangXi=40.7
21A0A CJK UNIFIED IDEOGRAPH-#21A0A, IRGKangXi=0287.100, RSKangXi=40.7
21A0B CJK UNIFIED IDEOGRAPH-#21A0B, IRGKangXi=0287.101, RSKangXi=40.7
21A0C CJK UNIFIED IDEOGRAPH-#21A0C, IRGKangXi=0287.101, RSKangXi=40.7
21A0D CJK UNIFIED IDEOGRAPH-#21A0D, IRGKangXi=0287.101, RSKangXi=40.7
21A0E CJK UNIFIED IDEOGRAPH-#21A0E, IRGKangXi=0287.101, RSKangXi=40.7
21A0F CJK UNIFIED IDEOGRAPH-#21A0F, IRGKangXi=0287.101, RSKangXi=40.7
21A10 CJK UNIFIED IDEOGRAPH-#21A10, IRGKangXi=0287.101, RSKangXi=40.7
21A11 CJK UNIFIED IDEOGRAPH-#21A11, IRGKangXi=0287.101, RSKangXi=40.7
21A12 CJK UNIFIED IDEOGRAPH-#21A12, IRGKangXi=0287.101, RSKangXi=40.7
21A13 CJK UNIFIED IDEOGRAPH-#21A13, IRGKangXi=0287.101, RSKangXi=40.7
21A14 CJK UNIFIED IDEOGRAPH-#21A14, IRGKangXi=0287.101, RSKangXi=40.7
21A15 CJK UNIFIED IDEOGRAPH-#21A15, IRGKangXi=0287.101, RSKangXi=40.7
21A16 CJK UNIFIED IDEOGRAPH-#21A16, IRGKangXi=0287.101, RSKangXi=40.7
21A17 CJK UNIFIED IDEOGRAPH-#21A17, IRGKangXi=0287.101, RSKangXi=40.7
21A18 CJK UNIFIED IDEOGRAPH-#21A18, IRGKangXi=0287.101, RSKangXi=40.7
21A19 CJK UNIFIED IDEOGRAPH-#21A19, IRGKangXi=0287.101, RSKangXi=40.7
21A1A CJK UNIFIED IDEOGRAPH-#21A1A, IRGKangXi=0287.101, RSKangXi=40.7
21A1B CJK UNIFIED IDEOGRAPH-#21A1B, IRGKangXi=0287.101, RSKangXi=40.7
21A1C CJK UNIFIED IDEOGRAPH-#21A1C, IRGKangXi=0287.101, RSKangXi=40.7
21A1D CJK UNIFIED IDEOGRAPH-#21A1D, IRGKangXi=0287.101, RSKangXi=40.7
21A1E CJK UNIFIED IDEOGRAPH-#21A1E, IRGKangXi=0287.101, RSKangXi=40.7
21A1F CJK UNIFIED IDEOGRAPH-#21A1F, IRGKangXi=0287.101, RSKangXi=40.7
21A20 CJK UNIFIED IDEOGRAPH-#21A20, IRGKangXi=0287.101, RSKangXi=40.7
21A21 CJK UNIFIED IDEOGRAPH-#21A21, IRGKangXi=0287.101, RSKangXi=40.7
21A22 CJK UNIFIED IDEOGRAPH-#21A22, IRGKangXi=0287.110, RSKangXi=40.8
21A23 CJK UNIFIED IDEOGRAPH-#21A23, IRGKangXi=0287.120, RSKangXi=40.8
21A24 CJK UNIFIED IDEOGRAPH-#21A24, IRGKangXi=0288.020, RSKangXi=40.8
21A25 CJK UNIFIED IDEOGRAPH-#21A25, IRGKangXi=0288.140, RSKangXi=40.8
21A26 CJK UNIFIED IDEOGRAPH-#21A26, IRGKangXi=0288.160, RSKangXi=40.8
21A27 CJK UNIFIED IDEOGRAPH-#21A27, IRGKangXi=0288.180, RSKangXi=40.8
21A28 CJK UNIFIED IDEOGRAPH-#21A28, IRGKangXi=0288.190, RSKangXi=40.8
21A29 CJK UNIFIED IDEOGRAPH-#21A29, IRGKangXi=0288.200, RSKangXi=40.8
21A2A CJK UNIFIED IDEOGRAPH-#21A2A, IRGKangXi=0288.201, RSKangXi=40.8
21A2B CJK UNIFIED IDEOGRAPH-#21A2B, IRGKangXi=0288.201, RSKangXi=40.8
21A2C CJK UNIFIED IDEOGRAPH-#21A2C, IRGKangXi=0288.201, RSKangXi=40.8
21A2D CJK UNIFIED IDEOGRAPH-#21A2D, IRGKangXi=0288.201, RSKangXi=40.8
21A2E CJK UNIFIED IDEOGRAPH-#21A2E, IRGKangXi=0288.201, RSKangXi=40.8
21A2F CJK UNIFIED IDEOGRAPH-#21A2F, IRGKangXi=0288.201, RSKangXi=40.8
21A30 CJK UNIFIED IDEOGRAPH-#21A30, IRGKangXi=0288.201, RSKangXi=40.8
21A31 CJK UNIFIED IDEOGRAPH-#21A31, IRGKangXi=0288.201, RSKangXi=40.8
21A32 CJK UNIFIED IDEOGRAPH-#21A32, IRGKangXi=0288.201, RSKangXi=40.8
21A33 CJK UNIFIED IDEOGRAPH-#21A33, IRGKangXi=0288.201, RSKangXi=40.8
21A34 CJK UNIFIED IDEOGRAPH-#21A34, IRGKangXi=0288.201, RSKangXi=40.8, Def{rather; it is better; it is easier}
21A35 CJK UNIFIED IDEOGRAPH-#21A35, IRGKangXi=0288.201, RSKangXi=40.8
21A36 CJK UNIFIED IDEOGRAPH-#21A36, IRGKangXi=0288.201, RSKangXi=40.8
21A37 CJK UNIFIED IDEOGRAPH-#21A37, IRGKangXi=0288.201, RSKangXi=40.8
21A38 CJK UNIFIED IDEOGRAPH-#21A38, IRGKangXi=0288.201, RSKangXi=40.8
21A39 CJK UNIFIED IDEOGRAPH-#21A39, IRGKangXi=0288.201, RSKangXi=40.8
21A3A CJK UNIFIED IDEOGRAPH-#21A3A, IRGKangXi=0288.201, RSKangXi=40.8
21A3B CJK UNIFIED IDEOGRAPH-#21A3B, IRGKangXi=0288.201, RSKangXi=40.8
21A3C CJK UNIFIED IDEOGRAPH-#21A3C, IRGKangXi=0288.201, RSKangXi=40.8
21A3D CJK UNIFIED IDEOGRAPH-#21A3D, IRGKangXi=0288.220, RSKangXi=40.9
21A3E CJK UNIFIED IDEOGRAPH-#21A3E, IRGKangXi=0288.240, RSKangXi=40.9
21A3F CJK UNIFIED IDEOGRAPH-#21A3F, IRGKangXi=0288.250, RSKangXi=40.9
21A40 CJK UNIFIED IDEOGRAPH-#21A40, IRGKangXi=0288.260, RSKangXi=40.9
21A41 CJK UNIFIED IDEOGRAPH-#21A41, IRGKangXi=0289.010, RSKangXi=40.9
21A42 CJK UNIFIED IDEOGRAPH-#21A42, IRGKangXi=0289.050, RSKangXi=40.9
21A43 CJK UNIFIED IDEOGRAPH-#21A43, IRGKangXi=0289.120, RSKangXi=40.9
21A44 CJK UNIFIED IDEOGRAPH-#21A44, IRGKangXi=0289.130, RSKangXi=40.9
21A45 CJK UNIFIED IDEOGRAPH-#21A45, IRGKangXi=0289.170, RSKangXi=40.9
21A46 CJK UNIFIED IDEOGRAPH-#21A46, IRGKangXi=0289.180, RSKangXi=40.9
21A47 CJK UNIFIED IDEOGRAPH-#21A47, IRGKangXi=0289.190, RSKangXi=40.9
21A48 CJK UNIFIED IDEOGRAPH-#21A48, IRGKangXi=0289.200, RSKangXi=40.9
21A49 CJK UNIFIED IDEOGRAPH-#21A49, IRGKangXi=0289.210, RSKangXi=40.9
21A4A CJK UNIFIED IDEOGRAPH-#21A4A, IRGKangXi=0289.211, RSKangXi=40.9
21A4B CJK UNIFIED IDEOGRAPH-#21A4B, IRGKangXi=0289.211, RSKangXi=40.9
21A4C CJK UNIFIED IDEOGRAPH-#21A4C, IRGKangXi=0289.211, RSKangXi=40.9
21A4D CJK UNIFIED IDEOGRAPH-#21A4D, IRGKangXi=0289.211, RSKangXi=40.9
21A4E CJK UNIFIED IDEOGRAPH-#21A4E, IRGKangXi=0289.211, RSKangXi=40.9
21A4F CJK UNIFIED IDEOGRAPH-#21A4F, IRGKangXi=0289.211, RSKangXi=40.9
21A50 CJK UNIFIED IDEOGRAPH-#21A50, IRGKangXi=0289.211, RSKangXi=40.9
21A51 CJK UNIFIED IDEOGRAPH-#21A51, IRGKangXi=0289.211, RSKangXi=40.9
21A52 CJK UNIFIED IDEOGRAPH-#21A52, IRGKangXi=0289.211, RSKangXi=40.9
21A53 CJK UNIFIED IDEOGRAPH-#21A53, IRGKangXi=0289.211, RSKangXi=40.9
21A54 CJK UNIFIED IDEOGRAPH-#21A54, IRGKangXi=0289.211, RSKangXi=40.9
21A55 CJK UNIFIED IDEOGRAPH-#21A55, IRGKangXi=0289.211, RSKangXi=40.9
21A56 CJK UNIFIED IDEOGRAPH-#21A56, IRGKangXi=0289.211, RSKangXi=40.9
21A57 CJK UNIFIED IDEOGRAPH-#21A57, IRGKangXi=0289.211, RSKangXi=40.9
21A58 CJK UNIFIED IDEOGRAPH-#21A58, IRGKangXi=0289.211, RSKangXi=40.9
21A59 CJK UNIFIED IDEOGRAPH-#21A59, IRGKangXi=0289.211, RSKangXi=40.9
21A5A CJK UNIFIED IDEOGRAPH-#21A5A, IRGKangXi=0289.211, RSKangXi=40.9
21A5B CJK UNIFIED IDEOGRAPH-#21A5B, IRGKangXi=0289.211, RSKangXi=40.9
21A5C CJK UNIFIED IDEOGRAPH-#21A5C, IRGKangXi=0289.211, RSKangXi=40.9
21A5D CJK UNIFIED IDEOGRAPH-#21A5D, IRGKangXi=0289.211, RSKangXi=40.9
21A5E CJK UNIFIED IDEOGRAPH-#21A5E, IRGKangXi=0289.211, RSKangXi=40.9
21A5F CJK UNIFIED IDEOGRAPH-#21A5F, IRGKangXi=0289.220, RSKangXi=40.10
21A60 CJK UNIFIED IDEOGRAPH-#21A60, IRGKangXi=0289.240, RSKangXi=40.10
21A61 CJK UNIFIED IDEOGRAPH-#21A61, IRGKangXi=0289.260, RSKangXi=40.10
21A62 CJK UNIFIED IDEOGRAPH-#21A62, IRGKangXi=0289.280, RSKangXi=40.10
21A63 CJK UNIFIED IDEOGRAPH-#21A63, IRGKangXi=0289.290, RSKangXi=40.10
21A64 CJK UNIFIED IDEOGRAPH-#21A64, IRGKangXi=0290.010, RSKangXi=40.10
21A65 CJK UNIFIED IDEOGRAPH-#21A65, IRGKangXi=0290.030, RSKangXi=40.10
21A66 CJK UNIFIED IDEOGRAPH-#21A66, IRGKangXi=0290.060, RSKangXi=40.10
21A67 CJK UNIFIED IDEOGRAPH-#21A67, IRGKangXi=0290.070, RSKangXi=40.10
21A68 CJK UNIFIED IDEOGRAPH-#21A68, IRGKangXi=0290.080, RSKangXi=40.10
21A69 CJK UNIFIED IDEOGRAPH-#21A69, IRGKangXi=0290.110, RSKangXi=40.10
21A6A CJK UNIFIED IDEOGRAPH-#21A6A, IRGKangXi=0290.120, RSKangXi=40.10
21A6B CJK UNIFIED IDEOGRAPH-#21A6B, IRGKangXi=0290.121, RSKangXi=40.10
21A6C CJK UNIFIED IDEOGRAPH-#21A6C, IRGKangXi=0290.121, RSKangXi=40.10
21A6D CJK UNIFIED IDEOGRAPH-#21A6D, IRGKangXi=0290.121, RSKangXi=40.10
21A6E CJK UNIFIED IDEOGRAPH-#21A6E, IRGKangXi=0290.121, RSKangXi=40.10
21A6F CJK UNIFIED IDEOGRAPH-#21A6F, IRGKangXi=0290.121, RSKangXi=40.10
21A70 CJK UNIFIED IDEOGRAPH-#21A70, IRGKangXi=0290.121, RSKangXi=40.10
21A71 CJK UNIFIED IDEOGRAPH-#21A71, IRGKangXi=0290.121, RSKangXi=40.10
21A72 CJK UNIFIED IDEOGRAPH-#21A72, IRGKangXi=0290.121, RSKangXi=40.10
21A73 CJK UNIFIED IDEOGRAPH-#21A73, IRGKangXi=0290.121, RSKangXi=40.10
21A74 CJK UNIFIED IDEOGRAPH-#21A74, IRGKangXi=0290.121, RSKangXi=40.10
21A75 CJK UNIFIED IDEOGRAPH-#21A75, IRGKangXi=0290.121, RSKangXi=40.10
21A76 CJK UNIFIED IDEOGRAPH-#21A76, IRGKangXi=0290.121, RSKangXi=40.10
21A77 CJK UNIFIED IDEOGRAPH-#21A77, IRGKangXi=0290.121, RSKangXi=40.10
21A78 CJK UNIFIED IDEOGRAPH-#21A78, IRGKangXi=0290.121, RSKangXi=40.10
21A79 CJK UNIFIED IDEOGRAPH-#21A79, IRGKangXi=0290.121, RSKangXi=40.10
21A7A CJK UNIFIED IDEOGRAPH-#21A7A, IRGKangXi=0290.121, RSKangXi=40.10
21A7B CJK UNIFIED IDEOGRAPH-#21A7B, IRGKangXi=0290.170, RSKangXi=40.11
21A7C CJK UNIFIED IDEOGRAPH-#21A7C, IRGKangXi=0290.200, RSKangXi=40.11
21A7D CJK UNIFIED IDEOGRAPH-#21A7D, IRGKangXi=0290.210, RSKangXi=40.11
21A7E CJK UNIFIED IDEOGRAPH-#21A7E, IRGKangXi=0291.030, RSKangXi=40.11
21A7F CJK UNIFIED IDEOGRAPH-#21A7F, IRGKangXi=0291.070, RSKangXi=40.11
21A80 CJK UNIFIED IDEOGRAPH-#21A80, IRGKangXi=0291.100, RSKangXi=40.11
21A81 CJK UNIFIED IDEOGRAPH-#21A81, IRGKangXi=0291.120, RSKangXi=40.11
21A82 CJK UNIFIED IDEOGRAPH-#21A82, IRGKangXi=0291.130, RSKangXi=40.11
21A83 CJK UNIFIED IDEOGRAPH-#21A83, IRGKangXi=0291.140, RSKangXi=40.11
21A84 CJK UNIFIED IDEOGRAPH-#21A84, IRGKangXi=0291.150, RSKangXi=40.11
21A85 CJK UNIFIED IDEOGRAPH-#21A85, IRGKangXi=0291.160, RSKangXi=40.11
21A86 CJK UNIFIED IDEOGRAPH-#21A86, IRGKangXi=0291.170, RSKangXi=40.11
21A87 CJK UNIFIED IDEOGRAPH-#21A87, IRGKangXi=0291.181, RSKangXi=40.11
21A88 CJK UNIFIED IDEOGRAPH-#21A88, IRGKangXi=0291.181, RSKangXi=40.11
21A89 CJK UNIFIED IDEOGRAPH-#21A89, IRGKangXi=0291.181, RSKangXi=40.11
21A8A CJK UNIFIED IDEOGRAPH-#21A8A, IRGKangXi=0291.181, RSKangXi=40.11
21A8B CJK UNIFIED IDEOGRAPH-#21A8B, IRGKangXi=0291.181, RSKangXi=40.11
21A8C CJK UNIFIED IDEOGRAPH-#21A8C, IRGKangXi=0291.181, RSKangXi=40.11
21A8D CJK UNIFIED IDEOGRAPH-#21A8D, IRGKangXi=0291.181, RSKangXi=40.11
21A8E CJK UNIFIED IDEOGRAPH-#21A8E, IRGKangXi=0291.181, RSKangXi=40.11
21A8F CJK UNIFIED IDEOGRAPH-#21A8F, IRGKangXi=0291.181, RSKangXi=40.11
21A90 CJK UNIFIED IDEOGRAPH-#21A90, IRGKangXi=0291.181, RSKangXi=40.11
21A91 CJK UNIFIED IDEOGRAPH-#21A91, IRGKangXi=0291.181, RSKangXi=40.11
21A92 CJK UNIFIED IDEOGRAPH-#21A92, IRGKangXi=0291.181, RSKangXi=40.11
21A93 CJK UNIFIED IDEOGRAPH-#21A93, IRGKangXi=0291.181, RSKangXi=40.11
21A94 CJK UNIFIED IDEOGRAPH-#21A94, IRGKangXi=0291.181, RSKangXi=40.11
21A95 CJK UNIFIED IDEOGRAPH-#21A95, IRGKangXi=0291.181, RSKangXi=40.11
21A96 CJK UNIFIED IDEOGRAPH-#21A96, IRGKangXi=0291.181, RSKangXi=40.11
21A97 CJK UNIFIED IDEOGRAPH-#21A97, IRGKangXi=0291.181, RSKangXi=40.11
21A98 CJK UNIFIED IDEOGRAPH-#21A98, IRGKangXi=0291.181, RSKangXi=40.11
21A99 CJK UNIFIED IDEOGRAPH-#21A99, IRGKangXi=0291.181, RSKangXi=40.11
21A9A CJK UNIFIED IDEOGRAPH-#21A9A, IRGKangXi=0291.181, RSKangXi=40.11
21A9B CJK UNIFIED IDEOGRAPH-#21A9B, IRGKangXi=0291.181, RSKangXi=40.11
21A9C CJK UNIFIED IDEOGRAPH-#21A9C, IRGKangXi=0291.181, RSKangXi=40.11
21A9D CJK UNIFIED IDEOGRAPH-#21A9D, IRGKangXi=0291.181, RSKangXi=40.11
21A9E CJK UNIFIED IDEOGRAPH-#21A9E, IRGKangXi=0291.181, RSKangXi=29.12
21A9F CJK UNIFIED IDEOGRAPH-#21A9F, IRGKangXi=0291.190, RSKangXi=40.12
21AA0 CJK UNIFIED IDEOGRAPH-#21AA0, IRGKangXi=0291.210, RSKangXi=40.12
21AA1 CJK UNIFIED IDEOGRAPH-#21AA1, IRGKangXi=0292.050, RSKangXi=40.12
21AA2 CJK UNIFIED IDEOGRAPH-#21AA2, IRGKangXi=0292.080, RSKangXi=40.12
21AA3 CJK UNIFIED IDEOGRAPH-#21AA3, IRGKangXi=0292.110, RSKangXi=40.12
21AA4 CJK UNIFIED IDEOGRAPH-#21AA4, IRGKangXi=0292.120, RSKangXi=40.12
21AA5 CJK UNIFIED IDEOGRAPH-#21AA5, IRGKangXi=0292.130, RSKangXi=40.12
21AA6 CJK UNIFIED IDEOGRAPH-#21AA6, IRGKangXi=0292.131, RSKangXi=40.12
21AA7 CJK UNIFIED IDEOGRAPH-#21AA7, IRGKangXi=0292.131, RSKangXi=40.12
21AA8 CJK UNIFIED IDEOGRAPH-#21AA8, IRGKangXi=0292.131, RSKangXi=40.12
21AA9 CJK UNIFIED IDEOGRAPH-#21AA9, IRGKangXi=0292.131, RSKangXi=40.12
21AAA CJK UNIFIED IDEOGRAPH-#21AAA, IRGKangXi=0292.131, RSKangXi=40.12
21AAB CJK UNIFIED IDEOGRAPH-#21AAB, IRGKangXi=0292.131, RSKangXi=40.12
21AAC CJK UNIFIED IDEOGRAPH-#21AAC, IRGKangXi=0292.131, RSKangXi=40.12
21AAD CJK UNIFIED IDEOGRAPH-#21AAD, IRGKangXi=0292.131, RSKangXi=40.12
21AAE CJK UNIFIED IDEOGRAPH-#21AAE, IRGKangXi=0292.131, RSKangXi=40.12
21AAF CJK UNIFIED IDEOGRAPH-#21AAF, IRGKangXi=0292.131, RSKangXi=40.12
21AB0 CJK UNIFIED IDEOGRAPH-#21AB0, IRGKangXi=0292.131, RSKangXi=40.12
21AB1 CJK UNIFIED IDEOGRAPH-#21AB1, IRGKangXi=0292.131, RSKangXi=40.12
21AB2 CJK UNIFIED IDEOGRAPH-#21AB2, IRGKangXi=0292.131, RSKangXi=40.12
21AB3 CJK UNIFIED IDEOGRAPH-#21AB3, IRGKangXi=0292.131, RSKangXi=40.12
21AB4 CJK UNIFIED IDEOGRAPH-#21AB4, IRGKangXi=0292.131, RSKangXi=40.12
21AB5 CJK UNIFIED IDEOGRAPH-#21AB5, IRGKangXi=0292.131, RSKangXi=40.12
21AB6 CJK UNIFIED IDEOGRAPH-#21AB6, IRGKangXi=0292.131, RSKangXi=40.12
21AB7 CJK UNIFIED IDEOGRAPH-#21AB7, IRGKangXi=0292.131, RSKangXi=40.12
21AB8 CJK UNIFIED IDEOGRAPH-#21AB8, IRGKangXi=0292.131, RSKangXi=40.12
21AB9 CJK UNIFIED IDEOGRAPH-#21AB9, IRGKangXi=0292.131, RSKangXi=40.12
21ABA CJK UNIFIED IDEOGRAPH-#21ABA, IRGKangXi=0292.131, RSKangXi=40.12
21ABB CJK UNIFIED IDEOGRAPH-#21ABB, IRGKangXi=0292.131, RSKangXi=40.12
21ABC CJK UNIFIED IDEOGRAPH-#21ABC, IRGKangXi=0292.131, RSKangXi=40.12
21ABD CJK UNIFIED IDEOGRAPH-#21ABD, IRGKangXi=0292.131, RSKangXi=40.12
21ABE CJK UNIFIED IDEOGRAPH-#21ABE, IRGKangXi=0292.140, RSKangXi=40.13
21ABF CJK UNIFIED IDEOGRAPH-#21ABF, IRGKangXi=0292.150, RSKangXi=40.13
21AC0 CJK UNIFIED IDEOGRAPH-#21AC0, IRGKangXi=0292.180, RSKangXi=40.13
21AC1 CJK UNIFIED IDEOGRAPH-#21AC1, IRGKangXi=0292.190, RSKangXi=40.13
21AC2 CJK UNIFIED IDEOGRAPH-#21AC2, IRGKangXi=0292.200, RSKangXi=40.13
21AC3 CJK UNIFIED IDEOGRAPH-#21AC3, IRGKangXi=0292.210, RSKangXi=40.13
21AC4 CJK UNIFIED IDEOGRAPH-#21AC4, IRGKangXi=0292.220, RSKangXi=40.13
21AC5 CJK UNIFIED IDEOGRAPH-#21AC5, IRGKangXi=0292.230, RSKangXi=40.13
21AC6 CJK UNIFIED IDEOGRAPH-#21AC6, IRGKangXi=0292.231, RSKangXi=40.13
21AC7 CJK UNIFIED IDEOGRAPH-#21AC7, IRGKangXi=0292.231, RSKangXi=40.13
21AC8 CJK UNIFIED IDEOGRAPH-#21AC8, IRGKangXi=0292.231, RSKangXi=40.13
21AC9 CJK UNIFIED IDEOGRAPH-#21AC9, IRGKangXi=0292.231, RSKangXi=40.13
21ACA CJK UNIFIED IDEOGRAPH-#21ACA, IRGKangXi=0292.231, RSKangXi=40.13
21ACB CJK UNIFIED IDEOGRAPH-#21ACB, IRGKangXi=0292.231, RSKangXi=40.13
21ACC CJK UNIFIED IDEOGRAPH-#21ACC, IRGKangXi=0292.231, RSKangXi=40.13
21ACD CJK UNIFIED IDEOGRAPH-#21ACD, IRGKangXi=0292.231, RSKangXi=40.13
21ACE CJK UNIFIED IDEOGRAPH-#21ACE, IRGKangXi=0292.231, RSKangXi=40.13
21ACF CJK UNIFIED IDEOGRAPH-#21ACF, IRGKangXi=0292.231, RSKangXi=40.13
21AD0 CJK UNIFIED IDEOGRAPH-#21AD0, IRGKangXi=0292.231, RSKangXi=40.13
21AD1 CJK UNIFIED IDEOGRAPH-#21AD1, IRGKangXi=0292.260, RSKangXi=40.14
21AD2 CJK UNIFIED IDEOGRAPH-#21AD2, IRGKangXi=0292.270, RSKangXi=40.14
21AD3 CJK UNIFIED IDEOGRAPH-#21AD3, IRGKangXi=0292.271, RSKangXi=40.14
21AD4 CJK UNIFIED IDEOGRAPH-#21AD4, IRGKangXi=0292.271, RSKangXi=40.14
21AD5 CJK UNIFIED IDEOGRAPH-#21AD5, IRGKangXi=0292.271, RSKangXi=40.14
21AD6 CJK UNIFIED IDEOGRAPH-#21AD6, IRGKangXi=0292.271, RSKangXi=40.14
21AD7 CJK UNIFIED IDEOGRAPH-#21AD7, IRGKangXi=0292.271, RSKangXi=40.14
21AD8 CJK UNIFIED IDEOGRAPH-#21AD8, IRGKangXi=0292.271, RSKangXi=40.14
21AD9 CJK UNIFIED IDEOGRAPH-#21AD9, IRGKangXi=0292.271, RSKangXi=40.14
21ADA CJK UNIFIED IDEOGRAPH-#21ADA, IRGKangXi=0292.271, RSKangXi=40.14
21ADB CJK UNIFIED IDEOGRAPH-#21ADB, IRGKangXi=0292.271, RSKangXi=40.14
21ADC CJK UNIFIED IDEOGRAPH-#21ADC, IRGKangXi=0292.271, RSKangXi=40.14
21ADD CJK UNIFIED IDEOGRAPH-#21ADD, IRGKangXi=0292.271, RSKangXi=40.14
21ADE CJK UNIFIED IDEOGRAPH-#21ADE, IRGKangXi=0292.280, RSKangXi=40.15
21ADF CJK UNIFIED IDEOGRAPH-#21ADF, IRGKangXi=0293.020, RSKangXi=40.15
21AE0 CJK UNIFIED IDEOGRAPH-#21AE0, IRGKangXi=0293.021, RSKangXi=40.15
21AE1 CJK UNIFIED IDEOGRAPH-#21AE1, IRGKangXi=0293.021, RSKangXi=40.15
21AE2 CJK UNIFIED IDEOGRAPH-#21AE2, IRGKangXi=0293.021, RSKangXi=40.15
21AE3 CJK UNIFIED IDEOGRAPH-#21AE3, IRGKangXi=0293.021, RSKangXi=40.15
21AE4 CJK UNIFIED IDEOGRAPH-#21AE4, IRGKangXi=0293.021, RSKangXi=40.15
21AE5 CJK UNIFIED IDEOGRAPH-#21AE5, IRGKangXi=0293.021, RSKangXi=40.15
21AE6 CJK UNIFIED IDEOGRAPH-#21AE6, IRGKangXi=0293.021, RSKangXi=40.15
21AE7 CJK UNIFIED IDEOGRAPH-#21AE7, IRGKangXi=0293.021, RSKangXi=40.15
21AE8 CJK UNIFIED IDEOGRAPH-#21AE8, IRGKangXi=0293.021, RSKangXi=40.15
21AE9 CJK UNIFIED IDEOGRAPH-#21AE9, IRGKangXi=0293.021, RSKangXi=40.15
21AEA CJK UNIFIED IDEOGRAPH-#21AEA, IRGKangXi=0293.021, RSKangXi=40.15
21AEB CJK UNIFIED IDEOGRAPH-#21AEB, IRGKangXi=0293.021, RSKangXi=40.15
21AEC CJK UNIFIED IDEOGRAPH-#21AEC, IRGKangXi=0293.030, RSKangXi=40.16
21AED CJK UNIFIED IDEOGRAPH-#21AED, IRGKangXi=0293.040, RSKangXi=40.16
21AEE CJK UNIFIED IDEOGRAPH-#21AEE, IRGKangXi=0293.080, RSKangXi=40.16
21AEF CJK UNIFIED IDEOGRAPH-#21AEF, IRGKangXi=0293.090, RSKangXi=40.16
21AF0 CJK UNIFIED IDEOGRAPH-#21AF0, IRGKangXi=0293.100, RSKangXi=40.16
21AF1 CJK UNIFIED IDEOGRAPH-#21AF1, IRGKangXi=0293.110, RSKangXi=40.16
21AF2 CJK UNIFIED IDEOGRAPH-#21AF2, IRGKangXi=0293.111, RSKangXi=40.16
21AF3 CJK UNIFIED IDEOGRAPH-#21AF3, IRGKangXi=0293.111, RSKangXi=40.16
21AF4 CJK UNIFIED IDEOGRAPH-#21AF4, IRGKangXi=0293.111, RSKangXi=40.16
21AF5 CJK UNIFIED IDEOGRAPH-#21AF5, IRGKangXi=0293.111, RSKangXi=40.16
21AF6 CJK UNIFIED IDEOGRAPH-#21AF6, IRGKangXi=0293.111, RSKangXi=40.16
21AF7 CJK UNIFIED IDEOGRAPH-#21AF7, IRGKangXi=0293.151, RSKangXi=40.17
21AF8 CJK UNIFIED IDEOGRAPH-#21AF8, IRGKangXi=0293.151, RSKangXi=40.17
21AF9 CJK UNIFIED IDEOGRAPH-#21AF9, IRGKangXi=0293.151, RSKangXi=40.17
21AFA CJK UNIFIED IDEOGRAPH-#21AFA, IRGKangXi=0293.151, RSKangXi=40.17
21AFB CJK UNIFIED IDEOGRAPH-#21AFB, IRGKangXi=0293.151, RSKangXi=40.17
21AFC CJK UNIFIED IDEOGRAPH-#21AFC, IRGKangXi=0293.170, RSKangXi=40.18
21AFD CJK UNIFIED IDEOGRAPH-#21AFD, IRGKangXi=0293.180, RSKangXi=40.18
21AFE CJK UNIFIED IDEOGRAPH-#21AFE, IRGKangXi=0293.200, RSKangXi=40.18
21AFF CJK UNIFIED IDEOGRAPH-#21AFF, IRGKangXi=0293.201, RSKangXi=40.18
21B00 CJK UNIFIED IDEOGRAPH-#21B00, IRGKangXi=0293.201, RSKangXi=40.18
21B01 CJK UNIFIED IDEOGRAPH-#21B01, IRGKangXi=0293.201, RSKangXi=40.18
21B02 CJK UNIFIED IDEOGRAPH-#21B02, IRGKangXi=0293.201, RSKangXi=40.18
21B03 CJK UNIFIED IDEOGRAPH-#21B03, IRGKangXi=0293.201, RSKangXi=40.18
21B04 CJK UNIFIED IDEOGRAPH-#21B04, IRGKangXi=0293.210, RSKangXi=40.19
21B05 CJK UNIFIED IDEOGRAPH-#21B05, IRGKangXi=0293.220, RSKangXi=40.19
21B06 CJK UNIFIED IDEOGRAPH-#21B06, IRGKangXi=0293.230, RSKangXi=40.19
21B07 CJK UNIFIED IDEOGRAPH-#21B07, IRGKangXi=0293.240, RSKangXi=40.19
21B08 CJK UNIFIED IDEOGRAPH-#21B08, IRGKangXi=0293.241, RSKangXi=40.19
21B09 CJK UNIFIED IDEOGRAPH-#21B09, IRGKangXi=0293.241, RSKangXi=40.19
21B0A CJK UNIFIED IDEOGRAPH-#21B0A, IRGKangXi=0293.241, RSKangXi=40.19
21B0B CJK UNIFIED IDEOGRAPH-#21B0B, IRGKangXi=0293.241, RSKangXi=40.19
21B0C CJK UNIFIED IDEOGRAPH-#21B0C, IRGKangXi=0293.250, RSKangXi=40.20
21B0D CJK UNIFIED IDEOGRAPH-#21B0D, IRGKangXi=0293.260, RSKangXi=40.21
21B0E CJK UNIFIED IDEOGRAPH-#21B0E, IRGKangXi=0293.261, RSKangXi=40.24
21B0F CJK UNIFIED IDEOGRAPH-#21B0F, IRGKangXi=0293.261, RSKangXi=40.21
21B10 CJK UNIFIED IDEOGRAPH-#21B10, IRGKangXi=0293.261, RSKangXi=40.21
21B11 CJK UNIFIED IDEOGRAPH-#21B11, IRGKangXi=0293.270, RSKangXi=40.22
21B12 CJK UNIFIED IDEOGRAPH-#21B12, IRGKangXi=0293.280, RSKangXi=40.25
21B13 CJK UNIFIED IDEOGRAPH-#21B13, IRGKangXi=0293.281, RSKangXi=40.22
21B14 CJK UNIFIED IDEOGRAPH-#21B14, IRGKangXi=0293.281, RSKangXi=40.22
21B15 CJK UNIFIED IDEOGRAPH-#21B15, IRGKangXi=0293.281, RSKangXi=40.22
21B16 CJK UNIFIED IDEOGRAPH-#21B16, IRGKangXi=0293.300, RSKangXi=40.23
21B17 CJK UNIFIED IDEOGRAPH-#21B17, IRGKangXi=0293.301, RSKangXi=40.33
21B18 CJK UNIFIED IDEOGRAPH-#21B18, IRGKangXi=0293.301, RSKangXi=40.23
21B19 CJK UNIFIED IDEOGRAPH-#21B19, IRGKangXi=0293.310, RSKangXi=40.24, Def{to wake from sleep}
21B1A CJK UNIFIED IDEOGRAPH-#21B1A, IRGKangXi=0293.311, RSKangXi=40.24
21B1B CJK UNIFIED IDEOGRAPH-#21B1B, IRGKangXi=0293.311, RSKangXi=40.26
21B1C CJK UNIFIED IDEOGRAPH-#21B1C, IRGKangXi=0293.311, RSKangXi=40.33
21B1D CJK UNIFIED IDEOGRAPH-#21B1D, IRGKangXi=0293.321, RSKangXi=41.1
21B1E CJK UNIFIED IDEOGRAPH-#21B1E, IRGKangXi=0293.331, RSKangXi=41.3
21B1F CJK UNIFIED IDEOGRAPH-#21B1F, IRGKangXi=0294.030, RSKangXi=41.5
21B20 CJK UNIFIED IDEOGRAPH-#21B20, IRGKangXi=0294.060, RSKangXi=41.5
21B21 CJK UNIFIED IDEOGRAPH-#21B21, IRGKangXi=0294.061, RSKangXi=41.5
21B22 CJK UNIFIED IDEOGRAPH-#21B22, IRGKangXi=0294.061, RSKangXi=41.5
21B23 CJK UNIFIED IDEOGRAPH-#21B23, IRGKangXi=0294.061, RSKangXi=41.5
21B24 CJK UNIFIED IDEOGRAPH-#21B24, IRGKangXi=0294.061, RSKangXi=41.5
21B25 CJK UNIFIED IDEOGRAPH-#21B25, IRGKangXi=0294.061, RSKangXi=41.5
21B26 CJK UNIFIED IDEOGRAPH-#21B26, IRGKangXi=0294.061, RSKangXi=41.5
21B27 CJK UNIFIED IDEOGRAPH-#21B27, IRGKangXi=0294.100, RSKangXi=41.6
21B28 CJK UNIFIED IDEOGRAPH-#21B28, IRGKangXi=0294.110, RSKangXi=41.6
21B29 CJK UNIFIED IDEOGRAPH-#21B29, IRGKangXi=0294.111, RSKangXi=41.6
21B2A CJK UNIFIED IDEOGRAPH-#21B2A, IRGKangXi=0294.111, RSKangXi=41.6
21B2B CJK UNIFIED IDEOGRAPH-#21B2B, IRGKangXi=0294.111, RSKangXi=41.6
21B2C CJK UNIFIED IDEOGRAPH-#21B2C, IRGKangXi=0294.111, RSKangXi=41.6
21B2D CJK UNIFIED IDEOGRAPH-#21B2D, IRGKangXi=0294.151, RSKangXi=41.7
21B2E CJK UNIFIED IDEOGRAPH-#21B2E, IRGKangXi=0295.070, RSKangXi=41.8
21B2F CJK UNIFIED IDEOGRAPH-#21B2F, IRGKangXi=0295.080, RSKangXi=41.8
21B30 CJK UNIFIED IDEOGRAPH-#21B30, IRGKangXi=0295.090, RSKangXi=41.8
21B31 CJK UNIFIED IDEOGRAPH-#21B31, IRGKangXi=0295.091, RSKangXi=41.8
21B32 CJK UNIFIED IDEOGRAPH-#21B32, IRGKangXi=0295.091, RSKangXi=41.8
21B33 CJK UNIFIED IDEOGRAPH-#21B33, IRGKangXi=0295.110, RSKangXi=41.9
21B34 CJK UNIFIED IDEOGRAPH-#21B34, IRGKangXi=0296.010, RSKangXi=41.9
21B35 CJK UNIFIED IDEOGRAPH-#21B35, IRGKangXi=0296.011, RSKangXi=41.9
21B36 CJK UNIFIED IDEOGRAPH-#21B36, IRGKangXi=0296.011, RSKangXi=41.9
21B37 CJK UNIFIED IDEOGRAPH-#21B37, IRGKangXi=0296.011, RSKangXi=41.9
21B38 CJK UNIFIED IDEOGRAPH-#21B38, IRGKangXi=0296.011, RSKangXi=41.9
21B39 CJK UNIFIED IDEOGRAPH-#21B39, IRGKangXi=0296.020, RSKangXi=41.10
21B3A CJK UNIFIED IDEOGRAPH-#21B3A, IRGKangXi=0296.030, RSKangXi=41.10
21B3B CJK UNIFIED IDEOGRAPH-#21B3B, IRGKangXi=0296.040, RSKangXi=41.10
21B3C CJK UNIFIED IDEOGRAPH-#21B3C, IRGKangXi=0296.041, RSKangXi=41.10
21B3D CJK UNIFIED IDEOGRAPH-#21B3D, IRGKangXi=0296.050, RSKangXi=41.11
21B3E CJK UNIFIED IDEOGRAPH-#21B3E, IRGKangXi=0296.060, RSKangXi=41.11
21B3F CJK UNIFIED IDEOGRAPH-#21B3F, IRGKangXi=0296.071, RSKangXi=41.11
21B40 CJK UNIFIED IDEOGRAPH-#21B40, IRGKangXi=0296.071, RSKangXi=41.11
21B41 CJK UNIFIED IDEOGRAPH-#21B41, IRGKangXi=0296.071, RSKangXi=41.11
21B42 CJK UNIFIED IDEOGRAPH-#21B42, IRGKangXi=0296.080, RSKangXi=41.11
21B43 CJK UNIFIED IDEOGRAPH-#21B43, IRGKangXi=0296.081, RSKangXi=41.12
21B44 CJK UNIFIED IDEOGRAPH-#21B44, IRGKangXi=0296.081, RSKangXi=41.12
21B45 CJK UNIFIED IDEOGRAPH-#21B45, IRGKangXi=0296.081, RSKangXi=41.12
21B46 CJK UNIFIED IDEOGRAPH-#21B46, IRGKangXi=0296.081, RSKangXi=41.12
21B47 CJK UNIFIED IDEOGRAPH-#21B47, IRGKangXi=0296.081, RSKangXi=41.12
21B48 CJK UNIFIED IDEOGRAPH-#21B48, IRGKangXi=0296.081, RSKangXi=41.12
21B49 CJK UNIFIED IDEOGRAPH-#21B49, IRGKangXi=0296.081, RSKangXi=41.12
21B4A CJK UNIFIED IDEOGRAPH-#21B4A, IRGKangXi=0296.090, RSKangXi=41.13
21B4B CJK UNIFIED IDEOGRAPH-#21B4B, IRGKangXi=0296.111, RSKangXi=41.13
21B4C CJK UNIFIED IDEOGRAPH-#21B4C, IRGKangXi=0296.111, RSKangXi=41.13
21B4D CJK UNIFIED IDEOGRAPH-#21B4D, IRGKangXi=0296.120, RSKangXi=41.14
21B4E CJK UNIFIED IDEOGRAPH-#21B4E, IRGKangXi=0296.130, RSKangXi=41.14
21B4F CJK UNIFIED IDEOGRAPH-#21B4F, IRGKangXi=0296.131, RSKangXi=41.14
21B50 CJK UNIFIED IDEOGRAPH-#21B50, IRGKangXi=0296.140, RSKangXi=41.15
21B51 CJK UNIFIED IDEOGRAPH-#21B51, IRGKangXi=0296.150, RSKangXi=41.16
21B52 CJK UNIFIED IDEOGRAPH-#21B52, IRGKangXi=0296.160, RSKangXi=41.17
21B53 CJK UNIFIED IDEOGRAPH-#21B53, IRGKangXi=0296.170, RSKangXi=41.18
21B54 CJK UNIFIED IDEOGRAPH-#21B54, IRGKangXi=0296.181, RSKangXi=42.0
21B55 CJK UNIFIED IDEOGRAPH-#21B55, IRGKangXi=0296.210, RSKangXi=42.1
21B56 CJK UNIFIED IDEOGRAPH-#21B56, IRGKangXi=0296.211, RSKangXi=42.1
21B57 CJK UNIFIED IDEOGRAPH-#21B57, IRGKangXi=0296.220, RSKangXi=42.2
21B58 CJK UNIFIED IDEOGRAPH-#21B58, IRGKangXi=0297.011, RSKangXi=42.2
21B59 CJK UNIFIED IDEOGRAPH-#21B59, IRGKangXi=0297.030, RSKangXi=42.3
21B5A CJK UNIFIED IDEOGRAPH-#21B5A, IRGKangXi=0297.040, RSKangXi=42.3
21B5B CJK UNIFIED IDEOGRAPH-#21B5B, IRGKangXi=0297.061, RSKangXi=42.3
21B5C CJK UNIFIED IDEOGRAPH-#21B5C, IRGKangXi=0297.061, RSKangXi=42.3
21B5D CJK UNIFIED IDEOGRAPH-#21B5D, IRGKangXi=0297.070, RSKangXi=42.4
21B5E CJK UNIFIED IDEOGRAPH-#21B5E, IRGKangXi=0297.080, RSKangXi=42.4
21B5F CJK UNIFIED IDEOGRAPH-#21B5F, IRGKangXi=0297.090, RSKangXi=42.4
21B60 CJK UNIFIED IDEOGRAPH-#21B60, IRGKangXi=0297.100, RSKangXi=42.4
21B61 CJK UNIFIED IDEOGRAPH-#21B61, IRGKangXi=0297.101, RSKangXi=42.4
21B62 CJK UNIFIED IDEOGRAPH-#21B62, IRGKangXi=0297.101, RSKangXi=42.4
21B63 CJK UNIFIED IDEOGRAPH-#21B63, IRGKangXi=0297.101, RSKangXi=42.4
21B64 CJK UNIFIED IDEOGRAPH-#21B64, IRGKangXi=0297.101, RSKangXi=42.4
21B65 CJK UNIFIED IDEOGRAPH-#21B65, IRGKangXi=0297.120, RSKangXi=42.5
21B66 CJK UNIFIED IDEOGRAPH-#21B66, IRGKangXi=0297.121, RSKangXi=42.5
21B67 CJK UNIFIED IDEOGRAPH-#21B67, IRGKangXi=0297.121, RSKangXi=42.5
21B68 CJK UNIFIED IDEOGRAPH-#21B68, IRGKangXi=0297.121, RSKangXi=42.5
21B69 CJK UNIFIED IDEOGRAPH-#21B69, IRGKangXi=0297.121, RSKangXi=42.5
21B6A CJK UNIFIED IDEOGRAPH-#21B6A, IRGKangXi=0297.130, RSKangXi=42.6
21B6B CJK UNIFIED IDEOGRAPH-#21B6B, IRGKangXi=0297.150, RSKangXi=42.6
21B6C CJK UNIFIED IDEOGRAPH-#21B6C, IRGKangXi=0297.151, RSKangXi=42.6
21B6D CJK UNIFIED IDEOGRAPH-#21B6D, IRGKangXi=0297.151, RSKangXi=42.6
21B6E CJK UNIFIED IDEOGRAPH-#21B6E, IRGKangXi=0297.151, RSKangXi=42.6
21B6F CJK UNIFIED IDEOGRAPH-#21B6F, IRGKangXi=0297.151, RSKangXi=42.6
21B70 CJK UNIFIED IDEOGRAPH-#21B70, IRGKangXi=0297.151, RSKangXi=42.6
21B71 CJK UNIFIED IDEOGRAPH-#21B71, IRGKangXi=0297.151, RSKangXi=42.6
21B72 CJK UNIFIED IDEOGRAPH-#21B72, IRGKangXi=0297.151, RSKangXi=42.6
21B73 CJK UNIFIED IDEOGRAPH-#21B73, IRGKangXi=0297.151, RSKangXi=42.6
21B74 CJK UNIFIED IDEOGRAPH-#21B74, IRGKangXi=0297.170, RSKangXi=42.7
21B75 CJK UNIFIED IDEOGRAPH-#21B75, IRGKangXi=0297.171, RSKangXi=42.7
21B76 CJK UNIFIED IDEOGRAPH-#21B76, IRGKangXi=0297.171, RSKangXi=42.7
21B77 CJK UNIFIED IDEOGRAPH-#21B77, IRGKangXi=0297.171, RSKangXi=42.7
21B78 CJK UNIFIED IDEOGRAPH-#21B78, IRGKangXi=0297.171, RSKangXi=42.7
21B79 CJK UNIFIED IDEOGRAPH-#21B79, IRGKangXi=0297.171, RSKangXi=42.7
21B7A CJK UNIFIED IDEOGRAPH-#21B7A, IRGKangXi=0297.171, RSKangXi=42.7
21B7B CJK UNIFIED IDEOGRAPH-#21B7B, IRGKangXi=0297.171, RSKangXi=42.7
21B7C CJK UNIFIED IDEOGRAPH-#21B7C, IRGKangXi=0297.171, RSKangXi=42.7
21B7D CJK UNIFIED IDEOGRAPH-#21B7D, IRGKangXi=0297.180, RSKangXi=42.8
21B7E CJK UNIFIED IDEOGRAPH-#21B7E, IRGKangXi=0297.190, RSKangXi=42.8
21B7F CJK UNIFIED IDEOGRAPH-#21B7F, IRGKangXi=0297.210, RSKangXi=42.8
21B80 CJK UNIFIED IDEOGRAPH-#21B80, IRGKangXi=0297.220, RSKangXi=42.8
21B81 CJK UNIFIED IDEOGRAPH-#21B81, IRGKangXi=0297.230, RSKangXi=42.8
21B82 CJK UNIFIED IDEOGRAPH-#21B82, IRGKangXi=0297.231, RSKangXi=42.8
21B83 CJK UNIFIED IDEOGRAPH-#21B83, IRGKangXi=0297.231, RSKangXi=42.8
21B84 CJK UNIFIED IDEOGRAPH-#21B84, IRGKangXi=0297.231, RSKangXi=42.8
21B85 CJK UNIFIED IDEOGRAPH-#21B85, IRGKangXi=0297.231, RSKangXi=42.8
21B86 CJK UNIFIED IDEOGRAPH-#21B86, IRGKangXi=0297.231, RSKangXi=42.8
21B87 CJK UNIFIED IDEOGRAPH-#21B87, IRGKangXi=0297.231, RSKangXi=42.8
21B88 CJK UNIFIED IDEOGRAPH-#21B88, IRGKangXi=0297.231, RSKangXi=42.8
21B89 CJK UNIFIED IDEOGRAPH-#21B89, IRGKangXi=0297.231, RSKangXi=42.8
21B8A CJK UNIFIED IDEOGRAPH-#21B8A, IRGKangXi=0297.231, RSKangXi=42.8
21B8B CJK UNIFIED IDEOGRAPH-#21B8B, IRGKangXi=0297.231, RSKangXi=42.8
21B8C CJK UNIFIED IDEOGRAPH-#21B8C, IRGKangXi=0297.231, RSKangXi=42.8
21B8D CJK UNIFIED IDEOGRAPH-#21B8D, IRGKangXi=0297.231, RSKangXi=42.8
21B8E CJK UNIFIED IDEOGRAPH-#21B8E, IRGKangXi=0297.250, RSKangXi=42.9
21B8F CJK UNIFIED IDEOGRAPH-#21B8F, IRGKangXi=0297.251, RSKangXi=42.9
21B90 CJK UNIFIED IDEOGRAPH-#21B90, IRGKangXi=0297.251, RSKangXi=42.9
21B91 CJK UNIFIED IDEOGRAPH-#21B91, IRGKangXi=0297.251, RSKangXi=42.9
21B92 CJK UNIFIED IDEOGRAPH-#21B92, IRGKangXi=0297.251, RSKangXi=42.9
21B93 CJK UNIFIED IDEOGRAPH-#21B93, IRGKangXi=0297.251, RSKangXi=42.9
21B94 CJK UNIFIED IDEOGRAPH-#21B94, IRGKangXi=0297.251, RSKangXi=42.9
21B95 CJK UNIFIED IDEOGRAPH-#21B95, IRGKangXi=0297.251, RSKangXi=42.9
21B96 CJK UNIFIED IDEOGRAPH-#21B96, IRGKangXi=0297.251, RSKangXi=42.9
21B97 CJK UNIFIED IDEOGRAPH-#21B97, IRGKangXi=0297.251, RSKangXi=42.9
21B98 CJK UNIFIED IDEOGRAPH-#21B98, IRGKangXi=0297.271, RSKangXi=42.10
21B99 CJK UNIFIED IDEOGRAPH-#21B99, IRGKangXi=0297.271, RSKangXi=42.10
21B9A CJK UNIFIED IDEOGRAPH-#21B9A, IRGKangXi=0297.271, RSKangXi=42.10
21B9B CJK UNIFIED IDEOGRAPH-#21B9B, IRGKangXi=0297.271, RSKangXi=42.10
21B9C CJK UNIFIED IDEOGRAPH-#21B9C, IRGKangXi=0297.271, RSKangXi=42.10
21B9D CJK UNIFIED IDEOGRAPH-#21B9D, IRGKangXi=0297.271, RSKangXi=42.10
21B9E CJK UNIFIED IDEOGRAPH-#21B9E, IRGKangXi=0297.280, RSKangXi=42.11
21B9F CJK UNIFIED IDEOGRAPH-#21B9F, IRGKangXi=0297.290, RSKangXi=42.11
21BA0 CJK UNIFIED IDEOGRAPH-#21BA0, IRGKangXi=0297.301, RSKangXi=42.11
21BA1 CJK UNIFIED IDEOGRAPH-#21BA1, IRGKangXi=0297.301, RSKangXi=42.11
21BA2 CJK UNIFIED IDEOGRAPH-#21BA2, IRGKangXi=0297.301, RSKangXi=42.11
21BA3 CJK UNIFIED IDEOGRAPH-#21BA3, IRGKangXi=0297.301, RSKangXi=42.11
21BA4 CJK UNIFIED IDEOGRAPH-#21BA4, IRGKangXi=0297.301, RSKangXi=42.11
21BA5 CJK UNIFIED IDEOGRAPH-#21BA5, IRGKangXi=0297.301, RSKangXi=42.11
21BA6 CJK UNIFIED IDEOGRAPH-#21BA6, IRGKangXi=0297.310, RSKangXi=42.12, Def{worn out, spoiled}
21BA7 CJK UNIFIED IDEOGRAPH-#21BA7, IRGKangXi=0297.330, RSKangXi=42.12
21BA8 CJK UNIFIED IDEOGRAPH-#21BA8, IRGKangXi=0297.331, RSKangXi=42.12
21BA9 CJK UNIFIED IDEOGRAPH-#21BA9, IRGKangXi=0297.331, RSKangXi=42.12
21BAA CJK UNIFIED IDEOGRAPH-#21BAA, IRGKangXi=0297.331, RSKangXi=42.12
21BAB CJK UNIFIED IDEOGRAPH-#21BAB, IRGKangXi=0297.331, RSKangXi=42.12
21BAC CJK UNIFIED IDEOGRAPH-#21BAC, IRGKangXi=0297.331, RSKangXi=42.12
21BAD CJK UNIFIED IDEOGRAPH-#21BAD, IRGKangXi=0297.331, RSKangXi=42.12
21BAE CJK UNIFIED IDEOGRAPH-#21BAE, IRGKangXi=0297.331, RSKangXi=42.12
21BAF CJK UNIFIED IDEOGRAPH-#21BAF, IRGKangXi=0297.331, RSKangXi=42.12
21BB0 CJK UNIFIED IDEOGRAPH-#21BB0, IRGKangXi=0297.340, RSKangXi=42.13
21BB1 CJK UNIFIED IDEOGRAPH-#21BB1, IRGKangXi=0297.350, RSKangXi=42.13
21BB2 CJK UNIFIED IDEOGRAPH-#21BB2, IRGKangXi=0297.351, RSKangXi=42.13
21BB3 CJK UNIFIED IDEOGRAPH-#21BB3, IRGKangXi=0297.351, RSKangXi=42.13
21BB4 CJK UNIFIED IDEOGRAPH-#21BB4, IRGKangXi=0297.351, RSKangXi=42.14
21BB5 CJK UNIFIED IDEOGRAPH-#21BB5, IRGKangXi=0297.351, RSKangXi=42.14
21BB6 CJK UNIFIED IDEOGRAPH-#21BB6, IRGKangXi=0297.351, RSKangXi=42.14
21BB7 CJK UNIFIED IDEOGRAPH-#21BB7, IRGKangXi=0297.351, RSKangXi=42.15
21BB8 CJK UNIFIED IDEOGRAPH-#21BB8, IRGKangXi=0297.351, RSKangXi=42.15
21BB9 CJK UNIFIED IDEOGRAPH-#21BB9, IRGKangXi=0297.351, RSKangXi=42.15
21BBA CJK UNIFIED IDEOGRAPH-#21BBA, IRGKangXi=0297.351, RSKangXi=42.15
21BBB CJK UNIFIED IDEOGRAPH-#21BBB, IRGKangXi=0297.351, RSKangXi=42.15
21BBC CJK UNIFIED IDEOGRAPH-#21BBC, IRGKangXi=0297.360, RSKangXi=42.16
21BBD CJK UNIFIED IDEOGRAPH-#21BBD, IRGKangXi=0297.361, RSKangXi=42.16
21BBE CJK UNIFIED IDEOGRAPH-#21BBE, IRGKangXi=0297.361, RSKangXi=42.16
21BBF CJK UNIFIED IDEOGRAPH-#21BBF, IRGKangXi=0297.370, RSKangXi=42.18
21BC0 CJK UNIFIED IDEOGRAPH-#21BC0, IRGKangXi=0297.371, RSKangXi=42.29
21BC1 CJK UNIFIED IDEOGRAPH-#21BC1, IRGKangXi=0298.010, RSKangXi=43.0
21BC2 CJK UNIFIED IDEOGRAPH-#21BC2, IRGKangXi=0298.021, RSKangXi=43.0
21BC3 CJK UNIFIED IDEOGRAPH-#21BC3, IRGKangXi=0298.041, RSKangXi=43.1
21BC4 CJK UNIFIED IDEOGRAPH-#21BC4, IRGKangXi=0298.050, RSKangXi=43.2
21BC5 CJK UNIFIED IDEOGRAPH-#21BC5, IRGKangXi=0298.051, RSKangXi=43.2
21BC6 CJK UNIFIED IDEOGRAPH-#21BC6, IRGKangXi=0298.051, RSKangXi=43.2
21BC7 CJK UNIFIED IDEOGRAPH-#21BC7, IRGKangXi=0298.051, RSKangXi=43.2
21BC8 CJK UNIFIED IDEOGRAPH-#21BC8, IRGKangXi=0298.051, RSKangXi=43.2
21BC9 CJK UNIFIED IDEOGRAPH-#21BC9, IRGKangXi=0298.051, RSKangXi=43.2
21BCA CJK UNIFIED IDEOGRAPH-#21BCA, IRGKangXi=0298.051, RSKangXi=43.2
21BCB CJK UNIFIED IDEOGRAPH-#21BCB, IRGKangXi=0298.081, RSKangXi=43.3
21BCC CJK UNIFIED IDEOGRAPH-#21BCC, IRGKangXi=0298.081, RSKangXi=43.3
21BCD CJK UNIFIED IDEOGRAPH-#21BCD, IRGKangXi=0298.081, RSKangXi=43.3
21BCE CJK UNIFIED IDEOGRAPH-#21BCE, IRGKangXi=0298.081, RSKangXi=43.3
21BCF CJK UNIFIED IDEOGRAPH-#21BCF, IRGKangXi=0298.100, RSKangXi=43.4
21BD0 CJK UNIFIED IDEOGRAPH-#21BD0, IRGKangXi=0298.110, RSKangXi=43.4
21BD1 CJK UNIFIED IDEOGRAPH-#21BD1, IRGKangXi=0298.160, RSKangXi=43.4
21BD2 CJK UNIFIED IDEOGRAPH-#21BD2, IRGKangXi=0298.170, RSKangXi=43.4
21BD3 CJK UNIFIED IDEOGRAPH-#21BD3, IRGKangXi=0298.171, RSKangXi=43.4
21BD4 CJK UNIFIED IDEOGRAPH-#21BD4, IRGKangXi=0298.171, RSKangXi=43.4
21BD5 CJK UNIFIED IDEOGRAPH-#21BD5, IRGKangXi=0298.171, RSKangXi=43.4
21BD6 CJK UNIFIED IDEOGRAPH-#21BD6, IRGKangXi=0298.171, RSKangXi=43.4
21BD7 CJK UNIFIED IDEOGRAPH-#21BD7, IRGKangXi=0298.171, RSKangXi=43.4
21BD8 CJK UNIFIED IDEOGRAPH-#21BD8, IRGKangXi=0298.171, RSKangXi=43.4
21BD9 CJK UNIFIED IDEOGRAPH-#21BD9, IRGKangXi=0298.171, RSKangXi=43.4
21BDA CJK UNIFIED IDEOGRAPH-#21BDA, IRGKangXi=0298.180, RSKangXi=43.5
21BDB CJK UNIFIED IDEOGRAPH-#21BDB, IRGKangXi=0298.190, RSKangXi=43.5
21BDC CJK UNIFIED IDEOGRAPH-#21BDC, IRGKangXi=0298.200, RSKangXi=43.5
21BDD CJK UNIFIED IDEOGRAPH-#21BDD, IRGKangXi=0298.220, RSKangXi=43.5
21BDE CJK UNIFIED IDEOGRAPH-#21BDE, IRGKangXi=0298.221, RSKangXi=43.5
21BDF CJK UNIFIED IDEOGRAPH-#21BDF, IRGKangXi=0298.221, RSKangXi=43.5
21BE0 CJK UNIFIED IDEOGRAPH-#21BE0, IRGKangXi=0298.221, RSKangXi=43.5
21BE1 CJK UNIFIED IDEOGRAPH-#21BE1, IRGKangXi=0298.221, RSKangXi=43.5
21BE2 CJK UNIFIED IDEOGRAPH-#21BE2, IRGKangXi=0298.240, RSKangXi=43.6
21BE3 CJK UNIFIED IDEOGRAPH-#21BE3, IRGKangXi=0298.260, RSKangXi=43.6
21BE4 CJK UNIFIED IDEOGRAPH-#21BE4, IRGKangXi=0298.290, RSKangXi=43.6
21BE5 CJK UNIFIED IDEOGRAPH-#21BE5, IRGKangXi=0298.291, RSKangXi=142.3
21BE6 CJK UNIFIED IDEOGRAPH-#21BE6, IRGKangXi=0298.291, RSKangXi=43.6
21BE7 CJK UNIFIED IDEOGRAPH-#21BE7, IRGKangXi=0298.291, RSKangXi=43.6
21BE8 CJK UNIFIED IDEOGRAPH-#21BE8, IRGKangXi=0298.310, RSKangXi=43.7
21BE9 CJK UNIFIED IDEOGRAPH-#21BE9, IRGKangXi=0298.320, RSKangXi=43.7
21BEA CJK UNIFIED IDEOGRAPH-#21BEA, IRGKangXi=0298.330, RSKangXi=43.7
21BEB CJK UNIFIED IDEOGRAPH-#21BEB, IRGKangXi=0298.340, RSKangXi=43.7
21BEC CJK UNIFIED IDEOGRAPH-#21BEC, IRGKangXi=0298.341, RSKangXi=43.7
21BED CJK UNIFIED IDEOGRAPH-#21BED, IRGKangXi=0298.341, RSKangXi=43.7
21BEE CJK UNIFIED IDEOGRAPH-#21BEE, IRGKangXi=0298.341, RSKangXi=43.7
21BEF CJK UNIFIED IDEOGRAPH-#21BEF, IRGKangXi=0298.341, RSKangXi=43.7
21BF0 CJK UNIFIED IDEOGRAPH-#21BF0, IRGKangXi=0298.341, RSKangXi=43.7
21BF1 CJK UNIFIED IDEOGRAPH-#21BF1, IRGKangXi=0298.341, RSKangXi=43.7
21BF2 CJK UNIFIED IDEOGRAPH-#21BF2, IRGKangXi=0298.341, RSKangXi=43.7
21BF3 CJK UNIFIED IDEOGRAPH-#21BF3, IRGKangXi=0298.370, RSKangXi=43.8
21BF4 CJK UNIFIED IDEOGRAPH-#21BF4, IRGKangXi=0298.390, RSKangXi=43.8
21BF5 CJK UNIFIED IDEOGRAPH-#21BF5, IRGKangXi=0298.400, RSKangXi=43.8
21BF6 CJK UNIFIED IDEOGRAPH-#21BF6, IRGKangXi=0298.420, RSKangXi=43.8
21BF7 CJK UNIFIED IDEOGRAPH-#21BF7, IRGKangXi=0298.430, RSKangXi=43.8
21BF8 CJK UNIFIED IDEOGRAPH-#21BF8, IRGKangXi=0298.431, RSKangXi=43.8
21BF9 CJK UNIFIED IDEOGRAPH-#21BF9, IRGKangXi=0299.020, RSKangXi=43.9
21BFA CJK UNIFIED IDEOGRAPH-#21BFA, IRGKangXi=0299.030, RSKangXi=43.9
21BFB CJK UNIFIED IDEOGRAPH-#21BFB, IRGKangXi=0299.040, RSKangXi=43.9
21BFC CJK UNIFIED IDEOGRAPH-#21BFC, IRGKangXi=0299.061, RSKangXi=43.9
21BFD CJK UNIFIED IDEOGRAPH-#21BFD, IRGKangXi=0299.061, RSKangXi=43.9
21BFE CJK UNIFIED IDEOGRAPH-#21BFE, IRGKangXi=0299.061, RSKangXi=43.9
21BFF CJK UNIFIED IDEOGRAPH-#21BFF, IRGKangXi=0299.061, RSKangXi=43.9
21C00 CJK UNIFIED IDEOGRAPH-#21C00, IRGKangXi=0299.061, RSKangXi=43.9
21C01 CJK UNIFIED IDEOGRAPH-#21C01, IRGKangXi=0299.061, RSKangXi=43.9
21C02 CJK UNIFIED IDEOGRAPH-#21C02, IRGKangXi=0299.061, RSKangXi=43.9
21C03 CJK UNIFIED IDEOGRAPH-#21C03, IRGKangXi=0299.090, RSKangXi=43.10
21C04 CJK UNIFIED IDEOGRAPH-#21C04, IRGKangXi=0299.100, RSKangXi=43.10
21C05 CJK UNIFIED IDEOGRAPH-#21C05, IRGKangXi=0299.111, RSKangXi=43.10
21C06 CJK UNIFIED IDEOGRAPH-#21C06, IRGKangXi=0299.111, RSKangXi=43.10
21C07 CJK UNIFIED IDEOGRAPH-#21C07, IRGKangXi=0299.111, RSKangXi=43.10
21C08 CJK UNIFIED IDEOGRAPH-#21C08, IRGKangXi=0299.111, RSKangXi=43.10
21C09 CJK UNIFIED IDEOGRAPH-#21C09, IRGKangXi=0299.111, RSKangXi=43.10
21C0A CJK UNIFIED IDEOGRAPH-#21C0A, IRGKangXi=0299.111, RSKangXi=43.10
21C0B CJK UNIFIED IDEOGRAPH-#21C0B, IRGKangXi=0299.120, RSKangXi=43.11
21C0C CJK UNIFIED IDEOGRAPH-#21C0C, IRGKangXi=0299.130, RSKangXi=43.11
21C0D CJK UNIFIED IDEOGRAPH-#21C0D, IRGKangXi=0299.141, RSKangXi=43.11
21C0E CJK UNIFIED IDEOGRAPH-#21C0E, IRGKangXi=0299.141, RSKangXi=43.11
21C0F CJK UNIFIED IDEOGRAPH-#21C0F, IRGKangXi=0299.141, RSKangXi=43.11
21C10 CJK UNIFIED IDEOGRAPH-#21C10, IRGKangXi=0299.160, RSKangXi=43.12
21C11 CJK UNIFIED IDEOGRAPH-#21C11, IRGKangXi=0299.170, RSKangXi=43.12
21C12 CJK UNIFIED IDEOGRAPH-#21C12, IRGKangXi=0299.180, RSKangXi=43.12
21C13 CJK UNIFIED IDEOGRAPH-#21C13, IRGKangXi=0299.181, RSKangXi=43.12
21C14 CJK UNIFIED IDEOGRAPH-#21C14, IRGKangXi=0299.181, RSKangXi=43.12
21C15 CJK UNIFIED IDEOGRAPH-#21C15, IRGKangXi=0299.181, RSKangXi=43.12
21C16 CJK UNIFIED IDEOGRAPH-#21C16, IRGKangXi=0299.190, RSKangXi=43.13
21C17 CJK UNIFIED IDEOGRAPH-#21C17, IRGKangXi=0299.200, RSKangXi=43.13
21C18 CJK UNIFIED IDEOGRAPH-#21C18, IRGKangXi=0299.210, RSKangXi=43.13
21C19 CJK UNIFIED IDEOGRAPH-#21C19, IRGKangXi=0299.211, RSKangXi=43.13
21C1A CJK UNIFIED IDEOGRAPH-#21C1A, IRGKangXi=0299.211, RSKangXi=43.13
21C1B CJK UNIFIED IDEOGRAPH-#21C1B, IRGKangXi=0299.221, RSKangXi=43.14
21C1C CJK UNIFIED IDEOGRAPH-#21C1C, IRGKangXi=0299.221, RSKangXi=43.14
21C1D CJK UNIFIED IDEOGRAPH-#21C1D, IRGKangXi=0299.230, RSKangXi=43.18
21C1E CJK UNIFIED IDEOGRAPH-#21C1E, IRGKangXi=0299.231, RSKangXi=43.18
21C1F CJK UNIFIED IDEOGRAPH-#21C1F, IRGKangXi=0299.240, RSKangXi=43.19
21C20 CJK UNIFIED IDEOGRAPH-#21C20, IRGKangXi=0299.241, RSKangXi=43.19
21C21 CJK UNIFIED IDEOGRAPH-#21C21, IRGKangXi=0299.250, RSKangXi=43.22
21C22 CJK UNIFIED IDEOGRAPH-#21C22, IRGKangXi=0299.251, RSKangXi=43.22
21C23 CJK UNIFIED IDEOGRAPH-#21C23, IRGKangXi=0299.261, RSKangXi=44.0
21C24 CJK UNIFIED IDEOGRAPH-#21C24, IRGKangXi=0300.010, RSKangXi=44.2
21C25 CJK UNIFIED IDEOGRAPH-#21C25, IRGKangXi=0300.040, RSKangXi=44.2
21C26 CJK UNIFIED IDEOGRAPH-#21C26, IRGKangXi=0300.060, RSKangXi=44.2
21C27 CJK UNIFIED IDEOGRAPH-#21C27, IRGKangXi=0300.061, RSKangXi=44.2
21C28 CJK UNIFIED IDEOGRAPH-#21C28, IRGKangXi=0300.061, RSKangXi=44.2
21C29 CJK UNIFIED IDEOGRAPH-#21C29, IRGKangXi=0300.070, RSKangXi=44.3
21C2A CJK UNIFIED IDEOGRAPH-#21C2A, IRGKangXi=0300.080, RSKangXi=44.3, Def{(Cant.) end, bottom, rump}
21C2B CJK UNIFIED IDEOGRAPH-#21C2B, IRGKangXi=0300.100, RSKangXi=44.3
21C2C CJK UNIFIED IDEOGRAPH-#21C2C, IRGKangXi=0300.110, RSKangXi=44.3
21C2D CJK UNIFIED IDEOGRAPH-#21C2D, IRGKangXi=0300.130, RSKangXi=44.3
21C2E CJK UNIFIED IDEOGRAPH-#21C2E, IRGKangXi=0300.140, RSKangXi=44.3
21C2F CJK UNIFIED IDEOGRAPH-#21C2F, IRGKangXi=0300.150, RSKangXi=44.3
21C30 CJK UNIFIED IDEOGRAPH-#21C30, IRGKangXi=0300.151, RSKangXi=44.3
21C31 CJK UNIFIED IDEOGRAPH-#21C31, IRGKangXi=0300.151, RSKangXi=44.3
21C32 CJK UNIFIED IDEOGRAPH-#21C32, IRGKangXi=0300.151, RSKangXi=44.3
21C33 CJK UNIFIED IDEOGRAPH-#21C33, IRGKangXi=0300.151, RSKangXi=44.3
21C34 CJK UNIFIED IDEOGRAPH-#21C34, IRGKangXi=0300.161, RSKangXi=44.2
21C35 CJK UNIFIED IDEOGRAPH-#21C35, IRGKangXi=0300.210, RSKangXi=44.4
21C36 CJK UNIFIED IDEOGRAPH-#21C36, IRGKangXi=0300.240, RSKangXi=44.4
21C37 CJK UNIFIED IDEOGRAPH-#21C37, IRGKangXi=0300.241, RSKangXi=44.4
21C38 CJK UNIFIED IDEOGRAPH-#21C38, IRGKangXi=0300.241, RSKangXi=44.4
21C39 CJK UNIFIED IDEOGRAPH-#21C39, IRGKangXi=0300.241, RSKangXi=44.4
21C3A CJK UNIFIED IDEOGRAPH-#21C3A, IRGKangXi=0300.241, RSKangXi=44.4
21C3B CJK UNIFIED IDEOGRAPH-#21C3B, IRGKangXi=0300.241, RSKangXi=44.4
21C3C CJK UNIFIED IDEOGRAPH-#21C3C, IRGKangXi=0300.241, RSKangXi=44.4
21C3D CJK UNIFIED IDEOGRAPH-#21C3D, IRGKangXi=0300.241, RSKangXi=44.4
21C3E CJK UNIFIED IDEOGRAPH-#21C3E, IRGKangXi=0300.260, RSKangXi=44.5
21C3F CJK UNIFIED IDEOGRAPH-#21C3F, IRGKangXi=0300.280, RSKangXi=44.5
21C40 CJK UNIFIED IDEOGRAPH-#21C40, IRGKangXi=0301.020, RSKangXi=44.5
21C41 CJK UNIFIED IDEOGRAPH-#21C41, IRGKangXi=0301.110, RSKangXi=44.5
21C42 CJK UNIFIED IDEOGRAPH-#21C42, IRGKangXi=0301.120, RSKangXi=44.5
21C43 CJK UNIFIED IDEOGRAPH-#21C43, IRGKangXi=0301.140, RSKangXi=44.5
21C44 CJK UNIFIED IDEOGRAPH-#21C44, IRGKangXi=0301.141, RSKangXi=44.5
21C45 CJK UNIFIED IDEOGRAPH-#21C45, IRGKangXi=0301.141, RSKangXi=44.5
21C46 CJK UNIFIED IDEOGRAPH-#21C46, IRGKangXi=0301.141, RSKangXi=44.5, Def{to belong to; allied}
21C47 CJK UNIFIED IDEOGRAPH-#21C47, IRGKangXi=0301.141, RSKangXi=44.5
21C48 CJK UNIFIED IDEOGRAPH-#21C48, IRGKangXi=0301.141, RSKangXi=44.5
21C49 CJK UNIFIED IDEOGRAPH-#21C49, IRGKangXi=0301.141, RSKangXi=44.5
21C4A CJK UNIFIED IDEOGRAPH-#21C4A, IRGKangXi=0301.141, RSKangXi=44.5
21C4B CJK UNIFIED IDEOGRAPH-#21C4B, IRGKangXi=0301.141, RSKangXi=44.5
21C4C CJK UNIFIED IDEOGRAPH-#21C4C, IRGKangXi=0301.150, RSKangXi=44.6
21C4D CJK UNIFIED IDEOGRAPH-#21C4D, IRGKangXi=0301.160, RSKangXi=44.6
21C4E CJK UNIFIED IDEOGRAPH-#21C4E, IRGKangXi=0301.170, RSKangXi=44.6
21C4F CJK UNIFIED IDEOGRAPH-#21C4F, IRGKangXi=0301.230, RSKangXi=44.6
21C50 CJK UNIFIED IDEOGRAPH-#21C50, IRGKangXi=0301.270, RSKangXi=44.6
21C51 CJK UNIFIED IDEOGRAPH-#21C51, IRGKangXi=0301.290, RSKangXi=44.6
21C52 CJK UNIFIED IDEOGRAPH-#21C52, IRGKangXi=0301.320, RSKangXi=44.6
21C53 CJK UNIFIED IDEOGRAPH-#21C53, IRGKangXi=0301.330, RSKangXi=44.6
21C54 CJK UNIFIED IDEOGRAPH-#21C54, IRGKangXi=0301.340, RSKangXi=44.6
21C55 CJK UNIFIED IDEOGRAPH-#21C55, IRGKangXi=0301.350, RSKangXi=44.6
21C56 CJK UNIFIED IDEOGRAPH-#21C56, IRGKangXi=0301.351, RSKangXi=44.6
21C57 CJK UNIFIED IDEOGRAPH-#21C57, IRGKangXi=0301.351, RSKangXi=44.6
21C58 CJK UNIFIED IDEOGRAPH-#21C58, IRGKangXi=0301.351, RSKangXi=44.6
21C59 CJK UNIFIED IDEOGRAPH-#21C59, IRGKangXi=0301.351, RSKangXi=44.6
21C5A CJK UNIFIED IDEOGRAPH-#21C5A, IRGKangXi=0301.351, RSKangXi=44.6
21C5B CJK UNIFIED IDEOGRAPH-#21C5B, IRGKangXi=0301.351, RSKangXi=44.6
21C5C CJK UNIFIED IDEOGRAPH-#21C5C, IRGKangXi=0301.351, RSKangXi=44.6
21C5D CJK UNIFIED IDEOGRAPH-#21C5D, IRGKangXi=0301.351, RSKangXi=44.6
21C5E CJK UNIFIED IDEOGRAPH-#21C5E, IRGKangXi=0301.351, RSKangXi=44.6
21C5F CJK UNIFIED IDEOGRAPH-#21C5F, IRGKangXi=0301.351, RSKangXi=44.6
21C60 CJK UNIFIED IDEOGRAPH-#21C60, IRGKangXi=0301.351, RSKangXi=44.6
21C61 CJK UNIFIED IDEOGRAPH-#21C61, IRGKangXi=0301.351, RSKangXi=44.6
21C62 CJK UNIFIED IDEOGRAPH-#21C62, IRGKangXi=0302.010, RSKangXi=44.7
21C63 CJK UNIFIED IDEOGRAPH-#21C63, IRGKangXi=0302.020, RSKangXi=44.7
21C64 CJK UNIFIED IDEOGRAPH-#21C64, IRGKangXi=0302.060, RSKangXi=44.7
21C65 CJK UNIFIED IDEOGRAPH-#21C65, IRGKangXi=0302.130, RSKangXi=44.7
21C66 CJK UNIFIED IDEOGRAPH-#21C66, IRGKangXi=0302.140, RSKangXi=44.7
21C67 CJK UNIFIED IDEOGRAPH-#21C67, IRGKangXi=0302.150, RSKangXi=44.7
21C68 CJK UNIFIED IDEOGRAPH-#21C68, IRGKangXi=0302.160, RSKangXi=44.7
21C69 CJK UNIFIED IDEOGRAPH-#21C69, IRGKangXi=0302.161, RSKangXi=44.7
21C6A CJK UNIFIED IDEOGRAPH-#21C6A, IRGKangXi=0302.161, RSKangXi=44.7
21C6B CJK UNIFIED IDEOGRAPH-#21C6B, IRGKangXi=0302.161, RSKangXi=44.7
21C6C CJK UNIFIED IDEOGRAPH-#21C6C, IRGKangXi=0302.161, RSKangXi=44.7
21C6D CJK UNIFIED IDEOGRAPH-#21C6D, IRGKangXi=0302.161, RSKangXi=44.7
21C6E CJK UNIFIED IDEOGRAPH-#21C6E, IRGKangXi=0302.161, RSKangXi=44.7
21C6F CJK UNIFIED IDEOGRAPH-#21C6F, IRGKangXi=0302.161, RSKangXi=44.7
21C70 CJK UNIFIED IDEOGRAPH-#21C70, IRGKangXi=0302.161, RSKangXi=44.7
21C71 CJK UNIFIED IDEOGRAPH-#21C71, IRGKangXi=0302.161, RSKangXi=44.7
21C72 CJK UNIFIED IDEOGRAPH-#21C72, IRGKangXi=0302.161, RSKangXi=44.7
21C73 CJK UNIFIED IDEOGRAPH-#21C73, IRGKangXi=0302.161, RSKangXi=44.7
21C74 CJK UNIFIED IDEOGRAPH-#21C74, IRGKangXi=0302.161, RSKangXi=44.7
21C75 CJK UNIFIED IDEOGRAPH-#21C75, IRGKangXi=0302.161, RSKangXi=44.7
21C76 CJK UNIFIED IDEOGRAPH-#21C76, IRGKangXi=0302.161, RSKangXi=44.7
21C77 CJK UNIFIED IDEOGRAPH-#21C77, IRGKangXi=0302.161, RSKangXi=44.7
21C78 CJK UNIFIED IDEOGRAPH-#21C78, IRGKangXi=0302.161, RSKangXi=44.7
21C79 CJK UNIFIED IDEOGRAPH-#21C79, IRGKangXi=0302.161, RSKangXi=44.7
21C7A CJK UNIFIED IDEOGRAPH-#21C7A, IRGKangXi=0302.170, RSKangXi=44.8
21C7B CJK UNIFIED IDEOGRAPH-#21C7B, IRGKangXi=0302.190, RSKangXi=44.8
21C7C CJK UNIFIED IDEOGRAPH-#21C7C, IRGKangXi=0302.200, RSKangXi=44.8
21C7D CJK UNIFIED IDEOGRAPH-#21C7D, IRGKangXi=0302.210, RSKangXi=44.8
21C7E CJK UNIFIED IDEOGRAPH-#21C7E, IRGKangXi=0302.240, RSKangXi=44.8
21C7F CJK UNIFIED IDEOGRAPH-#21C7F, IRGKangXi=0302.270, RSKangXi=44.8
21C80 CJK UNIFIED IDEOGRAPH-#21C80, IRGKangXi=0302.280, RSKangXi=44.8
21C81 CJK UNIFIED IDEOGRAPH-#21C81, IRGKangXi=0302.300, RSKangXi=44.8
21C82 CJK UNIFIED IDEOGRAPH-#21C82, IRGKangXi=0302.310, RSKangXi=44.8
21C83 CJK UNIFIED IDEOGRAPH-#21C83, IRGKangXi=0302.320, RSKangXi=44.8
21C84 CJK UNIFIED IDEOGRAPH-#21C84, IRGKangXi=0302.321, RSKangXi=44.8
21C85 CJK UNIFIED IDEOGRAPH-#21C85, IRGKangXi=0302.321, RSKangXi=44.8
21C86 CJK UNIFIED IDEOGRAPH-#21C86, IRGKangXi=0302.321, RSKangXi=44.8
21C87 CJK UNIFIED IDEOGRAPH-#21C87, IRGKangXi=0302.321, RSKangXi=44.8
21C88 CJK UNIFIED IDEOGRAPH-#21C88, IRGKangXi=0302.321, RSKangXi=44.8
21C89 CJK UNIFIED IDEOGRAPH-#21C89, IRGKangXi=0302.321, RSKangXi=44.8
21C8A CJK UNIFIED IDEOGRAPH-#21C8A, IRGKangXi=0302.321, RSKangXi=44.8
21C8B CJK UNIFIED IDEOGRAPH-#21C8B, IRGKangXi=0302.321, RSKangXi=44.8
21C8C CJK UNIFIED IDEOGRAPH-#21C8C, IRGKangXi=0302.321, RSKangXi=44.8
21C8D CJK UNIFIED IDEOGRAPH-#21C8D, IRGKangXi=0302.321, RSKangXi=44.8
21C8E CJK UNIFIED IDEOGRAPH-#21C8E, IRGKangXi=0302.321, RSKangXi=44.8
21C8F CJK UNIFIED IDEOGRAPH-#21C8F, IRGKangXi=0302.321, RSKangXi=44.8
21C90 CJK UNIFIED IDEOGRAPH-#21C90, IRGKangXi=0302.321, RSKangXi=44.8
21C91 CJK UNIFIED IDEOGRAPH-#21C91, IRGKangXi=0302.321, RSKangXi=44.8
21C92 CJK UNIFIED IDEOGRAPH-#21C92, IRGKangXi=0302.321, RSKangXi=44.8
21C93 CJK UNIFIED IDEOGRAPH-#21C93, IRGKangXi=0302.321, RSKangXi=44.8
21C94 CJK UNIFIED IDEOGRAPH-#21C94, IRGKangXi=0303.010, RSKangXi=44.9
21C95 CJK UNIFIED IDEOGRAPH-#21C95, IRGKangXi=0303.020, RSKangXi=44.9, Def{tray, drawer}
21C96 CJK UNIFIED IDEOGRAPH-#21C96, IRGKangXi=0303.030, RSKangXi=44.9
21C97 CJK UNIFIED IDEOGRAPH-#21C97, IRGKangXi=0303.040, RSKangXi=44.9
21C98 CJK UNIFIED IDEOGRAPH-#21C98, IRGKangXi=0303.070, RSKangXi=44.9
21C99 CJK UNIFIED IDEOGRAPH-#21C99, IRGKangXi=0303.080, RSKangXi=44.9
21C9A CJK UNIFIED IDEOGRAPH-#21C9A, IRGKangXi=0303.090, RSKangXi=44.9
21C9B CJK UNIFIED IDEOGRAPH-#21C9B, IRGKangXi=0303.100, RSKangXi=44.9
21C9C CJK UNIFIED IDEOGRAPH-#21C9C, IRGKangXi=0303.130, RSKangXi=44.9
21C9D CJK UNIFIED IDEOGRAPH-#21C9D, IRGKangXi=0303.140, RSKangXi=44.9
21C9E CJK UNIFIED IDEOGRAPH-#21C9E, IRGKangXi=0303.150, RSKangXi=44.9
21C9F CJK UNIFIED IDEOGRAPH-#21C9F, IRGKangXi=0303.160, RSKangXi=44.9
21CA0 CJK UNIFIED IDEOGRAPH-#21CA0, IRGKangXi=0303.170, RSKangXi=44.9
21CA1 CJK UNIFIED IDEOGRAPH-#21CA1, IRGKangXi=0303.180, RSKangXi=44.9
21CA2 CJK UNIFIED IDEOGRAPH-#21CA2, IRGKangXi=0303.181, RSKangXi=44.9, Def{(Cant.) shit}
21CA3 CJK UNIFIED IDEOGRAPH-#21CA3, IRGKangXi=0303.181, RSKangXi=44.9
21CA4 CJK UNIFIED IDEOGRAPH-#21CA4, IRGKangXi=0303.181, RSKangXi=44.9
21CA5 CJK UNIFIED IDEOGRAPH-#21CA5, IRGKangXi=0303.181, RSKangXi=44.9
21CA6 CJK UNIFIED IDEOGRAPH-#21CA6, IRGKangXi=0303.181, RSKangXi=44.9
21CA7 CJK UNIFIED IDEOGRAPH-#21CA7, IRGKangXi=0303.181, RSKangXi=44.9
21CA8 CJK UNIFIED IDEOGRAPH-#21CA8, IRGKangXi=0303.181, RSKangXi=44.9
21CA9 CJK UNIFIED IDEOGRAPH-#21CA9, IRGKangXi=0303.181, RSKangXi=44.9
21CAA CJK UNIFIED IDEOGRAPH-#21CAA, IRGKangXi=0303.181, RSKangXi=44.9
21CAB CJK UNIFIED IDEOGRAPH-#21CAB, IRGKangXi=0303.181, RSKangXi=44.9
21CAC CJK UNIFIED IDEOGRAPH-#21CAC, IRGKangXi=0303.190, RSKangXi=44.10, Def{(Cant.) blunt}
21CAD CJK UNIFIED IDEOGRAPH-#21CAD, IRGKangXi=0303.200, RSKangXi=44.10
21CAE CJK UNIFIED IDEOGRAPH-#21CAE, IRGKangXi=0303.210, RSKangXi=44.10
21CAF CJK UNIFIED IDEOGRAPH-#21CAF, IRGKangXi=0303.220, RSKangXi=44.10
21CB0 CJK UNIFIED IDEOGRAPH-#21CB0, IRGKangXi=0303.230, RSKangXi=44.10
21CB1 CJK UNIFIED IDEOGRAPH-#21CB1, IRGKangXi=0303.240, RSKangXi=44.10
21CB2 CJK UNIFIED IDEOGRAPH-#21CB2, IRGKangXi=0303.250, RSKangXi=44.10
21CB3 CJK UNIFIED IDEOGRAPH-#21CB3, IRGKangXi=0303.260, RSKangXi=44.10
21CB4 CJK UNIFIED IDEOGRAPH-#21CB4, IRGKangXi=0303.270, RSKangXi=44.10
21CB5 CJK UNIFIED IDEOGRAPH-#21CB5, IRGKangXi=0303.280, RSKangXi=44.10
21CB6 CJK UNIFIED IDEOGRAPH-#21CB6, IRGKangXi=0303.290, RSKangXi=44.10
21CB7 CJK UNIFIED IDEOGRAPH-#21CB7, IRGKangXi=0303.291, RSKangXi=44.10
21CB8 CJK UNIFIED IDEOGRAPH-#21CB8, IRGKangXi=0303.291, RSKangXi=44.10
21CB9 CJK UNIFIED IDEOGRAPH-#21CB9, IRGKangXi=0303.291, RSKangXi=44.10
21CBA CJK UNIFIED IDEOGRAPH-#21CBA, IRGKangXi=0303.291, RSKangXi=44.10
21CBB CJK UNIFIED IDEOGRAPH-#21CBB, IRGKangXi=0303.291, RSKangXi=44.10
21CBC CJK UNIFIED IDEOGRAPH-#21CBC, IRGKangXi=0303.291, RSKangXi=44.10
21CBD CJK UNIFIED IDEOGRAPH-#21CBD, IRGKangXi=0303.291, RSKangXi=44.10
21CBE CJK UNIFIED IDEOGRAPH-#21CBE, IRGKangXi=0303.291, RSKangXi=44.10
21CBF CJK UNIFIED IDEOGRAPH-#21CBF, IRGKangXi=0303.291, RSKangXi=44.10
21CC0 CJK UNIFIED IDEOGRAPH-#21CC0, IRGKangXi=0303.291, RSKangXi=44.10
21CC1 CJK UNIFIED IDEOGRAPH-#21CC1, IRGKangXi=0303.291, RSKangXi=44.10
21CC2 CJK UNIFIED IDEOGRAPH-#21CC2, IRGKangXi=0303.291, RSKangXi=44.10
21CC3 CJK UNIFIED IDEOGRAPH-#21CC3, IRGKangXi=0303.291, RSKangXi=44.10
21CC4 CJK UNIFIED IDEOGRAPH-#21CC4, IRGKangXi=0303.320, RSKangXi=44.11
21CC5 CJK UNIFIED IDEOGRAPH-#21CC5, IRGKangXi=0303.330, RSKangXi=44.11
21CC6 CJK UNIFIED IDEOGRAPH-#21CC6, IRGKangXi=0303.340, RSKangXi=44.11
21CC7 CJK UNIFIED IDEOGRAPH-#21CC7, IRGKangXi=0303.360, RSKangXi=44.11
21CC8 CJK UNIFIED IDEOGRAPH-#21CC8, IRGKangXi=0303.380, RSKangXi=44.11
21CC9 CJK UNIFIED IDEOGRAPH-#21CC9, IRGKangXi=0303.390, RSKangXi=44.11
21CCA CJK UNIFIED IDEOGRAPH-#21CCA, IRGKangXi=0303.391, RSKangXi=44.11
21CCB CJK UNIFIED IDEOGRAPH-#21CCB, IRGKangXi=0303.391, RSKangXi=44.11
21CCC CJK UNIFIED IDEOGRAPH-#21CCC, IRGKangXi=0303.391, RSKangXi=44.11
21CCD CJK UNIFIED IDEOGRAPH-#21CCD, IRGKangXi=0303.391, RSKangXi=44.11
21CCE CJK UNIFIED IDEOGRAPH-#21CCE, IRGKangXi=0303.391, RSKangXi=44.11
21CCF CJK UNIFIED IDEOGRAPH-#21CCF, IRGKangXi=0303.391, RSKangXi=44.11
21CD0 CJK UNIFIED IDEOGRAPH-#21CD0, IRGKangXi=0303.440, RSKangXi=44.12
21CD1 CJK UNIFIED IDEOGRAPH-#21CD1, IRGKangXi=0303.460, RSKangXi=44.12
21CD2 CJK UNIFIED IDEOGRAPH-#21CD2, IRGKangXi=0303.461, RSKangXi=44.12
21CD3 CJK UNIFIED IDEOGRAPH-#21CD3, IRGKangXi=0303.461, RSKangXi=44.12
21CD4 CJK UNIFIED IDEOGRAPH-#21CD4, IRGKangXi=0303.461, RSKangXi=44.12
21CD5 CJK UNIFIED IDEOGRAPH-#21CD5, IRGKangXi=0303.461, RSKangXi=44.12
21CD6 CJK UNIFIED IDEOGRAPH-#21CD6, IRGKangXi=0303.461, RSKangXi=44.12
21CD7 CJK UNIFIED IDEOGRAPH-#21CD7, IRGKangXi=0303.461, RSKangXi=44.12
21CD8 CJK UNIFIED IDEOGRAPH-#21CD8, IRGKangXi=0303.461, RSKangXi=44.12
21CD9 CJK UNIFIED IDEOGRAPH-#21CD9, IRGKangXi=0303.461, RSKangXi=44.12
21CDA CJK UNIFIED IDEOGRAPH-#21CDA, IRGKangXi=0303.461, RSKangXi=44.12
21CDB CJK UNIFIED IDEOGRAPH-#21CDB, IRGKangXi=0303.461, RSKangXi=44.12
21CDC CJK UNIFIED IDEOGRAPH-#21CDC, IRGKangXi=0303.461, RSKangXi=44.12
21CDD CJK UNIFIED IDEOGRAPH-#21CDD, IRGKangXi=0303.461, RSKangXi=44.12
21CDE CJK UNIFIED IDEOGRAPH-#21CDE, IRGKangXi=0303.470, RSKangXi=44.12
21CDF CJK UNIFIED IDEOGRAPH-#21CDF, IRGKangXi=0303.490, RSKangXi=44.13
21CE0 CJK UNIFIED IDEOGRAPH-#21CE0, IRGKangXi=0303.500, RSKangXi=44.13
21CE1 CJK UNIFIED IDEOGRAPH-#21CE1, IRGKangXi=0303.510, RSKangXi=44.13
21CE2 CJK UNIFIED IDEOGRAPH-#21CE2, IRGKangXi=0303.511, RSKangXi=44.13
21CE3 CJK UNIFIED IDEOGRAPH-#21CE3, IRGKangXi=0303.511, RSKangXi=44.13
21CE4 CJK UNIFIED IDEOGRAPH-#21CE4, IRGKangXi=0303.511, RSKangXi=44.13
21CE5 CJK UNIFIED IDEOGRAPH-#21CE5, IRGKangXi=0303.511, RSKangXi=44.13
21CE6 CJK UNIFIED IDEOGRAPH-#21CE6, IRGKangXi=0303.511, RSKangXi=44.13
21CE7 CJK UNIFIED IDEOGRAPH-#21CE7, IRGKangXi=0303.511, RSKangXi=44.13
21CE8 CJK UNIFIED IDEOGRAPH-#21CE8, IRGKangXi=0303.520, RSKangXi=44.14
21CE9 CJK UNIFIED IDEOGRAPH-#21CE9, IRGKangXi=0304.011, RSKangXi=44.14
21CEA CJK UNIFIED IDEOGRAPH-#21CEA, IRGKangXi=0304.031, RSKangXi=44.15
21CEB CJK UNIFIED IDEOGRAPH-#21CEB, IRGKangXi=0304.031, RSKangXi=44.15
21CEC CJK UNIFIED IDEOGRAPH-#21CEC, IRGKangXi=0304.060, RSKangXi=44.16
21CED CJK UNIFIED IDEOGRAPH-#21CED, IRGKangXi=0304.061, RSKangXi=44.16
21CEE CJK UNIFIED IDEOGRAPH-#21CEE, IRGKangXi=0304.061, RSKangXi=44.16
21CEF CJK UNIFIED IDEOGRAPH-#21CEF, IRGKangXi=0304.061, RSKangXi=44.16
21CF0 CJK UNIFIED IDEOGRAPH-#21CF0, IRGKangXi=0304.061, RSKangXi=44.16
21CF1 CJK UNIFIED IDEOGRAPH-#21CF1, IRGKangXi=0304.061, RSKangXi=44.17
21CF2 CJK UNIFIED IDEOGRAPH-#21CF2, IRGKangXi=0304.061, RSKangXi=44.17
21CF3 CJK UNIFIED IDEOGRAPH-#21CF3, IRGKangXi=0304.061, RSKangXi=44.17
21CF4 CJK UNIFIED IDEOGRAPH-#21CF4, IRGKangXi=0304.061, RSKangXi=44.17
21CF5 CJK UNIFIED IDEOGRAPH-#21CF5, IRGKangXi=0304.071, RSKangXi=44.18
21CF6 CJK UNIFIED IDEOGRAPH-#21CF6, IRGKangXi=0304.071, RSKangXi=44.18
21CF7 CJK UNIFIED IDEOGRAPH-#21CF7, IRGKangXi=0304.071, RSKangXi=44.18
21CF8 CJK UNIFIED IDEOGRAPH-#21CF8, IRGKangXi=0304.080, RSKangXi=44.19
21CF9 CJK UNIFIED IDEOGRAPH-#21CF9, IRGKangXi=0304.081, RSKangXi=44.19
21CFA CJK UNIFIED IDEOGRAPH-#21CFA, IRGKangXi=0304.081, RSKangXi=44.19
21CFB CJK UNIFIED IDEOGRAPH-#21CFB, IRGKangXi=0304.091, RSKangXi=44.21
21CFC CJK UNIFIED IDEOGRAPH-#21CFC, IRGKangXi=0304.091, RSKangXi=44.22
21CFD CJK UNIFIED IDEOGRAPH-#21CFD, IRGKangXi=0304.091, RSKangXi=44.22
21CFE CJK UNIFIED IDEOGRAPH-#21CFE, IRGKangXi=0304.140, RSKangXi=45.0
21CFF CJK UNIFIED IDEOGRAPH-#21CFF, IRGKangXi=0304.141, RSKangXi=45.2
21D00 CJK UNIFIED IDEOGRAPH-#21D00, IRGKangXi=0304.141, RSKangXi=45.3
21D01 CJK UNIFIED IDEOGRAPH-#21D01, IRGKangXi=0305.020, RSKangXi=45.3
21D02 CJK UNIFIED IDEOGRAPH-#21D02, IRGKangXi=0305.030, RSKangXi=45.3
21D03 CJK UNIFIED IDEOGRAPH-#21D03, IRGKangXi=0305.031, RSKangXi=45.3
21D04 CJK UNIFIED IDEOGRAPH-#21D04, IRGKangXi=0305.031, RSKangXi=45.3
21D05 CJK UNIFIED IDEOGRAPH-#21D05, IRGKangXi=0305.031, RSKangXi=45.3
21D06 CJK UNIFIED IDEOGRAPH-#21D06, IRGKangXi=0305.050, RSKangXi=45.4
21D07 CJK UNIFIED IDEOGRAPH-#21D07, IRGKangXi=0305.090, RSKangXi=45.4
21D08 CJK UNIFIED IDEOGRAPH-#21D08, IRGKangXi=0305.100, RSKangXi=45.4
21D09 CJK UNIFIED IDEOGRAPH-#21D09, IRGKangXi=0305.101, RSKangXi=45.4
21D0A CJK UNIFIED IDEOGRAPH-#21D0A, IRGKangXi=0305.101, RSKangXi=45.4
21D0B CJK UNIFIED IDEOGRAPH-#21D0B, IRGKangXi=0305.110, RSKangXi=45.5
21D0C CJK UNIFIED IDEOGRAPH-#21D0C, IRGKangXi=0305.120, RSKangXi=45.5
21D0D CJK UNIFIED IDEOGRAPH-#21D0D, IRGKangXi=0305.130, RSKangXi=45.5
21D0E CJK UNIFIED IDEOGRAPH-#21D0E, IRGKangXi=0305.140, RSKangXi=45.6
21D0F CJK UNIFIED IDEOGRAPH-#21D0F, IRGKangXi=0305.150, RSKangXi=45.6
21D10 CJK UNIFIED IDEOGRAPH-#21D10, IRGKangXi=0305.160, RSKangXi=45.6
21D11 CJK UNIFIED IDEOGRAPH-#21D11, IRGKangXi=0305.170, RSKangXi=45.6
21D12 CJK UNIFIED IDEOGRAPH-#21D12, IRGKangXi=0305.171, RSKangXi=45.6
21D13 CJK UNIFIED IDEOGRAPH-#21D13, IRGKangXi=0305.171, RSKangXi=45.6
21D14 CJK UNIFIED IDEOGRAPH-#21D14, IRGKangXi=0305.171, RSKangXi=45.6
21D15 CJK UNIFIED IDEOGRAPH-#21D15, IRGKangXi=0305.180, RSKangXi=45.7
21D16 CJK UNIFIED IDEOGRAPH-#21D16, IRGKangXi=0305.190, RSKangXi=45.7
21D17 CJK UNIFIED IDEOGRAPH-#21D17, IRGKangXi=0305.200, RSKangXi=45.7
21D18 CJK UNIFIED IDEOGRAPH-#21D18, IRGKangXi=0305.210, RSKangXi=45.7
21D19 CJK UNIFIED IDEOGRAPH-#21D19, IRGKangXi=0305.211, RSKangXi=45.7
21D1A CJK UNIFIED IDEOGRAPH-#21D1A, IRGKangXi=0305.211, RSKangXi=45.7
21D1B CJK UNIFIED IDEOGRAPH-#21D1B, IRGKangXi=0305.220, RSKangXi=45.8
21D1C CJK UNIFIED IDEOGRAPH-#21D1C, IRGKangXi=0305.230, RSKangXi=45.8
21D1D CJK UNIFIED IDEOGRAPH-#21D1D, IRGKangXi=0305.240, RSKangXi=45.9
21D1E CJK UNIFIED IDEOGRAPH-#21D1E, IRGKangXi=0305.250, RSKangXi=45.9
21D1F CJK UNIFIED IDEOGRAPH-#21D1F, IRGKangXi=0305.260, RSKangXi=45.9
21D20 CJK UNIFIED IDEOGRAPH-#21D20, IRGKangXi=0305.270, RSKangXi=45.9
21D21 CJK UNIFIED IDEOGRAPH-#21D21, IRGKangXi=0305.280, RSKangXi=45.9
21D22 CJK UNIFIED IDEOGRAPH-#21D22, IRGKangXi=0305.281, RSKangXi=45.9
21D23 CJK UNIFIED IDEOGRAPH-#21D23, IRGKangXi=0305.281, RSKangXi=45.9
21D24 CJK UNIFIED IDEOGRAPH-#21D24, IRGKangXi=0305.290, RSKangXi=45.10
21D25 CJK UNIFIED IDEOGRAPH-#21D25, IRGKangXi=0305.300, RSKangXi=45.10
21D26 CJK UNIFIED IDEOGRAPH-#21D26, IRGKangXi=0305.310, RSKangXi=45.12
21D27 CJK UNIFIED IDEOGRAPH-#21D27, IRGKangXi=0305.320, RSKangXi=45.12
21D28 CJK UNIFIED IDEOGRAPH-#21D28, IRGKangXi=0305.330, RSKangXi=45.12
21D29 CJK UNIFIED IDEOGRAPH-#21D29, IRGKangXi=0305.340, RSKangXi=45.12
21D2A CJK UNIFIED IDEOGRAPH-#21D2A, IRGKangXi=0305.350, RSKangXi=45.15
21D2B CJK UNIFIED IDEOGRAPH-#21D2B, IRGKangXi=0305.351, RSKangXi=45.18
21D2C CJK UNIFIED IDEOGRAPH-#21D2C, IRGKangXi=0305.360, RSKangXi=45.19
21D2D CJK UNIFIED IDEOGRAPH-#21D2D, IRGKangXi=0307.020, RSKangXi=46.1
21D2E CJK UNIFIED IDEOGRAPH-#21D2E, IRGKangXi=0307.021, RSKangXi=46.1
21D2F CJK UNIFIED IDEOGRAPH-#21D2F, IRGKangXi=0307.021, RSKangXi=46.1
21D30 CJK UNIFIED IDEOGRAPH-#21D30, IRGKangXi=0307.080, RSKangXi=46.2
21D31 CJK UNIFIED IDEOGRAPH-#21D31, IRGKangXi=0307.100, RSKangXi=46.2
21D32 CJK UNIFIED IDEOGRAPH-#21D32, IRGKangXi=0307.120, RSKangXi=46.2
21D33 CJK UNIFIED IDEOGRAPH-#21D33, IRGKangXi=0307.130, RSKangXi=46.2
21D34 CJK UNIFIED IDEOGRAPH-#21D34, IRGKangXi=0307.131, RSKangXi=46.2
21D35 CJK UNIFIED IDEOGRAPH-#21D35, IRGKangXi=0307.131, RSKangXi=46.2
21D36 CJK UNIFIED IDEOGRAPH-#21D36, IRGKangXi=0307.131, RSKangXi=46.2
21D37 CJK UNIFIED IDEOGRAPH-#21D37, IRGKangXi=0307.131, RSKangXi=46.2
21D38 CJK UNIFIED IDEOGRAPH-#21D38, IRGKangXi=0307.131, RSKangXi=46.2
21D39 CJK UNIFIED IDEOGRAPH-#21D39, IRGKangXi=0307.131, RSKangXi=46.2
21D3A CJK UNIFIED IDEOGRAPH-#21D3A, IRGKangXi=0307.131, RSKangXi=46.2
21D3B CJK UNIFIED IDEOGRAPH-#21D3B, IRGKangXi=0307.131, RSKangXi=46.2
21D3C CJK UNIFIED IDEOGRAPH-#21D3C, IRGKangXi=0307.131, RSKangXi=46.2
21D3D CJK UNIFIED IDEOGRAPH-#21D3D, IRGKangXi=0307.131, RSKangXi=46.2
21D3E CJK UNIFIED IDEOGRAPH-#21D3E, IRGKangXi=0307.170, RSKangXi=46.3
21D3F CJK UNIFIED IDEOGRAPH-#21D3F, IRGKangXi=0307.210, RSKangXi=46.3
21D40 CJK UNIFIED IDEOGRAPH-#21D40, IRGKangXi=0307.250, RSKangXi=46.3
21D41 CJK UNIFIED IDEOGRAPH-#21D41, IRGKangXi=0307.270, RSKangXi=46.3
21D42 CJK UNIFIED IDEOGRAPH-#21D42, IRGKangXi=0307.271, RSKangXi=46.3
21D43 CJK UNIFIED IDEOGRAPH-#21D43, IRGKangXi=0307.271, RSKangXi=46.3
21D44 CJK UNIFIED IDEOGRAPH-#21D44, IRGKangXi=0307.271, RSKangXi=46.3
21D45 CJK UNIFIED IDEOGRAPH-#21D45, IRGKangXi=0307.271, RSKangXi=46.3
21D46 CJK UNIFIED IDEOGRAPH-#21D46, IRGKangXi=0307.271, RSKangXi=46.3
21D47 CJK UNIFIED IDEOGRAPH-#21D47, IRGKangXi=0307.271, RSKangXi=46.3
21D48 CJK UNIFIED IDEOGRAPH-#21D48, IRGKangXi=0307.271, RSKangXi=46.3
21D49 CJK UNIFIED IDEOGRAPH-#21D49, IRGKangXi=0307.271, RSKangXi=46.3
21D4A CJK UNIFIED IDEOGRAPH-#21D4A, IRGKangXi=0307.271, RSKangXi=46.3
21D4B CJK UNIFIED IDEOGRAPH-#21D4B, IRGKangXi=0307.271, RSKangXi=46.3
21D4C CJK UNIFIED IDEOGRAPH-#21D4C, IRGKangXi=0307.271, RSKangXi=46.3
21D4D CJK UNIFIED IDEOGRAPH-#21D4D, IRGKangXi=0307.271, RSKangXi=46.3
21D4E CJK UNIFIED IDEOGRAPH-#21D4E, IRGKangXi=0307.271, RSKangXi=46.3
21D4F CJK UNIFIED IDEOGRAPH-#21D4F, IRGKangXi=0307.271, RSKangXi=46.3
21D50 CJK UNIFIED IDEOGRAPH-#21D50, IRGKangXi=0307.271, RSKangXi=46.3
21D51 CJK UNIFIED IDEOGRAPH-#21D51, IRGKangXi=0307.271, RSKangXi=46.3
21D52 CJK UNIFIED IDEOGRAPH-#21D52, IRGKangXi=0307.271, RSKangXi=46.3
21D53 CJK UNIFIED IDEOGRAPH-#21D53, IRGKangXi=0307.280, RSKangXi=46.4
21D54 CJK UNIFIED IDEOGRAPH-#21D54, IRGKangXi=0307.300, RSKangXi=46.4
21D55 CJK UNIFIED IDEOGRAPH-#21D55, IRGKangXi=0307.310, RSKangXi=46.4
21D56 CJK UNIFIED IDEOGRAPH-#21D56, IRGKangXi=0308.030, RSKangXi=46.4
21D57 CJK UNIFIED IDEOGRAPH-#21D57, IRGKangXi=0308.070, RSKangXi=46.4
21D58 CJK UNIFIED IDEOGRAPH-#21D58, IRGKangXi=0308.080, RSKangXi=46.4
21D59 CJK UNIFIED IDEOGRAPH-#21D59, IRGKangXi=0308.090, RSKangXi=46.4
21D5A CJK UNIFIED IDEOGRAPH-#21D5A, IRGKangXi=0308.130, RSKangXi=46.4
21D5B CJK UNIFIED IDEOGRAPH-#21D5B, IRGKangXi=0308.150, RSKangXi=46.4
21D5C CJK UNIFIED IDEOGRAPH-#21D5C, IRGKangXi=0308.220, RSKangXi=46.4
21D5D CJK UNIFIED IDEOGRAPH-#21D5D, IRGKangXi=0308.310, RSKangXi=46.4
21D5E CJK UNIFIED IDEOGRAPH-#21D5E, IRGKangXi=0308.320, RSKangXi=46.4
21D5F CJK UNIFIED IDEOGRAPH-#21D5F, IRGKangXi=0308.331, RSKangXi=46.4
21D60 CJK UNIFIED IDEOGRAPH-#21D60, IRGKangXi=0308.331, RSKangXi=46.4
21D61 CJK UNIFIED IDEOGRAPH-#21D61, IRGKangXi=0308.331, RSKangXi=46.4
21D62 CJK UNIFIED IDEOGRAPH-#21D62, IRGKangXi=0308.331, RSKangXi=46.4
21D63 CJK UNIFIED IDEOGRAPH-#21D63, IRGKangXi=0308.331, RSKangXi=46.4
21D64 CJK UNIFIED IDEOGRAPH-#21D64, IRGKangXi=0308.331, RSKangXi=46.4
21D65 CJK UNIFIED IDEOGRAPH-#21D65, IRGKangXi=0308.331, RSKangXi=46.4
21D66 CJK UNIFIED IDEOGRAPH-#21D66, IRGKangXi=0308.331, RSKangXi=46.4
21D67 CJK UNIFIED IDEOGRAPH-#21D67, IRGKangXi=0308.331, RSKangXi=46.4
21D68 CJK UNIFIED IDEOGRAPH-#21D68, IRGKangXi=0308.331, RSKangXi=46.4
21D69 CJK UNIFIED IDEOGRAPH-#21D69, IRGKangXi=0308.331, RSKangXi=46.4
21D6A CJK UNIFIED IDEOGRAPH-#21D6A, IRGKangXi=0308.331, RSKangXi=46.4
21D6B CJK UNIFIED IDEOGRAPH-#21D6B, IRGKangXi=0308.331, RSKangXi=46.4
21D6C CJK UNIFIED IDEOGRAPH-#21D6C, IRGKangXi=0308.331, RSKangXi=46.4
21D6D CJK UNIFIED IDEOGRAPH-#21D6D, IRGKangXi=0308.331, RSKangXi=46.4
21D6E CJK UNIFIED IDEOGRAPH-#21D6E, IRGKangXi=0308.331, RSKangXi=46.4
21D6F CJK UNIFIED IDEOGRAPH-#21D6F, IRGKangXi=0308.331, RSKangXi=46.4
21D70 CJK UNIFIED IDEOGRAPH-#21D70, IRGKangXi=0308.331, RSKangXi=46.4
21D71 CJK UNIFIED IDEOGRAPH-#21D71, IRGKangXi=0308.331, RSKangXi=46.4
21D72 CJK UNIFIED IDEOGRAPH-#21D72, IRGKangXi=0308.331, RSKangXi=46.4
21D73 CJK UNIFIED IDEOGRAPH-#21D73, IRGKangXi=0308.331, RSKangXi=46.4
21D74 CJK UNIFIED IDEOGRAPH-#21D74, IRGKangXi=0308.331, RSKangXi=46.4
21D75 CJK UNIFIED IDEOGRAPH-#21D75, IRGKangXi=0308.331, RSKangXi=46.4
21D76 CJK UNIFIED IDEOGRAPH-#21D76, IRGKangXi=0308.331, RSKangXi=46.4
21D77 CJK UNIFIED IDEOGRAPH-#21D77, IRGKangXi=0308.331, RSKangXi=46.4
21D78 CJK UNIFIED IDEOGRAPH-#21D78, IRGKangXi=0308.331, RSKangXi=46.4
21D79 CJK UNIFIED IDEOGRAPH-#21D79, IRGKangXi=0308.331, RSKangXi=46.4
21D7A CJK UNIFIED IDEOGRAPH-#21D7A, IRGKangXi=0308.331, RSKangXi=46.4
21D7B CJK UNIFIED IDEOGRAPH-#21D7B, IRGKangXi=0308.331, RSKangXi=46.4
21D7C CJK UNIFIED IDEOGRAPH-#21D7C, IRGKangXi=0308.331, RSKangXi=46.4
21D7D CJK UNIFIED IDEOGRAPH-#21D7D, IRGKangXi=0308.331, RSKangXi=46.4
21D7E CJK UNIFIED IDEOGRAPH-#21D7E, IRGKangXi=0308.331, RSKangXi=46.4
21D7F CJK UNIFIED IDEOGRAPH-#21D7F, IRGKangXi=0308.331, RSKangXi=46.4
21D80 CJK UNIFIED IDEOGRAPH-#21D80, IRGKangXi=0308.331, RSKangXi=46.4
21D81 CJK UNIFIED IDEOGRAPH-#21D81, IRGKangXi=0308.331, RSKangXi=46.4
21D82 CJK UNIFIED IDEOGRAPH-#21D82, IRGKangXi=0308.331, RSKangXi=46.4
21D83 CJK UNIFIED IDEOGRAPH-#21D83, IRGKangXi=0308.370, RSKangXi=46.5
21D84 CJK UNIFIED IDEOGRAPH-#21D84, IRGKangXi=0308.410, RSKangXi=46.5
21D85 CJK UNIFIED IDEOGRAPH-#21D85, IRGKangXi=0308.420, RSKangXi=46.5
21D86 CJK UNIFIED IDEOGRAPH-#21D86, IRGKangXi=0308.430, RSKangXi=46.5
21D87 CJK UNIFIED IDEOGRAPH-#21D87, IRGKangXi=0308.440, RSKangXi=46.5
21D88 CJK UNIFIED IDEOGRAPH-#21D88, IRGKangXi=0309.010, RSKangXi=46.5
21D89 CJK UNIFIED IDEOGRAPH-#21D89, IRGKangXi=0309.050, RSKangXi=46.5
21D8A CJK UNIFIED IDEOGRAPH-#21D8A, IRGKangXi=0309.100, RSKangXi=46.5
21D8B CJK UNIFIED IDEOGRAPH-#21D8B, IRGKangXi=0309.130, RSKangXi=46.5
21D8C CJK UNIFIED IDEOGRAPH-#21D8C, IRGKangXi=0309.150, RSKangXi=46.5
21D8D CJK UNIFIED IDEOGRAPH-#21D8D, IRGKangXi=0309.170, RSKangXi=46.5
21D8E CJK UNIFIED IDEOGRAPH-#21D8E, IRGKangXi=0309.200, RSKangXi=46.5
21D8F CJK UNIFIED IDEOGRAPH-#21D8F, IRGKangXi=0309.290, RSKangXi=46.5
21D90 CJK UNIFIED IDEOGRAPH-#21D90, IRGKangXi=0309.340, RSKangXi=46.5
21D91 CJK UNIFIED IDEOGRAPH-#21D91, IRGKangXi=0310.020, RSKangXi=46.5
21D92 CJK UNIFIED IDEOGRAPH-#21D92, IRGKangXi=0310.060, RSKangXi=46.5
21D93 CJK UNIFIED IDEOGRAPH-#21D93, IRGKangXi=0310.070, RSKangXi=46.5
21D94 CJK UNIFIED IDEOGRAPH-#21D94, IRGKangXi=0310.071, RSKangXi=46.5
21D95 CJK UNIFIED IDEOGRAPH-#21D95, IRGKangXi=0310.071, RSKangXi=46.5
21D96 CJK UNIFIED IDEOGRAPH-#21D96, IRGKangXi=0310.071, RSKangXi=46.5
21D97 CJK UNIFIED IDEOGRAPH-#21D97, IRGKangXi=0310.071, RSKangXi=46.5
21D98 CJK UNIFIED IDEOGRAPH-#21D98, IRGKangXi=0310.071, RSKangXi=46.5
21D99 CJK UNIFIED IDEOGRAPH-#21D99, IRGKangXi=0310.071, RSKangXi=46.5
21D9A CJK UNIFIED IDEOGRAPH-#21D9A, IRGKangXi=0310.071, RSKangXi=46.5
21D9B CJK UNIFIED IDEOGRAPH-#21D9B, IRGKangXi=0310.071, RSKangXi=46.5
21D9C CJK UNIFIED IDEOGRAPH-#21D9C, IRGKangXi=0310.071, RSKangXi=46.5
21D9D CJK UNIFIED IDEOGRAPH-#21D9D, IRGKangXi=0310.071, RSKangXi=46.5
21D9E CJK UNIFIED IDEOGRAPH-#21D9E, IRGKangXi=0310.071, RSKangXi=46.5
21D9F CJK UNIFIED IDEOGRAPH-#21D9F, IRGKangXi=0310.071, RSKangXi=46.5
21DA0 CJK UNIFIED IDEOGRAPH-#21DA0, IRGKangXi=0310.071, RSKangXi=46.5
21DA1 CJK UNIFIED IDEOGRAPH-#21DA1, IRGKangXi=0310.071, RSKangXi=46.5
21DA2 CJK UNIFIED IDEOGRAPH-#21DA2, IRGKangXi=0310.071, RSKangXi=46.5
21DA3 CJK UNIFIED IDEOGRAPH-#21DA3, IRGKangXi=0310.071, RSKangXi=46.5
21DA4 CJK UNIFIED IDEOGRAPH-#21DA4, IRGKangXi=0310.071, RSKangXi=101.3
21DA5 CJK UNIFIED IDEOGRAPH-#21DA5, IRGKangXi=0310.071, RSKangXi=46.5
21DA6 CJK UNIFIED IDEOGRAPH-#21DA6, IRGKangXi=0310.071, RSKangXi=46.5
21DA7 CJK UNIFIED IDEOGRAPH-#21DA7, IRGKangXi=0310.071, RSKangXi=46.5
21DA8 CJK UNIFIED IDEOGRAPH-#21DA8, IRGKangXi=0310.071, RSKangXi=46.5
21DA9 CJK UNIFIED IDEOGRAPH-#21DA9, IRGKangXi=0310.071, RSKangXi=46.5
21DAA CJK UNIFIED IDEOGRAPH-#21DAA, IRGKangXi=0310.071, RSKangXi=46.5
21DAB CJK UNIFIED IDEOGRAPH-#21DAB, IRGKangXi=0310.130, RSKangXi=46.6
21DAC CJK UNIFIED IDEOGRAPH-#21DAC, IRGKangXi=0310.140, RSKangXi=46.6
21DAD CJK UNIFIED IDEOGRAPH-#21DAD, IRGKangXi=0310.150, RSKangXi=46.6
21DAE CJK UNIFIED IDEOGRAPH-#21DAE, IRGKangXi=0310.190, RSKangXi=46.6
21DAF CJK UNIFIED IDEOGRAPH-#21DAF, IRGKangXi=0310.240, RSKangXi=46.6
21DB0 CJK UNIFIED IDEOGRAPH-#21DB0, IRGKangXi=0310.300, RSKangXi=46.6
21DB1 CJK UNIFIED IDEOGRAPH-#21DB1, IRGKangXi=0310.310, RSKangXi=46.6
21DB2 CJK UNIFIED IDEOGRAPH-#21DB2, IRGKangXi=0310.320, RSKangXi=46.6
21DB3 CJK UNIFIED IDEOGRAPH-#21DB3, IRGKangXi=0310.340, RSKangXi=46.6
21DB4 CJK UNIFIED IDEOGRAPH-#21DB4, IRGKangXi=0311.061, RSKangXi=46.6
21DB5 CJK UNIFIED IDEOGRAPH-#21DB5, IRGKangXi=0311.061, RSKangXi=46.6
21DB6 CJK UNIFIED IDEOGRAPH-#21DB6, IRGKangXi=0311.061, RSKangXi=46.6
21DB7 CJK UNIFIED IDEOGRAPH-#21DB7, IRGKangXi=0311.061, RSKangXi=46.6
21DB8 CJK UNIFIED IDEOGRAPH-#21DB8, IRGKangXi=0311.061, RSKangXi=46.6
21DB9 CJK UNIFIED IDEOGRAPH-#21DB9, IRGKangXi=0311.061, RSKangXi=46.6
21DBA CJK UNIFIED IDEOGRAPH-#21DBA, IRGKangXi=0311.061, RSKangXi=46.6
21DBB CJK UNIFIED IDEOGRAPH-#21DBB, IRGKangXi=0311.061, RSKangXi=46.6
21DBC CJK UNIFIED IDEOGRAPH-#21DBC, IRGKangXi=0311.061, RSKangXi=46.6
21DBD CJK UNIFIED IDEOGRAPH-#21DBD, IRGKangXi=0311.061, RSKangXi=46.6
21DBE CJK UNIFIED IDEOGRAPH-#21DBE, IRGKangXi=0311.061, RSKangXi=46.6
21DBF CJK UNIFIED IDEOGRAPH-#21DBF, IRGKangXi=0311.061, RSKangXi=46.6
21DC0 CJK UNIFIED IDEOGRAPH-#21DC0, IRGKangXi=0311.061, RSKangXi=46.6
21DC1 CJK UNIFIED IDEOGRAPH-#21DC1, IRGKangXi=0311.061, RSKangXi=46.6
21DC2 CJK UNIFIED IDEOGRAPH-#21DC2, IRGKangXi=0311.061, RSKangXi=46.6
21DC3 CJK UNIFIED IDEOGRAPH-#21DC3, IRGKangXi=0311.061, RSKangXi=46.6
21DC4 CJK UNIFIED IDEOGRAPH-#21DC4, IRGKangXi=0311.061, RSKangXi=46.6
21DC5 CJK UNIFIED IDEOGRAPH-#21DC5, IRGKangXi=0311.061, RSKangXi=46.6
21DC6 CJK UNIFIED IDEOGRAPH-#21DC6, IRGKangXi=0311.061, RSKangXi=46.6
21DC7 CJK UNIFIED IDEOGRAPH-#21DC7, IRGKangXi=0311.061, RSKangXi=46.6
21DC8 CJK UNIFIED IDEOGRAPH-#21DC8, IRGKangXi=0311.061, RSKangXi=46.6
21DC9 CJK UNIFIED IDEOGRAPH-#21DC9, IRGKangXi=0311.061, RSKangXi=46.6
21DCA CJK UNIFIED IDEOGRAPH-#21DCA, IRGKangXi=0311.061, RSKangXi=46.6
21DCB CJK UNIFIED IDEOGRAPH-#21DCB, IRGKangXi=0311.061, RSKangXi=46.6
21DCC CJK UNIFIED IDEOGRAPH-#21DCC, IRGKangXi=0311.061, RSKangXi=46.6
21DCD CJK UNIFIED IDEOGRAPH-#21DCD, IRGKangXi=0311.061, RSKangXi=46.6
21DCE CJK UNIFIED IDEOGRAPH-#21DCE, IRGKangXi=0311.061, RSKangXi=46.6
21DCF CJK UNIFIED IDEOGRAPH-#21DCF, IRGKangXi=0311.061, RSKangXi=46.6
21DD0 CJK UNIFIED IDEOGRAPH-#21DD0, IRGKangXi=0311.061, RSKangXi=46.6
21DD1 CJK UNIFIED IDEOGRAPH-#21DD1, IRGKangXi=0311.061, RSKangXi=46.6
21DD2 CJK UNIFIED IDEOGRAPH-#21DD2, IRGKangXi=0311.061, RSKangXi=46.6
21DD3 CJK UNIFIED IDEOGRAPH-#21DD3, IRGKangXi=0311.061, RSKangXi=46.6
21DD4 CJK UNIFIED IDEOGRAPH-#21DD4, IRGKangXi=0311.061, RSKangXi=46.6
21DD5 CJK UNIFIED IDEOGRAPH-#21DD5, IRGKangXi=0311.080, RSKangXi=46.7
21DD6 CJK UNIFIED IDEOGRAPH-#21DD6, IRGKangXi=0311.120, RSKangXi=46.7
21DD7 CJK UNIFIED IDEOGRAPH-#21DD7, IRGKangXi=0311.130, RSKangXi=46.7
21DD8 CJK UNIFIED IDEOGRAPH-#21DD8, IRGKangXi=0311.140, RSKangXi=46.7
21DD9 CJK UNIFIED IDEOGRAPH-#21DD9, IRGKangXi=0311.150, RSKangXi=46.7
21DDA CJK UNIFIED IDEOGRAPH-#21DDA, IRGKangXi=0311.170, RSKangXi=46.7
21DDB CJK UNIFIED IDEOGRAPH-#21DDB, IRGKangXi=0311.180, RSKangXi=46.7
21DDC CJK UNIFIED IDEOGRAPH-#21DDC, IRGKangXi=0311.190, RSKangXi=46.7
21DDD CJK UNIFIED IDEOGRAPH-#21DDD, IRGKangXi=0311.200, RSKangXi=46.7
21DDE CJK UNIFIED IDEOGRAPH-#21DDE, IRGKangXi=0311.260, RSKangXi=46.7
21DDF CJK UNIFIED IDEOGRAPH-#21DDF, IRGKangXi=0311.280, RSKangXi=46.7
21DE0 CJK UNIFIED IDEOGRAPH-#21DE0, IRGKangXi=0311.350, RSKangXi=46.7
21DE1 CJK UNIFIED IDEOGRAPH-#21DE1, IRGKangXi=0311.370, RSKangXi=46.7
21DE2 CJK UNIFIED IDEOGRAPH-#21DE2, IRGKangXi=0311.390, RSKangXi=46.7
21DE3 CJK UNIFIED IDEOGRAPH-#21DE3, IRGKangXi=0312.090, RSKangXi=46.7
21DE4 CJK UNIFIED IDEOGRAPH-#21DE4, IRGKangXi=0312.100, RSKangXi=46.7
21DE5 CJK UNIFIED IDEOGRAPH-#21DE5, IRGKangXi=0312.130, RSKangXi=46.7
21DE6 CJK UNIFIED IDEOGRAPH-#21DE6, IRGKangXi=0312.150, RSKangXi=46.7
21DE7 CJK UNIFIED IDEOGRAPH-#21DE7, IRGKangXi=0312.160, RSKangXi=46.7
21DE8 CJK UNIFIED IDEOGRAPH-#21DE8, IRGKangXi=0312.200, RSKangXi=46.7
21DE9 CJK UNIFIED IDEOGRAPH-#21DE9, IRGKangXi=0312.230, RSKangXi=46.7
21DEA CJK UNIFIED IDEOGRAPH-#21DEA, IRGKangXi=0312.250, RSKangXi=46.7
21DEB CJK UNIFIED IDEOGRAPH-#21DEB, IRGKangXi=0312.270, RSKangXi=46.7
21DEC CJK UNIFIED IDEOGRAPH-#21DEC, IRGKangXi=0312.280, RSKangXi=46.7
21DED CJK UNIFIED IDEOGRAPH-#21DED, IRGKangXi=0312.290, RSKangXi=46.7
21DEE CJK UNIFIED IDEOGRAPH-#21DEE, IRGKangXi=0312.300, RSKangXi=46.7
21DEF CJK UNIFIED IDEOGRAPH-#21DEF, IRGKangXi=0312.301, RSKangXi=46.7
21DF0 CJK UNIFIED IDEOGRAPH-#21DF0, IRGKangXi=0312.301, RSKangXi=46.7
21DF1 CJK UNIFIED IDEOGRAPH-#21DF1, IRGKangXi=0312.301, RSKangXi=46.7
21DF2 CJK UNIFIED IDEOGRAPH-#21DF2, IRGKangXi=0312.301, RSKangXi=46.7
21DF3 CJK UNIFIED IDEOGRAPH-#21DF3, IRGKangXi=0312.301, RSKangXi=46.7
21DF4 CJK UNIFIED IDEOGRAPH-#21DF4, IRGKangXi=0312.301, RSKangXi=46.7
21DF5 CJK UNIFIED IDEOGRAPH-#21DF5, IRGKangXi=0312.301, RSKangXi=46.7
21DF6 CJK UNIFIED IDEOGRAPH-#21DF6, IRGKangXi=0312.301, RSKangXi=46.7
21DF7 CJK UNIFIED IDEOGRAPH-#21DF7, IRGKangXi=0312.301, RSKangXi=46.7
21DF8 CJK UNIFIED IDEOGRAPH-#21DF8, IRGKangXi=0312.301, RSKangXi=46.7
21DF9 CJK UNIFIED IDEOGRAPH-#21DF9, IRGKangXi=0312.301, RSKangXi=46.7
21DFA CJK UNIFIED IDEOGRAPH-#21DFA, IRGKangXi=0312.301, RSKangXi=46.7
21DFB CJK UNIFIED IDEOGRAPH-#21DFB, IRGKangXi=0312.301, RSKangXi=46.7
21DFC CJK UNIFIED IDEOGRAPH-#21DFC, IRGKangXi=0312.301, RSKangXi=46.7
21DFD CJK UNIFIED IDEOGRAPH-#21DFD, IRGKangXi=0312.301, RSKangXi=46.7
21DFE CJK UNIFIED IDEOGRAPH-#21DFE, IRGKangXi=0312.301, RSKangXi=46.7
21DFF CJK UNIFIED IDEOGRAPH-#21DFF, IRGKangXi=0312.301, RSKangXi=46.7
21E00 CJK UNIFIED IDEOGRAPH-#21E00, IRGKangXi=0312.301, RSKangXi=46.7
21E01 CJK UNIFIED IDEOGRAPH-#21E01, IRGKangXi=0312.301, RSKangXi=46.7
21E02 CJK UNIFIED IDEOGRAPH-#21E02, IRGKangXi=0312.301, RSKangXi=46.7
21E03 CJK UNIFIED IDEOGRAPH-#21E03, IRGKangXi=0312.301, RSKangXi=46.7
21E04 CJK UNIFIED IDEOGRAPH-#21E04, IRGKangXi=0312.301, RSKangXi=46.7
21E05 CJK UNIFIED IDEOGRAPH-#21E05, IRGKangXi=0312.301, RSKangXi=46.7
21E06 CJK UNIFIED IDEOGRAPH-#21E06, IRGKangXi=0312.301, RSKangXi=46.7
21E07 CJK UNIFIED IDEOGRAPH-#21E07, IRGKangXi=0312.301, RSKangXi=46.7
21E08 CJK UNIFIED IDEOGRAPH-#21E08, IRGKangXi=0312.301, RSKangXi=46.7
21E09 CJK UNIFIED IDEOGRAPH-#21E09, IRGKangXi=0312.301, RSKangXi=46.7
21E0A CJK UNIFIED IDEOGRAPH-#21E0A, IRGKangXi=0312.301, RSKangXi=46.7
21E0B CJK UNIFIED IDEOGRAPH-#21E0B, IRGKangXi=0312.301, RSKangXi=46.7
21E0C CJK UNIFIED IDEOGRAPH-#21E0C, IRGKangXi=0312.301, RSKangXi=46.7
21E0D CJK UNIFIED IDEOGRAPH-#21E0D, IRGKangXi=0312.301, RSKangXi=46.7
21E0E CJK UNIFIED IDEOGRAPH-#21E0E, IRGKangXi=0312.301, RSKangXi=46.7
21E0F CJK UNIFIED IDEOGRAPH-#21E0F, IRGKangXi=0312.301, RSKangXi=46.7
21E10 CJK UNIFIED IDEOGRAPH-#21E10, IRGKangXi=0312.301, RSKangXi=46.7
21E11 CJK UNIFIED IDEOGRAPH-#21E11, IRGKangXi=0312.340, RSKangXi=46.8
21E12 CJK UNIFIED IDEOGRAPH-#21E12, IRGKangXi=0312.350, RSKangXi=46.8
21E13 CJK UNIFIED IDEOGRAPH-#21E13, IRGKangXi=0312.360, RSKangXi=46.8
21E14 CJK UNIFIED IDEOGRAPH-#21E14, IRGKangXi=0313.040, RSKangXi=46.8
21E15 CJK UNIFIED IDEOGRAPH-#21E15, IRGKangXi=0313.060, RSKangXi=46.8
21E16 CJK UNIFIED IDEOGRAPH-#21E16, IRGKangXi=0313.080, RSKangXi=46.8
21E17 CJK UNIFIED IDEOGRAPH-#21E17, IRGKangXi=0313.120, RSKangXi=46.8
21E18 CJK UNIFIED IDEOGRAPH-#21E18, IRGKangXi=0313.130, RSKangXi=46.8
21E19 CJK UNIFIED IDEOGRAPH-#21E19, IRGKangXi=0313.140, RSKangXi=46.8
21E1A CJK UNIFIED IDEOGRAPH-#21E1A, IRGKangXi=0313.160, RSKangXi=46.8
21E1B CJK UNIFIED IDEOGRAPH-#21E1B, IRGKangXi=0313.210, RSKangXi=46.8
21E1C CJK UNIFIED IDEOGRAPH-#21E1C, IRGKangXi=0314.020, RSKangXi=46.8
21E1D CJK UNIFIED IDEOGRAPH-#21E1D, IRGKangXi=0314.040, RSKangXi=46.8
21E1E CJK UNIFIED IDEOGRAPH-#21E1E, IRGKangXi=0314.090, RSKangXi=46.8
21E1F CJK UNIFIED IDEOGRAPH-#21E1F, IRGKangXi=0314.160, RSKangXi=46.8
21E20 CJK UNIFIED IDEOGRAPH-#21E20, IRGKangXi=0314.170, RSKangXi=46.8
21E21 CJK UNIFIED IDEOGRAPH-#21E21, IRGKangXi=0314.200, RSKangXi=46.8
21E22 CJK UNIFIED IDEOGRAPH-#21E22, IRGKangXi=0314.210, RSKangXi=46.8
21E23 CJK UNIFIED IDEOGRAPH-#21E23, IRGKangXi=0314.220, RSKangXi=46.8
21E24 CJK UNIFIED IDEOGRAPH-#21E24, IRGKangXi=0314.230, RSKangXi=46.8
21E25 CJK UNIFIED IDEOGRAPH-#21E25, IRGKangXi=0314.270, RSKangXi=46.8
21E26 CJK UNIFIED IDEOGRAPH-#21E26, IRGKangXi=0314.310, RSKangXi=46.8
21E27 CJK UNIFIED IDEOGRAPH-#21E27, IRGKangXi=0315.050, RSKangXi=46.8
21E28 CJK UNIFIED IDEOGRAPH-#21E28, IRGKangXi=0315.090, RSKangXi=46.8
21E29 CJK UNIFIED IDEOGRAPH-#21E29, IRGKangXi=0315.110, RSKangXi=46.8
21E2A CJK UNIFIED IDEOGRAPH-#21E2A, IRGKangXi=0315.120, RSKangXi=46.8
21E2B CJK UNIFIED IDEOGRAPH-#21E2B, IRGKangXi=0315.130, RSKangXi=46.8
21E2C CJK UNIFIED IDEOGRAPH-#21E2C, IRGKangXi=0315.150, RSKangXi=46.8
21E2D CJK UNIFIED IDEOGRAPH-#21E2D, IRGKangXi=0315.151, RSKangXi=46.8
21E2E CJK UNIFIED IDEOGRAPH-#21E2E, IRGKangXi=0315.151, RSKangXi=46.8
21E2F CJK UNIFIED IDEOGRAPH-#21E2F, IRGKangXi=0315.151, RSKangXi=46.8
21E30 CJK UNIFIED IDEOGRAPH-#21E30, IRGKangXi=0315.151, RSKangXi=46.8
21E31 CJK UNIFIED IDEOGRAPH-#21E31, IRGKangXi=0315.151, RSKangXi=46.8
21E32 CJK UNIFIED IDEOGRAPH-#21E32, IRGKangXi=0315.151, RSKangXi=46.8
21E33 CJK UNIFIED IDEOGRAPH-#21E33, IRGKangXi=0315.151, RSKangXi=46.8
21E34 CJK UNIFIED IDEOGRAPH-#21E34, IRGKangXi=0315.151, RSKangXi=46.8
21E35 CJK UNIFIED IDEOGRAPH-#21E35, IRGKangXi=0315.151, RSKangXi=46.8
21E36 CJK UNIFIED IDEOGRAPH-#21E36, IRGKangXi=0315.151, RSKangXi=46.8
21E37 CJK UNIFIED IDEOGRAPH-#21E37, IRGKangXi=0315.151, RSKangXi=46.8
21E38 CJK UNIFIED IDEOGRAPH-#21E38, IRGKangXi=0315.151, RSKangXi=46.8
21E39 CJK UNIFIED IDEOGRAPH-#21E39, IRGKangXi=0315.151, RSKangXi=46.8
21E3A CJK UNIFIED IDEOGRAPH-#21E3A, IRGKangXi=0315.151, RSKangXi=46.8
21E3B CJK UNIFIED IDEOGRAPH-#21E3B, IRGKangXi=0315.151, RSKangXi=46.8
21E3C CJK UNIFIED IDEOGRAPH-#21E3C, IRGKangXi=0315.151, RSKangXi=46.8
21E3D CJK UNIFIED IDEOGRAPH-#21E3D, IRGKangXi=0315.151, RSKangXi=46.8
21E3E CJK UNIFIED IDEOGRAPH-#21E3E, IRGKangXi=0315.151, RSKangXi=46.8
21E3F CJK UNIFIED IDEOGRAPH-#21E3F, IRGKangXi=0315.151, RSKangXi=46.8
21E40 CJK UNIFIED IDEOGRAPH-#21E40, IRGKangXi=0315.151, RSKangXi=46.8
21E41 CJK UNIFIED IDEOGRAPH-#21E41, IRGKangXi=0315.151, RSKangXi=46.8
21E42 CJK UNIFIED IDEOGRAPH-#21E42, IRGKangXi=0315.151, RSKangXi=46.8
21E43 CJK UNIFIED IDEOGRAPH-#21E43, IRGKangXi=0315.151, RSKangXi=46.8
21E44 CJK UNIFIED IDEOGRAPH-#21E44, IRGKangXi=0315.151, RSKangXi=46.8
21E45 CJK UNIFIED IDEOGRAPH-#21E45, IRGKangXi=0315.151, RSKangXi=46.8
21E46 CJK UNIFIED IDEOGRAPH-#21E46, IRGKangXi=0315.151, RSKangXi=46.8
21E47 CJK UNIFIED IDEOGRAPH-#21E47, IRGKangXi=0315.151, RSKangXi=46.8
21E48 CJK UNIFIED IDEOGRAPH-#21E48, IRGKangXi=0315.151, RSKangXi=46.8
21E49 CJK UNIFIED IDEOGRAPH-#21E49, IRGKangXi=0315.151, RSKangXi=46.8
21E4A CJK UNIFIED IDEOGRAPH-#21E4A, IRGKangXi=0315.151, RSKangXi=46.8
21E4B CJK UNIFIED IDEOGRAPH-#21E4B, IRGKangXi=0315.151, RSKangXi=46.8
21E4C CJK UNIFIED IDEOGRAPH-#21E4C, IRGKangXi=0315.151, RSKangXi=46.8
21E4D CJK UNIFIED IDEOGRAPH-#21E4D, IRGKangXi=0315.151, RSKangXi=46.8
21E4E CJK UNIFIED IDEOGRAPH-#21E4E, IRGKangXi=0315.151, RSKangXi=46.8
21E4F CJK UNIFIED IDEOGRAPH-#21E4F, IRGKangXi=0315.151, RSKangXi=46.8
21E50 CJK UNIFIED IDEOGRAPH-#21E50, IRGKangXi=0315.151, RSKangXi=46.8
21E51 CJK UNIFIED IDEOGRAPH-#21E51, IRGKangXi=0315.151, RSKangXi=46.8
21E52 CJK UNIFIED IDEOGRAPH-#21E52, IRGKangXi=0315.151, RSKangXi=46.8
21E53 CJK UNIFIED IDEOGRAPH-#21E53, IRGKangXi=0315.151, RSKangXi=46.8
21E54 CJK UNIFIED IDEOGRAPH-#21E54, IRGKangXi=0315.151, RSKangXi=46.8
21E55 CJK UNIFIED IDEOGRAPH-#21E55, IRGKangXi=0315.151, RSKangXi=46.8
21E56 CJK UNIFIED IDEOGRAPH-#21E56, IRGKangXi=0315.151, RSKangXi=46.8
21E57 CJK UNIFIED IDEOGRAPH-#21E57, IRGKangXi=0315.151, RSKangXi=46.8
21E58 CJK UNIFIED IDEOGRAPH-#21E58, IRGKangXi=0315.151, RSKangXi=46.8
21E59 CJK UNIFIED IDEOGRAPH-#21E59, IRGKangXi=0315.151, RSKangXi=46.8
21E5A CJK UNIFIED IDEOGRAPH-#21E5A, IRGKangXi=0315.151, RSKangXi=46.8
21E5B CJK UNIFIED IDEOGRAPH-#21E5B, IRGKangXi=0315.151, RSKangXi=46.8
21E5C CJK UNIFIED IDEOGRAPH-#21E5C, IRGKangXi=0315.151, RSKangXi=46.8
21E5D CJK UNIFIED IDEOGRAPH-#21E5D, IRGKangXi=0315.151, RSKangXi=46.8
21E5E CJK UNIFIED IDEOGRAPH-#21E5E, IRGKangXi=0315.151, RSKangXi=46.8
21E5F CJK UNIFIED IDEOGRAPH-#21E5F, IRGKangXi=0315.151, RSKangXi=46.8
21E60 CJK UNIFIED IDEOGRAPH-#21E60, IRGKangXi=0315.151, RSKangXi=46.8
21E61 CJK UNIFIED IDEOGRAPH-#21E61, IRGKangXi=0315.151, RSKangXi=46.8
21E62 CJK UNIFIED IDEOGRAPH-#21E62, IRGKangXi=0315.151, RSKangXi=46.8
21E63 CJK UNIFIED IDEOGRAPH-#21E63, IRGKangXi=0315.151, RSKangXi=46.8
21E64 CJK UNIFIED IDEOGRAPH-#21E64, IRGKangXi=0315.151, RSKangXi=46.8
21E65 CJK UNIFIED IDEOGRAPH-#21E65, IRGKangXi=0315.151, RSKangXi=46.8
21E66 CJK UNIFIED IDEOGRAPH-#21E66, IRGKangXi=0315.151, RSKangXi=46.8
21E67 CJK UNIFIED IDEOGRAPH-#21E67, IRGKangXi=0315.151, RSKangXi=46.8
21E68 CJK UNIFIED IDEOGRAPH-#21E68, IRGKangXi=0315.151, RSKangXi=46.8
21E69 CJK UNIFIED IDEOGRAPH-#21E69, IRGKangXi=0315.151, RSKangXi=46.8
21E6A CJK UNIFIED IDEOGRAPH-#21E6A, IRGKangXi=0315.170, RSKangXi=46.9
21E6B CJK UNIFIED IDEOGRAPH-#21E6B, IRGKangXi=0315.180, RSKangXi=46.9
21E6C CJK UNIFIED IDEOGRAPH-#21E6C, IRGKangXi=0315.230, RSKangXi=46.9
21E6D CJK UNIFIED IDEOGRAPH-#21E6D, IRGKangXi=0315.250, RSKangXi=46.9
21E6E CJK UNIFIED IDEOGRAPH-#21E6E, IRGKangXi=0315.300, RSKangXi=46.9
21E6F CJK UNIFIED IDEOGRAPH-#21E6F, IRGKangXi=0315.320, RSKangXi=46.9
21E70 CJK UNIFIED IDEOGRAPH-#21E70, IRGKangXi=0315.330, RSKangXi=46.9
21E71 CJK UNIFIED IDEOGRAPH-#21E71, IRGKangXi=0315.380, RSKangXi=46.9
21E72 CJK UNIFIED IDEOGRAPH-#21E72, IRGKangXi=0316.070, RSKangXi=46.9
21E73 CJK UNIFIED IDEOGRAPH-#21E73, IRGKangXi=0316.140, RSKangXi=46.9
21E74 CJK UNIFIED IDEOGRAPH-#21E74, IRGKangXi=0316.150, RSKangXi=46.9
21E75 CJK UNIFIED IDEOGRAPH-#21E75, IRGKangXi=0316.200, RSKangXi=46.9
21E76 CJK UNIFIED IDEOGRAPH-#21E76, IRGKangXi=0316.210, RSKangXi=46.9
21E77 CJK UNIFIED IDEOGRAPH-#21E77, IRGKangXi=0316.230, RSKangXi=46.9
21E78 CJK UNIFIED IDEOGRAPH-#21E78, IRGKangXi=0316.240, RSKangXi=46.9
21E79 CJK UNIFIED IDEOGRAPH-#21E79, IRGKangXi=0316.320, RSKangXi=46.9
21E7A CJK UNIFIED IDEOGRAPH-#21E7A, IRGKangXi=0316.330, RSKangXi=46.9
21E7B CJK UNIFIED IDEOGRAPH-#21E7B, IRGKangXi=0316.340, RSKangXi=46.9
21E7C CJK UNIFIED IDEOGRAPH-#21E7C, IRGKangXi=0316.360, RSKangXi=46.9
21E7D CJK UNIFIED IDEOGRAPH-#21E7D, IRGKangXi=0316.370, RSKangXi=46.9
21E7E CJK UNIFIED IDEOGRAPH-#21E7E, IRGKangXi=0316.380, RSKangXi=46.9
21E7F CJK UNIFIED IDEOGRAPH-#21E7F, IRGKangXi=0316.381, RSKangXi=46.9
21E80 CJK UNIFIED IDEOGRAPH-#21E80, IRGKangXi=0316.381, RSKangXi=46.9
21E81 CJK UNIFIED IDEOGRAPH-#21E81, IRGKangXi=0316.381, RSKangXi=46.9
21E82 CJK UNIFIED IDEOGRAPH-#21E82, IRGKangXi=0316.381, RSKangXi=46.9
21E83 CJK UNIFIED IDEOGRAPH-#21E83, IRGKangXi=0316.381, RSKangXi=46.9
21E84 CJK UNIFIED IDEOGRAPH-#21E84, IRGKangXi=0316.381, RSKangXi=46.9
21E85 CJK UNIFIED IDEOGRAPH-#21E85, IRGKangXi=0316.381, RSKangXi=46.9
21E86 CJK UNIFIED IDEOGRAPH-#21E86, IRGKangXi=0316.381, RSKangXi=46.9
21E87 CJK UNIFIED IDEOGRAPH-#21E87, IRGKangXi=0316.381, RSKangXi=46.9
21E88 CJK UNIFIED IDEOGRAPH-#21E88, IRGKangXi=0316.381, RSKangXi=46.9
21E89 CJK UNIFIED IDEOGRAPH-#21E89, IRGKangXi=0316.381, RSKangXi=46.9
21E8A CJK UNIFIED IDEOGRAPH-#21E8A, IRGKangXi=0316.381, RSKangXi=46.9
21E8B CJK UNIFIED IDEOGRAPH-#21E8B, IRGKangXi=0316.381, RSKangXi=46.9
21E8C CJK UNIFIED IDEOGRAPH-#21E8C, IRGKangXi=0316.381, RSKangXi=46.9
21E8D CJK UNIFIED IDEOGRAPH-#21E8D, IRGKangXi=0316.381, RSKangXi=46.9
21E8E CJK UNIFIED IDEOGRAPH-#21E8E, IRGKangXi=0316.381, RSKangXi=46.9
21E8F CJK UNIFIED IDEOGRAPH-#21E8F, IRGKangXi=0316.381, RSKangXi=46.9
21E90 CJK UNIFIED IDEOGRAPH-#21E90, IRGKangXi=0316.381, RSKangXi=46.9
21E91 CJK UNIFIED IDEOGRAPH-#21E91, IRGKangXi=0316.381, RSKangXi=46.9
21E92 CJK UNIFIED IDEOGRAPH-#21E92, IRGKangXi=0316.381, RSKangXi=46.9
21E93 CJK UNIFIED IDEOGRAPH-#21E93, IRGKangXi=0316.381, RSKangXi=46.9
21E94 CJK UNIFIED IDEOGRAPH-#21E94, IRGKangXi=0316.381, RSKangXi=46.9
21E95 CJK UNIFIED IDEOGRAPH-#21E95, IRGKangXi=0316.381, RSKangXi=46.9
21E96 CJK UNIFIED IDEOGRAPH-#21E96, IRGKangXi=0316.381, RSKangXi=46.9
21E97 CJK UNIFIED IDEOGRAPH-#21E97, IRGKangXi=0316.381, RSKangXi=46.9
21E98 CJK UNIFIED IDEOGRAPH-#21E98, IRGKangXi=0316.381, RSKangXi=46.9
21E99 CJK UNIFIED IDEOGRAPH-#21E99, IRGKangXi=0316.381, RSKangXi=46.9
21E9A CJK UNIFIED IDEOGRAPH-#21E9A, IRGKangXi=0316.381, RSKangXi=46.9
21E9B CJK UNIFIED IDEOGRAPH-#21E9B, IRGKangXi=0316.381, RSKangXi=46.9
21E9C CJK UNIFIED IDEOGRAPH-#21E9C, IRGKangXi=0316.381, RSKangXi=46.9
21E9D CJK UNIFIED IDEOGRAPH-#21E9D, IRGKangXi=0316.381, RSKangXi=46.9
21E9E CJK UNIFIED IDEOGRAPH-#21E9E, IRGKangXi=0316.381, RSKangXi=46.9
21E9F CJK UNIFIED IDEOGRAPH-#21E9F, IRGKangXi=0316.381, RSKangXi=46.9
21EA0 CJK UNIFIED IDEOGRAPH-#21EA0, IRGKangXi=0316.381, RSKangXi=46.9
21EA1 CJK UNIFIED IDEOGRAPH-#21EA1, IRGKangXi=0316.381, RSKangXi=46.9
21EA2 CJK UNIFIED IDEOGRAPH-#21EA2, IRGKangXi=0316.381, RSKangXi=46.9
21EA3 CJK UNIFIED IDEOGRAPH-#21EA3, IRGKangXi=0316.381, RSKangXi=46.9
21EA4 CJK UNIFIED IDEOGRAPH-#21EA4, IRGKangXi=0316.381, RSKangXi=46.9
21EA5 CJK UNIFIED IDEOGRAPH-#21EA5, IRGKangXi=0316.381, RSKangXi=46.9
21EA6 CJK UNIFIED IDEOGRAPH-#21EA6, IRGKangXi=0316.381, RSKangXi=46.9
21EA7 CJK UNIFIED IDEOGRAPH-#21EA7, IRGKangXi=0316.381, RSKangXi=46.9
21EA8 CJK UNIFIED IDEOGRAPH-#21EA8, IRGKangXi=0316.381, RSKangXi=46.9
21EA9 CJK UNIFIED IDEOGRAPH-#21EA9, IRGKangXi=0316.381, RSKangXi=46.9
21EAA CJK UNIFIED IDEOGRAPH-#21EAA, IRGKangXi=0317.010, RSKangXi=46.10
21EAB CJK UNIFIED IDEOGRAPH-#21EAB, IRGKangXi=0317.020, RSKangXi=46.10
21EAC CJK UNIFIED IDEOGRAPH-#21EAC, IRGKangXi=0317.030, RSKangXi=46.10
21EAD CJK UNIFIED IDEOGRAPH-#21EAD, IRGKangXi=0317.040, RSKangXi=46.10
21EAE CJK UNIFIED IDEOGRAPH-#21EAE, IRGKangXi=0317.060, RSKangXi=46.10
21EAF CJK UNIFIED IDEOGRAPH-#21EAF, IRGKangXi=0317.090, RSKangXi=46.10
21EB0 CJK UNIFIED IDEOGRAPH-#21EB0, IRGKangXi=0317.120, RSKangXi=46.10
21EB1 CJK UNIFIED IDEOGRAPH-#21EB1, IRGKangXi=0317.130, RSKangXi=46.10
21EB2 CJK UNIFIED IDEOGRAPH-#21EB2, IRGKangXi=0317.150, RSKangXi=46.10
21EB3 CJK UNIFIED IDEOGRAPH-#21EB3, IRGKangXi=0317.180, RSKangXi=46.10
21EB4 CJK UNIFIED IDEOGRAPH-#21EB4, IRGKangXi=0317.200, RSKangXi=46.10
21EB5 CJK UNIFIED IDEOGRAPH-#21EB5, IRGKangXi=0317.230, RSKangXi=46.10
21EB6 CJK UNIFIED IDEOGRAPH-#21EB6, IRGKangXi=0317.240, RSKangXi=46.10
21EB7 CJK UNIFIED IDEOGRAPH-#21EB7, IRGKangXi=0317.310, RSKangXi=46.10
21EB8 CJK UNIFIED IDEOGRAPH-#21EB8, IRGKangXi=0317.320, RSKangXi=46.10
21EB9 CJK UNIFIED IDEOGRAPH-#21EB9, IRGKangXi=0317.330, RSKangXi=46.10
21EBA CJK UNIFIED IDEOGRAPH-#21EBA, IRGKangXi=0317.370, RSKangXi=46.10
21EBB CJK UNIFIED IDEOGRAPH-#21EBB, IRGKangXi=0317.380, RSKangXi=46.10
21EBC CJK UNIFIED IDEOGRAPH-#21EBC, IRGKangXi=0317.460, RSKangXi=46.10
21EBD CJK UNIFIED IDEOGRAPH-#21EBD, IRGKangXi=0317.470, RSKangXi=46.10
21EBE CJK UNIFIED IDEOGRAPH-#21EBE, IRGKangXi=0317.490, RSKangXi=46.10
21EBF CJK UNIFIED IDEOGRAPH-#21EBF, IRGKangXi=0317.520, RSKangXi=46.10
21EC0 CJK UNIFIED IDEOGRAPH-#21EC0, IRGKangXi=0317.521, RSKangXi=46.10
21EC1 CJK UNIFIED IDEOGRAPH-#21EC1, IRGKangXi=0317.521, RSKangXi=46.10
21EC2 CJK UNIFIED IDEOGRAPH-#21EC2, IRGKangXi=0317.521, RSKangXi=46.10
21EC3 CJK UNIFIED IDEOGRAPH-#21EC3, IRGKangXi=0317.521, RSKangXi=46.10
21EC4 CJK UNIFIED IDEOGRAPH-#21EC4, IRGKangXi=0317.521, RSKangXi=46.10
21EC5 CJK UNIFIED IDEOGRAPH-#21EC5, IRGKangXi=0317.521, RSKangXi=46.10
21EC6 CJK UNIFIED IDEOGRAPH-#21EC6, IRGKangXi=0317.521, RSKangXi=46.10
21EC7 CJK UNIFIED IDEOGRAPH-#21EC7, IRGKangXi=0317.521, RSKangXi=46.10
21EC8 CJK UNIFIED IDEOGRAPH-#21EC8, IRGKangXi=0317.521, RSKangXi=46.10
21EC9 CJK UNIFIED IDEOGRAPH-#21EC9, IRGKangXi=0317.521, RSKangXi=46.10
21ECA CJK UNIFIED IDEOGRAPH-#21ECA, IRGKangXi=0317.521, RSKangXi=46.10
21ECB CJK UNIFIED IDEOGRAPH-#21ECB, IRGKangXi=0317.521, RSKangXi=46.10
21ECC CJK UNIFIED IDEOGRAPH-#21ECC, IRGKangXi=0317.521, RSKangXi=46.10
21ECD CJK UNIFIED IDEOGRAPH-#21ECD, IRGKangXi=0317.521, RSKangXi=46.10
21ECE CJK UNIFIED IDEOGRAPH-#21ECE, IRGKangXi=0317.521, RSKangXi=46.10
21ECF CJK UNIFIED IDEOGRAPH-#21ECF, IRGKangXi=0317.521, RSKangXi=46.10
21ED0 CJK UNIFIED IDEOGRAPH-#21ED0, IRGKangXi=0317.521, RSKangXi=46.10
21ED1 CJK UNIFIED IDEOGRAPH-#21ED1, IRGKangXi=0317.521, RSKangXi=46.10
21ED2 CJK UNIFIED IDEOGRAPH-#21ED2, IRGKangXi=0317.521, RSKangXi=46.10
21ED3 CJK UNIFIED IDEOGRAPH-#21ED3, IRGKangXi=0317.521, RSKangXi=46.10
21ED4 CJK UNIFIED IDEOGRAPH-#21ED4, IRGKangXi=0317.521, RSKangXi=46.10
21ED5 CJK UNIFIED IDEOGRAPH-#21ED5, IRGKangXi=0317.521, RSKangXi=46.10, Def{year of age}
21ED6 CJK UNIFIED IDEOGRAPH-#21ED6, IRGKangXi=0317.521, RSKangXi=46.10
21ED7 CJK UNIFIED IDEOGRAPH-#21ED7, IRGKangXi=0317.521, RSKangXi=46.10
21ED8 CJK UNIFIED IDEOGRAPH-#21ED8, IRGKangXi=0317.530, RSKangXi=46.11
21ED9 CJK UNIFIED IDEOGRAPH-#21ED9, IRGKangXi=0317.540, RSKangXi=46.11
21EDA CJK UNIFIED IDEOGRAPH-#21EDA, IRGKangXi=0318.050, RSKangXi=46.11
21EDB CJK UNIFIED IDEOGRAPH-#21EDB, IRGKangXi=0318.060, RSKangXi=46.11
21EDC CJK UNIFIED IDEOGRAPH-#21EDC, IRGKangXi=0318.100, RSKangXi=46.11
21EDD CJK UNIFIED IDEOGRAPH-#21EDD, IRGKangXi=0318.110, RSKangXi=46.11
21EDE CJK UNIFIED IDEOGRAPH-#21EDE, IRGKangXi=0318.120, RSKangXi=46.11
21EDF CJK UNIFIED IDEOGRAPH-#21EDF, IRGKangXi=0318.130, RSKangXi=46.11
21EE0 CJK UNIFIED IDEOGRAPH-#21EE0, IRGKangXi=0318.140, RSKangXi=46.11
21EE1 CJK UNIFIED IDEOGRAPH-#21EE1, IRGKangXi=0318.150, RSKangXi=46.11
21EE2 CJK UNIFIED IDEOGRAPH-#21EE2, IRGKangXi=0318.170, RSKangXi=46.11
21EE3 CJK UNIFIED IDEOGRAPH-#21EE3, IRGKangXi=0318.190, RSKangXi=46.11
21EE4 CJK UNIFIED IDEOGRAPH-#21EE4, IRGKangXi=0318.210, RSKangXi=46.11
21EE5 CJK UNIFIED IDEOGRAPH-#21EE5, IRGKangXi=0318.220, RSKangXi=46.11
21EE6 CJK UNIFIED IDEOGRAPH-#21EE6, IRGKangXi=0318.230, RSKangXi=46.11
21EE7 CJK UNIFIED IDEOGRAPH-#21EE7, IRGKangXi=0318.240, RSKangXi=46.11
21EE8 CJK UNIFIED IDEOGRAPH-#21EE8, IRGKangXi=0318.340, RSKangXi=46.11
21EE9 CJK UNIFIED IDEOGRAPH-#21EE9, IRGKangXi=0318.350, RSKangXi=46.11
21EEA CJK UNIFIED IDEOGRAPH-#21EEA, IRGKangXi=0318.360, RSKangXi=46.11
21EEB CJK UNIFIED IDEOGRAPH-#21EEB, IRGKangXi=0318.370, RSKangXi=46.11
21EEC CJK UNIFIED IDEOGRAPH-#21EEC, IRGKangXi=0318.380, RSKangXi=46.11
21EED CJK UNIFIED IDEOGRAPH-#21EED, IRGKangXi=0318.420, RSKangXi=46.11
21EEE CJK UNIFIED IDEOGRAPH-#21EEE, IRGKangXi=0319.010, RSKangXi=46.11
21EEF CJK UNIFIED IDEOGRAPH-#21EEF, IRGKangXi=0319.020, RSKangXi=46.11
21EF0 CJK UNIFIED IDEOGRAPH-#21EF0, IRGKangXi=0319.060, RSKangXi=46.11
21EF1 CJK UNIFIED IDEOGRAPH-#21EF1, IRGKangXi=0319.100, RSKangXi=46.11
21EF2 CJK UNIFIED IDEOGRAPH-#21EF2, IRGKangXi=0319.110, RSKangXi=46.11
21EF3 CJK UNIFIED IDEOGRAPH-#21EF3, IRGKangXi=0319.111, RSKangXi=46.11
21EF4 CJK UNIFIED IDEOGRAPH-#21EF4, IRGKangXi=0319.111, RSKangXi=46.11
21EF5 CJK UNIFIED IDEOGRAPH-#21EF5, IRGKangXi=0319.111, RSKangXi=46.11
21EF6 CJK UNIFIED IDEOGRAPH-#21EF6, IRGKangXi=0319.111, RSKangXi=46.11
21EF7 CJK UNIFIED IDEOGRAPH-#21EF7, IRGKangXi=0319.111, RSKangXi=46.11
21EF8 CJK UNIFIED IDEOGRAPH-#21EF8, IRGKangXi=0319.111, RSKangXi=46.11
21EF9 CJK UNIFIED IDEOGRAPH-#21EF9, IRGKangXi=0319.111, RSKangXi=46.11
21EFA CJK UNIFIED IDEOGRAPH-#21EFA, IRGKangXi=0319.111, RSKangXi=46.11
21EFB CJK UNIFIED IDEOGRAPH-#21EFB, IRGKangXi=0319.111, RSKangXi=46.11
21EFC CJK UNIFIED IDEOGRAPH-#21EFC, IRGKangXi=0319.111, RSKangXi=46.11
21EFD CJK UNIFIED IDEOGRAPH-#21EFD, IRGKangXi=0319.111, RSKangXi=46.11
21EFE CJK UNIFIED IDEOGRAPH-#21EFE, IRGKangXi=0319.111, RSKangXi=46.11
21EFF CJK UNIFIED IDEOGRAPH-#21EFF, IRGKangXi=0319.111, RSKangXi=46.11
21F00 CJK UNIFIED IDEOGRAPH-#21F00, IRGKangXi=0319.111, RSKangXi=46.11
21F01 CJK UNIFIED IDEOGRAPH-#21F01, IRGKangXi=0319.111, RSKangXi=46.11
21F02 CJK UNIFIED IDEOGRAPH-#21F02, IRGKangXi=0319.111, RSKangXi=46.11
21F03 CJK UNIFIED IDEOGRAPH-#21F03, IRGKangXi=0319.111, RSKangXi=46.11
21F04 CJK UNIFIED IDEOGRAPH-#21F04, IRGKangXi=0319.111, RSKangXi=46.11
21F05 CJK UNIFIED IDEOGRAPH-#21F05, IRGKangXi=0319.111, RSKangXi=46.11
21F06 CJK UNIFIED IDEOGRAPH-#21F06, IRGKangXi=0319.111, RSKangXi=46.11
21F07 CJK UNIFIED IDEOGRAPH-#21F07, IRGKangXi=0319.111, RSKangXi=46.11
21F08 CJK UNIFIED IDEOGRAPH-#21F08, IRGKangXi=0319.111, RSKangXi=46.11
21F09 CJK UNIFIED IDEOGRAPH-#21F09, IRGKangXi=0319.111, RSKangXi=46.11
21F0A CJK UNIFIED IDEOGRAPH-#21F0A, IRGKangXi=0319.150, RSKangXi=46.12
21F0B CJK UNIFIED IDEOGRAPH-#21F0B, IRGKangXi=0319.180, RSKangXi=46.12
21F0C CJK UNIFIED IDEOGRAPH-#21F0C, IRGKangXi=0319.200, RSKangXi=46.12
21F0D CJK UNIFIED IDEOGRAPH-#21F0D, IRGKangXi=0319.210, RSKangXi=46.12
21F0E CJK UNIFIED IDEOGRAPH-#21F0E, IRGKangXi=0319.220, RSKangXi=46.12
21F0F CJK UNIFIED IDEOGRAPH-#21F0F, IRGKangXi=0319.230, RSKangXi=46.12
21F10 CJK UNIFIED IDEOGRAPH-#21F10, IRGKangXi=0319.240, RSKangXi=46.12
21F11 CJK UNIFIED IDEOGRAPH-#21F11, IRGKangXi=0319.280, RSKangXi=46.12
21F12 CJK UNIFIED IDEOGRAPH-#21F12, IRGKangXi=0319.300, RSKangXi=46.12
21F13 CJK UNIFIED IDEOGRAPH-#21F13, IRGKangXi=0319.330, RSKangXi=46.12
21F14 CJK UNIFIED IDEOGRAPH-#21F14, IRGKangXi=0319.340, RSKangXi=46.12
21F15 CJK UNIFIED IDEOGRAPH-#21F15, IRGKangXi=0319.370, RSKangXi=46.12
21F16 CJK UNIFIED IDEOGRAPH-#21F16, IRGKangXi=0319.390, RSKangXi=46.12
21F17 CJK UNIFIED IDEOGRAPH-#21F17, IRGKangXi=0319.480, RSKangXi=46.12
21F18 CJK UNIFIED IDEOGRAPH-#21F18, IRGKangXi=0320.030, RSKangXi=46.12
21F19 CJK UNIFIED IDEOGRAPH-#21F19, IRGKangXi=0320.040, RSKangXi=46.12
21F1A CJK UNIFIED IDEOGRAPH-#21F1A, IRGKangXi=0320.050, RSKangXi=46.12
21F1B CJK UNIFIED IDEOGRAPH-#21F1B, IRGKangXi=0320.110, RSKangXi=46.12
21F1C CJK UNIFIED IDEOGRAPH-#21F1C, IRGKangXi=0320.120, RSKangXi=46.12
21F1D CJK UNIFIED IDEOGRAPH-#21F1D, IRGKangXi=0320.130, RSKangXi=46.12
21F1E CJK UNIFIED IDEOGRAPH-#21F1E, IRGKangXi=0320.131, RSKangXi=46.12
21F1F CJK UNIFIED IDEOGRAPH-#21F1F, IRGKangXi=0320.131, RSKangXi=46.12
21F20 CJK UNIFIED IDEOGRAPH-#21F20, IRGKangXi=0320.131, RSKangXi=46.12
21F21 CJK UNIFIED IDEOGRAPH-#21F21, IRGKangXi=0320.131, RSKangXi=46.12
21F22 CJK UNIFIED IDEOGRAPH-#21F22, IRGKangXi=0320.131, RSKangXi=46.12
21F23 CJK UNIFIED IDEOGRAPH-#21F23, IRGKangXi=0320.131, RSKangXi=46.12
21F24 CJK UNIFIED IDEOGRAPH-#21F24, IRGKangXi=0320.131, RSKangXi=46.12
21F25 CJK UNIFIED IDEOGRAPH-#21F25, IRGKangXi=0320.131, RSKangXi=46.12
21F26 CJK UNIFIED IDEOGRAPH-#21F26, IRGKangXi=0320.131, RSKangXi=46.12
21F27 CJK UNIFIED IDEOGRAPH-#21F27, IRGKangXi=0320.131, RSKangXi=46.12
21F28 CJK UNIFIED IDEOGRAPH-#21F28, IRGKangXi=0320.131, RSKangXi=46.12
21F29 CJK UNIFIED IDEOGRAPH-#21F29, IRGKangXi=0320.131, RSKangXi=46.12
21F2A CJK UNIFIED IDEOGRAPH-#21F2A, IRGKangXi=0320.131, RSKangXi=46.12
21F2B CJK UNIFIED IDEOGRAPH-#21F2B, IRGKangXi=0320.131, RSKangXi=46.12
21F2C CJK UNIFIED IDEOGRAPH-#21F2C, IRGKangXi=0320.131, RSKangXi=46.12
21F2D CJK UNIFIED IDEOGRAPH-#21F2D, IRGKangXi=0320.131, RSKangXi=46.12
21F2E CJK UNIFIED IDEOGRAPH-#21F2E, IRGKangXi=0320.131, RSKangXi=46.12
21F2F CJK UNIFIED IDEOGRAPH-#21F2F, IRGKangXi=0320.131, RSKangXi=46.12
21F30 CJK UNIFIED IDEOGRAPH-#21F30, IRGKangXi=0320.131, RSKangXi=46.12
21F31 CJK UNIFIED IDEOGRAPH-#21F31, IRGKangXi=0320.131, RSKangXi=46.12
21F32 CJK UNIFIED IDEOGRAPH-#21F32, IRGKangXi=0320.131, RSKangXi=46.12
21F33 CJK UNIFIED IDEOGRAPH-#21F33, IRGKangXi=0320.131, RSKangXi=46.12
21F34 CJK UNIFIED IDEOGRAPH-#21F34, IRGKangXi=0320.131, RSKangXi=46.12
21F35 CJK UNIFIED IDEOGRAPH-#21F35, IRGKangXi=0320.131, RSKangXi=46.12
21F36 CJK UNIFIED IDEOGRAPH-#21F36, IRGKangXi=0320.131, RSKangXi=46.12
21F37 CJK UNIFIED IDEOGRAPH-#21F37, IRGKangXi=0320.131, RSKangXi=46.12
21F38 CJK UNIFIED IDEOGRAPH-#21F38, IRGKangXi=0320.131, RSKangXi=46.12
21F39 CJK UNIFIED IDEOGRAPH-#21F39, IRGKangXi=0320.131, RSKangXi=46.12
21F3A CJK UNIFIED IDEOGRAPH-#21F3A, IRGKangXi=0320.131, RSKangXi=46.12
21F3B CJK UNIFIED IDEOGRAPH-#21F3B, IRGKangXi=0320.131, RSKangXi=46.12
21F3C CJK UNIFIED IDEOGRAPH-#21F3C, IRGKangXi=0320.131, RSKangXi=46.12
21F3D CJK UNIFIED IDEOGRAPH-#21F3D, IRGKangXi=0320.170, RSKangXi=46.13
21F3E CJK UNIFIED IDEOGRAPH-#21F3E, IRGKangXi=0320.210, RSKangXi=46.13
21F3F CJK UNIFIED IDEOGRAPH-#21F3F, IRGKangXi=0320.220, RSKangXi=46.13
21F40 CJK UNIFIED IDEOGRAPH-#21F40, IRGKangXi=0320.240, RSKangXi=46.13
21F41 CJK UNIFIED IDEOGRAPH-#21F41, IRGKangXi=0320.270, RSKangXi=46.13
21F42 CJK UNIFIED IDEOGRAPH-#21F42, IRGKangXi=0320.290, RSKangXi=46.13
21F43 CJK UNIFIED IDEOGRAPH-#21F43, IRGKangXi=0320.300, RSKangXi=46.13
21F44 CJK UNIFIED IDEOGRAPH-#21F44, IRGKangXi=0320.340, RSKangXi=46.13
21F45 CJK UNIFIED IDEOGRAPH-#21F45, IRGKangXi=0320.350, RSKangXi=46.13
21F46 CJK UNIFIED IDEOGRAPH-#21F46, IRGKangXi=0320.360, RSKangXi=46.13
21F47 CJK UNIFIED IDEOGRAPH-#21F47, IRGKangXi=0321.010, RSKangXi=46.13
21F48 CJK UNIFIED IDEOGRAPH-#21F48, IRGKangXi=0321.020, RSKangXi=46.13
21F49 CJK UNIFIED IDEOGRAPH-#21F49, IRGKangXi=0321.040, RSKangXi=46.14
21F4A CJK UNIFIED IDEOGRAPH-#21F4A, IRGKangXi=0321.060, RSKangXi=46.13
21F4B CJK UNIFIED IDEOGRAPH-#21F4B, IRGKangXi=0321.081, RSKangXi=46.13
21F4C CJK UNIFIED IDEOGRAPH-#21F4C, IRGKangXi=0321.081, RSKangXi=46.13
21F4D CJK UNIFIED IDEOGRAPH-#21F4D, IRGKangXi=0321.081, RSKangXi=46.13
21F4E CJK UNIFIED IDEOGRAPH-#21F4E, IRGKangXi=0321.081, RSKangXi=46.13
21F4F CJK UNIFIED IDEOGRAPH-#21F4F, IRGKangXi=0321.081, RSKangXi=46.13
21F50 CJK UNIFIED IDEOGRAPH-#21F50, IRGKangXi=0321.081, RSKangXi=46.13
21F51 CJK UNIFIED IDEOGRAPH-#21F51, IRGKangXi=0321.081, RSKangXi=46.13
21F52 CJK UNIFIED IDEOGRAPH-#21F52, IRGKangXi=0321.081, RSKangXi=46.13
21F53 CJK UNIFIED IDEOGRAPH-#21F53, IRGKangXi=0321.081, RSKangXi=46.13
21F54 CJK UNIFIED IDEOGRAPH-#21F54, IRGKangXi=0321.081, RSKangXi=46.13
21F55 CJK UNIFIED IDEOGRAPH-#21F55, IRGKangXi=0321.081, RSKangXi=46.13
21F56 CJK UNIFIED IDEOGRAPH-#21F56, IRGKangXi=0321.081, RSKangXi=46.13
21F57 CJK UNIFIED IDEOGRAPH-#21F57, IRGKangXi=0321.081, RSKangXi=46.13
21F58 CJK UNIFIED IDEOGRAPH-#21F58, IRGKangXi=0321.081, RSKangXi=46.13
21F59 CJK UNIFIED IDEOGRAPH-#21F59, IRGKangXi=0321.081, RSKangXi=46.13
21F5A CJK UNIFIED IDEOGRAPH-#21F5A, IRGKangXi=0321.081, RSKangXi=46.13
21F5B CJK UNIFIED IDEOGRAPH-#21F5B, IRGKangXi=0321.081, RSKangXi=46.13
21F5C CJK UNIFIED IDEOGRAPH-#21F5C, IRGKangXi=0321.110, RSKangXi=46.14
21F5D CJK UNIFIED IDEOGRAPH-#21F5D, IRGKangXi=0321.140, RSKangXi=46.14
21F5E CJK UNIFIED IDEOGRAPH-#21F5E, IRGKangXi=0321.150, RSKangXi=46.14
21F5F CJK UNIFIED IDEOGRAPH-#21F5F, IRGKangXi=0321.160, RSKangXi=46.14
21F60 CJK UNIFIED IDEOGRAPH-#21F60, IRGKangXi=0321.190, RSKangXi=46.14
21F61 CJK UNIFIED IDEOGRAPH-#21F61, IRGKangXi=0321.200, RSKangXi=46.14
21F62 CJK UNIFIED IDEOGRAPH-#21F62, IRGKangXi=0321.220, RSKangXi=46.14
21F63 CJK UNIFIED IDEOGRAPH-#21F63, IRGKangXi=0321.240, RSKangXi=46.14
21F64 CJK UNIFIED IDEOGRAPH-#21F64, IRGKangXi=0321.260, RSKangXi=46.14
21F65 CJK UNIFIED IDEOGRAPH-#21F65, IRGKangXi=0321.340, RSKangXi=46.14
21F66 CJK UNIFIED IDEOGRAPH-#21F66, IRGKangXi=0321.350, RSKangXi=46.14
21F67 CJK UNIFIED IDEOGRAPH-#21F67, IRGKangXi=0321.360, RSKangXi=46.14
21F68 CJK UNIFIED IDEOGRAPH-#21F68, IRGKangXi=0321.361, RSKangXi=46.14
21F69 CJK UNIFIED IDEOGRAPH-#21F69, IRGKangXi=0321.361, RSKangXi=46.14
21F6A CJK UNIFIED IDEOGRAPH-#21F6A, IRGKangXi=0321.361, RSKangXi=46.14
21F6B CJK UNIFIED IDEOGRAPH-#21F6B, IRGKangXi=0321.361, RSKangXi=46.14
21F6C CJK UNIFIED IDEOGRAPH-#21F6C, IRGKangXi=0321.361, RSKangXi=46.14
21F6D CJK UNIFIED IDEOGRAPH-#21F6D, IRGKangXi=0321.361, RSKangXi=46.14
21F6E CJK UNIFIED IDEOGRAPH-#21F6E, IRGKangXi=0321.361, RSKangXi=46.14
21F6F CJK UNIFIED IDEOGRAPH-#21F6F, IRGKangXi=0321.361, RSKangXi=46.14
21F70 CJK UNIFIED IDEOGRAPH-#21F70, IRGKangXi=0321.361, RSKangXi=46.14
21F71 CJK UNIFIED IDEOGRAPH-#21F71, IRGKangXi=0321.361, RSKangXi=46.14, Def{a high hill; the name of a hill}
21F72 CJK UNIFIED IDEOGRAPH-#21F72, IRGKangXi=0321.361, RSKangXi=46.14
21F73 CJK UNIFIED IDEOGRAPH-#21F73, IRGKangXi=0321.361, RSKangXi=46.14
21F74 CJK UNIFIED IDEOGRAPH-#21F74, IRGKangXi=0321.361, RSKangXi=46.14
21F75 CJK UNIFIED IDEOGRAPH-#21F75, IRGKangXi=0321.361, RSKangXi=46.14
21F76 CJK UNIFIED IDEOGRAPH-#21F76, IRGKangXi=0321.361, RSKangXi=46.14
21F77 CJK UNIFIED IDEOGRAPH-#21F77, IRGKangXi=0321.361, RSKangXi=46.14
21F78 CJK UNIFIED IDEOGRAPH-#21F78, IRGKangXi=0321.361, RSKangXi=46.14
21F79 CJK UNIFIED IDEOGRAPH-#21F79, IRGKangXi=0321.361, RSKangXi=46.14
21F7A CJK UNIFIED IDEOGRAPH-#21F7A, IRGKangXi=0321.361, RSKangXi=46.14
21F7B CJK UNIFIED IDEOGRAPH-#21F7B, IRGKangXi=0321.361, RSKangXi=46.14
21F7C CJK UNIFIED IDEOGRAPH-#21F7C, IRGKangXi=0321.361, RSKangXi=46.14
21F7D CJK UNIFIED IDEOGRAPH-#21F7D, IRGKangXi=0321.361, RSKangXi=46.14
21F7E CJK UNIFIED IDEOGRAPH-#21F7E, IRGKangXi=0321.361, RSKangXi=46.14
21F7F CJK UNIFIED IDEOGRAPH-#21F7F, IRGKangXi=0321.361, RSKangXi=46.14
21F80 CJK UNIFIED IDEOGRAPH-#21F80, IRGKangXi=0321.361, RSKangXi=46.14
21F81 CJK UNIFIED IDEOGRAPH-#21F81, IRGKangXi=0321.361, RSKangXi=46.14
21F82 CJK UNIFIED IDEOGRAPH-#21F82, IRGKangXi=0321.380, RSKangXi=46.15
21F83 CJK UNIFIED IDEOGRAPH-#21F83, IRGKangXi=0321.390, RSKangXi=46.15
21F84 CJK UNIFIED IDEOGRAPH-#21F84, IRGKangXi=0321.400, RSKangXi=46.15
21F85 CJK UNIFIED IDEOGRAPH-#21F85, IRGKangXi=0321.410, RSKangXi=46.15
21F86 CJK UNIFIED IDEOGRAPH-#21F86, IRGKangXi=0321.420, RSKangXi=46.15
21F87 CJK UNIFIED IDEOGRAPH-#21F87, IRGKangXi=0321.430, RSKangXi=46.15
21F88 CJK UNIFIED IDEOGRAPH-#21F88, IRGKangXi=0321.440, RSKangXi=46.15
21F89 CJK UNIFIED IDEOGRAPH-#21F89, IRGKangXi=0322.010, RSKangXi=46.15
21F8A CJK UNIFIED IDEOGRAPH-#21F8A, IRGKangXi=0322.030, RSKangXi=46.15
21F8B CJK UNIFIED IDEOGRAPH-#21F8B, IRGKangXi=0322.040, RSKangXi=46.15
21F8C CJK UNIFIED IDEOGRAPH-#21F8C, IRGKangXi=0322.050, RSKangXi=46.15
21F8D CJK UNIFIED IDEOGRAPH-#21F8D, IRGKangXi=0322.060, RSKangXi=46.15
21F8E CJK UNIFIED IDEOGRAPH-#21F8E, IRGKangXi=0322.061, RSKangXi=46.15
21F8F CJK UNIFIED IDEOGRAPH-#21F8F, IRGKangXi=0322.061, RSKangXi=46.15
21F90 CJK UNIFIED IDEOGRAPH-#21F90, IRGKangXi=0322.061, RSKangXi=46.15
21F91 CJK UNIFIED IDEOGRAPH-#21F91, IRGKangXi=0322.061, RSKangXi=46.15
21F92 CJK UNIFIED IDEOGRAPH-#21F92, IRGKangXi=0322.061, RSKangXi=46.15
21F93 CJK UNIFIED IDEOGRAPH-#21F93, IRGKangXi=0322.061, RSKangXi=46.15
21F94 CJK UNIFIED IDEOGRAPH-#21F94, IRGKangXi=0322.061, RSKangXi=46.15
21F95 CJK UNIFIED IDEOGRAPH-#21F95, IRGKangXi=0322.061, RSKangXi=46.15
21F96 CJK UNIFIED IDEOGRAPH-#21F96, IRGKangXi=0322.061, RSKangXi=46.15
21F97 CJK UNIFIED IDEOGRAPH-#21F97, IRGKangXi=0322.061, RSKangXi=37.15
21F98 CJK UNIFIED IDEOGRAPH-#21F98, IRGKangXi=0322.070, RSKangXi=46.16
21F99 CJK UNIFIED IDEOGRAPH-#21F99, IRGKangXi=0322.100, RSKangXi=46.16
21F9A CJK UNIFIED IDEOGRAPH-#21F9A, IRGKangXi=0322.110, RSKangXi=46.16
21F9B CJK UNIFIED IDEOGRAPH-#21F9B, IRGKangXi=0322.120, RSKangXi=46.16
21F9C CJK UNIFIED IDEOGRAPH-#21F9C, IRGKangXi=0322.130, RSKangXi=46.16
21F9D CJK UNIFIED IDEOGRAPH-#21F9D, IRGKangXi=0322.160, RSKangXi=46.16
21F9E CJK UNIFIED IDEOGRAPH-#21F9E, IRGKangXi=0322.170, RSKangXi=46.16
21F9F CJK UNIFIED IDEOGRAPH-#21F9F, IRGKangXi=0322.180, RSKangXi=46.16
21FA0 CJK UNIFIED IDEOGRAPH-#21FA0, IRGKangXi=0322.181, RSKangXi=46.15
21FA1 CJK UNIFIED IDEOGRAPH-#21FA1, IRGKangXi=0322.181, RSKangXi=46.16
21FA2 CJK UNIFIED IDEOGRAPH-#21FA2, IRGKangXi=0322.181, RSKangXi=46.16
21FA3 CJK UNIFIED IDEOGRAPH-#21FA3, IRGKangXi=0322.181, RSKangXi=46.16
21FA4 CJK UNIFIED IDEOGRAPH-#21FA4, IRGKangXi=0322.181, RSKangXi=46.16
21FA5 CJK UNIFIED IDEOGRAPH-#21FA5, IRGKangXi=0322.181, RSKangXi=46.16
21FA6 CJK UNIFIED IDEOGRAPH-#21FA6, IRGKangXi=0322.181, RSKangXi=46.16
21FA7 CJK UNIFIED IDEOGRAPH-#21FA7, IRGKangXi=0322.181, RSKangXi=46.16
21FA8 CJK UNIFIED IDEOGRAPH-#21FA8, IRGKangXi=0322.181, RSKangXi=46.16
21FA9 CJK UNIFIED IDEOGRAPH-#21FA9, IRGKangXi=0322.181, RSKangXi=46.16
21FAA CJK UNIFIED IDEOGRAPH-#21FAA, IRGKangXi=0322.181, RSKangXi=46.16
21FAB CJK UNIFIED IDEOGRAPH-#21FAB, IRGKangXi=0322.181, RSKangXi=46.16
21FAC CJK UNIFIED IDEOGRAPH-#21FAC, IRGKangXi=0322.181, RSKangXi=46.16
21FAD CJK UNIFIED IDEOGRAPH-#21FAD, IRGKangXi=0322.181, RSKangXi=46.16
21FAE CJK UNIFIED IDEOGRAPH-#21FAE, IRGKangXi=0322.210, RSKangXi=46.17
21FAF CJK UNIFIED IDEOGRAPH-#21FAF, IRGKangXi=0322.220, RSKangXi=46.17
21FB0 CJK UNIFIED IDEOGRAPH-#21FB0, IRGKangXi=0322.250, RSKangXi=46.17
21FB1 CJK UNIFIED IDEOGRAPH-#21FB1, IRGKangXi=0322.260, RSKangXi=46.17
21FB2 CJK UNIFIED IDEOGRAPH-#21FB2, IRGKangXi=0322.290, RSKangXi=46.17
21FB3 CJK UNIFIED IDEOGRAPH-#21FB3, IRGKangXi=0322.291, RSKangXi=46.17
21FB4 CJK UNIFIED IDEOGRAPH-#21FB4, IRGKangXi=0322.291, RSKangXi=46.17
21FB5 CJK UNIFIED IDEOGRAPH-#21FB5, IRGKangXi=0322.291, RSKangXi=46.17
21FB6 CJK UNIFIED IDEOGRAPH-#21FB6, IRGKangXi=0322.291, RSKangXi=46.17
21FB7 CJK UNIFIED IDEOGRAPH-#21FB7, IRGKangXi=0322.291, RSKangXi=46.17
21FB8 CJK UNIFIED IDEOGRAPH-#21FB8, IRGKangXi=0322.291, RSKangXi=46.17
21FB9 CJK UNIFIED IDEOGRAPH-#21FB9, IRGKangXi=0322.291, RSKangXi=46.17
21FBA CJK UNIFIED IDEOGRAPH-#21FBA, IRGKangXi=0322.291, RSKangXi=46.17
21FBB CJK UNIFIED IDEOGRAPH-#21FBB, IRGKangXi=0322.310, RSKangXi=46.14
21FBC CJK UNIFIED IDEOGRAPH-#21FBC, IRGKangXi=0322.330, RSKangXi=46.18
21FBD CJK UNIFIED IDEOGRAPH-#21FBD, IRGKangXi=0322.380, RSKangXi=46.18
21FBE CJK UNIFIED IDEOGRAPH-#21FBE, IRGKangXi=0322.390, RSKangXi=46.18
21FBF CJK UNIFIED IDEOGRAPH-#21FBF, IRGKangXi=0322.391, RSKangXi=46.18
21FC0 CJK UNIFIED IDEOGRAPH-#21FC0, IRGKangXi=0322.391, RSKangXi=46.18
21FC1 CJK UNIFIED IDEOGRAPH-#21FC1, IRGKangXi=0322.391, RSKangXi=46.18
21FC2 CJK UNIFIED IDEOGRAPH-#21FC2, IRGKangXi=0322.391, RSKangXi=46.18
21FC3 CJK UNIFIED IDEOGRAPH-#21FC3, IRGKangXi=0322.391, RSKangXi=46.18
21FC4 CJK UNIFIED IDEOGRAPH-#21FC4, IRGKangXi=0322.391, RSKangXi=46.18
21FC5 CJK UNIFIED IDEOGRAPH-#21FC5, IRGKangXi=0322.391, RSKangXi=46.18
21FC6 CJK UNIFIED IDEOGRAPH-#21FC6, IRGKangXi=0322.391, RSKangXi=46.18
21FC7 CJK UNIFIED IDEOGRAPH-#21FC7, IRGKangXi=0322.400, RSKangXi=46.19
21FC8 CJK UNIFIED IDEOGRAPH-#21FC8, IRGKangXi=0322.420, RSKangXi=46.19
21FC9 CJK UNIFIED IDEOGRAPH-#21FC9, IRGKangXi=0323.010, RSKangXi=46.19
21FCA CJK UNIFIED IDEOGRAPH-#21FCA, IRGKangXi=0323.020, RSKangXi=46.19
21FCB CJK UNIFIED IDEOGRAPH-#21FCB, IRGKangXi=0323.030, RSKangXi=46.19
21FCC CJK UNIFIED IDEOGRAPH-#21FCC, IRGKangXi=0323.060, RSKangXi=46.19
21FCD CJK UNIFIED IDEOGRAPH-#21FCD, IRGKangXi=0323.061, RSKangXi=46.19
21FCE CJK UNIFIED IDEOGRAPH-#21FCE, IRGKangXi=0323.061, RSKangXi=46.19
21FCF CJK UNIFIED IDEOGRAPH-#21FCF, IRGKangXi=0323.061, RSKangXi=46.19
21FD0 CJK UNIFIED IDEOGRAPH-#21FD0, IRGKangXi=0323.061, RSKangXi=46.19
21FD1 CJK UNIFIED IDEOGRAPH-#21FD1, IRGKangXi=0323.061, RSKangXi=46.19
21FD2 CJK UNIFIED IDEOGRAPH-#21FD2, IRGKangXi=0323.101, RSKangXi=46.20
21FD3 CJK UNIFIED IDEOGRAPH-#21FD3, IRGKangXi=0323.101, RSKangXi=46.20
21FD4 CJK UNIFIED IDEOGRAPH-#21FD4, IRGKangXi=0323.110, RSKangXi=46.21
21FD5 CJK UNIFIED IDEOGRAPH-#21FD5, IRGKangXi=0323.120, RSKangXi=46.21
21FD6 CJK UNIFIED IDEOGRAPH-#21FD6, IRGKangXi=0323.130, RSKangXi=46.21
21FD7 CJK UNIFIED IDEOGRAPH-#21FD7, IRGKangXi=0323.131, RSKangXi=46.21
21FD8 CJK UNIFIED IDEOGRAPH-#21FD8, IRGKangXi=0323.131, RSKangXi=46.21
21FD9 CJK UNIFIED IDEOGRAPH-#21FD9, IRGKangXi=0323.131, RSKangXi=46.21
21FDA CJK UNIFIED IDEOGRAPH-#21FDA, IRGKangXi=0323.131, RSKangXi=46.21
21FDB CJK UNIFIED IDEOGRAPH-#21FDB, IRGKangXi=0323.131, RSKangXi=46.21
21FDC CJK UNIFIED IDEOGRAPH-#21FDC, IRGKangXi=0323.131, RSKangXi=46.21
21FDD CJK UNIFIED IDEOGRAPH-#21FDD, IRGKangXi=0323.140, RSKangXi=46.22
21FDE CJK UNIFIED IDEOGRAPH-#21FDE, IRGKangXi=0323.141, RSKangXi=46.22
21FDF CJK UNIFIED IDEOGRAPH-#21FDF, IRGKangXi=0323.141, RSKangXi=46.22
21FE0 CJK UNIFIED IDEOGRAPH-#21FE0, IRGKangXi=0323.150, RSKangXi=46.24
21FE1 CJK UNIFIED IDEOGRAPH-#21FE1, IRGKangXi=0323.160, RSKangXi=46.24
21FE2 CJK UNIFIED IDEOGRAPH-#21FE2, IRGKangXi=0323.161, RSKangXi=46.25
21FE3 CJK UNIFIED IDEOGRAPH-#21FE3, IRGKangXi=0323.161, RSKangXi=46.24
21FE4 CJK UNIFIED IDEOGRAPH-#21FE4, IRGKangXi=0323.161, RSKangXi=46.24
21FE5 CJK UNIFIED IDEOGRAPH-#21FE5, IRGKangXi=0323.170, RSKangXi=46.29
21FE6 CJK UNIFIED IDEOGRAPH-#21FE6, IRGKangXi=0323.190, RSKangXi=47.0
21FE7 CJK UNIFIED IDEOGRAPH-#21FE7, IRGKangXi=0323.200, RSKangXi=47.1
21FE8 CJK UNIFIED IDEOGRAPH-#21FE8, IRGKangXi=0323.210, RSKangXi=47.-2
21FE9 CJK UNIFIED IDEOGRAPH-#21FE9, IRGKangXi=0323.240, RSKangXi=47.3
21FEA CJK UNIFIED IDEOGRAPH-#21FEA, IRGKangXi=0323.250, RSKangXi=47.3
21FEB CJK UNIFIED IDEOGRAPH-#21FEB, IRGKangXi=0324.061, RSKangXi=47.3
21FEC CJK UNIFIED IDEOGRAPH-#21FEC, IRGKangXi=0324.061, RSKangXi=47.3
21FED CJK UNIFIED IDEOGRAPH-#21FED, IRGKangXi=0324.061, RSKangXi=47.3
21FEE CJK UNIFIED IDEOGRAPH-#21FEE, IRGKangXi=0324.090, RSKangXi=47.4
21FEF CJK UNIFIED IDEOGRAPH-#21FEF, IRGKangXi=0324.100, RSKangXi=47.4
21FF0 CJK UNIFIED IDEOGRAPH-#21FF0, IRGKangXi=0324.111, RSKangXi=47.4
21FF1 CJK UNIFIED IDEOGRAPH-#21FF1, IRGKangXi=0324.120, RSKangXi=47.5
21FF2 CJK UNIFIED IDEOGRAPH-#21FF2, IRGKangXi=0324.121, RSKangXi=47.5
21FF3 CJK UNIFIED IDEOGRAPH-#21FF3, IRGKangXi=0324.121, RSKangXi=47.5
21FF4 CJK UNIFIED IDEOGRAPH-#21FF4, IRGKangXi=0324.121, RSKangXi=47.5
21FF5 CJK UNIFIED IDEOGRAPH-#21FF5, IRGKangXi=0324.121, RSKangXi=47.5
21FF6 CJK UNIFIED IDEOGRAPH-#21FF6, IRGKangXi=0324.121, RSKangXi=47.5
21FF7 CJK UNIFIED IDEOGRAPH-#21FF7, IRGKangXi=0324.130, RSKangXi=47.6
21FF8 CJK UNIFIED IDEOGRAPH-#21FF8, IRGKangXi=0324.140, RSKangXi=47.6
21FF9 CJK UNIFIED IDEOGRAPH-#21FF9, IRGKangXi=0324.150, RSKangXi=47.6
21FFA CJK UNIFIED IDEOGRAPH-#21FFA, IRGKangXi=0324.151, RSKangXi=47.6, Def{brain}
21FFB CJK UNIFIED IDEOGRAPH-#21FFB, IRGKangXi=0324.151, RSKangXi=47.6
21FFC CJK UNIFIED IDEOGRAPH-#21FFC, IRGKangXi=0324.151, RSKangXi=47.7
21FFD CJK UNIFIED IDEOGRAPH-#21FFD, IRGKangXi=0324.151, RSKangXi=47.7
21FFE CJK UNIFIED IDEOGRAPH-#21FFE, IRGKangXi=0324.160, RSKangXi=47.8
21FFF CJK UNIFIED IDEOGRAPH-#21FFF, IRGKangXi=0324.180, RSKangXi=47.8
22000 CJK UNIFIED IDEOGRAPH-#22000, IRGKangXi=0324.181, RSKangXi=47.8
22001 CJK UNIFIED IDEOGRAPH-#22001, IRGKangXi=0324.190, RSKangXi=47.9
22002 CJK UNIFIED IDEOGRAPH-#22002, IRGKangXi=0324.210, RSKangXi=47.11
22003 CJK UNIFIED IDEOGRAPH-#22003, IRGKangXi=0324.221, RSKangXi=47.12
22004 CJK UNIFIED IDEOGRAPH-#22004, IRGKangXi=0324.221, RSKangXi=47.13
22005 CJK UNIFIED IDEOGRAPH-#22005, IRGKangXi=0324.221, RSKangXi=47.13
22006 CJK UNIFIED IDEOGRAPH-#22006, IRGKangXi=0324.221, RSKangXi=47.13
22007 CJK UNIFIED IDEOGRAPH-#22007, IRGKangXi=0324.221, RSKangXi=47.14
22008 CJK UNIFIED IDEOGRAPH-#22008, IRGKangXi=0324.230, RSKangXi=47.15
22009 CJK UNIFIED IDEOGRAPH-#22009, IRGKangXi=0324.240, RSKangXi=47.16
2200A CJK UNIFIED IDEOGRAPH-#2200A, IRGKangXi=0324.241, RSKangXi=47.16
2200B CJK UNIFIED IDEOGRAPH-#2200B, IRGKangXi=0324.241, RSKangXi=47.17
2200C CJK UNIFIED IDEOGRAPH-#2200C, IRGKangXi=0324.241, RSKangXi=47.19
2200D CJK UNIFIED IDEOGRAPH-#2200D, IRGKangXi=0324.241, RSKangXi=47.19
2200E CJK UNIFIED IDEOGRAPH-#2200E, IRGKangXi=0324.241, RSKangXi=47.21
2200F CJK UNIFIED IDEOGRAPH-#2200F, IRGKangXi=0324.241, RSKangXi=47.24
22010 CJK UNIFIED IDEOGRAPH-#22010, IRGKangXi=0324.241, RSKangXi=47.26
22011 CJK UNIFIED IDEOGRAPH-#22011, IRGKangXi=0325.050, RSKangXi=48.1, Def{ancient form of 巨}
22012 CJK UNIFIED IDEOGRAPH-#22012, IRGKangXi=0325.070, RSKangXi=48.1
22013 CJK UNIFIED IDEOGRAPH-#22013, IRGKangXi=0325.071, RSKangXi=48.1
22014 CJK UNIFIED IDEOGRAPH-#22014, IRGKangXi=0325.071, RSKangXi=48.1
22015 CJK UNIFIED IDEOGRAPH-#22015, IRGKangXi=0325.071, RSKangXi=48.1
22016 CJK UNIFIED IDEOGRAPH-#22016, IRGKangXi=0325.151, RSKangXi=48.2
22017 CJK UNIFIED IDEOGRAPH-#22017, IRGKangXi=0325.151, RSKangXi=48.2
22018 CJK UNIFIED IDEOGRAPH-#22018, IRGKangXi=0325.151, RSKangXi=48.2
22019 CJK UNIFIED IDEOGRAPH-#22019, IRGKangXi=0325.151, RSKangXi=48.2
2201A CJK UNIFIED IDEOGRAPH-#2201A, IRGKangXi=0325.170, RSKangXi=48.3
2201B CJK UNIFIED IDEOGRAPH-#2201B, IRGKangXi=0325.171, RSKangXi=48.3
2201C CJK UNIFIED IDEOGRAPH-#2201C, IRGKangXi=0325.180, RSKangXi=48.4
2201D CJK UNIFIED IDEOGRAPH-#2201D, IRGKangXi=0326.010, RSKangXi=48.4
2201E CJK UNIFIED IDEOGRAPH-#2201E, IRGKangXi=0326.011, RSKangXi=48.4
2201F CJK UNIFIED IDEOGRAPH-#2201F, IRGKangXi=0326.011, RSKangXi=48.5
22020 CJK UNIFIED IDEOGRAPH-#22020, IRGKangXi=0326.011, RSKangXi=48.6
22021 CJK UNIFIED IDEOGRAPH-#22021, IRGKangXi=0326.031, RSKangXi=48.7
22022 CJK UNIFIED IDEOGRAPH-#22022, IRGKangXi=0326.031, RSKangXi=48.7
22023 CJK UNIFIED IDEOGRAPH-#22023, IRGKangXi=0326.040, RSKangXi=48.8
22024 CJK UNIFIED IDEOGRAPH-#22024, IRGKangXi=0326.051, RSKangXi=48.9
22025 CJK UNIFIED IDEOGRAPH-#22025, IRGKangXi=0326.051, RSKangXi=48.9
22026 CJK UNIFIED IDEOGRAPH-#22026, IRGKangXi=0326.051, RSKangXi=48.10
22027 CJK UNIFIED IDEOGRAPH-#22027, IRGKangXi=0326.051, RSKangXi=48.10
22028 CJK UNIFIED IDEOGRAPH-#22028, IRGKangXi=0326.051, RSKangXi=48.12
22029 CJK UNIFIED IDEOGRAPH-#22029, IRGKangXi=0326.060, RSKangXi=48.12
2202A CJK UNIFIED IDEOGRAPH-#2202A, IRGKangXi=0326.071, RSKangXi=48.12
2202B CJK UNIFIED IDEOGRAPH-#2202B, IRGKangXi=0326.071, RSKangXi=48.12
2202C CJK UNIFIED IDEOGRAPH-#2202C, IRGKangXi=0326.071, RSKangXi=48.13
2202D CJK UNIFIED IDEOGRAPH-#2202D, IRGKangXi=0326.071, RSKangXi=48.14
2202E CJK UNIFIED IDEOGRAPH-#2202E, IRGKangXi=0326.071, RSKangXi=48.15
2202F CJK UNIFIED IDEOGRAPH-#2202F, IRGKangXi=0326.080, RSKangXi=48.16
22030 CJK UNIFIED IDEOGRAPH-#22030, IRGKangXi=0326.081, RSKangXi=48.18
22031 CJK UNIFIED IDEOGRAPH-#22031, IRGKangXi=0326.081, RSKangXi=48.18
22032 CJK UNIFIED IDEOGRAPH-#22032, IRGKangXi=0326.081, RSKangXi=48.18
22033 CJK UNIFIED IDEOGRAPH-#22033, IRGKangXi=0327.011, RSKangXi=49.1
22034 CJK UNIFIED IDEOGRAPH-#22034, IRGKangXi=0327.020, RSKangXi=49.2
22035 CJK UNIFIED IDEOGRAPH-#22035, IRGKangXi=0327.031, RSKangXi=49.2
22036 CJK UNIFIED IDEOGRAPH-#22036, IRGKangXi=0327.031, RSKangXi=49.3
22037 CJK UNIFIED IDEOGRAPH-#22037, IRGKangXi=0327.060, RSKangXi=49.5
22038 CJK UNIFIED IDEOGRAPH-#22038, IRGKangXi=0327.061, RSKangXi=49.5
22039 CJK UNIFIED IDEOGRAPH-#22039, IRGKangXi=0327.070, RSKangXi=49.6
2203A CJK UNIFIED IDEOGRAPH-#2203A, IRGKangXi=0327.080, RSKangXi=49.6
2203B CJK UNIFIED IDEOGRAPH-#2203B, IRGKangXi=0327.101, RSKangXi=49.6
2203C CJK UNIFIED IDEOGRAPH-#2203C, IRGKangXi=0327.101, RSKangXi=49.7
2203D CJK UNIFIED IDEOGRAPH-#2203D, IRGKangXi=0327.101, RSKangXi=49.7
2203E CJK UNIFIED IDEOGRAPH-#2203E, IRGKangXi=0327.101, RSKangXi=49.7
2203F CJK UNIFIED IDEOGRAPH-#2203F, IRGKangXi=0327.101, RSKangXi=49.7
22040 CJK UNIFIED IDEOGRAPH-#22040, IRGKangXi=0327.120, RSKangXi=49.8
22041 CJK UNIFIED IDEOGRAPH-#22041, IRGKangXi=0327.130, RSKangXi=49.8
22042 CJK UNIFIED IDEOGRAPH-#22042, IRGKangXi=0327.140, RSKangXi=49.8
22043 CJK UNIFIED IDEOGRAPH-#22043, IRGKangXi=0327.150, RSKangXi=49.8
22044 CJK UNIFIED IDEOGRAPH-#22044, IRGKangXi=0327.151, RSKangXi=49.8
22045 CJK UNIFIED IDEOGRAPH-#22045, IRGKangXi=0327.180, RSKangXi=49.9
22046 CJK UNIFIED IDEOGRAPH-#22046, IRGKangXi=0327.181, RSKangXi=49.9
22047 CJK UNIFIED IDEOGRAPH-#22047, IRGKangXi=0327.181, RSKangXi=49.9
22048 CJK UNIFIED IDEOGRAPH-#22048, IRGKangXi=0327.181, RSKangXi=49.9
22049 CJK UNIFIED IDEOGRAPH-#22049, IRGKangXi=0327.181, RSKangXi=49.9
2204A CJK UNIFIED IDEOGRAPH-#2204A, IRGKangXi=0327.181, RSKangXi=49.10
2204B CJK UNIFIED IDEOGRAPH-#2204B, IRGKangXi=0327.181, RSKangXi=49.12
2204C CJK UNIFIED IDEOGRAPH-#2204C, IRGKangXi=0327.181, RSKangXi=49.12
2204D CJK UNIFIED IDEOGRAPH-#2204D, IRGKangXi=0327.181, RSKangXi=49.13
2204E CJK UNIFIED IDEOGRAPH-#2204E, IRGKangXi=0327.181, RSKangXi=49.14
2204F CJK UNIFIED IDEOGRAPH-#2204F, IRGKangXi=0327.181, RSKangXi=49.13
22050 CJK UNIFIED IDEOGRAPH-#22050, IRGKangXi=0327.190, RSKangXi=49.15
22051 CJK UNIFIED IDEOGRAPH-#22051, IRGKangXi=0327.191, RSKangXi=49.17
22052 CJK UNIFIED IDEOGRAPH-#22052, IRGKangXi=0328.040, RSKangXi=50.2
22053 CJK UNIFIED IDEOGRAPH-#22053, IRGKangXi=0328.080, RSKangXi=50.2
22054 CJK UNIFIED IDEOGRAPH-#22054, IRGKangXi=0328.081, RSKangXi=50.2
22055 CJK UNIFIED IDEOGRAPH-#22055, IRGKangXi=0328.100, RSKangXi=50.3
22056 CJK UNIFIED IDEOGRAPH-#22056, IRGKangXi=0328.110, RSKangXi=50.3
22057 CJK UNIFIED IDEOGRAPH-#22057, IRGKangXi=0328.130, RSKangXi=50.3
22058 CJK UNIFIED IDEOGRAPH-#22058, IRGKangXi=0329.010, RSKangXi=50.3
22059 CJK UNIFIED IDEOGRAPH-#22059, IRGKangXi=0329.030, RSKangXi=50.3
2205A CJK UNIFIED IDEOGRAPH-#2205A, IRGKangXi=0329.040, RSKangXi=50.3
2205B CJK UNIFIED IDEOGRAPH-#2205B, IRGKangXi=0329.050, RSKangXi=50.3
2205C CJK UNIFIED IDEOGRAPH-#2205C, IRGKangXi=0329.051, RSKangXi=50.3
2205D CJK UNIFIED IDEOGRAPH-#2205D, IRGKangXi=0329.051, RSKangXi=50.3
2205E CJK UNIFIED IDEOGRAPH-#2205E, IRGKangXi=0329.051, RSKangXi=50.3
2205F CJK UNIFIED IDEOGRAPH-#2205F, IRGKangXi=0329.051, RSKangXi=50.3
22060 CJK UNIFIED IDEOGRAPH-#22060, IRGKangXi=0329.051, RSKangXi=50.3
22061 CJK UNIFIED IDEOGRAPH-#22061, IRGKangXi=0329.051, RSKangXi=50.3
22062 CJK UNIFIED IDEOGRAPH-#22062, IRGKangXi=0329.051, RSKangXi=50.3
22063 CJK UNIFIED IDEOGRAPH-#22063, IRGKangXi=0329.051, RSKangXi=50.3
22064 CJK UNIFIED IDEOGRAPH-#22064, IRGKangXi=0329.051, RSKangXi=50.3
22065 CJK UNIFIED IDEOGRAPH-#22065, IRGKangXi=0329.080, RSKangXi=50.4
22066 CJK UNIFIED IDEOGRAPH-#22066, IRGKangXi=0329.090, RSKangXi=50.4
22067 CJK UNIFIED IDEOGRAPH-#22067, IRGKangXi=0329.100, RSKangXi=50.4
22068 CJK UNIFIED IDEOGRAPH-#22068, IRGKangXi=0329.110, RSKangXi=50.4
22069 CJK UNIFIED IDEOGRAPH-#22069, IRGKangXi=0329.160, RSKangXi=50.4
2206A CJK UNIFIED IDEOGRAPH-#2206A, IRGKangXi=0329.170, RSKangXi=50.4
2206B CJK UNIFIED IDEOGRAPH-#2206B, IRGKangXi=0329.200, RSKangXi=50.4
2206C CJK UNIFIED IDEOGRAPH-#2206C, IRGKangXi=0329.230, RSKangXi=50.4
2206D CJK UNIFIED IDEOGRAPH-#2206D, IRGKangXi=0329.240, RSKangXi=50.4
2206E CJK UNIFIED IDEOGRAPH-#2206E, IRGKangXi=0329.250, RSKangXi=50.4
2206F CJK UNIFIED IDEOGRAPH-#2206F, IRGKangXi=0329.260, RSKangXi=50.4
22070 CJK UNIFIED IDEOGRAPH-#22070, IRGKangXi=0329.280, RSKangXi=50.4
22071 CJK UNIFIED IDEOGRAPH-#22071, IRGKangXi=0329.290, RSKangXi=50.4
22072 CJK UNIFIED IDEOGRAPH-#22072, IRGKangXi=0329.291, RSKangXi=50.4
22073 CJK UNIFIED IDEOGRAPH-#22073, IRGKangXi=0329.291, RSKangXi=50.4
22074 CJK UNIFIED IDEOGRAPH-#22074, IRGKangXi=0329.291, RSKangXi=50.4
22075 CJK UNIFIED IDEOGRAPH-#22075, IRGKangXi=0329.291, RSKangXi=50.4
22076 CJK UNIFIED IDEOGRAPH-#22076, IRGKangXi=0329.291, RSKangXi=50.4
22077 CJK UNIFIED IDEOGRAPH-#22077, IRGKangXi=0329.291, RSKangXi=50.4
22078 CJK UNIFIED IDEOGRAPH-#22078, IRGKangXi=0329.291, RSKangXi=50.4
22079 CJK UNIFIED IDEOGRAPH-#22079, IRGKangXi=0329.291, RSKangXi=50.4
2207A CJK UNIFIED IDEOGRAPH-#2207A, IRGKangXi=0329.291, RSKangXi=50.4
2207B CJK UNIFIED IDEOGRAPH-#2207B, IRGKangXi=0329.320, RSKangXi=50.5
2207C CJK UNIFIED IDEOGRAPH-#2207C, IRGKangXi=0329.330, RSKangXi=50.5
2207D CJK UNIFIED IDEOGRAPH-#2207D, IRGKangXi=0329.350, RSKangXi=50.5
2207E CJK UNIFIED IDEOGRAPH-#2207E, IRGKangXi=0329.360, RSKangXi=50.5
2207F CJK UNIFIED IDEOGRAPH-#2207F, IRGKangXi=0329.370, RSKangXi=50.5
22080 CJK UNIFIED IDEOGRAPH-#22080, IRGKangXi=0329.380, RSKangXi=50.5
22081 CJK UNIFIED IDEOGRAPH-#22081, IRGKangXi=0329.430, RSKangXi=50.5
22082 CJK UNIFIED IDEOGRAPH-#22082, IRGKangXi=0330.080, RSKangXi=50.5
22083 CJK UNIFIED IDEOGRAPH-#22083, IRGKangXi=0330.090, RSKangXi=50.5
22084 CJK UNIFIED IDEOGRAPH-#22084, IRGKangXi=0330.100, RSKangXi=50.5
22085 CJK UNIFIED IDEOGRAPH-#22085, IRGKangXi=0330.110, RSKangXi=50.5
22086 CJK UNIFIED IDEOGRAPH-#22086, IRGKangXi=0330.120, RSKangXi=50.5
22087 CJK UNIFIED IDEOGRAPH-#22087, IRGKangXi=0330.130, RSKangXi=50.5
22088 CJK UNIFIED IDEOGRAPH-#22088, IRGKangXi=0330.131, RSKangXi=50.5
22089 CJK UNIFIED IDEOGRAPH-#22089, IRGKangXi=0330.131, RSKangXi=50.5
2208A CJK UNIFIED IDEOGRAPH-#2208A, IRGKangXi=0330.131, RSKangXi=50.5
2208B CJK UNIFIED IDEOGRAPH-#2208B, IRGKangXi=0330.131, RSKangXi=50.5
2208C CJK UNIFIED IDEOGRAPH-#2208C, IRGKangXi=0330.131, RSKangXi=50.5
2208D CJK UNIFIED IDEOGRAPH-#2208D, IRGKangXi=0330.131, RSKangXi=50.5
2208E CJK UNIFIED IDEOGRAPH-#2208E, IRGKangXi=0330.131, RSKangXi=50.5
2208F CJK UNIFIED IDEOGRAPH-#2208F, IRGKangXi=0330.131, RSKangXi=50.5
22090 CJK UNIFIED IDEOGRAPH-#22090, IRGKangXi=0330.190, RSKangXi=50.6
22091 CJK UNIFIED IDEOGRAPH-#22091, IRGKangXi=0330.200, RSKangXi=50.6, Def{to wipe , rub clean}
22092 CJK UNIFIED IDEOGRAPH-#22092, IRGKangXi=0330.220, RSKangXi=50.6
22093 CJK UNIFIED IDEOGRAPH-#22093, IRGKangXi=0331.070, RSKangXi=50.6
22094 CJK UNIFIED IDEOGRAPH-#22094, IRGKangXi=0331.080, RSKangXi=50.6
22095 CJK UNIFIED IDEOGRAPH-#22095, IRGKangXi=0331.100, RSKangXi=50.6
22096 CJK UNIFIED IDEOGRAPH-#22096, IRGKangXi=0331.150, RSKangXi=50.6
22097 CJK UNIFIED IDEOGRAPH-#22097, IRGKangXi=0331.160, RSKangXi=50.6
22098 CJK UNIFIED IDEOGRAPH-#22098, IRGKangXi=0331.170, RSKangXi=50.6
22099 CJK UNIFIED IDEOGRAPH-#22099, IRGKangXi=0331.180, RSKangXi=50.6
2209A CJK UNIFIED IDEOGRAPH-#2209A, IRGKangXi=0331.190, RSKangXi=50.6
2209B CJK UNIFIED IDEOGRAPH-#2209B, IRGKangXi=0331.191, RSKangXi=50.6
2209C CJK UNIFIED IDEOGRAPH-#2209C, IRGKangXi=0331.191, RSKangXi=50.6
2209D CJK UNIFIED IDEOGRAPH-#2209D, IRGKangXi=0331.191, RSKangXi=50.6
2209E CJK UNIFIED IDEOGRAPH-#2209E, IRGKangXi=0331.191, RSKangXi=50.6
2209F CJK UNIFIED IDEOGRAPH-#2209F, IRGKangXi=0331.191, RSKangXi=50.6
220A0 CJK UNIFIED IDEOGRAPH-#220A0, IRGKangXi=0331.191, RSKangXi=50.6
220A1 CJK UNIFIED IDEOGRAPH-#220A1, IRGKangXi=0331.191, RSKangXi=50.6
220A2 CJK UNIFIED IDEOGRAPH-#220A2, IRGKangXi=0331.191, RSKangXi=50.6
220A3 CJK UNIFIED IDEOGRAPH-#220A3, IRGKangXi=0331.191, RSKangXi=50.6
220A4 CJK UNIFIED IDEOGRAPH-#220A4, IRGKangXi=0331.191, RSKangXi=50.6
220A5 CJK UNIFIED IDEOGRAPH-#220A5, IRGKangXi=0331.191, RSKangXi=50.6
220A6 CJK UNIFIED IDEOGRAPH-#220A6, IRGKangXi=0331.191, RSKangXi=50.6
220A7 CJK UNIFIED IDEOGRAPH-#220A7, IRGKangXi=0331.191, RSKangXi=50.6
220A8 CJK UNIFIED IDEOGRAPH-#220A8, IRGKangXi=0331.191, RSKangXi=50.6
220A9 CJK UNIFIED IDEOGRAPH-#220A9, IRGKangXi=0331.191, RSKangXi=50.6
220AA CJK UNIFIED IDEOGRAPH-#220AA, IRGKangXi=0331.191, RSKangXi=50.6
220AB CJK UNIFIED IDEOGRAPH-#220AB, IRGKangXi=0331.191, RSKangXi=50.6
220AC CJK UNIFIED IDEOGRAPH-#220AC, IRGKangXi=0331.191, RSKangXi=50.6
220AD CJK UNIFIED IDEOGRAPH-#220AD, IRGKangXi=0331.191, RSKangXi=50.6
220AE CJK UNIFIED IDEOGRAPH-#220AE, IRGKangXi=0331.191, RSKangXi=50.6
220AF CJK UNIFIED IDEOGRAPH-#220AF, IRGKangXi=0331.191, RSKangXi=50.6
220B0 CJK UNIFIED IDEOGRAPH-#220B0, IRGKangXi=0331.191, RSKangXi=50.6
220B1 CJK UNIFIED IDEOGRAPH-#220B1, IRGKangXi=0331.210, RSKangXi=50.7
220B2 CJK UNIFIED IDEOGRAPH-#220B2, IRGKangXi=0331.220, RSKangXi=50.7
220B3 CJK UNIFIED IDEOGRAPH-#220B3, IRGKangXi=0331.250, RSKangXi=50.7
220B4 CJK UNIFIED IDEOGRAPH-#220B4, IRGKangXi=0331.260, RSKangXi=50.7
220B5 CJK UNIFIED IDEOGRAPH-#220B5, IRGKangXi=0331.270, RSKangXi=50.7
220B6 CJK UNIFIED IDEOGRAPH-#220B6, IRGKangXi=0331.280, RSKangXi=50.7
220B7 CJK UNIFIED IDEOGRAPH-#220B7, IRGKangXi=0331.300, RSKangXi=50.7
220B8 CJK UNIFIED IDEOGRAPH-#220B8, IRGKangXi=0331.310, RSKangXi=50.7
220B9 CJK UNIFIED IDEOGRAPH-#220B9, IRGKangXi=0331.320, RSKangXi=50.7
220BA CJK UNIFIED IDEOGRAPH-#220BA, IRGKangXi=0331.340, RSKangXi=50.7
220BB CJK UNIFIED IDEOGRAPH-#220BB, IRGKangXi=0332.010, RSKangXi=50.7
220BC CJK UNIFIED IDEOGRAPH-#220BC, IRGKangXi=0332.020, RSKangXi=50.7
220BD CJK UNIFIED IDEOGRAPH-#220BD, IRGKangXi=0332.040, RSKangXi=50.7
220BE CJK UNIFIED IDEOGRAPH-#220BE, IRGKangXi=0332.050, RSKangXi=50.7
220BF CJK UNIFIED IDEOGRAPH-#220BF, IRGKangXi=0332.060, RSKangXi=50.7
220C0 CJK UNIFIED IDEOGRAPH-#220C0, IRGKangXi=0332.070, RSKangXi=50.7
220C1 CJK UNIFIED IDEOGRAPH-#220C1, IRGKangXi=0332.110, RSKangXi=50.7
220C2 CJK UNIFIED IDEOGRAPH-#220C2, IRGKangXi=0332.120, RSKangXi=50.7
220C3 CJK UNIFIED IDEOGRAPH-#220C3, IRGKangXi=0332.121, RSKangXi=50.7
220C4 CJK UNIFIED IDEOGRAPH-#220C4, IRGKangXi=0332.121, RSKangXi=50.7
220C5 CJK UNIFIED IDEOGRAPH-#220C5, IRGKangXi=0332.121, RSKangXi=50.7
220C6 CJK UNIFIED IDEOGRAPH-#220C6, IRGKangXi=0332.121, RSKangXi=50.7
220C7 CJK UNIFIED IDEOGRAPH-#220C7, IRGKangXi=0332.121, RSKangXi=50.7, Def{(Cant.) a sail}
220C8 CJK UNIFIED IDEOGRAPH-#220C8, IRGKangXi=0332.121, RSKangXi=50.7
220C9 CJK UNIFIED IDEOGRAPH-#220C9, IRGKangXi=0332.121, RSKangXi=50.7
220CA CJK UNIFIED IDEOGRAPH-#220CA, IRGKangXi=0332.121, RSKangXi=50.7
220CB CJK UNIFIED IDEOGRAPH-#220CB, IRGKangXi=0332.121, RSKangXi=50.7
220CC CJK UNIFIED IDEOGRAPH-#220CC, IRGKangXi=0332.121, RSKangXi=50.7
220CD CJK UNIFIED IDEOGRAPH-#220CD, IRGKangXi=0332.130, RSKangXi=50.8
220CE CJK UNIFIED IDEOGRAPH-#220CE, IRGKangXi=0332.140, RSKangXi=50.8
220CF CJK UNIFIED IDEOGRAPH-#220CF, IRGKangXi=0332.150, RSKangXi=50.8
220D0 CJK UNIFIED IDEOGRAPH-#220D0, IRGKangXi=0332.160, RSKangXi=50.8
220D1 CJK UNIFIED IDEOGRAPH-#220D1, IRGKangXi=0332.170, RSKangXi=50.8
220D2 CJK UNIFIED IDEOGRAPH-#220D2, IRGKangXi=0332.180, RSKangXi=50.8
220D3 CJK UNIFIED IDEOGRAPH-#220D3, IRGKangXi=0332.210, RSKangXi=50.8
220D4 CJK UNIFIED IDEOGRAPH-#220D4, IRGKangXi=0332.240, RSKangXi=50.8
220D5 CJK UNIFIED IDEOGRAPH-#220D5, IRGKangXi=0333.020, RSKangXi=50.8, Def{a covering, awning, screen}
220D6 CJK UNIFIED IDEOGRAPH-#220D6, IRGKangXi=0333.030, RSKangXi=50.8
220D7 CJK UNIFIED IDEOGRAPH-#220D7, IRGKangXi=0333.040, RSKangXi=50.8
220D8 CJK UNIFIED IDEOGRAPH-#220D8, IRGKangXi=0333.070, RSKangXi=50.8
220D9 CJK UNIFIED IDEOGRAPH-#220D9, IRGKangXi=0333.090, RSKangXi=50.8
220DA CJK UNIFIED IDEOGRAPH-#220DA, IRGKangXi=0333.130, RSKangXi=50.8
220DB CJK UNIFIED IDEOGRAPH-#220DB, IRGKangXi=0333.140, RSKangXi=50.8
220DC CJK UNIFIED IDEOGRAPH-#220DC, IRGKangXi=0333.160, RSKangXi=50.8
220DD CJK UNIFIED IDEOGRAPH-#220DD, IRGKangXi=0333.161, RSKangXi=50.8
220DE CJK UNIFIED IDEOGRAPH-#220DE, IRGKangXi=0333.161, RSKangXi=50.8
220DF CJK UNIFIED IDEOGRAPH-#220DF, IRGKangXi=0333.161, RSKangXi=50.8
220E0 CJK UNIFIED IDEOGRAPH-#220E0, IRGKangXi=0333.161, RSKangXi=50.8
220E1 CJK UNIFIED IDEOGRAPH-#220E1, IRGKangXi=0333.161, RSKangXi=50.8
220E2 CJK UNIFIED IDEOGRAPH-#220E2, IRGKangXi=0333.161, RSKangXi=50.8
220E3 CJK UNIFIED IDEOGRAPH-#220E3, IRGKangXi=0333.161, RSKangXi=50.8
220E4 CJK UNIFIED IDEOGRAPH-#220E4, IRGKangXi=0333.161, RSKangXi=50.8
220E5 CJK UNIFIED IDEOGRAPH-#220E5, IRGKangXi=0333.161, RSKangXi=50.8
220E6 CJK UNIFIED IDEOGRAPH-#220E6, IRGKangXi=0333.161, RSKangXi=50.8
220E7 CJK UNIFIED IDEOGRAPH-#220E7, IRGKangXi=0333.161, RSKangXi=50.8
220E8 CJK UNIFIED IDEOGRAPH-#220E8, IRGKangXi=0333.161, RSKangXi=50.8
220E9 CJK UNIFIED IDEOGRAPH-#220E9, IRGKangXi=0333.161, RSKangXi=50.8
220EA CJK UNIFIED IDEOGRAPH-#220EA, IRGKangXi=0333.161, RSKangXi=50.8
220EB CJK UNIFIED IDEOGRAPH-#220EB, IRGKangXi=0333.180, RSKangXi=50.9
220EC CJK UNIFIED IDEOGRAPH-#220EC, IRGKangXi=0333.200, RSKangXi=50.9
220ED CJK UNIFIED IDEOGRAPH-#220ED, IRGKangXi=0334.010, RSKangXi=50.9
220EE CJK UNIFIED IDEOGRAPH-#220EE, IRGKangXi=0334.020, RSKangXi=50.9
220EF CJK UNIFIED IDEOGRAPH-#220EF, IRGKangXi=0334.040, RSKangXi=50.9
220F0 CJK UNIFIED IDEOGRAPH-#220F0, IRGKangXi=0334.070, RSKangXi=50.9
220F1 CJK UNIFIED IDEOGRAPH-#220F1, IRGKangXi=0334.110, RSKangXi=50.9
220F2 CJK UNIFIED IDEOGRAPH-#220F2, IRGKangXi=0334.120, RSKangXi=50.9
220F3 CJK UNIFIED IDEOGRAPH-#220F3, IRGKangXi=0334.160, RSKangXi=50.9
220F4 CJK UNIFIED IDEOGRAPH-#220F4, IRGKangXi=0334.230, RSKangXi=50.9
220F5 CJK UNIFIED IDEOGRAPH-#220F5, IRGKangXi=0334.240, RSKangXi=50.9
220F6 CJK UNIFIED IDEOGRAPH-#220F6, IRGKangXi=0334.260, RSKangXi=50.9
220F7 CJK UNIFIED IDEOGRAPH-#220F7, IRGKangXi=0334.270, RSKangXi=50.9
220F8 CJK UNIFIED IDEOGRAPH-#220F8, IRGKangXi=0334.280, RSKangXi=50.9
220F9 CJK UNIFIED IDEOGRAPH-#220F9, IRGKangXi=0334.290, RSKangXi=50.9
220FA CJK UNIFIED IDEOGRAPH-#220FA, IRGKangXi=0334.291, RSKangXi=50.9
220FB CJK UNIFIED IDEOGRAPH-#220FB, IRGKangXi=0334.291, RSKangXi=50.9
220FC CJK UNIFIED IDEOGRAPH-#220FC, IRGKangXi=0334.291, RSKangXi=50.9
220FD CJK UNIFIED IDEOGRAPH-#220FD, IRGKangXi=0334.291, RSKangXi=50.9
220FE CJK UNIFIED IDEOGRAPH-#220FE, IRGKangXi=0334.291, RSKangXi=50.9
220FF CJK UNIFIED IDEOGRAPH-#220FF, IRGKangXi=0334.291, RSKangXi=50.9
22100 CJK UNIFIED IDEOGRAPH-#22100, IRGKangXi=0334.291, RSKangXi=50.9
22101 CJK UNIFIED IDEOGRAPH-#22101, IRGKangXi=0334.291, RSKangXi=50.9
22102 CJK UNIFIED IDEOGRAPH-#22102, IRGKangXi=0334.291, RSKangXi=50.9
22103 CJK UNIFIED IDEOGRAPH-#22103, IRGKangXi=0334.291, RSKangXi=50.9
22104 CJK UNIFIED IDEOGRAPH-#22104, IRGKangXi=0334.291, RSKangXi=50.9
22105 CJK UNIFIED IDEOGRAPH-#22105, IRGKangXi=0334.291, RSKangXi=50.9
22106 CJK UNIFIED IDEOGRAPH-#22106, IRGKangXi=0334.291, RSKangXi=50.9
22107 CJK UNIFIED IDEOGRAPH-#22107, IRGKangXi=0334.291, RSKangXi=50.9
22108 CJK UNIFIED IDEOGRAPH-#22108, IRGKangXi=0334.291, RSKangXi=50.9
22109 CJK UNIFIED IDEOGRAPH-#22109, IRGKangXi=0334.291, RSKangXi=50.9
2210A CJK UNIFIED IDEOGRAPH-#2210A, IRGKangXi=0334.300, RSKangXi=50.10
2210B CJK UNIFIED IDEOGRAPH-#2210B, IRGKangXi=0334.310, RSKangXi=50.10
2210C CJK UNIFIED IDEOGRAPH-#2210C, IRGKangXi=0334.320, RSKangXi=50.10
2210D CJK UNIFIED IDEOGRAPH-#2210D, IRGKangXi=0334.330, RSKangXi=50.10
2210E CJK UNIFIED IDEOGRAPH-#2210E, IRGKangXi=0334.340, RSKangXi=50.10
2210F CJK UNIFIED IDEOGRAPH-#2210F, IRGKangXi=0334.370, RSKangXi=50.10
22110 CJK UNIFIED IDEOGRAPH-#22110, IRGKangXi=0334.400, RSKangXi=50.10
22111 CJK UNIFIED IDEOGRAPH-#22111, IRGKangXi=0335.050, RSKangXi=50.10
22112 CJK UNIFIED IDEOGRAPH-#22112, IRGKangXi=0335.090, RSKangXi=50.10
22113 CJK UNIFIED IDEOGRAPH-#22113, IRGKangXi=0335.100, RSKangXi=50.10
22114 CJK UNIFIED IDEOGRAPH-#22114, IRGKangXi=0335.110, RSKangXi=50.10
22115 CJK UNIFIED IDEOGRAPH-#22115, IRGKangXi=0335.120, RSKangXi=50.10
22116 CJK UNIFIED IDEOGRAPH-#22116, IRGKangXi=0335.130, RSKangXi=50.10
22117 CJK UNIFIED IDEOGRAPH-#22117, IRGKangXi=0335.140, RSKangXi=50.10
22118 CJK UNIFIED IDEOGRAPH-#22118, IRGKangXi=0335.150, RSKangXi=50.10
22119 CJK UNIFIED IDEOGRAPH-#22119, IRGKangXi=0335.151, RSKangXi=50.10
2211A CJK UNIFIED IDEOGRAPH-#2211A, IRGKangXi=0335.151, RSKangXi=50.10
2211B CJK UNIFIED IDEOGRAPH-#2211B, IRGKangXi=0335.151, RSKangXi=50.10
2211C CJK UNIFIED IDEOGRAPH-#2211C, IRGKangXi=0335.151, RSKangXi=50.10
2211D CJK UNIFIED IDEOGRAPH-#2211D, IRGKangXi=0335.151, RSKangXi=50.10
2211E CJK UNIFIED IDEOGRAPH-#2211E, IRGKangXi=0335.151, RSKangXi=50.10
2211F CJK UNIFIED IDEOGRAPH-#2211F, IRGKangXi=0335.170, RSKangXi=50.11
22120 CJK UNIFIED IDEOGRAPH-#22120, IRGKangXi=0335.180, RSKangXi=50.11
22121 CJK UNIFIED IDEOGRAPH-#22121, IRGKangXi=0335.200, RSKangXi=50.11
22122 CJK UNIFIED IDEOGRAPH-#22122, IRGKangXi=0335.230, RSKangXi=50.11
22123 CJK UNIFIED IDEOGRAPH-#22123, IRGKangXi=0335.240, RSKangXi=50.11
22124 CJK UNIFIED IDEOGRAPH-#22124, IRGKangXi=0335.260, RSKangXi=50.11
22125 CJK UNIFIED IDEOGRAPH-#22125, IRGKangXi=0335.270, RSKangXi=50.11
22126 CJK UNIFIED IDEOGRAPH-#22126, IRGKangXi=0336.040, RSKangXi=50.11
22127 CJK UNIFIED IDEOGRAPH-#22127, IRGKangXi=0336.070, RSKangXi=50.11
22128 CJK UNIFIED IDEOGRAPH-#22128, IRGKangXi=0336.081, RSKangXi=50.11
22129 CJK UNIFIED IDEOGRAPH-#22129, IRGKangXi=0336.081, RSKangXi=50.11
2212A CJK UNIFIED IDEOGRAPH-#2212A, IRGKangXi=0336.081, RSKangXi=50.11
2212B CJK UNIFIED IDEOGRAPH-#2212B, IRGKangXi=0336.081, RSKangXi=50.11
2212C CJK UNIFIED IDEOGRAPH-#2212C, IRGKangXi=0336.081, RSKangXi=50.11
2212D CJK UNIFIED IDEOGRAPH-#2212D, IRGKangXi=0336.081, RSKangXi=50.11
2212E CJK UNIFIED IDEOGRAPH-#2212E, IRGKangXi=0336.081, RSKangXi=50.11
2212F CJK UNIFIED IDEOGRAPH-#2212F, IRGKangXi=0336.081, RSKangXi=50.11
22130 CJK UNIFIED IDEOGRAPH-#22130, IRGKangXi=0336.081, RSKangXi=50.11
22131 CJK UNIFIED IDEOGRAPH-#22131, IRGKangXi=0336.081, RSKangXi=50.11
22132 CJK UNIFIED IDEOGRAPH-#22132, IRGKangXi=0336.081, RSKangXi=50.11
22133 CJK UNIFIED IDEOGRAPH-#22133, IRGKangXi=0336.100, RSKangXi=50.12
22134 CJK UNIFIED IDEOGRAPH-#22134, IRGKangXi=0336.110, RSKangXi=50.12
22135 CJK UNIFIED IDEOGRAPH-#22135, IRGKangXi=0336.120, RSKangXi=50.12
22136 CJK UNIFIED IDEOGRAPH-#22136, IRGKangXi=0336.130, RSKangXi=50.12, Def{the noise of tearing silk; to tear}
22137 CJK UNIFIED IDEOGRAPH-#22137, IRGKangXi=0336.140, RSKangXi=50.12
22138 CJK UNIFIED IDEOGRAPH-#22138, IRGKangXi=0336.160, RSKangXi=50.12
22139 CJK UNIFIED IDEOGRAPH-#22139, IRGKangXi=0336.180, RSKangXi=50.12
2213A CJK UNIFIED IDEOGRAPH-#2213A, IRGKangXi=0336.190, RSKangXi=50.12
2213B CJK UNIFIED IDEOGRAPH-#2213B, IRGKangXi=0336.230, RSKangXi=50.12
2213C CJK UNIFIED IDEOGRAPH-#2213C, IRGKangXi=0336.240, RSKangXi=50.12
2213D CJK UNIFIED IDEOGRAPH-#2213D, IRGKangXi=0336.250, RSKangXi=50.12
2213E CJK UNIFIED IDEOGRAPH-#2213E, IRGKangXi=0337.030, RSKangXi=50.12
2213F CJK UNIFIED IDEOGRAPH-#2213F, IRGKangXi=0337.031, RSKangXi=50.12
22140 CJK UNIFIED IDEOGRAPH-#22140, IRGKangXi=0337.031, RSKangXi=50.12
22141 CJK UNIFIED IDEOGRAPH-#22141, IRGKangXi=0337.031, RSKangXi=50.12
22142 CJK UNIFIED IDEOGRAPH-#22142, IRGKangXi=0337.031, RSKangXi=50.12
22143 CJK UNIFIED IDEOGRAPH-#22143, IRGKangXi=0337.031, RSKangXi=50.12
22144 CJK UNIFIED IDEOGRAPH-#22144, IRGKangXi=0337.031, RSKangXi=50.12
22145 CJK UNIFIED IDEOGRAPH-#22145, IRGKangXi=0337.031, RSKangXi=50.12
22146 CJK UNIFIED IDEOGRAPH-#22146, IRGKangXi=0337.031, RSKangXi=50.12
22147 CJK UNIFIED IDEOGRAPH-#22147, IRGKangXi=0337.031, RSKangXi=50.12
22148 CJK UNIFIED IDEOGRAPH-#22148, IRGKangXi=0337.031, RSKangXi=50.12
22149 CJK UNIFIED IDEOGRAPH-#22149, IRGKangXi=0337.031, RSKangXi=50.12
2214A CJK UNIFIED IDEOGRAPH-#2214A, IRGKangXi=0337.031, RSKangXi=50.12
2214B CJK UNIFIED IDEOGRAPH-#2214B, IRGKangXi=0337.031, RSKangXi=50.12
2214C CJK UNIFIED IDEOGRAPH-#2214C, IRGKangXi=0337.031, RSKangXi=50.12
2214D CJK UNIFIED IDEOGRAPH-#2214D, IRGKangXi=0337.040, RSKangXi=50.13
2214E CJK UNIFIED IDEOGRAPH-#2214E, IRGKangXi=0337.050, RSKangXi=50.13
2214F CJK UNIFIED IDEOGRAPH-#2214F, IRGKangXi=0337.070, RSKangXi=50.13, Def{blinds, window screens}
22150 CJK UNIFIED IDEOGRAPH-#22150, IRGKangXi=0337.100, RSKangXi=50.13
22151 CJK UNIFIED IDEOGRAPH-#22151, IRGKangXi=0337.110, RSKangXi=50.13
22152 CJK UNIFIED IDEOGRAPH-#22152, IRGKangXi=0337.120, RSKangXi=50.13
22153 CJK UNIFIED IDEOGRAPH-#22153, IRGKangXi=0337.140, RSKangXi=50.13
22154 CJK UNIFIED IDEOGRAPH-#22154, IRGKangXi=0337.160, RSKangXi=50.13
22155 CJK UNIFIED IDEOGRAPH-#22155, IRGKangXi=0337.170, RSKangXi=50.13
22156 CJK UNIFIED IDEOGRAPH-#22156, IRGKangXi=0337.171, RSKangXi=50.13, Def{curtain, screen}
22157 CJK UNIFIED IDEOGRAPH-#22157, IRGKangXi=0337.171, RSKangXi=50.13
22158 CJK UNIFIED IDEOGRAPH-#22158, IRGKangXi=0337.171, RSKangXi=50.13
22159 CJK UNIFIED IDEOGRAPH-#22159, IRGKangXi=0337.171, RSKangXi=50.13
2215A CJK UNIFIED IDEOGRAPH-#2215A, IRGKangXi=0337.171, RSKangXi=50.13
2215B CJK UNIFIED IDEOGRAPH-#2215B, IRGKangXi=0337.171, RSKangXi=50.13
2215C CJK UNIFIED IDEOGRAPH-#2215C, IRGKangXi=0337.171, RSKangXi=50.13
2215D CJK UNIFIED IDEOGRAPH-#2215D, IRGKangXi=0337.171, RSKangXi=50.13
2215E CJK UNIFIED IDEOGRAPH-#2215E, IRGKangXi=0337.171, RSKangXi=50.13
2215F CJK UNIFIED IDEOGRAPH-#2215F, IRGKangXi=0337.190, RSKangXi=50.14
22160 CJK UNIFIED IDEOGRAPH-#22160, IRGKangXi=0337.220, RSKangXi=50.14
22161 CJK UNIFIED IDEOGRAPH-#22161, IRGKangXi=0337.240, RSKangXi=50.14
22162 CJK UNIFIED IDEOGRAPH-#22162, IRGKangXi=0338.020, RSKangXi=50.14
22163 CJK UNIFIED IDEOGRAPH-#22163, IRGKangXi=0338.021, RSKangXi=50.14
22164 CJK UNIFIED IDEOGRAPH-#22164, IRGKangXi=0338.021, RSKangXi=50.14
22165 CJK UNIFIED IDEOGRAPH-#22165, IRGKangXi=0338.021, RSKangXi=50.14, Def{variant of 㡡 U+3861, a screen to make a temporary kitchen}
22166 CJK UNIFIED IDEOGRAPH-#22166, IRGKangXi=0338.021, RSKangXi=50.14
22167 CJK UNIFIED IDEOGRAPH-#22167, IRGKangXi=0338.021, RSKangXi=50.14
22168 CJK UNIFIED IDEOGRAPH-#22168, IRGKangXi=0338.021, RSKangXi=50.14
22169 CJK UNIFIED IDEOGRAPH-#22169, IRGKangXi=0338.060, RSKangXi=50.15
2216A CJK UNIFIED IDEOGRAPH-#2216A, IRGKangXi=0338.070, RSKangXi=50.15
2216B CJK UNIFIED IDEOGRAPH-#2216B, IRGKangXi=0338.080, RSKangXi=50.15
2216C CJK UNIFIED IDEOGRAPH-#2216C, IRGKangXi=0338.081, RSKangXi=50.15
2216D CJK UNIFIED IDEOGRAPH-#2216D, IRGKangXi=0338.090, RSKangXi=50.16
2216E CJK UNIFIED IDEOGRAPH-#2216E, IRGKangXi=0338.100, RSKangXi=50.16
2216F CJK UNIFIED IDEOGRAPH-#2216F, IRGKangXi=0338.110, RSKangXi=50.16
22170 CJK UNIFIED IDEOGRAPH-#22170, IRGKangXi=0338.120, RSKangXi=50.16
22171 CJK UNIFIED IDEOGRAPH-#22171, IRGKangXi=0338.140, RSKangXi=50.16
22172 CJK UNIFIED IDEOGRAPH-#22172, IRGKangXi=0338.141, RSKangXi=50.16
22173 CJK UNIFIED IDEOGRAPH-#22173, IRGKangXi=0338.141, RSKangXi=50.16
22174 CJK UNIFIED IDEOGRAPH-#22174, IRGKangXi=0338.141, RSKangXi=50.16
22175 CJK UNIFIED IDEOGRAPH-#22175, IRGKangXi=0338.141, RSKangXi=50.16
22176 CJK UNIFIED IDEOGRAPH-#22176, IRGKangXi=0338.141, RSKangXi=50.16
22177 CJK UNIFIED IDEOGRAPH-#22177, IRGKangXi=0338.141, RSKangXi=50.16
22178 CJK UNIFIED IDEOGRAPH-#22178, IRGKangXi=0338.150, RSKangXi=50.17
22179 CJK UNIFIED IDEOGRAPH-#22179, IRGKangXi=0338.190, RSKangXi=50.17
2217A CJK UNIFIED IDEOGRAPH-#2217A, IRGKangXi=0338.191, RSKangXi=50.17
2217B CJK UNIFIED IDEOGRAPH-#2217B, IRGKangXi=0338.200, RSKangXi=50.18
2217C CJK UNIFIED IDEOGRAPH-#2217C, IRGKangXi=0338.210, RSKangXi=50.18
2217D CJK UNIFIED IDEOGRAPH-#2217D, IRGKangXi=0338.211, RSKangXi=50.18
2217E CJK UNIFIED IDEOGRAPH-#2217E, IRGKangXi=0338.230, RSKangXi=50.19
2217F CJK UNIFIED IDEOGRAPH-#2217F, IRGKangXi=0338.231, RSKangXi=50.19
22180 CJK UNIFIED IDEOGRAPH-#22180, IRGKangXi=0338.231, RSKangXi=50.19
22181 CJK UNIFIED IDEOGRAPH-#22181, IRGKangXi=0338.231, RSKangXi=50.19
22182 CJK UNIFIED IDEOGRAPH-#22182, IRGKangXi=0338.231, RSKangXi=50.20
22183 CJK UNIFIED IDEOGRAPH-#22183, IRGKangXi=0338.231, RSKangXi=50.21
22184 CJK UNIFIED IDEOGRAPH-#22184, IRGKangXi=0338.250, RSKangXi=50.21
22185 CJK UNIFIED IDEOGRAPH-#22185, IRGKangXi=0338.251, RSKangXi=50.21
22186 CJK UNIFIED IDEOGRAPH-#22186, IRGKangXi=0338.251, RSKangXi=50.21
22187 CJK UNIFIED IDEOGRAPH-#22187, IRGKangXi=0338.251, RSKangXi=50.24
22188 CJK UNIFIED IDEOGRAPH-#22188, IRGKangXi=0338.251, RSKangXi=50.24
22189 CJK UNIFIED IDEOGRAPH-#22189, IRGKangXi=0339.020, RSKangXi=51.2
2218A CJK UNIFIED IDEOGRAPH-#2218A, IRGKangXi=0340.040, RSKangXi=51.4
2218B CJK UNIFIED IDEOGRAPH-#2218B, IRGKangXi=0340.050, RSKangXi=51.4
2218C CJK UNIFIED IDEOGRAPH-#2218C, IRGKangXi=0340.051, RSKangXi=51.4
2218D CJK UNIFIED IDEOGRAPH-#2218D, IRGKangXi=0340.060, RSKangXi=51.5
2218E CJK UNIFIED IDEOGRAPH-#2218E, IRGKangXi=0341.040, RSKangXi=51.5
2218F CJK UNIFIED IDEOGRAPH-#2218F, IRGKangXi=0341.041, RSKangXi=51.5
22190 CJK UNIFIED IDEOGRAPH-#22190, IRGKangXi=0341.041, RSKangXi=51.5
22191 CJK UNIFIED IDEOGRAPH-#22191, IRGKangXi=0341.050, RSKangXi=51.6
22192 CJK UNIFIED IDEOGRAPH-#22192, IRGKangXi=0341.051, RSKangXi=51.6
22193 CJK UNIFIED IDEOGRAPH-#22193, IRGKangXi=0341.051, RSKangXi=51.6
22194 CJK UNIFIED IDEOGRAPH-#22194, IRGKangXi=0341.051, RSKangXi=51.6
22195 CJK UNIFIED IDEOGRAPH-#22195, IRGKangXi=0341.051, RSKangXi=51.6
22196 CJK UNIFIED IDEOGRAPH-#22196, IRGKangXi=0341.060, RSKangXi=51.7
22197 CJK UNIFIED IDEOGRAPH-#22197, IRGKangXi=0341.061, RSKangXi=51.7
22198 CJK UNIFIED IDEOGRAPH-#22198, IRGKangXi=0341.061, RSKangXi=51.7
22199 CJK UNIFIED IDEOGRAPH-#22199, IRGKangXi=0341.061, RSKangXi=51.7
2219A CJK UNIFIED IDEOGRAPH-#2219A, IRGKangXi=0341.061, RSKangXi=51.8
2219B CJK UNIFIED IDEOGRAPH-#2219B, IRGKangXi=0341.070, RSKangXi=51.9
2219C CJK UNIFIED IDEOGRAPH-#2219C, IRGKangXi=0341.080, RSKangXi=51.9
2219D CJK UNIFIED IDEOGRAPH-#2219D, IRGKangXi=0341.081, RSKangXi=51.9
2219E CJK UNIFIED IDEOGRAPH-#2219E, IRGKangXi=0341.100, RSKangXi=51.10, Def{a bunch, a handful}
2219F CJK UNIFIED IDEOGRAPH-#2219F, IRGKangXi=0341.110, RSKangXi=51.10
221A0 CJK UNIFIED IDEOGRAPH-#221A0, IRGKangXi=0341.111, RSKangXi=51.10
221A1 CJK UNIFIED IDEOGRAPH-#221A1, IRGKangXi=0341.111, RSKangXi=51.11, Def{(Cant.) female breast, milk}
221A2 CJK UNIFIED IDEOGRAPH-#221A2, IRGKangXi=0341.111, RSKangXi=51.11
221A3 CJK UNIFIED IDEOGRAPH-#221A3, IRGKangXi=0341.111, RSKangXi=36.11
221A4 CJK UNIFIED IDEOGRAPH-#221A4, IRGKangXi=0341.111, RSKangXi=51.11
221A5 CJK UNIFIED IDEOGRAPH-#221A5, IRGKangXi=0341.111, RSKangXi=51.12
221A6 CJK UNIFIED IDEOGRAPH-#221A6, IRGKangXi=0341.111, RSKangXi=51.13
221A7 CJK UNIFIED IDEOGRAPH-#221A7, IRGKangXi=0341.111, RSKangXi=51.13
221A8 CJK UNIFIED IDEOGRAPH-#221A8, IRGKangXi=0341.111, RSKangXi=51.13
221A9 CJK UNIFIED IDEOGRAPH-#221A9, IRGKangXi=0341.111, RSKangXi=51.13
221AA CJK UNIFIED IDEOGRAPH-#221AA, IRGKangXi=0341.111, RSKangXi=51.15
221AB CJK UNIFIED IDEOGRAPH-#221AB, IRGKangXi=0341.111, RSKangXi=51.16
221AC CJK UNIFIED IDEOGRAPH-#221AC, IRGKangXi=0341.111, RSKangXi=51.17
221AD CJK UNIFIED IDEOGRAPH-#221AD, IRGKangXi=0341.111, RSKangXi=51.17
221AE CJK UNIFIED IDEOGRAPH-#221AE, IRGKangXi=0341.111, RSKangXi=51.20
221AF CJK UNIFIED IDEOGRAPH-#221AF, IRGKangXi=0342.010, RSKangXi=52.1
221B0 CJK UNIFIED IDEOGRAPH-#221B0, IRGKangXi=0342.011, RSKangXi=52.1
221B1 CJK UNIFIED IDEOGRAPH-#221B1, IRGKangXi=0342.011, RSKangXi=52.1
221B2 CJK UNIFIED IDEOGRAPH-#221B2, IRGKangXi=0342.040, RSKangXi=52.2
221B3 CJK UNIFIED IDEOGRAPH-#221B3, IRGKangXi=0342.041, RSKangXi=52.2
221B4 CJK UNIFIED IDEOGRAPH-#221B4, IRGKangXi=0342.041, RSKangXi=52.2
221B5 CJK UNIFIED IDEOGRAPH-#221B5, IRGKangXi=0342.041, RSKangXi=52.2
221B6 CJK UNIFIED IDEOGRAPH-#221B6, IRGKangXi=0342.050, RSKangXi=52.3
221B7 CJK UNIFIED IDEOGRAPH-#221B7, IRGKangXi=0342.060, RSKangXi=52.4
221B8 CJK UNIFIED IDEOGRAPH-#221B8, IRGKangXi=0342.070, RSKangXi=52.4
221B9 CJK UNIFIED IDEOGRAPH-#221B9, IRGKangXi=0342.071, RSKangXi=52.4
221BA CJK UNIFIED IDEOGRAPH-#221BA, IRGKangXi=0342.071, RSKangXi=52.4
221BB CJK UNIFIED IDEOGRAPH-#221BB, IRGKangXi=0342.080, RSKangXi=52.5
221BC CJK UNIFIED IDEOGRAPH-#221BC, IRGKangXi=0342.090, RSKangXi=52.5
221BD CJK UNIFIED IDEOGRAPH-#221BD, IRGKangXi=0342.100, RSKangXi=52.5
221BE CJK UNIFIED IDEOGRAPH-#221BE, IRGKangXi=0342.101, RSKangXi=52.5
221BF CJK UNIFIED IDEOGRAPH-#221BF, IRGKangXi=0342.110, RSKangXi=52.6
221C0 CJK UNIFIED IDEOGRAPH-#221C0, IRGKangXi=0342.121, RSKangXi=44.6
221C1 CJK UNIFIED IDEOGRAPH-#221C1, IRGKangXi=0342.121, RSKangXi=52.7
221C2 CJK UNIFIED IDEOGRAPH-#221C2, IRGKangXi=0342.121, RSKangXi=52.6
221C3 CJK UNIFIED IDEOGRAPH-#221C3, IRGKangXi=0342.121, RSKangXi=52.7
221C4 CJK UNIFIED IDEOGRAPH-#221C4, IRGKangXi=0342.121, RSKangXi=52.7
221C5 CJK UNIFIED IDEOGRAPH-#221C5, IRGKangXi=0342.121, RSKangXi=52.7
221C6 CJK UNIFIED IDEOGRAPH-#221C6, IRGKangXi=0342.121, RSKangXi=52.7
221C7 CJK UNIFIED IDEOGRAPH-#221C7, IRGKangXi=0342.130, RSKangXi=52.8, Def{to run threads though a web in weaving}
221C8 CJK UNIFIED IDEOGRAPH-#221C8, IRGKangXi=0342.131, RSKangXi=52.8
221C9 CJK UNIFIED IDEOGRAPH-#221C9, IRGKangXi=0342.131, RSKangXi=52.8
221CA CJK UNIFIED IDEOGRAPH-#221CA, IRGKangXi=0342.181, RSKangXi=52.9
221CB CJK UNIFIED IDEOGRAPH-#221CB, IRGKangXi=0342.181, RSKangXi=52.10
221CC CJK UNIFIED IDEOGRAPH-#221CC, IRGKangXi=0343.010, RSKangXi=52.11
221CD CJK UNIFIED IDEOGRAPH-#221CD, IRGKangXi=0343.030, RSKangXi=52.11
221CE CJK UNIFIED IDEOGRAPH-#221CE, IRGKangXi=0343.031, RSKangXi=52.11
221CF CJK UNIFIED IDEOGRAPH-#221CF, IRGKangXi=0343.031, RSKangXi=52.11
221D0 CJK UNIFIED IDEOGRAPH-#221D0, IRGKangXi=0343.031, RSKangXi=52.12
221D1 CJK UNIFIED IDEOGRAPH-#221D1, IRGKangXi=0343.031, RSKangXi=52.12
221D2 CJK UNIFIED IDEOGRAPH-#221D2, IRGKangXi=0343.031, RSKangXi=52.12
221D3 CJK UNIFIED IDEOGRAPH-#221D3, IRGKangXi=0343.031, RSKangXi=52.12
221D4 CJK UNIFIED IDEOGRAPH-#221D4, IRGKangXi=0343.041, RSKangXi=42.14
221D5 CJK UNIFIED IDEOGRAPH-#221D5, IRGKangXi=0343.041, RSKangXi=17.16
221D6 CJK UNIFIED IDEOGRAPH-#221D6, IRGKangXi=0343.041, RSKangXi=52.19
221D7 CJK UNIFIED IDEOGRAPH-#221D7, IRGKangXi=0343.100, RSKangXi=53.3
221D8 CJK UNIFIED IDEOGRAPH-#221D8, IRGKangXi=0343.110, RSKangXi=53.3
221D9 CJK UNIFIED IDEOGRAPH-#221D9, IRGKangXi=0343.120, RSKangXi=53.3
221DA CJK UNIFIED IDEOGRAPH-#221DA, IRGKangXi=0343.140, RSKangXi=53.3
221DB CJK UNIFIED IDEOGRAPH-#221DB, IRGKangXi=0343.160, RSKangXi=53.3
221DC CJK UNIFIED IDEOGRAPH-#221DC, IRGKangXi=0343.170, RSKangXi=53.3
221DD CJK UNIFIED IDEOGRAPH-#221DD, IRGKangXi=0343.190, RSKangXi=53.3
221DE CJK UNIFIED IDEOGRAPH-#221DE, IRGKangXi=0343.200, RSKangXi=53.3
221DF CJK UNIFIED IDEOGRAPH-#221DF, IRGKangXi=0343.201, RSKangXi=53.3
221E0 CJK UNIFIED IDEOGRAPH-#221E0, IRGKangXi=0343.201, RSKangXi=53.3
221E1 CJK UNIFIED IDEOGRAPH-#221E1, IRGKangXi=0343.201, RSKangXi=53.3
221E2 CJK UNIFIED IDEOGRAPH-#221E2, IRGKangXi=0343.201, RSKangXi=53.3
221E3 CJK UNIFIED IDEOGRAPH-#221E3, IRGKangXi=0343.250, RSKangXi=53.4
221E4 CJK UNIFIED IDEOGRAPH-#221E4, IRGKangXi=0343.260, RSKangXi=53.4
221E5 CJK UNIFIED IDEOGRAPH-#221E5, IRGKangXi=0343.310, RSKangXi=53.4
221E6 CJK UNIFIED IDEOGRAPH-#221E6, IRGKangXi=0343.320, RSKangXi=53.4
221E7 CJK UNIFIED IDEOGRAPH-#221E7, IRGKangXi=0343.330, RSKangXi=53.4
221E8 CJK UNIFIED IDEOGRAPH-#221E8, IRGKangXi=0344.020, RSKangXi=53.4
221E9 CJK UNIFIED IDEOGRAPH-#221E9, IRGKangXi=0344.030, RSKangXi=53.4
221EA CJK UNIFIED IDEOGRAPH-#221EA, IRGKangXi=0344.040, RSKangXi=53.4
221EB CJK UNIFIED IDEOGRAPH-#221EB, IRGKangXi=0344.050, RSKangXi=53.4
221EC CJK UNIFIED IDEOGRAPH-#221EC, IRGKangXi=0344.051, RSKangXi=53.4
221ED CJK UNIFIED IDEOGRAPH-#221ED, IRGKangXi=0344.051, RSKangXi=53.4
221EE CJK UNIFIED IDEOGRAPH-#221EE, IRGKangXi=0344.051, RSKangXi=53.4
221EF CJK UNIFIED IDEOGRAPH-#221EF, IRGKangXi=0344.051, RSKangXi=53.4
221F0 CJK UNIFIED IDEOGRAPH-#221F0, IRGKangXi=0344.051, RSKangXi=53.4
221F1 CJK UNIFIED IDEOGRAPH-#221F1, IRGKangXi=0344.051, RSKangXi=53.4
221F2 CJK UNIFIED IDEOGRAPH-#221F2, IRGKangXi=0344.130, RSKangXi=53.5
221F3 CJK UNIFIED IDEOGRAPH-#221F3, IRGKangXi=0344.150, RSKangXi=53.5
221F4 CJK UNIFIED IDEOGRAPH-#221F4, IRGKangXi=0344.160, RSKangXi=53.5
221F5 CJK UNIFIED IDEOGRAPH-#221F5, IRGKangXi=0344.170, RSKangXi=53.5
221F6 CJK UNIFIED IDEOGRAPH-#221F6, IRGKangXi=0344.190, RSKangXi=53.5
221F7 CJK UNIFIED IDEOGRAPH-#221F7, IRGKangXi=0344.210, RSKangXi=53.5
221F8 CJK UNIFIED IDEOGRAPH-#221F8, IRGKangXi=0344.250, RSKangXi=53.5
221F9 CJK UNIFIED IDEOGRAPH-#221F9, IRGKangXi=0345.050, RSKangXi=53.5
221FA CJK UNIFIED IDEOGRAPH-#221FA, IRGKangXi=0345.060, RSKangXi=53.5
221FB CJK UNIFIED IDEOGRAPH-#221FB, IRGKangXi=0345.070, RSKangXi=53.5
221FC CJK UNIFIED IDEOGRAPH-#221FC, IRGKangXi=0345.080, RSKangXi=53.5
221FD CJK UNIFIED IDEOGRAPH-#221FD, IRGKangXi=0345.081, RSKangXi=53.5
221FE CJK UNIFIED IDEOGRAPH-#221FE, IRGKangXi=0345.081, RSKangXi=53.5
221FF CJK UNIFIED IDEOGRAPH-#221FF, IRGKangXi=0345.081, RSKangXi=53.5
22200 CJK UNIFIED IDEOGRAPH-#22200, IRGKangXi=0345.081, RSKangXi=53.5
22201 CJK UNIFIED IDEOGRAPH-#22201, IRGKangXi=0345.081, RSKangXi=53.5
22202 CJK UNIFIED IDEOGRAPH-#22202, IRGKangXi=0345.081, RSKangXi=53.5
22203 CJK UNIFIED IDEOGRAPH-#22203, IRGKangXi=0345.081, RSKangXi=53.5
22204 CJK UNIFIED IDEOGRAPH-#22204, IRGKangXi=0345.081, RSKangXi=53.5
22205 CJK UNIFIED IDEOGRAPH-#22205, IRGKangXi=0345.081, RSKangXi=53.5
22206 CJK UNIFIED IDEOGRAPH-#22206, IRGKangXi=0345.081, RSKangXi=53.5
22207 CJK UNIFIED IDEOGRAPH-#22207, IRGKangXi=0345.090, RSKangXi=53.6
22208 CJK UNIFIED IDEOGRAPH-#22208, IRGKangXi=0345.100, RSKangXi=53.6, Def{(Cant.) dimple}
22209 CJK UNIFIED IDEOGRAPH-#22209, IRGKangXi=0345.150, RSKangXi=53.6
2220A CJK UNIFIED IDEOGRAPH-#2220A, IRGKangXi=0345.160, RSKangXi=53.6
2220B CJK UNIFIED IDEOGRAPH-#2220B, IRGKangXi=0345.170, RSKangXi=53.6
2220C CJK UNIFIED IDEOGRAPH-#2220C, IRGKangXi=0346.020, RSKangXi=53.6
2220D CJK UNIFIED IDEOGRAPH-#2220D, IRGKangXi=0346.021, RSKangXi=53.6
2220E CJK UNIFIED IDEOGRAPH-#2220E, IRGKangXi=0346.021, RSKangXi=53.6
2220F CJK UNIFIED IDEOGRAPH-#2220F, IRGKangXi=0346.021, RSKangXi=53.6
22210 CJK UNIFIED IDEOGRAPH-#22210, IRGKangXi=0346.021, RSKangXi=53.6
22211 CJK UNIFIED IDEOGRAPH-#22211, IRGKangXi=0346.021, RSKangXi=53.6
22212 CJK UNIFIED IDEOGRAPH-#22212, IRGKangXi=0346.021, RSKangXi=53.6
22213 CJK UNIFIED IDEOGRAPH-#22213, IRGKangXi=0346.021, RSKangXi=53.6
22214 CJK UNIFIED IDEOGRAPH-#22214, IRGKangXi=0346.021, RSKangXi=53.6
22215 CJK UNIFIED IDEOGRAPH-#22215, IRGKangXi=0346.021, RSKangXi=53.6
22216 CJK UNIFIED IDEOGRAPH-#22216, IRGKangXi=0346.021, RSKangXi=53.6
22217 CJK UNIFIED IDEOGRAPH-#22217, IRGKangXi=0346.021, RSKangXi=53.6
22218 CJK UNIFIED IDEOGRAPH-#22218, IRGKangXi=0346.021, RSKangXi=53.6, Def{variant of 鹿 U+9E7F, a deer; surname}
22219 CJK UNIFIED IDEOGRAPH-#22219, IRGKangXi=0346.040, RSKangXi=53.7
2221A CJK UNIFIED IDEOGRAPH-#2221A, IRGKangXi=0346.060, RSKangXi=53.7
2221B CJK UNIFIED IDEOGRAPH-#2221B, IRGKangXi=0346.070, RSKangXi=53.7
2221C CJK UNIFIED IDEOGRAPH-#2221C, IRGKangXi=0346.100, RSKangXi=53.7
2221D CJK UNIFIED IDEOGRAPH-#2221D, IRGKangXi=0346.110, RSKangXi=53.7
2221E CJK UNIFIED IDEOGRAPH-#2221E, IRGKangXi=0346.150, RSKangXi=53.7
2221F CJK UNIFIED IDEOGRAPH-#2221F, IRGKangXi=0346.160, RSKangXi=53.7
22220 CJK UNIFIED IDEOGRAPH-#22220, IRGKangXi=0346.180, RSKangXi=53.7
22221 CJK UNIFIED IDEOGRAPH-#22221, IRGKangXi=0346.190, RSKangXi=53.7
22222 CJK UNIFIED IDEOGRAPH-#22222, IRGKangXi=0346.200, RSKangXi=53.7
22223 CJK UNIFIED IDEOGRAPH-#22223, IRGKangXi=0346.250, RSKangXi=53.7
22224 CJK UNIFIED IDEOGRAPH-#22224, IRGKangXi=0346.260, RSKangXi=53.7
22225 CJK UNIFIED IDEOGRAPH-#22225, IRGKangXi=0346.280, RSKangXi=53.7
22226 CJK UNIFIED IDEOGRAPH-#22226, IRGKangXi=0346.290, RSKangXi=53.7
22227 CJK UNIFIED IDEOGRAPH-#22227, IRGKangXi=0346.291, RSKangXi=53.7
22228 CJK UNIFIED IDEOGRAPH-#22228, IRGKangXi=0346.291, RSKangXi=53.7
22229 CJK UNIFIED IDEOGRAPH-#22229, IRGKangXi=0346.291, RSKangXi=53.7
2222A CJK UNIFIED IDEOGRAPH-#2222A, IRGKangXi=0346.291, RSKangXi=53.7
2222B CJK UNIFIED IDEOGRAPH-#2222B, IRGKangXi=0346.291, RSKangXi=53.7
2222C CJK UNIFIED IDEOGRAPH-#2222C, IRGKangXi=0346.291, RSKangXi=53.7
2222D CJK UNIFIED IDEOGRAPH-#2222D, IRGKangXi=0346.291, RSKangXi=53.7
2222E CJK UNIFIED IDEOGRAPH-#2222E, IRGKangXi=0346.291, RSKangXi=53.7
2222F CJK UNIFIED IDEOGRAPH-#2222F, IRGKangXi=0346.291, RSKangXi=53.7
22230 CJK UNIFIED IDEOGRAPH-#22230, IRGKangXi=0346.291, RSKangXi=53.7
22231 CJK UNIFIED IDEOGRAPH-#22231, IRGKangXi=0346.291, RSKangXi=53.7
22232 CJK UNIFIED IDEOGRAPH-#22232, IRGKangXi=0346.291, RSKangXi=39.7
22233 CJK UNIFIED IDEOGRAPH-#22233, IRGKangXi=0346.310, RSKangXi=53.8
22234 CJK UNIFIED IDEOGRAPH-#22234, IRGKangXi=0346.340, RSKangXi=53.8
22235 CJK UNIFIED IDEOGRAPH-#22235, IRGKangXi=0347.030, RSKangXi=53.8
22236 CJK UNIFIED IDEOGRAPH-#22236, IRGKangXi=0347.050, RSKangXi=53.8
22237 CJK UNIFIED IDEOGRAPH-#22237, IRGKangXi=0347.070, RSKangXi=53.8
22238 CJK UNIFIED IDEOGRAPH-#22238, IRGKangXi=0347.080, RSKangXi=53.8
22239 CJK UNIFIED IDEOGRAPH-#22239, IRGKangXi=0347.090, RSKangXi=53.8
2223A CJK UNIFIED IDEOGRAPH-#2223A, IRGKangXi=0347.100, RSKangXi=53.8
2223B CJK UNIFIED IDEOGRAPH-#2223B, IRGKangXi=0347.110, RSKangXi=53.8
2223C CJK UNIFIED IDEOGRAPH-#2223C, IRGKangXi=0347.120, RSKangXi=53.8
2223D CJK UNIFIED IDEOGRAPH-#2223D, IRGKangXi=0347.130, RSKangXi=53.8
2223E CJK UNIFIED IDEOGRAPH-#2223E, IRGKangXi=0347.170, RSKangXi=53.8
2223F CJK UNIFIED IDEOGRAPH-#2223F, IRGKangXi=0347.180, RSKangXi=53.8
22240 CJK UNIFIED IDEOGRAPH-#22240, IRGKangXi=0347.190, RSKangXi=53.8
22241 CJK UNIFIED IDEOGRAPH-#22241, IRGKangXi=0347.260, RSKangXi=53.8
22242 CJK UNIFIED IDEOGRAPH-#22242, IRGKangXi=0347.290, RSKangXi=53.8
22243 CJK UNIFIED IDEOGRAPH-#22243, IRGKangXi=0348.010, RSKangXi=53.8
22244 CJK UNIFIED IDEOGRAPH-#22244, IRGKangXi=0348.020, RSKangXi=53.8
22245 CJK UNIFIED IDEOGRAPH-#22245, IRGKangXi=0348.040, RSKangXi=53.8
22246 CJK UNIFIED IDEOGRAPH-#22246, IRGKangXi=0348.060, RSKangXi=53.8
22247 CJK UNIFIED IDEOGRAPH-#22247, IRGKangXi=0348.070, RSKangXi=53.8
22248 CJK UNIFIED IDEOGRAPH-#22248, IRGKangXi=0348.080, RSKangXi=53.8
22249 CJK UNIFIED IDEOGRAPH-#22249, IRGKangXi=0348.081, RSKangXi=53.8
2224A CJK UNIFIED IDEOGRAPH-#2224A, IRGKangXi=0348.081, RSKangXi=53.8
2224B CJK UNIFIED IDEOGRAPH-#2224B, IRGKangXi=0348.081, RSKangXi=53.8
2224C CJK UNIFIED IDEOGRAPH-#2224C, IRGKangXi=0348.081, RSKangXi=53.8
2224D CJK UNIFIED IDEOGRAPH-#2224D, IRGKangXi=0348.081, RSKangXi=53.8
2224E CJK UNIFIED IDEOGRAPH-#2224E, IRGKangXi=0348.081, RSKangXi=53.8
2224F CJK UNIFIED IDEOGRAPH-#2224F, IRGKangXi=0348.081, RSKangXi=53.8
22250 CJK UNIFIED IDEOGRAPH-#22250, IRGKangXi=0348.081, RSKangXi=53.8
22251 CJK UNIFIED IDEOGRAPH-#22251, IRGKangXi=0348.081, RSKangXi=53.8
22252 CJK UNIFIED IDEOGRAPH-#22252, IRGKangXi=0348.081, RSKangXi=53.8
22253 CJK UNIFIED IDEOGRAPH-#22253, IRGKangXi=0348.081, RSKangXi=53.8
22254 CJK UNIFIED IDEOGRAPH-#22254, IRGKangXi=0348.081, RSKangXi=53.8
22255 CJK UNIFIED IDEOGRAPH-#22255, IRGKangXi=0348.081, RSKangXi=53.8
22256 CJK UNIFIED IDEOGRAPH-#22256, IRGKangXi=0348.081, RSKangXi=198.0
22257 CJK UNIFIED IDEOGRAPH-#22257, IRGKangXi=0348.081, RSKangXi=53.8
22258 CJK UNIFIED IDEOGRAPH-#22258, IRGKangXi=0348.081, RSKangXi=53.8
22259 CJK UNIFIED IDEOGRAPH-#22259, IRGKangXi=0348.081, RSKangXi=53.8
2225A CJK UNIFIED IDEOGRAPH-#2225A, IRGKangXi=0348.081, RSKangXi=53.8
2225B CJK UNIFIED IDEOGRAPH-#2225B, IRGKangXi=0348.090, RSKangXi=53.9
2225C CJK UNIFIED IDEOGRAPH-#2225C, IRGKangXi=0348.100, RSKangXi=53.9
2225D CJK UNIFIED IDEOGRAPH-#2225D, IRGKangXi=0348.120, RSKangXi=53.9
2225E CJK UNIFIED IDEOGRAPH-#2225E, IRGKangXi=0348.130, RSKangXi=53.9
2225F CJK UNIFIED IDEOGRAPH-#2225F, IRGKangXi=0348.150, RSKangXi=53.9
22260 CJK UNIFIED IDEOGRAPH-#22260, IRGKangXi=0348.170, RSKangXi=53.9
22261 CJK UNIFIED IDEOGRAPH-#22261, IRGKangXi=0348.180, RSKangXi=53.9
22262 CJK UNIFIED IDEOGRAPH-#22262, IRGKangXi=0348.190, RSKangXi=53.9
22263 CJK UNIFIED IDEOGRAPH-#22263, IRGKangXi=0348.210, RSKangXi=53.9
22264 CJK UNIFIED IDEOGRAPH-#22264, IRGKangXi=0348.230, RSKangXi=53.9
22265 CJK UNIFIED IDEOGRAPH-#22265, IRGKangXi=0348.250, RSKangXi=53.9
22266 CJK UNIFIED IDEOGRAPH-#22266, IRGKangXi=0348.280, RSKangXi=53.9
22267 CJK UNIFIED IDEOGRAPH-#22267, IRGKangXi=0348.290, RSKangXi=53.9
22268 CJK UNIFIED IDEOGRAPH-#22268, IRGKangXi=0348.300, RSKangXi=53.9
22269 CJK UNIFIED IDEOGRAPH-#22269, IRGKangXi=0348.310, RSKangXi=53.9
2226A CJK UNIFIED IDEOGRAPH-#2226A, IRGKangXi=0348.330, RSKangXi=53.9
2226B CJK UNIFIED IDEOGRAPH-#2226B, IRGKangXi=0348.340, RSKangXi=53.9
2226C CJK UNIFIED IDEOGRAPH-#2226C, IRGKangXi=0348.350, RSKangXi=53.9
2226D CJK UNIFIED IDEOGRAPH-#2226D, IRGKangXi=0348.360, RSKangXi=53.9
2226E CJK UNIFIED IDEOGRAPH-#2226E, IRGKangXi=0348.361, RSKangXi=53.9
2226F CJK UNIFIED IDEOGRAPH-#2226F, IRGKangXi=0348.361, RSKangXi=53.9
22270 CJK UNIFIED IDEOGRAPH-#22270, IRGKangXi=0348.361, RSKangXi=53.9
22271 CJK UNIFIED IDEOGRAPH-#22271, IRGKangXi=0348.361, RSKangXi=53.9
22272 CJK UNIFIED IDEOGRAPH-#22272, IRGKangXi=0348.361, RSKangXi=53.9
22273 CJK UNIFIED IDEOGRAPH-#22273, IRGKangXi=0348.361, RSKangXi=53.9
22274 CJK UNIFIED IDEOGRAPH-#22274, IRGKangXi=0348.361, RSKangXi=53.9
22275 CJK UNIFIED IDEOGRAPH-#22275, IRGKangXi=0348.361, RSKangXi=53.9
22276 CJK UNIFIED IDEOGRAPH-#22276, IRGKangXi=0348.361, RSKangXi=53.9
22277 CJK UNIFIED IDEOGRAPH-#22277, IRGKangXi=0348.361, RSKangXi=53.9
22278 CJK UNIFIED IDEOGRAPH-#22278, IRGKangXi=0348.361, RSKangXi=53.9
22279 CJK UNIFIED IDEOGRAPH-#22279, IRGKangXi=0348.361, RSKangXi=53.9
2227A CJK UNIFIED IDEOGRAPH-#2227A, IRGKangXi=0348.361, RSKangXi=53.9
2227B CJK UNIFIED IDEOGRAPH-#2227B, IRGKangXi=0348.361, RSKangXi=53.9
2227C CJK UNIFIED IDEOGRAPH-#2227C, IRGKangXi=0348.361, RSKangXi=53.9
2227D CJK UNIFIED IDEOGRAPH-#2227D, IRGKangXi=0348.361, RSKangXi=53.9
2227E CJK UNIFIED IDEOGRAPH-#2227E, IRGKangXi=0348.361, RSKangXi=53.9
2227F CJK UNIFIED IDEOGRAPH-#2227F, IRGKangXi=0349.020, RSKangXi=53.10
22280 CJK UNIFIED IDEOGRAPH-#22280, IRGKangXi=0349.040, RSKangXi=53.10
22281 CJK UNIFIED IDEOGRAPH-#22281, IRGKangXi=0349.050, RSKangXi=53.10
22282 CJK UNIFIED IDEOGRAPH-#22282, IRGKangXi=0349.150, RSKangXi=53.10
22283 CJK UNIFIED IDEOGRAPH-#22283, IRGKangXi=0349.160, RSKangXi=53.10
22284 CJK UNIFIED IDEOGRAPH-#22284, IRGKangXi=0349.170, RSKangXi=53.10
22285 CJK UNIFIED IDEOGRAPH-#22285, IRGKangXi=0349.180, RSKangXi=53.10
22286 CJK UNIFIED IDEOGRAPH-#22286, IRGKangXi=0349.190, RSKangXi=53.10
22287 CJK UNIFIED IDEOGRAPH-#22287, IRGKangXi=0349.200, RSKangXi=53.10
22288 CJK UNIFIED IDEOGRAPH-#22288, IRGKangXi=0349.201, RSKangXi=53.10
22289 CJK UNIFIED IDEOGRAPH-#22289, IRGKangXi=0349.201, RSKangXi=53.10
2228A CJK UNIFIED IDEOGRAPH-#2228A, IRGKangXi=0349.201, RSKangXi=53.10
2228B CJK UNIFIED IDEOGRAPH-#2228B, IRGKangXi=0349.201, RSKangXi=53.10
2228C CJK UNIFIED IDEOGRAPH-#2228C, IRGKangXi=0349.201, RSKangXi=53.10
2228D CJK UNIFIED IDEOGRAPH-#2228D, IRGKangXi=0349.201, RSKangXi=53.10, Def{variant of 厨 U+53A8, a kitchen; a closet; a cupboard}
2228E CJK UNIFIED IDEOGRAPH-#2228E, IRGKangXi=0349.201, RSKangXi=53.10
2228F CJK UNIFIED IDEOGRAPH-#2228F, IRGKangXi=0349.201, RSKangXi=53.10
22290 CJK UNIFIED IDEOGRAPH-#22290, IRGKangXi=0349.201, RSKangXi=53.10
22291 CJK UNIFIED IDEOGRAPH-#22291, IRGKangXi=0349.201, RSKangXi=53.10
22292 CJK UNIFIED IDEOGRAPH-#22292, IRGKangXi=0349.201, RSKangXi=53.10
22293 CJK UNIFIED IDEOGRAPH-#22293, IRGKangXi=0349.201, RSKangXi=53.10
22294 CJK UNIFIED IDEOGRAPH-#22294, IRGKangXi=0349.201, RSKangXi=53.10
22295 CJK UNIFIED IDEOGRAPH-#22295, IRGKangXi=0349.220, RSKangXi=53.11
22296 CJK UNIFIED IDEOGRAPH-#22296, IRGKangXi=0349.230, RSKangXi=53.11
22297 CJK UNIFIED IDEOGRAPH-#22297, IRGKangXi=0349.310, RSKangXi=53.11
22298 CJK UNIFIED IDEOGRAPH-#22298, IRGKangXi=0349.320, RSKangXi=53.11
22299 CJK UNIFIED IDEOGRAPH-#22299, IRGKangXi=0350.080, RSKangXi=53.11
2229A CJK UNIFIED IDEOGRAPH-#2229A, IRGKangXi=0350.100, RSKangXi=53.11
2229B CJK UNIFIED IDEOGRAPH-#2229B, IRGKangXi=0350.110, RSKangXi=53.11
2229C CJK UNIFIED IDEOGRAPH-#2229C, IRGKangXi=0350.120, RSKangXi=53.11
2229D CJK UNIFIED IDEOGRAPH-#2229D, IRGKangXi=0350.140, RSKangXi=53.11
2229E CJK UNIFIED IDEOGRAPH-#2229E, IRGKangXi=0350.141, RSKangXi=53.11
2229F CJK UNIFIED IDEOGRAPH-#2229F, IRGKangXi=0350.141, RSKangXi=53.11
222A0 CJK UNIFIED IDEOGRAPH-#222A0, IRGKangXi=0350.141, RSKangXi=53.11
222A1 CJK UNIFIED IDEOGRAPH-#222A1, IRGKangXi=0350.141, RSKangXi=53.11
222A2 CJK UNIFIED IDEOGRAPH-#222A2, IRGKangXi=0350.141, RSKangXi=53.11
222A3 CJK UNIFIED IDEOGRAPH-#222A3, IRGKangXi=0350.141, RSKangXi=53.11
222A4 CJK UNIFIED IDEOGRAPH-#222A4, IRGKangXi=0350.141, RSKangXi=53.11
222A5 CJK UNIFIED IDEOGRAPH-#222A5, IRGKangXi=0350.141, RSKangXi=53.11
222A6 CJK UNIFIED IDEOGRAPH-#222A6, IRGKangXi=0350.141, RSKangXi=53.11
222A7 CJK UNIFIED IDEOGRAPH-#222A7, IRGKangXi=0350.141, RSKangXi=53.11
222A8 CJK UNIFIED IDEOGRAPH-#222A8, IRGKangXi=0350.141, RSKangXi=53.11
222A9 CJK UNIFIED IDEOGRAPH-#222A9, IRGKangXi=0350.141, RSKangXi=53.11
222AA CJK UNIFIED IDEOGRAPH-#222AA, IRGKangXi=0350.141, RSKangXi=53.11
222AB CJK UNIFIED IDEOGRAPH-#222AB, IRGKangXi=0350.141, RSKangXi=53.11
222AC CJK UNIFIED IDEOGRAPH-#222AC, IRGKangXi=0350.141, RSKangXi=53.11
222AD CJK UNIFIED IDEOGRAPH-#222AD, IRGKangXi=0350.160, RSKangXi=53.12
222AE CJK UNIFIED IDEOGRAPH-#222AE, IRGKangXi=0350.190, RSKangXi=53.12
222AF CJK UNIFIED IDEOGRAPH-#222AF, IRGKangXi=0350.200, RSKangXi=53.12
222B0 CJK UNIFIED IDEOGRAPH-#222B0, IRGKangXi=0350.210, RSKangXi=53.12
222B1 CJK UNIFIED IDEOGRAPH-#222B1, IRGKangXi=0350.240, RSKangXi=53.12
222B2 CJK UNIFIED IDEOGRAPH-#222B2, IRGKangXi=0350.250, RSKangXi=53.12
222B3 CJK UNIFIED IDEOGRAPH-#222B3, IRGKangXi=0351.050, RSKangXi=53.12
222B4 CJK UNIFIED IDEOGRAPH-#222B4, IRGKangXi=0351.060, RSKangXi=53.12
222B5 CJK UNIFIED IDEOGRAPH-#222B5, IRGKangXi=0351.070, RSKangXi=53.12
222B6 CJK UNIFIED IDEOGRAPH-#222B6, IRGKangXi=0351.071, RSKangXi=53.12
222B7 CJK UNIFIED IDEOGRAPH-#222B7, IRGKangXi=0351.071, RSKangXi=53.12
222B8 CJK UNIFIED IDEOGRAPH-#222B8, IRGKangXi=0351.071, RSKangXi=53.12
222B9 CJK UNIFIED IDEOGRAPH-#222B9, IRGKangXi=0351.071, RSKangXi=53.12
222BA CJK UNIFIED IDEOGRAPH-#222BA, IRGKangXi=0351.071, RSKangXi=53.12
222BB CJK UNIFIED IDEOGRAPH-#222BB, IRGKangXi=0351.071, RSKangXi=53.12
222BC CJK UNIFIED IDEOGRAPH-#222BC, IRGKangXi=0351.071, RSKangXi=53.12
222BD CJK UNIFIED IDEOGRAPH-#222BD, IRGKangXi=0351.071, RSKangXi=53.12
222BE CJK UNIFIED IDEOGRAPH-#222BE, IRGKangXi=0351.071, RSKangXi=53.12
222BF CJK UNIFIED IDEOGRAPH-#222BF, IRGKangXi=0351.071, RSKangXi=53.12
222C0 CJK UNIFIED IDEOGRAPH-#222C0, IRGKangXi=0351.071, RSKangXi=53.12
222C1 CJK UNIFIED IDEOGRAPH-#222C1, IRGKangXi=0351.071, RSKangXi=53.12
222C2 CJK UNIFIED IDEOGRAPH-#222C2, IRGKangXi=0351.080, RSKangXi=53.13
222C3 CJK UNIFIED IDEOGRAPH-#222C3, IRGKangXi=0351.090, RSKangXi=53.13
222C4 CJK UNIFIED IDEOGRAPH-#222C4, IRGKangXi=0351.130, RSKangXi=53.13
222C5 CJK UNIFIED IDEOGRAPH-#222C5, IRGKangXi=0351.180, RSKangXi=53.13
222C6 CJK UNIFIED IDEOGRAPH-#222C6, IRGKangXi=0351.200, RSKangXi=53.13
222C7 CJK UNIFIED IDEOGRAPH-#222C7, IRGKangXi=0351.210, RSKangXi=53.13
222C8 CJK UNIFIED IDEOGRAPH-#222C8, IRGKangXi=0351.231, RSKangXi=53.13
222C9 CJK UNIFIED IDEOGRAPH-#222C9, IRGKangXi=0351.231, RSKangXi=53.13
222CA CJK UNIFIED IDEOGRAPH-#222CA, IRGKangXi=0351.231, RSKangXi=53.13
222CB CJK UNIFIED IDEOGRAPH-#222CB, IRGKangXi=0351.231, RSKangXi=53.13
222CC CJK UNIFIED IDEOGRAPH-#222CC, IRGKangXi=0351.231, RSKangXi=53.13
222CD CJK UNIFIED IDEOGRAPH-#222CD, IRGKangXi=0351.231, RSKangXi=53.13
222CE CJK UNIFIED IDEOGRAPH-#222CE, IRGKangXi=0351.231, RSKangXi=53.13
222CF CJK UNIFIED IDEOGRAPH-#222CF, IRGKangXi=0351.231, RSKangXi=53.13
222D0 CJK UNIFIED IDEOGRAPH-#222D0, IRGKangXi=0351.231, RSKangXi=53.13
222D1 CJK UNIFIED IDEOGRAPH-#222D1, IRGKangXi=0351.240, RSKangXi=53.14
222D2 CJK UNIFIED IDEOGRAPH-#222D2, IRGKangXi=0351.250, RSKangXi=53.14
222D3 CJK UNIFIED IDEOGRAPH-#222D3, IRGKangXi=0351.260, RSKangXi=53.14
222D4 CJK UNIFIED IDEOGRAPH-#222D4, IRGKangXi=0351.270, RSKangXi=53.14
222D5 CJK UNIFIED IDEOGRAPH-#222D5, IRGKangXi=0351.271, RSKangXi=53.14
222D6 CJK UNIFIED IDEOGRAPH-#222D6, IRGKangXi=0351.271, RSKangXi=53.14
222D7 CJK UNIFIED IDEOGRAPH-#222D7, IRGKangXi=0351.271, RSKangXi=53.14
222D8 CJK UNIFIED IDEOGRAPH-#222D8, IRGKangXi=0351.271, RSKangXi=53.14
222D9 CJK UNIFIED IDEOGRAPH-#222D9, IRGKangXi=0351.271, RSKangXi=53.14
222DA CJK UNIFIED IDEOGRAPH-#222DA, IRGKangXi=0351.271, RSKangXi=53.14
222DB CJK UNIFIED IDEOGRAPH-#222DB, IRGKangXi=0351.271, RSKangXi=53.14
222DC CJK UNIFIED IDEOGRAPH-#222DC, IRGKangXi=0351.271, RSKangXi=142.11
222DD CJK UNIFIED IDEOGRAPH-#222DD, IRGKangXi=0351.271, RSKangXi=53.14
222DE CJK UNIFIED IDEOGRAPH-#222DE, IRGKangXi=0351.271, RSKangXi=53.14
222DF CJK UNIFIED IDEOGRAPH-#222DF, IRGKangXi=0351.271, RSKangXi=53.14
222E0 CJK UNIFIED IDEOGRAPH-#222E0, IRGKangXi=0351.271, RSKangXi=53.14
222E1 CJK UNIFIED IDEOGRAPH-#222E1, IRGKangXi=0351.280, RSKangXi=53.15
222E2 CJK UNIFIED IDEOGRAPH-#222E2, IRGKangXi=0352.010, RSKangXi=53.15
222E3 CJK UNIFIED IDEOGRAPH-#222E3, IRGKangXi=0352.020, RSKangXi=53.15
222E4 CJK UNIFIED IDEOGRAPH-#222E4, IRGKangXi=0352.021, RSKangXi=53.15
222E5 CJK UNIFIED IDEOGRAPH-#222E5, IRGKangXi=0352.021, RSKangXi=53.15
222E6 CJK UNIFIED IDEOGRAPH-#222E6, IRGKangXi=0352.021, RSKangXi=53.15
222E7 CJK UNIFIED IDEOGRAPH-#222E7, IRGKangXi=0352.021, RSKangXi=53.15
222E8 CJK UNIFIED IDEOGRAPH-#222E8, IRGKangXi=0352.021, RSKangXi=53.15
222E9 CJK UNIFIED IDEOGRAPH-#222E9, IRGKangXi=0352.021, RSKangXi=53.15
222EA CJK UNIFIED IDEOGRAPH-#222EA, IRGKangXi=0352.021, RSKangXi=53.15
222EB CJK UNIFIED IDEOGRAPH-#222EB, IRGKangXi=0352.021, RSKangXi=53.15
222EC CJK UNIFIED IDEOGRAPH-#222EC, IRGKangXi=0352.021, RSKangXi=53.15
222ED CJK UNIFIED IDEOGRAPH-#222ED, IRGKangXi=0352.021, RSKangXi=53.15
222EE CJK UNIFIED IDEOGRAPH-#222EE, IRGKangXi=0352.030, RSKangXi=53.16
222EF CJK UNIFIED IDEOGRAPH-#222EF, IRGKangXi=0352.060, RSKangXi=53.16
222F0 CJK UNIFIED IDEOGRAPH-#222F0, IRGKangXi=0352.070, RSKangXi=53.16
222F1 CJK UNIFIED IDEOGRAPH-#222F1, IRGKangXi=0352.080, RSKangXi=53.16
222F2 CJK UNIFIED IDEOGRAPH-#222F2, IRGKangXi=0352.090, RSKangXi=53.16
222F3 CJK UNIFIED IDEOGRAPH-#222F3, IRGKangXi=0352.091, RSKangXi=53.16
222F4 CJK UNIFIED IDEOGRAPH-#222F4, IRGKangXi=0352.091, RSKangXi=53.16
222F5 CJK UNIFIED IDEOGRAPH-#222F5, IRGKangXi=0352.091, RSKangXi=53.16
222F6 CJK UNIFIED IDEOGRAPH-#222F6, IRGKangXi=0352.091, RSKangXi=53.16
222F7 CJK UNIFIED IDEOGRAPH-#222F7, IRGKangXi=0352.091, RSKangXi=53.16
222F8 CJK UNIFIED IDEOGRAPH-#222F8, IRGKangXi=0352.091, RSKangXi=53.16
222F9 CJK UNIFIED IDEOGRAPH-#222F9, IRGKangXi=0352.091, RSKangXi=53.16
222FA CJK UNIFIED IDEOGRAPH-#222FA, IRGKangXi=0352.091, RSKangXi=53.16
222FB CJK UNIFIED IDEOGRAPH-#222FB, IRGKangXi=0352.100, RSKangXi=53.17
222FC CJK UNIFIED IDEOGRAPH-#222FC, IRGKangXi=0352.140, RSKangXi=53.17
222FD CJK UNIFIED IDEOGRAPH-#222FD, IRGKangXi=0352.150, RSKangXi=53.17
222FE CJK UNIFIED IDEOGRAPH-#222FE, IRGKangXi=0352.160, RSKangXi=53.17
222FF CJK UNIFIED IDEOGRAPH-#222FF, IRGKangXi=0352.170, RSKangXi=53.17
22300 CJK UNIFIED IDEOGRAPH-#22300, IRGKangXi=0352.171, RSKangXi=53.17
22301 CJK UNIFIED IDEOGRAPH-#22301, IRGKangXi=0352.171, RSKangXi=53.17
22302 CJK UNIFIED IDEOGRAPH-#22302, IRGKangXi=0352.171, RSKangXi=53.17
22303 CJK UNIFIED IDEOGRAPH-#22303, IRGKangXi=0352.171, RSKangXi=53.17
22304 CJK UNIFIED IDEOGRAPH-#22304, IRGKangXi=0352.180, RSKangXi=53.18
22305 CJK UNIFIED IDEOGRAPH-#22305, IRGKangXi=0352.191, RSKangXi=53.18
22306 CJK UNIFIED IDEOGRAPH-#22306, IRGKangXi=0352.191, RSKangXi=53.18
22307 CJK UNIFIED IDEOGRAPH-#22307, IRGKangXi=0352.191, RSKangXi=85.18
22308 CJK UNIFIED IDEOGRAPH-#22308, IRGKangXi=0352.200, RSKangXi=53.19
22309 CJK UNIFIED IDEOGRAPH-#22309, IRGKangXi=0352.210, RSKangXi=53.19
2230A CJK UNIFIED IDEOGRAPH-#2230A, IRGKangXi=0352.221, RSKangXi=53.19
2230B CJK UNIFIED IDEOGRAPH-#2230B, IRGKangXi=0352.221
2230C CJK UNIFIED IDEOGRAPH-#2230C, IRGKangXi=0352.221, RSKangXi=53.19
2230D CJK UNIFIED IDEOGRAPH-#2230D, IRGKangXi=0352.230, RSKangXi=53.20
2230E CJK UNIFIED IDEOGRAPH-#2230E, IRGKangXi=0352.231, RSKangXi=53.20
2230F CJK UNIFIED IDEOGRAPH-#2230F, IRGKangXi=0352.231, RSKangXi=53.20
22310 CJK UNIFIED IDEOGRAPH-#22310, IRGKangXi=0352.231, RSKangXi=53.20
22311 CJK UNIFIED IDEOGRAPH-#22311, IRGKangXi=0352.231, RSKangXi=53.20
22312 CJK UNIFIED IDEOGRAPH-#22312, IRGKangXi=0352.231, RSKangXi=53.21
22313 CJK UNIFIED IDEOGRAPH-#22313, IRGKangXi=0352.250, RSKangXi=53.23
22314 CJK UNIFIED IDEOGRAPH-#22314, IRGKangXi=0352.260, RSKangXi=53.24
22315 CJK UNIFIED IDEOGRAPH-#22315, IRGKangXi=0352.270, RSKangXi=53.24
22316 CJK UNIFIED IDEOGRAPH-#22316, IRGKangXi=0352.271, RSKangXi=53.25
22317 CJK UNIFIED IDEOGRAPH-#22317, IRGKangXi=0352.281, RSKangXi=54.2
22318 CJK UNIFIED IDEOGRAPH-#22318, IRGKangXi=0352.291, RSKangXi=54.3
22319 CJK UNIFIED IDEOGRAPH-#22319, IRGKangXi=0352.291, RSKangXi=54.3
2231A CJK UNIFIED IDEOGRAPH-#2231A, IRGKangXi=0352.291, RSKangXi=54.3
2231B CJK UNIFIED IDEOGRAPH-#2231B, IRGKangXi=0353.010, RSKangXi=54.5
2231C CJK UNIFIED IDEOGRAPH-#2231C, IRGKangXi=0353.021, RSKangXi=54.4
2231D CJK UNIFIED IDEOGRAPH-#2231D, IRGKangXi=0353.030, RSKangXi=54.5
2231E CJK UNIFIED IDEOGRAPH-#2231E, IRGKangXi=0353.031, RSKangXi=54.5
2231F CJK UNIFIED IDEOGRAPH-#2231F, IRGKangXi=0353.051, RSKangXi=54.6
22320 CJK UNIFIED IDEOGRAPH-#22320, IRGKangXi=0353.051, RSKangXi=54.7
22321 CJK UNIFIED IDEOGRAPH-#22321, IRGKangXi=0353.051, RSKangXi=54.7
22322 CJK UNIFIED IDEOGRAPH-#22322, IRGKangXi=0353.051, RSKangXi=54.7
22323 CJK UNIFIED IDEOGRAPH-#22323, IRGKangXi=0353.051, RSKangXi=54.7
22324 CJK UNIFIED IDEOGRAPH-#22324, IRGKangXi=0353.051, RSKangXi=54.7
22325 CJK UNIFIED IDEOGRAPH-#22325, IRGKangXi=0353.051, RSKangXi=54.7
22326 CJK UNIFIED IDEOGRAPH-#22326, IRGKangXi=0353.060, RSKangXi=54.8
22327 CJK UNIFIED IDEOGRAPH-#22327, IRGKangXi=0353.061, RSKangXi=54.8
22328 CJK UNIFIED IDEOGRAPH-#22328, IRGKangXi=0353.070, RSKangXi=54.9
22329 CJK UNIFIED IDEOGRAPH-#22329, IRGKangXi=0353.071, RSKangXi=54.9
2232A CJK UNIFIED IDEOGRAPH-#2232A, IRGKangXi=0353.071, RSKangXi=54.9
2232B CJK UNIFIED IDEOGRAPH-#2232B, IRGKangXi=0353.071, RSKangXi=54.10
2232C CJK UNIFIED IDEOGRAPH-#2232C, IRGKangXi=0353.101, RSKangXi=55.0
2232D CJK UNIFIED IDEOGRAPH-#2232D, IRGKangXi=0353.101, RSKangXi=55.1
2232E CJK UNIFIED IDEOGRAPH-#2232E, IRGKangXi=0353.111, RSKangXi=55.2
2232F CJK UNIFIED IDEOGRAPH-#2232F, IRGKangXi=0353.111, RSKangXi=55.2
22330 CJK UNIFIED IDEOGRAPH-#22330, IRGKangXi=0353.130, RSKangXi=55.3
22331 CJK UNIFIED IDEOGRAPH-#22331, IRGKangXi=0353.140, RSKangXi=55.3
22332 CJK UNIFIED IDEOGRAPH-#22332, IRGKangXi=0353.141, RSKangXi=55.3
22333 CJK UNIFIED IDEOGRAPH-#22333, IRGKangXi=0353.160, RSKangXi=55.4
22334 CJK UNIFIED IDEOGRAPH-#22334, IRGKangXi=0354.020, RSKangXi=55.6
22335 CJK UNIFIED IDEOGRAPH-#22335, IRGKangXi=0354.040, RSKangXi=55.4
22336 CJK UNIFIED IDEOGRAPH-#22336, IRGKangXi=0354.041, RSKangXi=55.4
22337 CJK UNIFIED IDEOGRAPH-#22337, IRGKangXi=0354.041, RSKangXi=55.4
22338 CJK UNIFIED IDEOGRAPH-#22338, IRGKangXi=0354.041, RSKangXi=55.4
22339 CJK UNIFIED IDEOGRAPH-#22339, IRGKangXi=0354.041, RSKangXi=55.4
2233A CJK UNIFIED IDEOGRAPH-#2233A, IRGKangXi=0354.041, RSKangXi=55.4
2233B CJK UNIFIED IDEOGRAPH-#2233B, IRGKangXi=0354.050, RSKangXi=55.5
2233C CJK UNIFIED IDEOGRAPH-#2233C, IRGKangXi=0354.060, RSKangXi=55.6
2233D CJK UNIFIED IDEOGRAPH-#2233D, IRGKangXi=0354.071, RSKangXi=55.5
2233E CJK UNIFIED IDEOGRAPH-#2233E, IRGKangXi=0354.071, RSKangXi=55.5
2233F CJK UNIFIED IDEOGRAPH-#2233F, IRGKangXi=0354.071, RSKangXi=55.5
22340 CJK UNIFIED IDEOGRAPH-#22340, IRGKangXi=0354.071, RSKangXi=55.5
22341 CJK UNIFIED IDEOGRAPH-#22341, IRGKangXi=0354.071, RSKangXi=55.5
22342 CJK UNIFIED IDEOGRAPH-#22342, IRGKangXi=0354.071, RSKangXi=55.6
22343 CJK UNIFIED IDEOGRAPH-#22343, IRGKangXi=0354.120, RSKangXi=55.6
22344 CJK UNIFIED IDEOGRAPH-#22344, IRGKangXi=0354.130, RSKangXi=55.6
22345 CJK UNIFIED IDEOGRAPH-#22345, IRGKangXi=0354.140, RSKangXi=55.6
22346 CJK UNIFIED IDEOGRAPH-#22346, IRGKangXi=0354.141, RSKangXi=55.6
22347 CJK UNIFIED IDEOGRAPH-#22347, IRGKangXi=0354.141, RSKangXi=55.6
22348 CJK UNIFIED IDEOGRAPH-#22348, IRGKangXi=0354.141, RSKangXi=55.6
22349 CJK UNIFIED IDEOGRAPH-#22349, IRGKangXi=0354.141, RSKangXi=55.6
2234A CJK UNIFIED IDEOGRAPH-#2234A, IRGKangXi=0354.141, RSKangXi=55.6
2234B CJK UNIFIED IDEOGRAPH-#2234B, IRGKangXi=0354.141, RSKangXi=55.6
2234C CJK UNIFIED IDEOGRAPH-#2234C, IRGKangXi=0354.141, RSKangXi=55.6
2234D CJK UNIFIED IDEOGRAPH-#2234D, IRGKangXi=0354.150, RSKangXi=55.7
2234E CJK UNIFIED IDEOGRAPH-#2234E, IRGKangXi=0354.160, RSKangXi=55.7
2234F CJK UNIFIED IDEOGRAPH-#2234F, IRGKangXi=0354.170, RSKangXi=55.7
22350 CJK UNIFIED IDEOGRAPH-#22350, IRGKangXi=0354.180, RSKangXi=55.7
22351 CJK UNIFIED IDEOGRAPH-#22351, IRGKangXi=0354.181, RSKangXi=55.7
22352 CJK UNIFIED IDEOGRAPH-#22352, IRGKangXi=0354.181, RSKangXi=55.7
22353 CJK UNIFIED IDEOGRAPH-#22353, IRGKangXi=0354.181, RSKangXi=55.7
22354 CJK UNIFIED IDEOGRAPH-#22354, IRGKangXi=0354.190, RSKangXi=55.8
22355 CJK UNIFIED IDEOGRAPH-#22355, IRGKangXi=0354.200, RSKangXi=55.8
22356 CJK UNIFIED IDEOGRAPH-#22356, IRGKangXi=0354.210, RSKangXi=55.8
22357 CJK UNIFIED IDEOGRAPH-#22357, IRGKangXi=0354.220, RSKangXi=55.8
22358 CJK UNIFIED IDEOGRAPH-#22358, IRGKangXi=0354.221, RSKangXi=55.8
22359 CJK UNIFIED IDEOGRAPH-#22359, IRGKangXi=0354.221, RSKangXi=55.8
2235A CJK UNIFIED IDEOGRAPH-#2235A, IRGKangXi=0354.230, RSKangXi=55.9
2235B CJK UNIFIED IDEOGRAPH-#2235B, IRGKangXi=0354.240, RSKangXi=55.9
2235C CJK UNIFIED IDEOGRAPH-#2235C, IRGKangXi=0354.250, RSKangXi=55.9
2235D CJK UNIFIED IDEOGRAPH-#2235D, IRGKangXi=0354.260, RSKangXi=55.9
2235E CJK UNIFIED IDEOGRAPH-#2235E, IRGKangXi=0354.270, RSKangXi=55.9
2235F CJK UNIFIED IDEOGRAPH-#2235F, IRGKangXi=0354.271, RSKangXi=55.9
22360 CJK UNIFIED IDEOGRAPH-#22360, IRGKangXi=0354.271, RSKangXi=55.9
22361 CJK UNIFIED IDEOGRAPH-#22361, IRGKangXi=0354.271, RSKangXi=55.9
22362 CJK UNIFIED IDEOGRAPH-#22362, IRGKangXi=0354.280, RSKangXi=55.10
22363 CJK UNIFIED IDEOGRAPH-#22363, IRGKangXi=0354.290, RSKangXi=55.10
22364 CJK UNIFIED IDEOGRAPH-#22364, IRGKangXi=0354.291, RSKangXi=55.10
22365 CJK UNIFIED IDEOGRAPH-#22365, IRGKangXi=0354.291, RSKangXi=55.10
22366 CJK UNIFIED IDEOGRAPH-#22366, IRGKangXi=0354.310, RSKangXi=55.11
22367 CJK UNIFIED IDEOGRAPH-#22367, IRGKangXi=0354.320, RSKangXi=55.11
22368 CJK UNIFIED IDEOGRAPH-#22368, IRGKangXi=0354.330, RSKangXi=55.11
22369 CJK UNIFIED IDEOGRAPH-#22369, IRGKangXi=0354.331, RSKangXi=55.11
2236A CJK UNIFIED IDEOGRAPH-#2236A, IRGKangXi=0354.331, RSKangXi=55.11
2236B CJK UNIFIED IDEOGRAPH-#2236B, IRGKangXi=0354.331, RSKangXi=55.11
2236C CJK UNIFIED IDEOGRAPH-#2236C, IRGKangXi=0354.350, RSKangXi=55.12
2236D CJK UNIFIED IDEOGRAPH-#2236D, IRGKangXi=0354.351, RSKangXi=17.12
2236E CJK UNIFIED IDEOGRAPH-#2236E, IRGKangXi=0354.360, RSKangXi=55.13
2236F CJK UNIFIED IDEOGRAPH-#2236F, IRGKangXi=0354.380, RSKangXi=55.13
22370 CJK UNIFIED IDEOGRAPH-#22370, IRGKangXi=0354.390, RSKangXi=55.13
22371 CJK UNIFIED IDEOGRAPH-#22371, IRGKangXi=0354.400, RSKangXi=55.13
22372 CJK UNIFIED IDEOGRAPH-#22372, IRGKangXi=0354.410, RSKangXi=55.14
22373 CJK UNIFIED IDEOGRAPH-#22373, IRGKangXi=0354.411, RSKangXi=55.14
22374 CJK UNIFIED IDEOGRAPH-#22374, IRGKangXi=0354.411, RSKangXi=55.14
22375 CJK UNIFIED IDEOGRAPH-#22375, IRGKangXi=0354.411, RSKangXi=55.16
22376 CJK UNIFIED IDEOGRAPH-#22376, IRGKangXi=0354.420, RSKangXi=55.19
22377 CJK UNIFIED IDEOGRAPH-#22377, IRGKangXi=0354.430, RSKangXi=55.24
22378 CJK UNIFIED IDEOGRAPH-#22378, IRGKangXi=0354.431, RSKangXi=55.24
22379 CJK UNIFIED IDEOGRAPH-#22379, IRGKangXi=0354.431, RSKangXi=55.26
2237A CJK UNIFIED IDEOGRAPH-#2237A, IRGKangXi=0355.011, RSKangXi=56.0
2237B CJK UNIFIED IDEOGRAPH-#2237B, IRGKangXi=0355.030, RSKangXi=56.1
2237C CJK UNIFIED IDEOGRAPH-#2237C, IRGKangXi=0355.031, RSKangXi=56.1
2237D CJK UNIFIED IDEOGRAPH-#2237D, IRGKangXi=0355.061, RSKangXi=56.3
2237E CJK UNIFIED IDEOGRAPH-#2237E, IRGKangXi=0355.061, RSKangXi=56.3
2237F CJK UNIFIED IDEOGRAPH-#2237F, IRGKangXi=0355.070, RSKangXi=56.4
22380 CJK UNIFIED IDEOGRAPH-#22380, IRGKangXi=0355.080, RSKangXi=56.4
22381 CJK UNIFIED IDEOGRAPH-#22381, IRGKangXi=0355.090, RSKangXi=56.4
22382 CJK UNIFIED IDEOGRAPH-#22382, IRGKangXi=0355.091, RSKangXi=56.4
22383 CJK UNIFIED IDEOGRAPH-#22383, IRGKangXi=0355.091, RSKangXi=56.4
22384 CJK UNIFIED IDEOGRAPH-#22384, IRGKangXi=0355.100, RSKangXi=56.5
22385 CJK UNIFIED IDEOGRAPH-#22385, IRGKangXi=0355.101, RSKangXi=56.5
22386 CJK UNIFIED IDEOGRAPH-#22386, IRGKangXi=0355.110, RSKangXi=56.6
22387 CJK UNIFIED IDEOGRAPH-#22387, IRGKangXi=0355.121, RSKangXi=56.6
22388 CJK UNIFIED IDEOGRAPH-#22388, IRGKangXi=0355.121, RSKangXi=56.6
22389 CJK UNIFIED IDEOGRAPH-#22389, IRGKangXi=0355.121, RSKangXi=56.6
2238A CJK UNIFIED IDEOGRAPH-#2238A, IRGKangXi=0355.121, RSKangXi=56.6
2238B CJK UNIFIED IDEOGRAPH-#2238B, IRGKangXi=0355.121, RSKangXi=56.7
2238C CJK UNIFIED IDEOGRAPH-#2238C, IRGKangXi=0355.121, RSKangXi=56.7
2238D CJK UNIFIED IDEOGRAPH-#2238D, IRGKangXi=0355.130, RSKangXi=56.8
2238E CJK UNIFIED IDEOGRAPH-#2238E, IRGKangXi=0355.141, RSKangXi=56.9
2238F CJK UNIFIED IDEOGRAPH-#2238F, IRGKangXi=0355.151, RSKangXi=56.10
22390 CJK UNIFIED IDEOGRAPH-#22390, IRGKangXi=0355.151, RSKangXi=56.10
22391 CJK UNIFIED IDEOGRAPH-#22391, IRGKangXi=0355.151, RSKangXi=56.12
22392 CJK UNIFIED IDEOGRAPH-#22392, IRGKangXi=0355.160, RSKangXi=56.12
22393 CJK UNIFIED IDEOGRAPH-#22393, IRGKangXi=0355.161, RSKangXi=56.13
22394 CJK UNIFIED IDEOGRAPH-#22394, IRGKangXi=0355.161, RSKangXi=56.14
22395 CJK UNIFIED IDEOGRAPH-#22395, IRGKangXi=0355.161, RSKangXi=56.15
22396 CJK UNIFIED IDEOGRAPH-#22396, IRGKangXi=0355.161, RSKangXi=56.18
22397 CJK UNIFIED IDEOGRAPH-#22397, IRGKangXi=0356.020, RSKangXi=57.0
22398 CJK UNIFIED IDEOGRAPH-#22398, IRGKangXi=0356.030, RSKangXi=57.0
22399 CJK UNIFIED IDEOGRAPH-#22399, IRGKangXi=0356.040, RSKangXi=57.1
2239A CJK UNIFIED IDEOGRAPH-#2239A, IRGKangXi=0356.050, RSKangXi=57.1
2239B CJK UNIFIED IDEOGRAPH-#2239B, IRGKangXi=0356.060, RSKangXi=57.1
2239C CJK UNIFIED IDEOGRAPH-#2239C, IRGKangXi=0356.100, RSKangXi=57.1
2239D CJK UNIFIED IDEOGRAPH-#2239D, IRGKangXi=0356.110, RSKangXi=57.1
2239E CJK UNIFIED IDEOGRAPH-#2239E, IRGKangXi=0356.121, RSKangXi=57.1
2239F CJK UNIFIED IDEOGRAPH-#2239F, IRGKangXi=0356.121, RSKangXi=57.1
223A0 CJK UNIFIED IDEOGRAPH-#223A0, IRGKangXi=0356.121, RSKangXi=57.1
223A1 CJK UNIFIED IDEOGRAPH-#223A1, IRGKangXi=0356.121, RSKangXi=57.1
223A2 CJK UNIFIED IDEOGRAPH-#223A2, IRGKangXi=0356.130, RSKangXi=57.2
223A3 CJK UNIFIED IDEOGRAPH-#223A3, IRGKangXi=0356.140, RSKangXi=57.2
223A4 CJK UNIFIED IDEOGRAPH-#223A4, IRGKangXi=0356.150, RSKangXi=57.2
223A5 CJK UNIFIED IDEOGRAPH-#223A5, IRGKangXi=0356.180, RSKangXi=57.2
223A6 CJK UNIFIED IDEOGRAPH-#223A6, IRGKangXi=0356.190, RSKangXi=57.2
223A7 CJK UNIFIED IDEOGRAPH-#223A7, IRGKangXi=0356.200, RSKangXi=57.2
223A8 CJK UNIFIED IDEOGRAPH-#223A8, IRGKangXi=0356.201, RSKangXi=57.2
223A9 CJK UNIFIED IDEOGRAPH-#223A9, IRGKangXi=0356.201, RSKangXi=57.2
223AA CJK UNIFIED IDEOGRAPH-#223AA, IRGKangXi=0356.201, RSKangXi=57.2
223AB CJK UNIFIED IDEOGRAPH-#223AB, IRGKangXi=0357.020, RSKangXi=57.3
223AC CJK UNIFIED IDEOGRAPH-#223AC, IRGKangXi=0357.030, RSKangXi=57.3
223AD CJK UNIFIED IDEOGRAPH-#223AD, IRGKangXi=0357.080, RSKangXi=57.3
223AE CJK UNIFIED IDEOGRAPH-#223AE, IRGKangXi=0357.100, RSKangXi=57.3
223AF CJK UNIFIED IDEOGRAPH-#223AF, IRGKangXi=0357.101, RSKangXi=57.3
223B0 CJK UNIFIED IDEOGRAPH-#223B0, IRGKangXi=0357.101, RSKangXi=57.3
223B1 CJK UNIFIED IDEOGRAPH-#223B1, IRGKangXi=0357.101, RSKangXi=57.3
223B2 CJK UNIFIED IDEOGRAPH-#223B2, IRGKangXi=0357.101, RSKangXi=57.3
223B3 CJK UNIFIED IDEOGRAPH-#223B3, IRGKangXi=0357.101, RSKangXi=57.3
223B4 CJK UNIFIED IDEOGRAPH-#223B4, IRGKangXi=0357.101, RSKangXi=57.3
223B5 CJK UNIFIED IDEOGRAPH-#223B5, IRGKangXi=0357.101, RSKangXi=57.3
223B6 CJK UNIFIED IDEOGRAPH-#223B6, IRGKangXi=0357.101, RSKangXi=57.3
223B7 CJK UNIFIED IDEOGRAPH-#223B7, IRGKangXi=0357.110, RSKangXi=57.4
223B8 CJK UNIFIED IDEOGRAPH-#223B8, IRGKangXi=0357.130, RSKangXi=57.4
223B9 CJK UNIFIED IDEOGRAPH-#223B9, IRGKangXi=0357.150, RSKangXi=57.4
223BA CJK UNIFIED IDEOGRAPH-#223BA, IRGKangXi=0357.200, RSKangXi=57.4
223BB CJK UNIFIED IDEOGRAPH-#223BB, IRGKangXi=0357.210, RSKangXi=57.4
223BC CJK UNIFIED IDEOGRAPH-#223BC, IRGKangXi=0357.211, RSKangXi=57.4
223BD CJK UNIFIED IDEOGRAPH-#223BD, IRGKangXi=0357.211, RSKangXi=57.4
223BE CJK UNIFIED IDEOGRAPH-#223BE, IRGKangXi=0357.211, RSKangXi=57.4
223BF CJK UNIFIED IDEOGRAPH-#223BF, IRGKangXi=0357.211, RSKangXi=57.4
223C0 CJK UNIFIED IDEOGRAPH-#223C0, IRGKangXi=0357.211, RSKangXi=57.4
223C1 CJK UNIFIED IDEOGRAPH-#223C1, IRGKangXi=0357.211, RSKangXi=57.4
223C2 CJK UNIFIED IDEOGRAPH-#223C2, IRGKangXi=0357.211, RSKangXi=57.4
223C3 CJK UNIFIED IDEOGRAPH-#223C3, IRGKangXi=0357.211, RSKangXi=57.4
223C4 CJK UNIFIED IDEOGRAPH-#223C4, IRGKangXi=0357.211, RSKangXi=57.4
223C5 CJK UNIFIED IDEOGRAPH-#223C5, IRGKangXi=0357.211, RSKangXi=57.4
223C6 CJK UNIFIED IDEOGRAPH-#223C6, IRGKangXi=0357.230, RSKangXi=57.5
223C7 CJK UNIFIED IDEOGRAPH-#223C7, IRGKangXi=0357.270, RSKangXi=57.5
223C8 CJK UNIFIED IDEOGRAPH-#223C8, IRGKangXi=0357.320, RSKangXi=57.5
223C9 CJK UNIFIED IDEOGRAPH-#223C9, IRGKangXi=0358.020, RSKangXi=57.5
223CA CJK UNIFIED IDEOGRAPH-#223CA, IRGKangXi=0358.031, RSKangXi=57.5
223CB CJK UNIFIED IDEOGRAPH-#223CB, IRGKangXi=0358.031, RSKangXi=57.5
223CC CJK UNIFIED IDEOGRAPH-#223CC, IRGKangXi=0358.031, RSKangXi=57.5
223CD CJK UNIFIED IDEOGRAPH-#223CD, IRGKangXi=0358.031, RSKangXi=57.5
223CE CJK UNIFIED IDEOGRAPH-#223CE, IRGKangXi=0358.031, RSKangXi=57.5
223CF CJK UNIFIED IDEOGRAPH-#223CF, IRGKangXi=0358.031, RSKangXi=57.5
223D0 CJK UNIFIED IDEOGRAPH-#223D0, IRGKangXi=0358.031, RSKangXi=57.5
223D1 CJK UNIFIED IDEOGRAPH-#223D1, IRGKangXi=0358.031, RSKangXi=57.5
223D2 CJK UNIFIED IDEOGRAPH-#223D2, IRGKangXi=0358.031, RSKangXi=57.5
223D3 CJK UNIFIED IDEOGRAPH-#223D3, IRGKangXi=0358.031, RSKangXi=57.5
223D4 CJK UNIFIED IDEOGRAPH-#223D4, IRGKangXi=0358.060, RSKangXi=57.6
223D5 CJK UNIFIED IDEOGRAPH-#223D5, IRGKangXi=0358.100, RSKangXi=57.6
223D6 CJK UNIFIED IDEOGRAPH-#223D6, IRGKangXi=0358.110, RSKangXi=57.6
223D7 CJK UNIFIED IDEOGRAPH-#223D7, IRGKangXi=0358.120, RSKangXi=57.6
223D8 CJK UNIFIED IDEOGRAPH-#223D8, IRGKangXi=0358.130, RSKangXi=57.6
223D9 CJK UNIFIED IDEOGRAPH-#223D9, IRGKangXi=0358.180, RSKangXi=57.6
223DA CJK UNIFIED IDEOGRAPH-#223DA, IRGKangXi=0358.190, RSKangXi=57.6
223DB CJK UNIFIED IDEOGRAPH-#223DB, IRGKangXi=0358.191, RSKangXi=57.6
223DC CJK UNIFIED IDEOGRAPH-#223DC, IRGKangXi=0358.191, RSKangXi=57.6
223DD CJK UNIFIED IDEOGRAPH-#223DD, IRGKangXi=0358.191, RSKangXi=57.6
223DE CJK UNIFIED IDEOGRAPH-#223DE, IRGKangXi=0358.191, RSKangXi=57.6
223DF CJK UNIFIED IDEOGRAPH-#223DF, IRGKangXi=0358.191, RSKangXi=57.6
223E0 CJK UNIFIED IDEOGRAPH-#223E0, IRGKangXi=0358.191, RSKangXi=57.6
223E1 CJK UNIFIED IDEOGRAPH-#223E1, IRGKangXi=0358.191, RSKangXi=57.6
223E2 CJK UNIFIED IDEOGRAPH-#223E2, IRGKangXi=0358.191, RSKangXi=57.6
223E3 CJK UNIFIED IDEOGRAPH-#223E3, IRGKangXi=0358.191, RSKangXi=57.6
223E4 CJK UNIFIED IDEOGRAPH-#223E4, IRGKangXi=0358.200, RSKangXi=57.7
223E5 CJK UNIFIED IDEOGRAPH-#223E5, IRGKangXi=0358.230, RSKangXi=57.7
223E6 CJK UNIFIED IDEOGRAPH-#223E6, IRGKangXi=0359.020, RSKangXi=57.7
223E7 CJK UNIFIED IDEOGRAPH-#223E7, IRGKangXi=0359.030, RSKangXi=57.7
223E8 CJK UNIFIED IDEOGRAPH-#223E8, IRGKangXi=0359.040, RSKangXi=57.7
223E9 CJK UNIFIED IDEOGRAPH-#223E9, IRGKangXi=0359.050, RSKangXi=57.7
223EA CJK UNIFIED IDEOGRAPH-#223EA, IRGKangXi=0359.060, RSKangXi=57.7
223EB CJK UNIFIED IDEOGRAPH-#223EB, IRGKangXi=0359.061, RSKangXi=57.7
223EC CJK UNIFIED IDEOGRAPH-#223EC, IRGKangXi=0359.061, RSKangXi=57.7
223ED CJK UNIFIED IDEOGRAPH-#223ED, IRGKangXi=0359.061, RSKangXi=57.7
223EE CJK UNIFIED IDEOGRAPH-#223EE, IRGKangXi=0359.070, RSKangXi=57.8
223EF CJK UNIFIED IDEOGRAPH-#223EF, IRGKangXi=0359.090, RSKangXi=57.8
223F0 CJK UNIFIED IDEOGRAPH-#223F0, IRGKangXi=0359.100, RSKangXi=57.8
223F1 CJK UNIFIED IDEOGRAPH-#223F1, IRGKangXi=0359.110, RSKangXi=57.8
223F2 CJK UNIFIED IDEOGRAPH-#223F2, IRGKangXi=0359.120, RSKangXi=57.8
223F3 CJK UNIFIED IDEOGRAPH-#223F3, IRGKangXi=0359.140, RSKangXi=57.8, Def{pulled taut}
223F4 CJK UNIFIED IDEOGRAPH-#223F4, IRGKangXi=0359.160, RSKangXi=57.8
223F5 CJK UNIFIED IDEOGRAPH-#223F5, IRGKangXi=0359.170, RSKangXi=57.8
223F6 CJK UNIFIED IDEOGRAPH-#223F6, IRGKangXi=0359.180, RSKangXi=57.8
223F7 CJK UNIFIED IDEOGRAPH-#223F7, IRGKangXi=0359.220, RSKangXi=57.8
223F8 CJK UNIFIED IDEOGRAPH-#223F8, IRGKangXi=0360.030, RSKangXi=57.8
223F9 CJK UNIFIED IDEOGRAPH-#223F9, IRGKangXi=0360.031, RSKangXi=57.8
223FA CJK UNIFIED IDEOGRAPH-#223FA, IRGKangXi=0360.031, RSKangXi=57.8
223FB CJK UNIFIED IDEOGRAPH-#223FB, IRGKangXi=0360.031, RSKangXi=57.8
223FC CJK UNIFIED IDEOGRAPH-#223FC, IRGKangXi=0360.031, RSKangXi=57.8
223FD CJK UNIFIED IDEOGRAPH-#223FD, IRGKangXi=0360.031, RSKangXi=57.8
223FE CJK UNIFIED IDEOGRAPH-#223FE, IRGKangXi=0360.031, RSKangXi=57.8
223FF CJK UNIFIED IDEOGRAPH-#223FF, IRGKangXi=0360.031, RSKangXi=57.8
22400 CJK UNIFIED IDEOGRAPH-#22400, IRGKangXi=0360.050, RSKangXi=57.9
22401 CJK UNIFIED IDEOGRAPH-#22401, IRGKangXi=0360.070, RSKangXi=57.9
22402 CJK UNIFIED IDEOGRAPH-#22402, IRGKangXi=0360.150, RSKangXi=57.9
22403 CJK UNIFIED IDEOGRAPH-#22403, IRGKangXi=0360.170, RSKangXi=57.9
22404 CJK UNIFIED IDEOGRAPH-#22404, IRGKangXi=0360.180, RSKangXi=57.9
22405 CJK UNIFIED IDEOGRAPH-#22405, IRGKangXi=0360.210, RSKangXi=57.9
22406 CJK UNIFIED IDEOGRAPH-#22406, IRGKangXi=0360.220, RSKangXi=57.9
22407 CJK UNIFIED IDEOGRAPH-#22407, IRGKangXi=0360.221, RSKangXi=57.9
22408 CJK UNIFIED IDEOGRAPH-#22408, IRGKangXi=0360.221, RSKangXi=57.9
22409 CJK UNIFIED IDEOGRAPH-#22409, IRGKangXi=0360.221, RSKangXi=57.9
2240A CJK UNIFIED IDEOGRAPH-#2240A, IRGKangXi=0360.230, RSKangXi=57.10
2240B CJK UNIFIED IDEOGRAPH-#2240B, IRGKangXi=0360.250, RSKangXi=57.10
2240C CJK UNIFIED IDEOGRAPH-#2240C, IRGKangXi=0360.300, RSKangXi=57.10
2240D CJK UNIFIED IDEOGRAPH-#2240D, IRGKangXi=0360.301, RSKangXi=57.10
2240E CJK UNIFIED IDEOGRAPH-#2240E, IRGKangXi=0360.301, RSKangXi=57.10
2240F CJK UNIFIED IDEOGRAPH-#2240F, IRGKangXi=0360.301, RSKangXi=57.10
22410 CJK UNIFIED IDEOGRAPH-#22410, IRGKangXi=0360.301, RSKangXi=57.10
22411 CJK UNIFIED IDEOGRAPH-#22411, IRGKangXi=0360.301, RSKangXi=57.10
22412 CJK UNIFIED IDEOGRAPH-#22412, IRGKangXi=0360.320, RSKangXi=57.11
22413 CJK UNIFIED IDEOGRAPH-#22413, IRGKangXi=0360.330, RSKangXi=57.11
22414 CJK UNIFIED IDEOGRAPH-#22414, IRGKangXi=0360.340, RSKangXi=57.11
22415 CJK UNIFIED IDEOGRAPH-#22415, IRGKangXi=0360.370, RSKangXi=57.11
22416 CJK UNIFIED IDEOGRAPH-#22416, IRGKangXi=0360.380, RSKangXi=57.11
22417 CJK UNIFIED IDEOGRAPH-#22417, IRGKangXi=0360.381, RSKangXi=57.11
22418 CJK UNIFIED IDEOGRAPH-#22418, IRGKangXi=0360.381, RSKangXi=57.11
22419 CJK UNIFIED IDEOGRAPH-#22419, IRGKangXi=0360.381, RSKangXi=57.11
2241A CJK UNIFIED IDEOGRAPH-#2241A, IRGKangXi=0360.381, RSKangXi=57.11
2241B CJK UNIFIED IDEOGRAPH-#2241B, IRGKangXi=0360.381, RSKangXi=57.11
2241C CJK UNIFIED IDEOGRAPH-#2241C, IRGKangXi=0360.381, RSKangXi=57.11
2241D CJK UNIFIED IDEOGRAPH-#2241D, IRGKangXi=0360.381, RSKangXi=57.11
2241E CJK UNIFIED IDEOGRAPH-#2241E, IRGKangXi=0360.420, RSKangXi=57.12
2241F CJK UNIFIED IDEOGRAPH-#2241F, IRGKangXi=0360.440, RSKangXi=57.12
22420 CJK UNIFIED IDEOGRAPH-#22420, IRGKangXi=0361.010, RSKangXi=57.12
22421 CJK UNIFIED IDEOGRAPH-#22421, IRGKangXi=0361.030, RSKangXi=57.12
22422 CJK UNIFIED IDEOGRAPH-#22422, IRGKangXi=0361.031, RSKangXi=57.12
22423 CJK UNIFIED IDEOGRAPH-#22423, IRGKangXi=0361.031, RSKangXi=57.12
22424 CJK UNIFIED IDEOGRAPH-#22424, IRGKangXi=0361.031, RSKangXi=57.12
22425 CJK UNIFIED IDEOGRAPH-#22425, IRGKangXi=0361.040, RSKangXi=57.13
22426 CJK UNIFIED IDEOGRAPH-#22426, IRGKangXi=0361.050, RSKangXi=57.13
22427 CJK UNIFIED IDEOGRAPH-#22427, IRGKangXi=0361.070, RSKangXi=57.13, Def{a stand, frame}
22428 CJK UNIFIED IDEOGRAPH-#22428, IRGKangXi=0361.090, RSKangXi=57.13
22429 CJK UNIFIED IDEOGRAPH-#22429, IRGKangXi=0361.100, RSKangXi=57.13
2242A CJK UNIFIED IDEOGRAPH-#2242A, IRGKangXi=0361.101, RSKangXi=57.13
2242B CJK UNIFIED IDEOGRAPH-#2242B, IRGKangXi=0361.101, RSKangXi=119.10
2242C CJK UNIFIED IDEOGRAPH-#2242C, IRGKangXi=0361.130, RSKangXi=57.14
2242D CJK UNIFIED IDEOGRAPH-#2242D, IRGKangXi=0361.140, RSKangXi=57.14
2242E CJK UNIFIED IDEOGRAPH-#2242E, IRGKangXi=0361.141, RSKangXi=57.14
2242F CJK UNIFIED IDEOGRAPH-#2242F, IRGKangXi=0361.141, RSKangXi=57.14
22430 CJK UNIFIED IDEOGRAPH-#22430, IRGKangXi=0361.141, RSKangXi=57.14
22431 CJK UNIFIED IDEOGRAPH-#22431, IRGKangXi=0361.141, RSKangXi=57.14
22432 CJK UNIFIED IDEOGRAPH-#22432, IRGKangXi=0361.160, RSKangXi=57.15
22433 CJK UNIFIED IDEOGRAPH-#22433, IRGKangXi=0361.170, RSKangXi=57.15
22434 CJK UNIFIED IDEOGRAPH-#22434, IRGKangXi=0361.171, RSKangXi=57.15
22435 CJK UNIFIED IDEOGRAPH-#22435, IRGKangXi=0361.171, RSKangXi=57.15
22436 CJK UNIFIED IDEOGRAPH-#22436, IRGKangXi=0361.171, RSKangXi=57.15
22437 CJK UNIFIED IDEOGRAPH-#22437, IRGKangXi=0361.171, RSKangXi=57.15
22438 CJK UNIFIED IDEOGRAPH-#22438, IRGKangXi=0361.180, RSKangXi=57.16
22439 CJK UNIFIED IDEOGRAPH-#22439, IRGKangXi=0361.190, RSKangXi=57.16
2243A CJK UNIFIED IDEOGRAPH-#2243A, IRGKangXi=0361.191, RSKangXi=57.16
2243B CJK UNIFIED IDEOGRAPH-#2243B, IRGKangXi=0361.191, RSKangXi=57.16
2243C CJK UNIFIED IDEOGRAPH-#2243C, IRGKangXi=0361.200, RSKangXi=57.16
2243D CJK UNIFIED IDEOGRAPH-#2243D, IRGKangXi=0361.201, RSKangXi=57.16
2243E CJK UNIFIED IDEOGRAPH-#2243E, IRGKangXi=0361.201, RSKangXi=57.16
2243F CJK UNIFIED IDEOGRAPH-#2243F, IRGKangXi=0361.210, RSKangXi=57.17
22440 CJK UNIFIED IDEOGRAPH-#22440, IRGKangXi=0361.220, RSKangXi=57.17
22441 CJK UNIFIED IDEOGRAPH-#22441, IRGKangXi=0361.230, RSKangXi=57.17
22442 CJK UNIFIED IDEOGRAPH-#22442, IRGKangXi=0361.231, RSKangXi=57.17
22443 CJK UNIFIED IDEOGRAPH-#22443, IRGKangXi=0361.231, RSKangXi=57.17
22444 CJK UNIFIED IDEOGRAPH-#22444, IRGKangXi=0361.231, RSKangXi=57.17
22445 CJK UNIFIED IDEOGRAPH-#22445, IRGKangXi=0361.231, RSKangXi=57.17
22446 CJK UNIFIED IDEOGRAPH-#22446, IRGKangXi=0361.240, RSKangXi=57.18
22447 CJK UNIFIED IDEOGRAPH-#22447, IRGKangXi=0361.260, RSKangXi=57.18
22448 CJK UNIFIED IDEOGRAPH-#22448, IRGKangXi=0361.270, RSKangXi=57.18
22449 CJK UNIFIED IDEOGRAPH-#22449, IRGKangXi=0361.271, RSKangXi=57.18
2244A CJK UNIFIED IDEOGRAPH-#2244A, IRGKangXi=0362.010, RSKangXi=57.19
2244B CJK UNIFIED IDEOGRAPH-#2244B, IRGKangXi=0362.021, RSKangXi=57.21
2244C CJK UNIFIED IDEOGRAPH-#2244C, IRGKangXi=0362.030, RSKangXi=57.22
2244D CJK UNIFIED IDEOGRAPH-#2244D, IRGKangXi=0362.031, RSKangXi=57.25
2244E CJK UNIFIED IDEOGRAPH-#2244E, IRGKangXi=0362.031, RSKangXi=57.29
2244F CJK UNIFIED IDEOGRAPH-#2244F, IRGKangXi=0362.060, RSKangXi=58.3
22450 CJK UNIFIED IDEOGRAPH-#22450, IRGKangXi=0362.061, RSKangXi=58.3
22451 CJK UNIFIED IDEOGRAPH-#22451, IRGKangXi=0362.061, RSKangXi=58.3
22452 CJK UNIFIED IDEOGRAPH-#22452, IRGKangXi=0362.061, RSKangXi=58.3
22453 CJK UNIFIED IDEOGRAPH-#22453, IRGKangXi=0362.070, RSKangXi=58.4
22454 CJK UNIFIED IDEOGRAPH-#22454, IRGKangXi=0362.100, RSKangXi=58.5
22455 CJK UNIFIED IDEOGRAPH-#22455, IRGKangXi=0362.110, RSKangXi=58.5
22456 CJK UNIFIED IDEOGRAPH-#22456, IRGKangXi=0362.111, RSKangXi=102.3
22457 CJK UNIFIED IDEOGRAPH-#22457, IRGKangXi=0362.130, RSKangXi=58.6
22458 CJK UNIFIED IDEOGRAPH-#22458, IRGKangXi=0362.140, RSKangXi=58.6
22459 CJK UNIFIED IDEOGRAPH-#22459, IRGKangXi=0362.150, RSKangXi=58.6
2245A CJK UNIFIED IDEOGRAPH-#2245A, IRGKangXi=0362.151, RSKangXi=58.6
2245B CJK UNIFIED IDEOGRAPH-#2245B, IRGKangXi=0362.151, RSKangXi=58.7
2245C CJK UNIFIED IDEOGRAPH-#2245C, IRGKangXi=0362.151, RSKangXi=58.7
2245D CJK UNIFIED IDEOGRAPH-#2245D, IRGKangXi=0362.151, RSKangXi=58.7
2245E CJK UNIFIED IDEOGRAPH-#2245E, IRGKangXi=0362.161, RSKangXi=58.8
2245F CJK UNIFIED IDEOGRAPH-#2245F, IRGKangXi=0362.161, RSKangXi=58.8
22460 CJK UNIFIED IDEOGRAPH-#22460, IRGKangXi=0362.161, RSKangXi=58.8
22461 CJK UNIFIED IDEOGRAPH-#22461, IRGKangXi=0362.161, RSKangXi=58.8
22462 CJK UNIFIED IDEOGRAPH-#22462, IRGKangXi=0362.180, RSKangXi=58.9
22463 CJK UNIFIED IDEOGRAPH-#22463, IRGKangXi=0362.190, RSKangXi=58.9
22464 CJK UNIFIED IDEOGRAPH-#22464, IRGKangXi=0362.191, RSKangXi=58.9
22465 CJK UNIFIED IDEOGRAPH-#22465, IRGKangXi=0362.191, RSKangXi=58.10
22466 CJK UNIFIED IDEOGRAPH-#22466, IRGKangXi=0362.200, RSKangXi=58.10
22467 CJK UNIFIED IDEOGRAPH-#22467, IRGKangXi=0362.211, RSKangXi=58.10
22468 CJK UNIFIED IDEOGRAPH-#22468, IRGKangXi=0362.220, RSKangXi=58.11
22469 CJK UNIFIED IDEOGRAPH-#22469, IRGKangXi=0362.221, RSKangXi=58.11
2246A CJK UNIFIED IDEOGRAPH-#2246A, IRGKangXi=0362.221, RSKangXi=58.11
2246B CJK UNIFIED IDEOGRAPH-#2246B, IRGKangXi=0362.221, RSKangXi=58.11
2246C CJK UNIFIED IDEOGRAPH-#2246C, IRGKangXi=0362.221, RSKangXi=58.11
2246D CJK UNIFIED IDEOGRAPH-#2246D, IRGKangXi=0362.230, RSKangXi=58.12
2246E CJK UNIFIED IDEOGRAPH-#2246E, IRGKangXi=0362.231, RSKangXi=58.12
2246F CJK UNIFIED IDEOGRAPH-#2246F, IRGKangXi=0362.251, RSKangXi=58.13
22470 CJK UNIFIED IDEOGRAPH-#22470, IRGKangXi=0362.251, RSKangXi=48.13
22471 CJK UNIFIED IDEOGRAPH-#22471, IRGKangXi=0362.251, RSKangXi=58.13
22472 CJK UNIFIED IDEOGRAPH-#22472, IRGKangXi=0362.251, RSKangXi=58.14
22473 CJK UNIFIED IDEOGRAPH-#22473, IRGKangXi=0362.291, RSKangXi=58.15
22474 CJK UNIFIED IDEOGRAPH-#22474, IRGKangXi=0362.291, RSKangXi=58.15
22475 CJK UNIFIED IDEOGRAPH-#22475, IRGKangXi=0362.291, RSKangXi=58.15
22476 CJK UNIFIED IDEOGRAPH-#22476, IRGKangXi=0362.291, RSKangXi=58.15
22477 CJK UNIFIED IDEOGRAPH-#22477, IRGKangXi=0362.300, RSKangXi=58.16
22478 CJK UNIFIED IDEOGRAPH-#22478, IRGKangXi=0362.310, RSKangXi=58.16
22479 CJK UNIFIED IDEOGRAPH-#22479, IRGKangXi=0362.311, RSKangXi=58.16
2247A CJK UNIFIED IDEOGRAPH-#2247A, IRGKangXi=0362.311, RSKangXi=58.16
2247B CJK UNIFIED IDEOGRAPH-#2247B, IRGKangXi=0362.311, RSKangXi=58.17
2247C CJK UNIFIED IDEOGRAPH-#2247C, IRGKangXi=0362.311, RSKangXi=58.17
2247D CJK UNIFIED IDEOGRAPH-#2247D, IRGKangXi=0362.311, RSKangXi=58.19
2247E CJK UNIFIED IDEOGRAPH-#2247E, IRGKangXi=0362.320, RSKangXi=58.20
2247F CJK UNIFIED IDEOGRAPH-#2247F, IRGKangXi=0363.010, RSKangXi=58.23
22480 CJK UNIFIED IDEOGRAPH-#22480, IRGKangXi=0363.030, RSKangXi=59.2
22481 CJK UNIFIED IDEOGRAPH-#22481, IRGKangXi=0363.031, RSKangXi=59.2
22482 CJK UNIFIED IDEOGRAPH-#22482, IRGKangXi=0363.031, RSKangXi=59.2
22483 CJK UNIFIED IDEOGRAPH-#22483, IRGKangXi=0363.050, RSKangXi=59.3
22484 CJK UNIFIED IDEOGRAPH-#22484, IRGKangXi=0363.051, RSKangXi=59.3
22485 CJK UNIFIED IDEOGRAPH-#22485, IRGKangXi=0363.051, RSKangXi=59.5
22486 CJK UNIFIED IDEOGRAPH-#22486, IRGKangXi=0363.051, RSKangXi=59.3
22487 CJK UNIFIED IDEOGRAPH-#22487, IRGKangXi=0363.081, RSKangXi=59.4
22488 CJK UNIFIED IDEOGRAPH-#22488, IRGKangXi=0363.081, RSKangXi=59.4
22489 CJK UNIFIED IDEOGRAPH-#22489, IRGKangXi=0363.100, RSKangXi=59.5, Def{a surname}
2248A CJK UNIFIED IDEOGRAPH-#2248A, IRGKangXi=0363.121, RSKangXi=59.5
2248B CJK UNIFIED IDEOGRAPH-#2248B, IRGKangXi=0363.121, RSKangXi=59.5
2248C CJK UNIFIED IDEOGRAPH-#2248C, IRGKangXi=0363.121, RSKangXi=59.5
2248D CJK UNIFIED IDEOGRAPH-#2248D, IRGKangXi=0363.121, RSKangXi=59.5
2248E CJK UNIFIED IDEOGRAPH-#2248E, IRGKangXi=0363.131, RSKangXi=59.6
2248F CJK UNIFIED IDEOGRAPH-#2248F, IRGKangXi=0363.150, RSKangXi=59.7
22490 CJK UNIFIED IDEOGRAPH-#22490, IRGKangXi=0363.160, RSKangXi=59.7
22491 CJK UNIFIED IDEOGRAPH-#22491, IRGKangXi=0363.170, RSKangXi=59.7
22492 CJK UNIFIED IDEOGRAPH-#22492, IRGKangXi=0363.171, RSKangXi=59.7
22493 CJK UNIFIED IDEOGRAPH-#22493, IRGKangXi=0363.171, RSKangXi=59.7
22494 CJK UNIFIED IDEOGRAPH-#22494, IRGKangXi=0363.180, RSKangXi=59.8
22495 CJK UNIFIED IDEOGRAPH-#22495, IRGKangXi=0363.200, RSKangXi=59.8
22496 CJK UNIFIED IDEOGRAPH-#22496, IRGKangXi=0364.010, RSKangXi=59.8
22497 CJK UNIFIED IDEOGRAPH-#22497, IRGKangXi=0364.020, RSKangXi=59.8
22498 CJK UNIFIED IDEOGRAPH-#22498, IRGKangXi=0364.021, RSKangXi=59.8
22499 CJK UNIFIED IDEOGRAPH-#22499, IRGKangXi=0364.021, RSKangXi=59.8
2249A CJK UNIFIED IDEOGRAPH-#2249A, IRGKangXi=0364.021, RSKangXi=59.8
2249B CJK UNIFIED IDEOGRAPH-#2249B, IRGKangXi=0364.021, RSKangXi=59.8
2249C CJK UNIFIED IDEOGRAPH-#2249C, IRGKangXi=0364.021, RSKangXi=59.8
2249D CJK UNIFIED IDEOGRAPH-#2249D, IRGKangXi=0364.021, RSKangXi=59.8
2249E CJK UNIFIED IDEOGRAPH-#2249E, IRGKangXi=0364.030, RSKangXi=59.9
2249F CJK UNIFIED IDEOGRAPH-#2249F, IRGKangXi=0364.040, RSKangXi=59.9
224A0 CJK UNIFIED IDEOGRAPH-#224A0, IRGKangXi=0364.060, RSKangXi=59.9
224A1 CJK UNIFIED IDEOGRAPH-#224A1, IRGKangXi=0364.070, RSKangXi=59.9
224A2 CJK UNIFIED IDEOGRAPH-#224A2, IRGKangXi=0364.081, RSKangXi=59.9
224A3 CJK UNIFIED IDEOGRAPH-#224A3, IRGKangXi=0364.081, RSKangXi=59.9
224A4 CJK UNIFIED IDEOGRAPH-#224A4, IRGKangXi=0364.090, RSKangXi=59.10
224A5 CJK UNIFIED IDEOGRAPH-#224A5, IRGKangXi=0364.110, RSKangXi=59.10
224A6 CJK UNIFIED IDEOGRAPH-#224A6, IRGKangXi=0364.120, RSKangXi=59.10
224A7 CJK UNIFIED IDEOGRAPH-#224A7, IRGKangXi=0364.130, RSKangXi=59.10
224A8 CJK UNIFIED IDEOGRAPH-#224A8, IRGKangXi=0364.131, RSKangXi=59.10
224A9 CJK UNIFIED IDEOGRAPH-#224A9, IRGKangXi=0364.170, RSKangXi=59.11
224AA CJK UNIFIED IDEOGRAPH-#224AA, IRGKangXi=0364.180, RSKangXi=59.11
224AB CJK UNIFIED IDEOGRAPH-#224AB, IRGKangXi=0364.200, RSKangXi=59.12
224AC CJK UNIFIED IDEOGRAPH-#224AC, IRGKangXi=0364.220, RSKangXi=59.12
224AD CJK UNIFIED IDEOGRAPH-#224AD, IRGKangXi=0364.230, RSKangXi=59.12
224AE CJK UNIFIED IDEOGRAPH-#224AE, IRGKangXi=0364.231, RSKangXi=59.12
224AF CJK UNIFIED IDEOGRAPH-#224AF, IRGKangXi=0364.231, RSKangXi=59.12
224B0 CJK UNIFIED IDEOGRAPH-#224B0, IRGKangXi=0364.250, RSKangXi=59.13
224B1 CJK UNIFIED IDEOGRAPH-#224B1, IRGKangXi=0364.251, RSKangXi=59.13
224B2 CJK UNIFIED IDEOGRAPH-#224B2, IRGKangXi=0364.251, RSKangXi=59.13
224B3 CJK UNIFIED IDEOGRAPH-#224B3, IRGKangXi=0364.251, RSKangXi=59.13
224B4 CJK UNIFIED IDEOGRAPH-#224B4, IRGKangXi=0364.260, RSKangXi=59.14
224B5 CJK UNIFIED IDEOGRAPH-#224B5, IRGKangXi=0364.270, RSKangXi=59.15
224B6 CJK UNIFIED IDEOGRAPH-#224B6, IRGKangXi=0364.271, RSKangXi=59.18
224B7 CJK UNIFIED IDEOGRAPH-#224B7, IRGKangXi=0364.271, RSKangXi=59.17
224B8 CJK UNIFIED IDEOGRAPH-#224B8, IRGKangXi=0364.290, RSKangXi=59.19
224B9 CJK UNIFIED IDEOGRAPH-#224B9, IRGKangXi=0364.300, RSKangXi=59.19, Def{surname}
224BA CJK UNIFIED IDEOGRAPH-#224BA, IRGKangXi=0364.301, RSKangXi=59.19
224BB CJK UNIFIED IDEOGRAPH-#224BB, IRGKangXi=0364.301, RSKangXi=59.22
224BC CJK UNIFIED IDEOGRAPH-#224BC, IRGKangXi=0365.011, RSKangXi=60.1
224BD CJK UNIFIED IDEOGRAPH-#224BD, IRGKangXi=0365.011, RSKangXi=60.1
224BE CJK UNIFIED IDEOGRAPH-#224BE, IRGKangXi=0365.020, RSKangXi=60.2
224BF CJK UNIFIED IDEOGRAPH-#224BF, IRGKangXi=0365.040, RSKangXi=60.2
224C0 CJK UNIFIED IDEOGRAPH-#224C0, IRGKangXi=0365.050, RSKangXi=60.3
224C1 CJK UNIFIED IDEOGRAPH-#224C1, IRGKangXi=0365.071, RSKangXi=60.3
224C2 CJK UNIFIED IDEOGRAPH-#224C2, IRGKangXi=0365.071, RSKangXi=60.3
224C3 CJK UNIFIED IDEOGRAPH-#224C3, IRGKangXi=0365.071, RSKangXi=60.3
224C4 CJK UNIFIED IDEOGRAPH-#224C4, IRGKangXi=0365.090, RSKangXi=60.4
224C5 CJK UNIFIED IDEOGRAPH-#224C5, IRGKangXi=0365.100, RSKangXi=60.4
224C6 CJK UNIFIED IDEOGRAPH-#224C6, IRGKangXi=0365.110, RSKangXi=60.4
224C7 CJK UNIFIED IDEOGRAPH-#224C7, IRGKangXi=0365.120, RSKangXi=60.4
224C8 CJK UNIFIED IDEOGRAPH-#224C8, IRGKangXi=0365.140, RSKangXi=60.4
224C9 CJK UNIFIED IDEOGRAPH-#224C9, IRGKangXi=0365.160, RSKangXi=60.4
224CA CJK UNIFIED IDEOGRAPH-#224CA, IRGKangXi=0365.170, RSKangXi=60.4
224CB CJK UNIFIED IDEOGRAPH-#224CB, IRGKangXi=0365.210, RSKangXi=60.4
224CC CJK UNIFIED IDEOGRAPH-#224CC, IRGKangXi=0365.211, RSKangXi=60.4
224CD CJK UNIFIED IDEOGRAPH-#224CD, IRGKangXi=0365.211, RSKangXi=60.4
224CE CJK UNIFIED IDEOGRAPH-#224CE, IRGKangXi=0365.211, RSKangXi=60.4
224CF CJK UNIFIED IDEOGRAPH-#224CF, IRGKangXi=0365.211, RSKangXi=60.4
224D0 CJK UNIFIED IDEOGRAPH-#224D0, IRGKangXi=0365.211, RSKangXi=60.4
224D1 CJK UNIFIED IDEOGRAPH-#224D1, IRGKangXi=0365.211, RSKangXi=60.4
224D2 CJK UNIFIED IDEOGRAPH-#224D2, IRGKangXi=0365.220, RSKangXi=60.5
224D3 CJK UNIFIED IDEOGRAPH-#224D3, IRGKangXi=0365.230, RSKangXi=60.5
224D4 CJK UNIFIED IDEOGRAPH-#224D4, IRGKangXi=0365.260, RSKangXi=60.5
224D5 CJK UNIFIED IDEOGRAPH-#224D5, IRGKangXi=0365.270, RSKangXi=60.5
224D6 CJK UNIFIED IDEOGRAPH-#224D6, IRGKangXi=0365.350, RSKangXi=60.5
224D7 CJK UNIFIED IDEOGRAPH-#224D7, IRGKangXi=0365.360, RSKangXi=60.5
224D8 CJK UNIFIED IDEOGRAPH-#224D8, IRGKangXi=0365.411, RSKangXi=60.5
224D9 CJK UNIFIED IDEOGRAPH-#224D9, IRGKangXi=0365.411, RSKangXi=60.5
224DA CJK UNIFIED IDEOGRAPH-#224DA, IRGKangXi=0365.411, RSKangXi=60.5
224DB CJK UNIFIED IDEOGRAPH-#224DB, IRGKangXi=0365.411, RSKangXi=60.5
224DC CJK UNIFIED IDEOGRAPH-#224DC, IRGKangXi=0366.020, RSKangXi=60.6
224DD CJK UNIFIED IDEOGRAPH-#224DD, IRGKangXi=0366.030, RSKangXi=60.6
224DE CJK UNIFIED IDEOGRAPH-#224DE, IRGKangXi=0366.070, RSKangXi=60.6
224DF CJK UNIFIED IDEOGRAPH-#224DF, IRGKangXi=0366.090, RSKangXi=60.6
224E0 CJK UNIFIED IDEOGRAPH-#224E0, IRGKangXi=0366.120, RSKangXi=60.6
224E1 CJK UNIFIED IDEOGRAPH-#224E1, IRGKangXi=0366.160, RSKangXi=60.6
224E2 CJK UNIFIED IDEOGRAPH-#224E2, IRGKangXi=0367.020, RSKangXi=60.6
224E3 CJK UNIFIED IDEOGRAPH-#224E3, IRGKangXi=0367.050, RSKangXi=60.6
224E4 CJK UNIFIED IDEOGRAPH-#224E4, IRGKangXi=0367.051, RSKangXi=60.6
224E5 CJK UNIFIED IDEOGRAPH-#224E5, IRGKangXi=0367.051, RSKangXi=60.6
224E6 CJK UNIFIED IDEOGRAPH-#224E6, IRGKangXi=0367.051, RSKangXi=60.6
224E7 CJK UNIFIED IDEOGRAPH-#224E7, IRGKangXi=0367.051, RSKangXi=60.6
224E8 CJK UNIFIED IDEOGRAPH-#224E8, IRGKangXi=0367.051, RSKangXi=60.6
224E9 CJK UNIFIED IDEOGRAPH-#224E9, IRGKangXi=0367.051, RSKangXi=60.6
224EA CJK UNIFIED IDEOGRAPH-#224EA, IRGKangXi=0367.070, RSKangXi=60.7
224EB CJK UNIFIED IDEOGRAPH-#224EB, IRGKangXi=0367.080, RSKangXi=60.7
224EC CJK UNIFIED IDEOGRAPH-#224EC, IRGKangXi=0367.090, RSKangXi=60.7
224ED CJK UNIFIED IDEOGRAPH-#224ED, IRGKangXi=0367.120, RSKangXi=60.7
224EE CJK UNIFIED IDEOGRAPH-#224EE, IRGKangXi=0367.130, RSKangXi=60.7
224EF CJK UNIFIED IDEOGRAPH-#224EF, IRGKangXi=0367.150, RSKangXi=60.7
224F0 CJK UNIFIED IDEOGRAPH-#224F0, IRGKangXi=0367.160, RSKangXi=60.7
224F1 CJK UNIFIED IDEOGRAPH-#224F1, IRGKangXi=0367.180, RSKangXi=60.7
224F2 CJK UNIFIED IDEOGRAPH-#224F2, IRGKangXi=0367.200, RSKangXi=60.7
224F3 CJK UNIFIED IDEOGRAPH-#224F3, IRGKangXi=0367.210, RSKangXi=60.7
224F4 CJK UNIFIED IDEOGRAPH-#224F4, IRGKangXi=0367.240, RSKangXi=60.7
224F5 CJK UNIFIED IDEOGRAPH-#224F5, IRGKangXi=0367.250, RSKangXi=60.7
224F6 CJK UNIFIED IDEOGRAPH-#224F6, IRGKangXi=0367.260, RSKangXi=60.7
224F7 CJK UNIFIED IDEOGRAPH-#224F7, IRGKangXi=0367.270, RSKangXi=60.7
224F8 CJK UNIFIED IDEOGRAPH-#224F8, IRGKangXi=0367.271, RSKangXi=60.7
224F9 CJK UNIFIED IDEOGRAPH-#224F9, IRGKangXi=0367.271, RSKangXi=60.7
224FA CJK UNIFIED IDEOGRAPH-#224FA, IRGKangXi=0367.271, RSKangXi=60.7
224FB CJK UNIFIED IDEOGRAPH-#224FB, IRGKangXi=0367.271, RSKangXi=60.7
224FC CJK UNIFIED IDEOGRAPH-#224FC, IRGKangXi=0367.271, RSKangXi=60.7
224FD CJK UNIFIED IDEOGRAPH-#224FD, IRGKangXi=0367.271, RSKangXi=60.7
224FE CJK UNIFIED IDEOGRAPH-#224FE, IRGKangXi=0367.271, RSKangXi=60.7
224FF CJK UNIFIED IDEOGRAPH-#224FF, IRGKangXi=0367.271, RSKangXi=60.7
22500 CJK UNIFIED IDEOGRAPH-#22500, IRGKangXi=0367.271, RSKangXi=60.7
22501 CJK UNIFIED IDEOGRAPH-#22501, IRGKangXi=0367.280, RSKangXi=60.8
22502 CJK UNIFIED IDEOGRAPH-#22502, IRGKangXi=0367.290, RSKangXi=60.8
22503 CJK UNIFIED IDEOGRAPH-#22503, IRGKangXi=0368.020, RSKangXi=60.8
22504 CJK UNIFIED IDEOGRAPH-#22504, IRGKangXi=0368.030, RSKangXi=60.8
22505 CJK UNIFIED IDEOGRAPH-#22505, IRGKangXi=0368.090, RSKangXi=60.8
22506 CJK UNIFIED IDEOGRAPH-#22506, IRGKangXi=0368.100, RSKangXi=60.8
22507 CJK UNIFIED IDEOGRAPH-#22507, IRGKangXi=0368.110, RSKangXi=60.8
22508 CJK UNIFIED IDEOGRAPH-#22508, IRGKangXi=0368.120, RSKangXi=60.8
22509 CJK UNIFIED IDEOGRAPH-#22509, IRGKangXi=0368.130, RSKangXi=60.8
2250A CJK UNIFIED IDEOGRAPH-#2250A, IRGKangXi=0368.160, RSKangXi=60.8
2250B CJK UNIFIED IDEOGRAPH-#2250B, IRGKangXi=0368.200, RSKangXi=60.8
2250C CJK UNIFIED IDEOGRAPH-#2250C, IRGKangXi=0368.220, RSKangXi=60.8
2250D CJK UNIFIED IDEOGRAPH-#2250D, IRGKangXi=0369.030, RSKangXi=60.8
2250E CJK UNIFIED IDEOGRAPH-#2250E, IRGKangXi=0369.050, RSKangXi=60.8
2250F CJK UNIFIED IDEOGRAPH-#2250F, IRGKangXi=0369.060, RSKangXi=60.8
22510 CJK UNIFIED IDEOGRAPH-#22510, IRGKangXi=0369.070, RSKangXi=60.8
22511 CJK UNIFIED IDEOGRAPH-#22511, IRGKangXi=0369.080, RSKangXi=60.8
22512 CJK UNIFIED IDEOGRAPH-#22512, IRGKangXi=0369.081, RSKangXi=60.8
22513 CJK UNIFIED IDEOGRAPH-#22513, IRGKangXi=0369.081, RSKangXi=60.8
22514 CJK UNIFIED IDEOGRAPH-#22514, IRGKangXi=0369.081, RSKangXi=60.8
22515 CJK UNIFIED IDEOGRAPH-#22515, IRGKangXi=0369.081, RSKangXi=60.8
22516 CJK UNIFIED IDEOGRAPH-#22516, IRGKangXi=0369.081, RSKangXi=60.8
22517 CJK UNIFIED IDEOGRAPH-#22517, IRGKangXi=0369.081, RSKangXi=60.8
22518 CJK UNIFIED IDEOGRAPH-#22518, IRGKangXi=0369.081, RSKangXi=60.8
22519 CJK UNIFIED IDEOGRAPH-#22519, IRGKangXi=0369.081, RSKangXi=60.8
2251A CJK UNIFIED IDEOGRAPH-#2251A, IRGKangXi=0369.081, RSKangXi=60.8
2251B CJK UNIFIED IDEOGRAPH-#2251B, IRGKangXi=0369.081, RSKangXi=60.8
2251C CJK UNIFIED IDEOGRAPH-#2251C, IRGKangXi=0369.081, RSKangXi=60.8
2251D CJK UNIFIED IDEOGRAPH-#2251D, IRGKangXi=0369.081, RSKangXi=60.8
2251E CJK UNIFIED IDEOGRAPH-#2251E, IRGKangXi=0369.081, RSKangXi=60.8
2251F CJK UNIFIED IDEOGRAPH-#2251F, IRGKangXi=0369.140, RSKangXi=60.9
22520 CJK UNIFIED IDEOGRAPH-#22520, IRGKangXi=0369.150, RSKangXi=60.9
22521 CJK UNIFIED IDEOGRAPH-#22521, IRGKangXi=0369.160, RSKangXi=60.9
22522 CJK UNIFIED IDEOGRAPH-#22522, IRGKangXi=0369.180, RSKangXi=60.9
22523 CJK UNIFIED IDEOGRAPH-#22523, IRGKangXi=0369.190, RSKangXi=60.9
22524 CJK UNIFIED IDEOGRAPH-#22524, IRGKangXi=0369.200, RSKangXi=60.9
22525 CJK UNIFIED IDEOGRAPH-#22525, IRGKangXi=0369.260, RSKangXi=60.9
22526 CJK UNIFIED IDEOGRAPH-#22526, IRGKangXi=0369.270, RSKangXi=60.9
22527 CJK UNIFIED IDEOGRAPH-#22527, IRGKangXi=0370.010, RSKangXi=60.9
22528 CJK UNIFIED IDEOGRAPH-#22528, IRGKangXi=0370.020, RSKangXi=60.9
22529 CJK UNIFIED IDEOGRAPH-#22529, IRGKangXi=0370.030, RSKangXi=60.9
2252A CJK UNIFIED IDEOGRAPH-#2252A, IRGKangXi=0370.040, RSKangXi=60.9
2252B CJK UNIFIED IDEOGRAPH-#2252B, IRGKangXi=0370.051, RSKangXi=60.9
2252C CJK UNIFIED IDEOGRAPH-#2252C, IRGKangXi=0370.051, RSKangXi=144.6
2252D CJK UNIFIED IDEOGRAPH-#2252D, IRGKangXi=0370.051, RSKangXi=60.9
2252E CJK UNIFIED IDEOGRAPH-#2252E, IRGKangXi=0370.051, RSKangXi=60.9
2252F CJK UNIFIED IDEOGRAPH-#2252F, IRGKangXi=0370.051, RSKangXi=60.9
22530 CJK UNIFIED IDEOGRAPH-#22530, IRGKangXi=0370.051, RSKangXi=60.9
22531 CJK UNIFIED IDEOGRAPH-#22531, IRGKangXi=0370.051, RSKangXi=60.9
22532 CJK UNIFIED IDEOGRAPH-#22532, IRGKangXi=0370.060, RSKangXi=60.10
22533 CJK UNIFIED IDEOGRAPH-#22533, IRGKangXi=0370.070, RSKangXi=60.10
22534 CJK UNIFIED IDEOGRAPH-#22534, IRGKangXi=0370.110, RSKangXi=60.10
22535 CJK UNIFIED IDEOGRAPH-#22535, IRGKangXi=0370.140, RSKangXi=60.10
22536 CJK UNIFIED IDEOGRAPH-#22536, IRGKangXi=0370.150, RSKangXi=60.10
22537 CJK UNIFIED IDEOGRAPH-#22537, IRGKangXi=0370.160, RSKangXi=60.10
22538 CJK UNIFIED IDEOGRAPH-#22538, IRGKangXi=0370.170, RSKangXi=60.10
22539 CJK UNIFIED IDEOGRAPH-#22539, IRGKangXi=0370.180, RSKangXi=60.10
2253A CJK UNIFIED IDEOGRAPH-#2253A, IRGKangXi=0370.191, RSKangXi=60.10
2253B CJK UNIFIED IDEOGRAPH-#2253B, IRGKangXi=0370.191, RSKangXi=60.10
2253C CJK UNIFIED IDEOGRAPH-#2253C, IRGKangXi=0370.191, RSKangXi=60.10
2253D CJK UNIFIED IDEOGRAPH-#2253D, IRGKangXi=0370.191, RSKangXi=60.10
2253E CJK UNIFIED IDEOGRAPH-#2253E, IRGKangXi=0370.191, RSKangXi=60.10
2253F CJK UNIFIED IDEOGRAPH-#2253F, IRGKangXi=0370.191, RSKangXi=60.10
22540 CJK UNIFIED IDEOGRAPH-#22540, IRGKangXi=0370.191, RSKangXi=60.10
22541 CJK UNIFIED IDEOGRAPH-#22541, IRGKangXi=0370.191, RSKangXi=60.10
22542 CJK UNIFIED IDEOGRAPH-#22542, IRGKangXi=0370.191, RSKangXi=60.10
22543 CJK UNIFIED IDEOGRAPH-#22543, IRGKangXi=0370.191, RSKangXi=60.10
22544 CJK UNIFIED IDEOGRAPH-#22544, IRGKangXi=0370.191, RSKangXi=60.10
22545 CJK UNIFIED IDEOGRAPH-#22545, IRGKangXi=0370.191, RSKangXi=60.10
22546 CJK UNIFIED IDEOGRAPH-#22546, IRGKangXi=0370.191, RSKangXi=60.10
22547 CJK UNIFIED IDEOGRAPH-#22547, IRGKangXi=0370.191, RSKangXi=60.10
22548 CJK UNIFIED IDEOGRAPH-#22548, IRGKangXi=0370.191, RSKangXi=60.10
22549 CJK UNIFIED IDEOGRAPH-#22549, IRGKangXi=0370.191, RSKangXi=60.10
2254A CJK UNIFIED IDEOGRAPH-#2254A, IRGKangXi=0370.191, RSKangXi=60.10
2254B CJK UNIFIED IDEOGRAPH-#2254B, IRGKangXi=0370.191, RSKangXi=60.10
2254C CJK UNIFIED IDEOGRAPH-#2254C, IRGKangXi=0370.191, RSKangXi=60.10
2254D CJK UNIFIED IDEOGRAPH-#2254D, IRGKangXi=0370.191, RSKangXi=60.10
2254E CJK UNIFIED IDEOGRAPH-#2254E, IRGKangXi=0370.191, RSKangXi=60.10
2254F CJK UNIFIED IDEOGRAPH-#2254F, IRGKangXi=0370.200, RSKangXi=60.11
22550 CJK UNIFIED IDEOGRAPH-#22550, IRGKangXi=0370.210, RSKangXi=60.11
22551 CJK UNIFIED IDEOGRAPH-#22551, IRGKangXi=0370.220, RSKangXi=60.11
22552 CJK UNIFIED IDEOGRAPH-#22552, IRGKangXi=0370.230, RSKangXi=60.11
22553 CJK UNIFIED IDEOGRAPH-#22553, IRGKangXi=0370.260, RSKangXi=60.11
22554 CJK UNIFIED IDEOGRAPH-#22554, IRGKangXi=0370.270, RSKangXi=60.11
22555 CJK UNIFIED IDEOGRAPH-#22555, IRGKangXi=0370.290, RSKangXi=60.11
22556 CJK UNIFIED IDEOGRAPH-#22556, IRGKangXi=0370.300, RSKangXi=60.11
22557 CJK UNIFIED IDEOGRAPH-#22557, IRGKangXi=0370.330, RSKangXi=60.11
22558 CJK UNIFIED IDEOGRAPH-#22558, IRGKangXi=0370.340, RSKangXi=60.11
22559 CJK UNIFIED IDEOGRAPH-#22559, IRGKangXi=0370.350, RSKangXi=60.11
2255A CJK UNIFIED IDEOGRAPH-#2255A, IRGKangXi=0370.360, RSKangXi=60.11
2255B CJK UNIFIED IDEOGRAPH-#2255B, IRGKangXi=0370.370, RSKangXi=60.11
2255C CJK UNIFIED IDEOGRAPH-#2255C, IRGKangXi=0370.380, RSKangXi=60.11
2255D CJK UNIFIED IDEOGRAPH-#2255D, IRGKangXi=0370.390, RSKangXi=60.11
2255E CJK UNIFIED IDEOGRAPH-#2255E, IRGKangXi=0370.400, RSKangXi=60.11
2255F CJK UNIFIED IDEOGRAPH-#2255F, IRGKangXi=0370.401, RSKangXi=60.11
22560 CJK UNIFIED IDEOGRAPH-#22560, IRGKangXi=0370.401, RSKangXi=60.11
22561 CJK UNIFIED IDEOGRAPH-#22561, IRGKangXi=0370.401, RSKangXi=60.11
22562 CJK UNIFIED IDEOGRAPH-#22562, IRGKangXi=0370.401, RSKangXi=60.11
22563 CJK UNIFIED IDEOGRAPH-#22563, IRGKangXi=0370.401, RSKangXi=60.11
22564 CJK UNIFIED IDEOGRAPH-#22564, IRGKangXi=0370.401, RSKangXi=60.11
22565 CJK UNIFIED IDEOGRAPH-#22565, IRGKangXi=0370.401, RSKangXi=60.11
22566 CJK UNIFIED IDEOGRAPH-#22566, IRGKangXi=0370.401, RSKangXi=60.11
22567 CJK UNIFIED IDEOGRAPH-#22567, IRGKangXi=0370.401, RSKangXi=60.10
22568 CJK UNIFIED IDEOGRAPH-#22568, IRGKangXi=0370.401, RSKangXi=60.11
22569 CJK UNIFIED IDEOGRAPH-#22569, IRGKangXi=0370.401, RSKangXi=60.11
2256A CJK UNIFIED IDEOGRAPH-#2256A, IRGKangXi=0371.050, RSKangXi=60.12
2256B CJK UNIFIED IDEOGRAPH-#2256B, IRGKangXi=0371.060, RSKangXi=60.12
2256C CJK UNIFIED IDEOGRAPH-#2256C, IRGKangXi=0371.130, RSKangXi=60.12
2256D CJK UNIFIED IDEOGRAPH-#2256D, IRGKangXi=0371.140, RSKangXi=60.12
2256E CJK UNIFIED IDEOGRAPH-#2256E, IRGKangXi=0371.150, RSKangXi=60.12
2256F CJK UNIFIED IDEOGRAPH-#2256F, IRGKangXi=0371.160, RSKangXi=60.12
22570 CJK UNIFIED IDEOGRAPH-#22570, IRGKangXi=0371.170, RSKangXi=60.12
22571 CJK UNIFIED IDEOGRAPH-#22571, IRGKangXi=0371.180, RSKangXi=60.12
22572 CJK UNIFIED IDEOGRAPH-#22572, IRGKangXi=0371.190, RSKangXi=60.12
22573 CJK UNIFIED IDEOGRAPH-#22573, IRGKangXi=0371.191, RSKangXi=60.12
22574 CJK UNIFIED IDEOGRAPH-#22574, IRGKangXi=0371.191, RSKangXi=60.12
22575 CJK UNIFIED IDEOGRAPH-#22575, IRGKangXi=0371.191, RSKangXi=60.12
22576 CJK UNIFIED IDEOGRAPH-#22576, IRGKangXi=0371.191, RSKangXi=60.12
22577 CJK UNIFIED IDEOGRAPH-#22577, IRGKangXi=0371.191, RSKangXi=60.12
22578 CJK UNIFIED IDEOGRAPH-#22578, IRGKangXi=0371.191, RSKangXi=60.12
22579 CJK UNIFIED IDEOGRAPH-#22579, IRGKangXi=0371.200, RSKangXi=60.13
2257A CJK UNIFIED IDEOGRAPH-#2257A, IRGKangXi=0371.230, RSKangXi=60.13
2257B CJK UNIFIED IDEOGRAPH-#2257B, IRGKangXi=0371.250, RSKangXi=60.13
2257C CJK UNIFIED IDEOGRAPH-#2257C, IRGKangXi=0371.260, RSKangXi=60.13
2257D CJK UNIFIED IDEOGRAPH-#2257D, IRGKangXi=0372.010, RSKangXi=60.13
2257E CJK UNIFIED IDEOGRAPH-#2257E, IRGKangXi=0372.020, RSKangXi=60.13
2257F CJK UNIFIED IDEOGRAPH-#2257F, IRGKangXi=0372.021, RSKangXi=60.13
22580 CJK UNIFIED IDEOGRAPH-#22580, IRGKangXi=0372.021, RSKangXi=60.13
22581 CJK UNIFIED IDEOGRAPH-#22581, IRGKangXi=0372.021, RSKangXi=60.13
22582 CJK UNIFIED IDEOGRAPH-#22582, IRGKangXi=0372.021, RSKangXi=60.13
22583 CJK UNIFIED IDEOGRAPH-#22583, IRGKangXi=0372.021, RSKangXi=60.13
22584 CJK UNIFIED IDEOGRAPH-#22584, IRGKangXi=0372.021, RSKangXi=60.13
22585 CJK UNIFIED IDEOGRAPH-#22585, IRGKangXi=0372.021, RSKangXi=144.10
22586 CJK UNIFIED IDEOGRAPH-#22586, IRGKangXi=0372.021, RSKangXi=60.13
22587 CJK UNIFIED IDEOGRAPH-#22587, IRGKangXi=0372.021, RSKangXi=60.13
22588 CJK UNIFIED IDEOGRAPH-#22588, IRGKangXi=0372.060, RSKangXi=60.14
22589 CJK UNIFIED IDEOGRAPH-#22589, IRGKangXi=0372.070, RSKangXi=60.14
2258A CJK UNIFIED IDEOGRAPH-#2258A, IRGKangXi=0372.080, RSKangXi=60.14
2258B CJK UNIFIED IDEOGRAPH-#2258B, IRGKangXi=0372.081, RSKangXi=144.11
2258C CJK UNIFIED IDEOGRAPH-#2258C, IRGKangXi=0372.081, RSKangXi=60.14
2258D CJK UNIFIED IDEOGRAPH-#2258D, IRGKangXi=0372.081, RSKangXi=60.14
2258E CJK UNIFIED IDEOGRAPH-#2258E, IRGKangXi=0372.081, RSKangXi=60.14
2258F CJK UNIFIED IDEOGRAPH-#2258F, IRGKangXi=0372.090, RSKangXi=60.15
22590 CJK UNIFIED IDEOGRAPH-#22590, IRGKangXi=0372.100, RSKangXi=60.15
22591 CJK UNIFIED IDEOGRAPH-#22591, IRGKangXi=0372.110, RSKangXi=60.15
22592 CJK UNIFIED IDEOGRAPH-#22592, IRGKangXi=0372.120, RSKangXi=60.15
22593 CJK UNIFIED IDEOGRAPH-#22593, IRGKangXi=0372.121, RSKangXi=60.15
22594 CJK UNIFIED IDEOGRAPH-#22594, IRGKangXi=0372.121, RSKangXi=60.15
22595 CJK UNIFIED IDEOGRAPH-#22595, IRGKangXi=0372.121, RSKangXi=60.15
22596 CJK UNIFIED IDEOGRAPH-#22596, IRGKangXi=0372.121, RSKangXi=60.15
22597 CJK UNIFIED IDEOGRAPH-#22597, IRGKangXi=0372.121, RSKangXi=60.15
22598 CJK UNIFIED IDEOGRAPH-#22598, IRGKangXi=0372.140, RSKangXi=60.16
22599 CJK UNIFIED IDEOGRAPH-#22599, IRGKangXi=0372.150, RSKangXi=60.16
2259A CJK UNIFIED IDEOGRAPH-#2259A, IRGKangXi=0372.160, RSKangXi=60.16
2259B CJK UNIFIED IDEOGRAPH-#2259B, IRGKangXi=0372.161, RSKangXi=203.7
2259C CJK UNIFIED IDEOGRAPH-#2259C, IRGKangXi=0372.161, RSKangXi=60.16
2259D CJK UNIFIED IDEOGRAPH-#2259D, IRGKangXi=0372.170, RSKangXi=60.17
2259E CJK UNIFIED IDEOGRAPH-#2259E, IRGKangXi=0372.180, RSKangXi=60.17
2259F CJK UNIFIED IDEOGRAPH-#2259F, IRGKangXi=0372.190, RSKangXi=60.17
225A0 CJK UNIFIED IDEOGRAPH-#225A0, IRGKangXi=0372.201, RSKangXi=60.17
225A1 CJK UNIFIED IDEOGRAPH-#225A1, IRGKangXi=0372.201, RSKangXi=144.14
225A2 CJK UNIFIED IDEOGRAPH-#225A2, IRGKangXi=0372.201, RSKangXi=60.17
225A3 CJK UNIFIED IDEOGRAPH-#225A3, IRGKangXi=0372.220, RSKangXi=60.18
225A4 CJK UNIFIED IDEOGRAPH-#225A4, IRGKangXi=0372.230, RSKangXi=60.18
225A5 CJK UNIFIED IDEOGRAPH-#225A5, IRGKangXi=0372.240, RSKangXi=60.19
225A6 CJK UNIFIED IDEOGRAPH-#225A6, IRGKangXi=0372.250, RSKangXi=60.20
225A7 CJK UNIFIED IDEOGRAPH-#225A7, IRGKangXi=0372.260, RSKangXi=60.22
225A8 CJK UNIFIED IDEOGRAPH-#225A8, IRGKangXi=0372.261, RSKangXi=60.24
225A9 CJK UNIFIED IDEOGRAPH-#225A9, IRGKangXi=0375.011, RSKangXi=61.-1
225AA CJK UNIFIED IDEOGRAPH-#225AA, IRGKangXi=0375.030, RSKangXi=61.1
225AB CJK UNIFIED IDEOGRAPH-#225AB, IRGKangXi=0375.060, RSKangXi=61.2
225AC CJK UNIFIED IDEOGRAPH-#225AC, IRGKangXi=0375.090, RSKangXi=61.2
225AD CJK UNIFIED IDEOGRAPH-#225AD, IRGKangXi=0375.100, RSKangXi=61.2
225AE CJK UNIFIED IDEOGRAPH-#225AE, IRGKangXi=0375.111, RSKangXi=61.2
225AF CJK UNIFIED IDEOGRAPH-#225AF, IRGKangXi=0375.111, RSKangXi=61.2
225B0 CJK UNIFIED IDEOGRAPH-#225B0, IRGKangXi=0375.111, RSKangXi=61.2
225B1 CJK UNIFIED IDEOGRAPH-#225B1, IRGKangXi=0375.111, RSKangXi=61.2
225B2 CJK UNIFIED IDEOGRAPH-#225B2, IRGKangXi=0376.030, RSKangXi=61.3
225B3 CJK UNIFIED IDEOGRAPH-#225B3, IRGKangXi=0376.120, RSKangXi=61.3
225B4 CJK UNIFIED IDEOGRAPH-#225B4, IRGKangXi=0376.140, RSKangXi=61.3
225B5 CJK UNIFIED IDEOGRAPH-#225B5, IRGKangXi=0376.170, RSKangXi=61.3
225B6 CJK UNIFIED IDEOGRAPH-#225B6, IRGKangXi=0376.190, RSKangXi=61.3
225B7 CJK UNIFIED IDEOGRAPH-#225B7, IRGKangXi=0376.200, RSKangXi=61.3
225B8 CJK UNIFIED IDEOGRAPH-#225B8, IRGKangXi=0376.230, RSKangXi=61.3
225B9 CJK UNIFIED IDEOGRAPH-#225B9, IRGKangXi=0377.020, RSKangXi=61.3
225BA CJK UNIFIED IDEOGRAPH-#225BA, IRGKangXi=0377.040, RSKangXi=61.3
225BB CJK UNIFIED IDEOGRAPH-#225BB, IRGKangXi=0377.070, RSKangXi=61.3
225BC CJK UNIFIED IDEOGRAPH-#225BC, IRGKangXi=0377.071, RSKangXi=61.3
225BD CJK UNIFIED IDEOGRAPH-#225BD, IRGKangXi=0377.071, RSKangXi=61.3
225BE CJK UNIFIED IDEOGRAPH-#225BE, IRGKangXi=0377.071, RSKangXi=61.3
225BF CJK UNIFIED IDEOGRAPH-#225BF, IRGKangXi=0377.071, RSKangXi=61.3
225C0 CJK UNIFIED IDEOGRAPH-#225C0, IRGKangXi=0377.071, RSKangXi=61.3
225C1 CJK UNIFIED IDEOGRAPH-#225C1, IRGKangXi=0377.071, RSKangXi=61.3
225C2 CJK UNIFIED IDEOGRAPH-#225C2, IRGKangXi=0377.071, RSKangXi=61.3
225C3 CJK UNIFIED IDEOGRAPH-#225C3, IRGKangXi=0377.071, RSKangXi=61.3
225C4 CJK UNIFIED IDEOGRAPH-#225C4, IRGKangXi=0377.071, RSKangXi=61.3
225C5 CJK UNIFIED IDEOGRAPH-#225C5, IRGKangXi=0377.071, RSKangXi=61.3
225C6 CJK UNIFIED IDEOGRAPH-#225C6, IRGKangXi=0377.071, RSKangXi=61.3
225C7 CJK UNIFIED IDEOGRAPH-#225C7, IRGKangXi=0377.071, RSKangXi=61.3
225C8 CJK UNIFIED IDEOGRAPH-#225C8, IRGKangXi=0377.071, RSKangXi=61.3
225C9 CJK UNIFIED IDEOGRAPH-#225C9, IRGKangXi=0377.120, RSKangXi=61.4
225CA CJK UNIFIED IDEOGRAPH-#225CA, IRGKangXi=0377.190, RSKangXi=61.4
225CB CJK UNIFIED IDEOGRAPH-#225CB, IRGKangXi=0377.240, RSKangXi=61.4
225CC CJK UNIFIED IDEOGRAPH-#225CC, IRGKangXi=0377.280, RSKangXi=61.4
225CD CJK UNIFIED IDEOGRAPH-#225CD, IRGKangXi=0378.040, RSKangXi=61.4
225CE CJK UNIFIED IDEOGRAPH-#225CE, IRGKangXi=0378.090, RSKangXi=61.4
225CF CJK UNIFIED IDEOGRAPH-#225CF, IRGKangXi=0378.100, RSKangXi=61.4
225D0 CJK UNIFIED IDEOGRAPH-#225D0, IRGKangXi=0378.140, RSKangXi=61.4
225D1 CJK UNIFIED IDEOGRAPH-#225D1, IRGKangXi=0378.160, RSKangXi=61.4
225D2 CJK UNIFIED IDEOGRAPH-#225D2, IRGKangXi=0378.170, RSKangXi=61.4
225D3 CJK UNIFIED IDEOGRAPH-#225D3, IRGKangXi=0378.240, RSKangXi=61.4
225D4 CJK UNIFIED IDEOGRAPH-#225D4, IRGKangXi=0378.260, RSKangXi=61.4
225D5 CJK UNIFIED IDEOGRAPH-#225D5, IRGKangXi=0378.280, RSKangXi=61.4
225D6 CJK UNIFIED IDEOGRAPH-#225D6, IRGKangXi=0379.030, RSKangXi=61.4
225D7 CJK UNIFIED IDEOGRAPH-#225D7, IRGKangXi=0379.040, RSKangXi=61.4
225D8 CJK UNIFIED IDEOGRAPH-#225D8, IRGKangXi=0379.060, RSKangXi=61.4
225D9 CJK UNIFIED IDEOGRAPH-#225D9, IRGKangXi=0379.071, RSKangXi=61.4
225DA CJK UNIFIED IDEOGRAPH-#225DA, IRGKangXi=0379.071, RSKangXi=61.4
225DB CJK UNIFIED IDEOGRAPH-#225DB, IRGKangXi=0379.071, RSKangXi=61.4
225DC CJK UNIFIED IDEOGRAPH-#225DC, IRGKangXi=0379.071, RSKangXi=61.4
225DD CJK UNIFIED IDEOGRAPH-#225DD, IRGKangXi=0379.071, RSKangXi=61.4
225DE CJK UNIFIED IDEOGRAPH-#225DE, IRGKangXi=0379.071, RSKangXi=61.4
225DF CJK UNIFIED IDEOGRAPH-#225DF, IRGKangXi=0379.071, RSKangXi=61.4
225E0 CJK UNIFIED IDEOGRAPH-#225E0, IRGKangXi=0379.071, RSKangXi=61.4
225E1 CJK UNIFIED IDEOGRAPH-#225E1, IRGKangXi=0379.071, RSKangXi=61.4
225E2 CJK UNIFIED IDEOGRAPH-#225E2, IRGKangXi=0379.071, RSKangXi=61.4
225E3 CJK UNIFIED IDEOGRAPH-#225E3, IRGKangXi=0379.071, RSKangXi=61.4
225E4 CJK UNIFIED IDEOGRAPH-#225E4, IRGKangXi=0379.071, RSKangXi=61.4
225E5 CJK UNIFIED IDEOGRAPH-#225E5, IRGKangXi=0379.071, RSKangXi=61.4
225E6 CJK UNIFIED IDEOGRAPH-#225E6, IRGKangXi=0379.071, RSKangXi=61.4
225E7 CJK UNIFIED IDEOGRAPH-#225E7, IRGKangXi=0379.071, RSKangXi=61.4
225E8 CJK UNIFIED IDEOGRAPH-#225E8, IRGKangXi=0379.071, RSKangXi=61.4
225E9 CJK UNIFIED IDEOGRAPH-#225E9, IRGKangXi=0379.071, RSKangXi=61.4
225EA CJK UNIFIED IDEOGRAPH-#225EA, IRGKangXi=0379.071, RSKangXi=61.4
225EB CJK UNIFIED IDEOGRAPH-#225EB, IRGKangXi=0379.071, RSKangXi=61.4
225EC CJK UNIFIED IDEOGRAPH-#225EC, IRGKangXi=0379.071, RSKangXi=61.4
225ED CJK UNIFIED IDEOGRAPH-#225ED, IRGKangXi=0379.071, RSKangXi=61.4
225EE CJK UNIFIED IDEOGRAPH-#225EE, IRGKangXi=0379.071, RSKangXi=61.4
225EF CJK UNIFIED IDEOGRAPH-#225EF, IRGKangXi=0379.071, RSKangXi=61.4
225F0 CJK UNIFIED IDEOGRAPH-#225F0, IRGKangXi=0379.071, RSKangXi=61.4
225F1 CJK UNIFIED IDEOGRAPH-#225F1, IRGKangXi=0379.071, RSKangXi=61.4
225F2 CJK UNIFIED IDEOGRAPH-#225F2, IRGKangXi=0379.071, RSKangXi=61.4
225F3 CJK UNIFIED IDEOGRAPH-#225F3, IRGKangXi=0379.071, RSKangXi=61.4
225F4 CJK UNIFIED IDEOGRAPH-#225F4, IRGKangXi=0379.071, RSKangXi=61.4
225F5 CJK UNIFIED IDEOGRAPH-#225F5, IRGKangXi=0379.071, RSKangXi=61.4
225F6 CJK UNIFIED IDEOGRAPH-#225F6, IRGKangXi=0379.071, RSKangXi=61.4
225F7 CJK UNIFIED IDEOGRAPH-#225F7, IRGKangXi=0379.071, RSKangXi=61.4
225F8 CJK UNIFIED IDEOGRAPH-#225F8, IRGKangXi=0379.071, RSKangXi=61.4
225F9 CJK UNIFIED IDEOGRAPH-#225F9, IRGKangXi=0379.071, RSKangXi=61.4
225FA CJK UNIFIED IDEOGRAPH-#225FA, IRGKangXi=0379.071, RSKangXi=61.4
225FB CJK UNIFIED IDEOGRAPH-#225FB, IRGKangXi=0379.071, RSKangXi=61.4
225FC CJK UNIFIED IDEOGRAPH-#225FC, IRGKangXi=0379.071, RSKangXi=61.4
225FD CJK UNIFIED IDEOGRAPH-#225FD, IRGKangXi=0379.071, RSKangXi=61.4
225FE CJK UNIFIED IDEOGRAPH-#225FE, IRGKangXi=0379.071, RSKangXi=61.4
225FF CJK UNIFIED IDEOGRAPH-#225FF, IRGKangXi=0379.090, RSKangXi=61.5
22600 CJK UNIFIED IDEOGRAPH-#22600, IRGKangXi=0380.010, RSKangXi=61.5
22601 CJK UNIFIED IDEOGRAPH-#22601, IRGKangXi=0380.050, RSKangXi=61.5
22602 CJK UNIFIED IDEOGRAPH-#22602, IRGKangXi=0380.100, RSKangXi=61.5
22603 CJK UNIFIED IDEOGRAPH-#22603, IRGKangXi=0380.120, RSKangXi=61.5
22604 CJK UNIFIED IDEOGRAPH-#22604, IRGKangXi=0380.130, RSKangXi=61.5
22605 CJK UNIFIED IDEOGRAPH-#22605, IRGKangXi=0380.150, RSKangXi=61.5, Def{(Cant.) flurried, flustered; arbitrariliy}
22606 CJK UNIFIED IDEOGRAPH-#22606, IRGKangXi=0380.230, RSKangXi=61.5
22607 CJK UNIFIED IDEOGRAPH-#22607, IRGKangXi=0381.010, RSKangXi=61.5
22608 CJK UNIFIED IDEOGRAPH-#22608, IRGKangXi=0381.020, RSKangXi=61.5
22609 CJK UNIFIED IDEOGRAPH-#22609, IRGKangXi=0381.100, RSKangXi=61.5
2260A CJK UNIFIED IDEOGRAPH-#2260A, IRGKangXi=0381.110, RSKangXi=61.5
2260B CJK UNIFIED IDEOGRAPH-#2260B, IRGKangXi=0382.070, RSKangXi=61.5
2260C CJK UNIFIED IDEOGRAPH-#2260C, IRGKangXi=0382.110, RSKangXi=61.5
2260D CJK UNIFIED IDEOGRAPH-#2260D, IRGKangXi=0382.120, RSKangXi=61.5
2260E CJK UNIFIED IDEOGRAPH-#2260E, IRGKangXi=0382.140, RSKangXi=61.5
2260F CJK UNIFIED IDEOGRAPH-#2260F, IRGKangXi=0383.030, RSKangXi=61.5
22610 CJK UNIFIED IDEOGRAPH-#22610, IRGKangXi=0383.040, RSKangXi=61.5
22611 CJK UNIFIED IDEOGRAPH-#22611, IRGKangXi=0383.050, RSKangXi=61.5
22612 CJK UNIFIED IDEOGRAPH-#22612, IRGKangXi=0383.060, RSKangXi=61.5
22613 CJK UNIFIED IDEOGRAPH-#22613, IRGKangXi=0383.070, RSKangXi=61.5
22614 CJK UNIFIED IDEOGRAPH-#22614, IRGKangXi=0383.080, RSKangXi=61.5
22615 CJK UNIFIED IDEOGRAPH-#22615, IRGKangXi=0383.090, RSKangXi=61.5
22616 CJK UNIFIED IDEOGRAPH-#22616, IRGKangXi=0383.100, RSKangXi=61.5
22617 CJK UNIFIED IDEOGRAPH-#22617, IRGKangXi=0383.111, RSKangXi=61.5
22618 CJK UNIFIED IDEOGRAPH-#22618, IRGKangXi=0383.111, RSKangXi=61.5
22619 CJK UNIFIED IDEOGRAPH-#22619, IRGKangXi=0383.111, RSKangXi=61.5
2261A CJK UNIFIED IDEOGRAPH-#2261A, IRGKangXi=0383.111, RSKangXi=61.5
2261B CJK UNIFIED IDEOGRAPH-#2261B, IRGKangXi=0383.111, RSKangXi=61.5
2261C CJK UNIFIED IDEOGRAPH-#2261C, IRGKangXi=0383.111, RSKangXi=61.5
2261D CJK UNIFIED IDEOGRAPH-#2261D, IRGKangXi=0383.111, RSKangXi=61.5
2261E CJK UNIFIED IDEOGRAPH-#2261E, IRGKangXi=0383.111, RSKangXi=61.5
2261F CJK UNIFIED IDEOGRAPH-#2261F, IRGKangXi=0383.111, RSKangXi=61.5
22620 CJK UNIFIED IDEOGRAPH-#22620, IRGKangXi=0383.111, RSKangXi=61.5
22621 CJK UNIFIED IDEOGRAPH-#22621, IRGKangXi=0383.111, RSKangXi=61.5
22622 CJK UNIFIED IDEOGRAPH-#22622, IRGKangXi=0383.111, RSKangXi=61.5
22623 CJK UNIFIED IDEOGRAPH-#22623, IRGKangXi=0383.111, RSKangXi=61.5
22624 CJK UNIFIED IDEOGRAPH-#22624, IRGKangXi=0383.111, RSKangXi=61.5
22625 CJK UNIFIED IDEOGRAPH-#22625, IRGKangXi=0383.111, RSKangXi=61.5
22626 CJK UNIFIED IDEOGRAPH-#22626, IRGKangXi=0383.111, RSKangXi=61.5
22627 CJK UNIFIED IDEOGRAPH-#22627, IRGKangXi=0383.111, RSKangXi=61.5
22628 CJK UNIFIED IDEOGRAPH-#22628, IRGKangXi=0383.111, RSKangXi=61.5
22629 CJK UNIFIED IDEOGRAPH-#22629, IRGKangXi=0383.111, RSKangXi=61.5
2262A CJK UNIFIED IDEOGRAPH-#2262A, IRGKangXi=0383.111, RSKangXi=61.5
2262B CJK UNIFIED IDEOGRAPH-#2262B, IRGKangXi=0383.111, RSKangXi=61.5
2262C CJK UNIFIED IDEOGRAPH-#2262C, IRGKangXi=0383.111, RSKangXi=61.5
2262D CJK UNIFIED IDEOGRAPH-#2262D, IRGKangXi=0383.111, RSKangXi=61.5
2262E CJK UNIFIED IDEOGRAPH-#2262E, IRGKangXi=0383.111, RSKangXi=61.5
2262F CJK UNIFIED IDEOGRAPH-#2262F, IRGKangXi=0383.111, RSKangXi=61.5
22630 CJK UNIFIED IDEOGRAPH-#22630, IRGKangXi=0383.111, RSKangXi=61.5
22631 CJK UNIFIED IDEOGRAPH-#22631, IRGKangXi=0383.111, RSKangXi=61.5
22632 CJK UNIFIED IDEOGRAPH-#22632, IRGKangXi=0383.111, RSKangXi=61.5
22633 CJK UNIFIED IDEOGRAPH-#22633, IRGKangXi=0383.111, RSKangXi=61.5
22634 CJK UNIFIED IDEOGRAPH-#22634, IRGKangXi=0383.140, RSKangXi=61.6
22635 CJK UNIFIED IDEOGRAPH-#22635, IRGKangXi=0383.150, RSKangXi=61.6
22636 CJK UNIFIED IDEOGRAPH-#22636, IRGKangXi=0383.220, RSKangXi=61.6
22637 CJK UNIFIED IDEOGRAPH-#22637, IRGKangXi=0383.230, RSKangXi=61.6
22638 CJK UNIFIED IDEOGRAPH-#22638, IRGKangXi=0383.300, RSKangXi=61.6, Def{to hate; willful}
22639 CJK UNIFIED IDEOGRAPH-#22639, IRGKangXi=0383.350, RSKangXi=61.6
2263A CJK UNIFIED IDEOGRAPH-#2263A, IRGKangXi=0383.380, RSKangXi=61.6
2263B CJK UNIFIED IDEOGRAPH-#2263B, IRGKangXi=0383.390, RSKangXi=61.6
2263C CJK UNIFIED IDEOGRAPH-#2263C, IRGKangXi=0383.420, RSKangXi=61.6
2263D CJK UNIFIED IDEOGRAPH-#2263D, IRGKangXi=0384.110, RSKangXi=61.6
2263E CJK UNIFIED IDEOGRAPH-#2263E, IRGKangXi=0384.160, RSKangXi=61.6
2263F CJK UNIFIED IDEOGRAPH-#2263F, IRGKangXi=0384.190, RSKangXi=61.6
22640 CJK UNIFIED IDEOGRAPH-#22640, IRGKangXi=0384.250, RSKangXi=61.6
22641 CJK UNIFIED IDEOGRAPH-#22641, IRGKangXi=0385.010, RSKangXi=61.6
22642 CJK UNIFIED IDEOGRAPH-#22642, IRGKangXi=0385.050, RSKangXi=61.6
22643 CJK UNIFIED IDEOGRAPH-#22643, IRGKangXi=0385.100, RSKangXi=61.6
22644 CJK UNIFIED IDEOGRAPH-#22644, IRGKangXi=0385.160, RSKangXi=61.6
22645 CJK UNIFIED IDEOGRAPH-#22645, IRGKangXi=0386.020, RSKangXi=61.6
22646 CJK UNIFIED IDEOGRAPH-#22646, IRGKangXi=0386.040, RSKangXi=61.6
22647 CJK UNIFIED IDEOGRAPH-#22647, IRGKangXi=0386.070, RSKangXi=61.6
22648 CJK UNIFIED IDEOGRAPH-#22648, IRGKangXi=0386.080, RSKangXi=61.6
22649 CJK UNIFIED IDEOGRAPH-#22649, IRGKangXi=0386.090, RSKangXi=61.6
2264A CJK UNIFIED IDEOGRAPH-#2264A, IRGKangXi=0386.110, RSKangXi=61.6
2264B CJK UNIFIED IDEOGRAPH-#2264B, IRGKangXi=0386.120, RSKangXi=61.6
2264C CJK UNIFIED IDEOGRAPH-#2264C, IRGKangXi=0386.130, RSKangXi=61.6
2264D CJK UNIFIED IDEOGRAPH-#2264D, IRGKangXi=0386.140, RSKangXi=61.6
2264E CJK UNIFIED IDEOGRAPH-#2264E, IRGKangXi=0386.160, RSKangXi=61.6
2264F CJK UNIFIED IDEOGRAPH-#2264F, IRGKangXi=0386.161, RSKangXi=61.6
22650 CJK UNIFIED IDEOGRAPH-#22650, IRGKangXi=0386.161, RSKangXi=61.6
22651 CJK UNIFIED IDEOGRAPH-#22651, IRGKangXi=0386.161, RSKangXi=61.6
22652 CJK UNIFIED IDEOGRAPH-#22652, IRGKangXi=0386.161, RSKangXi=61.6
22653 CJK UNIFIED IDEOGRAPH-#22653, IRGKangXi=0386.161, RSKangXi=61.6
22654 CJK UNIFIED IDEOGRAPH-#22654, IRGKangXi=0386.161, RSKangXi=61.6
22655 CJK UNIFIED IDEOGRAPH-#22655, IRGKangXi=0386.161, RSKangXi=61.6
22656 CJK UNIFIED IDEOGRAPH-#22656, IRGKangXi=0386.161, RSKangXi=61.6
22657 CJK UNIFIED IDEOGRAPH-#22657, IRGKangXi=0386.161, RSKangXi=61.6
22658 CJK UNIFIED IDEOGRAPH-#22658, IRGKangXi=0386.161, RSKangXi=61.6
22659 CJK UNIFIED IDEOGRAPH-#22659, IRGKangXi=0386.161, RSKangXi=61.6
2265A CJK UNIFIED IDEOGRAPH-#2265A, IRGKangXi=0386.161, RSKangXi=61.6
2265B CJK UNIFIED IDEOGRAPH-#2265B, IRGKangXi=0386.161, RSKangXi=61.6
2265C CJK UNIFIED IDEOGRAPH-#2265C, IRGKangXi=0386.161, RSKangXi=61.6
2265D CJK UNIFIED IDEOGRAPH-#2265D, IRGKangXi=0386.161, RSKangXi=61.6
2265E CJK UNIFIED IDEOGRAPH-#2265E, IRGKangXi=0386.161, RSKangXi=61.6
2265F CJK UNIFIED IDEOGRAPH-#2265F, IRGKangXi=0386.161, RSKangXi=61.6
22660 CJK UNIFIED IDEOGRAPH-#22660, IRGKangXi=0386.161, RSKangXi=61.6
22661 CJK UNIFIED IDEOGRAPH-#22661, IRGKangXi=0386.161, RSKangXi=61.6
22662 CJK UNIFIED IDEOGRAPH-#22662, IRGKangXi=0386.161, RSKangXi=61.6, Def{to fear}
22663 CJK UNIFIED IDEOGRAPH-#22663, IRGKangXi=0386.161, RSKangXi=61.6
22664 CJK UNIFIED IDEOGRAPH-#22664, IRGKangXi=0386.161, RSKangXi=61.6
22665 CJK UNIFIED IDEOGRAPH-#22665, IRGKangXi=0386.161, RSKangXi=61.6
22666 CJK UNIFIED IDEOGRAPH-#22666, IRGKangXi=0386.161, RSKangXi=61.6
22667 CJK UNIFIED IDEOGRAPH-#22667, IRGKangXi=0386.161, RSKangXi=61.6
22668 CJK UNIFIED IDEOGRAPH-#22668, IRGKangXi=0386.161, RSKangXi=61.6
22669 CJK UNIFIED IDEOGRAPH-#22669, IRGKangXi=0386.161, RSKangXi=61.6
2266A CJK UNIFIED IDEOGRAPH-#2266A, IRGKangXi=0386.161, RSKangXi=61.6
2266B CJK UNIFIED IDEOGRAPH-#2266B, IRGKangXi=0386.161, RSKangXi=61.6
2266C CJK UNIFIED IDEOGRAPH-#2266C, IRGKangXi=0386.161, RSKangXi=61.6
2266D CJK UNIFIED IDEOGRAPH-#2266D, IRGKangXi=0386.161, RSKangXi=61.6
2266E CJK UNIFIED IDEOGRAPH-#2266E, IRGKangXi=0386.161, RSKangXi=61.6
2266F CJK UNIFIED IDEOGRAPH-#2266F, IRGKangXi=0386.161, RSKangXi=61.6
22670 CJK UNIFIED IDEOGRAPH-#22670, IRGKangXi=0386.161, RSKangXi=61.6
22671 CJK UNIFIED IDEOGRAPH-#22671, IRGKangXi=0386.250, RSKangXi=61.7, Def{to impose upon; stupid}
22672 CJK UNIFIED IDEOGRAPH-#22672, IRGKangXi=0386.270, RSKangXi=61.7
22673 CJK UNIFIED IDEOGRAPH-#22673, IRGKangXi=0386.280, RSKangXi=61.7
22674 CJK UNIFIED IDEOGRAPH-#22674, IRGKangXi=0386.360, RSKangXi=61.7
22675 CJK UNIFIED IDEOGRAPH-#22675, IRGKangXi=0386.420, RSKangXi=61.7
22676 CJK UNIFIED IDEOGRAPH-#22676, IRGKangXi=0387.020, RSKangXi=61.7
22677 CJK UNIFIED IDEOGRAPH-#22677, IRGKangXi=0387.030, RSKangXi=61.7
22678 CJK UNIFIED IDEOGRAPH-#22678, IRGKangXi=0387.060, RSKangXi=61.7
22679 CJK UNIFIED IDEOGRAPH-#22679, IRGKangXi=0387.100, RSKangXi=61.7
2267A CJK UNIFIED IDEOGRAPH-#2267A, IRGKangXi=0387.120, RSKangXi=61.7
2267B CJK UNIFIED IDEOGRAPH-#2267B, IRGKangXi=0387.140, RSKangXi=61.7
2267C CJK UNIFIED IDEOGRAPH-#2267C, IRGKangXi=0387.150, RSKangXi=61.7
2267D CJK UNIFIED IDEOGRAPH-#2267D, IRGKangXi=0387.190, RSKangXi=61.7
2267E CJK UNIFIED IDEOGRAPH-#2267E, IRGKangXi=0387.240, RSKangXi=61.7
2267F CJK UNIFIED IDEOGRAPH-#2267F, IRGKangXi=0387.300, RSKangXi=61.7
22680 CJK UNIFIED IDEOGRAPH-#22680, IRGKangXi=0388.010, RSKangXi=61.7
22681 CJK UNIFIED IDEOGRAPH-#22681, IRGKangXi=0388.020, RSKangXi=61.7
22682 CJK UNIFIED IDEOGRAPH-#22682, IRGKangXi=0388.080, RSKangXi=61.7
22683 CJK UNIFIED IDEOGRAPH-#22683, IRGKangXi=0388.100, RSKangXi=61.8
22684 CJK UNIFIED IDEOGRAPH-#22684, IRGKangXi=0388.120, RSKangXi=61.7
22685 CJK UNIFIED IDEOGRAPH-#22685, IRGKangXi=0388.200, RSKangXi=61.7
22686 CJK UNIFIED IDEOGRAPH-#22686, IRGKangXi=0388.220, RSKangXi=61.7
22687 CJK UNIFIED IDEOGRAPH-#22687, IRGKangXi=0388.240, RSKangXi=61.7
22688 CJK UNIFIED IDEOGRAPH-#22688, IRGKangXi=0388.250, RSKangXi=61.7
22689 CJK UNIFIED IDEOGRAPH-#22689, IRGKangXi=0388.260, RSKangXi=61.7
2268A CJK UNIFIED IDEOGRAPH-#2268A, IRGKangXi=0388.270, RSKangXi=61.7
2268B CJK UNIFIED IDEOGRAPH-#2268B, IRGKangXi=0388.280, RSKangXi=61.7
2268C CJK UNIFIED IDEOGRAPH-#2268C, IRGKangXi=0388.290, RSKangXi=61.7
2268D CJK UNIFIED IDEOGRAPH-#2268D, IRGKangXi=0388.300, RSKangXi=61.7
2268E CJK UNIFIED IDEOGRAPH-#2268E, IRGKangXi=0388.310, RSKangXi=61.7
2268F CJK UNIFIED IDEOGRAPH-#2268F, IRGKangXi=0388.320, RSKangXi=61.7
22690 CJK UNIFIED IDEOGRAPH-#22690, IRGKangXi=0388.330, RSKangXi=61.7
22691 CJK UNIFIED IDEOGRAPH-#22691, IRGKangXi=0388.340, RSKangXi=61.7
22692 CJK UNIFIED IDEOGRAPH-#22692, IRGKangXi=0388.341, RSKangXi=61.7
22693 CJK UNIFIED IDEOGRAPH-#22693, IRGKangXi=0388.341, RSKangXi=61.7
22694 CJK UNIFIED IDEOGRAPH-#22694, IRGKangXi=0388.341, RSKangXi=61.7
22695 CJK UNIFIED IDEOGRAPH-#22695, IRGKangXi=0388.341, RSKangXi=61.7
22696 CJK UNIFIED IDEOGRAPH-#22696, IRGKangXi=0388.341, RSKangXi=61.7, Def{(Cant.) intensifier}
22697 CJK UNIFIED IDEOGRAPH-#22697, IRGKangXi=0388.341, RSKangXi=61.7
22698 CJK UNIFIED IDEOGRAPH-#22698, IRGKangXi=0388.341, RSKangXi=61.7
22699 CJK UNIFIED IDEOGRAPH-#22699, IRGKangXi=0388.341, RSKangXi=61.7
2269A CJK UNIFIED IDEOGRAPH-#2269A, IRGKangXi=0388.341, RSKangXi=61.7
2269B CJK UNIFIED IDEOGRAPH-#2269B, IRGKangXi=0388.341, RSKangXi=61.7
2269C CJK UNIFIED IDEOGRAPH-#2269C, IRGKangXi=0388.341, RSKangXi=61.7
2269D CJK UNIFIED IDEOGRAPH-#2269D, IRGKangXi=0388.341, RSKangXi=61.7
2269E CJK UNIFIED IDEOGRAPH-#2269E, IRGKangXi=0388.341, RSKangXi=61.7
2269F CJK UNIFIED IDEOGRAPH-#2269F, IRGKangXi=0388.341, RSKangXi=61.7
226A0 CJK UNIFIED IDEOGRAPH-#226A0, IRGKangXi=0388.341, RSKangXi=61.7
226A1 CJK UNIFIED IDEOGRAPH-#226A1, IRGKangXi=0388.341, RSKangXi=61.7
226A2 CJK UNIFIED IDEOGRAPH-#226A2, IRGKangXi=0388.341, RSKangXi=61.7
226A3 CJK UNIFIED IDEOGRAPH-#226A3, IRGKangXi=0388.341, RSKangXi=61.7
226A4 CJK UNIFIED IDEOGRAPH-#226A4, IRGKangXi=0388.341, RSKangXi=61.7
226A5 CJK UNIFIED IDEOGRAPH-#226A5, IRGKangXi=0388.341, RSKangXi=61.7
226A6 CJK UNIFIED IDEOGRAPH-#226A6, IRGKangXi=0388.341, RSKangXi=61.7
226A7 CJK UNIFIED IDEOGRAPH-#226A7, IRGKangXi=0388.341, RSKangXi=61.7
226A8 CJK UNIFIED IDEOGRAPH-#226A8, IRGKangXi=0388.341, RSKangXi=61.7
226A9 CJK UNIFIED IDEOGRAPH-#226A9, IRGKangXi=0388.341, RSKangXi=61.7
226AA CJK UNIFIED IDEOGRAPH-#226AA, IRGKangXi=0388.341, RSKangXi=61.7
226AB CJK UNIFIED IDEOGRAPH-#226AB, IRGKangXi=0388.341, RSKangXi=61.7
226AC CJK UNIFIED IDEOGRAPH-#226AC, IRGKangXi=0388.341, RSKangXi=61.7
226AD CJK UNIFIED IDEOGRAPH-#226AD, IRGKangXi=0388.341, RSKangXi=61.7
226AE CJK UNIFIED IDEOGRAPH-#226AE, IRGKangXi=0388.341, RSKangXi=61.7
226AF CJK UNIFIED IDEOGRAPH-#226AF, IRGKangXi=0388.341, RSKangXi=61.7
226B0 CJK UNIFIED IDEOGRAPH-#226B0, IRGKangXi=0388.341, RSKangXi=61.7
226B1 CJK UNIFIED IDEOGRAPH-#226B1, IRGKangXi=0388.341, RSKangXi=61.7
226B2 CJK UNIFIED IDEOGRAPH-#226B2, IRGKangXi=0388.341, RSKangXi=61.7
226B3 CJK UNIFIED IDEOGRAPH-#226B3, IRGKangXi=0388.341, RSKangXi=61.7
226B4 CJK UNIFIED IDEOGRAPH-#226B4, IRGKangXi=0388.341, RSKangXi=61.7
226B5 CJK UNIFIED IDEOGRAPH-#226B5, IRGKangXi=0388.341, RSKangXi=61.7
226B6 CJK UNIFIED IDEOGRAPH-#226B6, IRGKangXi=0388.341, RSKangXi=61.7
226B7 CJK UNIFIED IDEOGRAPH-#226B7, IRGKangXi=0388.341, RSKangXi=61.7
226B8 CJK UNIFIED IDEOGRAPH-#226B8, IRGKangXi=0388.341, RSKangXi=61.7
226B9 CJK UNIFIED IDEOGRAPH-#226B9, IRGKangXi=0388.341, RSKangXi=61.7
226BA CJK UNIFIED IDEOGRAPH-#226BA, IRGKangXi=0388.341, RSKangXi=61.7
226BB CJK UNIFIED IDEOGRAPH-#226BB, IRGKangXi=0388.341, RSKangXi=61.7
226BC CJK UNIFIED IDEOGRAPH-#226BC, IRGKangXi=0388.341, RSKangXi=61.7
226BD CJK UNIFIED IDEOGRAPH-#226BD, IRGKangXi=0388.341, RSKangXi=61.7
226BE CJK UNIFIED IDEOGRAPH-#226BE, IRGKangXi=0388.341, RSKangXi=61.7
226BF CJK UNIFIED IDEOGRAPH-#226BF, IRGKangXi=0388.341, RSKangXi=61.7
226C0 CJK UNIFIED IDEOGRAPH-#226C0, IRGKangXi=0389.050, RSKangXi=61.8
226C1 CJK UNIFIED IDEOGRAPH-#226C1, IRGKangXi=0389.110, RSKangXi=61.8
226C2 CJK UNIFIED IDEOGRAPH-#226C2, IRGKangXi=0389.140, RSKangXi=61.8
226C3 CJK UNIFIED IDEOGRAPH-#226C3, IRGKangXi=0389.150, RSKangXi=61.8
226C4 CJK UNIFIED IDEOGRAPH-#226C4, IRGKangXi=0389.160, RSKangXi=61.8
226C5 CJK UNIFIED IDEOGRAPH-#226C5, IRGKangXi=0389.170, RSKangXi=61.8
226C6 CJK UNIFIED IDEOGRAPH-#226C6, IRGKangXi=0389.280, RSKangXi=61.8
226C7 CJK UNIFIED IDEOGRAPH-#226C7, IRGKangXi=0390.030, RSKangXi=61.8
226C8 CJK UNIFIED IDEOGRAPH-#226C8, IRGKangXi=0390.070, RSKangXi=61.8
226C9 CJK UNIFIED IDEOGRAPH-#226C9, IRGKangXi=0390.090, RSKangXi=61.8
226CA CJK UNIFIED IDEOGRAPH-#226CA, IRGKangXi=0390.100, RSKangXi=61.8
226CB CJK UNIFIED IDEOGRAPH-#226CB, IRGKangXi=0390.140, RSKangXi=61.8
226CC CJK UNIFIED IDEOGRAPH-#226CC, IRGKangXi=0390.220, RSKangXi=61.8
226CD CJK UNIFIED IDEOGRAPH-#226CD, IRGKangXi=0390.240, RSKangXi=61.8
226CE CJK UNIFIED IDEOGRAPH-#226CE, IRGKangXi=0390.250, RSKangXi=61.8
226CF CJK UNIFIED IDEOGRAPH-#226CF, IRGKangXi=0390.260, RSKangXi=61.8
226D0 CJK UNIFIED IDEOGRAPH-#226D0, IRGKangXi=0390.270, RSKangXi=61.8
226D1 CJK UNIFIED IDEOGRAPH-#226D1, IRGKangXi=0390.280, RSKangXi=61.8
226D2 CJK UNIFIED IDEOGRAPH-#226D2, IRGKangXi=0390.290, RSKangXi=61.8
226D3 CJK UNIFIED IDEOGRAPH-#226D3, IRGKangXi=0390.310, RSKangXi=61.8
226D4 CJK UNIFIED IDEOGRAPH-#226D4, IRGKangXi=0390.320, RSKangXi=61.8
226D5 CJK UNIFIED IDEOGRAPH-#226D5, IRGKangXi=0390.380, RSKangXi=61.8
226D6 CJK UNIFIED IDEOGRAPH-#226D6, IRGKangXi=0390.390, RSKangXi=61.8
226D7 CJK UNIFIED IDEOGRAPH-#226D7, IRGKangXi=0390.420, RSKangXi=61.8
226D8 CJK UNIFIED IDEOGRAPH-#226D8, IRGKangXi=0390.430, RSKangXi=61.8
226D9 CJK UNIFIED IDEOGRAPH-#226D9, IRGKangXi=0390.440, RSKangXi=61.8
226DA CJK UNIFIED IDEOGRAPH-#226DA, IRGKangXi=0390.470, RSKangXi=61.8
226DB CJK UNIFIED IDEOGRAPH-#226DB, IRGKangXi=0391.050, RSKangXi=61.8
226DC CJK UNIFIED IDEOGRAPH-#226DC, IRGKangXi=0391.130, RSKangXi=61.8
226DD CJK UNIFIED IDEOGRAPH-#226DD, IRGKangXi=0391.140, RSKangXi=61.8
226DE CJK UNIFIED IDEOGRAPH-#226DE, IRGKangXi=0391.160, RSKangXi=61.8
226DF CJK UNIFIED IDEOGRAPH-#226DF, IRGKangXi=0391.240, RSKangXi=61.8
226E0 CJK UNIFIED IDEOGRAPH-#226E0, IRGKangXi=0392.010, RSKangXi=61.8
226E1 CJK UNIFIED IDEOGRAPH-#226E1, IRGKangXi=0392.020, RSKangXi=61.8
226E2 CJK UNIFIED IDEOGRAPH-#226E2, IRGKangXi=0392.040, RSKangXi=61.8
226E3 CJK UNIFIED IDEOGRAPH-#226E3, IRGKangXi=0392.050, RSKangXi=61.8
226E4 CJK UNIFIED IDEOGRAPH-#226E4, IRGKangXi=0392.060, RSKangXi=61.8
226E5 CJK UNIFIED IDEOGRAPH-#226E5, IRGKangXi=0392.070, RSKangXi=61.8
226E6 CJK UNIFIED IDEOGRAPH-#226E6, IRGKangXi=0392.080, RSKangXi=61.8
226E7 CJK UNIFIED IDEOGRAPH-#226E7, IRGKangXi=0392.100, RSKangXi=61.8
226E8 CJK UNIFIED IDEOGRAPH-#226E8, IRGKangXi=0392.110, RSKangXi=61.8
226E9 CJK UNIFIED IDEOGRAPH-#226E9, IRGKangXi=0392.120, RSKangXi=61.8
226EA CJK UNIFIED IDEOGRAPH-#226EA, IRGKangXi=0392.130, RSKangXi=61.8
226EB CJK UNIFIED IDEOGRAPH-#226EB, IRGKangXi=0392.140, RSKangXi=61.8
226EC CJK UNIFIED IDEOGRAPH-#226EC, IRGKangXi=0392.150, RSKangXi=61.8
226ED CJK UNIFIED IDEOGRAPH-#226ED, IRGKangXi=0392.170, RSKangXi=61.8
226EE CJK UNIFIED IDEOGRAPH-#226EE, IRGKangXi=0392.180, RSKangXi=61.8
226EF CJK UNIFIED IDEOGRAPH-#226EF, IRGKangXi=0392.181, RSKangXi=61.8
226F0 CJK UNIFIED IDEOGRAPH-#226F0, IRGKangXi=0392.181, RSKangXi=61.8
226F1 CJK UNIFIED IDEOGRAPH-#226F1, IRGKangXi=0392.181, RSKangXi=61.8
226F2 CJK UNIFIED IDEOGRAPH-#226F2, IRGKangXi=0392.181, RSKangXi=61.8
226F3 CJK UNIFIED IDEOGRAPH-#226F3, IRGKangXi=0392.181, RSKangXi=61.8
226F4 CJK UNIFIED IDEOGRAPH-#226F4, IRGKangXi=0392.181, RSKangXi=61.8, Def{(Cant.) annoyed, impatient, restless}
226F5 CJK UNIFIED IDEOGRAPH-#226F5, IRGKangXi=0392.181, RSKangXi=61.8, Def{(Cant.) annoyed, irritated}
226F6 CJK UNIFIED IDEOGRAPH-#226F6, IRGKangXi=0392.181, RSKangXi=61.8
226F7 CJK UNIFIED IDEOGRAPH-#226F7, IRGKangXi=0392.181, RSKangXi=61.8
226F8 CJK UNIFIED IDEOGRAPH-#226F8, IRGKangXi=0392.181, RSKangXi=61.8
226F9 CJK UNIFIED IDEOGRAPH-#226F9, IRGKangXi=0392.181, RSKangXi=61.8
226FA CJK UNIFIED IDEOGRAPH-#226FA, IRGKangXi=0392.181, RSKangXi=61.8
226FB CJK UNIFIED IDEOGRAPH-#226FB, IRGKangXi=0392.181, RSKangXi=61.8
226FC CJK UNIFIED IDEOGRAPH-#226FC, IRGKangXi=0392.181, RSKangXi=61.8
226FD CJK UNIFIED IDEOGRAPH-#226FD, IRGKangXi=0392.181, RSKangXi=61.8
226FE CJK UNIFIED IDEOGRAPH-#226FE, IRGKangXi=0392.181, RSKangXi=61.8
226FF CJK UNIFIED IDEOGRAPH-#226FF, IRGKangXi=0392.181, RSKangXi=61.8
22700 CJK UNIFIED IDEOGRAPH-#22700, IRGKangXi=0392.181, RSKangXi=61.8
22701 CJK UNIFIED IDEOGRAPH-#22701, IRGKangXi=0392.181, RSKangXi=61.8
22702 CJK UNIFIED IDEOGRAPH-#22702, IRGKangXi=0392.181, RSKangXi=61.8
22703 CJK UNIFIED IDEOGRAPH-#22703, IRGKangXi=0392.181, RSKangXi=61.8
22704 CJK UNIFIED IDEOGRAPH-#22704, IRGKangXi=0392.181, RSKangXi=61.8
22705 CJK UNIFIED IDEOGRAPH-#22705, IRGKangXi=0392.181, RSKangXi=61.8
22706 CJK UNIFIED IDEOGRAPH-#22706, IRGKangXi=0392.181, RSKangXi=61.8
22707 CJK UNIFIED IDEOGRAPH-#22707, IRGKangXi=0392.181, RSKangXi=61.8
22708 CJK UNIFIED IDEOGRAPH-#22708, IRGKangXi=0392.181, RSKangXi=61.8
22709 CJK UNIFIED IDEOGRAPH-#22709, IRGKangXi=0392.181, RSKangXi=61.8
2270A CJK UNIFIED IDEOGRAPH-#2270A, IRGKangXi=0392.181, RSKangXi=61.8
2270B CJK UNIFIED IDEOGRAPH-#2270B, IRGKangXi=0392.181, RSKangXi=61.8
2270C CJK UNIFIED IDEOGRAPH-#2270C, IRGKangXi=0392.181, RSKangXi=61.8
2270D CJK UNIFIED IDEOGRAPH-#2270D, IRGKangXi=0392.181, RSKangXi=61.8
2270E CJK UNIFIED IDEOGRAPH-#2270E, IRGKangXi=0392.181, RSKangXi=61.8
2270F CJK UNIFIED IDEOGRAPH-#2270F, IRGKangXi=0392.181, RSKangXi=61.8
22710 CJK UNIFIED IDEOGRAPH-#22710, IRGKangXi=0392.181, RSKangXi=61.8
22711 CJK UNIFIED IDEOGRAPH-#22711, IRGKangXi=0392.181, RSKangXi=61.8
22712 CJK UNIFIED IDEOGRAPH-#22712, IRGKangXi=0392.181, RSKangXi=61.8
22713 CJK UNIFIED IDEOGRAPH-#22713, IRGKangXi=0392.181, RSKangXi=61.8
22714 CJK UNIFIED IDEOGRAPH-#22714, IRGKangXi=0392.181, RSKangXi=61.8
22715 CJK UNIFIED IDEOGRAPH-#22715, IRGKangXi=0392.181, RSKangXi=61.8
22716 CJK UNIFIED IDEOGRAPH-#22716, IRGKangXi=0392.181, RSKangXi=61.8
22717 CJK UNIFIED IDEOGRAPH-#22717, IRGKangXi=0392.181, RSKangXi=61.8
22718 CJK UNIFIED IDEOGRAPH-#22718, IRGKangXi=0392.181, RSKangXi=61.8
22719 CJK UNIFIED IDEOGRAPH-#22719, IRGKangXi=0392.181, RSKangXi=61.8
2271A CJK UNIFIED IDEOGRAPH-#2271A, IRGKangXi=0392.181, RSKangXi=61.8
2271B CJK UNIFIED IDEOGRAPH-#2271B, IRGKangXi=0392.181, RSKangXi=61.8
2271C CJK UNIFIED IDEOGRAPH-#2271C, IRGKangXi=0392.181, RSKangXi=61.8
2271D CJK UNIFIED IDEOGRAPH-#2271D, IRGKangXi=0392.181, RSKangXi=61.8
2271E CJK UNIFIED IDEOGRAPH-#2271E, IRGKangXi=0392.181, RSKangXi=61.8
2271F CJK UNIFIED IDEOGRAPH-#2271F, IRGKangXi=0392.181, RSKangXi=61.8
22720 CJK UNIFIED IDEOGRAPH-#22720, IRGKangXi=0392.181, RSKangXi=61.8
22721 CJK UNIFIED IDEOGRAPH-#22721, IRGKangXi=0392.181, RSKangXi=61.8
22722 CJK UNIFIED IDEOGRAPH-#22722, IRGKangXi=0392.181, RSKangXi=61.8
22723 CJK UNIFIED IDEOGRAPH-#22723, IRGKangXi=0392.181, RSKangXi=61.8
22724 CJK UNIFIED IDEOGRAPH-#22724, IRGKangXi=0392.181, RSKangXi=61.8
22725 CJK UNIFIED IDEOGRAPH-#22725, IRGKangXi=0392.181, RSKangXi=61.8
22726 CJK UNIFIED IDEOGRAPH-#22726, IRGKangXi=0392.181, RSKangXi=61.8
22727 CJK UNIFIED IDEOGRAPH-#22727, IRGKangXi=0392.181, RSKangXi=61.8
22728 CJK UNIFIED IDEOGRAPH-#22728, IRGKangXi=0392.300, RSKangXi=61.9
22729 CJK UNIFIED IDEOGRAPH-#22729, IRGKangXi=0392.310, RSKangXi=61.9
2272A CJK UNIFIED IDEOGRAPH-#2272A, IRGKangXi=0393.020, RSKangXi=61.9
2272B CJK UNIFIED IDEOGRAPH-#2272B, IRGKangXi=0393.070, RSKangXi=61.9, Def{intelligent, tranquil}
2272C CJK UNIFIED IDEOGRAPH-#2272C, IRGKangXi=0393.090, RSKangXi=61.9, Def{to estimate, calculate}
2272D CJK UNIFIED IDEOGRAPH-#2272D, IRGKangXi=0393.100, RSKangXi=61.9
2272E CJK UNIFIED IDEOGRAPH-#2272E, IRGKangXi=0393.120, RSKangXi=61.9
2272F CJK UNIFIED IDEOGRAPH-#2272F, IRGKangXi=0393.130, RSKangXi=61.9
22730 CJK UNIFIED IDEOGRAPH-#22730, IRGKangXi=0393.140, RSKangXi=61.9
22731 CJK UNIFIED IDEOGRAPH-#22731, IRGKangXi=0393.170, RSKangXi=61.9
22732 CJK UNIFIED IDEOGRAPH-#22732, IRGKangXi=0393.190, RSKangXi=61.9
22733 CJK UNIFIED IDEOGRAPH-#22733, IRGKangXi=0393.220, RSKangXi=61.9
22734 CJK UNIFIED IDEOGRAPH-#22734, IRGKangXi=0393.280, RSKangXi=61.9
22735 CJK UNIFIED IDEOGRAPH-#22735, IRGKangXi=0393.290, RSKangXi=61.9
22736 CJK UNIFIED IDEOGRAPH-#22736, IRGKangXi=0393.300, RSKangXi=61.9
22737 CJK UNIFIED IDEOGRAPH-#22737, IRGKangXi=0393.310, RSKangXi=61.9
22738 CJK UNIFIED IDEOGRAPH-#22738, IRGKangXi=0393.320, RSKangXi=61.9, Def{worthless, inferior, trashy}
22739 CJK UNIFIED IDEOGRAPH-#22739, IRGKangXi=0393.340, RSKangXi=61.9
2273A CJK UNIFIED IDEOGRAPH-#2273A, IRGKangXi=0394.050, RSKangXi=61.9
2273B CJK UNIFIED IDEOGRAPH-#2273B, IRGKangXi=0394.060, RSKangXi=61.9
2273C CJK UNIFIED IDEOGRAPH-#2273C, IRGKangXi=0394.070, RSKangXi=61.9
2273D CJK UNIFIED IDEOGRAPH-#2273D, IRGKangXi=0394.080, RSKangXi=61.9
2273E CJK UNIFIED IDEOGRAPH-#2273E, IRGKangXi=0394.100, RSKangXi=61.9
2273F CJK UNIFIED IDEOGRAPH-#2273F, IRGKangXi=0394.120, RSKangXi=61.9
22740 CJK UNIFIED IDEOGRAPH-#22740, IRGKangXi=0394.130, RSKangXi=61.9
22741 CJK UNIFIED IDEOGRAPH-#22741, IRGKangXi=0394.140, RSKangXi=61.9
22742 CJK UNIFIED IDEOGRAPH-#22742, IRGKangXi=0394.230, RSKangXi=61.9
22743 CJK UNIFIED IDEOGRAPH-#22743, IRGKangXi=0394.240, RSKangXi=61.9
22744 CJK UNIFIED IDEOGRAPH-#22744, IRGKangXi=0394.250, RSKangXi=61.9
22745 CJK UNIFIED IDEOGRAPH-#22745, IRGKangXi=0394.270, RSKangXi=61.9
22746 CJK UNIFIED IDEOGRAPH-#22746, IRGKangXi=0394.280, RSKangXi=61.9
22747 CJK UNIFIED IDEOGRAPH-#22747, IRGKangXi=0394.300, RSKangXi=61.9
22748 CJK UNIFIED IDEOGRAPH-#22748, IRGKangXi=0394.320, RSKangXi=61.9
22749 CJK UNIFIED IDEOGRAPH-#22749, IRGKangXi=0394.330, RSKangXi=61.9
2274A CJK UNIFIED IDEOGRAPH-#2274A, IRGKangXi=0395.010, RSKangXi=61.9
2274B CJK UNIFIED IDEOGRAPH-#2274B, IRGKangXi=0395.040, RSKangXi=61.9
2274C CJK UNIFIED IDEOGRAPH-#2274C, IRGKangXi=0395.070, RSKangXi=61.9
2274D CJK UNIFIED IDEOGRAPH-#2274D, IRGKangXi=0395.280, RSKangXi=61.9
2274E CJK UNIFIED IDEOGRAPH-#2274E, IRGKangXi=0395.300, RSKangXi=61.9
2274F CJK UNIFIED IDEOGRAPH-#2274F, IRGKangXi=0395.310, RSKangXi=61.9
22750 CJK UNIFIED IDEOGRAPH-#22750, IRGKangXi=0396.010, RSKangXi=61.9
22751 CJK UNIFIED IDEOGRAPH-#22751, IRGKangXi=0396.030, RSKangXi=61.9
22752 CJK UNIFIED IDEOGRAPH-#22752, IRGKangXi=0396.040, RSKangXi=61.9
22753 CJK UNIFIED IDEOGRAPH-#22753, IRGKangXi=0396.050, RSKangXi=61.9
22754 CJK UNIFIED IDEOGRAPH-#22754, IRGKangXi=0396.060, RSKangXi=61.9
22755 CJK UNIFIED IDEOGRAPH-#22755, IRGKangXi=0396.070, RSKangXi=61.9
22756 CJK UNIFIED IDEOGRAPH-#22756, IRGKangXi=0396.071, RSKangXi=61.9
22757 CJK UNIFIED IDEOGRAPH-#22757, IRGKangXi=0396.071, RSKangXi=61.9
22758 CJK UNIFIED IDEOGRAPH-#22758, IRGKangXi=0396.071, RSKangXi=61.9
22759 CJK UNIFIED IDEOGRAPH-#22759, IRGKangXi=0396.071, RSKangXi=61.9
2275A CJK UNIFIED IDEOGRAPH-#2275A, IRGKangXi=0396.071, RSKangXi=61.9
2275B CJK UNIFIED IDEOGRAPH-#2275B, IRGKangXi=0396.071, RSKangXi=61.9
2275C CJK UNIFIED IDEOGRAPH-#2275C, IRGKangXi=0396.071, RSKangXi=61.9
2275D CJK UNIFIED IDEOGRAPH-#2275D, IRGKangXi=0396.071, RSKangXi=61.9
2275E CJK UNIFIED IDEOGRAPH-#2275E, IRGKangXi=0396.071, RSKangXi=61.9
2275F CJK UNIFIED IDEOGRAPH-#2275F, IRGKangXi=0396.071, RSKangXi=61.9
22760 CJK UNIFIED IDEOGRAPH-#22760, IRGKangXi=0396.071, RSKangXi=61.9
22761 CJK UNIFIED IDEOGRAPH-#22761, IRGKangXi=0396.071, RSKangXi=61.9
22762 CJK UNIFIED IDEOGRAPH-#22762, IRGKangXi=0396.071, RSKangXi=61.9
22763 CJK UNIFIED IDEOGRAPH-#22763, IRGKangXi=0396.071, RSKangXi=61.9
22764 CJK UNIFIED IDEOGRAPH-#22764, IRGKangXi=0396.071, RSKangXi=61.9
22765 CJK UNIFIED IDEOGRAPH-#22765, IRGKangXi=0396.071, RSKangXi=61.9
22766 CJK UNIFIED IDEOGRAPH-#22766, IRGKangXi=0396.071, RSKangXi=61.9
22767 CJK UNIFIED IDEOGRAPH-#22767, IRGKangXi=0396.071, RSKangXi=61.9
22768 CJK UNIFIED IDEOGRAPH-#22768, IRGKangXi=0396.071, RSKangXi=61.9
22769 CJK UNIFIED IDEOGRAPH-#22769, IRGKangXi=0396.071, RSKangXi=61.9
2276A CJK UNIFIED IDEOGRAPH-#2276A, IRGKangXi=0396.071, RSKangXi=61.9
2276B CJK UNIFIED IDEOGRAPH-#2276B, IRGKangXi=0396.071, RSKangXi=61.9
2276C CJK UNIFIED IDEOGRAPH-#2276C, IRGKangXi=0396.071, RSKangXi=61.9
2276D CJK UNIFIED IDEOGRAPH-#2276D, IRGKangXi=0396.071, RSKangXi=61.9
2276E CJK UNIFIED IDEOGRAPH-#2276E, IRGKangXi=0396.071, RSKangXi=61.9
2276F CJK UNIFIED IDEOGRAPH-#2276F, IRGKangXi=0396.071, RSKangXi=61.9
22770 CJK UNIFIED IDEOGRAPH-#22770, IRGKangXi=0396.071, RSKangXi=61.9
22771 CJK UNIFIED IDEOGRAPH-#22771, IRGKangXi=0396.071, RSKangXi=61.9
22772 CJK UNIFIED IDEOGRAPH-#22772, IRGKangXi=0396.071, RSKangXi=61.9
22773 CJK UNIFIED IDEOGRAPH-#22773, IRGKangXi=0396.071, RSKangXi=61.9
22774 CJK UNIFIED IDEOGRAPH-#22774, IRGKangXi=0396.071, RSKangXi=61.9
22775 CJK UNIFIED IDEOGRAPH-#22775, IRGKangXi=0396.071, RSKangXi=61.9, Def{(Cant.) 花𢝵, to be fashionable}
22776 CJK UNIFIED IDEOGRAPH-#22776, IRGKangXi=0396.071, RSKangXi=61.9
22777 CJK UNIFIED IDEOGRAPH-#22777, IRGKangXi=0396.071, RSKangXi=61.9
22778 CJK UNIFIED IDEOGRAPH-#22778, IRGKangXi=0396.071, RSKangXi=61.9
22779 CJK UNIFIED IDEOGRAPH-#22779, IRGKangXi=0396.071, RSKangXi=61.9
2277A CJK UNIFIED IDEOGRAPH-#2277A, IRGKangXi=0396.071, RSKangXi=61.9
2277B CJK UNIFIED IDEOGRAPH-#2277B, IRGKangXi=0396.071, RSKangXi=61.9
2277C CJK UNIFIED IDEOGRAPH-#2277C, IRGKangXi=0396.071, RSKangXi=61.9
2277D CJK UNIFIED IDEOGRAPH-#2277D, IRGKangXi=0396.071, RSKangXi=61.9
2277E CJK UNIFIED IDEOGRAPH-#2277E, IRGKangXi=0396.071, RSKangXi=61.9
2277F CJK UNIFIED IDEOGRAPH-#2277F, IRGKangXi=0396.071, RSKangXi=61.9
22780 CJK UNIFIED IDEOGRAPH-#22780, IRGKangXi=0396.071, RSKangXi=61.9
22781 CJK UNIFIED IDEOGRAPH-#22781, IRGKangXi=0396.071, RSKangXi=61.9
22782 CJK UNIFIED IDEOGRAPH-#22782, IRGKangXi=0396.071, RSKangXi=61.9
22783 CJK UNIFIED IDEOGRAPH-#22783, IRGKangXi=0396.071, RSKangXi=61.9
22784 CJK UNIFIED IDEOGRAPH-#22784, IRGKangXi=0396.071, RSKangXi=61.9
22785 CJK UNIFIED IDEOGRAPH-#22785, IRGKangXi=0396.071, RSKangXi=61.9
22786 CJK UNIFIED IDEOGRAPH-#22786, IRGKangXi=0396.071, RSKangXi=61.9
22787 CJK UNIFIED IDEOGRAPH-#22787, IRGKangXi=0396.071, RSKangXi=61.9
22788 CJK UNIFIED IDEOGRAPH-#22788, IRGKangXi=0396.071, RSKangXi=61.9
22789 CJK UNIFIED IDEOGRAPH-#22789, IRGKangXi=0396.071, RSKangXi=61.9
2278A CJK UNIFIED IDEOGRAPH-#2278A, IRGKangXi=0396.071, RSKangXi=61.9
2278B CJK UNIFIED IDEOGRAPH-#2278B, IRGKangXi=0396.071, RSKangXi=61.9
2278C CJK UNIFIED IDEOGRAPH-#2278C, IRGKangXi=0396.071, RSKangXi=61.9
2278D CJK UNIFIED IDEOGRAPH-#2278D, IRGKangXi=0396.071, RSKangXi=61.9
2278E CJK UNIFIED IDEOGRAPH-#2278E, IRGKangXi=0396.130, RSKangXi=61.10
2278F CJK UNIFIED IDEOGRAPH-#2278F, IRGKangXi=0396.170, RSKangXi=61.10
22790 CJK UNIFIED IDEOGRAPH-#22790, IRGKangXi=0396.220, RSKangXi=61.10
22791 CJK UNIFIED IDEOGRAPH-#22791, IRGKangXi=0396.250, RSKangXi=61.10
22792 CJK UNIFIED IDEOGRAPH-#22792, IRGKangXi=0396.300, RSKangXi=61.10
22793 CJK UNIFIED IDEOGRAPH-#22793, IRGKangXi=0396.330, RSKangXi=61.10
22794 CJK UNIFIED IDEOGRAPH-#22794, IRGKangXi=0396.350, RSKangXi=61.10
22795 CJK UNIFIED IDEOGRAPH-#22795, IRGKangXi=0396.370, RSKangXi=61.10
22796 CJK UNIFIED IDEOGRAPH-#22796, IRGKangXi=0396.400, RSKangXi=61.10
22797 CJK UNIFIED IDEOGRAPH-#22797, IRGKangXi=0396.410, RSKangXi=61.10
22798 CJK UNIFIED IDEOGRAPH-#22798, IRGKangXi=0396.430, RSKangXi=61.10
22799 CJK UNIFIED IDEOGRAPH-#22799, IRGKangXi=0396.450, RSKangXi=61.10
2279A CJK UNIFIED IDEOGRAPH-#2279A, IRGKangXi=0397.020, RSKangXi=61.10
2279B CJK UNIFIED IDEOGRAPH-#2279B, IRGKangXi=0397.030, RSKangXi=61.10
2279C CJK UNIFIED IDEOGRAPH-#2279C, IRGKangXi=0397.080, RSKangXi=61.10
2279D CJK UNIFIED IDEOGRAPH-#2279D, IRGKangXi=0397.160, RSKangXi=61.10
2279E CJK UNIFIED IDEOGRAPH-#2279E, IRGKangXi=0397.180, RSKangXi=61.10
2279F CJK UNIFIED IDEOGRAPH-#2279F, IRGKangXi=0397.240, RSKangXi=61.10
227A0 CJK UNIFIED IDEOGRAPH-#227A0, IRGKangXi=0398.040, RSKangXi=61.10
227A1 CJK UNIFIED IDEOGRAPH-#227A1, IRGKangXi=0398.050, RSKangXi=61.10
227A2 CJK UNIFIED IDEOGRAPH-#227A2, IRGKangXi=0398.070, RSKangXi=61.10
227A3 CJK UNIFIED IDEOGRAPH-#227A3, IRGKangXi=0398.080, RSKangXi=61.10
227A4 CJK UNIFIED IDEOGRAPH-#227A4, IRGKangXi=0398.100, RSKangXi=61.10
227A5 CJK UNIFIED IDEOGRAPH-#227A5, IRGKangXi=0398.120, RSKangXi=61.10
227A6 CJK UNIFIED IDEOGRAPH-#227A6, IRGKangXi=0398.130, RSKangXi=61.10
227A7 CJK UNIFIED IDEOGRAPH-#227A7, IRGKangXi=0398.140, RSKangXi=61.10
227A8 CJK UNIFIED IDEOGRAPH-#227A8, IRGKangXi=0398.150, RSKangXi=61.10
227A9 CJK UNIFIED IDEOGRAPH-#227A9, IRGKangXi=0398.160, RSKangXi=61.10
227AA CJK UNIFIED IDEOGRAPH-#227AA, IRGKangXi=0398.170, RSKangXi=61.10
227AB CJK UNIFIED IDEOGRAPH-#227AB, IRGKangXi=0398.180, RSKangXi=61.10
227AC CJK UNIFIED IDEOGRAPH-#227AC, IRGKangXi=0398.190, RSKangXi=61.10
227AD CJK UNIFIED IDEOGRAPH-#227AD, IRGKangXi=0398.200, RSKangXi=61.10
227AE CJK UNIFIED IDEOGRAPH-#227AE, IRGKangXi=0398.220, RSKangXi=61.10
227AF CJK UNIFIED IDEOGRAPH-#227AF, IRGKangXi=0398.230, RSKangXi=61.10
227B0 CJK UNIFIED IDEOGRAPH-#227B0, IRGKangXi=0398.240, RSKangXi=61.10
227B1 CJK UNIFIED IDEOGRAPH-#227B1, IRGKangXi=0398.250, RSKangXi=61.10
227B2 CJK UNIFIED IDEOGRAPH-#227B2, IRGKangXi=0398.260, RSKangXi=61.10
227B3 CJK UNIFIED IDEOGRAPH-#227B3, IRGKangXi=0398.261, RSKangXi=61.10
227B4 CJK UNIFIED IDEOGRAPH-#227B4, IRGKangXi=0398.261, RSKangXi=61.10
227B5 CJK UNIFIED IDEOGRAPH-#227B5, IRGKangXi=0398.261, RSKangXi=61.10, Def{(Cant.) to brush, whisk}
227B6 CJK UNIFIED IDEOGRAPH-#227B6, IRGKangXi=0398.261, RSKangXi=61.10
227B7 CJK UNIFIED IDEOGRAPH-#227B7, IRGKangXi=0398.261, RSKangXi=61.10
227B8 CJK UNIFIED IDEOGRAPH-#227B8, IRGKangXi=0398.261, RSKangXi=61.10
227B9 CJK UNIFIED IDEOGRAPH-#227B9, IRGKangXi=0398.261, RSKangXi=61.10
227BA CJK UNIFIED IDEOGRAPH-#227BA, IRGKangXi=0398.261, RSKangXi=61.10
227BB CJK UNIFIED IDEOGRAPH-#227BB, IRGKangXi=0398.261, RSKangXi=61.10
227BC CJK UNIFIED IDEOGRAPH-#227BC, IRGKangXi=0398.261, RSKangXi=61.10
227BD CJK UNIFIED IDEOGRAPH-#227BD, IRGKangXi=0398.261, RSKangXi=61.10
227BE CJK UNIFIED IDEOGRAPH-#227BE, IRGKangXi=0398.261, RSKangXi=61.10
227BF CJK UNIFIED IDEOGRAPH-#227BF, IRGKangXi=0398.261, RSKangXi=61.10
227C0 CJK UNIFIED IDEOGRAPH-#227C0, IRGKangXi=0398.261, RSKangXi=61.10
227C1 CJK UNIFIED IDEOGRAPH-#227C1, IRGKangXi=0398.261, RSKangXi=61.10
227C2 CJK UNIFIED IDEOGRAPH-#227C2, IRGKangXi=0398.261, RSKangXi=61.10
227C3 CJK UNIFIED IDEOGRAPH-#227C3, IRGKangXi=0398.261, RSKangXi=61.10
227C4 CJK UNIFIED IDEOGRAPH-#227C4, IRGKangXi=0398.261, RSKangXi=61.10
227C5 CJK UNIFIED IDEOGRAPH-#227C5, IRGKangXi=0398.261, RSKangXi=61.10
227C6 CJK UNIFIED IDEOGRAPH-#227C6, IRGKangXi=0398.261, RSKangXi=61.10
227C7 CJK UNIFIED IDEOGRAPH-#227C7, IRGKangXi=0398.261, RSKangXi=61.10
227C8 CJK UNIFIED IDEOGRAPH-#227C8, IRGKangXi=0398.261, RSKangXi=61.10
227C9 CJK UNIFIED IDEOGRAPH-#227C9, IRGKangXi=0398.261, RSKangXi=61.10
227CA CJK UNIFIED IDEOGRAPH-#227CA, IRGKangXi=0398.261, RSKangXi=61.10
227CB CJK UNIFIED IDEOGRAPH-#227CB, IRGKangXi=0398.261, RSKangXi=61.10
227CC CJK UNIFIED IDEOGRAPH-#227CC, IRGKangXi=0398.261, RSKangXi=61.10
227CD CJK UNIFIED IDEOGRAPH-#227CD, IRGKangXi=0398.261, RSKangXi=61.10
227CE CJK UNIFIED IDEOGRAPH-#227CE, IRGKangXi=0398.261, RSKangXi=61.10
227CF CJK UNIFIED IDEOGRAPH-#227CF, IRGKangXi=0398.261, RSKangXi=61.10
227D0 CJK UNIFIED IDEOGRAPH-#227D0, IRGKangXi=0398.261, RSKangXi=61.10
227D1 CJK UNIFIED IDEOGRAPH-#227D1, IRGKangXi=0398.261, RSKangXi=61.10
227D2 CJK UNIFIED IDEOGRAPH-#227D2, IRGKangXi=0398.261, RSKangXi=61.10
227D3 CJK UNIFIED IDEOGRAPH-#227D3, IRGKangXi=0398.261, RSKangXi=61.10
227D4 CJK UNIFIED IDEOGRAPH-#227D4, IRGKangXi=0398.261, RSKangXi=61.10
227D5 CJK UNIFIED IDEOGRAPH-#227D5, IRGKangXi=0398.261, RSKangXi=61.10
227D6 CJK UNIFIED IDEOGRAPH-#227D6, IRGKangXi=0398.261, RSKangXi=61.10
227D7 CJK UNIFIED IDEOGRAPH-#227D7, IRGKangXi=0398.261, RSKangXi=61.10
227D8 CJK UNIFIED IDEOGRAPH-#227D8, IRGKangXi=0398.261, RSKangXi=61.10
227D9 CJK UNIFIED IDEOGRAPH-#227D9, IRGKangXi=0398.261, RSKangXi=61.10
227DA CJK UNIFIED IDEOGRAPH-#227DA, IRGKangXi=0398.261, RSKangXi=61.10
227DB CJK UNIFIED IDEOGRAPH-#227DB, IRGKangXi=0398.261, RSKangXi=61.10
227DC CJK UNIFIED IDEOGRAPH-#227DC, IRGKangXi=0398.261, RSKangXi=61.10
227DD CJK UNIFIED IDEOGRAPH-#227DD, IRGKangXi=0398.261, RSKangXi=61.10
227DE CJK UNIFIED IDEOGRAPH-#227DE, IRGKangXi=0398.261, RSKangXi=61.10
227DF CJK UNIFIED IDEOGRAPH-#227DF, IRGKangXi=0398.261, RSKangXi=61.10
227E0 CJK UNIFIED IDEOGRAPH-#227E0, IRGKangXi=0398.280, RSKangXi=61.11
227E1 CJK UNIFIED IDEOGRAPH-#227E1, IRGKangXi=0398.300, RSKangXi=61.11
227E2 CJK UNIFIED IDEOGRAPH-#227E2, IRGKangXi=0398.340, RSKangXi=61.11
227E3 CJK UNIFIED IDEOGRAPH-#227E3, IRGKangXi=0399.070, RSKangXi=61.11
227E4 CJK UNIFIED IDEOGRAPH-#227E4, IRGKangXi=0399.100, RSKangXi=61.11
227E5 CJK UNIFIED IDEOGRAPH-#227E5, IRGKangXi=0399.150, RSKangXi=61.11
227E6 CJK UNIFIED IDEOGRAPH-#227E6, IRGKangXi=0399.190, RSKangXi=61.11
227E7 CJK UNIFIED IDEOGRAPH-#227E7, IRGKangXi=0399.200, RSKangXi=61.11
227E8 CJK UNIFIED IDEOGRAPH-#227E8, IRGKangXi=0399.210, RSKangXi=61.11
227E9 CJK UNIFIED IDEOGRAPH-#227E9, IRGKangXi=0399.220, RSKangXi=61.11
227EA CJK UNIFIED IDEOGRAPH-#227EA, IRGKangXi=0399.230, RSKangXi=61.11
227EB CJK UNIFIED IDEOGRAPH-#227EB, IRGKangXi=0399.320, RSKangXi=61.11
227EC CJK UNIFIED IDEOGRAPH-#227EC, IRGKangXi=0400.020, RSKangXi=61.11
227ED CJK UNIFIED IDEOGRAPH-#227ED, IRGKangXi=0400.040, RSKangXi=61.11
227EE CJK UNIFIED IDEOGRAPH-#227EE, IRGKangXi=0400.070, RSKangXi=61.11
227EF CJK UNIFIED IDEOGRAPH-#227EF, IRGKangXi=0401.030, RSKangXi=61.11
227F0 CJK UNIFIED IDEOGRAPH-#227F0, IRGKangXi=0401.040, RSKangXi=61.11
227F1 CJK UNIFIED IDEOGRAPH-#227F1, IRGKangXi=0401.060, RSKangXi=61.11
227F2 CJK UNIFIED IDEOGRAPH-#227F2, IRGKangXi=0401.090, RSKangXi=61.11
227F3 CJK UNIFIED IDEOGRAPH-#227F3, IRGKangXi=0401.100, RSKangXi=61.11
227F4 CJK UNIFIED IDEOGRAPH-#227F4, IRGKangXi=0401.110, RSKangXi=61.11
227F5 CJK UNIFIED IDEOGRAPH-#227F5, IRGKangXi=0401.150, RSKangXi=61.11
227F6 CJK UNIFIED IDEOGRAPH-#227F6, IRGKangXi=0401.170, RSKangXi=61.11
227F7 CJK UNIFIED IDEOGRAPH-#227F7, IRGKangXi=0401.200, RSKangXi=61.11
227F8 CJK UNIFIED IDEOGRAPH-#227F8, IRGKangXi=0401.210, RSKangXi=61.11
227F9 CJK UNIFIED IDEOGRAPH-#227F9, IRGKangXi=0401.230, RSKangXi=61.11
227FA CJK UNIFIED IDEOGRAPH-#227FA, IRGKangXi=0401.240, RSKangXi=61.11
227FB CJK UNIFIED IDEOGRAPH-#227FB, IRGKangXi=0401.290, RSKangXi=61.11
227FC CJK UNIFIED IDEOGRAPH-#227FC, IRGKangXi=0401.330, RSKangXi=61.11
227FD CJK UNIFIED IDEOGRAPH-#227FD, IRGKangXi=0401.340, RSKangXi=61.11
227FE CJK UNIFIED IDEOGRAPH-#227FE, IRGKangXi=0401.350, RSKangXi=61.11
227FF CJK UNIFIED IDEOGRAPH-#227FF, IRGKangXi=0401.380, RSKangXi=61.11
22800 CJK UNIFIED IDEOGRAPH-#22800, IRGKangXi=0401.390, RSKangXi=61.11
22801 CJK UNIFIED IDEOGRAPH-#22801, IRGKangXi=0401.391, RSKangXi=61.11
22802 CJK UNIFIED IDEOGRAPH-#22802, IRGKangXi=0401.391, RSKangXi=61.11
22803 CJK UNIFIED IDEOGRAPH-#22803, IRGKangXi=0401.391, RSKangXi=61.11, Def{(Cant.) to guard against; to take precautions}
22804 CJK UNIFIED IDEOGRAPH-#22804, IRGKangXi=0401.391, RSKangXi=61.11
22805 CJK UNIFIED IDEOGRAPH-#22805, IRGKangXi=0401.391, RSKangXi=61.11
22806 CJK UNIFIED IDEOGRAPH-#22806, IRGKangXi=0401.391, RSKangXi=61.11
22807 CJK UNIFIED IDEOGRAPH-#22807, IRGKangXi=0401.391, RSKangXi=61.11
22808 CJK UNIFIED IDEOGRAPH-#22808, IRGKangXi=0401.391, RSKangXi=61.11
22809 CJK UNIFIED IDEOGRAPH-#22809, IRGKangXi=0401.391, RSKangXi=61.11
2280A CJK UNIFIED IDEOGRAPH-#2280A, IRGKangXi=0401.391, RSKangXi=61.11
2280B CJK UNIFIED IDEOGRAPH-#2280B, IRGKangXi=0401.391, RSKangXi=61.11
2280C CJK UNIFIED IDEOGRAPH-#2280C, IRGKangXi=0401.391, RSKangXi=61.11
2280D CJK UNIFIED IDEOGRAPH-#2280D, IRGKangXi=0401.391, RSKangXi=61.11
2280E CJK UNIFIED IDEOGRAPH-#2280E, IRGKangXi=0401.391, RSKangXi=61.11
2280F CJK UNIFIED IDEOGRAPH-#2280F, IRGKangXi=0401.391, RSKangXi=61.11
22810 CJK UNIFIED IDEOGRAPH-#22810, IRGKangXi=0401.391, RSKangXi=61.11
22811 CJK UNIFIED IDEOGRAPH-#22811, IRGKangXi=0401.391, RSKangXi=61.11
22812 CJK UNIFIED IDEOGRAPH-#22812, IRGKangXi=0401.391, RSKangXi=61.11
22813 CJK UNIFIED IDEOGRAPH-#22813, IRGKangXi=0401.391, RSKangXi=61.11
22814 CJK UNIFIED IDEOGRAPH-#22814, IRGKangXi=0401.391, RSKangXi=61.11
22815 CJK UNIFIED IDEOGRAPH-#22815, IRGKangXi=0401.391, RSKangXi=61.11
22816 CJK UNIFIED IDEOGRAPH-#22816, IRGKangXi=0401.391, RSKangXi=61.11
22817 CJK UNIFIED IDEOGRAPH-#22817, IRGKangXi=0401.391, RSKangXi=61.11
22818 CJK UNIFIED IDEOGRAPH-#22818, IRGKangXi=0401.391, RSKangXi=61.11
22819 CJK UNIFIED IDEOGRAPH-#22819, IRGKangXi=0401.391, RSKangXi=61.11
2281A CJK UNIFIED IDEOGRAPH-#2281A, IRGKangXi=0401.391, RSKangXi=61.11
2281B CJK UNIFIED IDEOGRAPH-#2281B, IRGKangXi=0401.391, RSKangXi=61.11
2281C CJK UNIFIED IDEOGRAPH-#2281C, IRGKangXi=0401.391, RSKangXi=61.11
2281D CJK UNIFIED IDEOGRAPH-#2281D, IRGKangXi=0401.391, RSKangXi=61.11
2281E CJK UNIFIED IDEOGRAPH-#2281E, IRGKangXi=0401.391, RSKangXi=61.11
2281F CJK UNIFIED IDEOGRAPH-#2281F, IRGKangXi=0401.391, RSKangXi=61.11
22820 CJK UNIFIED IDEOGRAPH-#22820, IRGKangXi=0401.391, RSKangXi=61.11
22821 CJK UNIFIED IDEOGRAPH-#22821, IRGKangXi=0401.391, RSKangXi=61.11
22822 CJK UNIFIED IDEOGRAPH-#22822, IRGKangXi=0401.391, RSKangXi=61.11
22823 CJK UNIFIED IDEOGRAPH-#22823, IRGKangXi=0401.391, RSKangXi=61.11
22824 CJK UNIFIED IDEOGRAPH-#22824, IRGKangXi=0401.391, RSKangXi=61.11
22825 CJK UNIFIED IDEOGRAPH-#22825, IRGKangXi=0401.391, RSKangXi=61.11
22826 CJK UNIFIED IDEOGRAPH-#22826, IRGKangXi=0401.391, RSKangXi=61.11
22827 CJK UNIFIED IDEOGRAPH-#22827, IRGKangXi=0401.391, RSKangXi=61.11
22828 CJK UNIFIED IDEOGRAPH-#22828, IRGKangXi=0401.391, RSKangXi=61.11
22829 CJK UNIFIED IDEOGRAPH-#22829, IRGKangXi=0401.391, RSKangXi=61.11
2282A CJK UNIFIED IDEOGRAPH-#2282A, IRGKangXi=0401.391, RSKangXi=61.11
2282B CJK UNIFIED IDEOGRAPH-#2282B, IRGKangXi=0401.391, RSKangXi=61.11
2282C CJK UNIFIED IDEOGRAPH-#2282C, IRGKangXi=0401.391, RSKangXi=61.11
2282D CJK UNIFIED IDEOGRAPH-#2282D, IRGKangXi=0401.391, RSKangXi=61.11
2282E CJK UNIFIED IDEOGRAPH-#2282E, IRGKangXi=0401.391, RSKangXi=61.11
2282F CJK UNIFIED IDEOGRAPH-#2282F, IRGKangXi=0401.391, RSKangXi=61.11
22830 CJK UNIFIED IDEOGRAPH-#22830, IRGKangXi=0401.391, RSKangXi=61.11
22831 CJK UNIFIED IDEOGRAPH-#22831, IRGKangXi=0401.430, RSKangXi=61.12
22832 CJK UNIFIED IDEOGRAPH-#22832, IRGKangXi=0401.440, RSKangXi=61.12
22833 CJK UNIFIED IDEOGRAPH-#22833, IRGKangXi=0402.040, RSKangXi=61.12, Def{irritable, surly; sad}
22834 CJK UNIFIED IDEOGRAPH-#22834, IRGKangXi=0402.140, RSKangXi=61.12
22835 CJK UNIFIED IDEOGRAPH-#22835, IRGKangXi=0402.150, RSKangXi=61.12, Def{alarmed, agitated}
22836 CJK UNIFIED IDEOGRAPH-#22836, IRGKangXi=0402.230, RSKangXi=61.12
22837 CJK UNIFIED IDEOGRAPH-#22837, IRGKangXi=0402.270, RSKangXi=61.12
22838 CJK UNIFIED IDEOGRAPH-#22838, IRGKangXi=0403.020, RSKangXi=61.12
22839 CJK UNIFIED IDEOGRAPH-#22839, IRGKangXi=0403.090, RSKangXi=61.12
2283A CJK UNIFIED IDEOGRAPH-#2283A, IRGKangXi=0403.120, RSKangXi=61.12
2283B CJK UNIFIED IDEOGRAPH-#2283B, IRGKangXi=0403.140, RSKangXi=61.12
2283C CJK UNIFIED IDEOGRAPH-#2283C, IRGKangXi=0403.150, RSKangXi=61.12
2283D CJK UNIFIED IDEOGRAPH-#2283D, IRGKangXi=0403.180, RSKangXi=61.12
2283E CJK UNIFIED IDEOGRAPH-#2283E, IRGKangXi=0403.270, RSKangXi=61.12
2283F CJK UNIFIED IDEOGRAPH-#2283F, IRGKangXi=0403.280, RSKangXi=61.12
22840 CJK UNIFIED IDEOGRAPH-#22840, IRGKangXi=0403.290, RSKangXi=61.12
22841 CJK UNIFIED IDEOGRAPH-#22841, IRGKangXi=0403.300, RSKangXi=61.12
22842 CJK UNIFIED IDEOGRAPH-#22842, IRGKangXi=0403.330, RSKangXi=61.12
22843 CJK UNIFIED IDEOGRAPH-#22843, IRGKangXi=0403.370, RSKangXi=61.12
22844 CJK UNIFIED IDEOGRAPH-#22844, IRGKangXi=0404.030, RSKangXi=61.12
22845 CJK UNIFIED IDEOGRAPH-#22845, IRGKangXi=0404.050, RSKangXi=61.12
22846 CJK UNIFIED IDEOGRAPH-#22846, IRGKangXi=0404.070, RSKangXi=61.12
22847 CJK UNIFIED IDEOGRAPH-#22847, IRGKangXi=0404.080, RSKangXi=61.12
22848 CJK UNIFIED IDEOGRAPH-#22848, IRGKangXi=0404.100, RSKangXi=61.12
22849 CJK UNIFIED IDEOGRAPH-#22849, IRGKangXi=0404.120, RSKangXi=61.12
2284A CJK UNIFIED IDEOGRAPH-#2284A, IRGKangXi=0404.130, RSKangXi=61.12
2284B CJK UNIFIED IDEOGRAPH-#2284B, IRGKangXi=0404.140, RSKangXi=61.12
2284C CJK UNIFIED IDEOGRAPH-#2284C, IRGKangXi=0404.170, RSKangXi=61.12
2284D CJK UNIFIED IDEOGRAPH-#2284D, IRGKangXi=0404.180, RSKangXi=61.12
2284E CJK UNIFIED IDEOGRAPH-#2284E, IRGKangXi=0404.190, RSKangXi=61.12
2284F CJK UNIFIED IDEOGRAPH-#2284F, IRGKangXi=0404.200, RSKangXi=61.12
22850 CJK UNIFIED IDEOGRAPH-#22850, IRGKangXi=0404.210, RSKangXi=61.12
22851 CJK UNIFIED IDEOGRAPH-#22851, IRGKangXi=0404.220, RSKangXi=61.12
22852 CJK UNIFIED IDEOGRAPH-#22852, IRGKangXi=0404.230, RSKangXi=61.12
22853 CJK UNIFIED IDEOGRAPH-#22853, IRGKangXi=0404.240, RSKangXi=61.12
22854 CJK UNIFIED IDEOGRAPH-#22854, IRGKangXi=0404.250, RSKangXi=61.12
22855 CJK UNIFIED IDEOGRAPH-#22855, IRGKangXi=0404.260, RSKangXi=61.12
22856 CJK UNIFIED IDEOGRAPH-#22856, IRGKangXi=0404.270, RSKangXi=61.12
22857 CJK UNIFIED IDEOGRAPH-#22857, IRGKangXi=0404.280, RSKangXi=61.12
22858 CJK UNIFIED IDEOGRAPH-#22858, IRGKangXi=0404.290, RSKangXi=61.12
22859 CJK UNIFIED IDEOGRAPH-#22859, IRGKangXi=0404.300, RSKangXi=61.12
2285A CJK UNIFIED IDEOGRAPH-#2285A, IRGKangXi=0404.301, RSKangXi=61.12
2285B CJK UNIFIED IDEOGRAPH-#2285B, IRGKangXi=0404.301, RSKangXi=61.12
2285C CJK UNIFIED IDEOGRAPH-#2285C, IRGKangXi=0404.301, RSKangXi=61.12
2285D CJK UNIFIED IDEOGRAPH-#2285D, IRGKangXi=0404.301, RSKangXi=61.12
2285E CJK UNIFIED IDEOGRAPH-#2285E, IRGKangXi=0404.301, RSKangXi=61.12
2285F CJK UNIFIED IDEOGRAPH-#2285F, IRGKangXi=0404.301, RSKangXi=61.12
22860 CJK UNIFIED IDEOGRAPH-#22860, IRGKangXi=0404.301, RSKangXi=61.12
22861 CJK UNIFIED IDEOGRAPH-#22861, IRGKangXi=0404.301, RSKangXi=61.12
22862 CJK UNIFIED IDEOGRAPH-#22862, IRGKangXi=0404.301, RSKangXi=61.12
22863 CJK UNIFIED IDEOGRAPH-#22863, IRGKangXi=0404.301, RSKangXi=61.12
22864 CJK UNIFIED IDEOGRAPH-#22864, IRGKangXi=0404.301, RSKangXi=61.12
22865 CJK UNIFIED IDEOGRAPH-#22865, IRGKangXi=0404.301, RSKangXi=61.12
22866 CJK UNIFIED IDEOGRAPH-#22866, IRGKangXi=0404.301, RSKangXi=61.12
22867 CJK UNIFIED IDEOGRAPH-#22867, IRGKangXi=0404.301, RSKangXi=61.12
22868 CJK UNIFIED IDEOGRAPH-#22868, IRGKangXi=0404.301, RSKangXi=61.12
22869 CJK UNIFIED IDEOGRAPH-#22869, IRGKangXi=0404.301, RSKangXi=61.12
2286A CJK UNIFIED IDEOGRAPH-#2286A, IRGKangXi=0404.301, RSKangXi=61.12
2286B CJK UNIFIED IDEOGRAPH-#2286B, IRGKangXi=0404.301, RSKangXi=61.12
2286C CJK UNIFIED IDEOGRAPH-#2286C, IRGKangXi=0404.301, RSKangXi=61.12
2286D CJK UNIFIED IDEOGRAPH-#2286D, IRGKangXi=0404.301, RSKangXi=61.12
2286E CJK UNIFIED IDEOGRAPH-#2286E, IRGKangXi=0404.301, RSKangXi=61.12
2286F CJK UNIFIED IDEOGRAPH-#2286F, IRGKangXi=0404.301, RSKangXi=61.12
22870 CJK UNIFIED IDEOGRAPH-#22870, IRGKangXi=0404.301, RSKangXi=61.12
22871 CJK UNIFIED IDEOGRAPH-#22871, IRGKangXi=0404.301, RSKangXi=61.12
22872 CJK UNIFIED IDEOGRAPH-#22872, IRGKangXi=0404.301, RSKangXi=61.12
22873 CJK UNIFIED IDEOGRAPH-#22873, IRGKangXi=0404.301, RSKangXi=61.12
22874 CJK UNIFIED IDEOGRAPH-#22874, IRGKangXi=0404.301, RSKangXi=61.12
22875 CJK UNIFIED IDEOGRAPH-#22875, IRGKangXi=0404.301, RSKangXi=61.12
22876 CJK UNIFIED IDEOGRAPH-#22876, IRGKangXi=0404.301, RSKangXi=61.12
22877 CJK UNIFIED IDEOGRAPH-#22877, IRGKangXi=0404.301, RSKangXi=61.12
22878 CJK UNIFIED IDEOGRAPH-#22878, IRGKangXi=0404.301, RSKangXi=61.12
22879 CJK UNIFIED IDEOGRAPH-#22879, IRGKangXi=0404.301, RSKangXi=61.12
2287A CJK UNIFIED IDEOGRAPH-#2287A, IRGKangXi=0404.301, RSKangXi=61.12
2287B CJK UNIFIED IDEOGRAPH-#2287B, IRGKangXi=0404.301, RSKangXi=61.12
2287C CJK UNIFIED IDEOGRAPH-#2287C, IRGKangXi=0404.301, RSKangXi=61.12
2287D CJK UNIFIED IDEOGRAPH-#2287D, IRGKangXi=0404.301, RSKangXi=61.12
2287E CJK UNIFIED IDEOGRAPH-#2287E, IRGKangXi=0404.301, RSKangXi=61.12
2287F CJK UNIFIED IDEOGRAPH-#2287F, IRGKangXi=0404.301, RSKangXi=61.12
22880 CJK UNIFIED IDEOGRAPH-#22880, IRGKangXi=0404.301, RSKangXi=61.12
22881 CJK UNIFIED IDEOGRAPH-#22881, IRGKangXi=0404.301, RSKangXi=61.12
22882 CJK UNIFIED IDEOGRAPH-#22882, IRGKangXi=0404.301, RSKangXi=61.12
22883 CJK UNIFIED IDEOGRAPH-#22883, IRGKangXi=0404.301, RSKangXi=61.12
22884 CJK UNIFIED IDEOGRAPH-#22884, IRGKangXi=0404.301, RSKangXi=61.12
22885 CJK UNIFIED IDEOGRAPH-#22885, IRGKangXi=0404.301, RSKangXi=61.12
22886 CJK UNIFIED IDEOGRAPH-#22886, IRGKangXi=0404.301, RSKangXi=61.12
22887 CJK UNIFIED IDEOGRAPH-#22887, IRGKangXi=0404.301, RSKangXi=61.12
22888 CJK UNIFIED IDEOGRAPH-#22888, IRGKangXi=0404.301, RSKangXi=61.12
22889 CJK UNIFIED IDEOGRAPH-#22889, IRGKangXi=0404.301, RSKangXi=61.12
2288A CJK UNIFIED IDEOGRAPH-#2288A, IRGKangXi=0404.301, RSKangXi=61.12
2288B CJK UNIFIED IDEOGRAPH-#2288B, IRGKangXi=0404.301, RSKangXi=61.12
2288C CJK UNIFIED IDEOGRAPH-#2288C, IRGKangXi=0404.301, RSKangXi=61.12
2288D CJK UNIFIED IDEOGRAPH-#2288D, IRGKangXi=0404.301, RSKangXi=61.12
2288E CJK UNIFIED IDEOGRAPH-#2288E, IRGKangXi=0404.301, RSKangXi=61.12
2288F CJK UNIFIED IDEOGRAPH-#2288F, IRGKangXi=0404.301, RSKangXi=61.12
22890 CJK UNIFIED IDEOGRAPH-#22890, IRGKangXi=0404.301, RSKangXi=61.12
22891 CJK UNIFIED IDEOGRAPH-#22891, IRGKangXi=0404.301, RSKangXi=61.12
22892 CJK UNIFIED IDEOGRAPH-#22892, IRGKangXi=0404.340, RSKangXi=61.13
22893 CJK UNIFIED IDEOGRAPH-#22893, IRGKangXi=0404.360, RSKangXi=61.13
22894 CJK UNIFIED IDEOGRAPH-#22894, IRGKangXi=0404.380, RSKangXi=61.13
22895 CJK UNIFIED IDEOGRAPH-#22895, IRGKangXi=0404.390, RSKangXi=61.13
22896 CJK UNIFIED IDEOGRAPH-#22896, IRGKangXi=0404.400, RSKangXi=61.13
22897 CJK UNIFIED IDEOGRAPH-#22897, IRGKangXi=0404.410, RSKangXi=61.13
22898 CJK UNIFIED IDEOGRAPH-#22898, IRGKangXi=0404.450, RSKangXi=61.13
22899 CJK UNIFIED IDEOGRAPH-#22899, IRGKangXi=0405.020, RSKangXi=61.13
2289A CJK UNIFIED IDEOGRAPH-#2289A, IRGKangXi=0405.050, RSKangXi=61.13
2289B CJK UNIFIED IDEOGRAPH-#2289B, IRGKangXi=0405.060, RSKangXi=61.13
2289C CJK UNIFIED IDEOGRAPH-#2289C, IRGKangXi=0405.100, RSKangXi=61.13
2289D CJK UNIFIED IDEOGRAPH-#2289D, IRGKangXi=0405.150, RSKangXi=61.13
2289E CJK UNIFIED IDEOGRAPH-#2289E, IRGKangXi=0405.220, RSKangXi=61.13
2289F CJK UNIFIED IDEOGRAPH-#2289F, IRGKangXi=0406.060, RSKangXi=61.13
228A0 CJK UNIFIED IDEOGRAPH-#228A0, IRGKangXi=0406.070, RSKangXi=61.13
228A1 CJK UNIFIED IDEOGRAPH-#228A1, IRGKangXi=0406.080, RSKangXi=61.13
228A2 CJK UNIFIED IDEOGRAPH-#228A2, IRGKangXi=0406.090, RSKangXi=61.13
228A3 CJK UNIFIED IDEOGRAPH-#228A3, IRGKangXi=0406.100, RSKangXi=61.13
228A4 CJK UNIFIED IDEOGRAPH-#228A4, IRGKangXi=0406.110, RSKangXi=61.13
228A5 CJK UNIFIED IDEOGRAPH-#228A5, IRGKangXi=0406.120, RSKangXi=61.13
228A6 CJK UNIFIED IDEOGRAPH-#228A6, IRGKangXi=0406.130, RSKangXi=61.13
228A7 CJK UNIFIED IDEOGRAPH-#228A7, IRGKangXi=0406.140, RSKangXi=61.13
228A8 CJK UNIFIED IDEOGRAPH-#228A8, IRGKangXi=0406.141, RSKangXi=61.13
228A9 CJK UNIFIED IDEOGRAPH-#228A9, IRGKangXi=0406.141, RSKangXi=61.13
228AA CJK UNIFIED IDEOGRAPH-#228AA, IRGKangXi=0406.141, RSKangXi=61.13
228AB CJK UNIFIED IDEOGRAPH-#228AB, IRGKangXi=0406.141, RSKangXi=61.13
228AC CJK UNIFIED IDEOGRAPH-#228AC, IRGKangXi=0406.141, RSKangXi=61.13
228AD CJK UNIFIED IDEOGRAPH-#228AD, IRGKangXi=0406.141, RSKangXi=61.13
228AE CJK UNIFIED IDEOGRAPH-#228AE, IRGKangXi=0406.141, RSKangXi=61.13
228AF CJK UNIFIED IDEOGRAPH-#228AF, IRGKangXi=0406.141, RSKangXi=61.13
228B0 CJK UNIFIED IDEOGRAPH-#228B0, IRGKangXi=0406.141, RSKangXi=61.13
228B1 CJK UNIFIED IDEOGRAPH-#228B1, IRGKangXi=0406.141, RSKangXi=61.13
228B2 CJK UNIFIED IDEOGRAPH-#228B2, IRGKangXi=0406.141, RSKangXi=61.13
228B3 CJK UNIFIED IDEOGRAPH-#228B3, IRGKangXi=0406.141, RSKangXi=61.13
228B4 CJK UNIFIED IDEOGRAPH-#228B4, IRGKangXi=0406.141, RSKangXi=61.13
228B5 CJK UNIFIED IDEOGRAPH-#228B5, IRGKangXi=0406.141, RSKangXi=61.13
228B6 CJK UNIFIED IDEOGRAPH-#228B6, IRGKangXi=0406.141, RSKangXi=61.13
228B7 CJK UNIFIED IDEOGRAPH-#228B7, IRGKangXi=0406.141, RSKangXi=61.13
228B8 CJK UNIFIED IDEOGRAPH-#228B8, IRGKangXi=0406.141, RSKangXi=61.13
228B9 CJK UNIFIED IDEOGRAPH-#228B9, IRGKangXi=0406.141, RSKangXi=61.13
228BA CJK UNIFIED IDEOGRAPH-#228BA, IRGKangXi=0406.141, RSKangXi=61.13
228BB CJK UNIFIED IDEOGRAPH-#228BB, IRGKangXi=0406.141, RSKangXi=61.13
228BC CJK UNIFIED IDEOGRAPH-#228BC, IRGKangXi=0406.141, RSKangXi=61.13
228BD CJK UNIFIED IDEOGRAPH-#228BD, IRGKangXi=0406.141, RSKangXi=61.13
228BE CJK UNIFIED IDEOGRAPH-#228BE, IRGKangXi=0406.141, RSKangXi=61.13
228BF CJK UNIFIED IDEOGRAPH-#228BF, IRGKangXi=0406.141, RSKangXi=61.13
228C0 CJK UNIFIED IDEOGRAPH-#228C0, IRGKangXi=0406.141, RSKangXi=61.13
228C1 CJK UNIFIED IDEOGRAPH-#228C1, IRGKangXi=0406.141, RSKangXi=61.13
228C2 CJK UNIFIED IDEOGRAPH-#228C2, IRGKangXi=0406.141, RSKangXi=61.13
228C3 CJK UNIFIED IDEOGRAPH-#228C3, IRGKangXi=0406.141, RSKangXi=61.13
228C4 CJK UNIFIED IDEOGRAPH-#228C4, IRGKangXi=0406.141, RSKangXi=61.13
228C5 CJK UNIFIED IDEOGRAPH-#228C5, IRGKangXi=0406.141, RSKangXi=61.13
228C6 CJK UNIFIED IDEOGRAPH-#228C6, IRGKangXi=0406.141, RSKangXi=61.13
228C7 CJK UNIFIED IDEOGRAPH-#228C7, IRGKangXi=0406.141, RSKangXi=61.13
228C8 CJK UNIFIED IDEOGRAPH-#228C8, IRGKangXi=0406.141, RSKangXi=61.13
228C9 CJK UNIFIED IDEOGRAPH-#228C9, IRGKangXi=0406.141, RSKangXi=61.13
228CA CJK UNIFIED IDEOGRAPH-#228CA, IRGKangXi=0406.141, RSKangXi=61.13
228CB CJK UNIFIED IDEOGRAPH-#228CB, IRGKangXi=0406.141, RSKangXi=61.13
228CC CJK UNIFIED IDEOGRAPH-#228CC, IRGKangXi=0406.141, RSKangXi=61.13
228CD CJK UNIFIED IDEOGRAPH-#228CD, IRGKangXi=0406.141, RSKangXi=61.13
228CE CJK UNIFIED IDEOGRAPH-#228CE, IRGKangXi=0406.150, RSKangXi=61.14
228CF CJK UNIFIED IDEOGRAPH-#228CF, IRGKangXi=0406.160, RSKangXi=61.14
228D0 CJK UNIFIED IDEOGRAPH-#228D0, IRGKangXi=0406.170, RSKangXi=61.14
228D1 CJK UNIFIED IDEOGRAPH-#228D1, IRGKangXi=0406.210, RSKangXi=61.14
228D2 CJK UNIFIED IDEOGRAPH-#228D2, IRGKangXi=0406.220, RSKangXi=61.14
228D3 CJK UNIFIED IDEOGRAPH-#228D3, IRGKangXi=0406.290, RSKangXi=61.14
228D4 CJK UNIFIED IDEOGRAPH-#228D4, IRGKangXi=0406.310, RSKangXi=61.14
228D5 CJK UNIFIED IDEOGRAPH-#228D5, IRGKangXi=0406.340, RSKangXi=61.14
228D6 CJK UNIFIED IDEOGRAPH-#228D6, IRGKangXi=0406.390, RSKangXi=61.14
228D7 CJK UNIFIED IDEOGRAPH-#228D7, IRGKangXi=0406.400, RSKangXi=61.14
228D8 CJK UNIFIED IDEOGRAPH-#228D8, IRGKangXi=0406.410, RSKangXi=61.14
228D9 CJK UNIFIED IDEOGRAPH-#228D9, IRGKangXi=0406.420, RSKangXi=61.14
228DA CJK UNIFIED IDEOGRAPH-#228DA, IRGKangXi=0407.010, RSKangXi=61.14
228DB CJK UNIFIED IDEOGRAPH-#228DB, IRGKangXi=0407.070, RSKangXi=61.14
228DC CJK UNIFIED IDEOGRAPH-#228DC, IRGKangXi=0407.090, RSKangXi=61.14
228DD CJK UNIFIED IDEOGRAPH-#228DD, IRGKangXi=0407.100, RSKangXi=61.14
228DE CJK UNIFIED IDEOGRAPH-#228DE, IRGKangXi=0407.110, RSKangXi=61.14
228DF CJK UNIFIED IDEOGRAPH-#228DF, IRGKangXi=0407.130, RSKangXi=61.14
228E0 CJK UNIFIED IDEOGRAPH-#228E0, IRGKangXi=0407.140, RSKangXi=61.14
228E1 CJK UNIFIED IDEOGRAPH-#228E1, IRGKangXi=0407.150, RSKangXi=61.14
228E2 CJK UNIFIED IDEOGRAPH-#228E2, IRGKangXi=0407.160, RSKangXi=61.14
228E3 CJK UNIFIED IDEOGRAPH-#228E3, IRGKangXi=0407.161, RSKangXi=61.14
228E4 CJK UNIFIED IDEOGRAPH-#228E4, IRGKangXi=0407.161, RSKangXi=61.14
228E5 CJK UNIFIED IDEOGRAPH-#228E5, IRGKangXi=0407.161, RSKangXi=61.14
228E6 CJK UNIFIED IDEOGRAPH-#228E6, IRGKangXi=0407.161, RSKangXi=61.14
228E7 CJK UNIFIED IDEOGRAPH-#228E7, IRGKangXi=0407.161, RSKangXi=61.14
228E8 CJK UNIFIED IDEOGRAPH-#228E8, IRGKangXi=0407.161, RSKangXi=61.14
228E9 CJK UNIFIED IDEOGRAPH-#228E9, IRGKangXi=0407.161, RSKangXi=61.14
228EA CJK UNIFIED IDEOGRAPH-#228EA, IRGKangXi=0407.161, RSKangXi=61.14
228EB CJK UNIFIED IDEOGRAPH-#228EB, IRGKangXi=0407.161, RSKangXi=61.14
228EC CJK UNIFIED IDEOGRAPH-#228EC, IRGKangXi=0407.161, RSKangXi=61.14
228ED CJK UNIFIED IDEOGRAPH-#228ED, IRGKangXi=0407.161, RSKangXi=61.14
228EE CJK UNIFIED IDEOGRAPH-#228EE, IRGKangXi=0407.161, RSKangXi=61.14
228EF CJK UNIFIED IDEOGRAPH-#228EF, IRGKangXi=0407.161, RSKangXi=61.14
228F0 CJK UNIFIED IDEOGRAPH-#228F0, IRGKangXi=0407.161, RSKangXi=61.14
228F1 CJK UNIFIED IDEOGRAPH-#228F1, IRGKangXi=0407.161, RSKangXi=61.14
228F2 CJK UNIFIED IDEOGRAPH-#228F2, IRGKangXi=0407.161, RSKangXi=61.14
228F3 CJK UNIFIED IDEOGRAPH-#228F3, IRGKangXi=0407.161, RSKangXi=61.14
228F4 CJK UNIFIED IDEOGRAPH-#228F4, IRGKangXi=0407.161, RSKangXi=61.14
228F5 CJK UNIFIED IDEOGRAPH-#228F5, IRGKangXi=0407.161, RSKangXi=61.14
228F6 CJK UNIFIED IDEOGRAPH-#228F6, IRGKangXi=0407.161, RSKangXi=61.14
228F7 CJK UNIFIED IDEOGRAPH-#228F7, IRGKangXi=0407.161, RSKangXi=61.14
228F8 CJK UNIFIED IDEOGRAPH-#228F8, IRGKangXi=0407.161, RSKangXi=61.14
228F9 CJK UNIFIED IDEOGRAPH-#228F9, IRGKangXi=0407.161, RSKangXi=61.14
228FA CJK UNIFIED IDEOGRAPH-#228FA, IRGKangXi=0407.161, RSKangXi=61.14
228FB CJK UNIFIED IDEOGRAPH-#228FB, IRGKangXi=0407.190, RSKangXi=61.15
228FC CJK UNIFIED IDEOGRAPH-#228FC, IRGKangXi=0407.200, RSKangXi=61.15
228FD CJK UNIFIED IDEOGRAPH-#228FD, IRGKangXi=0407.210, RSKangXi=61.15
228FE CJK UNIFIED IDEOGRAPH-#228FE, IRGKangXi=0407.220, RSKangXi=61.15
228FF CJK UNIFIED IDEOGRAPH-#228FF, IRGKangXi=0407.260, RSKangXi=61.15
22900 CJK UNIFIED IDEOGRAPH-#22900, IRGKangXi=0407.290, RSKangXi=61.15
22901 CJK UNIFIED IDEOGRAPH-#22901, IRGKangXi=0407.300, RSKangXi=61.15
22902 CJK UNIFIED IDEOGRAPH-#22902, IRGKangXi=0407.330, RSKangXi=61.15
22903 CJK UNIFIED IDEOGRAPH-#22903, IRGKangXi=0407.340, RSKangXi=61.15
22904 CJK UNIFIED IDEOGRAPH-#22904, IRGKangXi=0407.350, RSKangXi=61.15
22905 CJK UNIFIED IDEOGRAPH-#22905, IRGKangXi=0407.370, RSKangXi=61.15
22906 CJK UNIFIED IDEOGRAPH-#22906, IRGKangXi=0407.380, RSKangXi=61.15
22907 CJK UNIFIED IDEOGRAPH-#22907, IRGKangXi=0407.390, RSKangXi=61.15
22908 CJK UNIFIED IDEOGRAPH-#22908, IRGKangXi=0407.420, RSKangXi=61.15
22909 CJK UNIFIED IDEOGRAPH-#22909, IRGKangXi=0407.430, RSKangXi=61.15
2290A CJK UNIFIED IDEOGRAPH-#2290A, IRGKangXi=0407.450, RSKangXi=61.15
2290B CJK UNIFIED IDEOGRAPH-#2290B, IRGKangXi=0407.460, RSKangXi=61.15
2290C CJK UNIFIED IDEOGRAPH-#2290C, IRGKangXi=0407.480, RSKangXi=61.15
2290D CJK UNIFIED IDEOGRAPH-#2290D, IRGKangXi=0407.490, RSKangXi=61.15
2290E CJK UNIFIED IDEOGRAPH-#2290E, IRGKangXi=0407.500, RSKangXi=61.15
2290F CJK UNIFIED IDEOGRAPH-#2290F, IRGKangXi=0407.510, RSKangXi=61.15
22910 CJK UNIFIED IDEOGRAPH-#22910, IRGKangXi=0407.520, RSKangXi=61.15
22911 CJK UNIFIED IDEOGRAPH-#22911, IRGKangXi=0407.530, RSKangXi=61.15
22912 CJK UNIFIED IDEOGRAPH-#22912, IRGKangXi=0407.540, RSKangXi=61.15
22913 CJK UNIFIED IDEOGRAPH-#22913, IRGKangXi=0407.550, RSKangXi=61.15
22914 CJK UNIFIED IDEOGRAPH-#22914, IRGKangXi=0407.551, RSKangXi=61.15
22915 CJK UNIFIED IDEOGRAPH-#22915, IRGKangXi=0407.551, RSKangXi=61.15
22916 CJK UNIFIED IDEOGRAPH-#22916, IRGKangXi=0407.551, RSKangXi=61.15
22917 CJK UNIFIED IDEOGRAPH-#22917, IRGKangXi=0407.551, RSKangXi=61.15
22918 CJK UNIFIED IDEOGRAPH-#22918, IRGKangXi=0407.551, RSKangXi=61.15
22919 CJK UNIFIED IDEOGRAPH-#22919, IRGKangXi=0407.551, RSKangXi=61.15
2291A CJK UNIFIED IDEOGRAPH-#2291A, IRGKangXi=0407.551, RSKangXi=61.15
2291B CJK UNIFIED IDEOGRAPH-#2291B, IRGKangXi=0407.551, RSKangXi=61.15
2291C CJK UNIFIED IDEOGRAPH-#2291C, IRGKangXi=0407.551, RSKangXi=61.15
2291D CJK UNIFIED IDEOGRAPH-#2291D, IRGKangXi=0407.551, RSKangXi=61.15
2291E CJK UNIFIED IDEOGRAPH-#2291E, IRGKangXi=0407.551, RSKangXi=61.15
2291F CJK UNIFIED IDEOGRAPH-#2291F, IRGKangXi=0407.551, RSKangXi=61.15
22920 CJK UNIFIED IDEOGRAPH-#22920, IRGKangXi=0407.551, RSKangXi=61.15
22921 CJK UNIFIED IDEOGRAPH-#22921, IRGKangXi=0407.551, RSKangXi=61.15
22922 CJK UNIFIED IDEOGRAPH-#22922, IRGKangXi=0407.551, RSKangXi=61.15
22923 CJK UNIFIED IDEOGRAPH-#22923, IRGKangXi=0407.551, RSKangXi=61.15
22924 CJK UNIFIED IDEOGRAPH-#22924, IRGKangXi=0407.551, RSKangXi=61.15
22925 CJK UNIFIED IDEOGRAPH-#22925, IRGKangXi=0407.551, RSKangXi=61.15
22926 CJK UNIFIED IDEOGRAPH-#22926, IRGKangXi=0408.010, RSKangXi=61.16
22927 CJK UNIFIED IDEOGRAPH-#22927, IRGKangXi=0408.020, RSKangXi=61.16
22928 CJK UNIFIED IDEOGRAPH-#22928, IRGKangXi=0408.030, RSKangXi=61.16
22929 CJK UNIFIED IDEOGRAPH-#22929, IRGKangXi=0408.040, RSKangXi=61.16
2292A CJK UNIFIED IDEOGRAPH-#2292A, IRGKangXi=0408.080, RSKangXi=61.16
2292B CJK UNIFIED IDEOGRAPH-#2292B, IRGKangXi=0408.090, RSKangXi=61.16
2292C CJK UNIFIED IDEOGRAPH-#2292C, IRGKangXi=0408.100, RSKangXi=61.16
2292D CJK UNIFIED IDEOGRAPH-#2292D, IRGKangXi=0408.110, RSKangXi=61.16
2292E CJK UNIFIED IDEOGRAPH-#2292E, IRGKangXi=0408.190, RSKangXi=61.16
2292F CJK UNIFIED IDEOGRAPH-#2292F, IRGKangXi=0408.200, RSKangXi=61.16
22930 CJK UNIFIED IDEOGRAPH-#22930, IRGKangXi=0408.210, RSKangXi=61.16
22931 CJK UNIFIED IDEOGRAPH-#22931, IRGKangXi=0408.220, RSKangXi=61.16
22932 CJK UNIFIED IDEOGRAPH-#22932, IRGKangXi=0408.230, RSKangXi=61.16
22933 CJK UNIFIED IDEOGRAPH-#22933, IRGKangXi=0408.250, RSKangXi=61.16
22934 CJK UNIFIED IDEOGRAPH-#22934, IRGKangXi=0408.260, RSKangXi=61.16
22935 CJK UNIFIED IDEOGRAPH-#22935, IRGKangXi=0408.270, RSKangXi=61.16
22936 CJK UNIFIED IDEOGRAPH-#22936, IRGKangXi=0408.280, RSKangXi=61.16
22937 CJK UNIFIED IDEOGRAPH-#22937, IRGKangXi=0408.290, RSKangXi=61.16
22938 CJK UNIFIED IDEOGRAPH-#22938, IRGKangXi=0408.291, RSKangXi=61.16
22939 CJK UNIFIED IDEOGRAPH-#22939, IRGKangXi=0408.291, RSKangXi=61.16, Def{(Cant.) satisfied, comfortable}
2293A CJK UNIFIED IDEOGRAPH-#2293A, IRGKangXi=0408.291, RSKangXi=61.16
2293B CJK UNIFIED IDEOGRAPH-#2293B, IRGKangXi=0408.291, RSKangXi=61.16
2293C CJK UNIFIED IDEOGRAPH-#2293C, IRGKangXi=0408.291, RSKangXi=61.16
2293D CJK UNIFIED IDEOGRAPH-#2293D, IRGKangXi=0408.291, RSKangXi=61.16
2293E CJK UNIFIED IDEOGRAPH-#2293E, IRGKangXi=0408.291, RSKangXi=61.16
2293F CJK UNIFIED IDEOGRAPH-#2293F, IRGKangXi=0408.291, RSKangXi=61.16
22940 CJK UNIFIED IDEOGRAPH-#22940, IRGKangXi=0408.291, RSKangXi=61.16
22941 CJK UNIFIED IDEOGRAPH-#22941, IRGKangXi=0408.291, RSKangXi=61.16
22942 CJK UNIFIED IDEOGRAPH-#22942, IRGKangXi=0408.291, RSKangXi=61.16
22943 CJK UNIFIED IDEOGRAPH-#22943, IRGKangXi=0408.291, RSKangXi=61.16
22944 CJK UNIFIED IDEOGRAPH-#22944, IRGKangXi=0408.291, RSKangXi=61.16
22945 CJK UNIFIED IDEOGRAPH-#22945, IRGKangXi=0408.291, RSKangXi=61.16
22946 CJK UNIFIED IDEOGRAPH-#22946, IRGKangXi=0408.291, RSKangXi=61.16
22947 CJK UNIFIED IDEOGRAPH-#22947, IRGKangXi=0408.291, RSKangXi=61.16
22948 CJK UNIFIED IDEOGRAPH-#22948, IRGKangXi=0408.291, RSKangXi=61.16
22949 CJK UNIFIED IDEOGRAPH-#22949, IRGKangXi=0408.291, RSKangXi=61.16
2294A CJK UNIFIED IDEOGRAPH-#2294A, IRGKangXi=0408.291, RSKangXi=61.16
2294B CJK UNIFIED IDEOGRAPH-#2294B, IRGKangXi=0408.291, RSKangXi=61.17
2294C CJK UNIFIED IDEOGRAPH-#2294C, IRGKangXi=0408.300, RSKangXi=61.17
2294D CJK UNIFIED IDEOGRAPH-#2294D, IRGKangXi=0408.330, RSKangXi=61.17
2294E CJK UNIFIED IDEOGRAPH-#2294E, IRGKangXi=0408.360, RSKangXi=61.17
2294F CJK UNIFIED IDEOGRAPH-#2294F, IRGKangXi=0408.370, RSKangXi=61.17
22950 CJK UNIFIED IDEOGRAPH-#22950, IRGKangXi=0408.390, RSKangXi=61.17
22951 CJK UNIFIED IDEOGRAPH-#22951, IRGKangXi=0408.400, RSKangXi=61.17
22952 CJK UNIFIED IDEOGRAPH-#22952, IRGKangXi=0408.410, RSKangXi=61.17
22953 CJK UNIFIED IDEOGRAPH-#22953, IRGKangXi=0408.420, RSKangXi=61.17
22954 CJK UNIFIED IDEOGRAPH-#22954, IRGKangXi=0408.421, RSKangXi=61.17
22955 CJK UNIFIED IDEOGRAPH-#22955, IRGKangXi=0408.421, RSKangXi=61.17
22956 CJK UNIFIED IDEOGRAPH-#22956, IRGKangXi=0408.421, RSKangXi=61.17
22957 CJK UNIFIED IDEOGRAPH-#22957, IRGKangXi=0408.460, RSKangXi=61.18
22958 CJK UNIFIED IDEOGRAPH-#22958, IRGKangXi=0408.470, RSKangXi=61.18
22959 CJK UNIFIED IDEOGRAPH-#22959, IRGKangXi=0408.480, RSKangXi=61.18
2295A CJK UNIFIED IDEOGRAPH-#2295A, IRGKangXi=0408.490, RSKangXi=61.18
2295B CJK UNIFIED IDEOGRAPH-#2295B, IRGKangXi=0408.500, RSKangXi=61.18
2295C CJK UNIFIED IDEOGRAPH-#2295C, IRGKangXi=0408.510, RSKangXi=61.18
2295D CJK UNIFIED IDEOGRAPH-#2295D, IRGKangXi=0408.520, RSKangXi=61.18
2295E CJK UNIFIED IDEOGRAPH-#2295E, IRGKangXi=0408.530, RSKangXi=61.18, Def{same as 忡; a sad, uneasy countenance}
2295F CJK UNIFIED IDEOGRAPH-#2295F, IRGKangXi=0409.030, RSKangXi=61.18
22960 CJK UNIFIED IDEOGRAPH-#22960, IRGKangXi=0409.040, RSKangXi=61.18, Def{terrified, afraid}
22961 CJK UNIFIED IDEOGRAPH-#22961, IRGKangXi=0409.060, RSKangXi=61.18
22962 CJK UNIFIED IDEOGRAPH-#22962, IRGKangXi=0409.061, RSKangXi=61.18
22963 CJK UNIFIED IDEOGRAPH-#22963, IRGKangXi=0409.061, RSKangXi=61.18
22964 CJK UNIFIED IDEOGRAPH-#22964, IRGKangXi=0409.061, RSKangXi=61.18
22965 CJK UNIFIED IDEOGRAPH-#22965, IRGKangXi=0409.080, RSKangXi=61.19
22966 CJK UNIFIED IDEOGRAPH-#22966, IRGKangXi=0409.120, RSKangXi=61.19
22967 CJK UNIFIED IDEOGRAPH-#22967, IRGKangXi=0409.150, RSKangXi=61.19
22968 CJK UNIFIED IDEOGRAPH-#22968, IRGKangXi=0409.160, RSKangXi=61.19
22969 CJK UNIFIED IDEOGRAPH-#22969, IRGKangXi=0409.170, RSKangXi=61.19
2296A CJK UNIFIED IDEOGRAPH-#2296A, IRGKangXi=0409.171, RSKangXi=61.19
2296B CJK UNIFIED IDEOGRAPH-#2296B, IRGKangXi=0409.171, RSKangXi=61.19
2296C CJK UNIFIED IDEOGRAPH-#2296C, IRGKangXi=0409.171, RSKangXi=61.19
2296D CJK UNIFIED IDEOGRAPH-#2296D, IRGKangXi=0409.171, RSKangXi=61.19
2296E CJK UNIFIED IDEOGRAPH-#2296E, IRGKangXi=0409.171, RSKangXi=61.19
2296F CJK UNIFIED IDEOGRAPH-#2296F, IRGKangXi=0409.180, RSKangXi=61.20
22970 CJK UNIFIED IDEOGRAPH-#22970, IRGKangXi=0409.190, RSKangXi=61.20
22971 CJK UNIFIED IDEOGRAPH-#22971, IRGKangXi=0409.220, RSKangXi=61.20
22972 CJK UNIFIED IDEOGRAPH-#22972, IRGKangXi=0409.230, RSKangXi=61.20
22973 CJK UNIFIED IDEOGRAPH-#22973, IRGKangXi=0409.240, RSKangXi=61.20
22974 CJK UNIFIED IDEOGRAPH-#22974, IRGKangXi=0409.241, RSKangXi=61.20
22975 CJK UNIFIED IDEOGRAPH-#22975, IRGKangXi=0409.241, RSKangXi=61.20
22976 CJK UNIFIED IDEOGRAPH-#22976, IRGKangXi=0409.241, RSKangXi=61.20
22977 CJK UNIFIED IDEOGRAPH-#22977, IRGKangXi=0409.241, RSKangXi=61.20
22978 CJK UNIFIED IDEOGRAPH-#22978, IRGKangXi=0409.241, RSKangXi=61.20
22979 CJK UNIFIED IDEOGRAPH-#22979, IRGKangXi=0409.241, RSKangXi=61.20
2297A CJK UNIFIED IDEOGRAPH-#2297A, IRGKangXi=0409.241, RSKangXi=61.20
2297B CJK UNIFIED IDEOGRAPH-#2297B, IRGKangXi=0409.250, RSKangXi=61.21
2297C CJK UNIFIED IDEOGRAPH-#2297C, IRGKangXi=0409.260, RSKangXi=61.21
2297D CJK UNIFIED IDEOGRAPH-#2297D, IRGKangXi=0409.280, RSKangXi=61.21
2297E CJK UNIFIED IDEOGRAPH-#2297E, IRGKangXi=0409.290, RSKangXi=61.21
2297F CJK UNIFIED IDEOGRAPH-#2297F, IRGKangXi=0409.291, RSKangXi=61.21
22980 CJK UNIFIED IDEOGRAPH-#22980, IRGKangXi=0409.291, RSKangXi=61.21
22981 CJK UNIFIED IDEOGRAPH-#22981, IRGKangXi=0409.291, RSKangXi=61.21
22982 CJK UNIFIED IDEOGRAPH-#22982, IRGKangXi=0409.291, RSKangXi=61.21, Def{(Cant.) to brag, praise oneself}
22983 CJK UNIFIED IDEOGRAPH-#22983, IRGKangXi=0409.291, RSKangXi=61.23
22984 CJK UNIFIED IDEOGRAPH-#22984, IRGKangXi=0409.291, RSKangXi=61.23
22985 CJK UNIFIED IDEOGRAPH-#22985, IRGKangXi=0409.320, RSKangXi=61.24
22986 CJK UNIFIED IDEOGRAPH-#22986, IRGKangXi=0409.321, RSKangXi=61.24
22987 CJK UNIFIED IDEOGRAPH-#22987, IRGKangXi=0409.321, RSKangXi=61.24
22988 CJK UNIFIED IDEOGRAPH-#22988, IRGKangXi=0409.330, RSKangXi=61.25
22989 CJK UNIFIED IDEOGRAPH-#22989, IRGKangXi=0409.340, RSKangXi=61.25
2298A CJK UNIFIED IDEOGRAPH-#2298A, IRGKangXi=0409.350, RSKangXi=61.27
2298B CJK UNIFIED IDEOGRAPH-#2298B, IRGKangXi=0409.351, RSKangXi=61.28
2298C CJK UNIFIED IDEOGRAPH-#2298C, IRGKangXi=0411.031, RSKangXi=62.1
2298D CJK UNIFIED IDEOGRAPH-#2298D, IRGKangXi=0411.031, RSKangXi=62.1
2298E CJK UNIFIED IDEOGRAPH-#2298E, IRGKangXi=0411.050, RSKangXi=62.2
2298F CJK UNIFIED IDEOGRAPH-#2298F, IRGKangXi=0411.070, RSKangXi=62.2, Def{to cut, wound, hurt}
22990 CJK UNIFIED IDEOGRAPH-#22990, IRGKangXi=0411.090, RSKangXi=62.2
22991 CJK UNIFIED IDEOGRAPH-#22991, IRGKangXi=0411.091, RSKangXi=62.2
22992 CJK UNIFIED IDEOGRAPH-#22992, IRGKangXi=0411.100, RSKangXi=62.3
22993 CJK UNIFIED IDEOGRAPH-#22993, IRGKangXi=0412.080, RSKangXi=62.3
22994 CJK UNIFIED IDEOGRAPH-#22994, IRGKangXi=0412.081, RSKangXi=62.3
22995 CJK UNIFIED IDEOGRAPH-#22995, IRGKangXi=0412.081, RSKangXi=62.3
22996 CJK UNIFIED IDEOGRAPH-#22996, IRGKangXi=0412.081, RSKangXi=62.3
22997 CJK UNIFIED IDEOGRAPH-#22997, IRGKangXi=0412.081, RSKangXi=62.3
22998 CJK UNIFIED IDEOGRAPH-#22998, IRGKangXi=0412.081, RSKangXi=62.3
22999 CJK UNIFIED IDEOGRAPH-#22999, IRGKangXi=0412.081, RSKangXi=62.3
2299A CJK UNIFIED IDEOGRAPH-#2299A, IRGKangXi=0412.090, RSKangXi=62.4
2299B CJK UNIFIED IDEOGRAPH-#2299B, IRGKangXi=0412.100, RSKangXi=62.4
2299C CJK UNIFIED IDEOGRAPH-#2299C, IRGKangXi=0412.120, RSKangXi=62.4
2299D CJK UNIFIED IDEOGRAPH-#2299D, IRGKangXi=0412.130, RSKangXi=62.4
2299E CJK UNIFIED IDEOGRAPH-#2299E, IRGKangXi=0412.150, RSKangXi=62.4
2299F CJK UNIFIED IDEOGRAPH-#2299F, IRGKangXi=0412.160, RSKangXi=62.4
229A0 CJK UNIFIED IDEOGRAPH-#229A0, IRGKangXi=0412.200, RSKangXi=62.4
229A1 CJK UNIFIED IDEOGRAPH-#229A1, IRGKangXi=0412.210, RSKangXi=62.4
229A2 CJK UNIFIED IDEOGRAPH-#229A2, IRGKangXi=0412.220, RSKangXi=62.4
229A3 CJK UNIFIED IDEOGRAPH-#229A3, IRGKangXi=0412.221, RSKangXi=62.4
229A4 CJK UNIFIED IDEOGRAPH-#229A4, IRGKangXi=0412.221, RSKangXi=62.4
229A5 CJK UNIFIED IDEOGRAPH-#229A5, IRGKangXi=0412.221, RSKangXi=62.4
229A6 CJK UNIFIED IDEOGRAPH-#229A6, IRGKangXi=0412.230, RSKangXi=62.5
229A7 CJK UNIFIED IDEOGRAPH-#229A7, IRGKangXi=0412.240, RSKangXi=62.5
229A8 CJK UNIFIED IDEOGRAPH-#229A8, IRGKangXi=0412.250, RSKangXi=62.5
229A9 CJK UNIFIED IDEOGRAPH-#229A9, IRGKangXi=0412.260, RSKangXi=62.5
229AA CJK UNIFIED IDEOGRAPH-#229AA, IRGKangXi=0412.270, RSKangXi=62.5
229AB CJK UNIFIED IDEOGRAPH-#229AB, IRGKangXi=0412.280, RSKangXi=62.5
229AC CJK UNIFIED IDEOGRAPH-#229AC, IRGKangXi=0412.290, RSKangXi=62.5
229AD CJK UNIFIED IDEOGRAPH-#229AD, IRGKangXi=0412.291, RSKangXi=62.5
229AE CJK UNIFIED IDEOGRAPH-#229AE, IRGKangXi=0412.291, RSKangXi=62.5
229AF CJK UNIFIED IDEOGRAPH-#229AF, IRGKangXi=0412.291, RSKangXi=62.5
229B0 CJK UNIFIED IDEOGRAPH-#229B0, IRGKangXi=0412.291, RSKangXi=62.5
229B1 CJK UNIFIED IDEOGRAPH-#229B1, IRGKangXi=0412.291, RSKangXi=62.5
229B2 CJK UNIFIED IDEOGRAPH-#229B2, IRGKangXi=0412.291, RSKangXi=62.5
229B3 CJK UNIFIED IDEOGRAPH-#229B3, IRGKangXi=0412.291, RSKangXi=62.5
229B4 CJK UNIFIED IDEOGRAPH-#229B4, IRGKangXi=0412.291, RSKangXi=62.5
229B5 CJK UNIFIED IDEOGRAPH-#229B5, IRGKangXi=0412.291, RSKangXi=62.5
229B6 CJK UNIFIED IDEOGRAPH-#229B6, IRGKangXi=0412.291, RSKangXi=62.5
229B7 CJK UNIFIED IDEOGRAPH-#229B7, IRGKangXi=0412.330, RSKangXi=62.6
229B8 CJK UNIFIED IDEOGRAPH-#229B8, IRGKangXi=0412.340, RSKangXi=62.6
229B9 CJK UNIFIED IDEOGRAPH-#229B9, IRGKangXi=0412.360, RSKangXi=62.6
229BA CJK UNIFIED IDEOGRAPH-#229BA, IRGKangXi=0412.370, RSKangXi=62.6
229BB CJK UNIFIED IDEOGRAPH-#229BB, IRGKangXi=0412.371, RSKangXi=62.6
229BC CJK UNIFIED IDEOGRAPH-#229BC, IRGKangXi=0412.371, RSKangXi=62.6
229BD CJK UNIFIED IDEOGRAPH-#229BD, IRGKangXi=0412.371, RSKangXi=62.6
229BE CJK UNIFIED IDEOGRAPH-#229BE, IRGKangXi=0412.371, RSKangXi=62.6
229BF CJK UNIFIED IDEOGRAPH-#229BF, IRGKangXi=0413.010, RSKangXi=62.7
229C0 CJK UNIFIED IDEOGRAPH-#229C0, IRGKangXi=0413.030, RSKangXi=62.7
229C1 CJK UNIFIED IDEOGRAPH-#229C1, IRGKangXi=0413.060, RSKangXi=62.7
229C2 CJK UNIFIED IDEOGRAPH-#229C2, IRGKangXi=0413.061, RSKangXi=62.7
229C3 CJK UNIFIED IDEOGRAPH-#229C3, IRGKangXi=0413.061, RSKangXi=62.7
229C4 CJK UNIFIED IDEOGRAPH-#229C4, IRGKangXi=0413.061, RSKangXi=62.7
229C5 CJK UNIFIED IDEOGRAPH-#229C5, IRGKangXi=0413.061, RSKangXi=62.7
229C6 CJK UNIFIED IDEOGRAPH-#229C6, IRGKangXi=0413.061, RSKangXi=62.7
229C7 CJK UNIFIED IDEOGRAPH-#229C7, IRGKangXi=0413.061, RSKangXi=62.7
229C8 CJK UNIFIED IDEOGRAPH-#229C8, IRGKangXi=0413.070, RSKangXi=62.8
229C9 CJK UNIFIED IDEOGRAPH-#229C9, IRGKangXi=0413.110, RSKangXi=62.8
229CA CJK UNIFIED IDEOGRAPH-#229CA, IRGKangXi=0413.120, RSKangXi=62.8
229CB CJK UNIFIED IDEOGRAPH-#229CB, IRGKangXi=0413.130, RSKangXi=62.8
229CC CJK UNIFIED IDEOGRAPH-#229CC, IRGKangXi=0413.140, RSKangXi=62.8
229CD CJK UNIFIED IDEOGRAPH-#229CD, IRGKangXi=0413.141, RSKangXi=62.8
229CE CJK UNIFIED IDEOGRAPH-#229CE, IRGKangXi=0413.141, RSKangXi=62.8
229CF CJK UNIFIED IDEOGRAPH-#229CF, IRGKangXi=0413.141, RSKangXi=62.8
229D0 CJK UNIFIED IDEOGRAPH-#229D0, IRGKangXi=0413.141, RSKangXi=62.8
229D1 CJK UNIFIED IDEOGRAPH-#229D1, IRGKangXi=0413.141, RSKangXi=62.8
229D2 CJK UNIFIED IDEOGRAPH-#229D2, IRGKangXi=0413.141, RSKangXi=62.8
229D3 CJK UNIFIED IDEOGRAPH-#229D3, IRGKangXi=0413.141, RSKangXi=62.8
229D4 CJK UNIFIED IDEOGRAPH-#229D4, IRGKangXi=0413.150, RSKangXi=62.9
229D5 CJK UNIFIED IDEOGRAPH-#229D5, IRGKangXi=0413.200, RSKangXi=62.9
229D6 CJK UNIFIED IDEOGRAPH-#229D6, IRGKangXi=0413.210, RSKangXi=62.9
229D7 CJK UNIFIED IDEOGRAPH-#229D7, IRGKangXi=0413.220, RSKangXi=62.9
229D8 CJK UNIFIED IDEOGRAPH-#229D8, IRGKangXi=0413.240, RSKangXi=62.9
229D9 CJK UNIFIED IDEOGRAPH-#229D9, IRGKangXi=0413.241, RSKangXi=62.9
229DA CJK UNIFIED IDEOGRAPH-#229DA, IRGKangXi=0413.241, RSKangXi=62.9
229DB CJK UNIFIED IDEOGRAPH-#229DB, IRGKangXi=0413.241, RSKangXi=62.9
229DC CJK UNIFIED IDEOGRAPH-#229DC, IRGKangXi=0413.241, RSKangXi=62.9
229DD CJK UNIFIED IDEOGRAPH-#229DD, IRGKangXi=0413.241, RSKangXi=62.9
229DE CJK UNIFIED IDEOGRAPH-#229DE, IRGKangXi=0413.241, RSKangXi=62.9
229DF CJK UNIFIED IDEOGRAPH-#229DF, IRGKangXi=0413.241, RSKangXi=62.9
229E0 CJK UNIFIED IDEOGRAPH-#229E0, IRGKangXi=0413.241, RSKangXi=62.9
229E1 CJK UNIFIED IDEOGRAPH-#229E1, IRGKangXi=0413.241, RSKangXi=62.9
229E2 CJK UNIFIED IDEOGRAPH-#229E2, IRGKangXi=0413.260, RSKangXi=62.10
229E3 CJK UNIFIED IDEOGRAPH-#229E3, IRGKangXi=0413.270, RSKangXi=62.10
229E4 CJK UNIFIED IDEOGRAPH-#229E4, IRGKangXi=0413.310, RSKangXi=62.10
229E5 CJK UNIFIED IDEOGRAPH-#229E5, IRGKangXi=0413.340, RSKangXi=62.10
229E6 CJK UNIFIED IDEOGRAPH-#229E6, IRGKangXi=0413.350, RSKangXi=62.10
229E7 CJK UNIFIED IDEOGRAPH-#229E7, IRGKangXi=0413.360, RSKangXi=62.10
229E8 CJK UNIFIED IDEOGRAPH-#229E8, IRGKangXi=0413.370, RSKangXi=62.11
229E9 CJK UNIFIED IDEOGRAPH-#229E9, IRGKangXi=0413.371, RSKangXi=62.10
229EA CJK UNIFIED IDEOGRAPH-#229EA, IRGKangXi=0413.371, RSKangXi=62.10
229EB CJK UNIFIED IDEOGRAPH-#229EB, IRGKangXi=0413.371, RSKangXi=62.10
229EC CJK UNIFIED IDEOGRAPH-#229EC, IRGKangXi=0413.371, RSKangXi=62.10
229ED CJK UNIFIED IDEOGRAPH-#229ED, IRGKangXi=0413.371, RSKangXi=62.10
229EE CJK UNIFIED IDEOGRAPH-#229EE, IRGKangXi=0413.371, RSKangXi=62.10
229EF CJK UNIFIED IDEOGRAPH-#229EF, IRGKangXi=0413.371, RSKangXi=62.10
229F0 CJK UNIFIED IDEOGRAPH-#229F0, IRGKangXi=0413.371, RSKangXi=62.10
229F1 CJK UNIFIED IDEOGRAPH-#229F1, IRGKangXi=0413.371, RSKangXi=62.10
229F2 CJK UNIFIED IDEOGRAPH-#229F2, IRGKangXi=0413.371, RSKangXi=62.11
229F3 CJK UNIFIED IDEOGRAPH-#229F3, IRGKangXi=0413.390, RSKangXi=62.11
229F4 CJK UNIFIED IDEOGRAPH-#229F4, IRGKangXi=0413.400, RSKangXi=62.11
229F5 CJK UNIFIED IDEOGRAPH-#229F5, IRGKangXi=0414.020, RSKangXi=62.11
229F6 CJK UNIFIED IDEOGRAPH-#229F6, IRGKangXi=0414.030, RSKangXi=62.11
229F7 CJK UNIFIED IDEOGRAPH-#229F7, IRGKangXi=0414.070, RSKangXi=62.11
229F8 CJK UNIFIED IDEOGRAPH-#229F8, IRGKangXi=0414.080, RSKangXi=62.11
229F9 CJK UNIFIED IDEOGRAPH-#229F9, IRGKangXi=0414.090, RSKangXi=62.11
229FA CJK UNIFIED IDEOGRAPH-#229FA, IRGKangXi=0414.091, RSKangXi=62.11
229FB CJK UNIFIED IDEOGRAPH-#229FB, IRGKangXi=0414.091, RSKangXi=62.11
229FC CJK UNIFIED IDEOGRAPH-#229FC, IRGKangXi=0414.091, RSKangXi=62.11
229FD CJK UNIFIED IDEOGRAPH-#229FD, IRGKangXi=0414.091, RSKangXi=62.11
229FE CJK UNIFIED IDEOGRAPH-#229FE, IRGKangXi=0414.091, RSKangXi=62.11
229FF CJK UNIFIED IDEOGRAPH-#229FF, IRGKangXi=0414.091, RSKangXi=62.11
22A00 CJK UNIFIED IDEOGRAPH-#22A00, IRGKangXi=0414.091, RSKangXi=62.11
22A01 CJK UNIFIED IDEOGRAPH-#22A01, IRGKangXi=0414.091, RSKangXi=62.11
22A02 CJK UNIFIED IDEOGRAPH-#22A02, IRGKangXi=0414.091, RSKangXi=62.11
22A03 CJK UNIFIED IDEOGRAPH-#22A03, IRGKangXi=0414.091, RSKangXi=62.11
22A04 CJK UNIFIED IDEOGRAPH-#22A04, IRGKangXi=0414.091, RSKangXi=62.11
22A05 CJK UNIFIED IDEOGRAPH-#22A05, IRGKangXi=0414.091, RSKangXi=62.11
22A06 CJK UNIFIED IDEOGRAPH-#22A06, IRGKangXi=0414.091, RSKangXi=62.11
22A07 CJK UNIFIED IDEOGRAPH-#22A07, IRGKangXi=0414.100, RSKangXi=62.12
22A08 CJK UNIFIED IDEOGRAPH-#22A08, IRGKangXi=0414.140, RSKangXi=62.12
22A09 CJK UNIFIED IDEOGRAPH-#22A09, IRGKangXi=0414.150, RSKangXi=62.12
22A0A CJK UNIFIED IDEOGRAPH-#22A0A, IRGKangXi=0414.160, RSKangXi=62.12
22A0B CJK UNIFIED IDEOGRAPH-#22A0B, IRGKangXi=0414.170, RSKangXi=62.12
22A0C CJK UNIFIED IDEOGRAPH-#22A0C, IRGKangXi=0414.180, RSKangXi=62.12
22A0D CJK UNIFIED IDEOGRAPH-#22A0D, IRGKangXi=0414.190, RSKangXi=62.12
22A0E CJK UNIFIED IDEOGRAPH-#22A0E, IRGKangXi=0414.191, RSKangXi=62.12
22A0F CJK UNIFIED IDEOGRAPH-#22A0F, IRGKangXi=0414.191, RSKangXi=62.12
22A10 CJK UNIFIED IDEOGRAPH-#22A10, IRGKangXi=0414.191, RSKangXi=30.13
22A11 CJK UNIFIED IDEOGRAPH-#22A11, IRGKangXi=0414.191, RSKangXi=62.12
22A12 CJK UNIFIED IDEOGRAPH-#22A12, IRGKangXi=0414.191, RSKangXi=62.12
22A13 CJK UNIFIED IDEOGRAPH-#22A13, IRGKangXi=0414.200, RSKangXi=62.13
22A14 CJK UNIFIED IDEOGRAPH-#22A14, IRGKangXi=0414.220, RSKangXi=62.13
22A15 CJK UNIFIED IDEOGRAPH-#22A15, IRGKangXi=0414.231, RSKangXi=62.13
22A16 CJK UNIFIED IDEOGRAPH-#22A16, IRGKangXi=0414.231, RSKangXi=62.13
22A17 CJK UNIFIED IDEOGRAPH-#22A17, IRGKangXi=0414.231, RSKangXi=62.13
22A18 CJK UNIFIED IDEOGRAPH-#22A18, IRGKangXi=0414.261, RSKangXi=62.14
22A19 CJK UNIFIED IDEOGRAPH-#22A19, IRGKangXi=0414.261, RSKangXi=62.14
22A1A CJK UNIFIED IDEOGRAPH-#22A1A, IRGKangXi=0414.261, RSKangXi=62.15
22A1B CJK UNIFIED IDEOGRAPH-#22A1B, IRGKangXi=0414.270, RSKangXi=62.15
22A1C CJK UNIFIED IDEOGRAPH-#22A1C, IRGKangXi=0414.271, RSKangXi=62.15
22A1D CJK UNIFIED IDEOGRAPH-#22A1D, IRGKangXi=0414.271, RSKangXi=62.15
22A1E CJK UNIFIED IDEOGRAPH-#22A1E, IRGKangXi=0414.280, RSKangXi=62.16
22A1F CJK UNIFIED IDEOGRAPH-#22A1F, IRGKangXi=0414.290, RSKangXi=62.16
22A20 CJK UNIFIED IDEOGRAPH-#22A20, IRGKangXi=0414.291, RSKangXi=62.16
22A21 CJK UNIFIED IDEOGRAPH-#22A21, IRGKangXi=0414.300, RSKangXi=62.17
22A22 CJK UNIFIED IDEOGRAPH-#22A22, IRGKangXi=0414.301, RSKangXi=62.17
22A23 CJK UNIFIED IDEOGRAPH-#22A23, IRGKangXi=0414.301, RSKangXi=62.17
22A24 CJK UNIFIED IDEOGRAPH-#22A24, IRGKangXi=0415.011, RSKangXi=63.1
22A25 CJK UNIFIED IDEOGRAPH-#22A25, IRGKangXi=0415.011, RSKangXi=63.1
22A26 CJK UNIFIED IDEOGRAPH-#22A26, IRGKangXi=0415.020, RSKangXi=63.2
22A27 CJK UNIFIED IDEOGRAPH-#22A27, IRGKangXi=0415.021, RSKangXi=63.2
22A28 CJK UNIFIED IDEOGRAPH-#22A28, IRGKangXi=0415.021, RSKangXi=63.2
22A29 CJK UNIFIED IDEOGRAPH-#22A29, IRGKangXi=0415.021, RSKangXi=63.2
22A2A CJK UNIFIED IDEOGRAPH-#22A2A, IRGKangXi=0415.040, RSKangXi=63.3
22A2B CJK UNIFIED IDEOGRAPH-#22A2B, IRGKangXi=0415.060, RSKangXi=63.3
22A2C CJK UNIFIED IDEOGRAPH-#22A2C, IRGKangXi=0415.081, RSKangXi=63.3
22A2D CJK UNIFIED IDEOGRAPH-#22A2D, IRGKangXi=0415.081, RSKangXi=63.3
22A2E CJK UNIFIED IDEOGRAPH-#22A2E, IRGKangXi=0415.081, RSKangXi=63.3
22A2F CJK UNIFIED IDEOGRAPH-#22A2F, IRGKangXi=0415.180, RSKangXi=63.4
22A30 CJK UNIFIED IDEOGRAPH-#22A30, IRGKangXi=0415.181, RSKangXi=63.4
22A31 CJK UNIFIED IDEOGRAPH-#22A31, IRGKangXi=0415.181, RSKangXi=63.4
22A32 CJK UNIFIED IDEOGRAPH-#22A32, IRGKangXi=0415.181, RSKangXi=63.4
22A33 CJK UNIFIED IDEOGRAPH-#22A33, IRGKangXi=0415.181, RSKangXi=63.4
22A34 CJK UNIFIED IDEOGRAPH-#22A34, IRGKangXi=0415.181, RSKangXi=63.4
22A35 CJK UNIFIED IDEOGRAPH-#22A35, IRGKangXi=0415.181, RSKangXi=63.4
22A36 CJK UNIFIED IDEOGRAPH-#22A36, IRGKangXi=0415.200, RSKangXi=63.5
22A37 CJK UNIFIED IDEOGRAPH-#22A37, IRGKangXi=0415.210, RSKangXi=63.5
22A38 CJK UNIFIED IDEOGRAPH-#22A38, IRGKangXi=0416.010, RSKangXi=63.5
22A39 CJK UNIFIED IDEOGRAPH-#22A39, IRGKangXi=0416.030, RSKangXi=63.5
22A3A CJK UNIFIED IDEOGRAPH-#22A3A, IRGKangXi=0416.070, RSKangXi=63.5
22A3B CJK UNIFIED IDEOGRAPH-#22A3B, IRGKangXi=0416.071, RSKangXi=63.5
22A3C CJK UNIFIED IDEOGRAPH-#22A3C, IRGKangXi=0416.071, RSKangXi=63.5
22A3D CJK UNIFIED IDEOGRAPH-#22A3D, IRGKangXi=0416.071, RSKangXi=63.5
22A3E CJK UNIFIED IDEOGRAPH-#22A3E, IRGKangXi=0416.071, RSKangXi=63.5
22A3F CJK UNIFIED IDEOGRAPH-#22A3F, IRGKangXi=0416.071, RSKangXi=63.5
22A40 CJK UNIFIED IDEOGRAPH-#22A40, IRGKangXi=0416.071, RSKangXi=63.5
22A41 CJK UNIFIED IDEOGRAPH-#22A41, IRGKangXi=0416.071, RSKangXi=63.5
22A42 CJK UNIFIED IDEOGRAPH-#22A42, IRGKangXi=0416.071, RSKangXi=63.5
22A43 CJK UNIFIED IDEOGRAPH-#22A43, IRGKangXi=0416.071, RSKangXi=63.5
22A44 CJK UNIFIED IDEOGRAPH-#22A44, IRGKangXi=0416.071, RSKangXi=63.5
22A45 CJK UNIFIED IDEOGRAPH-#22A45, IRGKangXi=0416.090, RSKangXi=63.6
22A46 CJK UNIFIED IDEOGRAPH-#22A46, IRGKangXi=0416.100, RSKangXi=63.6
22A47 CJK UNIFIED IDEOGRAPH-#22A47, IRGKangXi=0416.110, RSKangXi=63.6
22A48 CJK UNIFIED IDEOGRAPH-#22A48, IRGKangXi=0416.150, RSKangXi=63.6
22A49 CJK UNIFIED IDEOGRAPH-#22A49, IRGKangXi=0416.151, RSKangXi=63.6
22A4A CJK UNIFIED IDEOGRAPH-#22A4A, IRGKangXi=0416.151, RSKangXi=63.6
22A4B CJK UNIFIED IDEOGRAPH-#22A4B, IRGKangXi=0416.151, RSKangXi=63.6
22A4C CJK UNIFIED IDEOGRAPH-#22A4C, IRGKangXi=0416.151, RSKangXi=63.6
22A4D CJK UNIFIED IDEOGRAPH-#22A4D, IRGKangXi=0416.180, RSKangXi=63.7
22A4E CJK UNIFIED IDEOGRAPH-#22A4E, IRGKangXi=0416.181, RSKangXi=63.7
22A4F CJK UNIFIED IDEOGRAPH-#22A4F, IRGKangXi=0416.181, RSKangXi=63.7
22A50 CJK UNIFIED IDEOGRAPH-#22A50, IRGKangXi=0416.181, RSKangXi=63.7
22A51 CJK UNIFIED IDEOGRAPH-#22A51, IRGKangXi=0416.210, RSKangXi=63.8
22A52 CJK UNIFIED IDEOGRAPH-#22A52, IRGKangXi=0416.220, RSKangXi=63.8
22A53 CJK UNIFIED IDEOGRAPH-#22A53, IRGKangXi=0416.221, RSKangXi=63.8
22A54 CJK UNIFIED IDEOGRAPH-#22A54, IRGKangXi=0416.221, RSKangXi=63.8
22A55 CJK UNIFIED IDEOGRAPH-#22A55, IRGKangXi=0416.221, RSKangXi=63.8
22A56 CJK UNIFIED IDEOGRAPH-#22A56, IRGKangXi=0416.230, RSKangXi=63.9
22A57 CJK UNIFIED IDEOGRAPH-#22A57, IRGKangXi=0416.231, RSKangXi=63.9
22A58 CJK UNIFIED IDEOGRAPH-#22A58, IRGKangXi=0416.240, RSKangXi=63.10
22A59 CJK UNIFIED IDEOGRAPH-#22A59, IRGKangXi=0416.250, RSKangXi=63.10
22A5A CJK UNIFIED IDEOGRAPH-#22A5A, IRGKangXi=0416.251, RSKangXi=63.10
22A5B CJK UNIFIED IDEOGRAPH-#22A5B, IRGKangXi=0416.251, RSKangXi=63.10
22A5C CJK UNIFIED IDEOGRAPH-#22A5C, IRGKangXi=0416.251, RSKangXi=63.11
22A5D CJK UNIFIED IDEOGRAPH-#22A5D, IRGKangXi=0416.251, RSKangXi=63.11
22A5E CJK UNIFIED IDEOGRAPH-#22A5E, IRGKangXi=0416.251, RSKangXi=63.11
22A5F CJK UNIFIED IDEOGRAPH-#22A5F, IRGKangXi=0416.251, RSKangXi=63.12
22A60 CJK UNIFIED IDEOGRAPH-#22A60, IRGKangXi=0416.260, RSKangXi=63.13
22A61 CJK UNIFIED IDEOGRAPH-#22A61, IRGKangXi=0416.261, RSKangXi=63.14
22A62 CJK UNIFIED IDEOGRAPH-#22A62, IRGKangXi=0416.270, RSKangXi=63.17
22A63 CJK UNIFIED IDEOGRAPH-#22A63, IRGKangXi=0416.271, RSKangXi=63.19
22A64 CJK UNIFIED IDEOGRAPH-#22A64, IRGKangXi=0416.271, RSKangXi=63.19
22A65 CJK UNIFIED IDEOGRAPH-#22A65, IRGKangXi=0417.020, RSKangXi=64.1
22A66 CJK UNIFIED IDEOGRAPH-#22A66, IRGKangXi=0417.030, RSKangXi=64.1, Def{(Cant.) to squeeze out (as from a tube); to tickle}
22A67 CJK UNIFIED IDEOGRAPH-#22A67, IRGKangXi=0417.031, RSKangXi=64.1
22A68 CJK UNIFIED IDEOGRAPH-#22A68, IRGKangXi=0417.050, RSKangXi=64.2
22A69 CJK UNIFIED IDEOGRAPH-#22A69, IRGKangXi=0417.131, RSKangXi=64.2
22A6A CJK UNIFIED IDEOGRAPH-#22A6A, IRGKangXi=0417.131, RSKangXi=64.2
22A6B CJK UNIFIED IDEOGRAPH-#22A6B, IRGKangXi=0417.131, RSKangXi=64.2
22A6C CJK UNIFIED IDEOGRAPH-#22A6C, IRGKangXi=0417.131, RSKangXi=64.2
22A6D CJK UNIFIED IDEOGRAPH-#22A6D, IRGKangXi=0417.140, RSKangXi=64.3
22A6E CJK UNIFIED IDEOGRAPH-#22A6E, IRGKangXi=0417.160, RSKangXi=64.3
22A6F CJK UNIFIED IDEOGRAPH-#22A6F, IRGKangXi=0417.210, RSKangXi=64.3
22A70 CJK UNIFIED IDEOGRAPH-#22A70, IRGKangXi=0418.100, RSKangXi=64.3
22A71 CJK UNIFIED IDEOGRAPH-#22A71, IRGKangXi=0418.110, RSKangXi=64.3
22A72 CJK UNIFIED IDEOGRAPH-#22A72, IRGKangXi=0418.130, RSKangXi=64.3
22A73 CJK UNIFIED IDEOGRAPH-#22A73, IRGKangXi=0418.141, RSKangXi=64.3
22A74 CJK UNIFIED IDEOGRAPH-#22A74, IRGKangXi=0418.141, RSKangXi=64.3
22A75 CJK UNIFIED IDEOGRAPH-#22A75, IRGKangXi=0418.141, RSKangXi=64.3
22A76 CJK UNIFIED IDEOGRAPH-#22A76, IRGKangXi=0418.141, RSKangXi=64.3
22A77 CJK UNIFIED IDEOGRAPH-#22A77, IRGKangXi=0418.141, RSKangXi=64.3
22A78 CJK UNIFIED IDEOGRAPH-#22A78, IRGKangXi=0418.141, RSKangXi=64.3
22A79 CJK UNIFIED IDEOGRAPH-#22A79, IRGKangXi=0418.141, RSKangXi=64.3
22A7A CJK UNIFIED IDEOGRAPH-#22A7A, IRGKangXi=0418.141, RSKangXi=64.3
22A7B CJK UNIFIED IDEOGRAPH-#22A7B, IRGKangXi=0418.141, RSKangXi=64.3
22A7C CJK UNIFIED IDEOGRAPH-#22A7C, IRGKangXi=0418.141, RSKangXi=64.3
22A7D CJK UNIFIED IDEOGRAPH-#22A7D, IRGKangXi=0418.141, RSKangXi=64.3
22A7E CJK UNIFIED IDEOGRAPH-#22A7E, IRGKangXi=0418.141, RSKangXi=64.3
22A7F CJK UNIFIED IDEOGRAPH-#22A7F, IRGKangXi=0418.141, RSKangXi=64.3
22A80 CJK UNIFIED IDEOGRAPH-#22A80, IRGKangXi=0418.141, RSKangXi=64.3
22A81 CJK UNIFIED IDEOGRAPH-#22A81, IRGKangXi=0418.141, RSKangXi=64.3
22A82 CJK UNIFIED IDEOGRAPH-#22A82, IRGKangXi=0418.141, RSKangXi=64.3
22A83 CJK UNIFIED IDEOGRAPH-#22A83, IRGKangXi=0418.150, RSKangXi=64.4
22A84 CJK UNIFIED IDEOGRAPH-#22A84, IRGKangXi=0418.170, RSKangXi=64.4
22A85 CJK UNIFIED IDEOGRAPH-#22A85, IRGKangXi=0418.190, RSKangXi=64.4
22A86 CJK UNIFIED IDEOGRAPH-#22A86, IRGKangXi=0418.210, RSKangXi=64.4
22A87 CJK UNIFIED IDEOGRAPH-#22A87, IRGKangXi=0419.110, RSKangXi=64.4
22A88 CJK UNIFIED IDEOGRAPH-#22A88, IRGKangXi=0419.160, RSKangXi=64.4
22A89 CJK UNIFIED IDEOGRAPH-#22A89, IRGKangXi=0420.010, RSKangXi=64.4
22A8A CJK UNIFIED IDEOGRAPH-#22A8A, IRGKangXi=0420.030, RSKangXi=64.4
22A8B CJK UNIFIED IDEOGRAPH-#22A8B, IRGKangXi=0420.040, RSKangXi=64.4
22A8C CJK UNIFIED IDEOGRAPH-#22A8C, IRGKangXi=0420.090, RSKangXi=64.4
22A8D CJK UNIFIED IDEOGRAPH-#22A8D, IRGKangXi=0420.110, RSKangXi=64.4
22A8E CJK UNIFIED IDEOGRAPH-#22A8E, IRGKangXi=0420.140, RSKangXi=64.4
22A8F CJK UNIFIED IDEOGRAPH-#22A8F, IRGKangXi=0420.170, RSKangXi=64.4
22A90 CJK UNIFIED IDEOGRAPH-#22A90, IRGKangXi=0420.190, RSKangXi=64.4
22A91 CJK UNIFIED IDEOGRAPH-#22A91, IRGKangXi=0421.050, RSKangXi=64.4
22A92 CJK UNIFIED IDEOGRAPH-#22A92, IRGKangXi=0422.050, RSKangXi=64.4
22A93 CJK UNIFIED IDEOGRAPH-#22A93, IRGKangXi=0422.060, RSKangXi=64.4
22A94 CJK UNIFIED IDEOGRAPH-#22A94, IRGKangXi=0422.080, RSKangXi=64.4
22A95 CJK UNIFIED IDEOGRAPH-#22A95, IRGKangXi=0422.090, RSKangXi=64.4
22A96 CJK UNIFIED IDEOGRAPH-#22A96, IRGKangXi=0422.100, RSKangXi=64.4
22A97 CJK UNIFIED IDEOGRAPH-#22A97, IRGKangXi=0422.110, RSKangXi=64.4
22A98 CJK UNIFIED IDEOGRAPH-#22A98, IRGKangXi=0422.121, RSKangXi=64.4
22A99 CJK UNIFIED IDEOGRAPH-#22A99, IRGKangXi=0422.121, RSKangXi=64.4
22A9A CJK UNIFIED IDEOGRAPH-#22A9A, IRGKangXi=0422.121, RSKangXi=64.4
22A9B CJK UNIFIED IDEOGRAPH-#22A9B, IRGKangXi=0422.121, RSKangXi=64.4
22A9C CJK UNIFIED IDEOGRAPH-#22A9C, IRGKangXi=0422.121, RSKangXi=64.4
22A9D CJK UNIFIED IDEOGRAPH-#22A9D, IRGKangXi=0422.121, RSKangXi=64.4
22A9E CJK UNIFIED IDEOGRAPH-#22A9E, IRGKangXi=0422.121, RSKangXi=64.4
22A9F CJK UNIFIED IDEOGRAPH-#22A9F, IRGKangXi=0422.121, RSKangXi=64.4
22AA0 CJK UNIFIED IDEOGRAPH-#22AA0, IRGKangXi=0422.121, RSKangXi=64.4
22AA1 CJK UNIFIED IDEOGRAPH-#22AA1, IRGKangXi=0422.121, RSKangXi=64.4
22AA2 CJK UNIFIED IDEOGRAPH-#22AA2, IRGKangXi=0422.121, RSKangXi=64.4
22AA3 CJK UNIFIED IDEOGRAPH-#22AA3, IRGKangXi=0422.121, RSKangXi=64.4
22AA4 CJK UNIFIED IDEOGRAPH-#22AA4, IRGKangXi=0422.121, RSKangXi=64.4
22AA5 CJK UNIFIED IDEOGRAPH-#22AA5, IRGKangXi=0422.121, RSKangXi=64.4
22AA6 CJK UNIFIED IDEOGRAPH-#22AA6, IRGKangXi=0422.121, RSKangXi=64.4
22AA7 CJK UNIFIED IDEOGRAPH-#22AA7, IRGKangXi=0422.121, RSKangXi=64.4
22AA8 CJK UNIFIED IDEOGRAPH-#22AA8, IRGKangXi=0422.121, RSKangXi=64.4
22AA9 CJK UNIFIED IDEOGRAPH-#22AA9, IRGKangXi=0422.121, RSKangXi=64.4
22AAA CJK UNIFIED IDEOGRAPH-#22AAA, IRGKangXi=0422.121, RSKangXi=64.4
22AAB CJK UNIFIED IDEOGRAPH-#22AAB, IRGKangXi=0422.121, RSKangXi=64.4
22AAC CJK UNIFIED IDEOGRAPH-#22AAC, IRGKangXi=0422.121, RSKangXi=64.4
22AAD CJK UNIFIED IDEOGRAPH-#22AAD, IRGKangXi=0422.121, RSKangXi=64.4
22AAE CJK UNIFIED IDEOGRAPH-#22AAE, IRGKangXi=0422.121, RSKangXi=64.4
22AAF CJK UNIFIED IDEOGRAPH-#22AAF, IRGKangXi=0422.121, RSKangXi=64.4
22AB0 CJK UNIFIED IDEOGRAPH-#22AB0, IRGKangXi=0422.121, RSKangXi=64.4
22AB1 CJK UNIFIED IDEOGRAPH-#22AB1, IRGKangXi=0422.121, RSKangXi=64.4
22AB2 CJK UNIFIED IDEOGRAPH-#22AB2, IRGKangXi=0422.121, RSKangXi=64.4
22AB3 CJK UNIFIED IDEOGRAPH-#22AB3, IRGKangXi=0422.121, RSKangXi=64.4
22AB4 CJK UNIFIED IDEOGRAPH-#22AB4, IRGKangXi=0422.170, RSKangXi=64.5
22AB5 CJK UNIFIED IDEOGRAPH-#22AB5, IRGKangXi=0422.180, RSKangXi=64.5
22AB6 CJK UNIFIED IDEOGRAPH-#22AB6, IRGKangXi=0424.030, RSKangXi=64.5
22AB7 CJK UNIFIED IDEOGRAPH-#22AB7, IRGKangXi=0424.170, RSKangXi=64.5
22AB8 CJK UNIFIED IDEOGRAPH-#22AB8, IRGKangXi=0427.080, RSKangXi=64.5
22AB9 CJK UNIFIED IDEOGRAPH-#22AB9, IRGKangXi=0427.090, RSKangXi=64.5
22ABA CJK UNIFIED IDEOGRAPH-#22ABA, IRGKangXi=0427.100, RSKangXi=64.5
22ABB CJK UNIFIED IDEOGRAPH-#22ABB, IRGKangXi=0427.110, RSKangXi=64.5
22ABC CJK UNIFIED IDEOGRAPH-#22ABC, IRGKangXi=0427.120, RSKangXi=64.5
22ABD CJK UNIFIED IDEOGRAPH-#22ABD, IRGKangXi=0427.130, RSKangXi=64.5
22ABE CJK UNIFIED IDEOGRAPH-#22ABE, IRGKangXi=0427.140, RSKangXi=64.5
22ABF CJK UNIFIED IDEOGRAPH-#22ABF, IRGKangXi=0427.150, RSKangXi=64.5
22AC0 CJK UNIFIED IDEOGRAPH-#22AC0, IRGKangXi=0427.160, RSKangXi=64.5
22AC1 CJK UNIFIED IDEOGRAPH-#22AC1, IRGKangXi=0427.161, RSKangXi=64.5
22AC2 CJK UNIFIED IDEOGRAPH-#22AC2, IRGKangXi=0427.161, RSKangXi=64.5
22AC3 CJK UNIFIED IDEOGRAPH-#22AC3, IRGKangXi=0427.161, RSKangXi=64.5
22AC4 CJK UNIFIED IDEOGRAPH-#22AC4, IRGKangXi=0427.161, RSKangXi=64.5
22AC5 CJK UNIFIED IDEOGRAPH-#22AC5, IRGKangXi=0427.161, RSKangXi=64.5
22AC6 CJK UNIFIED IDEOGRAPH-#22AC6, IRGKangXi=0427.161, RSKangXi=64.5
22AC7 CJK UNIFIED IDEOGRAPH-#22AC7, IRGKangXi=0427.161, RSKangXi=64.5
22AC8 CJK UNIFIED IDEOGRAPH-#22AC8, IRGKangXi=0427.161, RSKangXi=64.5
22AC9 CJK UNIFIED IDEOGRAPH-#22AC9, IRGKangXi=0427.161, RSKangXi=64.5
22ACA CJK UNIFIED IDEOGRAPH-#22ACA, IRGKangXi=0427.161, RSKangXi=64.5
22ACB CJK UNIFIED IDEOGRAPH-#22ACB, IRGKangXi=0427.161, RSKangXi=64.5
22ACC CJK UNIFIED IDEOGRAPH-#22ACC, IRGKangXi=0427.161, RSKangXi=64.5
22ACD CJK UNIFIED IDEOGRAPH-#22ACD, IRGKangXi=0427.161, RSKangXi=64.5
22ACE CJK UNIFIED IDEOGRAPH-#22ACE, IRGKangXi=0427.161, RSKangXi=64.5
22ACF CJK UNIFIED IDEOGRAPH-#22ACF, IRGKangXi=0427.161, RSKangXi=64.5, Def{(Cant.) to cover}
22AD0 CJK UNIFIED IDEOGRAPH-#22AD0, IRGKangXi=0427.161, RSKangXi=64.5
22AD1 CJK UNIFIED IDEOGRAPH-#22AD1, IRGKangXi=0427.161, RSKangXi=64.5
22AD2 CJK UNIFIED IDEOGRAPH-#22AD2, IRGKangXi=0427.161, RSKangXi=64.5
22AD3 CJK UNIFIED IDEOGRAPH-#22AD3, IRGKangXi=0427.161, RSKangXi=64.5
22AD4 CJK UNIFIED IDEOGRAPH-#22AD4, IRGKangXi=0427.161, RSKangXi=64.5
22AD5 CJK UNIFIED IDEOGRAPH-#22AD5, IRGKangXi=0427.161, RSKangXi=64.5, Def{(Cant.) to throw away}
22AD6 CJK UNIFIED IDEOGRAPH-#22AD6, IRGKangXi=0427.161, RSKangXi=64.5
22AD7 CJK UNIFIED IDEOGRAPH-#22AD7, IRGKangXi=0427.161, RSKangXi=64.5
22AD8 CJK UNIFIED IDEOGRAPH-#22AD8, IRGKangXi=0427.161, RSKangXi=64.5
22AD9 CJK UNIFIED IDEOGRAPH-#22AD9, IRGKangXi=0427.161, RSKangXi=64.5
22ADA CJK UNIFIED IDEOGRAPH-#22ADA, IRGKangXi=0427.161, RSKangXi=64.5
22ADB CJK UNIFIED IDEOGRAPH-#22ADB, IRGKangXi=0427.161, RSKangXi=64.5
22ADC CJK UNIFIED IDEOGRAPH-#22ADC, IRGKangXi=0427.161, RSKangXi=64.5
22ADD CJK UNIFIED IDEOGRAPH-#22ADD, IRGKangXi=0427.161, RSKangXi=64.5
22ADE CJK UNIFIED IDEOGRAPH-#22ADE, IRGKangXi=0427.161, RSKangXi=64.5
22ADF CJK UNIFIED IDEOGRAPH-#22ADF, IRGKangXi=0427.161, RSKangXi=64.5
22AE0 CJK UNIFIED IDEOGRAPH-#22AE0, IRGKangXi=0427.161, RSKangXi=64.5
22AE1 CJK UNIFIED IDEOGRAPH-#22AE1, IRGKangXi=0427.161, RSKangXi=64.5
22AE2 CJK UNIFIED IDEOGRAPH-#22AE2, IRGKangXi=0427.161, RSKangXi=64.5
22AE3 CJK UNIFIED IDEOGRAPH-#22AE3, IRGKangXi=0427.161, RSKangXi=64.5
22AE4 CJK UNIFIED IDEOGRAPH-#22AE4, IRGKangXi=0428.070, RSKangXi=64.6
22AE5 CJK UNIFIED IDEOGRAPH-#22AE5, IRGKangXi=0428.080, RSKangXi=64.6
22AE6 CJK UNIFIED IDEOGRAPH-#22AE6, IRGKangXi=0428.090, RSKangXi=64.6, Def{variant of 拍, to clap, tap, beat; a beat or rhythm}
22AE7 CJK UNIFIED IDEOGRAPH-#22AE7, IRGKangXi=0428.120, RSKangXi=64.6
22AE8 CJK UNIFIED IDEOGRAPH-#22AE8, IRGKangXi=0428.130, RSKangXi=64.6, Def{(Cant.) to push from behind}
22AE9 CJK UNIFIED IDEOGRAPH-#22AE9, IRGKangXi=0428.150, RSKangXi=64.6
22AEA CJK UNIFIED IDEOGRAPH-#22AEA, IRGKangXi=0429.030, RSKangXi=64.6
22AEB CJK UNIFIED IDEOGRAPH-#22AEB, IRGKangXi=0429.070, RSKangXi=64.6, Def{(Cant.) to rub}
22AEC CJK UNIFIED IDEOGRAPH-#22AEC, IRGKangXi=0429.090, RSKangXi=64.6
22AED CJK UNIFIED IDEOGRAPH-#22AED, IRGKangXi=0429.100, RSKangXi=64.6
22AEE CJK UNIFIED IDEOGRAPH-#22AEE, IRGKangXi=0429.140, RSKangXi=64.6
22AEF CJK UNIFIED IDEOGRAPH-#22AEF, IRGKangXi=0429.180, RSKangXi=64.6
22AF0 CJK UNIFIED IDEOGRAPH-#22AF0, IRGKangXi=0430.010, RSKangXi=64.6
22AF1 CJK UNIFIED IDEOGRAPH-#22AF1, IRGKangXi=0430.020, RSKangXi=64.6
22AF2 CJK UNIFIED IDEOGRAPH-#22AF2, IRGKangXi=0430.050, RSKangXi=64.6
22AF3 CJK UNIFIED IDEOGRAPH-#22AF3, IRGKangXi=0430.060, RSKangXi=64.6
22AF4 CJK UNIFIED IDEOGRAPH-#22AF4, IRGKangXi=0430.100, RSKangXi=64.6
22AF5 CJK UNIFIED IDEOGRAPH-#22AF5, IRGKangXi=0430.150, RSKangXi=64.6
22AF6 CJK UNIFIED IDEOGRAPH-#22AF6, IRGKangXi=0430.190, RSKangXi=64.6
22AF7 CJK UNIFIED IDEOGRAPH-#22AF7, IRGKangXi=0431.010, RSKangXi=64.6
22AF8 CJK UNIFIED IDEOGRAPH-#22AF8, IRGKangXi=0431.040, RSKangXi=64.6
22AF9 CJK UNIFIED IDEOGRAPH-#22AF9, IRGKangXi=0431.050, RSKangXi=64.6
22AFA CJK UNIFIED IDEOGRAPH-#22AFA, IRGKangXi=0431.060, RSKangXi=64.6
22AFB CJK UNIFIED IDEOGRAPH-#22AFB, IRGKangXi=0431.070, RSKangXi=64.6
22AFC CJK UNIFIED IDEOGRAPH-#22AFC, IRGKangXi=0431.100, RSKangXi=64.6
22AFD CJK UNIFIED IDEOGRAPH-#22AFD, IRGKangXi=0431.110, RSKangXi=64.6
22AFE CJK UNIFIED IDEOGRAPH-#22AFE, IRGKangXi=0431.140, RSKangXi=64.6
22AFF CJK UNIFIED IDEOGRAPH-#22AFF, IRGKangXi=0431.150, RSKangXi=64.6
22B00 CJK UNIFIED IDEOGRAPH-#22B00, IRGKangXi=0431.170, RSKangXi=64.6
22B01 CJK UNIFIED IDEOGRAPH-#22B01, IRGKangXi=0431.171, RSKangXi=64.6
22B02 CJK UNIFIED IDEOGRAPH-#22B02, IRGKangXi=0431.171, RSKangXi=64.6
22B03 CJK UNIFIED IDEOGRAPH-#22B03, IRGKangXi=0431.171, RSKangXi=64.6
22B04 CJK UNIFIED IDEOGRAPH-#22B04, IRGKangXi=0431.171, RSKangXi=64.6
22B05 CJK UNIFIED IDEOGRAPH-#22B05, IRGKangXi=0431.171, RSKangXi=64.6
22B06 CJK UNIFIED IDEOGRAPH-#22B06, IRGKangXi=0431.171, RSKangXi=64.6
22B07 CJK UNIFIED IDEOGRAPH-#22B07, IRGKangXi=0431.171, RSKangXi=64.6
22B08 CJK UNIFIED IDEOGRAPH-#22B08, IRGKangXi=0431.171, RSKangXi=64.6
22B09 CJK UNIFIED IDEOGRAPH-#22B09, IRGKangXi=0431.171, RSKangXi=64.6
22B0A CJK UNIFIED IDEOGRAPH-#22B0A, IRGKangXi=0431.171, RSKangXi=64.6
22B0B CJK UNIFIED IDEOGRAPH-#22B0B, IRGKangXi=0431.171, RSKangXi=64.6
22B0C CJK UNIFIED IDEOGRAPH-#22B0C, IRGKangXi=0431.171, RSKangXi=64.6
22B0D CJK UNIFIED IDEOGRAPH-#22B0D, IRGKangXi=0431.171, RSKangXi=64.6
22B0E CJK UNIFIED IDEOGRAPH-#22B0E, IRGKangXi=0431.171, RSKangXi=64.6
22B0F CJK UNIFIED IDEOGRAPH-#22B0F, IRGKangXi=0431.171, RSKangXi=64.6
22B10 CJK UNIFIED IDEOGRAPH-#22B10, IRGKangXi=0431.171, RSKangXi=64.6
22B11 CJK UNIFIED IDEOGRAPH-#22B11, IRGKangXi=0431.171, RSKangXi=64.6
22B12 CJK UNIFIED IDEOGRAPH-#22B12, IRGKangXi=0431.171, RSKangXi=64.6
22B13 CJK UNIFIED IDEOGRAPH-#22B13, IRGKangXi=0431.171, RSKangXi=64.6
22B14 CJK UNIFIED IDEOGRAPH-#22B14, IRGKangXi=0431.171, RSKangXi=64.6
22B15 CJK UNIFIED IDEOGRAPH-#22B15, IRGKangXi=0431.171, RSKangXi=64.6
22B16 CJK UNIFIED IDEOGRAPH-#22B16, IRGKangXi=0431.171, RSKangXi=64.6
22B17 CJK UNIFIED IDEOGRAPH-#22B17, IRGKangXi=0431.171, RSKangXi=64.6
22B18 CJK UNIFIED IDEOGRAPH-#22B18, IRGKangXi=0431.171, RSKangXi=64.6
22B19 CJK UNIFIED IDEOGRAPH-#22B19, IRGKangXi=0431.171, RSKangXi=64.6
22B1A CJK UNIFIED IDEOGRAPH-#22B1A, IRGKangXi=0431.171, RSKangXi=64.6
22B1B CJK UNIFIED IDEOGRAPH-#22B1B, IRGKangXi=0431.171, RSKangXi=64.6
22B1C CJK UNIFIED IDEOGRAPH-#22B1C, IRGKangXi=0431.171, RSKangXi=64.6
22B1D CJK UNIFIED IDEOGRAPH-#22B1D, IRGKangXi=0431.171, RSKangXi=64.6
22B1E CJK UNIFIED IDEOGRAPH-#22B1E, IRGKangXi=0431.171, RSKangXi=64.6
22B1F CJK UNIFIED IDEOGRAPH-#22B1F, IRGKangXi=0431.171, RSKangXi=64.6
22B20 CJK UNIFIED IDEOGRAPH-#22B20, IRGKangXi=0431.171, RSKangXi=64.6
22B21 CJK UNIFIED IDEOGRAPH-#22B21, IRGKangXi=0431.171, RSKangXi=64.6
22B22 CJK UNIFIED IDEOGRAPH-#22B22, IRGKangXi=0431.171, RSKangXi=64.6
22B23 CJK UNIFIED IDEOGRAPH-#22B23, IRGKangXi=0431.171, RSKangXi=64.6
22B24 CJK UNIFIED IDEOGRAPH-#22B24, IRGKangXi=0431.171, RSKangXi=64.6
22B25 CJK UNIFIED IDEOGRAPH-#22B25, IRGKangXi=0431.171, RSKangXi=64.6
22B26 CJK UNIFIED IDEOGRAPH-#22B26, IRGKangXi=0431.171, RSKangXi=64.6
22B27 CJK UNIFIED IDEOGRAPH-#22B27, IRGKangXi=0431.171, RSKangXi=64.6
22B28 CJK UNIFIED IDEOGRAPH-#22B28, IRGKangXi=0431.171, RSKangXi=64.6
22B29 CJK UNIFIED IDEOGRAPH-#22B29, IRGKangXi=0431.171, RSKangXi=64.6
22B2A CJK UNIFIED IDEOGRAPH-#22B2A, IRGKangXi=0431.171, RSKangXi=64.6
22B2B CJK UNIFIED IDEOGRAPH-#22B2B, IRGKangXi=0431.171, RSKangXi=64.6
22B2C CJK UNIFIED IDEOGRAPH-#22B2C, IRGKangXi=0431.171, RSKangXi=64.6
22B2D CJK UNIFIED IDEOGRAPH-#22B2D, IRGKangXi=0431.171, RSKangXi=64.6
22B2E CJK UNIFIED IDEOGRAPH-#22B2E, IRGKangXi=0431.171, RSKangXi=64.6
22B2F CJK UNIFIED IDEOGRAPH-#22B2F, IRGKangXi=0431.210, RSKangXi=64.7
22B30 CJK UNIFIED IDEOGRAPH-#22B30, IRGKangXi=0431.320, RSKangXi=64.7
22B31 CJK UNIFIED IDEOGRAPH-#22B31, IRGKangXi=0432.080, RSKangXi=64.7
22B32 CJK UNIFIED IDEOGRAPH-#22B32, IRGKangXi=0432.100, RSKangXi=64.7
22B33 CJK UNIFIED IDEOGRAPH-#22B33, IRGKangXi=0432.120, RSKangXi=64.7
22B34 CJK UNIFIED IDEOGRAPH-#22B34, IRGKangXi=0432.130, RSKangXi=64.7
22B35 CJK UNIFIED IDEOGRAPH-#22B35, IRGKangXi=0432.140, RSKangXi=64.7
22B36 CJK UNIFIED IDEOGRAPH-#22B36, IRGKangXi=0432.150, RSKangXi=64.7
22B37 CJK UNIFIED IDEOGRAPH-#22B37, IRGKangXi=0432.190, RSKangXi=64.7
22B38 CJK UNIFIED IDEOGRAPH-#22B38, IRGKangXi=0433.020, RSKangXi=64.7
22B39 CJK UNIFIED IDEOGRAPH-#22B39, IRGKangXi=0433.040, RSKangXi=64.7
22B3A CJK UNIFIED IDEOGRAPH-#22B3A, IRGKangXi=0433.050, RSKangXi=64.7
22B3B CJK UNIFIED IDEOGRAPH-#22B3B, IRGKangXi=0433.080, RSKangXi=64.7
22B3C CJK UNIFIED IDEOGRAPH-#22B3C, IRGKangXi=0433.090, RSKangXi=64.7
22B3D CJK UNIFIED IDEOGRAPH-#22B3D, IRGKangXi=0433.130, RSKangXi=64.7
22B3E CJK UNIFIED IDEOGRAPH-#22B3E, IRGKangXi=0433.140, RSKangXi=64.7
22B3F CJK UNIFIED IDEOGRAPH-#22B3F, IRGKangXi=0433.190, RSKangXi=64.7, Def{(Cant.) sections or wedges (as of fruit); to take in the hand; to use}
22B40 CJK UNIFIED IDEOGRAPH-#22B40, IRGKangXi=0433.210, RSKangXi=64.7
22B41 CJK UNIFIED IDEOGRAPH-#22B41, IRGKangXi=0433.230, RSKangXi=64.7
22B42 CJK UNIFIED IDEOGRAPH-#22B42, IRGKangXi=0433.240, RSKangXi=64.7
22B43 CJK UNIFIED IDEOGRAPH-#22B43, IRGKangXi=0434.030, RSKangXi=64.7, Def{(Cant.) to touch; to bump into; to take, get, receive; to lightly support something with the hand}
22B44 CJK UNIFIED IDEOGRAPH-#22B44, IRGKangXi=0434.040, RSKangXi=64.7
22B45 CJK UNIFIED IDEOGRAPH-#22B45, IRGKangXi=0434.110, RSKangXi=64.7
22B46 CJK UNIFIED IDEOGRAPH-#22B46, IRGKangXi=0434.140, RSKangXi=64.7, Def{to draw out; to levy; to strike}
22B47 CJK UNIFIED IDEOGRAPH-#22B47, IRGKangXi=0434.150, RSKangXi=64.7
22B48 CJK UNIFIED IDEOGRAPH-#22B48, IRGKangXi=0434.160, RSKangXi=64.7
22B49 CJK UNIFIED IDEOGRAPH-#22B49, IRGKangXi=0434.170, RSKangXi=64.7
22B4A CJK UNIFIED IDEOGRAPH-#22B4A, IRGKangXi=0434.190, RSKangXi=64.7
22B4B CJK UNIFIED IDEOGRAPH-#22B4B, IRGKangXi=0434.200, RSKangXi=64.7
22B4C CJK UNIFIED IDEOGRAPH-#22B4C, IRGKangXi=0434.210, RSKangXi=64.7
22B4D CJK UNIFIED IDEOGRAPH-#22B4D, IRGKangXi=0434.220, RSKangXi=64.7
22B4E CJK UNIFIED IDEOGRAPH-#22B4E, IRGKangXi=0434.240, RSKangXi=64.7
22B4F CJK UNIFIED IDEOGRAPH-#22B4F, IRGKangXi=0434.241
22B50 CJK UNIFIED IDEOGRAPH-#22B50, IRGKangXi=0434.241, RSKangXi=64.7
22B51 CJK UNIFIED IDEOGRAPH-#22B51, IRGKangXi=0434.241, RSKangXi=64.7
22B52 CJK UNIFIED IDEOGRAPH-#22B52, IRGKangXi=0434.241, RSKangXi=64.7
22B53 CJK UNIFIED IDEOGRAPH-#22B53, IRGKangXi=0434.241, RSKangXi=64.7
22B54 CJK UNIFIED IDEOGRAPH-#22B54, IRGKangXi=0434.241, RSKangXi=64.7
22B55 CJK UNIFIED IDEOGRAPH-#22B55, IRGKangXi=0434.241, RSKangXi=64.7
22B56 CJK UNIFIED IDEOGRAPH-#22B56, IRGKangXi=0434.241, RSKangXi=64.7
22B57 CJK UNIFIED IDEOGRAPH-#22B57, IRGKangXi=0434.241, RSKangXi=64.7
22B58 CJK UNIFIED IDEOGRAPH-#22B58, IRGKangXi=0434.241, RSKangXi=64.7
22B59 CJK UNIFIED IDEOGRAPH-#22B59, IRGKangXi=0434.241, RSKangXi=64.7
22B5A CJK UNIFIED IDEOGRAPH-#22B5A, IRGKangXi=0434.241, RSKangXi=64.7
22B5B CJK UNIFIED IDEOGRAPH-#22B5B, IRGKangXi=0434.241, RSKangXi=64.7
22B5C CJK UNIFIED IDEOGRAPH-#22B5C, IRGKangXi=0434.241, RSKangXi=64.7
22B5D CJK UNIFIED IDEOGRAPH-#22B5D, IRGKangXi=0434.241, RSKangXi=64.7
22B5E CJK UNIFIED IDEOGRAPH-#22B5E, IRGKangXi=0434.241, RSKangXi=64.7
22B5F CJK UNIFIED IDEOGRAPH-#22B5F, IRGKangXi=0434.241, RSKangXi=64.7
22B60 CJK UNIFIED IDEOGRAPH-#22B60, IRGKangXi=0434.241, RSKangXi=64.7
22B61 CJK UNIFIED IDEOGRAPH-#22B61, IRGKangXi=0434.241, RSKangXi=64.7
22B62 CJK UNIFIED IDEOGRAPH-#22B62, IRGKangXi=0434.241, RSKangXi=64.7
22B63 CJK UNIFIED IDEOGRAPH-#22B63, IRGKangXi=0434.241, RSKangXi=64.7
22B64 CJK UNIFIED IDEOGRAPH-#22B64, IRGKangXi=0434.241, RSKangXi=64.7
22B65 CJK UNIFIED IDEOGRAPH-#22B65, IRGKangXi=0434.241, RSKangXi=64.7
22B66 CJK UNIFIED IDEOGRAPH-#22B66, IRGKangXi=0434.241, RSKangXi=64.7
22B67 CJK UNIFIED IDEOGRAPH-#22B67, IRGKangXi=0434.241, RSKangXi=64.7
22B68 CJK UNIFIED IDEOGRAPH-#22B68, IRGKangXi=0434.241, RSKangXi=64.7
22B69 CJK UNIFIED IDEOGRAPH-#22B69, IRGKangXi=0434.241, RSKangXi=64.7
22B6A CJK UNIFIED IDEOGRAPH-#22B6A, IRGKangXi=0434.241, RSKangXi=64.7
22B6B CJK UNIFIED IDEOGRAPH-#22B6B, IRGKangXi=0434.241, RSKangXi=64.7
22B6C CJK UNIFIED IDEOGRAPH-#22B6C, IRGKangXi=0434.241, RSKangXi=64.7
22B6D CJK UNIFIED IDEOGRAPH-#22B6D, IRGKangXi=0434.241, RSKangXi=64.7
22B6E CJK UNIFIED IDEOGRAPH-#22B6E, IRGKangXi=0434.241, RSKangXi=64.7
22B6F CJK UNIFIED IDEOGRAPH-#22B6F, IRGKangXi=0434.241, RSKangXi=64.7
22B70 CJK UNIFIED IDEOGRAPH-#22B70, IRGKangXi=0434.241, RSKangXi=64.7
22B71 CJK UNIFIED IDEOGRAPH-#22B71, IRGKangXi=0434.241, RSKangXi=64.7
22B72 CJK UNIFIED IDEOGRAPH-#22B72, IRGKangXi=0434.241, RSKangXi=64.7
22B73 CJK UNIFIED IDEOGRAPH-#22B73, IRGKangXi=0434.241, RSKangXi=64.7
22B74 CJK UNIFIED IDEOGRAPH-#22B74, IRGKangXi=0434.241, RSKangXi=64.7
22B75 CJK UNIFIED IDEOGRAPH-#22B75, IRGKangXi=0434.241, RSKangXi=64.7
22B76 CJK UNIFIED IDEOGRAPH-#22B76, IRGKangXi=0434.241, RSKangXi=64.7
22B77 CJK UNIFIED IDEOGRAPH-#22B77, IRGKangXi=0434.241, RSKangXi=64.7
22B78 CJK UNIFIED IDEOGRAPH-#22B78, IRGKangXi=0434.241, RSKangXi=64.7
22B79 CJK UNIFIED IDEOGRAPH-#22B79, IRGKangXi=0434.241, RSKangXi=64.7
22B7A CJK UNIFIED IDEOGRAPH-#22B7A, IRGKangXi=0434.241, RSKangXi=64.7
22B7B CJK UNIFIED IDEOGRAPH-#22B7B, IRGKangXi=0434.241, RSKangXi=64.7
22B7C CJK UNIFIED IDEOGRAPH-#22B7C, IRGKangXi=0434.241, RSKangXi=64.7
22B7D CJK UNIFIED IDEOGRAPH-#22B7D, IRGKangXi=0434.241, RSKangXi=64.7
22B7E CJK UNIFIED IDEOGRAPH-#22B7E, IRGKangXi=0434.241, RSKangXi=64.7
22B7F CJK UNIFIED IDEOGRAPH-#22B7F, IRGKangXi=0434.241, RSKangXi=64.7
22B80 CJK UNIFIED IDEOGRAPH-#22B80, IRGKangXi=0434.241, RSKangXi=64.7
22B81 CJK UNIFIED IDEOGRAPH-#22B81, IRGKangXi=0434.280, RSKangXi=64.8
22B82 CJK UNIFIED IDEOGRAPH-#22B82, IRGKangXi=0434.320, RSKangXi=64.8
22B83 CJK UNIFIED IDEOGRAPH-#22B83, IRGKangXi=0434.340, RSKangXi=64.8
22B84 CJK UNIFIED IDEOGRAPH-#22B84, IRGKangXi=0435.010, RSKangXi=64.8
22B85 CJK UNIFIED IDEOGRAPH-#22B85, IRGKangXi=0435.070, RSKangXi=64.8
22B86 CJK UNIFIED IDEOGRAPH-#22B86, IRGKangXi=0435.090, RSKangXi=64.8
22B87 CJK UNIFIED IDEOGRAPH-#22B87, IRGKangXi=0435.100, RSKangXi=64.8
22B88 CJK UNIFIED IDEOGRAPH-#22B88, IRGKangXi=0435.190, RSKangXi=64.8
22B89 CJK UNIFIED IDEOGRAPH-#22B89, IRGKangXi=0435.210, RSKangXi=64.8
22B8A CJK UNIFIED IDEOGRAPH-#22B8A, IRGKangXi=0435.270, RSKangXi=64.8
22B8B CJK UNIFIED IDEOGRAPH-#22B8B, IRGKangXi=0435.280, RSKangXi=64.8
22B8C CJK UNIFIED IDEOGRAPH-#22B8C, IRGKangXi=0436.010, RSKangXi=64.8
22B8D CJK UNIFIED IDEOGRAPH-#22B8D, IRGKangXi=0436.050, RSKangXi=64.8
22B8E CJK UNIFIED IDEOGRAPH-#22B8E, IRGKangXi=0436.060, RSKangXi=64.8
22B8F CJK UNIFIED IDEOGRAPH-#22B8F, IRGKangXi=0437.020, RSKangXi=64.8
22B90 CJK UNIFIED IDEOGRAPH-#22B90, IRGKangXi=0437.040, RSKangXi=64.8
22B91 CJK UNIFIED IDEOGRAPH-#22B91, IRGKangXi=0437.100, RSKangXi=64.8, Def{(Cant.) classifier for lengths of cylindrically shaped objects}
22B92 CJK UNIFIED IDEOGRAPH-#22B92, IRGKangXi=0437.180, RSKangXi=64.8
22B93 CJK UNIFIED IDEOGRAPH-#22B93, IRGKangXi=0439.020, RSKangXi=64.8
22B94 CJK UNIFIED IDEOGRAPH-#22B94, IRGKangXi=0439.060, RSKangXi=64.8
22B95 CJK UNIFIED IDEOGRAPH-#22B95, IRGKangXi=0440.010, RSKangXi=64.8
22B96 CJK UNIFIED IDEOGRAPH-#22B96, IRGKangXi=0440.030, RSKangXi=64.8
22B97 CJK UNIFIED IDEOGRAPH-#22B97, IRGKangXi=0440.050, RSKangXi=64.8
22B98 CJK UNIFIED IDEOGRAPH-#22B98, IRGKangXi=0440.060, RSKangXi=64.8
22B99 CJK UNIFIED IDEOGRAPH-#22B99, IRGKangXi=0440.070, RSKangXi=64.8
22B9A CJK UNIFIED IDEOGRAPH-#22B9A, IRGKangXi=0440.080, RSKangXi=64.8
22B9B CJK UNIFIED IDEOGRAPH-#22B9B, IRGKangXi=0440.090, RSKangXi=64.8
22B9C CJK UNIFIED IDEOGRAPH-#22B9C, IRGKangXi=0440.100, RSKangXi=64.8
22B9D CJK UNIFIED IDEOGRAPH-#22B9D, IRGKangXi=0440.110, RSKangXi=64.8
22B9E CJK UNIFIED IDEOGRAPH-#22B9E, IRGKangXi=0440.120, RSKangXi=64.8
22B9F CJK UNIFIED IDEOGRAPH-#22B9F, IRGKangXi=0440.130, RSKangXi=64.8
22BA0 CJK UNIFIED IDEOGRAPH-#22BA0, IRGKangXi=0440.140, RSKangXi=64.8
22BA1 CJK UNIFIED IDEOGRAPH-#22BA1, IRGKangXi=0440.150, RSKangXi=64.8
22BA2 CJK UNIFIED IDEOGRAPH-#22BA2, IRGKangXi=0440.160, RSKangXi=64.8
22BA3 CJK UNIFIED IDEOGRAPH-#22BA3, IRGKangXi=0440.170, RSKangXi=64.8
22BA4 CJK UNIFIED IDEOGRAPH-#22BA4, IRGKangXi=0440.180, RSKangXi=64.8
22BA5 CJK UNIFIED IDEOGRAPH-#22BA5, IRGKangXi=0440.181, RSKangXi=64.8
22BA6 CJK UNIFIED IDEOGRAPH-#22BA6, IRGKangXi=0440.181, RSKangXi=64.8
22BA7 CJK UNIFIED IDEOGRAPH-#22BA7, IRGKangXi=0440.181, RSKangXi=64.8
22BA8 CJK UNIFIED IDEOGRAPH-#22BA8, IRGKangXi=0440.181, RSKangXi=64.8
22BA9 CJK UNIFIED IDEOGRAPH-#22BA9, IRGKangXi=0440.181, RSKangXi=64.8
22BAA CJK UNIFIED IDEOGRAPH-#22BAA, IRGKangXi=0440.181, RSKangXi=64.8
22BAB CJK UNIFIED IDEOGRAPH-#22BAB, IRGKangXi=0440.181, RSKangXi=64.8
22BAC CJK UNIFIED IDEOGRAPH-#22BAC, IRGKangXi=0440.181, RSKangXi=64.8
22BAD CJK UNIFIED IDEOGRAPH-#22BAD, IRGKangXi=0440.181, RSKangXi=64.8
22BAE CJK UNIFIED IDEOGRAPH-#22BAE, IRGKangXi=0440.181, RSKangXi=64.8
22BAF CJK UNIFIED IDEOGRAPH-#22BAF, IRGKangXi=0440.181, RSKangXi=64.8
22BB0 CJK UNIFIED IDEOGRAPH-#22BB0, IRGKangXi=0440.181, RSKangXi=64.8
22BB1 CJK UNIFIED IDEOGRAPH-#22BB1, IRGKangXi=0440.181, RSKangXi=64.8
22BB2 CJK UNIFIED IDEOGRAPH-#22BB2, IRGKangXi=0440.181, RSKangXi=64.8
22BB3 CJK UNIFIED IDEOGRAPH-#22BB3, IRGKangXi=0440.181, RSKangXi=64.8
22BB4 CJK UNIFIED IDEOGRAPH-#22BB4, IRGKangXi=0440.181, RSKangXi=64.8
22BB5 CJK UNIFIED IDEOGRAPH-#22BB5, IRGKangXi=0440.181, RSKangXi=64.8
22BB6 CJK UNIFIED IDEOGRAPH-#22BB6, IRGKangXi=0440.181, RSKangXi=64.8
22BB7 CJK UNIFIED IDEOGRAPH-#22BB7, IRGKangXi=0440.181, RSKangXi=64.8
22BB8 CJK UNIFIED IDEOGRAPH-#22BB8, IRGKangXi=0440.181, RSKangXi=64.8
22BB9 CJK UNIFIED IDEOGRAPH-#22BB9, IRGKangXi=0440.181, RSKangXi=64.8
22BBA CJK UNIFIED IDEOGRAPH-#22BBA, IRGKangXi=0440.181, RSKangXi=64.8
22BBB CJK UNIFIED IDEOGRAPH-#22BBB, IRGKangXi=0440.181, RSKangXi=64.8
22BBC CJK UNIFIED IDEOGRAPH-#22BBC, IRGKangXi=0440.181, RSKangXi=64.8
22BBD CJK UNIFIED IDEOGRAPH-#22BBD, IRGKangXi=0440.181, RSKangXi=64.8
22BBE CJK UNIFIED IDEOGRAPH-#22BBE, IRGKangXi=0440.181, RSKangXi=64.8
22BBF CJK UNIFIED IDEOGRAPH-#22BBF, IRGKangXi=0440.181, RSKangXi=64.8
22BC0 CJK UNIFIED IDEOGRAPH-#22BC0, IRGKangXi=0440.181, RSKangXi=64.8
22BC1 CJK UNIFIED IDEOGRAPH-#22BC1, IRGKangXi=0440.181, RSKangXi=64.8
22BC2 CJK UNIFIED IDEOGRAPH-#22BC2, IRGKangXi=0440.181, RSKangXi=64.8
22BC3 CJK UNIFIED IDEOGRAPH-#22BC3, IRGKangXi=0440.181, RSKangXi=64.8
22BC4 CJK UNIFIED IDEOGRAPH-#22BC4, IRGKangXi=0440.181, RSKangXi=64.8
22BC5 CJK UNIFIED IDEOGRAPH-#22BC5, IRGKangXi=0440.181, RSKangXi=64.8
22BC6 CJK UNIFIED IDEOGRAPH-#22BC6, IRGKangXi=0440.181, RSKangXi=64.8
22BC7 CJK UNIFIED IDEOGRAPH-#22BC7, IRGKangXi=0440.181, RSKangXi=64.8
22BC8 CJK UNIFIED IDEOGRAPH-#22BC8, IRGKangXi=0440.181, RSKangXi=64.8
22BC9 CJK UNIFIED IDEOGRAPH-#22BC9, IRGKangXi=0440.181, RSKangXi=64.8
22BCA CJK UNIFIED IDEOGRAPH-#22BCA, IRGKangXi=0440.181, RSKangXi=64.8, Def{(Cant.) determination, resolution}
22BCB CJK UNIFIED IDEOGRAPH-#22BCB, IRGKangXi=0440.181, RSKangXi=64.8
22BCC CJK UNIFIED IDEOGRAPH-#22BCC, IRGKangXi=0440.181, RSKangXi=64.8
22BCD CJK UNIFIED IDEOGRAPH-#22BCD, IRGKangXi=0440.181, RSKangXi=64.8
22BCE CJK UNIFIED IDEOGRAPH-#22BCE, IRGKangXi=0440.181, RSKangXi=64.8, Def{(Cant.) to scratch}
22BCF CJK UNIFIED IDEOGRAPH-#22BCF, IRGKangXi=0440.181, RSKangXi=64.8
22BD0 CJK UNIFIED IDEOGRAPH-#22BD0, IRGKangXi=0440.181, RSKangXi=64.8
22BD1 CJK UNIFIED IDEOGRAPH-#22BD1, IRGKangXi=0440.181, RSKangXi=64.8
22BD2 CJK UNIFIED IDEOGRAPH-#22BD2, IRGKangXi=0440.181, RSKangXi=64.8
22BD3 CJK UNIFIED IDEOGRAPH-#22BD3, IRGKangXi=0440.181, RSKangXi=64.8
22BD4 CJK UNIFIED IDEOGRAPH-#22BD4, IRGKangXi=0440.181, RSKangXi=64.8
22BD5 CJK UNIFIED IDEOGRAPH-#22BD5, IRGKangXi=0440.181, RSKangXi=64.8
22BD6 CJK UNIFIED IDEOGRAPH-#22BD6, IRGKangXi=0440.181, RSKangXi=64.8
22BD7 CJK UNIFIED IDEOGRAPH-#22BD7, IRGKangXi=0440.181, RSKangXi=64.8
22BD8 CJK UNIFIED IDEOGRAPH-#22BD8, IRGKangXi=0440.181, RSKangXi=64.8
22BD9 CJK UNIFIED IDEOGRAPH-#22BD9, IRGKangXi=0440.181, RSKangXi=64.8
22BDA CJK UNIFIED IDEOGRAPH-#22BDA, IRGKangXi=0440.181, RSKangXi=64.8
22BDB CJK UNIFIED IDEOGRAPH-#22BDB, IRGKangXi=0440.181, RSKangXi=64.8
22BDC CJK UNIFIED IDEOGRAPH-#22BDC, IRGKangXi=0440.181, RSKangXi=64.8
22BDD CJK UNIFIED IDEOGRAPH-#22BDD, IRGKangXi=0440.181, RSKangXi=64.8
22BDE CJK UNIFIED IDEOGRAPH-#22BDE, IRGKangXi=0440.181, RSKangXi=64.8
22BDF CJK UNIFIED IDEOGRAPH-#22BDF, IRGKangXi=0440.181, RSKangXi=64.8
22BE0 CJK UNIFIED IDEOGRAPH-#22BE0, IRGKangXi=0440.181, RSKangXi=64.8
22BE1 CJK UNIFIED IDEOGRAPH-#22BE1, IRGKangXi=0440.181, RSKangXi=64.8
22BE2 CJK UNIFIED IDEOGRAPH-#22BE2, IRGKangXi=0440.181, RSKangXi=64.8
22BE3 CJK UNIFIED IDEOGRAPH-#22BE3, IRGKangXi=0440.181, RSKangXi=64.8
22BE4 CJK UNIFIED IDEOGRAPH-#22BE4, IRGKangXi=0440.181, RSKangXi=64.8
22BE5 CJK UNIFIED IDEOGRAPH-#22BE5, IRGKangXi=0440.181, RSKangXi=64.8
22BE6 CJK UNIFIED IDEOGRAPH-#22BE6, IRGKangXi=0440.181, RSKangXi=64.8
22BE7 CJK UNIFIED IDEOGRAPH-#22BE7, IRGKangXi=0440.181, RSKangXi=64.8
22BE8 CJK UNIFIED IDEOGRAPH-#22BE8, IRGKangXi=0440.181, RSKangXi=64.8
22BE9 CJK UNIFIED IDEOGRAPH-#22BE9, IRGKangXi=0440.280, RSKangXi=64.9
22BEA CJK UNIFIED IDEOGRAPH-#22BEA, IRGKangXi=0440.290, RSKangXi=64.9
22BEB CJK UNIFIED IDEOGRAPH-#22BEB, IRGKangXi=0441.010, RSKangXi=64.9
22BEC CJK UNIFIED IDEOGRAPH-#22BEC, IRGKangXi=0441.030, RSKangXi=64.9
22BED CJK UNIFIED IDEOGRAPH-#22BED, IRGKangXi=0441.090, RSKangXi=64.9
22BEE CJK UNIFIED IDEOGRAPH-#22BEE, IRGKangXi=0441.110, RSKangXi=64.9
22BEF CJK UNIFIED IDEOGRAPH-#22BEF, IRGKangXi=0441.200, RSKangXi=64.9
22BF0 CJK UNIFIED IDEOGRAPH-#22BF0, IRGKangXi=0441.210, RSKangXi=64.9
22BF1 CJK UNIFIED IDEOGRAPH-#22BF1, IRGKangXi=0442.120, RSKangXi=64.9, Def{public opinion; to assemble; to seek}
22BF2 CJK UNIFIED IDEOGRAPH-#22BF2, IRGKangXi=0443.050, RSKangXi=64.9
22BF3 CJK UNIFIED IDEOGRAPH-#22BF3, IRGKangXi=0443.060, RSKangXi=64.9
22BF4 CJK UNIFIED IDEOGRAPH-#22BF4, IRGKangXi=0443.100, RSKangXi=64.9
22BF5 CJK UNIFIED IDEOGRAPH-#22BF5, IRGKangXi=0443.110, RSKangXi=64.9
22BF6 CJK UNIFIED IDEOGRAPH-#22BF6, IRGKangXi=0443.170, RSKangXi=64.9
22BF7 CJK UNIFIED IDEOGRAPH-#22BF7, IRGKangXi=0443.180, RSKangXi=64.9
22BF8 CJK UNIFIED IDEOGRAPH-#22BF8, IRGKangXi=0444.030, RSKangXi=64.9
22BF9 CJK UNIFIED IDEOGRAPH-#22BF9, IRGKangXi=0444.060, RSKangXi=64.9
22BFA CJK UNIFIED IDEOGRAPH-#22BFA, IRGKangXi=0444.070, RSKangXi=64.9
22BFB CJK UNIFIED IDEOGRAPH-#22BFB, IRGKangXi=0444.090, RSKangXi=64.9
22BFC CJK UNIFIED IDEOGRAPH-#22BFC, IRGKangXi=0444.130, RSKangXi=64.9
22BFD CJK UNIFIED IDEOGRAPH-#22BFD, IRGKangXi=0444.140, RSKangXi=64.9
22BFE CJK UNIFIED IDEOGRAPH-#22BFE, IRGKangXi=0444.150, RSKangXi=64.9
22BFF CJK UNIFIED IDEOGRAPH-#22BFF, IRGKangXi=0444.170, RSKangXi=64.9
22C00 CJK UNIFIED IDEOGRAPH-#22C00, IRGKangXi=0445.010, RSKangXi=64.9
22C01 CJK UNIFIED IDEOGRAPH-#22C01, IRGKangXi=0445.050, RSKangXi=64.9
22C02 CJK UNIFIED IDEOGRAPH-#22C02, IRGKangXi=0445.070, RSKangXi=64.9
22C03 CJK UNIFIED IDEOGRAPH-#22C03, IRGKangXi=0445.080, RSKangXi=64.9
22C04 CJK UNIFIED IDEOGRAPH-#22C04, IRGKangXi=0445.090, RSKangXi=64.9
22C05 CJK UNIFIED IDEOGRAPH-#22C05, IRGKangXi=0445.100, RSKangXi=64.9
22C06 CJK UNIFIED IDEOGRAPH-#22C06, IRGKangXi=0445.110, RSKangXi=64.9
22C07 CJK UNIFIED IDEOGRAPH-#22C07, IRGKangXi=0445.120, RSKangXi=64.9
22C08 CJK UNIFIED IDEOGRAPH-#22C08, IRGKangXi=0445.130, RSKangXi=64.9
22C09 CJK UNIFIED IDEOGRAPH-#22C09, IRGKangXi=0445.140, RSKangXi=64.9
22C0A CJK UNIFIED IDEOGRAPH-#22C0A, IRGKangXi=0445.150, RSKangXi=64.9
22C0B CJK UNIFIED IDEOGRAPH-#22C0B, IRGKangXi=0445.160, RSKangXi=64.9
22C0C CJK UNIFIED IDEOGRAPH-#22C0C, IRGKangXi=0445.170, RSKangXi=64.9
22C0D CJK UNIFIED IDEOGRAPH-#22C0D, IRGKangXi=0445.180, RSKangXi=64.9
22C0E CJK UNIFIED IDEOGRAPH-#22C0E, IRGKangXi=0445.190, RSKangXi=64.9
22C0F CJK UNIFIED IDEOGRAPH-#22C0F, IRGKangXi=0445.200, RSKangXi=64.9
22C10 CJK UNIFIED IDEOGRAPH-#22C10, IRGKangXi=0445.210, RSKangXi=64.9
22C11 CJK UNIFIED IDEOGRAPH-#22C11, IRGKangXi=0445.220, RSKangXi=64.9
22C12 CJK UNIFIED IDEOGRAPH-#22C12, IRGKangXi=0445.230, RSKangXi=64.9
22C13 CJK UNIFIED IDEOGRAPH-#22C13, IRGKangXi=0445.240, RSKangXi=64.9
22C14 CJK UNIFIED IDEOGRAPH-#22C14, IRGKangXi=0445.250, RSKangXi=64.9
22C15 CJK UNIFIED IDEOGRAPH-#22C15, IRGKangXi=0445.260, RSKangXi=64.9
22C16 CJK UNIFIED IDEOGRAPH-#22C16, IRGKangXi=0445.270, RSKangXi=64.9
22C17 CJK UNIFIED IDEOGRAPH-#22C17, IRGKangXi=0445.280, RSKangXi=64.9
22C18 CJK UNIFIED IDEOGRAPH-#22C18, IRGKangXi=0445.290, RSKangXi=64.9
22C19 CJK UNIFIED IDEOGRAPH-#22C19, IRGKangXi=0445.300, RSKangXi=64.9
22C1A CJK UNIFIED IDEOGRAPH-#22C1A, IRGKangXi=0445.310, RSKangXi=64.9
22C1B CJK UNIFIED IDEOGRAPH-#22C1B, IRGKangXi=0445.320, RSKangXi=64.9
22C1C CJK UNIFIED IDEOGRAPH-#22C1C, IRGKangXi=0445.330, RSKangXi=64.9
22C1D CJK UNIFIED IDEOGRAPH-#22C1D, IRGKangXi=0445.341, RSKangXi=64.9
22C1E CJK UNIFIED IDEOGRAPH-#22C1E, IRGKangXi=0445.341, RSKangXi=64.9
22C1F CJK UNIFIED IDEOGRAPH-#22C1F, IRGKangXi=0445.341, RSKangXi=64.9
22C20 CJK UNIFIED IDEOGRAPH-#22C20, IRGKangXi=0445.341, RSKangXi=64.9
22C21 CJK UNIFIED IDEOGRAPH-#22C21, IRGKangXi=0445.341, RSKangXi=64.9
22C22 CJK UNIFIED IDEOGRAPH-#22C22, IRGKangXi=0445.341, RSKangXi=64.9
22C23 CJK UNIFIED IDEOGRAPH-#22C23, IRGKangXi=0445.341, RSKangXi=64.9
22C24 CJK UNIFIED IDEOGRAPH-#22C24, IRGKangXi=0445.341, RSKangXi=64.9
22C25 CJK UNIFIED IDEOGRAPH-#22C25, IRGKangXi=0445.341, RSKangXi=64.9
22C26 CJK UNIFIED IDEOGRAPH-#22C26, IRGKangXi=0445.341, RSKangXi=64.9
22C27 CJK UNIFIED IDEOGRAPH-#22C27, IRGKangXi=0445.341, RSKangXi=64.9
22C28 CJK UNIFIED IDEOGRAPH-#22C28, IRGKangXi=0445.341, RSKangXi=64.9
22C29 CJK UNIFIED IDEOGRAPH-#22C29, IRGKangXi=0445.341, RSKangXi=64.9
22C2A CJK UNIFIED IDEOGRAPH-#22C2A, IRGKangXi=0445.341, RSKangXi=64.9
22C2B CJK UNIFIED IDEOGRAPH-#22C2B, IRGKangXi=0445.341, RSKangXi=64.9
22C2C CJK UNIFIED IDEOGRAPH-#22C2C, IRGKangXi=0445.341, RSKangXi=64.9
22C2D CJK UNIFIED IDEOGRAPH-#22C2D, IRGKangXi=0445.341, RSKangXi=64.9
22C2E CJK UNIFIED IDEOGRAPH-#22C2E, IRGKangXi=0445.341, RSKangXi=64.9
22C2F CJK UNIFIED IDEOGRAPH-#22C2F, IRGKangXi=0445.341, RSKangXi=64.9
22C30 CJK UNIFIED IDEOGRAPH-#22C30, IRGKangXi=0445.341, RSKangXi=64.9
22C31 CJK UNIFIED IDEOGRAPH-#22C31, IRGKangXi=0445.341, RSKangXi=64.9
22C32 CJK UNIFIED IDEOGRAPH-#22C32, IRGKangXi=0445.341, RSKangXi=64.9
22C33 CJK UNIFIED IDEOGRAPH-#22C33, IRGKangXi=0445.341, RSKangXi=64.9
22C34 CJK UNIFIED IDEOGRAPH-#22C34, IRGKangXi=0445.341, RSKangXi=64.9
22C35 CJK UNIFIED IDEOGRAPH-#22C35, IRGKangXi=0445.341, RSKangXi=64.9
22C36 CJK UNIFIED IDEOGRAPH-#22C36, IRGKangXi=0445.341, RSKangXi=64.9
22C37 CJK UNIFIED IDEOGRAPH-#22C37, IRGKangXi=0445.341, RSKangXi=64.9
22C38 CJK UNIFIED IDEOGRAPH-#22C38, IRGKangXi=0445.341, RSKangXi=64.9, Def{(Cant.) rotten, bad, spoiled}
22C39 CJK UNIFIED IDEOGRAPH-#22C39, IRGKangXi=0445.341, RSKangXi=64.9
22C3A CJK UNIFIED IDEOGRAPH-#22C3A, IRGKangXi=0445.341, RSKangXi=64.9
22C3B CJK UNIFIED IDEOGRAPH-#22C3B, IRGKangXi=0445.341, RSKangXi=64.9
22C3C CJK UNIFIED IDEOGRAPH-#22C3C, IRGKangXi=0445.341, RSKangXi=64.9
22C3D CJK UNIFIED IDEOGRAPH-#22C3D, IRGKangXi=0445.341, RSKangXi=64.9
22C3E CJK UNIFIED IDEOGRAPH-#22C3E, IRGKangXi=0445.341, RSKangXi=64.9, Def{general, overall, chief}
22C3F CJK UNIFIED IDEOGRAPH-#22C3F, IRGKangXi=0445.341, RSKangXi=109.8
22C40 CJK UNIFIED IDEOGRAPH-#22C40, IRGKangXi=0445.341, RSKangXi=64.9
22C41 CJK UNIFIED IDEOGRAPH-#22C41, IRGKangXi=0445.341, RSKangXi=64.9
22C42 CJK UNIFIED IDEOGRAPH-#22C42, IRGKangXi=0445.341, RSKangXi=64.9
22C43 CJK UNIFIED IDEOGRAPH-#22C43, IRGKangXi=0445.341, RSKangXi=64.9
22C44 CJK UNIFIED IDEOGRAPH-#22C44, IRGKangXi=0445.341, RSKangXi=64.9
22C45 CJK UNIFIED IDEOGRAPH-#22C45, IRGKangXi=0445.341, RSKangXi=64.9
22C46 CJK UNIFIED IDEOGRAPH-#22C46, IRGKangXi=0445.341, RSKangXi=64.9
22C47 CJK UNIFIED IDEOGRAPH-#22C47, IRGKangXi=0445.341, RSKangXi=64.9
22C48 CJK UNIFIED IDEOGRAPH-#22C48, IRGKangXi=0445.341, RSKangXi=64.9
22C49 CJK UNIFIED IDEOGRAPH-#22C49, IRGKangXi=0445.341, RSKangXi=64.9
22C4A CJK UNIFIED IDEOGRAPH-#22C4A, IRGKangXi=0445.341, RSKangXi=64.9
22C4B CJK UNIFIED IDEOGRAPH-#22C4B, IRGKangXi=0445.341, RSKangXi=64.9
22C4C CJK UNIFIED IDEOGRAPH-#22C4C, IRGKangXi=0445.341, RSKangXi=64.9
22C4D CJK UNIFIED IDEOGRAPH-#22C4D, IRGKangXi=0445.341, RSKangXi=64.9
22C4E CJK UNIFIED IDEOGRAPH-#22C4E, IRGKangXi=0445.341, RSKangXi=64.9
22C4F CJK UNIFIED IDEOGRAPH-#22C4F, IRGKangXi=0445.341, RSKangXi=64.9
22C50 CJK UNIFIED IDEOGRAPH-#22C50, IRGKangXi=0445.341, RSKangXi=64.9
22C51 CJK UNIFIED IDEOGRAPH-#22C51, IRGKangXi=0445.341, RSKangXi=64.9, Def{(Cant.) to scratch}
22C52 CJK UNIFIED IDEOGRAPH-#22C52, IRGKangXi=0445.341, RSKangXi=64.9
22C53 CJK UNIFIED IDEOGRAPH-#22C53, IRGKangXi=0445.341, RSKangXi=64.9
22C54 CJK UNIFIED IDEOGRAPH-#22C54, IRGKangXi=0445.341, RSKangXi=64.9
22C55 CJK UNIFIED IDEOGRAPH-#22C55, IRGKangXi=0445.341, RSKangXi=64.9, Def{(Cant.) to beat, poud; to get drenched}
22C56 CJK UNIFIED IDEOGRAPH-#22C56, IRGKangXi=0445.341, RSKangXi=64.9
22C57 CJK UNIFIED IDEOGRAPH-#22C57, IRGKangXi=0445.341, RSKangXi=64.9
22C58 CJK UNIFIED IDEOGRAPH-#22C58, IRGKangXi=0445.341, RSKangXi=64.9
22C59 CJK UNIFIED IDEOGRAPH-#22C59, IRGKangXi=0445.341, RSKangXi=64.9
22C5A CJK UNIFIED IDEOGRAPH-#22C5A, IRGKangXi=0445.341, RSKangXi=64.9
22C5B CJK UNIFIED IDEOGRAPH-#22C5B, IRGKangXi=0445.341, RSKangXi=64.9
22C5C CJK UNIFIED IDEOGRAPH-#22C5C, IRGKangXi=0445.341, RSKangXi=64.9
22C5D CJK UNIFIED IDEOGRAPH-#22C5D, IRGKangXi=0445.341, RSKangXi=64.9
22C5E CJK UNIFIED IDEOGRAPH-#22C5E, IRGKangXi=0445.341, RSKangXi=64.9
22C5F CJK UNIFIED IDEOGRAPH-#22C5F, IRGKangXi=0445.390, RSKangXi=64.10, Def{to strike, flog}
22C60 CJK UNIFIED IDEOGRAPH-#22C60, IRGKangXi=0446.020, RSKangXi=64.10
22C61 CJK UNIFIED IDEOGRAPH-#22C61, IRGKangXi=0446.080, RSKangXi=64.10
22C62 CJK UNIFIED IDEOGRAPH-#22C62, IRGKangXi=0446.100, RSKangXi=64.10, Def{to select; (Cant.) a wedge of a fruit such as an orange}
22C63 CJK UNIFIED IDEOGRAPH-#22C63, IRGKangXi=0446.160, RSKangXi=64.10
22C64 CJK UNIFIED IDEOGRAPH-#22C64, IRGKangXi=0446.170, RSKangXi=64.10
22C65 CJK UNIFIED IDEOGRAPH-#22C65, IRGKangXi=0446.180, RSKangXi=64.10
22C66 CJK UNIFIED IDEOGRAPH-#22C66, IRGKangXi=0446.190, RSKangXi=64.10
22C67 CJK UNIFIED IDEOGRAPH-#22C67, IRGKangXi=0447.060, RSKangXi=64.10
22C68 CJK UNIFIED IDEOGRAPH-#22C68, IRGKangXi=0447.080, RSKangXi=64.10
22C69 CJK UNIFIED IDEOGRAPH-#22C69, IRGKangXi=0447.170, RSKangXi=64.10
22C6A CJK UNIFIED IDEOGRAPH-#22C6A, IRGKangXi=0447.200, RSKangXi=64.10
22C6B CJK UNIFIED IDEOGRAPH-#22C6B, IRGKangXi=0448.080, RSKangXi=64.10
22C6C CJK UNIFIED IDEOGRAPH-#22C6C, IRGKangXi=0448.100, RSKangXi=64.10
22C6D CJK UNIFIED IDEOGRAPH-#22C6D, IRGKangXi=0448.170, RSKangXi=64.10
22C6E CJK UNIFIED IDEOGRAPH-#22C6E, IRGKangXi=0448.180, RSKangXi=64.10
22C6F CJK UNIFIED IDEOGRAPH-#22C6F, IRGKangXi=0448.190, RSKangXi=64.10
22C70 CJK UNIFIED IDEOGRAPH-#22C70, IRGKangXi=0448.270, RSKangXi=64.10
22C71 CJK UNIFIED IDEOGRAPH-#22C71, IRGKangXi=0448.280, RSKangXi=64.10
22C72 CJK UNIFIED IDEOGRAPH-#22C72, IRGKangXi=0448.290, RSKangXi=64.10
22C73 CJK UNIFIED IDEOGRAPH-#22C73, IRGKangXi=0448.300, RSKangXi=64.10
22C74 CJK UNIFIED IDEOGRAPH-#22C74, IRGKangXi=0448.320, RSKangXi=64.10
22C75 CJK UNIFIED IDEOGRAPH-#22C75, IRGKangXi=0448.330, RSKangXi=64.10
22C76 CJK UNIFIED IDEOGRAPH-#22C76, IRGKangXi=0448.350, RSKangXi=64.10
22C77 CJK UNIFIED IDEOGRAPH-#22C77, IRGKangXi=0448.360, RSKangXi=64.10
22C78 CJK UNIFIED IDEOGRAPH-#22C78, IRGKangXi=0448.380, RSKangXi=64.10
22C79 CJK UNIFIED IDEOGRAPH-#22C79, IRGKangXi=0449.010, RSKangXi=64.10
22C7A CJK UNIFIED IDEOGRAPH-#22C7A, IRGKangXi=0449.020, RSKangXi=64.10
22C7B CJK UNIFIED IDEOGRAPH-#22C7B, IRGKangXi=0449.040, RSKangXi=64.10
22C7C CJK UNIFIED IDEOGRAPH-#22C7C, IRGKangXi=0449.050, RSKangXi=64.10
22C7D CJK UNIFIED IDEOGRAPH-#22C7D, IRGKangXi=0449.060, RSKangXi=64.10
22C7E CJK UNIFIED IDEOGRAPH-#22C7E, IRGKangXi=0449.070, RSKangXi=64.10
22C7F CJK UNIFIED IDEOGRAPH-#22C7F, IRGKangXi=0449.080, RSKangXi=64.10
22C80 CJK UNIFIED IDEOGRAPH-#22C80, IRGKangXi=0449.081, RSKangXi=64.10
22C81 CJK UNIFIED IDEOGRAPH-#22C81, IRGKangXi=0449.081
22C82 CJK UNIFIED IDEOGRAPH-#22C82, IRGKangXi=0449.081, RSKangXi=64.10
22C83 CJK UNIFIED IDEOGRAPH-#22C83, IRGKangXi=0449.081, RSKangXi=64.10
22C84 CJK UNIFIED IDEOGRAPH-#22C84, IRGKangXi=0449.081, RSKangXi=64.10
22C85 CJK UNIFIED IDEOGRAPH-#22C85, IRGKangXi=0449.081, RSKangXi=64.10
22C86 CJK UNIFIED IDEOGRAPH-#22C86, IRGKangXi=0449.081, RSKangXi=64.10
22C87 CJK UNIFIED IDEOGRAPH-#22C87, IRGKangXi=0449.081, RSKangXi=64.10
22C88 CJK UNIFIED IDEOGRAPH-#22C88, IRGKangXi=0449.081, RSKangXi=64.10, Def{to tie a knot; join or tie fast}
22C89 CJK UNIFIED IDEOGRAPH-#22C89, IRGKangXi=0449.081, RSKangXi=64.10
22C8A CJK UNIFIED IDEOGRAPH-#22C8A, IRGKangXi=0449.081, RSKangXi=64.10
22C8B CJK UNIFIED IDEOGRAPH-#22C8B, IRGKangXi=0449.081, RSKangXi=64.10
22C8C CJK UNIFIED IDEOGRAPH-#22C8C, IRGKangXi=0449.081, RSKangXi=64.10
22C8D CJK UNIFIED IDEOGRAPH-#22C8D, IRGKangXi=0449.081, RSKangXi=64.10
22C8E CJK UNIFIED IDEOGRAPH-#22C8E, IRGKangXi=0449.081, RSKangXi=64.10
22C8F CJK UNIFIED IDEOGRAPH-#22C8F, IRGKangXi=0449.081, RSKangXi=64.10
22C90 CJK UNIFIED IDEOGRAPH-#22C90, IRGKangXi=0449.081, RSKangXi=64.10
22C91 CJK UNIFIED IDEOGRAPH-#22C91, IRGKangXi=0449.081, RSKangXi=64.10
22C92 CJK UNIFIED IDEOGRAPH-#22C92, IRGKangXi=0449.081, RSKangXi=64.10
22C93 CJK UNIFIED IDEOGRAPH-#22C93, IRGKangXi=0449.081, RSKangXi=64.10
22C94 CJK UNIFIED IDEOGRAPH-#22C94, IRGKangXi=0449.081, RSKangXi=64.10
22C95 CJK UNIFIED IDEOGRAPH-#22C95, IRGKangXi=0449.081, RSKangXi=64.10
22C96 CJK UNIFIED IDEOGRAPH-#22C96, IRGKangXi=0449.081, RSKangXi=64.10
22C97 CJK UNIFIED IDEOGRAPH-#22C97, IRGKangXi=0449.081, RSKangXi=64.10
22C98 CJK UNIFIED IDEOGRAPH-#22C98, IRGKangXi=0449.081, RSKangXi=64.10
22C99 CJK UNIFIED IDEOGRAPH-#22C99, IRGKangXi=0449.081, RSKangXi=64.10
22C9A CJK UNIFIED IDEOGRAPH-#22C9A, IRGKangXi=0449.081, RSKangXi=64.10
22C9B CJK UNIFIED IDEOGRAPH-#22C9B, IRGKangXi=0449.081, RSKangXi=64.10
22C9C CJK UNIFIED IDEOGRAPH-#22C9C, IRGKangXi=0449.081, RSKangXi=64.10
22C9D CJK UNIFIED IDEOGRAPH-#22C9D, IRGKangXi=0449.081, RSKangXi=64.10
22C9E CJK UNIFIED IDEOGRAPH-#22C9E, IRGKangXi=0449.081, RSKangXi=64.10
22C9F CJK UNIFIED IDEOGRAPH-#22C9F, IRGKangXi=0449.081, RSKangXi=64.10
22CA0 CJK UNIFIED IDEOGRAPH-#22CA0, IRGKangXi=0449.081, RSKangXi=64.10
22CA1 CJK UNIFIED IDEOGRAPH-#22CA1, IRGKangXi=0449.081, RSKangXi=64.10, Def{(Cant.) to grab with the hands; and, with}
22CA2 CJK UNIFIED IDEOGRAPH-#22CA2, IRGKangXi=0449.081, RSKangXi=64.10
22CA3 CJK UNIFIED IDEOGRAPH-#22CA3, IRGKangXi=0449.081, RSKangXi=64.10
22CA4 CJK UNIFIED IDEOGRAPH-#22CA4, IRGKangXi=0449.081, RSKangXi=64.10
22CA5 CJK UNIFIED IDEOGRAPH-#22CA5, IRGKangXi=0449.081, RSKangXi=64.10
22CA6 CJK UNIFIED IDEOGRAPH-#22CA6, IRGKangXi=0449.081, RSKangXi=64.10
22CA7 CJK UNIFIED IDEOGRAPH-#22CA7, IRGKangXi=0449.081, RSKangXi=64.10
22CA8 CJK UNIFIED IDEOGRAPH-#22CA8, IRGKangXi=0449.081, RSKangXi=64.10
22CA9 CJK UNIFIED IDEOGRAPH-#22CA9, IRGKangXi=0449.081, RSKangXi=64.10, Def{(Cant.) to affix a chop or seal to a document}
22CAA CJK UNIFIED IDEOGRAPH-#22CAA, IRGKangXi=0449.081, RSKangXi=64.10
22CAB CJK UNIFIED IDEOGRAPH-#22CAB, IRGKangXi=0449.081, RSKangXi=64.10
22CAC CJK UNIFIED IDEOGRAPH-#22CAC, IRGKangXi=0449.081, RSKangXi=64.10
22CAD CJK UNIFIED IDEOGRAPH-#22CAD, IRGKangXi=0449.081, RSKangXi=64.10
22CAE CJK UNIFIED IDEOGRAPH-#22CAE, IRGKangXi=0449.081, RSKangXi=64.10
22CAF CJK UNIFIED IDEOGRAPH-#22CAF, IRGKangXi=0449.081, RSKangXi=64.10
22CB0 CJK UNIFIED IDEOGRAPH-#22CB0, IRGKangXi=0449.081, RSKangXi=64.10
22CB1 CJK UNIFIED IDEOGRAPH-#22CB1, IRGKangXi=0449.081, RSKangXi=64.10
22CB2 CJK UNIFIED IDEOGRAPH-#22CB2, IRGKangXi=0449.081, RSKangXi=64.10, Def{to shore up, put on trestles}
22CB3 CJK UNIFIED IDEOGRAPH-#22CB3, IRGKangXi=0449.100, RSKangXi=64.11
22CB4 CJK UNIFIED IDEOGRAPH-#22CB4, IRGKangXi=0449.110, RSKangXi=64.11
22CB5 CJK UNIFIED IDEOGRAPH-#22CB5, IRGKangXi=0449.170, RSKangXi=64.11, Def{(Cant.) to save up (money), to save up bit-by-bit}
22CB6 CJK UNIFIED IDEOGRAPH-#22CB6, IRGKangXi=0449.210, RSKangXi=64.11
22CB7 CJK UNIFIED IDEOGRAPH-#22CB7, IRGKangXi=0449.310, RSKangXi=64.11, Def{to search; (Cant.) to scratch}
22CB8 CJK UNIFIED IDEOGRAPH-#22CB8, IRGKangXi=0450.020, RSKangXi=64.11, Def{(Cant.) to shake violently, stir; to strip}
22CB9 CJK UNIFIED IDEOGRAPH-#22CB9, IRGKangXi=0450.030, RSKangXi=64.11
22CBA CJK UNIFIED IDEOGRAPH-#22CBA, IRGKangXi=0450.040, RSKangXi=64.11
22CBB CJK UNIFIED IDEOGRAPH-#22CBB, IRGKangXi=0450.120, RSKangXi=64.11
22CBC CJK UNIFIED IDEOGRAPH-#22CBC, IRGKangXi=0450.180, RSKangXi=64.11
22CBD CJK UNIFIED IDEOGRAPH-#22CBD, IRGKangXi=0450.250, RSKangXi=64.11
22CBE CJK UNIFIED IDEOGRAPH-#22CBE, IRGKangXi=0450.260, RSKangXi=64.11
22CBF CJK UNIFIED IDEOGRAPH-#22CBF, IRGKangXi=0450.270, RSKangXi=64.11
22CC0 CJK UNIFIED IDEOGRAPH-#22CC0, IRGKangXi=0450.300, RSKangXi=64.11
22CC1 CJK UNIFIED IDEOGRAPH-#22CC1, IRGKangXi=0451.020, RSKangXi=64.11
22CC2 CJK UNIFIED IDEOGRAPH-#22CC2, IRGKangXi=0451.050, RSKangXi=64.11, Def{(Cant.) to scoop up, ladle out}
22CC3 CJK UNIFIED IDEOGRAPH-#22CC3, IRGKangXi=0451.060, RSKangXi=64.11
22CC4 CJK UNIFIED IDEOGRAPH-#22CC4, IRGKangXi=0451.070, RSKangXi=64.11
22CC5 CJK UNIFIED IDEOGRAPH-#22CC5, IRGKangXi=0451.110, RSKangXi=64.11
22CC6 CJK UNIFIED IDEOGRAPH-#22CC6, IRGKangXi=0451.130, RSKangXi=64.11, Def{(Cant.) to shake, rattle}
22CC7 CJK UNIFIED IDEOGRAPH-#22CC7, IRGKangXi=0451.140, RSKangXi=64.11
22CC8 CJK UNIFIED IDEOGRAPH-#22CC8, IRGKangXi=0451.150, RSKangXi=64.11
22CC9 CJK UNIFIED IDEOGRAPH-#22CC9, IRGKangXi=0451.160, RSKangXi=64.11
22CCA CJK UNIFIED IDEOGRAPH-#22CCA, IRGKangXi=0451.200, RSKangXi=64.11
22CCB CJK UNIFIED IDEOGRAPH-#22CCB, IRGKangXi=0452.020, RSKangXi=64.11
22CCC CJK UNIFIED IDEOGRAPH-#22CCC, IRGKangXi=0452.070, RSKangXi=64.11
22CCD CJK UNIFIED IDEOGRAPH-#22CCD, IRGKangXi=0453.010, RSKangXi=64.11
22CCE CJK UNIFIED IDEOGRAPH-#22CCE, IRGKangXi=0453.050, RSKangXi=64.11
22CCF CJK UNIFIED IDEOGRAPH-#22CCF, IRGKangXi=0453.070, RSKangXi=64.11
22CD0 CJK UNIFIED IDEOGRAPH-#22CD0, IRGKangXi=0453.080, RSKangXi=64.11
22CD1 CJK UNIFIED IDEOGRAPH-#22CD1, IRGKangXi=0453.090, RSKangXi=64.11
22CD2 CJK UNIFIED IDEOGRAPH-#22CD2, IRGKangXi=0453.100, RSKangXi=64.11
22CD3 CJK UNIFIED IDEOGRAPH-#22CD3, IRGKangXi=0453.110, RSKangXi=64.11
22CD4 CJK UNIFIED IDEOGRAPH-#22CD4, IRGKangXi=0453.130, RSKangXi=64.11
22CD5 CJK UNIFIED IDEOGRAPH-#22CD5, IRGKangXi=0453.140, RSKangXi=64.11
22CD6 CJK UNIFIED IDEOGRAPH-#22CD6, IRGKangXi=0453.150, RSKangXi=64.11
22CD7 CJK UNIFIED IDEOGRAPH-#22CD7, IRGKangXi=0453.160, RSKangXi=64.11
22CD8 CJK UNIFIED IDEOGRAPH-#22CD8, IRGKangXi=0453.170, RSKangXi=64.11
22CD9 CJK UNIFIED IDEOGRAPH-#22CD9, IRGKangXi=0453.180, RSKangXi=64.11
22CDA CJK UNIFIED IDEOGRAPH-#22CDA, IRGKangXi=0453.190, RSKangXi=64.11
22CDB CJK UNIFIED IDEOGRAPH-#22CDB, IRGKangXi=0453.191, RSKangXi=64.11
22CDC CJK UNIFIED IDEOGRAPH-#22CDC, IRGKangXi=0453.191, RSKangXi=64.11, Def{to waste}
22CDD CJK UNIFIED IDEOGRAPH-#22CDD, IRGKangXi=0453.191, RSKangXi=64.11
22CDE CJK UNIFIED IDEOGRAPH-#22CDE, IRGKangXi=0453.191, RSKangXi=64.11
22CDF CJK UNIFIED IDEOGRAPH-#22CDF, IRGKangXi=0453.191, RSKangXi=64.11
22CE0 CJK UNIFIED IDEOGRAPH-#22CE0, IRGKangXi=0453.191, RSKangXi=64.11
22CE1 CJK UNIFIED IDEOGRAPH-#22CE1, IRGKangXi=0453.191, RSKangXi=64.11
22CE2 CJK UNIFIED IDEOGRAPH-#22CE2, IRGKangXi=0453.191, RSKangXi=64.11
22CE3 CJK UNIFIED IDEOGRAPH-#22CE3, IRGKangXi=0453.191, RSKangXi=64.11
22CE4 CJK UNIFIED IDEOGRAPH-#22CE4, IRGKangXi=0453.191, RSKangXi=64.11
22CE5 CJK UNIFIED IDEOGRAPH-#22CE5, IRGKangXi=0453.191, RSKangXi=64.11
22CE6 CJK UNIFIED IDEOGRAPH-#22CE6, IRGKangXi=0453.191, RSKangXi=64.11
22CE7 CJK UNIFIED IDEOGRAPH-#22CE7, IRGKangXi=0453.191, RSKangXi=64.11
22CE8 CJK UNIFIED IDEOGRAPH-#22CE8, IRGKangXi=0453.191, RSKangXi=64.11
22CE9 CJK UNIFIED IDEOGRAPH-#22CE9, IRGKangXi=0453.191, RSKangXi=64.11
22CEA CJK UNIFIED IDEOGRAPH-#22CEA, IRGKangXi=0453.191, RSKangXi=64.11
22CEB CJK UNIFIED IDEOGRAPH-#22CEB, IRGKangXi=0453.191, RSKangXi=64.11
22CEC CJK UNIFIED IDEOGRAPH-#22CEC, IRGKangXi=0453.191, RSKangXi=64.11
22CED CJK UNIFIED IDEOGRAPH-#22CED, IRGKangXi=0453.191, RSKangXi=64.11
22CEE CJK UNIFIED IDEOGRAPH-#22CEE, IRGKangXi=0453.191, RSKangXi=64.11
22CEF CJK UNIFIED IDEOGRAPH-#22CEF, IRGKangXi=0453.191, RSKangXi=64.11
22CF0 CJK UNIFIED IDEOGRAPH-#22CF0, IRGKangXi=0453.191, RSKangXi=64.11
22CF1 CJK UNIFIED IDEOGRAPH-#22CF1, IRGKangXi=0453.191, RSKangXi=64.11
22CF2 CJK UNIFIED IDEOGRAPH-#22CF2, IRGKangXi=0453.191, RSKangXi=64.11
22CF3 CJK UNIFIED IDEOGRAPH-#22CF3, IRGKangXi=0453.191, RSKangXi=64.11
22CF4 CJK UNIFIED IDEOGRAPH-#22CF4, IRGKangXi=0453.191, RSKangXi=64.11
22CF5 CJK UNIFIED IDEOGRAPH-#22CF5, IRGKangXi=0453.191, RSKangXi=64.11
22CF6 CJK UNIFIED IDEOGRAPH-#22CF6, IRGKangXi=0453.191, RSKangXi=64.11
22CF7 CJK UNIFIED IDEOGRAPH-#22CF7, IRGKangXi=0453.191, RSKangXi=64.11
22CF8 CJK UNIFIED IDEOGRAPH-#22CF8, IRGKangXi=0453.191, RSKangXi=64.11
22CF9 CJK UNIFIED IDEOGRAPH-#22CF9, IRGKangXi=0453.191, RSKangXi=64.11
22CFA CJK UNIFIED IDEOGRAPH-#22CFA, IRGKangXi=0453.191, RSKangXi=64.11
22CFB CJK UNIFIED IDEOGRAPH-#22CFB, IRGKangXi=0453.191, RSKangXi=64.11
22CFC CJK UNIFIED IDEOGRAPH-#22CFC, IRGKangXi=0453.191, RSKangXi=64.11
22CFD CJK UNIFIED IDEOGRAPH-#22CFD, IRGKangXi=0453.191, RSKangXi=64.11
22CFE CJK UNIFIED IDEOGRAPH-#22CFE, IRGKangXi=0453.191, RSKangXi=64.11
22CFF CJK UNIFIED IDEOGRAPH-#22CFF, IRGKangXi=0453.191, RSKangXi=64.11
22D00 CJK UNIFIED IDEOGRAPH-#22D00, IRGKangXi=0453.191, RSKangXi=64.11
22D01 CJK UNIFIED IDEOGRAPH-#22D01, IRGKangXi=0453.191, RSKangXi=64.11
22D02 CJK UNIFIED IDEOGRAPH-#22D02, IRGKangXi=0453.191, RSKangXi=64.11
22D03 CJK UNIFIED IDEOGRAPH-#22D03, IRGKangXi=0453.191, RSKangXi=64.11
22D04 CJK UNIFIED IDEOGRAPH-#22D04, IRGKangXi=0453.191, RSKangXi=64.11
22D05 CJK UNIFIED IDEOGRAPH-#22D05, IRGKangXi=0453.191, RSKangXi=64.11
22D06 CJK UNIFIED IDEOGRAPH-#22D06, IRGKangXi=0453.191, RSKangXi=64.11
22D07 CJK UNIFIED IDEOGRAPH-#22D07, IRGKangXi=0453.191, RSKangXi=64.11
22D08 CJK UNIFIED IDEOGRAPH-#22D08, IRGKangXi=0453.191, RSKangXi=64.11, Def{(Cant.) to throw down, fall down}
22D09 CJK UNIFIED IDEOGRAPH-#22D09, IRGKangXi=0453.191, RSKangXi=64.11
22D0A CJK UNIFIED IDEOGRAPH-#22D0A, IRGKangXi=0453.191, RSKangXi=64.11
22D0B CJK UNIFIED IDEOGRAPH-#22D0B, IRGKangXi=0453.191, RSKangXi=64.11
22D0C CJK UNIFIED IDEOGRAPH-#22D0C, IRGKangXi=0453.191, RSKangXi=64.11
22D0D CJK UNIFIED IDEOGRAPH-#22D0D, IRGKangXi=0453.191, RSKangXi=64.11
22D0E CJK UNIFIED IDEOGRAPH-#22D0E, IRGKangXi=0453.191, RSKangXi=64.11
22D0F CJK UNIFIED IDEOGRAPH-#22D0F, IRGKangXi=0453.191, RSKangXi=64.11
22D10 CJK UNIFIED IDEOGRAPH-#22D10, IRGKangXi=0453.191, RSKangXi=64.11
22D11 CJK UNIFIED IDEOGRAPH-#22D11, IRGKangXi=0453.191, RSKangXi=64.11
22D12 CJK UNIFIED IDEOGRAPH-#22D12, IRGKangXi=0453.191, RSKangXi=64.11, Def{(Cant.) to chase, drive away}
22D13 CJK UNIFIED IDEOGRAPH-#22D13, IRGKangXi=0453.191, RSKangXi=64.11
22D14 CJK UNIFIED IDEOGRAPH-#22D14, IRGKangXi=0453.191, RSKangXi=64.11
22D15 CJK UNIFIED IDEOGRAPH-#22D15, IRGKangXi=0453.191, RSKangXi=64.11
22D16 CJK UNIFIED IDEOGRAPH-#22D16, IRGKangXi=0453.191, RSKangXi=64.11
22D17 CJK UNIFIED IDEOGRAPH-#22D17, IRGKangXi=0453.191, RSKangXi=64.11
22D18 CJK UNIFIED IDEOGRAPH-#22D18, IRGKangXi=0453.191, RSKangXi=64.11
22D19 CJK UNIFIED IDEOGRAPH-#22D19, IRGKangXi=0453.191, RSKangXi=64.11
22D1A CJK UNIFIED IDEOGRAPH-#22D1A, IRGKangXi=0453.191, RSKangXi=64.11
22D1B CJK UNIFIED IDEOGRAPH-#22D1B, IRGKangXi=0453.191, RSKangXi=64.11
22D1C CJK UNIFIED IDEOGRAPH-#22D1C, IRGKangXi=0453.191, RSKangXi=64.11
22D1D CJK UNIFIED IDEOGRAPH-#22D1D, IRGKangXi=0453.191, RSKangXi=64.11
22D1E CJK UNIFIED IDEOGRAPH-#22D1E, IRGKangXi=0453.191, RSKangXi=64.11
22D1F CJK UNIFIED IDEOGRAPH-#22D1F, IRGKangXi=0453.191, RSKangXi=64.11
22D20 CJK UNIFIED IDEOGRAPH-#22D20, IRGKangXi=0453.250, RSKangXi=64.12
22D21 CJK UNIFIED IDEOGRAPH-#22D21, IRGKangXi=0453.280, RSKangXi=64.12
22D22 CJK UNIFIED IDEOGRAPH-#22D22, IRGKangXi=0453.300, RSKangXi=64.12
22D23 CJK UNIFIED IDEOGRAPH-#22D23, IRGKangXi=0453.320, RSKangXi=64.12
22D24 CJK UNIFIED IDEOGRAPH-#22D24, IRGKangXi=0454.020, RSKangXi=64.12
22D25 CJK UNIFIED IDEOGRAPH-#22D25, IRGKangXi=0454.060, RSKangXi=64.12
22D26 CJK UNIFIED IDEOGRAPH-#22D26, IRGKangXi=0454.110, RSKangXi=64.12
22D27 CJK UNIFIED IDEOGRAPH-#22D27, IRGKangXi=0454.160, RSKangXi=64.12
22D28 CJK UNIFIED IDEOGRAPH-#22D28, IRGKangXi=0454.170, RSKangXi=64.12
22D29 CJK UNIFIED IDEOGRAPH-#22D29, IRGKangXi=0454.180, RSKangXi=64.12
22D2A CJK UNIFIED IDEOGRAPH-#22D2A, IRGKangXi=0455.020, RSKangXi=64.12
22D2B CJK UNIFIED IDEOGRAPH-#22D2B, IRGKangXi=0455.050, RSKangXi=64.12
22D2C CJK UNIFIED IDEOGRAPH-#22D2C, IRGKangXi=0455.060, RSKangXi=64.12
22D2D CJK UNIFIED IDEOGRAPH-#22D2D, IRGKangXi=0455.140, RSKangXi=64.12
22D2E CJK UNIFIED IDEOGRAPH-#22D2E, IRGKangXi=0455.170, RSKangXi=64.12
22D2F CJK UNIFIED IDEOGRAPH-#22D2F, IRGKangXi=0455.180, RSKangXi=64.12
22D30 CJK UNIFIED IDEOGRAPH-#22D30, IRGKangXi=0456.010, RSKangXi=64.12
22D31 CJK UNIFIED IDEOGRAPH-#22D31, IRGKangXi=0456.030, RSKangXi=64.12
22D32 CJK UNIFIED IDEOGRAPH-#22D32, IRGKangXi=0456.050, RSKangXi=64.12
22D33 CJK UNIFIED IDEOGRAPH-#22D33, IRGKangXi=0456.120, RSKangXi=64.12
22D34 CJK UNIFIED IDEOGRAPH-#22D34, IRGKangXi=0456.130, RSKangXi=64.12
22D35 CJK UNIFIED IDEOGRAPH-#22D35, IRGKangXi=0456.190, RSKangXi=64.12
22D36 CJK UNIFIED IDEOGRAPH-#22D36, IRGKangXi=0456.210, RSKangXi=64.12
22D37 CJK UNIFIED IDEOGRAPH-#22D37, IRGKangXi=0457.030, RSKangXi=64.12
22D38 CJK UNIFIED IDEOGRAPH-#22D38, IRGKangXi=0457.040, RSKangXi=64.12
22D39 CJK UNIFIED IDEOGRAPH-#22D39, IRGKangXi=0457.050, RSKangXi=64.12
22D3A CJK UNIFIED IDEOGRAPH-#22D3A, IRGKangXi=0457.060, RSKangXi=64.12
22D3B CJK UNIFIED IDEOGRAPH-#22D3B, IRGKangXi=0457.070, RSKangXi=64.12
22D3C CJK UNIFIED IDEOGRAPH-#22D3C, IRGKangXi=0457.080, RSKangXi=64.12
22D3D CJK UNIFIED IDEOGRAPH-#22D3D, IRGKangXi=0457.090, RSKangXi=64.12
22D3E CJK UNIFIED IDEOGRAPH-#22D3E, IRGKangXi=0457.100, RSKangXi=64.12
22D3F CJK UNIFIED IDEOGRAPH-#22D3F, IRGKangXi=0457.110, RSKangXi=64.12
22D40 CJK UNIFIED IDEOGRAPH-#22D40, IRGKangXi=0457.120, RSKangXi=64.12
22D41 CJK UNIFIED IDEOGRAPH-#22D41, IRGKangXi=0457.130, RSKangXi=64.12
22D42 CJK UNIFIED IDEOGRAPH-#22D42, IRGKangXi=0457.140, RSKangXi=64.12
22D43 CJK UNIFIED IDEOGRAPH-#22D43, IRGKangXi=0457.150, RSKangXi=64.12
22D44 CJK UNIFIED IDEOGRAPH-#22D44, IRGKangXi=0457.160, RSKangXi=64.12, Def{(Cant.) to save up (money)}
22D45 CJK UNIFIED IDEOGRAPH-#22D45, IRGKangXi=0457.161, RSKangXi=64.12
22D46 CJK UNIFIED IDEOGRAPH-#22D46, IRGKangXi=0457.161, RSKangXi=64.12
22D47 CJK UNIFIED IDEOGRAPH-#22D47, IRGKangXi=0457.161, RSKangXi=64.12
22D48 CJK UNIFIED IDEOGRAPH-#22D48, IRGKangXi=0457.161, RSKangXi=64.12
22D49 CJK UNIFIED IDEOGRAPH-#22D49, IRGKangXi=0457.161, RSKangXi=64.12
22D4A CJK UNIFIED IDEOGRAPH-#22D4A, IRGKangXi=0457.161, RSKangXi=64.12
22D4B CJK UNIFIED IDEOGRAPH-#22D4B, IRGKangXi=0457.161, RSKangXi=64.12
22D4C CJK UNIFIED IDEOGRAPH-#22D4C, IRGKangXi=0457.161, RSKangXi=64.12, Def{(Cant.) to goad, incite}
22D4D CJK UNIFIED IDEOGRAPH-#22D4D, IRGKangXi=0457.161, RSKangXi=64.12
22D4E CJK UNIFIED IDEOGRAPH-#22D4E, IRGKangXi=0457.161, RSKangXi=64.12
22D4F CJK UNIFIED IDEOGRAPH-#22D4F, IRGKangXi=0457.161, RSKangXi=64.12
22D50 CJK UNIFIED IDEOGRAPH-#22D50, IRGKangXi=0457.161, RSKangXi=64.12
22D51 CJK UNIFIED IDEOGRAPH-#22D51, IRGKangXi=0457.161, RSKangXi=64.12
22D52 CJK UNIFIED IDEOGRAPH-#22D52, IRGKangXi=0457.161, RSKangXi=64.12
22D53 CJK UNIFIED IDEOGRAPH-#22D53, IRGKangXi=0457.161, RSKangXi=64.12, Def{(Cant.) to rush; chase someone out, drive out}
22D54 CJK UNIFIED IDEOGRAPH-#22D54, IRGKangXi=0457.161, RSKangXi=64.12
22D55 CJK UNIFIED IDEOGRAPH-#22D55, IRGKangXi=0457.161, RSKangXi=64.12
22D56 CJK UNIFIED IDEOGRAPH-#22D56, IRGKangXi=0457.161, RSKangXi=64.12
22D57 CJK UNIFIED IDEOGRAPH-#22D57, IRGKangXi=0457.161, RSKangXi=64.12
22D58 CJK UNIFIED IDEOGRAPH-#22D58, IRGKangXi=0457.161, RSKangXi=64.12
22D59 CJK UNIFIED IDEOGRAPH-#22D59, IRGKangXi=0457.161, RSKangXi=64.12
22D5A CJK UNIFIED IDEOGRAPH-#22D5A, IRGKangXi=0457.161, RSKangXi=64.12
22D5B CJK UNIFIED IDEOGRAPH-#22D5B, IRGKangXi=0457.161, RSKangXi=64.12
22D5C CJK UNIFIED IDEOGRAPH-#22D5C, IRGKangXi=0457.161, RSKangXi=64.12
22D5D CJK UNIFIED IDEOGRAPH-#22D5D, IRGKangXi=0457.161, RSKangXi=64.12
22D5E CJK UNIFIED IDEOGRAPH-#22D5E, IRGKangXi=0457.161, RSKangXi=64.12
22D5F CJK UNIFIED IDEOGRAPH-#22D5F, IRGKangXi=0457.161, RSKangXi=64.12
22D60 CJK UNIFIED IDEOGRAPH-#22D60, IRGKangXi=0457.161, RSKangXi=64.12
22D61 CJK UNIFIED IDEOGRAPH-#22D61, IRGKangXi=0457.161, RSKangXi=64.12
22D62 CJK UNIFIED IDEOGRAPH-#22D62, IRGKangXi=0457.161, RSKangXi=64.12
22D63 CJK UNIFIED IDEOGRAPH-#22D63, IRGKangXi=0457.161, RSKangXi=64.12
22D64 CJK UNIFIED IDEOGRAPH-#22D64, IRGKangXi=0457.161, RSKangXi=64.12
22D65 CJK UNIFIED IDEOGRAPH-#22D65, IRGKangXi=0457.161, RSKangXi=64.12
22D66 CJK UNIFIED IDEOGRAPH-#22D66, IRGKangXi=0457.161, RSKangXi=64.12
22D67 CJK UNIFIED IDEOGRAPH-#22D67, IRGKangXi=0457.161, RSKangXi=64.12, Def{(Cant.) to draw lines}
22D68 CJK UNIFIED IDEOGRAPH-#22D68, IRGKangXi=0457.161, RSKangXi=64.12
22D69 CJK UNIFIED IDEOGRAPH-#22D69, IRGKangXi=0457.161, RSKangXi=64.12
22D6A CJK UNIFIED IDEOGRAPH-#22D6A, IRGKangXi=0457.161, RSKangXi=64.12
22D6B CJK UNIFIED IDEOGRAPH-#22D6B, IRGKangXi=0457.161, RSKangXi=64.12
22D6C CJK UNIFIED IDEOGRAPH-#22D6C, IRGKangXi=0457.161, RSKangXi=64.12
22D6D CJK UNIFIED IDEOGRAPH-#22D6D, IRGKangXi=0457.161, RSKangXi=64.12
22D6E CJK UNIFIED IDEOGRAPH-#22D6E, IRGKangXi=0457.161, RSKangXi=64.12
22D6F CJK UNIFIED IDEOGRAPH-#22D6F, IRGKangXi=0457.161, RSKangXi=64.12
22D70 CJK UNIFIED IDEOGRAPH-#22D70, IRGKangXi=0457.161, RSKangXi=64.12
22D71 CJK UNIFIED IDEOGRAPH-#22D71, IRGKangXi=0457.161, RSKangXi=64.12
22D72 CJK UNIFIED IDEOGRAPH-#22D72, IRGKangXi=0457.161, RSKangXi=64.12
22D73 CJK UNIFIED IDEOGRAPH-#22D73, IRGKangXi=0457.161, RSKangXi=64.12
22D74 CJK UNIFIED IDEOGRAPH-#22D74, IRGKangXi=0457.161, RSKangXi=64.12
22D75 CJK UNIFIED IDEOGRAPH-#22D75, IRGKangXi=0457.161, RSKangXi=64.12
22D76 CJK UNIFIED IDEOGRAPH-#22D76, IRGKangXi=0457.161, RSKangXi=64.12
22D77 CJK UNIFIED IDEOGRAPH-#22D77, IRGKangXi=0457.161, RSKangXi=64.12
22D78 CJK UNIFIED IDEOGRAPH-#22D78, IRGKangXi=0457.161, RSKangXi=64.12
22D79 CJK UNIFIED IDEOGRAPH-#22D79, IRGKangXi=0457.161, RSKangXi=64.12
22D7A CJK UNIFIED IDEOGRAPH-#22D7A, IRGKangXi=0457.161, RSKangXi=64.12
22D7B CJK UNIFIED IDEOGRAPH-#22D7B, IRGKangXi=0457.161, RSKangXi=64.12
22D7C CJK UNIFIED IDEOGRAPH-#22D7C, IRGKangXi=0457.161, RSKangXi=64.12
22D7D CJK UNIFIED IDEOGRAPH-#22D7D, IRGKangXi=0457.161, RSKangXi=64.12
22D7E CJK UNIFIED IDEOGRAPH-#22D7E, IRGKangXi=0457.161, RSKangXi=64.12
22D7F CJK UNIFIED IDEOGRAPH-#22D7F, IRGKangXi=0457.220, RSKangXi=64.13
22D80 CJK UNIFIED IDEOGRAPH-#22D80, IRGKangXi=0457.290, RSKangXi=64.13
22D81 CJK UNIFIED IDEOGRAPH-#22D81, IRGKangXi=0457.320, RSKangXi=64.13
22D82 CJK UNIFIED IDEOGRAPH-#22D82, IRGKangXi=0457.330, RSKangXi=64.13
22D83 CJK UNIFIED IDEOGRAPH-#22D83, IRGKangXi=0458.010, RSKangXi=64.13
22D84 CJK UNIFIED IDEOGRAPH-#22D84, IRGKangXi=0458.020, RSKangXi=64.13
22D85 CJK UNIFIED IDEOGRAPH-#22D85, IRGKangXi=0458.070, RSKangXi=64.13, Def{to divine; to fold}
22D86 CJK UNIFIED IDEOGRAPH-#22D86, IRGKangXi=0458.130, RSKangXi=64.13
22D87 CJK UNIFIED IDEOGRAPH-#22D87, IRGKangXi=0458.140, RSKangXi=64.13
22D88 CJK UNIFIED IDEOGRAPH-#22D88, IRGKangXi=0458.160, RSKangXi=64.13
22D89 CJK UNIFIED IDEOGRAPH-#22D89, IRGKangXi=0458.190, RSKangXi=64.13
22D8A CJK UNIFIED IDEOGRAPH-#22D8A, IRGKangXi=0458.200, RSKangXi=64.13
22D8B CJK UNIFIED IDEOGRAPH-#22D8B, IRGKangXi=0458.210, RSKangXi=64.13
22D8C CJK UNIFIED IDEOGRAPH-#22D8C, IRGKangXi=0458.230, RSKangXi=64.13
22D8D CJK UNIFIED IDEOGRAPH-#22D8D, IRGKangXi=0458.260, RSKangXi=64.13, Def{(Cant.) garbage}
22D8E CJK UNIFIED IDEOGRAPH-#22D8E, IRGKangXi=0458.280, RSKangXi=64.13
22D8F CJK UNIFIED IDEOGRAPH-#22D8F, IRGKangXi=0458.290, RSKangXi=64.13
22D90 CJK UNIFIED IDEOGRAPH-#22D90, IRGKangXi=0458.300, RSKangXi=64.13
22D91 CJK UNIFIED IDEOGRAPH-#22D91, IRGKangXi=0458.310, RSKangXi=64.13, Def{(same as U+22E23 𢸣) to select, pick}
22D92 CJK UNIFIED IDEOGRAPH-#22D92, IRGKangXi=0458.330, RSKangXi=64.13
22D93 CJK UNIFIED IDEOGRAPH-#22D93, IRGKangXi=0458.350, RSKangXi=64.13
22D94 CJK UNIFIED IDEOGRAPH-#22D94, IRGKangXi=0459.020, RSKangXi=64.13
22D95 CJK UNIFIED IDEOGRAPH-#22D95, IRGKangXi=0459.050, RSKangXi=64.13
22D96 CJK UNIFIED IDEOGRAPH-#22D96, IRGKangXi=0459.090, RSKangXi=64.13
22D97 CJK UNIFIED IDEOGRAPH-#22D97, IRGKangXi=0459.130, RSKangXi=64.13
22D98 CJK UNIFIED IDEOGRAPH-#22D98, IRGKangXi=0459.140, RSKangXi=64.13
22D99 CJK UNIFIED IDEOGRAPH-#22D99, IRGKangXi=0459.150, RSKangXi=64.13
22D9A CJK UNIFIED IDEOGRAPH-#22D9A, IRGKangXi=0459.170, RSKangXi=64.13
22D9B CJK UNIFIED IDEOGRAPH-#22D9B, IRGKangXi=0459.180, RSKangXi=64.13
22D9C CJK UNIFIED IDEOGRAPH-#22D9C, IRGKangXi=0459.190, RSKangXi=64.13, Def{(Cant.) to push; pull open}
22D9D CJK UNIFIED IDEOGRAPH-#22D9D, IRGKangXi=0459.200, RSKangXi=64.13
22D9E CJK UNIFIED IDEOGRAPH-#22D9E, IRGKangXi=0459.201, RSKangXi=64.13
22D9F CJK UNIFIED IDEOGRAPH-#22D9F, IRGKangXi=0459.201, RSKangXi=64.13
22DA0 CJK UNIFIED IDEOGRAPH-#22DA0, IRGKangXi=0459.201, RSKangXi=64.13, Def{(Cant.) to take without asking}
22DA1 CJK UNIFIED IDEOGRAPH-#22DA1, IRGKangXi=0459.201, RSKangXi=64.13
22DA2 CJK UNIFIED IDEOGRAPH-#22DA2, IRGKangXi=0459.201, RSKangXi=64.13
22DA3 CJK UNIFIED IDEOGRAPH-#22DA3, IRGKangXi=0459.201, RSKangXi=64.13, Def{to fold, double}
22DA4 CJK UNIFIED IDEOGRAPH-#22DA4, IRGKangXi=0459.201, RSKangXi=64.13, Def{(Cant.) to pester, nag; to wallow; to roll around on the floor}
22DA5 CJK UNIFIED IDEOGRAPH-#22DA5, IRGKangXi=0459.201, RSKangXi=64.13
22DA6 CJK UNIFIED IDEOGRAPH-#22DA6, IRGKangXi=0459.201, RSKangXi=64.13
22DA7 CJK UNIFIED IDEOGRAPH-#22DA7, IRGKangXi=0459.201, RSKangXi=64.13
22DA8 CJK UNIFIED IDEOGRAPH-#22DA8, IRGKangXi=0459.201, RSKangXi=64.13
22DA9 CJK UNIFIED IDEOGRAPH-#22DA9, IRGKangXi=0459.201, RSKangXi=64.13
22DAA CJK UNIFIED IDEOGRAPH-#22DAA, IRGKangXi=0459.201, RSKangXi=64.13
22DAB CJK UNIFIED IDEOGRAPH-#22DAB, IRGKangXi=0459.201, RSKangXi=64.13
22DAC CJK UNIFIED IDEOGRAPH-#22DAC, IRGKangXi=0459.201, RSKangXi=64.13
22DAD CJK UNIFIED IDEOGRAPH-#22DAD, IRGKangXi=0459.201, RSKangXi=64.13
22DAE CJK UNIFIED IDEOGRAPH-#22DAE, IRGKangXi=0459.201, RSKangXi=64.13
22DAF CJK UNIFIED IDEOGRAPH-#22DAF, IRGKangXi=0459.201, RSKangXi=64.13, Def{(Cant.) to pull, turn}
22DB0 CJK UNIFIED IDEOGRAPH-#22DB0, IRGKangXi=0459.201, RSKangXi=64.13
22DB1 CJK UNIFIED IDEOGRAPH-#22DB1, IRGKangXi=0459.201, RSKangXi=64.13
22DB2 CJK UNIFIED IDEOGRAPH-#22DB2, IRGKangXi=0459.201, RSKangXi=64.13
22DB3 CJK UNIFIED IDEOGRAPH-#22DB3, IRGKangXi=0459.201, RSKangXi=64.13
22DB4 CJK UNIFIED IDEOGRAPH-#22DB4, IRGKangXi=0459.201, RSKangXi=64.13
22DB5 CJK UNIFIED IDEOGRAPH-#22DB5, IRGKangXi=0459.201, RSKangXi=64.13
22DB6 CJK UNIFIED IDEOGRAPH-#22DB6, IRGKangXi=0459.201, RSKangXi=64.13
22DB7 CJK UNIFIED IDEOGRAPH-#22DB7, IRGKangXi=0459.201, RSKangXi=64.13
22DB8 CJK UNIFIED IDEOGRAPH-#22DB8, IRGKangXi=0459.201, RSKangXi=64.13
22DB9 CJK UNIFIED IDEOGRAPH-#22DB9, IRGKangXi=0459.201, RSKangXi=64.13
22DBA CJK UNIFIED IDEOGRAPH-#22DBA, IRGKangXi=0459.201, RSKangXi=64.13
22DBB CJK UNIFIED IDEOGRAPH-#22DBB, IRGKangXi=0459.201, RSKangXi=64.13
22DBC CJK UNIFIED IDEOGRAPH-#22DBC, IRGKangXi=0459.201, RSKangXi=64.13
22DBD CJK UNIFIED IDEOGRAPH-#22DBD, IRGKangXi=0459.201, RSKangXi=64.13
22DBE CJK UNIFIED IDEOGRAPH-#22DBE, IRGKangXi=0459.201, RSKangXi=64.13
22DBF CJK UNIFIED IDEOGRAPH-#22DBF, IRGKangXi=0459.201, RSKangXi=64.13
22DC0 CJK UNIFIED IDEOGRAPH-#22DC0, IRGKangXi=0459.201, RSKangXi=64.13
22DC1 CJK UNIFIED IDEOGRAPH-#22DC1, IRGKangXi=0459.201, RSKangXi=64.13
22DC2 CJK UNIFIED IDEOGRAPH-#22DC2, IRGKangXi=0459.201, RSKangXi=64.13
22DC3 CJK UNIFIED IDEOGRAPH-#22DC3, IRGKangXi=0459.201, RSKangXi=64.13
22DC4 CJK UNIFIED IDEOGRAPH-#22DC4, IRGKangXi=0459.201, RSKangXi=64.13
22DC5 CJK UNIFIED IDEOGRAPH-#22DC5, IRGKangXi=0459.201, RSKangXi=64.12
22DC6 CJK UNIFIED IDEOGRAPH-#22DC6, IRGKangXi=0459.201, RSKangXi=64.13
22DC7 CJK UNIFIED IDEOGRAPH-#22DC7, IRGKangXi=0459.201, RSKangXi=64.13
22DC8 CJK UNIFIED IDEOGRAPH-#22DC8, IRGKangXi=0459.201, RSKangXi=64.13
22DC9 CJK UNIFIED IDEOGRAPH-#22DC9, IRGKangXi=0459.201, RSKangXi=64.13
22DCA CJK UNIFIED IDEOGRAPH-#22DCA, IRGKangXi=0459.201, RSKangXi=64.13
22DCB CJK UNIFIED IDEOGRAPH-#22DCB, IRGKangXi=0459.240, RSKangXi=64.14
22DCC CJK UNIFIED IDEOGRAPH-#22DCC, IRGKangXi=0459.250, RSKangXi=64.14
22DCD CJK UNIFIED IDEOGRAPH-#22DCD, IRGKangXi=0460.020, RSKangXi=64.14
22DCE CJK UNIFIED IDEOGRAPH-#22DCE, IRGKangXi=0460.030, RSKangXi=64.14
22DCF CJK UNIFIED IDEOGRAPH-#22DCF, IRGKangXi=0460.080, RSKangXi=64.14
22DD0 CJK UNIFIED IDEOGRAPH-#22DD0, IRGKangXi=0460.110, RSKangXi=64.14
22DD1 CJK UNIFIED IDEOGRAPH-#22DD1, IRGKangXi=0460.160, RSKangXi=64.14
22DD2 CJK UNIFIED IDEOGRAPH-#22DD2, IRGKangXi=0460.180, RSKangXi=64.14
22DD3 CJK UNIFIED IDEOGRAPH-#22DD3, IRGKangXi=0460.200, RSKangXi=64.14
22DD4 CJK UNIFIED IDEOGRAPH-#22DD4, IRGKangXi=0460.210, RSKangXi=64.14
22DD5 CJK UNIFIED IDEOGRAPH-#22DD5, IRGKangXi=0460.220, RSKangXi=64.14
22DD6 CJK UNIFIED IDEOGRAPH-#22DD6, IRGKangXi=0460.240, RSKangXi=64.14
22DD7 CJK UNIFIED IDEOGRAPH-#22DD7, IRGKangXi=0460.250, RSKangXi=64.14
22DD8 CJK UNIFIED IDEOGRAPH-#22DD8, IRGKangXi=0460.280, RSKangXi=64.14
22DD9 CJK UNIFIED IDEOGRAPH-#22DD9, IRGKangXi=0460.290, RSKangXi=64.14
22DDA CJK UNIFIED IDEOGRAPH-#22DDA, IRGKangXi=0460.310, RSKangXi=64.14
22DDB CJK UNIFIED IDEOGRAPH-#22DDB, IRGKangXi=0460.320, RSKangXi=64.14
22DDC CJK UNIFIED IDEOGRAPH-#22DDC, IRGKangXi=0460.330, RSKangXi=64.14
22DDD CJK UNIFIED IDEOGRAPH-#22DDD, IRGKangXi=0461.010, RSKangXi=64.14
22DDE CJK UNIFIED IDEOGRAPH-#22DDE, IRGKangXi=0461.011, RSKangXi=64.14
22DDF CJK UNIFIED IDEOGRAPH-#22DDF, IRGKangXi=0461.011, RSKangXi=64.14
22DE0 CJK UNIFIED IDEOGRAPH-#22DE0, IRGKangXi=0461.011, RSKangXi=64.14
22DE1 CJK UNIFIED IDEOGRAPH-#22DE1, IRGKangXi=0461.011, RSKangXi=64.14
22DE2 CJK UNIFIED IDEOGRAPH-#22DE2, IRGKangXi=0461.011, RSKangXi=64.14
22DE3 CJK UNIFIED IDEOGRAPH-#22DE3, IRGKangXi=0461.011, RSKangXi=64.14
22DE4 CJK UNIFIED IDEOGRAPH-#22DE4, IRGKangXi=0461.011, RSKangXi=64.14, Def{to expel, reject}
22DE5 CJK UNIFIED IDEOGRAPH-#22DE5, IRGKangXi=0461.011, RSKangXi=64.14
22DE6 CJK UNIFIED IDEOGRAPH-#22DE6, IRGKangXi=0461.011, RSKangXi=64.14
22DE7 CJK UNIFIED IDEOGRAPH-#22DE7, IRGKangXi=0461.011, RSKangXi=64.14
22DE8 CJK UNIFIED IDEOGRAPH-#22DE8, IRGKangXi=0461.011, RSKangXi=64.14
22DE9 CJK UNIFIED IDEOGRAPH-#22DE9, IRGKangXi=0461.011, RSKangXi=64.14
22DEA CJK UNIFIED IDEOGRAPH-#22DEA, IRGKangXi=0461.011, RSKangXi=64.14
22DEB CJK UNIFIED IDEOGRAPH-#22DEB, IRGKangXi=0461.011, RSKangXi=64.14
22DEC CJK UNIFIED IDEOGRAPH-#22DEC, IRGKangXi=0461.011, RSKangXi=64.14
22DED CJK UNIFIED IDEOGRAPH-#22DED, IRGKangXi=0461.011, RSKangXi=64.14
22DEE CJK UNIFIED IDEOGRAPH-#22DEE, IRGKangXi=0461.011, RSKangXi=64.14, Def{(Cant.) to poke, nudge; stretch out}
22DEF CJK UNIFIED IDEOGRAPH-#22DEF, IRGKangXi=0461.011, RSKangXi=64.14
22DF0 CJK UNIFIED IDEOGRAPH-#22DF0, IRGKangXi=0461.011, RSKangXi=64.14
22DF1 CJK UNIFIED IDEOGRAPH-#22DF1, IRGKangXi=0461.011, RSKangXi=64.14
22DF2 CJK UNIFIED IDEOGRAPH-#22DF2, IRGKangXi=0461.011, RSKangXi=64.14
22DF3 CJK UNIFIED IDEOGRAPH-#22DF3, IRGKangXi=0461.011, RSKangXi=64.14
22DF4 CJK UNIFIED IDEOGRAPH-#22DF4, IRGKangXi=0461.011, RSKangXi=64.14
22DF5 CJK UNIFIED IDEOGRAPH-#22DF5, IRGKangXi=0461.011, RSKangXi=64.14
22DF6 CJK UNIFIED IDEOGRAPH-#22DF6, IRGKangXi=0461.050, RSKangXi=64.15
22DF7 CJK UNIFIED IDEOGRAPH-#22DF7, IRGKangXi=0461.080, RSKangXi=64.15
22DF8 CJK UNIFIED IDEOGRAPH-#22DF8, IRGKangXi=0461.130, RSKangXi=64.15
22DF9 CJK UNIFIED IDEOGRAPH-#22DF9, IRGKangXi=0461.150, RSKangXi=64.15
22DFA CJK UNIFIED IDEOGRAPH-#22DFA, IRGKangXi=0461.180, RSKangXi=64.15
22DFB CJK UNIFIED IDEOGRAPH-#22DFB, IRGKangXi=0461.220, RSKangXi=64.15
22DFC CJK UNIFIED IDEOGRAPH-#22DFC, IRGKangXi=0461.240, RSKangXi=64.15
22DFD CJK UNIFIED IDEOGRAPH-#22DFD, IRGKangXi=0461.260, RSKangXi=64.15
22DFE CJK UNIFIED IDEOGRAPH-#22DFE, IRGKangXi=0461.290, RSKangXi=64.15
22DFF CJK UNIFIED IDEOGRAPH-#22DFF, IRGKangXi=0461.310, RSKangXi=64.15
22E00 CJK UNIFIED IDEOGRAPH-#22E00, IRGKangXi=0461.330, RSKangXi=64.15
22E01 CJK UNIFIED IDEOGRAPH-#22E01, IRGKangXi=0462.050, RSKangXi=64.15
22E02 CJK UNIFIED IDEOGRAPH-#22E02, IRGKangXi=0462.080, RSKangXi=64.15
22E03 CJK UNIFIED IDEOGRAPH-#22E03, IRGKangXi=0462.090, RSKangXi=64.15
22E04 CJK UNIFIED IDEOGRAPH-#22E04, IRGKangXi=0462.100, RSKangXi=64.15
22E05 CJK UNIFIED IDEOGRAPH-#22E05, IRGKangXi=0462.110, RSKangXi=64.15
22E06 CJK UNIFIED IDEOGRAPH-#22E06, IRGKangXi=0462.120, RSKangXi=64.15
22E07 CJK UNIFIED IDEOGRAPH-#22E07, IRGKangXi=0462.140, RSKangXi=64.15
22E08 CJK UNIFIED IDEOGRAPH-#22E08, IRGKangXi=0462.150, RSKangXi=64.15
22E09 CJK UNIFIED IDEOGRAPH-#22E09, IRGKangXi=0462.160, RSKangXi=64.15
22E0A CJK UNIFIED IDEOGRAPH-#22E0A, IRGKangXi=0462.161, RSKangXi=64.15
22E0B CJK UNIFIED IDEOGRAPH-#22E0B, IRGKangXi=0462.161, RSKangXi=64.15
22E0C CJK UNIFIED IDEOGRAPH-#22E0C, IRGKangXi=0462.161, RSKangXi=64.15
22E0D CJK UNIFIED IDEOGRAPH-#22E0D, IRGKangXi=0462.161, RSKangXi=64.15
22E0E CJK UNIFIED IDEOGRAPH-#22E0E, IRGKangXi=0462.161, RSKangXi=64.15
22E0F CJK UNIFIED IDEOGRAPH-#22E0F, IRGKangXi=0462.161, RSKangXi=64.15
22E10 CJK UNIFIED IDEOGRAPH-#22E10, IRGKangXi=0462.161, RSKangXi=64.15
22E11 CJK UNIFIED IDEOGRAPH-#22E11, IRGKangXi=0462.161, RSKangXi=64.15
22E12 CJK UNIFIED IDEOGRAPH-#22E12, IRGKangXi=0462.161, RSKangXi=64.15
22E13 CJK UNIFIED IDEOGRAPH-#22E13, IRGKangXi=0462.161, RSKangXi=64.15
22E14 CJK UNIFIED IDEOGRAPH-#22E14, IRGKangXi=0462.161, RSKangXi=64.15
22E15 CJK UNIFIED IDEOGRAPH-#22E15, IRGKangXi=0462.161, RSKangXi=64.15
22E16 CJK UNIFIED IDEOGRAPH-#22E16, IRGKangXi=0462.161, RSKangXi=64.15
22E17 CJK UNIFIED IDEOGRAPH-#22E17, IRGKangXi=0462.161, RSKangXi=64.15
22E18 CJK UNIFIED IDEOGRAPH-#22E18, IRGKangXi=0462.161, RSKangXi=64.15
22E19 CJK UNIFIED IDEOGRAPH-#22E19, IRGKangXi=0462.161, RSKangXi=64.15
22E1A CJK UNIFIED IDEOGRAPH-#22E1A, IRGKangXi=0462.161, RSKangXi=64.15
22E1B CJK UNIFIED IDEOGRAPH-#22E1B, IRGKangXi=0462.161, RSKangXi=64.15
22E1C CJK UNIFIED IDEOGRAPH-#22E1C, IRGKangXi=0462.161, RSKangXi=64.15
22E1D CJK UNIFIED IDEOGRAPH-#22E1D, IRGKangXi=0462.161, RSKangXi=64.15
22E1E CJK UNIFIED IDEOGRAPH-#22E1E, IRGKangXi=0462.161, RSKangXi=64.15
22E1F CJK UNIFIED IDEOGRAPH-#22E1F, IRGKangXi=0462.161, RSKangXi=64.15
22E20 CJK UNIFIED IDEOGRAPH-#22E20, IRGKangXi=0462.161, RSKangXi=64.15
22E21 CJK UNIFIED IDEOGRAPH-#22E21, IRGKangXi=0462.161, RSKangXi=64.15
22E22 CJK UNIFIED IDEOGRAPH-#22E22, IRGKangXi=0462.161, RSKangXi=64.15
22E23 CJK UNIFIED IDEOGRAPH-#22E23, IRGKangXi=0462.190, RSKangXi=64.16, Def{to select, pick}
22E24 CJK UNIFIED IDEOGRAPH-#22E24, IRGKangXi=0462.200, RSKangXi=64.16
22E25 CJK UNIFIED IDEOGRAPH-#22E25, IRGKangXi=0462.220, RSKangXi=64.16
22E26 CJK UNIFIED IDEOGRAPH-#22E26, IRGKangXi=0462.240, RSKangXi=64.16
22E27 CJK UNIFIED IDEOGRAPH-#22E27, IRGKangXi=0462.260, RSKangXi=64.16
22E28 CJK UNIFIED IDEOGRAPH-#22E28, IRGKangXi=0462.270, RSKangXi=64.16
22E29 CJK UNIFIED IDEOGRAPH-#22E29, IRGKangXi=0462.290, RSKangXi=64.16
22E2A CJK UNIFIED IDEOGRAPH-#22E2A, IRGKangXi=0462.300, RSKangXi=64.16
22E2B CJK UNIFIED IDEOGRAPH-#22E2B, IRGKangXi=0462.310, RSKangXi=64.16
22E2C CJK UNIFIED IDEOGRAPH-#22E2C, IRGKangXi=0462.350, RSKangXi=64.16
22E2D CJK UNIFIED IDEOGRAPH-#22E2D, IRGKangXi=0462.370, RSKangXi=64.16
22E2E CJK UNIFIED IDEOGRAPH-#22E2E, IRGKangXi=0462.400, RSKangXi=64.16
22E2F CJK UNIFIED IDEOGRAPH-#22E2F, IRGKangXi=0462.410, RSKangXi=64.16
22E30 CJK UNIFIED IDEOGRAPH-#22E30, IRGKangXi=0462.420, RSKangXi=64.16
22E31 CJK UNIFIED IDEOGRAPH-#22E31, IRGKangXi=0462.430, RSKangXi=64.16
22E32 CJK UNIFIED IDEOGRAPH-#22E32, IRGKangXi=0462.440, RSKangXi=64.16
22E33 CJK UNIFIED IDEOGRAPH-#22E33, IRGKangXi=0462.450, RSKangXi=64.16
22E34 CJK UNIFIED IDEOGRAPH-#22E34, IRGKangXi=0462.460, RSKangXi=64.16
22E35 CJK UNIFIED IDEOGRAPH-#22E35, IRGKangXi=0462.461, RSKangXi=64.16
22E36 CJK UNIFIED IDEOGRAPH-#22E36, IRGKangXi=0462.461, RSKangXi=64.16
22E37 CJK UNIFIED IDEOGRAPH-#22E37, IRGKangXi=0462.461, RSKangXi=64.16
22E38 CJK UNIFIED IDEOGRAPH-#22E38, IRGKangXi=0462.461, RSKangXi=64.16
22E39 CJK UNIFIED IDEOGRAPH-#22E39, IRGKangXi=0462.461, RSKangXi=64.16
22E3A CJK UNIFIED IDEOGRAPH-#22E3A, IRGKangXi=0462.461, RSKangXi=64.16
22E3B CJK UNIFIED IDEOGRAPH-#22E3B, IRGKangXi=0462.461, RSKangXi=64.16
22E3C CJK UNIFIED IDEOGRAPH-#22E3C, IRGKangXi=0462.461, RSKangXi=64.16
22E3D CJK UNIFIED IDEOGRAPH-#22E3D, IRGKangXi=0462.461, RSKangXi=64.16
22E3E CJK UNIFIED IDEOGRAPH-#22E3E, IRGKangXi=0462.461, RSKangXi=64.16
22E3F CJK UNIFIED IDEOGRAPH-#22E3F, IRGKangXi=0462.461, RSKangXi=64.16
22E40 CJK UNIFIED IDEOGRAPH-#22E40, IRGKangXi=0462.461, RSKangXi=64.16
22E41 CJK UNIFIED IDEOGRAPH-#22E41, IRGKangXi=0462.461, RSKangXi=64.16
22E42 CJK UNIFIED IDEOGRAPH-#22E42, IRGKangXi=0462.461, RSKangXi=64.16
22E43 CJK UNIFIED IDEOGRAPH-#22E43, IRGKangXi=0462.461, RSKangXi=64.16
22E44 CJK UNIFIED IDEOGRAPH-#22E44, IRGKangXi=0462.461, RSKangXi=64.16
22E45 CJK UNIFIED IDEOGRAPH-#22E45, IRGKangXi=0462.461, RSKangXi=64.16
22E46 CJK UNIFIED IDEOGRAPH-#22E46, IRGKangXi=0462.461, RSKangXi=64.16
22E47 CJK UNIFIED IDEOGRAPH-#22E47, IRGKangXi=0462.461, RSKangXi=64.16
22E48 CJK UNIFIED IDEOGRAPH-#22E48, IRGKangXi=0462.461, RSKangXi=64.16
22E49 CJK UNIFIED IDEOGRAPH-#22E49, IRGKangXi=0462.461, RSKangXi=64.16
22E4A CJK UNIFIED IDEOGRAPH-#22E4A, IRGKangXi=0462.461, RSKangXi=64.16
22E4B CJK UNIFIED IDEOGRAPH-#22E4B, IRGKangXi=0462.461, RSKangXi=64.16
22E4C CJK UNIFIED IDEOGRAPH-#22E4C, IRGKangXi=0462.461, RSKangXi=64.16
22E4D CJK UNIFIED IDEOGRAPH-#22E4D, IRGKangXi=0462.490, RSKangXi=64.17
22E4E CJK UNIFIED IDEOGRAPH-#22E4E, IRGKangXi=0463.010, RSKangXi=64.17
22E4F CJK UNIFIED IDEOGRAPH-#22E4F, IRGKangXi=0463.020, RSKangXi=64.17
22E50 CJK UNIFIED IDEOGRAPH-#22E50, IRGKangXi=0463.050, RSKangXi=64.17
22E51 CJK UNIFIED IDEOGRAPH-#22E51, IRGKangXi=0463.060, RSKangXi=64.17, Def{(Cant.) to widen with force}
22E52 CJK UNIFIED IDEOGRAPH-#22E52, IRGKangXi=0463.070, RSKangXi=64.17
22E53 CJK UNIFIED IDEOGRAPH-#22E53, IRGKangXi=0463.100, RSKangXi=64.17
22E54 CJK UNIFIED IDEOGRAPH-#22E54, IRGKangXi=0463.130, RSKangXi=64.17
22E55 CJK UNIFIED IDEOGRAPH-#22E55, IRGKangXi=0463.150, RSKangXi=64.17
22E56 CJK UNIFIED IDEOGRAPH-#22E56, IRGKangXi=0463.160, RSKangXi=64.17
22E57 CJK UNIFIED IDEOGRAPH-#22E57, IRGKangXi=0463.170, RSKangXi=64.17
22E58 CJK UNIFIED IDEOGRAPH-#22E58, IRGKangXi=0463.180, RSKangXi=64.17
22E59 CJK UNIFIED IDEOGRAPH-#22E59, IRGKangXi=0463.190, RSKangXi=64.17
22E5A CJK UNIFIED IDEOGRAPH-#22E5A, IRGKangXi=0463.200, RSKangXi=64.17
22E5B CJK UNIFIED IDEOGRAPH-#22E5B, IRGKangXi=0463.211, RSKangXi=64.17
22E5C CJK UNIFIED IDEOGRAPH-#22E5C, IRGKangXi=0463.211, RSKangXi=64.17
22E5D CJK UNIFIED IDEOGRAPH-#22E5D, IRGKangXi=0463.211, RSKangXi=64.17
22E5E CJK UNIFIED IDEOGRAPH-#22E5E, IRGKangXi=0463.211, RSKangXi=64.17
22E5F CJK UNIFIED IDEOGRAPH-#22E5F, IRGKangXi=0463.211, RSKangXi=64.17
22E60 CJK UNIFIED IDEOGRAPH-#22E60, IRGKangXi=0463.211, RSKangXi=64.17
22E61 CJK UNIFIED IDEOGRAPH-#22E61, IRGKangXi=0463.211, RSKangXi=64.17
22E62 CJK UNIFIED IDEOGRAPH-#22E62, IRGKangXi=0463.211, RSKangXi=64.18
22E63 CJK UNIFIED IDEOGRAPH-#22E63, IRGKangXi=0463.211, RSKangXi=64.17
22E64 CJK UNIFIED IDEOGRAPH-#22E64, IRGKangXi=0463.211, RSKangXi=64.17
22E65 CJK UNIFIED IDEOGRAPH-#22E65, IRGKangXi=0463.211, RSKangXi=64.17
22E66 CJK UNIFIED IDEOGRAPH-#22E66, IRGKangXi=0463.211, RSKangXi=64.17
22E67 CJK UNIFIED IDEOGRAPH-#22E67, IRGKangXi=0463.211, RSKangXi=64.17
22E68 CJK UNIFIED IDEOGRAPH-#22E68, IRGKangXi=0463.211, RSKangXi=64.17
22E69 CJK UNIFIED IDEOGRAPH-#22E69, IRGKangXi=0463.211, RSKangXi=64.17
22E6A CJK UNIFIED IDEOGRAPH-#22E6A, IRGKangXi=0463.211, RSKangXi=64.17
22E6B CJK UNIFIED IDEOGRAPH-#22E6B, IRGKangXi=0463.211, RSKangXi=64.17
22E6C CJK UNIFIED IDEOGRAPH-#22E6C, IRGKangXi=0463.220, RSKangXi=64.18
22E6D CJK UNIFIED IDEOGRAPH-#22E6D, IRGKangXi=0463.230, RSKangXi=64.18
22E6E CJK UNIFIED IDEOGRAPH-#22E6E, IRGKangXi=0463.250, RSKangXi=64.18
22E6F CJK UNIFIED IDEOGRAPH-#22E6F, IRGKangXi=0463.290, RSKangXi=64.18
22E70 CJK UNIFIED IDEOGRAPH-#22E70, IRGKangXi=0463.320, RSKangXi=64.18
22E71 CJK UNIFIED IDEOGRAPH-#22E71, IRGKangXi=0464.010, RSKangXi=64.18
22E72 CJK UNIFIED IDEOGRAPH-#22E72, IRGKangXi=0464.020, RSKangXi=64.18
22E73 CJK UNIFIED IDEOGRAPH-#22E73, IRGKangXi=0464.030, RSKangXi=64.18
22E74 CJK UNIFIED IDEOGRAPH-#22E74, IRGKangXi=0464.040, RSKangXi=64.18
22E75 CJK UNIFIED IDEOGRAPH-#22E75, IRGKangXi=0464.050, RSKangXi=64.18
22E76 CJK UNIFIED IDEOGRAPH-#22E76, IRGKangXi=0464.051, RSKangXi=64.18
22E77 CJK UNIFIED IDEOGRAPH-#22E77, IRGKangXi=0464.051, RSKangXi=64.18
22E78 CJK UNIFIED IDEOGRAPH-#22E78, IRGKangXi=0464.051, RSKangXi=64.18
22E79 CJK UNIFIED IDEOGRAPH-#22E79, IRGKangXi=0464.051, RSKangXi=64.18
22E7A CJK UNIFIED IDEOGRAPH-#22E7A, IRGKangXi=0464.051, RSKangXi=64.18
22E7B CJK UNIFIED IDEOGRAPH-#22E7B, IRGKangXi=0464.051, RSKangXi=64.18
22E7C CJK UNIFIED IDEOGRAPH-#22E7C, IRGKangXi=0464.051, RSKangXi=64.18
22E7D CJK UNIFIED IDEOGRAPH-#22E7D, IRGKangXi=0464.051, RSKangXi=64.18
22E7E CJK UNIFIED IDEOGRAPH-#22E7E, IRGKangXi=0464.051, RSKangXi=64.18
22E7F CJK UNIFIED IDEOGRAPH-#22E7F, IRGKangXi=0464.051, RSKangXi=64.18
22E80 CJK UNIFIED IDEOGRAPH-#22E80, IRGKangXi=0464.051, RSKangXi=64.18
22E81 CJK UNIFIED IDEOGRAPH-#22E81, IRGKangXi=0464.051, RSKangXi=64.18
22E82 CJK UNIFIED IDEOGRAPH-#22E82, IRGKangXi=0464.060, RSKangXi=64.19
22E83 CJK UNIFIED IDEOGRAPH-#22E83, IRGKangXi=0464.070, RSKangXi=64.19
22E84 CJK UNIFIED IDEOGRAPH-#22E84, IRGKangXi=0464.080, RSKangXi=64.19
22E85 CJK UNIFIED IDEOGRAPH-#22E85, IRGKangXi=0464.130, RSKangXi=64.19
22E86 CJK UNIFIED IDEOGRAPH-#22E86, IRGKangXi=0464.140, RSKangXi=64.19
22E87 CJK UNIFIED IDEOGRAPH-#22E87, IRGKangXi=0464.150, RSKangXi=64.19
22E88 CJK UNIFIED IDEOGRAPH-#22E88, IRGKangXi=0464.170, RSKangXi=64.19
22E89 CJK UNIFIED IDEOGRAPH-#22E89, IRGKangXi=0464.210, RSKangXi=64.19
22E8A CJK UNIFIED IDEOGRAPH-#22E8A, IRGKangXi=0464.240, RSKangXi=64.19
22E8B CJK UNIFIED IDEOGRAPH-#22E8B, IRGKangXi=0464.250, RSKangXi=64.19, Def{(Cant.) to stitch together, quilt}
22E8C CJK UNIFIED IDEOGRAPH-#22E8C, IRGKangXi=0464.251, RSKangXi=64.19
22E8D CJK UNIFIED IDEOGRAPH-#22E8D, IRGKangXi=0464.251, RSKangXi=64.19
22E8E CJK UNIFIED IDEOGRAPH-#22E8E, IRGKangXi=0464.251, RSKangXi=64.19
22E8F CJK UNIFIED IDEOGRAPH-#22E8F, IRGKangXi=0464.251, RSKangXi=64.19
22E90 CJK UNIFIED IDEOGRAPH-#22E90, IRGKangXi=0464.251, RSKangXi=64.19
22E91 CJK UNIFIED IDEOGRAPH-#22E91, IRGKangXi=0464.251, RSKangXi=64.19
22E92 CJK UNIFIED IDEOGRAPH-#22E92, IRGKangXi=0464.251, RSKangXi=64.19
22E93 CJK UNIFIED IDEOGRAPH-#22E93, IRGKangXi=0464.251, RSKangXi=64.19
22E94 CJK UNIFIED IDEOGRAPH-#22E94, IRGKangXi=0464.251, RSKangXi=64.19
22E95 CJK UNIFIED IDEOGRAPH-#22E95, IRGKangXi=0464.251, RSKangXi=64.19
22E96 CJK UNIFIED IDEOGRAPH-#22E96, IRGKangXi=0465.050, RSKangXi=64.20
22E97 CJK UNIFIED IDEOGRAPH-#22E97, IRGKangXi=0465.051, RSKangXi=64.20
22E98 CJK UNIFIED IDEOGRAPH-#22E98, IRGKangXi=0465.051, RSKangXi=64.20
22E99 CJK UNIFIED IDEOGRAPH-#22E99, IRGKangXi=0465.051, RSKangXi=64.20
22E9A CJK UNIFIED IDEOGRAPH-#22E9A, IRGKangXi=0465.051, RSKangXi=64.20
22E9B CJK UNIFIED IDEOGRAPH-#22E9B, IRGKangXi=0465.051, RSKangXi=64.20
22E9C CJK UNIFIED IDEOGRAPH-#22E9C, IRGKangXi=0465.051, RSKangXi=64.20
22E9D CJK UNIFIED IDEOGRAPH-#22E9D, IRGKangXi=0465.051, RSKangXi=64.20
22E9E CJK UNIFIED IDEOGRAPH-#22E9E, IRGKangXi=0465.070, RSKangXi=64.21
22E9F CJK UNIFIED IDEOGRAPH-#22E9F, IRGKangXi=0465.080, RSKangXi=64.21
22EA0 CJK UNIFIED IDEOGRAPH-#22EA0, IRGKangXi=0465.090, RSKangXi=64.21
22EA1 CJK UNIFIED IDEOGRAPH-#22EA1, IRGKangXi=0465.100, RSKangXi=64.21
22EA2 CJK UNIFIED IDEOGRAPH-#22EA2, IRGKangXi=0465.110, RSKangXi=64.21
22EA3 CJK UNIFIED IDEOGRAPH-#22EA3, IRGKangXi=0465.121, RSKangXi=64.21
22EA4 CJK UNIFIED IDEOGRAPH-#22EA4, IRGKangXi=0465.121, RSKangXi=64.21
22EA5 CJK UNIFIED IDEOGRAPH-#22EA5, IRGKangXi=0465.121, RSKangXi=64.21
22EA6 CJK UNIFIED IDEOGRAPH-#22EA6, IRGKangXi=0465.121, RSKangXi=64.21
22EA7 CJK UNIFIED IDEOGRAPH-#22EA7, IRGKangXi=0465.121, RSKangXi=64.21
22EA8 CJK UNIFIED IDEOGRAPH-#22EA8, IRGKangXi=0465.121, RSKangXi=64.21
22EA9 CJK UNIFIED IDEOGRAPH-#22EA9, IRGKangXi=0465.121, RSKangXi=64.21
22EAA CJK UNIFIED IDEOGRAPH-#22EAA, IRGKangXi=0465.121, RSKangXi=64.21
22EAB CJK UNIFIED IDEOGRAPH-#22EAB, IRGKangXi=0465.121, RSKangXi=64.21
22EAC CJK UNIFIED IDEOGRAPH-#22EAC, IRGKangXi=0465.141, RSKangXi=64.22
22EAD CJK UNIFIED IDEOGRAPH-#22EAD, IRGKangXi=0465.141, RSKangXi=64.22
22EAE CJK UNIFIED IDEOGRAPH-#22EAE, IRGKangXi=0465.141, RSKangXi=64.22
22EAF CJK UNIFIED IDEOGRAPH-#22EAF, IRGKangXi=0465.141, RSKangXi=64.22
22EB0 CJK UNIFIED IDEOGRAPH-#22EB0, IRGKangXi=0465.150, RSKangXi=64.24
22EB1 CJK UNIFIED IDEOGRAPH-#22EB1, IRGKangXi=0465.160, RSKangXi=64.24
22EB2 CJK UNIFIED IDEOGRAPH-#22EB2, IRGKangXi=0465.161, RSKangXi=64.24
22EB3 CJK UNIFIED IDEOGRAPH-#22EB3, IRGKangXi=0465.170, RSKangXi=64.25, Def{to push, pull, port the helm; (Cant.) to hold to, cling to; to cock a gun}
22EB4 CJK UNIFIED IDEOGRAPH-#22EB4, IRGKangXi=0465.180, RSKangXi=64.29
22EB5 CJK UNIFIED IDEOGRAPH-#22EB5, IRGKangXi=0467.040, RSKangXi=65.2
22EB6 CJK UNIFIED IDEOGRAPH-#22EB6, IRGKangXi=0467.060, RSKangXi=65.3
22EB7 CJK UNIFIED IDEOGRAPH-#22EB7, IRGKangXi=0467.080, RSKangXi=65.4
22EB8 CJK UNIFIED IDEOGRAPH-#22EB8, IRGKangXi=0467.081, RSKangXi=65.4
22EB9 CJK UNIFIED IDEOGRAPH-#22EB9, IRGKangXi=0467.081, RSKangXi=65.4
22EBA CJK UNIFIED IDEOGRAPH-#22EBA, IRGKangXi=0467.081, RSKangXi=65.4
22EBB CJK UNIFIED IDEOGRAPH-#22EBB, IRGKangXi=0467.081, RSKangXi=65.4
22EBC CJK UNIFIED IDEOGRAPH-#22EBC, IRGKangXi=0467.081, RSKangXi=65.4
22EBD CJK UNIFIED IDEOGRAPH-#22EBD, IRGKangXi=0467.081, RSKangXi=65.4
22EBE CJK UNIFIED IDEOGRAPH-#22EBE, IRGKangXi=0467.100, RSKangXi=65.5
22EBF CJK UNIFIED IDEOGRAPH-#22EBF, IRGKangXi=0467.101, RSKangXi=65.5
22EC0 CJK UNIFIED IDEOGRAPH-#22EC0, IRGKangXi=0467.101, RSKangXi=65.5
22EC1 CJK UNIFIED IDEOGRAPH-#22EC1, IRGKangXi=0467.110, RSKangXi=65.6
22EC2 CJK UNIFIED IDEOGRAPH-#22EC2, IRGKangXi=0467.120, RSKangXi=65.6
22EC3 CJK UNIFIED IDEOGRAPH-#22EC3, IRGKangXi=0467.140, RSKangXi=65.6
22EC4 CJK UNIFIED IDEOGRAPH-#22EC4, IRGKangXi=0467.160, RSKangXi=65.6
22EC5 CJK UNIFIED IDEOGRAPH-#22EC5, IRGKangXi=0467.161, RSKangXi=65.6
22EC6 CJK UNIFIED IDEOGRAPH-#22EC6, IRGKangXi=0467.161, RSKangXi=65.6
22EC7 CJK UNIFIED IDEOGRAPH-#22EC7, IRGKangXi=0467.161, RSKangXi=65.6
22EC8 CJK UNIFIED IDEOGRAPH-#22EC8, IRGKangXi=0467.161, RSKangXi=36.7
22EC9 CJK UNIFIED IDEOGRAPH-#22EC9, IRGKangXi=0467.161, RSKangXi=65.6
22ECA CJK UNIFIED IDEOGRAPH-#22ECA, IRGKangXi=0467.180, RSKangXi=65.7
22ECB CJK UNIFIED IDEOGRAPH-#22ECB, IRGKangXi=0467.181, RSKangXi=65.7
22ECC CJK UNIFIED IDEOGRAPH-#22ECC, IRGKangXi=0467.181, RSKangXi=65.7
22ECD CJK UNIFIED IDEOGRAPH-#22ECD, IRGKangXi=0467.181, RSKangXi=65.7
22ECE CJK UNIFIED IDEOGRAPH-#22ECE, IRGKangXi=0467.190, RSKangXi=65.8
22ECF CJK UNIFIED IDEOGRAPH-#22ECF, IRGKangXi=0467.220, RSKangXi=65.8
22ED0 CJK UNIFIED IDEOGRAPH-#22ED0, IRGKangXi=0467.221, RSKangXi=65.8
22ED1 CJK UNIFIED IDEOGRAPH-#22ED1, IRGKangXi=0467.221, RSKangXi=65.8
22ED2 CJK UNIFIED IDEOGRAPH-#22ED2, IRGKangXi=0467.221, RSKangXi=65.8
22ED3 CJK UNIFIED IDEOGRAPH-#22ED3, IRGKangXi=0467.221, RSKangXi=65.8
22ED4 CJK UNIFIED IDEOGRAPH-#22ED4, IRGKangXi=0467.221, RSKangXi=65.8
22ED5 CJK UNIFIED IDEOGRAPH-#22ED5, IRGKangXi=0467.230, RSKangXi=65.9
22ED6 CJK UNIFIED IDEOGRAPH-#22ED6, IRGKangXi=0467.231, RSKangXi=65.9
22ED7 CJK UNIFIED IDEOGRAPH-#22ED7, IRGKangXi=0467.231, RSKangXi=65.9
22ED8 CJK UNIFIED IDEOGRAPH-#22ED8, IRGKangXi=0467.231, RSKangXi=65.9
22ED9 CJK UNIFIED IDEOGRAPH-#22ED9, IRGKangXi=0467.231, RSKangXi=65.9
22EDA CJK UNIFIED IDEOGRAPH-#22EDA, IRGKangXi=0467.240, RSKangXi=65.10
22EDB CJK UNIFIED IDEOGRAPH-#22EDB, IRGKangXi=0467.241, RSKangXi=65.10
22EDC CJK UNIFIED IDEOGRAPH-#22EDC, IRGKangXi=0467.241, RSKangXi=65.10
22EDD CJK UNIFIED IDEOGRAPH-#22EDD, IRGKangXi=0467.241, RSKangXi=65.11
22EDE CJK UNIFIED IDEOGRAPH-#22EDE, IRGKangXi=0467.241, RSKangXi=65.11
22EDF CJK UNIFIED IDEOGRAPH-#22EDF, IRGKangXi=0467.241, RSKangXi=65.11
22EE0 CJK UNIFIED IDEOGRAPH-#22EE0, IRGKangXi=0467.260, RSKangXi=65.12
22EE1 CJK UNIFIED IDEOGRAPH-#22EE1, IRGKangXi=0467.261, RSKangXi=65.12
22EE2 CJK UNIFIED IDEOGRAPH-#22EE2, IRGKangXi=0467.261, RSKangXi=65.12
22EE3 CJK UNIFIED IDEOGRAPH-#22EE3, IRGKangXi=0467.261, RSKangXi=65.12
22EE4 CJK UNIFIED IDEOGRAPH-#22EE4, IRGKangXi=0467.261, RSKangXi=65.12
22EE5 CJK UNIFIED IDEOGRAPH-#22EE5, IRGKangXi=0468.010, RSKangXi=65.13
22EE6 CJK UNIFIED IDEOGRAPH-#22EE6, IRGKangXi=0468.011, RSKangXi=65.13
22EE7 CJK UNIFIED IDEOGRAPH-#22EE7, IRGKangXi=0468.011, RSKangXi=65.13
22EE8 CJK UNIFIED IDEOGRAPH-#22EE8, IRGKangXi=0468.011, RSKangXi=65.13
22EE9 CJK UNIFIED IDEOGRAPH-#22EE9, IRGKangXi=0468.020, RSKangXi=65.13
22EEA CJK UNIFIED IDEOGRAPH-#22EEA, IRGKangXi=0468.030, RSKangXi=65.16
22EEB CJK UNIFIED IDEOGRAPH-#22EEB, IRGKangXi=0468.090, RSKangXi=66.3
22EEC CJK UNIFIED IDEOGRAPH-#22EEC, IRGKangXi=0468.130, RSKangXi=66.3
22EED CJK UNIFIED IDEOGRAPH-#22EED, IRGKangXi=0468.150, RSKangXi=66.3
22EEE CJK UNIFIED IDEOGRAPH-#22EEE, IRGKangXi=0468.170, RSKangXi=66.3
22EEF CJK UNIFIED IDEOGRAPH-#22EEF, IRGKangXi=0468.190, RSKangXi=66.3
22EF0 CJK UNIFIED IDEOGRAPH-#22EF0, IRGKangXi=0468.191, RSKangXi=66.3
22EF1 CJK UNIFIED IDEOGRAPH-#22EF1, IRGKangXi=0468.191, RSKangXi=66.3
22EF2 CJK UNIFIED IDEOGRAPH-#22EF2, IRGKangXi=0468.191, RSKangXi=66.3
22EF3 CJK UNIFIED IDEOGRAPH-#22EF3, IRGKangXi=0468.200, RSKangXi=66.4
22EF4 CJK UNIFIED IDEOGRAPH-#22EF4, IRGKangXi=0468.220, RSKangXi=66.4
22EF5 CJK UNIFIED IDEOGRAPH-#22EF5, IRGKangXi=0468.230, RSKangXi=66.4
22EF6 CJK UNIFIED IDEOGRAPH-#22EF6, IRGKangXi=0468.250, RSKangXi=66.4
22EF7 CJK UNIFIED IDEOGRAPH-#22EF7, IRGKangXi=0469.010, RSKangXi=66.4
22EF8 CJK UNIFIED IDEOGRAPH-#22EF8, IRGKangXi=0469.020, RSKangXi=66.4
22EF9 CJK UNIFIED IDEOGRAPH-#22EF9, IRGKangXi=0469.050, RSKangXi=66.4
22EFA CJK UNIFIED IDEOGRAPH-#22EFA, IRGKangXi=0469.070, RSKangXi=66.4
22EFB CJK UNIFIED IDEOGRAPH-#22EFB, IRGKangXi=0469.080, RSKangXi=66.4
22EFC CJK UNIFIED IDEOGRAPH-#22EFC, IRGKangXi=0469.090, RSKangXi=66.4
22EFD CJK UNIFIED IDEOGRAPH-#22EFD, IRGKangXi=0469.100, RSKangXi=66.4
22EFE CJK UNIFIED IDEOGRAPH-#22EFE, IRGKangXi=0469.120, RSKangXi=66.4
22EFF CJK UNIFIED IDEOGRAPH-#22EFF, IRGKangXi=0469.121, RSKangXi=66.4
22F00 CJK UNIFIED IDEOGRAPH-#22F00, IRGKangXi=0469.121, RSKangXi=66.4
22F01 CJK UNIFIED IDEOGRAPH-#22F01, IRGKangXi=0469.121, RSKangXi=66.4
22F02 CJK UNIFIED IDEOGRAPH-#22F02, IRGKangXi=0469.121, RSKangXi=66.4
22F03 CJK UNIFIED IDEOGRAPH-#22F03, IRGKangXi=0469.121, RSKangXi=66.4
22F04 CJK UNIFIED IDEOGRAPH-#22F04, IRGKangXi=0469.121, RSKangXi=66.4
22F05 CJK UNIFIED IDEOGRAPH-#22F05, IRGKangXi=0469.121, RSKangXi=66.4
22F06 CJK UNIFIED IDEOGRAPH-#22F06, IRGKangXi=0469.121, RSKangXi=66.4
22F07 CJK UNIFIED IDEOGRAPH-#22F07, IRGKangXi=0469.121, RSKangXi=66.4
22F08 CJK UNIFIED IDEOGRAPH-#22F08, IRGKangXi=0469.121, RSKangXi=66.4
22F09 CJK UNIFIED IDEOGRAPH-#22F09, IRGKangXi=0469.140, RSKangXi=66.5
22F0A CJK UNIFIED IDEOGRAPH-#22F0A, IRGKangXi=0469.150, RSKangXi=66.5
22F0B CJK UNIFIED IDEOGRAPH-#22F0B, IRGKangXi=0469.170, RSKangXi=66.5
22F0C CJK UNIFIED IDEOGRAPH-#22F0C, IRGKangXi=0469.210, RSKangXi=66.5
22F0D CJK UNIFIED IDEOGRAPH-#22F0D, IRGKangXi=0470.010, RSKangXi=66.5
22F0E CJK UNIFIED IDEOGRAPH-#22F0E, IRGKangXi=0470.020, RSKangXi=66.5
22F0F CJK UNIFIED IDEOGRAPH-#22F0F, IRGKangXi=0470.040, RSKangXi=66.5
22F10 CJK UNIFIED IDEOGRAPH-#22F10, IRGKangXi=0470.050, RSKangXi=66.5
22F11 CJK UNIFIED IDEOGRAPH-#22F11, IRGKangXi=0470.060, RSKangXi=66.5
22F12 CJK UNIFIED IDEOGRAPH-#22F12, IRGKangXi=0470.061, RSKangXi=66.5
22F13 CJK UNIFIED IDEOGRAPH-#22F13, IRGKangXi=0470.061, RSKangXi=66.5
22F14 CJK UNIFIED IDEOGRAPH-#22F14, IRGKangXi=0470.061, RSKangXi=66.5
22F15 CJK UNIFIED IDEOGRAPH-#22F15, IRGKangXi=0470.061, RSKangXi=66.5
22F16 CJK UNIFIED IDEOGRAPH-#22F16, IRGKangXi=0470.061, RSKangXi=66.5
22F17 CJK UNIFIED IDEOGRAPH-#22F17, IRGKangXi=0470.061, RSKangXi=66.5
22F18 CJK UNIFIED IDEOGRAPH-#22F18, IRGKangXi=0470.061, RSKangXi=66.5
22F19 CJK UNIFIED IDEOGRAPH-#22F19, IRGKangXi=0470.061, RSKangXi=66.5
22F1A CJK UNIFIED IDEOGRAPH-#22F1A, IRGKangXi=0470.061, RSKangXi=66.5
22F1B CJK UNIFIED IDEOGRAPH-#22F1B, IRGKangXi=0470.070, RSKangXi=66.6
22F1C CJK UNIFIED IDEOGRAPH-#22F1C, IRGKangXi=0470.090, RSKangXi=66.6
22F1D CJK UNIFIED IDEOGRAPH-#22F1D, IRGKangXi=0470.110, RSKangXi=66.6
22F1E CJK UNIFIED IDEOGRAPH-#22F1E, IRGKangXi=0470.120, RSKangXi=66.6
22F1F CJK UNIFIED IDEOGRAPH-#22F1F, IRGKangXi=0470.150, RSKangXi=66.6
22F20 CJK UNIFIED IDEOGRAPH-#22F20, IRGKangXi=0470.160, RSKangXi=66.6
22F21 CJK UNIFIED IDEOGRAPH-#22F21, IRGKangXi=0470.170, RSKangXi=66.6
22F22 CJK UNIFIED IDEOGRAPH-#22F22, IRGKangXi=0470.180, RSKangXi=66.6
22F23 CJK UNIFIED IDEOGRAPH-#22F23, IRGKangXi=0470.190, RSKangXi=66.6
22F24 CJK UNIFIED IDEOGRAPH-#22F24, IRGKangXi=0470.200, RSKangXi=66.6
22F25 CJK UNIFIED IDEOGRAPH-#22F25, IRGKangXi=0470.220, RSKangXi=66.6
22F26 CJK UNIFIED IDEOGRAPH-#22F26, IRGKangXi=0470.230, RSKangXi=66.6
22F27 CJK UNIFIED IDEOGRAPH-#22F27, IRGKangXi=0470.240, RSKangXi=66.6
22F28 CJK UNIFIED IDEOGRAPH-#22F28, IRGKangXi=0470.250, RSKangXi=66.6
22F29 CJK UNIFIED IDEOGRAPH-#22F29, IRGKangXi=0470.280, RSKangXi=66.6
22F2A CJK UNIFIED IDEOGRAPH-#22F2A, IRGKangXi=0470.290, RSKangXi=66.6
22F2B CJK UNIFIED IDEOGRAPH-#22F2B, IRGKangXi=0470.291, RSKangXi=66.6
22F2C CJK UNIFIED IDEOGRAPH-#22F2C, IRGKangXi=0470.291, RSKangXi=66.6
22F2D CJK UNIFIED IDEOGRAPH-#22F2D, IRGKangXi=0470.291, RSKangXi=66.6
22F2E CJK UNIFIED IDEOGRAPH-#22F2E, IRGKangXi=0470.291, RSKangXi=66.6
22F2F CJK UNIFIED IDEOGRAPH-#22F2F, IRGKangXi=0470.291, RSKangXi=66.6
22F30 CJK UNIFIED IDEOGRAPH-#22F30, IRGKangXi=0470.291, RSKangXi=66.6
22F31 CJK UNIFIED IDEOGRAPH-#22F31, IRGKangXi=0470.291, RSKangXi=66.6
22F32 CJK UNIFIED IDEOGRAPH-#22F32, IRGKangXi=0470.291, RSKangXi=66.6
22F33 CJK UNIFIED IDEOGRAPH-#22F33, IRGKangXi=0470.291, RSKangXi=66.6
22F34 CJK UNIFIED IDEOGRAPH-#22F34, IRGKangXi=0470.291, RSKangXi=66.6
22F35 CJK UNIFIED IDEOGRAPH-#22F35, IRGKangXi=0470.291, RSKangXi=66.6
22F36 CJK UNIFIED IDEOGRAPH-#22F36, IRGKangXi=0470.291, RSKangXi=66.6
22F37 CJK UNIFIED IDEOGRAPH-#22F37, IRGKangXi=0470.291, RSKangXi=66.6
22F38 CJK UNIFIED IDEOGRAPH-#22F38, IRGKangXi=0470.291, RSKangXi=66.6
22F39 CJK UNIFIED IDEOGRAPH-#22F39, IRGKangXi=0470.340, RSKangXi=66.7
22F3A CJK UNIFIED IDEOGRAPH-#22F3A, IRGKangXi=0470.350, RSKangXi=66.7
22F3B CJK UNIFIED IDEOGRAPH-#22F3B, IRGKangXi=0470.360, RSKangXi=66.7
22F3C CJK UNIFIED IDEOGRAPH-#22F3C, IRGKangXi=0471.010, RSKangXi=66.7
22F3D CJK UNIFIED IDEOGRAPH-#22F3D, IRGKangXi=0471.020, RSKangXi=66.7
22F3E CJK UNIFIED IDEOGRAPH-#22F3E, IRGKangXi=0471.030, RSKangXi=66.7
22F3F CJK UNIFIED IDEOGRAPH-#22F3F, IRGKangXi=0471.080, RSKangXi=66.7
22F40 CJK UNIFIED IDEOGRAPH-#22F40, IRGKangXi=0471.190, RSKangXi=66.7
22F41 CJK UNIFIED IDEOGRAPH-#22F41, IRGKangXi=0471.200, RSKangXi=66.7
22F42 CJK UNIFIED IDEOGRAPH-#22F42, IRGKangXi=0471.210, RSKangXi=66.7
22F43 CJK UNIFIED IDEOGRAPH-#22F43, IRGKangXi=0471.220, RSKangXi=66.7
22F44 CJK UNIFIED IDEOGRAPH-#22F44, IRGKangXi=0471.230, RSKangXi=66.7
22F45 CJK UNIFIED IDEOGRAPH-#22F45, IRGKangXi=0472.010, RSKangXi=66.7
22F46 CJK UNIFIED IDEOGRAPH-#22F46, IRGKangXi=0472.020, RSKangXi=66.7
22F47 CJK UNIFIED IDEOGRAPH-#22F47, IRGKangXi=0472.030, RSKangXi=66.7
22F48 CJK UNIFIED IDEOGRAPH-#22F48, IRGKangXi=0472.040, RSKangXi=66.7
22F49 CJK UNIFIED IDEOGRAPH-#22F49, IRGKangXi=0472.050, RSKangXi=66.7
22F4A CJK UNIFIED IDEOGRAPH-#22F4A, IRGKangXi=0472.051, RSKangXi=66.7
22F4B CJK UNIFIED IDEOGRAPH-#22F4B, IRGKangXi=0472.051, RSKangXi=66.7
22F4C CJK UNIFIED IDEOGRAPH-#22F4C, IRGKangXi=0472.051, RSKangXi=66.7
22F4D CJK UNIFIED IDEOGRAPH-#22F4D, IRGKangXi=0472.051, RSKangXi=66.7
22F4E CJK UNIFIED IDEOGRAPH-#22F4E, IRGKangXi=0472.051, RSKangXi=66.7
22F4F CJK UNIFIED IDEOGRAPH-#22F4F, IRGKangXi=0472.051, RSKangXi=66.7
22F50 CJK UNIFIED IDEOGRAPH-#22F50, IRGKangXi=0472.051, RSKangXi=66.7
22F51 CJK UNIFIED IDEOGRAPH-#22F51, IRGKangXi=0472.051, RSKangXi=66.7
22F52 CJK UNIFIED IDEOGRAPH-#22F52, IRGKangXi=0472.051, RSKangXi=66.7
22F53 CJK UNIFIED IDEOGRAPH-#22F53, IRGKangXi=0472.051, RSKangXi=66.7
22F54 CJK UNIFIED IDEOGRAPH-#22F54, IRGKangXi=0472.051, RSKangXi=66.7
22F55 CJK UNIFIED IDEOGRAPH-#22F55, IRGKangXi=0472.051, RSKangXi=66.7
22F56 CJK UNIFIED IDEOGRAPH-#22F56, IRGKangXi=0472.051, RSKangXi=66.7
22F57 CJK UNIFIED IDEOGRAPH-#22F57, IRGKangXi=0472.051, RSKangXi=66.7
22F58 CJK UNIFIED IDEOGRAPH-#22F58, IRGKangXi=0472.051, RSKangXi=66.7
22F59 CJK UNIFIED IDEOGRAPH-#22F59, IRGKangXi=0472.051, RSKangXi=66.7
22F5A CJK UNIFIED IDEOGRAPH-#22F5A, IRGKangXi=0472.060, RSKangXi=66.8
22F5B CJK UNIFIED IDEOGRAPH-#22F5B, IRGKangXi=0472.080, RSKangXi=66.8
22F5C CJK UNIFIED IDEOGRAPH-#22F5C, IRGKangXi=0472.140, RSKangXi=66.7
22F5D CJK UNIFIED IDEOGRAPH-#22F5D, IRGKangXi=0472.150, RSKangXi=66.8
22F5E CJK UNIFIED IDEOGRAPH-#22F5E, IRGKangXi=0472.160, RSKangXi=66.8
22F5F CJK UNIFIED IDEOGRAPH-#22F5F, IRGKangXi=0472.180, RSKangXi=66.8
22F60 CJK UNIFIED IDEOGRAPH-#22F60, IRGKangXi=0472.200, RSKangXi=66.8
22F61 CJK UNIFIED IDEOGRAPH-#22F61, IRGKangXi=0472.210, RSKangXi=66.8
22F62 CJK UNIFIED IDEOGRAPH-#22F62, IRGKangXi=0472.220, RSKangXi=66.8
22F63 CJK UNIFIED IDEOGRAPH-#22F63, IRGKangXi=0472.230, RSKangXi=66.8
22F64 CJK UNIFIED IDEOGRAPH-#22F64, IRGKangXi=0472.300, RSKangXi=66.8
22F65 CJK UNIFIED IDEOGRAPH-#22F65, IRGKangXi=0472.330, RSKangXi=66.8
22F66 CJK UNIFIED IDEOGRAPH-#22F66, IRGKangXi=0472.360, RSKangXi=66.8
22F67 CJK UNIFIED IDEOGRAPH-#22F67, IRGKangXi=0472.370, RSKangXi=66.8
22F68 CJK UNIFIED IDEOGRAPH-#22F68, IRGKangXi=0472.380, RSKangXi=66.8
22F69 CJK UNIFIED IDEOGRAPH-#22F69, IRGKangXi=0473.010, RSKangXi=66.8
22F6A CJK UNIFIED IDEOGRAPH-#22F6A, IRGKangXi=0473.030, RSKangXi=66.8
22F6B CJK UNIFIED IDEOGRAPH-#22F6B, IRGKangXi=0473.040, RSKangXi=66.8
22F6C CJK UNIFIED IDEOGRAPH-#22F6C, IRGKangXi=0473.120, RSKangXi=66.8
22F6D CJK UNIFIED IDEOGRAPH-#22F6D, IRGKangXi=0473.130, RSKangXi=66.8
22F6E CJK UNIFIED IDEOGRAPH-#22F6E, IRGKangXi=0473.140, RSKangXi=66.8
22F6F CJK UNIFIED IDEOGRAPH-#22F6F, IRGKangXi=0473.160, RSKangXi=66.8
22F70 CJK UNIFIED IDEOGRAPH-#22F70, IRGKangXi=0473.170, RSKangXi=66.8
22F71 CJK UNIFIED IDEOGRAPH-#22F71, IRGKangXi=0473.171, RSKangXi=66.8
22F72 CJK UNIFIED IDEOGRAPH-#22F72, IRGKangXi=0473.171, RSKangXi=66.8
22F73 CJK UNIFIED IDEOGRAPH-#22F73, IRGKangXi=0473.171, RSKangXi=66.8
22F74 CJK UNIFIED IDEOGRAPH-#22F74, IRGKangXi=0473.171, RSKangXi=66.8, Def{(Cant.) to poke, jab}
22F75 CJK UNIFIED IDEOGRAPH-#22F75, IRGKangXi=0473.171, RSKangXi=66.8
22F76 CJK UNIFIED IDEOGRAPH-#22F76, IRGKangXi=0473.171, RSKangXi=66.8
22F77 CJK UNIFIED IDEOGRAPH-#22F77, IRGKangXi=0473.171, RSKangXi=66.7
22F78 CJK UNIFIED IDEOGRAPH-#22F78, IRGKangXi=0473.171, RSKangXi=66.8
22F79 CJK UNIFIED IDEOGRAPH-#22F79, IRGKangXi=0473.171, RSKangXi=66.8
22F7A CJK UNIFIED IDEOGRAPH-#22F7A, IRGKangXi=0473.171, RSKangXi=66.8
22F7B CJK UNIFIED IDEOGRAPH-#22F7B, IRGKangXi=0473.171, RSKangXi=66.8
22F7C CJK UNIFIED IDEOGRAPH-#22F7C, IRGKangXi=0473.171, RSKangXi=66.8
22F7D CJK UNIFIED IDEOGRAPH-#22F7D, IRGKangXi=0473.171, RSKangXi=66.8
22F7E CJK UNIFIED IDEOGRAPH-#22F7E, IRGKangXi=0473.171, RSKangXi=66.8
22F7F CJK UNIFIED IDEOGRAPH-#22F7F, IRGKangXi=0473.190, RSKangXi=66.9
22F80 CJK UNIFIED IDEOGRAPH-#22F80, IRGKangXi=0473.200, RSKangXi=66.9
22F81 CJK UNIFIED IDEOGRAPH-#22F81, IRGKangXi=0473.230, RSKangXi=66.9
22F82 CJK UNIFIED IDEOGRAPH-#22F82, IRGKangXi=0473.240, RSKangXi=66.9
22F83 CJK UNIFIED IDEOGRAPH-#22F83, IRGKangXi=0473.250, RSKangXi=66.9
22F84 CJK UNIFIED IDEOGRAPH-#22F84, IRGKangXi=0473.260, RSKangXi=66.9
22F85 CJK UNIFIED IDEOGRAPH-#22F85, IRGKangXi=0473.270, RSKangXi=66.9
22F86 CJK UNIFIED IDEOGRAPH-#22F86, IRGKangXi=0473.280, RSKangXi=66.9
22F87 CJK UNIFIED IDEOGRAPH-#22F87, IRGKangXi=0473.290, RSKangXi=66.9
22F88 CJK UNIFIED IDEOGRAPH-#22F88, IRGKangXi=0473.300, RSKangXi=66.9
22F89 CJK UNIFIED IDEOGRAPH-#22F89, IRGKangXi=0473.310, RSKangXi=66.9
22F8A CJK UNIFIED IDEOGRAPH-#22F8A, IRGKangXi=0473.320, RSKangXi=66.9
22F8B CJK UNIFIED IDEOGRAPH-#22F8B, IRGKangXi=0473.330, RSKangXi=66.9
22F8C CJK UNIFIED IDEOGRAPH-#22F8C, IRGKangXi=0473.340, RSKangXi=66.9
22F8D CJK UNIFIED IDEOGRAPH-#22F8D, IRGKangXi=0474.010, RSKangXi=66.9
22F8E CJK UNIFIED IDEOGRAPH-#22F8E, IRGKangXi=0474.050, RSKangXi=66.9
22F8F CJK UNIFIED IDEOGRAPH-#22F8F, IRGKangXi=0474.060, RSKangXi=66.9
22F90 CJK UNIFIED IDEOGRAPH-#22F90, IRGKangXi=0474.070, RSKangXi=66.9
22F91 CJK UNIFIED IDEOGRAPH-#22F91, IRGKangXi=0474.080, RSKangXi=66.9
22F92 CJK UNIFIED IDEOGRAPH-#22F92, IRGKangXi=0474.100, RSKangXi=66.9
22F93 CJK UNIFIED IDEOGRAPH-#22F93, IRGKangXi=0474.110, RSKangXi=66.9
22F94 CJK UNIFIED IDEOGRAPH-#22F94, IRGKangXi=0474.120, RSKangXi=66.9
22F95 CJK UNIFIED IDEOGRAPH-#22F95, IRGKangXi=0474.131, RSKangXi=66.9
22F96 CJK UNIFIED IDEOGRAPH-#22F96, IRGKangXi=0474.131, RSKangXi=66.9
22F97 CJK UNIFIED IDEOGRAPH-#22F97, IRGKangXi=0474.131, RSKangXi=66.9
22F98 CJK UNIFIED IDEOGRAPH-#22F98, IRGKangXi=0474.131, RSKangXi=66.9
22F99 CJK UNIFIED IDEOGRAPH-#22F99, IRGKangXi=0474.131, RSKangXi=66.9
22F9A CJK UNIFIED IDEOGRAPH-#22F9A, IRGKangXi=0474.131, RSKangXi=66.9
22F9B CJK UNIFIED IDEOGRAPH-#22F9B, IRGKangXi=0474.131, RSKangXi=66.9
22F9C CJK UNIFIED IDEOGRAPH-#22F9C, IRGKangXi=0474.131, RSKangXi=66.9
22F9D CJK UNIFIED IDEOGRAPH-#22F9D, IRGKangXi=0474.131, RSKangXi=66.9
22F9E CJK UNIFIED IDEOGRAPH-#22F9E, IRGKangXi=0474.131, RSKangXi=66.9
22F9F CJK UNIFIED IDEOGRAPH-#22F9F, IRGKangXi=0474.131, RSKangXi=66.9
22FA0 CJK UNIFIED IDEOGRAPH-#22FA0, IRGKangXi=0474.131, RSKangXi=66.9
22FA1 CJK UNIFIED IDEOGRAPH-#22FA1, IRGKangXi=0474.131, RSKangXi=66.9
22FA2 CJK UNIFIED IDEOGRAPH-#22FA2, IRGKangXi=0474.131, RSKangXi=66.9
22FA3 CJK UNIFIED IDEOGRAPH-#22FA3, IRGKangXi=0474.131, RSKangXi=66.9
22FA4 CJK UNIFIED IDEOGRAPH-#22FA4, IRGKangXi=0474.131, RSKangXi=66.9
22FA5 CJK UNIFIED IDEOGRAPH-#22FA5, IRGKangXi=0474.131, RSKangXi=109.8
22FA6 CJK UNIFIED IDEOGRAPH-#22FA6, IRGKangXi=0474.140, RSKangXi=66.10
22FA7 CJK UNIFIED IDEOGRAPH-#22FA7, IRGKangXi=0474.150, RSKangXi=66.10
22FA8 CJK UNIFIED IDEOGRAPH-#22FA8, IRGKangXi=0474.160, RSKangXi=66.10
22FA9 CJK UNIFIED IDEOGRAPH-#22FA9, IRGKangXi=0474.170, RSKangXi=66.10
22FAA CJK UNIFIED IDEOGRAPH-#22FAA, IRGKangXi=0474.180, RSKangXi=66.10
22FAB CJK UNIFIED IDEOGRAPH-#22FAB, IRGKangXi=0474.200, RSKangXi=66.10
22FAC CJK UNIFIED IDEOGRAPH-#22FAC, IRGKangXi=0474.210, RSKangXi=66.10
22FAD CJK UNIFIED IDEOGRAPH-#22FAD, IRGKangXi=0474.220, RSKangXi=66.10
22FAE CJK UNIFIED IDEOGRAPH-#22FAE, IRGKangXi=0474.230, RSKangXi=66.10
22FAF CJK UNIFIED IDEOGRAPH-#22FAF, IRGKangXi=0474.260, RSKangXi=66.10
22FB0 CJK UNIFIED IDEOGRAPH-#22FB0, IRGKangXi=0474.270, RSKangXi=66.10
22FB1 CJK UNIFIED IDEOGRAPH-#22FB1, IRGKangXi=0474.280, RSKangXi=66.10
22FB2 CJK UNIFIED IDEOGRAPH-#22FB2, IRGKangXi=0474.290, RSKangXi=66.10
22FB3 CJK UNIFIED IDEOGRAPH-#22FB3, IRGKangXi=0474.300, RSKangXi=66.10
22FB4 CJK UNIFIED IDEOGRAPH-#22FB4, IRGKangXi=0474.330, RSKangXi=66.10
22FB5 CJK UNIFIED IDEOGRAPH-#22FB5, IRGKangXi=0474.340, RSKangXi=66.10
22FB6 CJK UNIFIED IDEOGRAPH-#22FB6, IRGKangXi=0474.360, RSKangXi=66.10
22FB7 CJK UNIFIED IDEOGRAPH-#22FB7, IRGKangXi=0474.370, RSKangXi=66.10
22FB8 CJK UNIFIED IDEOGRAPH-#22FB8, IRGKangXi=0474.380, RSKangXi=66.10
22FB9 CJK UNIFIED IDEOGRAPH-#22FB9, IRGKangXi=0474.390, RSKangXi=66.10
22FBA CJK UNIFIED IDEOGRAPH-#22FBA, IRGKangXi=0474.400, RSKangXi=66.10
22FBB CJK UNIFIED IDEOGRAPH-#22FBB, IRGKangXi=0474.401, RSKangXi=66.10
22FBC CJK UNIFIED IDEOGRAPH-#22FBC, IRGKangXi=0474.401, RSKangXi=66.10
22FBD CJK UNIFIED IDEOGRAPH-#22FBD, IRGKangXi=0474.401, RSKangXi=66.10
22FBE CJK UNIFIED IDEOGRAPH-#22FBE, IRGKangXi=0474.401, RSKangXi=66.10
22FBF CJK UNIFIED IDEOGRAPH-#22FBF, IRGKangXi=0474.401, RSKangXi=66.10
22FC0 CJK UNIFIED IDEOGRAPH-#22FC0, IRGKangXi=0474.401, RSKangXi=66.10
22FC1 CJK UNIFIED IDEOGRAPH-#22FC1, IRGKangXi=0474.401, RSKangXi=66.10
22FC2 CJK UNIFIED IDEOGRAPH-#22FC2, IRGKangXi=0474.401, RSKangXi=66.10
22FC3 CJK UNIFIED IDEOGRAPH-#22FC3, IRGKangXi=0474.401, RSKangXi=66.10
22FC4 CJK UNIFIED IDEOGRAPH-#22FC4, IRGKangXi=0474.401, RSKangXi=66.10
22FC5 CJK UNIFIED IDEOGRAPH-#22FC5, IRGKangXi=0474.401, RSKangXi=66.10
22FC6 CJK UNIFIED IDEOGRAPH-#22FC6, IRGKangXi=0474.401, RSKangXi=113.9
22FC7 CJK UNIFIED IDEOGRAPH-#22FC7, IRGKangXi=0474.410, RSKangXi=66.11
22FC8 CJK UNIFIED IDEOGRAPH-#22FC8, IRGKangXi=0474.430, RSKangXi=66.11
22FC9 CJK UNIFIED IDEOGRAPH-#22FC9, IRGKangXi=0474.440, RSKangXi=66.11
22FCA CJK UNIFIED IDEOGRAPH-#22FCA, IRGKangXi=0474.450, RSKangXi=66.11
22FCB CJK UNIFIED IDEOGRAPH-#22FCB, IRGKangXi=0474.460, RSKangXi=66.11
22FCC CJK UNIFIED IDEOGRAPH-#22FCC, IRGKangXi=0474.490, RSKangXi=66.11
22FCD CJK UNIFIED IDEOGRAPH-#22FCD, IRGKangXi=0474.520, RSKangXi=66.11
22FCE CJK UNIFIED IDEOGRAPH-#22FCE, IRGKangXi=0475.010, RSKangXi=66.11
22FCF CJK UNIFIED IDEOGRAPH-#22FCF, IRGKangXi=0475.020, RSKangXi=66.11
22FD0 CJK UNIFIED IDEOGRAPH-#22FD0, IRGKangXi=0475.030, RSKangXi=66.11
22FD1 CJK UNIFIED IDEOGRAPH-#22FD1, IRGKangXi=0475.070, RSKangXi=66.11
22FD2 CJK UNIFIED IDEOGRAPH-#22FD2, IRGKangXi=0475.080, RSKangXi=66.11
22FD3 CJK UNIFIED IDEOGRAPH-#22FD3, IRGKangXi=0475.090, RSKangXi=66.11
22FD4 CJK UNIFIED IDEOGRAPH-#22FD4, IRGKangXi=0475.100, RSKangXi=66.11
22FD5 CJK UNIFIED IDEOGRAPH-#22FD5, IRGKangXi=0475.101, RSKangXi=66.11
22FD6 CJK UNIFIED IDEOGRAPH-#22FD6, IRGKangXi=0475.101, RSKangXi=66.11
22FD7 CJK UNIFIED IDEOGRAPH-#22FD7, IRGKangXi=0475.101, RSKangXi=66.11
22FD8 CJK UNIFIED IDEOGRAPH-#22FD8, IRGKangXi=0475.101, RSKangXi=66.11
22FD9 CJK UNIFIED IDEOGRAPH-#22FD9, IRGKangXi=0475.101, RSKangXi=66.11
22FDA CJK UNIFIED IDEOGRAPH-#22FDA, IRGKangXi=0475.101, RSKangXi=66.11
22FDB CJK UNIFIED IDEOGRAPH-#22FDB, IRGKangXi=0475.101, RSKangXi=66.11
22FDC CJK UNIFIED IDEOGRAPH-#22FDC, IRGKangXi=0475.101, RSKangXi=66.11
22FDD CJK UNIFIED IDEOGRAPH-#22FDD, IRGKangXi=0475.101, RSKangXi=66.11
22FDE CJK UNIFIED IDEOGRAPH-#22FDE, IRGKangXi=0475.110, RSKangXi=66.12
22FDF CJK UNIFIED IDEOGRAPH-#22FDF, IRGKangXi=0475.140, RSKangXi=66.12
22FE0 CJK UNIFIED IDEOGRAPH-#22FE0, IRGKangXi=0475.150, RSKangXi=66.12
22FE1 CJK UNIFIED IDEOGRAPH-#22FE1, IRGKangXi=0475.160, RSKangXi=66.12
22FE2 CJK UNIFIED IDEOGRAPH-#22FE2, IRGKangXi=0475.170, RSKangXi=66.12
22FE3 CJK UNIFIED IDEOGRAPH-#22FE3, IRGKangXi=0475.190, RSKangXi=66.12
22FE4 CJK UNIFIED IDEOGRAPH-#22FE4, IRGKangXi=0475.200, RSKangXi=66.12
22FE5 CJK UNIFIED IDEOGRAPH-#22FE5, IRGKangXi=0475.210, RSKangXi=66.12
22FE6 CJK UNIFIED IDEOGRAPH-#22FE6, IRGKangXi=0475.240, RSKangXi=66.12
22FE7 CJK UNIFIED IDEOGRAPH-#22FE7, IRGKangXi=0475.250, RSKangXi=66.12
22FE8 CJK UNIFIED IDEOGRAPH-#22FE8, IRGKangXi=0475.260, RSKangXi=66.13
22FE9 CJK UNIFIED IDEOGRAPH-#22FE9, IRGKangXi=0475.270, RSKangXi=66.12
22FEA CJK UNIFIED IDEOGRAPH-#22FEA, IRGKangXi=0475.280, RSKangXi=66.12
22FEB CJK UNIFIED IDEOGRAPH-#22FEB, IRGKangXi=0475.290, RSKangXi=66.12
22FEC CJK UNIFIED IDEOGRAPH-#22FEC, IRGKangXi=0475.300, RSKangXi=66.12
22FED CJK UNIFIED IDEOGRAPH-#22FED, IRGKangXi=0475.310, RSKangXi=66.12
22FEE CJK UNIFIED IDEOGRAPH-#22FEE, IRGKangXi=0475.320, RSKangXi=66.12
22FEF CJK UNIFIED IDEOGRAPH-#22FEF, IRGKangXi=0475.321, RSKangXi=66.12
22FF0 CJK UNIFIED IDEOGRAPH-#22FF0, IRGKangXi=0475.321, RSKangXi=66.12
22FF1 CJK UNIFIED IDEOGRAPH-#22FF1, IRGKangXi=0475.321, RSKangXi=66.12
22FF2 CJK UNIFIED IDEOGRAPH-#22FF2, IRGKangXi=0475.321, RSKangXi=66.12
22FF3 CJK UNIFIED IDEOGRAPH-#22FF3, IRGKangXi=0475.321, RSKangXi=66.12
22FF4 CJK UNIFIED IDEOGRAPH-#22FF4, IRGKangXi=0475.321, RSKangXi=66.12
22FF5 CJK UNIFIED IDEOGRAPH-#22FF5, IRGKangXi=0475.321, RSKangXi=66.12
22FF6 CJK UNIFIED IDEOGRAPH-#22FF6, IRGKangXi=0475.321, RSKangXi=66.12
22FF7 CJK UNIFIED IDEOGRAPH-#22FF7, IRGKangXi=0475.321, RSKangXi=66.12
22FF8 CJK UNIFIED IDEOGRAPH-#22FF8, IRGKangXi=0475.321, RSKangXi=66.12
22FF9 CJK UNIFIED IDEOGRAPH-#22FF9, IRGKangXi=0475.321, RSKangXi=66.12
22FFA CJK UNIFIED IDEOGRAPH-#22FFA, IRGKangXi=0475.321, RSKangXi=66.12
22FFB CJK UNIFIED IDEOGRAPH-#22FFB, IRGKangXi=0475.321, RSKangXi=66.12
22FFC CJK UNIFIED IDEOGRAPH-#22FFC, IRGKangXi=0475.321, RSKangXi=66.12
22FFD CJK UNIFIED IDEOGRAPH-#22FFD, IRGKangXi=0475.321, RSKangXi=66.12
22FFE CJK UNIFIED IDEOGRAPH-#22FFE, IRGKangXi=0475.330, RSKangXi=66.13
22FFF CJK UNIFIED IDEOGRAPH-#22FFF, IRGKangXi=0475.340, RSKangXi=66.13
23000 CJK UNIFIED IDEOGRAPH-#23000, IRGKangXi=0475.350, RSKangXi=66.13
23001 CJK UNIFIED IDEOGRAPH-#23001, IRGKangXi=0475.360, RSKangXi=66.13
23002 CJK UNIFIED IDEOGRAPH-#23002, IRGKangXi=0475.370, RSKangXi=66.13
23003 CJK UNIFIED IDEOGRAPH-#23003, IRGKangXi=0475.380, RSKangXi=66.13
23004 CJK UNIFIED IDEOGRAPH-#23004, IRGKangXi=0476.030, RSKangXi=66.14
23005 CJK UNIFIED IDEOGRAPH-#23005, IRGKangXi=0476.031, RSKangXi=66.13
23006 CJK UNIFIED IDEOGRAPH-#23006, IRGKangXi=0476.031, RSKangXi=66.13
23007 CJK UNIFIED IDEOGRAPH-#23007, IRGKangXi=0476.031, RSKangXi=66.13
23008 CJK UNIFIED IDEOGRAPH-#23008, IRGKangXi=0476.031, RSKangXi=66.13
23009 CJK UNIFIED IDEOGRAPH-#23009, IRGKangXi=0476.031, RSKangXi=66.13
2300A CJK UNIFIED IDEOGRAPH-#2300A, IRGKangXi=0476.031, RSKangXi=66.13
2300B CJK UNIFIED IDEOGRAPH-#2300B, IRGKangXi=0476.031, RSKangXi=66.13
2300C CJK UNIFIED IDEOGRAPH-#2300C, IRGKangXi=0476.031, RSKangXi=66.13
2300D CJK UNIFIED IDEOGRAPH-#2300D, IRGKangXi=0476.031, RSKangXi=66.13
2300E CJK UNIFIED IDEOGRAPH-#2300E, IRGKangXi=0476.031, RSKangXi=66.13
2300F CJK UNIFIED IDEOGRAPH-#2300F, IRGKangXi=0476.031, RSKangXi=66.13
23010 CJK UNIFIED IDEOGRAPH-#23010, IRGKangXi=0476.040, RSKangXi=66.14
23011 CJK UNIFIED IDEOGRAPH-#23011, IRGKangXi=0476.060, RSKangXi=66.14
23012 CJK UNIFIED IDEOGRAPH-#23012, IRGKangXi=0476.070, RSKangXi=66.14, Def{to enter abruptly, a nod}
23013 CJK UNIFIED IDEOGRAPH-#23013, IRGKangXi=0476.100, RSKangXi=66.14
23014 CJK UNIFIED IDEOGRAPH-#23014, IRGKangXi=0476.110, RSKangXi=66.14
23015 CJK UNIFIED IDEOGRAPH-#23015, IRGKangXi=0476.120, RSKangXi=66.14
23016 CJK UNIFIED IDEOGRAPH-#23016, IRGKangXi=0476.130, RSKangXi=66.14
23017 CJK UNIFIED IDEOGRAPH-#23017, IRGKangXi=0476.131, RSKangXi=66.14
23018 CJK UNIFIED IDEOGRAPH-#23018, IRGKangXi=0476.131, RSKangXi=66.14
23019 CJK UNIFIED IDEOGRAPH-#23019, IRGKangXi=0476.131, RSKangXi=66.14
2301A CJK UNIFIED IDEOGRAPH-#2301A, IRGKangXi=0476.131, RSKangXi=66.14
2301B CJK UNIFIED IDEOGRAPH-#2301B, IRGKangXi=0476.140, RSKangXi=66.15
2301C CJK UNIFIED IDEOGRAPH-#2301C, IRGKangXi=0476.150, RSKangXi=66.15
2301D CJK UNIFIED IDEOGRAPH-#2301D, IRGKangXi=0476.160, RSKangXi=66.15
2301E CJK UNIFIED IDEOGRAPH-#2301E, IRGKangXi=0476.170, RSKangXi=66.15
2301F CJK UNIFIED IDEOGRAPH-#2301F, IRGKangXi=0476.191, RSKangXi=66.15
23020 CJK UNIFIED IDEOGRAPH-#23020, IRGKangXi=0476.191, RSKangXi=66.15
23021 CJK UNIFIED IDEOGRAPH-#23021, IRGKangXi=0476.191, RSKangXi=66.15
23022 CJK UNIFIED IDEOGRAPH-#23022, IRGKangXi=0476.191, RSKangXi=66.15
23023 CJK UNIFIED IDEOGRAPH-#23023, IRGKangXi=0476.210, RSKangXi=66.16
23024 CJK UNIFIED IDEOGRAPH-#23024, IRGKangXi=0476.220, RSKangXi=66.16
23025 CJK UNIFIED IDEOGRAPH-#23025, IRGKangXi=0476.240, RSKangXi=66.16
23026 CJK UNIFIED IDEOGRAPH-#23026, IRGKangXi=0476.250, RSKangXi=66.16
23027 CJK UNIFIED IDEOGRAPH-#23027, IRGKangXi=0476.260, RSKangXi=66.16
23028 CJK UNIFIED IDEOGRAPH-#23028, IRGKangXi=0476.270, RSKangXi=66.16
23029 CJK UNIFIED IDEOGRAPH-#23029, IRGKangXi=0476.271, RSKangXi=66.16
2302A CJK UNIFIED IDEOGRAPH-#2302A, IRGKangXi=0476.271, RSKangXi=66.16
2302B CJK UNIFIED IDEOGRAPH-#2302B, IRGKangXi=0476.271, RSKangXi=66.16
2302C CJK UNIFIED IDEOGRAPH-#2302C, IRGKangXi=0476.271, RSKangXi=66.16
2302D CJK UNIFIED IDEOGRAPH-#2302D, IRGKangXi=0476.271, RSKangXi=66.16
2302E CJK UNIFIED IDEOGRAPH-#2302E, IRGKangXi=0476.290, RSKangXi=66.17
2302F CJK UNIFIED IDEOGRAPH-#2302F, IRGKangXi=0476.300, RSKangXi=66.17
23030 CJK UNIFIED IDEOGRAPH-#23030, IRGKangXi=0476.310, RSKangXi=66.17
23031 CJK UNIFIED IDEOGRAPH-#23031, IRGKangXi=0476.311, RSKangXi=66.17
23032 CJK UNIFIED IDEOGRAPH-#23032, IRGKangXi=0476.311, RSKangXi=66.17
23033 CJK UNIFIED IDEOGRAPH-#23033, IRGKangXi=0476.320, RSKangXi=66.18
23034 CJK UNIFIED IDEOGRAPH-#23034, IRGKangXi=0476.321, RSKangXi=66.18
23035 CJK UNIFIED IDEOGRAPH-#23035, IRGKangXi=0476.330, RSKangXi=66.19
23036 CJK UNIFIED IDEOGRAPH-#23036, IRGKangXi=0476.340, RSKangXi=66.19
23037 CJK UNIFIED IDEOGRAPH-#23037, IRGKangXi=0476.350, RSKangXi=66.19
23038 CJK UNIFIED IDEOGRAPH-#23038, IRGKangXi=0476.360, RSKangXi=66.19
23039 CJK UNIFIED IDEOGRAPH-#23039, IRGKangXi=0476.361, RSKangXi=66.19
2303A CJK UNIFIED IDEOGRAPH-#2303A, IRGKangXi=0476.361, RSKangXi=66.19
2303B CJK UNIFIED IDEOGRAPH-#2303B, IRGKangXi=0476.370, RSKangXi=66.21
2303C CJK UNIFIED IDEOGRAPH-#2303C, IRGKangXi=0476.371, RSKangXi=66.21
2303D CJK UNIFIED IDEOGRAPH-#2303D, IRGKangXi=0476.371, RSKangXi=66.23
2303E CJK UNIFIED IDEOGRAPH-#2303E, IRGKangXi=0476.371, RSKangXi=66.23
2303F CJK UNIFIED IDEOGRAPH-#2303F, IRGKangXi=0476.371, RSKangXi=66.24
23040 CJK UNIFIED IDEOGRAPH-#23040, IRGKangXi=0476.371, RSKangXi=66.25
23041 CJK UNIFIED IDEOGRAPH-#23041, IRGKangXi=0477.011, RSKangXi=67.2
23042 CJK UNIFIED IDEOGRAPH-#23042, IRGKangXi=0477.011, RSKangXi=67.3
23043 CJK UNIFIED IDEOGRAPH-#23043, IRGKangXi=0477.011, RSKangXi=67.4
23044 CJK UNIFIED IDEOGRAPH-#23044, IRGKangXi=0477.011, RSKangXi=67.4
23045 CJK UNIFIED IDEOGRAPH-#23045, IRGKangXi=0477.011, RSKangXi=67.4
23046 CJK UNIFIED IDEOGRAPH-#23046, IRGKangXi=0477.011, RSKangXi=67.5
23047 CJK UNIFIED IDEOGRAPH-#23047, IRGKangXi=0477.011, RSKangXi=67.5
23048 CJK UNIFIED IDEOGRAPH-#23048, IRGKangXi=0477.011, RSKangXi=67.5
23049 CJK UNIFIED IDEOGRAPH-#23049, IRGKangXi=0477.011, RSKangXi=67.5
2304A CJK UNIFIED IDEOGRAPH-#2304A, IRGKangXi=0477.020, RSKangXi=67.6
2304B CJK UNIFIED IDEOGRAPH-#2304B, IRGKangXi=0477.030, RSKangXi=67.6
2304C CJK UNIFIED IDEOGRAPH-#2304C, IRGKangXi=0477.061, RSKangXi=67.6
2304D CJK UNIFIED IDEOGRAPH-#2304D, IRGKangXi=0477.061, RSKangXi=67.6
2304E CJK UNIFIED IDEOGRAPH-#2304E, IRGKangXi=0477.080, RSKangXi=67.7
2304F CJK UNIFIED IDEOGRAPH-#2304F, IRGKangXi=0477.090, RSKangXi=67.7
23050 CJK UNIFIED IDEOGRAPH-#23050, IRGKangXi=0477.091, RSKangXi=67.7
23051 CJK UNIFIED IDEOGRAPH-#23051, IRGKangXi=0477.091, RSKangXi=67.7
23052 CJK UNIFIED IDEOGRAPH-#23052, IRGKangXi=0477.091, RSKangXi=67.7
23053 CJK UNIFIED IDEOGRAPH-#23053, IRGKangXi=0477.091, RSKangXi=67.7
23054 CJK UNIFIED IDEOGRAPH-#23054, IRGKangXi=0477.111, RSKangXi=67.8
23055 CJK UNIFIED IDEOGRAPH-#23055, IRGKangXi=0477.111, RSKangXi=67.8
23056 CJK UNIFIED IDEOGRAPH-#23056, IRGKangXi=0477.111, RSKangXi=67.8
23057 CJK UNIFIED IDEOGRAPH-#23057, IRGKangXi=0477.140, RSKangXi=67.9
23058 CJK UNIFIED IDEOGRAPH-#23058, IRGKangXi=0477.141, RSKangXi=67.9
23059 CJK UNIFIED IDEOGRAPH-#23059, IRGKangXi=0477.141, RSKangXi=67.9
2305A CJK UNIFIED IDEOGRAPH-#2305A, IRGKangXi=0477.141, RSKangXi=67.8
2305B CJK UNIFIED IDEOGRAPH-#2305B, IRGKangXi=0477.150, RSKangXi=67.11
2305C CJK UNIFIED IDEOGRAPH-#2305C, IRGKangXi=0477.160, RSKangXi=67.11
2305D CJK UNIFIED IDEOGRAPH-#2305D, IRGKangXi=0477.170, RSKangXi=67.11
2305E CJK UNIFIED IDEOGRAPH-#2305E, IRGKangXi=0477.180, RSKangXi=67.11
2305F CJK UNIFIED IDEOGRAPH-#2305F, IRGKangXi=0477.181, RSKangXi=67.11
23060 CJK UNIFIED IDEOGRAPH-#23060, IRGKangXi=0477.181, RSKangXi=67.11
23061 CJK UNIFIED IDEOGRAPH-#23061, IRGKangXi=0477.181, RSKangXi=67.11
23062 CJK UNIFIED IDEOGRAPH-#23062, IRGKangXi=0477.190, RSKangXi=67.12
23063 CJK UNIFIED IDEOGRAPH-#23063, IRGKangXi=0477.200, RSKangXi=67.12
23064 CJK UNIFIED IDEOGRAPH-#23064, IRGKangXi=0477.201, RSKangXi=67.13
23065 CJK UNIFIED IDEOGRAPH-#23065, IRGKangXi=0477.201, RSKangXi=67.14
23066 CJK UNIFIED IDEOGRAPH-#23066, IRGKangXi=0477.201, RSKangXi=67.14
23067 CJK UNIFIED IDEOGRAPH-#23067, IRGKangXi=0477.211, RSKangXi=67.15
23068 CJK UNIFIED IDEOGRAPH-#23068, IRGKangXi=0477.211, RSKangXi=67.16
23069 CJK UNIFIED IDEOGRAPH-#23069, IRGKangXi=0477.221, RSKangXi=67.17
2306A CJK UNIFIED IDEOGRAPH-#2306A, IRGKangXi=0477.221, RSKangXi=67.17
2306B CJK UNIFIED IDEOGRAPH-#2306B, IRGKangXi=0477.231, RSKangXi=67.19
2306C CJK UNIFIED IDEOGRAPH-#2306C, IRGKangXi=0478.010, RSKangXi=68.0
2306D CJK UNIFIED IDEOGRAPH-#2306D, IRGKangXi=0478.021, RSKangXi=68.3
2306E CJK UNIFIED IDEOGRAPH-#2306E, IRGKangXi=0478.031, RSKangXi=68.4
2306F CJK UNIFIED IDEOGRAPH-#2306F, IRGKangXi=0478.031, RSKangXi=68.4
23070 CJK UNIFIED IDEOGRAPH-#23070, IRGKangXi=0478.031, RSKangXi=68.4
23071 CJK UNIFIED IDEOGRAPH-#23071, IRGKangXi=0478.050, RSKangXi=68.5
23072 CJK UNIFIED IDEOGRAPH-#23072, IRGKangXi=0478.051, RSKangXi=68.5
23073 CJK UNIFIED IDEOGRAPH-#23073, IRGKangXi=0478.070, RSKangXi=68.6
23074 CJK UNIFIED IDEOGRAPH-#23074, IRGKangXi=0478.080, RSKangXi=68.6
23075 CJK UNIFIED IDEOGRAPH-#23075, IRGKangXi=0478.110, RSKangXi=68.6
23076 CJK UNIFIED IDEOGRAPH-#23076, IRGKangXi=0478.111, RSKangXi=68.6
23077 CJK UNIFIED IDEOGRAPH-#23077, IRGKangXi=0478.120, RSKangXi=68.7
23078 CJK UNIFIED IDEOGRAPH-#23078, IRGKangXi=0478.151, RSKangXi=68.7
23079 CJK UNIFIED IDEOGRAPH-#23079, IRGKangXi=0478.151, RSKangXi=68.7
2307A CJK UNIFIED IDEOGRAPH-#2307A, IRGKangXi=0478.151, RSKangXi=68.7
2307B CJK UNIFIED IDEOGRAPH-#2307B, IRGKangXi=0478.151, RSKangXi=68.7
2307C CJK UNIFIED IDEOGRAPH-#2307C, IRGKangXi=0478.170, RSKangXi=68.8
2307D CJK UNIFIED IDEOGRAPH-#2307D, IRGKangXi=0478.171, RSKangXi=68.8
2307E CJK UNIFIED IDEOGRAPH-#2307E, IRGKangXi=0478.171, RSKangXi=68.8
2307F CJK UNIFIED IDEOGRAPH-#2307F, IRGKangXi=0478.171, RSKangXi=68.8
23080 CJK UNIFIED IDEOGRAPH-#23080, IRGKangXi=0478.171, RSKangXi=68.8
23081 CJK UNIFIED IDEOGRAPH-#23081, IRGKangXi=0478.200, RSKangXi=68.9
23082 CJK UNIFIED IDEOGRAPH-#23082, IRGKangXi=0478.210, RSKangXi=68.10
23083 CJK UNIFIED IDEOGRAPH-#23083, IRGKangXi=0478.211, RSKangXi=68.9
23084 CJK UNIFIED IDEOGRAPH-#23084, IRGKangXi=0478.211, RSKangXi=68.9
23085 CJK UNIFIED IDEOGRAPH-#23085, IRGKangXi=0478.211, RSKangXi=68.9
23086 CJK UNIFIED IDEOGRAPH-#23086, IRGKangXi=0478.240, RSKangXi=68.10
23087 CJK UNIFIED IDEOGRAPH-#23087, IRGKangXi=0478.241, RSKangXi=68.10
23088 CJK UNIFIED IDEOGRAPH-#23088, IRGKangXi=0478.241, RSKangXi=68.10
23089 CJK UNIFIED IDEOGRAPH-#23089, IRGKangXi=0478.260, RSKangXi=68.11
2308A CJK UNIFIED IDEOGRAPH-#2308A, IRGKangXi=0478.270, RSKangXi=68.11
2308B CJK UNIFIED IDEOGRAPH-#2308B, IRGKangXi=0478.271, RSKangXi=68.11
2308C CJK UNIFIED IDEOGRAPH-#2308C, IRGKangXi=0479.020, RSKangXi=68.13
2308D CJK UNIFIED IDEOGRAPH-#2308D, IRGKangXi=0479.021, RSKangXi=68.13
2308E CJK UNIFIED IDEOGRAPH-#2308E, IRGKangXi=0479.021, RSKangXi=68.14
2308F CJK UNIFIED IDEOGRAPH-#2308F, IRGKangXi=0479.021, RSKangXi=68.15
23090 CJK UNIFIED IDEOGRAPH-#23090, IRGKangXi=0479.021, RSKangXi=68.16
23091 CJK UNIFIED IDEOGRAPH-#23091, IRGKangXi=0479.060, RSKangXi=69.0
23092 CJK UNIFIED IDEOGRAPH-#23092, IRGKangXi=0479.061, RSKangXi=69.2
23093 CJK UNIFIED IDEOGRAPH-#23093, IRGKangXi=0479.061, RSKangXi=69.3
23094 CJK UNIFIED IDEOGRAPH-#23094, IRGKangXi=0479.100, RSKangXi=69.4
23095 CJK UNIFIED IDEOGRAPH-#23095, IRGKangXi=0479.110, RSKangXi=69.4
23096 CJK UNIFIED IDEOGRAPH-#23096, IRGKangXi=0479.111, RSKangXi=69.4
23097 CJK UNIFIED IDEOGRAPH-#23097, IRGKangXi=0479.111, RSKangXi=69.4
23098 CJK UNIFIED IDEOGRAPH-#23098, IRGKangXi=0479.111, RSKangXi=69.4
23099 CJK UNIFIED IDEOGRAPH-#23099, IRGKangXi=0479.120, RSKangXi=69.5
2309A CJK UNIFIED IDEOGRAPH-#2309A, IRGKangXi=0479.151, RSKangXi=69.5
2309B CJK UNIFIED IDEOGRAPH-#2309B, IRGKangXi=0479.161, RSKangXi=69.6
2309C CJK UNIFIED IDEOGRAPH-#2309C, IRGKangXi=0479.161, RSKangXi=69.6
2309D CJK UNIFIED IDEOGRAPH-#2309D, IRGKangXi=0479.161, RSKangXi=69.6
2309E CJK UNIFIED IDEOGRAPH-#2309E, IRGKangXi=0479.170, RSKangXi=69.7
2309F CJK UNIFIED IDEOGRAPH-#2309F, IRGKangXi=0479.190, RSKangXi=69.7
230A0 CJK UNIFIED IDEOGRAPH-#230A0, IRGKangXi=0479.201, RSKangXi=69.7
230A1 CJK UNIFIED IDEOGRAPH-#230A1, IRGKangXi=0479.210, RSKangXi=69.8
230A2 CJK UNIFIED IDEOGRAPH-#230A2, IRGKangXi=0479.220, RSKangXi=69.8
230A3 CJK UNIFIED IDEOGRAPH-#230A3, IRGKangXi=0479.230, RSKangXi=69.8
230A4 CJK UNIFIED IDEOGRAPH-#230A4, IRGKangXi=0480.010, RSKangXi=69.8
230A5 CJK UNIFIED IDEOGRAPH-#230A5, IRGKangXi=0480.060, RSKangXi=69.8
230A6 CJK UNIFIED IDEOGRAPH-#230A6, IRGKangXi=0480.070, RSKangXi=69.8
230A7 CJK UNIFIED IDEOGRAPH-#230A7, IRGKangXi=0480.080, RSKangXi=69.8
230A8 CJK UNIFIED IDEOGRAPH-#230A8, IRGKangXi=0480.090, RSKangXi=69.8
230A9 CJK UNIFIED IDEOGRAPH-#230A9, IRGKangXi=0480.091, RSKangXi=69.8
230AA CJK UNIFIED IDEOGRAPH-#230AA, IRGKangXi=0480.091, RSKangXi=69.8
230AB CJK UNIFIED IDEOGRAPH-#230AB, IRGKangXi=0480.091, RSKangXi=113.7
230AC CJK UNIFIED IDEOGRAPH-#230AC, IRGKangXi=0480.091, RSKangXi=69.8
230AD CJK UNIFIED IDEOGRAPH-#230AD, IRGKangXi=0480.091, RSKangXi=69.8
230AE CJK UNIFIED IDEOGRAPH-#230AE, IRGKangXi=0480.130, RSKangXi=69.9
230AF CJK UNIFIED IDEOGRAPH-#230AF, IRGKangXi=0480.140, RSKangXi=69.9
230B0 CJK UNIFIED IDEOGRAPH-#230B0, IRGKangXi=0480.150, RSKangXi=69.9
230B1 CJK UNIFIED IDEOGRAPH-#230B1, IRGKangXi=0480.160, RSKangXi=69.9
230B2 CJK UNIFIED IDEOGRAPH-#230B2, IRGKangXi=0480.161, RSKangXi=69.9
230B3 CJK UNIFIED IDEOGRAPH-#230B3, IRGKangXi=0480.161, RSKangXi=69.9
230B4 CJK UNIFIED IDEOGRAPH-#230B4, IRGKangXi=0480.161, RSKangXi=69.9
230B5 CJK UNIFIED IDEOGRAPH-#230B5, IRGKangXi=0480.161, RSKangXi=69.9
230B6 CJK UNIFIED IDEOGRAPH-#230B6, IRGKangXi=0480.190, RSKangXi=69.10
230B7 CJK UNIFIED IDEOGRAPH-#230B7, IRGKangXi=0480.191, RSKangXi=69.10
230B8 CJK UNIFIED IDEOGRAPH-#230B8, IRGKangXi=0480.191, RSKangXi=69.10
230B9 CJK UNIFIED IDEOGRAPH-#230B9, IRGKangXi=0480.191, RSKangXi=69.10
230BA CJK UNIFIED IDEOGRAPH-#230BA, IRGKangXi=0480.191, RSKangXi=69.10
230BB CJK UNIFIED IDEOGRAPH-#230BB, IRGKangXi=0480.200, RSKangXi=69.11
230BC CJK UNIFIED IDEOGRAPH-#230BC, IRGKangXi=0480.220, RSKangXi=69.11
230BD CJK UNIFIED IDEOGRAPH-#230BD, IRGKangXi=0480.230, RSKangXi=69.11
230BE CJK UNIFIED IDEOGRAPH-#230BE, IRGKangXi=0480.231, RSKangXi=69.11
230BF CJK UNIFIED IDEOGRAPH-#230BF, IRGKangXi=0480.231, RSKangXi=69.11
230C0 CJK UNIFIED IDEOGRAPH-#230C0, IRGKangXi=0480.240, RSKangXi=69.12
230C1 CJK UNIFIED IDEOGRAPH-#230C1, IRGKangXi=0480.260, RSKangXi=69.12
230C2 CJK UNIFIED IDEOGRAPH-#230C2, IRGKangXi=0480.270, RSKangXi=69.12
230C3 CJK UNIFIED IDEOGRAPH-#230C3, IRGKangXi=0480.280, RSKangXi=69.12
230C4 CJK UNIFIED IDEOGRAPH-#230C4, IRGKangXi=0480.281, RSKangXi=69.12
230C5 CJK UNIFIED IDEOGRAPH-#230C5, IRGKangXi=0480.281, RSKangXi=69.12
230C6 CJK UNIFIED IDEOGRAPH-#230C6, IRGKangXi=0480.281, RSKangXi=69.12
230C7 CJK UNIFIED IDEOGRAPH-#230C7, IRGKangXi=0480.290, RSKangXi=69.13
230C8 CJK UNIFIED IDEOGRAPH-#230C8, IRGKangXi=0480.300, RSKangXi=69.13
230C9 CJK UNIFIED IDEOGRAPH-#230C9, IRGKangXi=0480.321, RSKangXi=69.13
230CA CJK UNIFIED IDEOGRAPH-#230CA, IRGKangXi=0480.321, RSKangXi=69.13
230CB CJK UNIFIED IDEOGRAPH-#230CB, IRGKangXi=0480.321, RSKangXi=69.13
230CC CJK UNIFIED IDEOGRAPH-#230CC, IRGKangXi=0480.330, RSKangXi=69.14
230CD CJK UNIFIED IDEOGRAPH-#230CD, IRGKangXi=0480.340, RSKangXi=69.14
230CE CJK UNIFIED IDEOGRAPH-#230CE, IRGKangXi=0480.381, RSKangXi=69.14
230CF CJK UNIFIED IDEOGRAPH-#230CF, IRGKangXi=0480.381, RSKangXi=69.14
230D0 CJK UNIFIED IDEOGRAPH-#230D0, IRGKangXi=0480.381, RSKangXi=69.14
230D1 CJK UNIFIED IDEOGRAPH-#230D1, IRGKangXi=0480.390, RSKangXi=69.15
230D2 CJK UNIFIED IDEOGRAPH-#230D2, IRGKangXi=0480.391, RSKangXi=69.15
230D3 CJK UNIFIED IDEOGRAPH-#230D3, IRGKangXi=0480.391, RSKangXi=69.15
230D4 CJK UNIFIED IDEOGRAPH-#230D4, IRGKangXi=0480.400, RSKangXi=69.16
230D5 CJK UNIFIED IDEOGRAPH-#230D5, IRGKangXi=0480.401, RSKangXi=69.16
230D6 CJK UNIFIED IDEOGRAPH-#230D6, IRGKangXi=0481.010, RSKangXi=69.18
230D7 CJK UNIFIED IDEOGRAPH-#230D7, IRGKangXi=0481.051, RSKangXi=70.2
230D8 CJK UNIFIED IDEOGRAPH-#230D8, IRGKangXi=0481.060, RSKangXi=70.3
230D9 CJK UNIFIED IDEOGRAPH-#230D9, IRGKangXi=0481.070, RSKangXi=70.3
230DA CJK UNIFIED IDEOGRAPH-#230DA, IRGKangXi=0481.131, RSKangXi=70.4
230DB CJK UNIFIED IDEOGRAPH-#230DB, IRGKangXi=0481.131, RSKangXi=70.4
230DC CJK UNIFIED IDEOGRAPH-#230DC, IRGKangXi=0481.131, RSKangXi=70.4
230DD CJK UNIFIED IDEOGRAPH-#230DD, IRGKangXi=0482.060, RSKangXi=70.5
230DE CJK UNIFIED IDEOGRAPH-#230DE, IRGKangXi=0482.080, RSKangXi=70.5
230DF CJK UNIFIED IDEOGRAPH-#230DF, IRGKangXi=0482.100, RSKangXi=70.5
230E0 CJK UNIFIED IDEOGRAPH-#230E0, IRGKangXi=0482.101, RSKangXi=70.5
230E1 CJK UNIFIED IDEOGRAPH-#230E1, IRGKangXi=0482.101, RSKangXi=70.5
230E2 CJK UNIFIED IDEOGRAPH-#230E2, IRGKangXi=0482.101, RSKangXi=70.5
230E3 CJK UNIFIED IDEOGRAPH-#230E3, IRGKangXi=0482.101, RSKangXi=70.5
230E4 CJK UNIFIED IDEOGRAPH-#230E4, IRGKangXi=0482.101, RSKangXi=70.5
230E5 CJK UNIFIED IDEOGRAPH-#230E5, IRGKangXi=0482.101, RSKangXi=70.5
230E6 CJK UNIFIED IDEOGRAPH-#230E6, IRGKangXi=0482.160, RSKangXi=70.6
230E7 CJK UNIFIED IDEOGRAPH-#230E7, IRGKangXi=0483.010, RSKangXi=70.6
230E8 CJK UNIFIED IDEOGRAPH-#230E8, IRGKangXi=0483.070, RSKangXi=70.6
230E9 CJK UNIFIED IDEOGRAPH-#230E9, IRGKangXi=0483.090, RSKangXi=70.6
230EA CJK UNIFIED IDEOGRAPH-#230EA, IRGKangXi=0483.100, RSKangXi=70.6
230EB CJK UNIFIED IDEOGRAPH-#230EB, IRGKangXi=0483.101, RSKangXi=70.6
230EC CJK UNIFIED IDEOGRAPH-#230EC, IRGKangXi=0483.101, RSKangXi=70.6
230ED CJK UNIFIED IDEOGRAPH-#230ED, IRGKangXi=0483.101, RSKangXi=70.6
230EE CJK UNIFIED IDEOGRAPH-#230EE, IRGKangXi=0483.101, RSKangXi=70.6
230EF CJK UNIFIED IDEOGRAPH-#230EF, IRGKangXi=0483.101, RSKangXi=70.6
230F0 CJK UNIFIED IDEOGRAPH-#230F0, IRGKangXi=0483.101, RSKangXi=70.6
230F1 CJK UNIFIED IDEOGRAPH-#230F1, IRGKangXi=0483.101, RSKangXi=70.6
230F2 CJK UNIFIED IDEOGRAPH-#230F2, IRGKangXi=0483.101, RSKangXi=70.6
230F3 CJK UNIFIED IDEOGRAPH-#230F3, IRGKangXi=0483.130, RSKangXi=70.7
230F4 CJK UNIFIED IDEOGRAPH-#230F4, IRGKangXi=0483.140, RSKangXi=70.7
230F5 CJK UNIFIED IDEOGRAPH-#230F5, IRGKangXi=0484.080, RSKangXi=70.7
230F6 CJK UNIFIED IDEOGRAPH-#230F6, IRGKangXi=0484.081, RSKangXi=70.7
230F7 CJK UNIFIED IDEOGRAPH-#230F7, IRGKangXi=0484.081, RSKangXi=70.7
230F8 CJK UNIFIED IDEOGRAPH-#230F8, IRGKangXi=0484.081, RSKangXi=70.7
230F9 CJK UNIFIED IDEOGRAPH-#230F9, IRGKangXi=0484.081, RSKangXi=70.7
230FA CJK UNIFIED IDEOGRAPH-#230FA, IRGKangXi=0484.081, RSKangXi=70.7
230FB CJK UNIFIED IDEOGRAPH-#230FB, IRGKangXi=0484.081, RSKangXi=70.7
230FC CJK UNIFIED IDEOGRAPH-#230FC, IRGKangXi=0484.090, RSKangXi=70.8
230FD CJK UNIFIED IDEOGRAPH-#230FD, IRGKangXi=0484.100, RSKangXi=70.8
230FE CJK UNIFIED IDEOGRAPH-#230FE, IRGKangXi=0484.110, RSKangXi=70.8
230FF CJK UNIFIED IDEOGRAPH-#230FF, IRGKangXi=0484.130, RSKangXi=70.8
23100 CJK UNIFIED IDEOGRAPH-#23100, IRGKangXi=0484.140, RSKangXi=70.8
23101 CJK UNIFIED IDEOGRAPH-#23101, IRGKangXi=0484.150, RSKangXi=70.8
23102 CJK UNIFIED IDEOGRAPH-#23102, IRGKangXi=0484.151, RSKangXi=70.8
23103 CJK UNIFIED IDEOGRAPH-#23103, IRGKangXi=0484.151, RSKangXi=70.8
23104 CJK UNIFIED IDEOGRAPH-#23104, IRGKangXi=0484.151, RSKangXi=70.8
23105 CJK UNIFIED IDEOGRAPH-#23105, IRGKangXi=0484.151, RSKangXi=70.8
23106 CJK UNIFIED IDEOGRAPH-#23106, IRGKangXi=0484.151, RSKangXi=70.8
23107 CJK UNIFIED IDEOGRAPH-#23107, IRGKangXi=0484.151, RSKangXi=70.8
23108 CJK UNIFIED IDEOGRAPH-#23108, IRGKangXi=0484.160, RSKangXi=70.9
23109 CJK UNIFIED IDEOGRAPH-#23109, IRGKangXi=0484.170, RSKangXi=70.9
2310A CJK UNIFIED IDEOGRAPH-#2310A, IRGKangXi=0484.220, RSKangXi=70.9
2310B CJK UNIFIED IDEOGRAPH-#2310B, IRGKangXi=0484.221, RSKangXi=70.9
2310C CJK UNIFIED IDEOGRAPH-#2310C, IRGKangXi=0484.221, RSKangXi=70.9
2310D CJK UNIFIED IDEOGRAPH-#2310D, IRGKangXi=0484.221, RSKangXi=70.9
2310E CJK UNIFIED IDEOGRAPH-#2310E, IRGKangXi=0484.230, RSKangXi=70.10
2310F CJK UNIFIED IDEOGRAPH-#2310F, IRGKangXi=0484.240, RSKangXi=70.10
23110 CJK UNIFIED IDEOGRAPH-#23110, IRGKangXi=0484.250, RSKangXi=70.10
23111 CJK UNIFIED IDEOGRAPH-#23111, IRGKangXi=0484.270, RSKangXi=70.10
23112 CJK UNIFIED IDEOGRAPH-#23112, IRGKangXi=0484.281, RSKangXi=70.10
23113 CJK UNIFIED IDEOGRAPH-#23113, IRGKangXi=0484.281, RSKangXi=70.10
23114 CJK UNIFIED IDEOGRAPH-#23114, IRGKangXi=0484.290, RSKangXi=70.11
23115 CJK UNIFIED IDEOGRAPH-#23115, IRGKangXi=0485.011, RSKangXi=70.11
23116 CJK UNIFIED IDEOGRAPH-#23116, IRGKangXi=0485.011, RSKangXi=70.11
23117 CJK UNIFIED IDEOGRAPH-#23117, IRGKangXi=0485.011, RSKangXi=70.12
23118 CJK UNIFIED IDEOGRAPH-#23118, IRGKangXi=0485.020, RSKangXi=70.12
23119 CJK UNIFIED IDEOGRAPH-#23119, IRGKangXi=0485.030, RSKangXi=70.12, Def{a sign for a tavern or shop}
2311A CJK UNIFIED IDEOGRAPH-#2311A, IRGKangXi=0485.050, RSKangXi=70.12
2311B CJK UNIFIED IDEOGRAPH-#2311B, IRGKangXi=0485.051, RSKangXi=70.12
2311C CJK UNIFIED IDEOGRAPH-#2311C, IRGKangXi=0485.051, RSKangXi=70.12
2311D CJK UNIFIED IDEOGRAPH-#2311D, IRGKangXi=0485.060, RSKangXi=70.13
2311E CJK UNIFIED IDEOGRAPH-#2311E, IRGKangXi=0485.080, RSKangXi=70.14
2311F CJK UNIFIED IDEOGRAPH-#2311F, IRGKangXi=0485.100, RSKangXi=70.14
23120 CJK UNIFIED IDEOGRAPH-#23120, IRGKangXi=0485.110, RSKangXi=70.14
23121 CJK UNIFIED IDEOGRAPH-#23121, IRGKangXi=0485.120, RSKangXi=70.14
23122 CJK UNIFIED IDEOGRAPH-#23122, IRGKangXi=0485.130, RSKangXi=70.14
23123 CJK UNIFIED IDEOGRAPH-#23123, IRGKangXi=0485.131, RSKangXi=70.14
23124 CJK UNIFIED IDEOGRAPH-#23124, IRGKangXi=0485.161, RSKangXi=70.15
23125 CJK UNIFIED IDEOGRAPH-#23125, IRGKangXi=0485.171, RSKangXi=70.16
23126 CJK UNIFIED IDEOGRAPH-#23126, IRGKangXi=0485.180, RSKangXi=70.17
23127 CJK UNIFIED IDEOGRAPH-#23127, IRGKangXi=0485.190, RSKangXi=70.18
23128 CJK UNIFIED IDEOGRAPH-#23128, IRGKangXi=0485.200, RSKangXi=70.18
23129 CJK UNIFIED IDEOGRAPH-#23129, IRGKangXi=0485.211, RSKangXi=70.19
2312A CJK UNIFIED IDEOGRAPH-#2312A, IRGKangXi=0485.220, RSKangXi=70.20
2312B CJK UNIFIED IDEOGRAPH-#2312B, IRGKangXi=0485.221, RSKangXi=70.21
2312C CJK UNIFIED IDEOGRAPH-#2312C, IRGKangXi=0485.221, RSKangXi=70.22
2312D CJK UNIFIED IDEOGRAPH-#2312D, IRGKangXi=0485.261, RSKangXi=71.2
2312E CJK UNIFIED IDEOGRAPH-#2312E, IRGKangXi=0485.270, RSKangXi=71.3
2312F CJK UNIFIED IDEOGRAPH-#2312F, IRGKangXi=0485.271, RSKangXi=71.3
23130 CJK UNIFIED IDEOGRAPH-#23130, IRGKangXi=0485.271, RSKangXi=71.5
23131 CJK UNIFIED IDEOGRAPH-#23131, IRGKangXi=0485.280, RSKangXi=71.6
23132 CJK UNIFIED IDEOGRAPH-#23132, IRGKangXi=0485.290, RSKangXi=71.6
23133 CJK UNIFIED IDEOGRAPH-#23133, IRGKangXi=0485.291, RSKangXi=71.6
23134 CJK UNIFIED IDEOGRAPH-#23134, IRGKangXi=0485.320, RSKangXi=71.8
23135 CJK UNIFIED IDEOGRAPH-#23135, IRGKangXi=0485.330, RSKangXi=71.8
23136 CJK UNIFIED IDEOGRAPH-#23136, IRGKangXi=0485.340, RSKangXi=71.9
23137 CJK UNIFIED IDEOGRAPH-#23137, IRGKangXi=0485.360, RSKangXi=71.9
23138 CJK UNIFIED IDEOGRAPH-#23138, IRGKangXi=0485.370, RSKangXi=71.9
23139 CJK UNIFIED IDEOGRAPH-#23139, IRGKangXi=0485.371, RSKangXi=71.11
2313A CJK UNIFIED IDEOGRAPH-#2313A, IRGKangXi=0485.371, RSKangXi=71.12
2313B CJK UNIFIED IDEOGRAPH-#2313B, IRGKangXi=0489.040, RSKangXi=72.1
2313C CJK UNIFIED IDEOGRAPH-#2313C, IRGKangXi=0489.050, RSKangXi=72.1
2313D CJK UNIFIED IDEOGRAPH-#2313D, IRGKangXi=0489.051, RSKangXi=72.1
2313E CJK UNIFIED IDEOGRAPH-#2313E, IRGKangXi=0489.140, RSKangXi=72.2
2313F CJK UNIFIED IDEOGRAPH-#2313F, IRGKangXi=0490.020, RSKangXi=72.2
23140 CJK UNIFIED IDEOGRAPH-#23140, IRGKangXi=0490.030, RSKangXi=72.2
23141 CJK UNIFIED IDEOGRAPH-#23141, IRGKangXi=0490.041, RSKangXi=72.2
23142 CJK UNIFIED IDEOGRAPH-#23142, IRGKangXi=0490.041, RSKangXi=72.2
23143 CJK UNIFIED IDEOGRAPH-#23143, IRGKangXi=0490.041, RSKangXi=72.2
23144 CJK UNIFIED IDEOGRAPH-#23144, IRGKangXi=0490.041, RSKangXi=72.3
23145 CJK UNIFIED IDEOGRAPH-#23145, IRGKangXi=0490.041, RSKangXi=72.2
23146 CJK UNIFIED IDEOGRAPH-#23146, IRGKangXi=0490.080, RSKangXi=72.3
23147 CJK UNIFIED IDEOGRAPH-#23147, IRGKangXi=0490.100, RSKangXi=72.3
23148 CJK UNIFIED IDEOGRAPH-#23148, IRGKangXi=0490.110, RSKangXi=72.3
23149 CJK UNIFIED IDEOGRAPH-#23149, IRGKangXi=0490.120, RSKangXi=72.3
2314A CJK UNIFIED IDEOGRAPH-#2314A, IRGKangXi=0490.170, RSKangXi=72.3
2314B CJK UNIFIED IDEOGRAPH-#2314B, IRGKangXi=0490.180, RSKangXi=72.3
2314C CJK UNIFIED IDEOGRAPH-#2314C, IRGKangXi=0490.190, RSKangXi=72.3
2314D CJK UNIFIED IDEOGRAPH-#2314D, IRGKangXi=0490.200, RSKangXi=72.3
2314E CJK UNIFIED IDEOGRAPH-#2314E, IRGKangXi=0490.210, RSKangXi=72.3
2314F CJK UNIFIED IDEOGRAPH-#2314F, IRGKangXi=0490.221, RSKangXi=72.3
23150 CJK UNIFIED IDEOGRAPH-#23150, IRGKangXi=0490.221, RSKangXi=72.3
23151 CJK UNIFIED IDEOGRAPH-#23151, IRGKangXi=0490.221, RSKangXi=72.3
23152 CJK UNIFIED IDEOGRAPH-#23152, IRGKangXi=0490.221, RSKangXi=72.3
23153 CJK UNIFIED IDEOGRAPH-#23153, IRGKangXi=0490.221, RSKangXi=72.3
23154 CJK UNIFIED IDEOGRAPH-#23154, IRGKangXi=0490.221, RSKangXi=72.3
23155 CJK UNIFIED IDEOGRAPH-#23155, IRGKangXi=0490.221, RSKangXi=72.3
23156 CJK UNIFIED IDEOGRAPH-#23156, IRGKangXi=0490.221, RSKangXi=72.3
23157 CJK UNIFIED IDEOGRAPH-#23157, IRGKangXi=0490.221, RSKangXi=72.3
23158 CJK UNIFIED IDEOGRAPH-#23158, IRGKangXi=0490.221, RSKangXi=72.3
23159 CJK UNIFIED IDEOGRAPH-#23159, IRGKangXi=0490.221, RSKangXi=72.3
2315A CJK UNIFIED IDEOGRAPH-#2315A, IRGKangXi=0490.290, RSKangXi=72.4
2315B CJK UNIFIED IDEOGRAPH-#2315B, IRGKangXi=0490.340, RSKangXi=72.4
2315C CJK UNIFIED IDEOGRAPH-#2315C, IRGKangXi=0491.010, RSKangXi=72.4
2315D CJK UNIFIED IDEOGRAPH-#2315D, IRGKangXi=0491.060, RSKangXi=72.4
2315E CJK UNIFIED IDEOGRAPH-#2315E, IRGKangXi=0491.090, RSKangXi=72.4
2315F CJK UNIFIED IDEOGRAPH-#2315F, IRGKangXi=0491.170, RSKangXi=72.4
23160 CJK UNIFIED IDEOGRAPH-#23160, IRGKangXi=0491.200, RSKangXi=72.4
23161 CJK UNIFIED IDEOGRAPH-#23161, IRGKangXi=0492.040, RSKangXi=72.4
23162 CJK UNIFIED IDEOGRAPH-#23162, IRGKangXi=0492.070, RSKangXi=72.4
23163 CJK UNIFIED IDEOGRAPH-#23163, IRGKangXi=0492.090, RSKangXi=72.4
23164 CJK UNIFIED IDEOGRAPH-#23164, IRGKangXi=0492.100, RSKangXi=72.4
23165 CJK UNIFIED IDEOGRAPH-#23165, IRGKangXi=0492.110, RSKangXi=72.4
23166 CJK UNIFIED IDEOGRAPH-#23166, IRGKangXi=0492.120, RSKangXi=72.4
23167 CJK UNIFIED IDEOGRAPH-#23167, IRGKangXi=0492.121, RSKangXi=72.4
23168 CJK UNIFIED IDEOGRAPH-#23168, IRGKangXi=0492.121, RSKangXi=72.4
23169 CJK UNIFIED IDEOGRAPH-#23169, IRGKangXi=0492.121, RSKangXi=72.4
2316A CJK UNIFIED IDEOGRAPH-#2316A, IRGKangXi=0492.121, RSKangXi=72.4
2316B CJK UNIFIED IDEOGRAPH-#2316B, IRGKangXi=0492.121, RSKangXi=72.4
2316C CJK UNIFIED IDEOGRAPH-#2316C, IRGKangXi=0492.121, RSKangXi=72.4
2316D CJK UNIFIED IDEOGRAPH-#2316D, IRGKangXi=0492.121, RSKangXi=72.4
2316E CJK UNIFIED IDEOGRAPH-#2316E, IRGKangXi=0492.121, RSKangXi=72.4
2316F CJK UNIFIED IDEOGRAPH-#2316F, IRGKangXi=0492.121, RSKangXi=72.4
23170 CJK UNIFIED IDEOGRAPH-#23170, IRGKangXi=0492.121, RSKangXi=72.4
23171 CJK UNIFIED IDEOGRAPH-#23171, IRGKangXi=0492.121, RSKangXi=72.4
23172 CJK UNIFIED IDEOGRAPH-#23172, IRGKangXi=0492.121, RSKangXi=72.4
23173 CJK UNIFIED IDEOGRAPH-#23173, IRGKangXi=0492.121, RSKangXi=72.4
23174 CJK UNIFIED IDEOGRAPH-#23174, IRGKangXi=0492.121, RSKangXi=72.4
23175 CJK UNIFIED IDEOGRAPH-#23175, IRGKangXi=0492.121, RSKangXi=72.4
23176 CJK UNIFIED IDEOGRAPH-#23176, IRGKangXi=0492.121, RSKangXi=72.4
23177 CJK UNIFIED IDEOGRAPH-#23177, IRGKangXi=0492.150, RSKangXi=72.5
23178 CJK UNIFIED IDEOGRAPH-#23178, IRGKangXi=0492.180, RSKangXi=72.5
23179 CJK UNIFIED IDEOGRAPH-#23179, IRGKangXi=0493.170, RSKangXi=72.5
2317A CJK UNIFIED IDEOGRAPH-#2317A, IRGKangXi=0493.250, RSKangXi=72.5
2317B CJK UNIFIED IDEOGRAPH-#2317B, IRGKangXi=0494.100, RSKangXi=72.5
2317C CJK UNIFIED IDEOGRAPH-#2317C, IRGKangXi=0494.110, RSKangXi=72.5
2317D CJK UNIFIED IDEOGRAPH-#2317D, IRGKangXi=0494.150, RSKangXi=72.5
2317E CJK UNIFIED IDEOGRAPH-#2317E, IRGKangXi=0494.160, RSKangXi=72.5
2317F CJK UNIFIED IDEOGRAPH-#2317F, IRGKangXi=0494.181, RSKangXi=72.5
23180 CJK UNIFIED IDEOGRAPH-#23180, IRGKangXi=0494.181, RSKangXi=72.5
23181 CJK UNIFIED IDEOGRAPH-#23181, IRGKangXi=0494.181, RSKangXi=72.5
23182 CJK UNIFIED IDEOGRAPH-#23182, IRGKangXi=0494.181, RSKangXi=72.5
23183 CJK UNIFIED IDEOGRAPH-#23183, IRGKangXi=0494.181, RSKangXi=72.5
23184 CJK UNIFIED IDEOGRAPH-#23184, IRGKangXi=0494.181, RSKangXi=72.5
23185 CJK UNIFIED IDEOGRAPH-#23185, IRGKangXi=0494.181, RSKangXi=72.5
23186 CJK UNIFIED IDEOGRAPH-#23186, IRGKangXi=0494.181, RSKangXi=72.5
23187 CJK UNIFIED IDEOGRAPH-#23187, IRGKangXi=0494.181, RSKangXi=72.5
23188 CJK UNIFIED IDEOGRAPH-#23188, IRGKangXi=0494.181, RSKangXi=72.5
23189 CJK UNIFIED IDEOGRAPH-#23189, IRGKangXi=0494.181, RSKangXi=73.5
2318A CJK UNIFIED IDEOGRAPH-#2318A, IRGKangXi=0494.181, RSKangXi=72.5
2318B CJK UNIFIED IDEOGRAPH-#2318B, IRGKangXi=0494.181, RSKangXi=72.5
2318C CJK UNIFIED IDEOGRAPH-#2318C, IRGKangXi=0494.181, RSKangXi=72.5
2318D CJK UNIFIED IDEOGRAPH-#2318D, IRGKangXi=0494.181, RSKangXi=72.5
2318E CJK UNIFIED IDEOGRAPH-#2318E, IRGKangXi=0494.181, RSKangXi=72.5
2318F CJK UNIFIED IDEOGRAPH-#2318F, IRGKangXi=0494.181, RSKangXi=72.5
23190 CJK UNIFIED IDEOGRAPH-#23190, IRGKangXi=0494.181, RSKangXi=72.5
23191 CJK UNIFIED IDEOGRAPH-#23191, IRGKangXi=0494.181, RSKangXi=72.5
23192 CJK UNIFIED IDEOGRAPH-#23192, IRGKangXi=0494.190, RSKangXi=72.6
23193 CJK UNIFIED IDEOGRAPH-#23193, IRGKangXi=0494.280, RSKangXi=72.6
23194 CJK UNIFIED IDEOGRAPH-#23194, IRGKangXi=0495.040, RSKangXi=72.6
23195 CJK UNIFIED IDEOGRAPH-#23195, IRGKangXi=0495.070, RSKangXi=72.6
23196 CJK UNIFIED IDEOGRAPH-#23196, IRGKangXi=0495.080, RSKangXi=72.6
23197 CJK UNIFIED IDEOGRAPH-#23197, IRGKangXi=0495.110, RSKangXi=72.6
23198 CJK UNIFIED IDEOGRAPH-#23198, IRGKangXi=0495.120, RSKangXi=72.6
23199 CJK UNIFIED IDEOGRAPH-#23199, IRGKangXi=0495.130, RSKangXi=72.6
2319A CJK UNIFIED IDEOGRAPH-#2319A, IRGKangXi=0495.170, RSKangXi=72.6
2319B CJK UNIFIED IDEOGRAPH-#2319B, IRGKangXi=0495.180, RSKangXi=72.6
2319C CJK UNIFIED IDEOGRAPH-#2319C, IRGKangXi=0495.190, RSKangXi=72.6
2319D CJK UNIFIED IDEOGRAPH-#2319D, IRGKangXi=0495.200, RSKangXi=72.6
2319E CJK UNIFIED IDEOGRAPH-#2319E, IRGKangXi=0495.220, RSKangXi=72.6
2319F CJK UNIFIED IDEOGRAPH-#2319F, IRGKangXi=0495.230, RSKangXi=72.6
231A0 CJK UNIFIED IDEOGRAPH-#231A0, IRGKangXi=0495.240, RSKangXi=72.6
231A1 CJK UNIFIED IDEOGRAPH-#231A1, IRGKangXi=0495.241, RSKangXi=72.6
231A2 CJK UNIFIED IDEOGRAPH-#231A2, IRGKangXi=0495.241, RSKangXi=72.6
231A3 CJK UNIFIED IDEOGRAPH-#231A3, IRGKangXi=0495.241, RSKangXi=72.6
231A4 CJK UNIFIED IDEOGRAPH-#231A4, IRGKangXi=0495.241, RSKangXi=72.6
231A5 CJK UNIFIED IDEOGRAPH-#231A5, IRGKangXi=0495.241, RSKangXi=72.6
231A6 CJK UNIFIED IDEOGRAPH-#231A6, IRGKangXi=0495.241, RSKangXi=72.6
231A7 CJK UNIFIED IDEOGRAPH-#231A7, IRGKangXi=0495.241, RSKangXi=72.6
231A8 CJK UNIFIED IDEOGRAPH-#231A8, IRGKangXi=0495.241, RSKangXi=72.6
231A9 CJK UNIFIED IDEOGRAPH-#231A9, IRGKangXi=0495.241, RSKangXi=72.6
231AA CJK UNIFIED IDEOGRAPH-#231AA, IRGKangXi=0495.241, RSKangXi=72.6
231AB CJK UNIFIED IDEOGRAPH-#231AB, IRGKangXi=0495.241, RSKangXi=72.6
231AC CJK UNIFIED IDEOGRAPH-#231AC, IRGKangXi=0495.241, RSKangXi=72.6
231AD CJK UNIFIED IDEOGRAPH-#231AD, IRGKangXi=0495.241, RSKangXi=72.6
231AE CJK UNIFIED IDEOGRAPH-#231AE, IRGKangXi=0495.241, RSKangXi=72.6
231AF CJK UNIFIED IDEOGRAPH-#231AF, IRGKangXi=0495.241, RSKangXi=72.6
231B0 CJK UNIFIED IDEOGRAPH-#231B0, IRGKangXi=0495.241, RSKangXi=72.6
231B1 CJK UNIFIED IDEOGRAPH-#231B1, IRGKangXi=0495.241, RSKangXi=72.6
231B2 CJK UNIFIED IDEOGRAPH-#231B2, IRGKangXi=0495.250, RSKangXi=72.7
231B3 CJK UNIFIED IDEOGRAPH-#231B3, IRGKangXi=0495.260, RSKangXi=72.7
231B4 CJK UNIFIED IDEOGRAPH-#231B4, IRGKangXi=0495.290, RSKangXi=72.7
231B5 CJK UNIFIED IDEOGRAPH-#231B5, IRGKangXi=0495.310, RSKangXi=72.7
231B6 CJK UNIFIED IDEOGRAPH-#231B6, IRGKangXi=0495.360, RSKangXi=72.7
231B7 CJK UNIFIED IDEOGRAPH-#231B7, IRGKangXi=0495.380, RSKangXi=72.7
231B8 CJK UNIFIED IDEOGRAPH-#231B8, IRGKangXi=0495.400, RSKangXi=72.7
231B9 CJK UNIFIED IDEOGRAPH-#231B9, IRGKangXi=0495.420, RSKangXi=72.7
231BA CJK UNIFIED IDEOGRAPH-#231BA, IRGKangXi=0496.050, RSKangXi=72.7
231BB CJK UNIFIED IDEOGRAPH-#231BB, IRGKangXi=0496.150, RSKangXi=72.7
231BC CJK UNIFIED IDEOGRAPH-#231BC, IRGKangXi=0496.160, RSKangXi=72.7
231BD CJK UNIFIED IDEOGRAPH-#231BD, IRGKangXi=0496.170, RSKangXi=72.7
231BE CJK UNIFIED IDEOGRAPH-#231BE, IRGKangXi=0496.190, RSKangXi=72.7
231BF CJK UNIFIED IDEOGRAPH-#231BF, IRGKangXi=0496.200, RSKangXi=72.7
231C0 CJK UNIFIED IDEOGRAPH-#231C0, IRGKangXi=0496.201, RSKangXi=72.7
231C1 CJK UNIFIED IDEOGRAPH-#231C1, IRGKangXi=0496.201, RSKangXi=72.7
231C2 CJK UNIFIED IDEOGRAPH-#231C2, IRGKangXi=0496.201, RSKangXi=72.7
231C3 CJK UNIFIED IDEOGRAPH-#231C3, IRGKangXi=0496.201, RSKangXi=72.7
231C4 CJK UNIFIED IDEOGRAPH-#231C4, IRGKangXi=0496.201, RSKangXi=72.7
231C5 CJK UNIFIED IDEOGRAPH-#231C5, IRGKangXi=0496.201, RSKangXi=72.7
231C6 CJK UNIFIED IDEOGRAPH-#231C6, IRGKangXi=0496.201, RSKangXi=72.7
231C7 CJK UNIFIED IDEOGRAPH-#231C7, IRGKangXi=0496.201, RSKangXi=72.7
231C8 CJK UNIFIED IDEOGRAPH-#231C8, IRGKangXi=0496.201, RSKangXi=72.7
231C9 CJK UNIFIED IDEOGRAPH-#231C9, IRGKangXi=0496.201, RSKangXi=72.7
231CA CJK UNIFIED IDEOGRAPH-#231CA, IRGKangXi=0496.201, RSKangXi=72.7
231CB CJK UNIFIED IDEOGRAPH-#231CB, IRGKangXi=0496.201, RSKangXi=72.7
231CC CJK UNIFIED IDEOGRAPH-#231CC, IRGKangXi=0496.201, RSKangXi=72.7
231CD CJK UNIFIED IDEOGRAPH-#231CD, IRGKangXi=0496.201, RSKangXi=72.7
231CE CJK UNIFIED IDEOGRAPH-#231CE, IRGKangXi=0496.201, RSKangXi=72.7
231CF CJK UNIFIED IDEOGRAPH-#231CF, IRGKangXi=0496.201, RSKangXi=72.7
231D0 CJK UNIFIED IDEOGRAPH-#231D0, IRGKangXi=0496.201, RSKangXi=72.7
231D1 CJK UNIFIED IDEOGRAPH-#231D1, IRGKangXi=0496.201, RSKangXi=72.7
231D2 CJK UNIFIED IDEOGRAPH-#231D2, IRGKangXi=0496.201, RSKangXi=72.7
231D3 CJK UNIFIED IDEOGRAPH-#231D3, IRGKangXi=0496.201, RSKangXi=72.7
231D4 CJK UNIFIED IDEOGRAPH-#231D4, IRGKangXi=0496.201, RSKangXi=72.7
231D5 CJK UNIFIED IDEOGRAPH-#231D5, IRGKangXi=0496.201, RSKangXi=72.7
231D6 CJK UNIFIED IDEOGRAPH-#231D6, IRGKangXi=0496.201, RSKangXi=72.7
231D7 CJK UNIFIED IDEOGRAPH-#231D7, IRGKangXi=0496.201, RSKangXi=72.7
231D8 CJK UNIFIED IDEOGRAPH-#231D8, IRGKangXi=0496.201, RSKangXi=72.7
231D9 CJK UNIFIED IDEOGRAPH-#231D9, IRGKangXi=0496.201, RSKangXi=72.7
231DA CJK UNIFIED IDEOGRAPH-#231DA, IRGKangXi=0496.201, RSKangXi=72.7
231DB CJK UNIFIED IDEOGRAPH-#231DB, IRGKangXi=0496.201, RSKangXi=72.7
231DC CJK UNIFIED IDEOGRAPH-#231DC, IRGKangXi=0496.201, RSKangXi=72.7
231DD CJK UNIFIED IDEOGRAPH-#231DD, IRGKangXi=0496.201, RSKangXi=72.7
231DE CJK UNIFIED IDEOGRAPH-#231DE, IRGKangXi=0496.201, RSKangXi=72.7
231DF CJK UNIFIED IDEOGRAPH-#231DF, IRGKangXi=0496.201, RSKangXi=72.7
231E0 CJK UNIFIED IDEOGRAPH-#231E0, IRGKangXi=0496.201, RSKangXi=72.7
231E1 CJK UNIFIED IDEOGRAPH-#231E1, IRGKangXi=0496.201, RSKangXi=72.7
231E2 CJK UNIFIED IDEOGRAPH-#231E2, IRGKangXi=0496.210, RSKangXi=72.8, Def{to try fruit, etc., in the sun}
231E3 CJK UNIFIED IDEOGRAPH-#231E3, IRGKangXi=0496.260, RSKangXi=72.8
231E4 CJK UNIFIED IDEOGRAPH-#231E4, IRGKangXi=0496.310, RSKangXi=72.8
231E5 CJK UNIFIED IDEOGRAPH-#231E5, IRGKangXi=0496.320, RSKangXi=72.8
231E6 CJK UNIFIED IDEOGRAPH-#231E6, IRGKangXi=0497.010, RSKangXi=72.8
231E7 CJK UNIFIED IDEOGRAPH-#231E7, IRGKangXi=0497.020, RSKangXi=72.8
231E8 CJK UNIFIED IDEOGRAPH-#231E8, IRGKangXi=0497.040, RSKangXi=72.8
231E9 CJK UNIFIED IDEOGRAPH-#231E9, IRGKangXi=0497.050, RSKangXi=72.8
231EA CJK UNIFIED IDEOGRAPH-#231EA, IRGKangXi=0497.070, RSKangXi=72.8
231EB CJK UNIFIED IDEOGRAPH-#231EB, IRGKangXi=0497.090, RSKangXi=72.8
231EC CJK UNIFIED IDEOGRAPH-#231EC, IRGKangXi=0497.110, RSKangXi=72.8
231ED CJK UNIFIED IDEOGRAPH-#231ED, IRGKangXi=0497.200, RSKangXi=72.8
231EE CJK UNIFIED IDEOGRAPH-#231EE, IRGKangXi=0497.220, RSKangXi=72.8
231EF CJK UNIFIED IDEOGRAPH-#231EF, IRGKangXi=0497.240, RSKangXi=72.8
231F0 CJK UNIFIED IDEOGRAPH-#231F0, IRGKangXi=0497.260, RSKangXi=72.8
231F1 CJK UNIFIED IDEOGRAPH-#231F1, IRGKangXi=0497.280, RSKangXi=72.8
231F2 CJK UNIFIED IDEOGRAPH-#231F2, IRGKangXi=0497.290, RSKangXi=72.8
231F3 CJK UNIFIED IDEOGRAPH-#231F3, IRGKangXi=0497.300, RSKangXi=72.8
231F4 CJK UNIFIED IDEOGRAPH-#231F4, IRGKangXi=0497.310, RSKangXi=72.8
231F5 CJK UNIFIED IDEOGRAPH-#231F5, IRGKangXi=0497.311, RSKangXi=72.8
231F6 CJK UNIFIED IDEOGRAPH-#231F6, IRGKangXi=0497.311, RSKangXi=72.8
231F7 CJK UNIFIED IDEOGRAPH-#231F7, IRGKangXi=0497.311, RSKangXi=72.8
231F8 CJK UNIFIED IDEOGRAPH-#231F8, IRGKangXi=0497.311, RSKangXi=72.8
231F9 CJK UNIFIED IDEOGRAPH-#231F9, IRGKangXi=0497.311, RSKangXi=72.8
231FA CJK UNIFIED IDEOGRAPH-#231FA, IRGKangXi=0497.311, RSKangXi=72.8
231FB CJK UNIFIED IDEOGRAPH-#231FB, IRGKangXi=0497.311, RSKangXi=72.8
231FC CJK UNIFIED IDEOGRAPH-#231FC, IRGKangXi=0497.311, RSKangXi=72.8
231FD CJK UNIFIED IDEOGRAPH-#231FD, IRGKangXi=0497.311, RSKangXi=72.8
231FE CJK UNIFIED IDEOGRAPH-#231FE, IRGKangXi=0497.311, RSKangXi=72.8
231FF CJK UNIFIED IDEOGRAPH-#231FF, IRGKangXi=0497.311, RSKangXi=72.8
23200 CJK UNIFIED IDEOGRAPH-#23200, IRGKangXi=0497.311, RSKangXi=72.8
23201 CJK UNIFIED IDEOGRAPH-#23201, IRGKangXi=0497.311, RSKangXi=72.8
23202 CJK UNIFIED IDEOGRAPH-#23202, IRGKangXi=0497.311, RSKangXi=72.8
23203 CJK UNIFIED IDEOGRAPH-#23203, IRGKangXi=0497.311, RSKangXi=72.8
23204 CJK UNIFIED IDEOGRAPH-#23204, IRGKangXi=0497.311, RSKangXi=72.8
23205 CJK UNIFIED IDEOGRAPH-#23205, IRGKangXi=0497.311, RSKangXi=72.8
23206 CJK UNIFIED IDEOGRAPH-#23206, IRGKangXi=0497.311, RSKangXi=72.8
23207 CJK UNIFIED IDEOGRAPH-#23207, IRGKangXi=0497.311, RSKangXi=72.8
23208 CJK UNIFIED IDEOGRAPH-#23208, IRGKangXi=0497.311, RSKangXi=72.8
23209 CJK UNIFIED IDEOGRAPH-#23209, IRGKangXi=0497.311, RSKangXi=72.8
2320A CJK UNIFIED IDEOGRAPH-#2320A, IRGKangXi=0497.311, RSKangXi=72.8
2320B CJK UNIFIED IDEOGRAPH-#2320B, IRGKangXi=0497.311, RSKangXi=72.8
2320C CJK UNIFIED IDEOGRAPH-#2320C, IRGKangXi=0497.311, RSKangXi=72.8
2320D CJK UNIFIED IDEOGRAPH-#2320D, IRGKangXi=0497.311, RSKangXi=72.8
2320E CJK UNIFIED IDEOGRAPH-#2320E, IRGKangXi=0497.311, RSKangXi=72.8
2320F CJK UNIFIED IDEOGRAPH-#2320F, IRGKangXi=0497.311, RSKangXi=72.8
23210 CJK UNIFIED IDEOGRAPH-#23210, IRGKangXi=0497.311, RSKangXi=72.8
23211 CJK UNIFIED IDEOGRAPH-#23211, IRGKangXi=0497.311, RSKangXi=72.8
23212 CJK UNIFIED IDEOGRAPH-#23212, IRGKangXi=0497.311, RSKangXi=72.8
23213 CJK UNIFIED IDEOGRAPH-#23213, IRGKangXi=0497.311, RSKangXi=72.8
23214 CJK UNIFIED IDEOGRAPH-#23214, IRGKangXi=0497.311, RSKangXi=72.8
23215 CJK UNIFIED IDEOGRAPH-#23215, IRGKangXi=0497.311, RSKangXi=72.8
23216 CJK UNIFIED IDEOGRAPH-#23216, IRGKangXi=0497.311, RSKangXi=72.8
23217 CJK UNIFIED IDEOGRAPH-#23217, IRGKangXi=0497.311, RSKangXi=72.8
23218 CJK UNIFIED IDEOGRAPH-#23218, IRGKangXi=0497.311, RSKangXi=72.8
23219 CJK UNIFIED IDEOGRAPH-#23219, IRGKangXi=0497.311, RSKangXi=72.8
2321A CJK UNIFIED IDEOGRAPH-#2321A, IRGKangXi=0497.311, RSKangXi=72.8
2321B CJK UNIFIED IDEOGRAPH-#2321B, IRGKangXi=0497.311, RSKangXi=72.8
2321C CJK UNIFIED IDEOGRAPH-#2321C, IRGKangXi=0497.311, RSKangXi=72.8
2321D CJK UNIFIED IDEOGRAPH-#2321D, IRGKangXi=0497.311, RSKangXi=72.8
2321E CJK UNIFIED IDEOGRAPH-#2321E, IRGKangXi=0497.311, RSKangXi=72.8
2321F CJK UNIFIED IDEOGRAPH-#2321F, IRGKangXi=0497.311, RSKangXi=72.8
23220 CJK UNIFIED IDEOGRAPH-#23220, IRGKangXi=0497.311, RSKangXi=72.8
23221 CJK UNIFIED IDEOGRAPH-#23221, IRGKangXi=0497.311, RSKangXi=72.8
23222 CJK UNIFIED IDEOGRAPH-#23222, IRGKangXi=0497.311, RSKangXi=72.8
23223 CJK UNIFIED IDEOGRAPH-#23223, IRGKangXi=0497.311, RSKangXi=72.8
23224 CJK UNIFIED IDEOGRAPH-#23224, IRGKangXi=0498.010, RSKangXi=72.9
23225 CJK UNIFIED IDEOGRAPH-#23225, IRGKangXi=0498.040, RSKangXi=72.9
23226 CJK UNIFIED IDEOGRAPH-#23226, IRGKangXi=0498.060, RSKangXi=72.9
23227 CJK UNIFIED IDEOGRAPH-#23227, IRGKangXi=0498.200, RSKangXi=72.9
23228 CJK UNIFIED IDEOGRAPH-#23228, IRGKangXi=0498.290, RSKangXi=72.9
23229 CJK UNIFIED IDEOGRAPH-#23229, IRGKangXi=0498.300, RSKangXi=72.9
2322A CJK UNIFIED IDEOGRAPH-#2322A, IRGKangXi=0498.310, RSKangXi=72.9
2322B CJK UNIFIED IDEOGRAPH-#2322B, IRGKangXi=0498.311, RSKangXi=72.9
2322C CJK UNIFIED IDEOGRAPH-#2322C, IRGKangXi=0498.311, RSKangXi=72.9
2322D CJK UNIFIED IDEOGRAPH-#2322D, IRGKangXi=0498.311, RSKangXi=72.9
2322E CJK UNIFIED IDEOGRAPH-#2322E, IRGKangXi=0498.311, RSKangXi=72.9
2322F CJK UNIFIED IDEOGRAPH-#2322F, IRGKangXi=0498.311, RSKangXi=72.9
23230 CJK UNIFIED IDEOGRAPH-#23230, IRGKangXi=0498.311, RSKangXi=72.9
23231 CJK UNIFIED IDEOGRAPH-#23231, IRGKangXi=0498.311, RSKangXi=72.9
23232 CJK UNIFIED IDEOGRAPH-#23232, IRGKangXi=0498.311, RSKangXi=72.9
23233 CJK UNIFIED IDEOGRAPH-#23233, IRGKangXi=0498.311, RSKangXi=72.9
23234 CJK UNIFIED IDEOGRAPH-#23234, IRGKangXi=0498.311, RSKangXi=72.9
23235 CJK UNIFIED IDEOGRAPH-#23235, IRGKangXi=0498.311, RSKangXi=72.9
23236 CJK UNIFIED IDEOGRAPH-#23236, IRGKangXi=0498.311, RSKangXi=72.9
23237 CJK UNIFIED IDEOGRAPH-#23237, IRGKangXi=0498.311, RSKangXi=72.9
23238 CJK UNIFIED IDEOGRAPH-#23238, IRGKangXi=0498.311, RSKangXi=72.9
23239 CJK UNIFIED IDEOGRAPH-#23239, IRGKangXi=0498.311, RSKangXi=72.9
2323A CJK UNIFIED IDEOGRAPH-#2323A, IRGKangXi=0498.311, RSKangXi=72.9
2323B CJK UNIFIED IDEOGRAPH-#2323B, IRGKangXi=0498.311, RSKangXi=72.9
2323C CJK UNIFIED IDEOGRAPH-#2323C, IRGKangXi=0498.311, RSKangXi=72.9
2323D CJK UNIFIED IDEOGRAPH-#2323D, IRGKangXi=0498.311, RSKangXi=72.9
2323E CJK UNIFIED IDEOGRAPH-#2323E, IRGKangXi=0498.311, RSKangXi=72.9
2323F CJK UNIFIED IDEOGRAPH-#2323F, IRGKangXi=0498.311, RSKangXi=72.9
23240 CJK UNIFIED IDEOGRAPH-#23240, IRGKangXi=0498.311, RSKangXi=72.9
23241 CJK UNIFIED IDEOGRAPH-#23241, IRGKangXi=0498.311, RSKangXi=72.9
23242 CJK UNIFIED IDEOGRAPH-#23242, IRGKangXi=0498.311, RSKangXi=72.9
23243 CJK UNIFIED IDEOGRAPH-#23243, IRGKangXi=0498.311, RSKangXi=72.9
23244 CJK UNIFIED IDEOGRAPH-#23244, IRGKangXi=0498.311, RSKangXi=72.9
23245 CJK UNIFIED IDEOGRAPH-#23245, IRGKangXi=0498.311, RSKangXi=72.9
23246 CJK UNIFIED IDEOGRAPH-#23246, IRGKangXi=0498.311, RSKangXi=72.9
23247 CJK UNIFIED IDEOGRAPH-#23247, IRGKangXi=0498.311, RSKangXi=72.9
23248 CJK UNIFIED IDEOGRAPH-#23248, IRGKangXi=0498.311, RSKangXi=72.9
23249 CJK UNIFIED IDEOGRAPH-#23249, IRGKangXi=0498.311, RSKangXi=72.9
2324A CJK UNIFIED IDEOGRAPH-#2324A, IRGKangXi=0498.311, RSKangXi=72.9
2324B CJK UNIFIED IDEOGRAPH-#2324B, IRGKangXi=0498.311, RSKangXi=72.9
2324C CJK UNIFIED IDEOGRAPH-#2324C, IRGKangXi=0498.311, RSKangXi=72.9
2324D CJK UNIFIED IDEOGRAPH-#2324D, IRGKangXi=0498.311, RSKangXi=72.9
2324E CJK UNIFIED IDEOGRAPH-#2324E, IRGKangXi=0498.311, RSKangXi=72.9
2324F CJK UNIFIED IDEOGRAPH-#2324F, IRGKangXi=0498.311, RSKangXi=72.9
23250 CJK UNIFIED IDEOGRAPH-#23250, IRGKangXi=0498.311, RSKangXi=72.9
23251 CJK UNIFIED IDEOGRAPH-#23251, IRGKangXi=0498.311, RSKangXi=72.9
23252 CJK UNIFIED IDEOGRAPH-#23252, IRGKangXi=0498.330, RSKangXi=72.10
23253 CJK UNIFIED IDEOGRAPH-#23253, IRGKangXi=0498.350, RSKangXi=72.10
23254 CJK UNIFIED IDEOGRAPH-#23254, IRGKangXi=0498.380, RSKangXi=72.10
23255 CJK UNIFIED IDEOGRAPH-#23255, IRGKangXi=0498.440, RSKangXi=72.10
23256 CJK UNIFIED IDEOGRAPH-#23256, IRGKangXi=0498.450, RSKangXi=72.10
23257 CJK UNIFIED IDEOGRAPH-#23257, IRGKangXi=0498.460, RSKangXi=72.10
23258 CJK UNIFIED IDEOGRAPH-#23258, IRGKangXi=0498.470, RSKangXi=72.10
23259 CJK UNIFIED IDEOGRAPH-#23259, IRGKangXi=0498.520, RSKangXi=72.10
2325A CJK UNIFIED IDEOGRAPH-#2325A, IRGKangXi=0498.530, RSKangXi=72.10
2325B CJK UNIFIED IDEOGRAPH-#2325B, IRGKangXi=0499.040, RSKangXi=72.10
2325C CJK UNIFIED IDEOGRAPH-#2325C, IRGKangXi=0499.050, RSKangXi=72.10
2325D CJK UNIFIED IDEOGRAPH-#2325D, IRGKangXi=0499.061, RSKangXi=72.10
2325E CJK UNIFIED IDEOGRAPH-#2325E, IRGKangXi=0499.061, RSKangXi=72.10, Def{white, clear}
2325F CJK UNIFIED IDEOGRAPH-#2325F, IRGKangXi=0499.061, RSKangXi=72.10
23260 CJK UNIFIED IDEOGRAPH-#23260, IRGKangXi=0499.061, RSKangXi=72.10
23261 CJK UNIFIED IDEOGRAPH-#23261, IRGKangXi=0499.061, RSKangXi=54.11
23262 CJK UNIFIED IDEOGRAPH-#23262, IRGKangXi=0499.061, RSKangXi=72.10
23263 CJK UNIFIED IDEOGRAPH-#23263, IRGKangXi=0499.061, RSKangXi=72.10
23264 CJK UNIFIED IDEOGRAPH-#23264, IRGKangXi=0499.061, RSKangXi=72.10
23265 CJK UNIFIED IDEOGRAPH-#23265, IRGKangXi=0499.061, RSKangXi=72.10
23266 CJK UNIFIED IDEOGRAPH-#23266, IRGKangXi=0499.061, RSKangXi=72.10
23267 CJK UNIFIED IDEOGRAPH-#23267, IRGKangXi=0499.061, RSKangXi=72.10
23268 CJK UNIFIED IDEOGRAPH-#23268, IRGKangXi=0499.061, RSKangXi=72.10
23269 CJK UNIFIED IDEOGRAPH-#23269, IRGKangXi=0499.061, RSKangXi=72.10
2326A CJK UNIFIED IDEOGRAPH-#2326A, IRGKangXi=0499.061, RSKangXi=72.10
2326B CJK UNIFIED IDEOGRAPH-#2326B, IRGKangXi=0499.061, RSKangXi=72.10
2326C CJK UNIFIED IDEOGRAPH-#2326C, IRGKangXi=0499.061, RSKangXi=72.10
2326D CJK UNIFIED IDEOGRAPH-#2326D, IRGKangXi=0499.061, RSKangXi=72.10
2326E CJK UNIFIED IDEOGRAPH-#2326E, IRGKangXi=0499.061, RSKangXi=72.10
2326F CJK UNIFIED IDEOGRAPH-#2326F, IRGKangXi=0499.061, RSKangXi=72.10
23270 CJK UNIFIED IDEOGRAPH-#23270, IRGKangXi=0499.061, RSKangXi=72.10
23271 CJK UNIFIED IDEOGRAPH-#23271, IRGKangXi=0499.061, RSKangXi=72.10
23272 CJK UNIFIED IDEOGRAPH-#23272, IRGKangXi=0499.061, RSKangXi=72.10
23273 CJK UNIFIED IDEOGRAPH-#23273, IRGKangXi=0499.061, RSKangXi=72.10
23274 CJK UNIFIED IDEOGRAPH-#23274, IRGKangXi=0499.061, RSKangXi=72.10
23275 CJK UNIFIED IDEOGRAPH-#23275, IRGKangXi=0499.061, RSKangXi=72.10
23276 CJK UNIFIED IDEOGRAPH-#23276, IRGKangXi=0499.061, RSKangXi=72.10
23277 CJK UNIFIED IDEOGRAPH-#23277, IRGKangXi=0499.061, RSKangXi=72.10
23278 CJK UNIFIED IDEOGRAPH-#23278, IRGKangXi=0499.061, RSKangXi=72.10
23279 CJK UNIFIED IDEOGRAPH-#23279, IRGKangXi=0499.061, RSKangXi=72.10
2327A CJK UNIFIED IDEOGRAPH-#2327A, IRGKangXi=0499.061, RSKangXi=72.10
2327B CJK UNIFIED IDEOGRAPH-#2327B, IRGKangXi=0499.080, RSKangXi=72.11
2327C CJK UNIFIED IDEOGRAPH-#2327C, IRGKangXi=0499.090, RSKangXi=72.11
2327D CJK UNIFIED IDEOGRAPH-#2327D, IRGKangXi=0499.110, RSKangXi=72.11
2327E CJK UNIFIED IDEOGRAPH-#2327E, IRGKangXi=0499.190, RSKangXi=72.11
2327F CJK UNIFIED IDEOGRAPH-#2327F, IRGKangXi=0499.200, RSKangXi=72.11
23280 CJK UNIFIED IDEOGRAPH-#23280, IRGKangXi=0499.240, RSKangXi=72.11
23281 CJK UNIFIED IDEOGRAPH-#23281, IRGKangXi=0499.270, RSKangXi=72.11
23282 CJK UNIFIED IDEOGRAPH-#23282, IRGKangXi=0499.330, RSKangXi=72.11
23283 CJK UNIFIED IDEOGRAPH-#23283, IRGKangXi=0499.340, RSKangXi=72.11
23284 CJK UNIFIED IDEOGRAPH-#23284, IRGKangXi=0499.350, RSKangXi=72.11
23285 CJK UNIFIED IDEOGRAPH-#23285, IRGKangXi=0499.360, RSKangXi=72.11
23286 CJK UNIFIED IDEOGRAPH-#23286, IRGKangXi=0499.361, RSKangXi=72.11
23287 CJK UNIFIED IDEOGRAPH-#23287, IRGKangXi=0499.361, RSKangXi=72.11
23288 CJK UNIFIED IDEOGRAPH-#23288, IRGKangXi=0499.361, RSKangXi=72.11
23289 CJK UNIFIED IDEOGRAPH-#23289, IRGKangXi=0499.361, RSKangXi=72.12
2328A CJK UNIFIED IDEOGRAPH-#2328A, IRGKangXi=0499.361, RSKangXi=72.11
2328B CJK UNIFIED IDEOGRAPH-#2328B, IRGKangXi=0499.361, RSKangXi=72.11
2328C CJK UNIFIED IDEOGRAPH-#2328C, IRGKangXi=0499.361, RSKangXi=72.11
2328D CJK UNIFIED IDEOGRAPH-#2328D, IRGKangXi=0499.361, RSKangXi=72.11
2328E CJK UNIFIED IDEOGRAPH-#2328E, IRGKangXi=0499.361, RSKangXi=72.11
2328F CJK UNIFIED IDEOGRAPH-#2328F, IRGKangXi=0499.361, RSKangXi=72.11
23290 CJK UNIFIED IDEOGRAPH-#23290, IRGKangXi=0499.361, RSKangXi=72.11
23291 CJK UNIFIED IDEOGRAPH-#23291, IRGKangXi=0499.361, RSKangXi=72.11
23292 CJK UNIFIED IDEOGRAPH-#23292, IRGKangXi=0499.361, RSKangXi=41.12
23293 CJK UNIFIED IDEOGRAPH-#23293, IRGKangXi=0499.361, RSKangXi=72.11
23294 CJK UNIFIED IDEOGRAPH-#23294, IRGKangXi=0499.361, RSKangXi=72.11
23295 CJK UNIFIED IDEOGRAPH-#23295, IRGKangXi=0499.361, RSKangXi=72.11
23296 CJK UNIFIED IDEOGRAPH-#23296, IRGKangXi=0499.361, RSKangXi=72.11
23297 CJK UNIFIED IDEOGRAPH-#23297, IRGKangXi=0499.361, RSKangXi=72.11
23298 CJK UNIFIED IDEOGRAPH-#23298, IRGKangXi=0499.361, RSKangXi=72.11
23299 CJK UNIFIED IDEOGRAPH-#23299, IRGKangXi=0499.361, RSKangXi=72.11
2329A CJK UNIFIED IDEOGRAPH-#2329A, IRGKangXi=0499.361, RSKangXi=72.11
2329B CJK UNIFIED IDEOGRAPH-#2329B, IRGKangXi=0499.361, RSKangXi=72.11
2329C CJK UNIFIED IDEOGRAPH-#2329C, IRGKangXi=0499.361, RSKangXi=72.11
2329D CJK UNIFIED IDEOGRAPH-#2329D, IRGKangXi=0499.361, RSKangXi=72.11
2329E CJK UNIFIED IDEOGRAPH-#2329E, IRGKangXi=0499.480, RSKangXi=72.12
2329F CJK UNIFIED IDEOGRAPH-#2329F, IRGKangXi=0499.500, RSKangXi=72.12
232A0 CJK UNIFIED IDEOGRAPH-#232A0, IRGKangXi=0500.140, RSKangXi=72.12
232A1 CJK UNIFIED IDEOGRAPH-#232A1, IRGKangXi=0500.150, RSKangXi=72.12
232A2 CJK UNIFIED IDEOGRAPH-#232A2, IRGKangXi=0500.190, RSKangXi=72.12
232A3 CJK UNIFIED IDEOGRAPH-#232A3, IRGKangXi=0500.200, RSKangXi=72.12
232A4 CJK UNIFIED IDEOGRAPH-#232A4, IRGKangXi=0500.210, RSKangXi=72.12
232A5 CJK UNIFIED IDEOGRAPH-#232A5, IRGKangXi=0500.220, RSKangXi=72.12
232A6 CJK UNIFIED IDEOGRAPH-#232A6, IRGKangXi=0500.230, RSKangXi=72.12
232A7 CJK UNIFIED IDEOGRAPH-#232A7, IRGKangXi=0500.240, RSKangXi=72.12
232A8 CJK UNIFIED IDEOGRAPH-#232A8, IRGKangXi=0500.250, RSKangXi=72.12
232A9 CJK UNIFIED IDEOGRAPH-#232A9, IRGKangXi=0500.251, RSKangXi=72.12
232AA CJK UNIFIED IDEOGRAPH-#232AA, IRGKangXi=0500.251, RSKangXi=72.12
232AB CJK UNIFIED IDEOGRAPH-#232AB, IRGKangXi=0500.251, RSKangXi=72.12
232AC CJK UNIFIED IDEOGRAPH-#232AC, IRGKangXi=0500.251, RSKangXi=72.12
232AD CJK UNIFIED IDEOGRAPH-#232AD, IRGKangXi=0500.251, RSKangXi=72.12
232AE CJK UNIFIED IDEOGRAPH-#232AE, IRGKangXi=0500.251, RSKangXi=72.12
232AF CJK UNIFIED IDEOGRAPH-#232AF, IRGKangXi=0500.251, RSKangXi=72.12
232B0 CJK UNIFIED IDEOGRAPH-#232B0, IRGKangXi=0500.251, RSKangXi=72.12
232B1 CJK UNIFIED IDEOGRAPH-#232B1, IRGKangXi=0500.251, RSKangXi=72.12
232B2 CJK UNIFIED IDEOGRAPH-#232B2, IRGKangXi=0500.251, RSKangXi=72.12
232B3 CJK UNIFIED IDEOGRAPH-#232B3, IRGKangXi=0500.251, RSKangXi=72.12
232B4 CJK UNIFIED IDEOGRAPH-#232B4, IRGKangXi=0500.251, RSKangXi=72.12
232B5 CJK UNIFIED IDEOGRAPH-#232B5, IRGKangXi=0500.251, RSKangXi=72.12
232B6 CJK UNIFIED IDEOGRAPH-#232B6, IRGKangXi=0500.251, RSKangXi=72.12
232B7 CJK UNIFIED IDEOGRAPH-#232B7, IRGKangXi=0500.251, RSKangXi=72.12
232B8 CJK UNIFIED IDEOGRAPH-#232B8, IRGKangXi=0500.251, RSKangXi=72.12
232B9 CJK UNIFIED IDEOGRAPH-#232B9, IRGKangXi=0500.251, RSKangXi=72.12
232BA CJK UNIFIED IDEOGRAPH-#232BA, IRGKangXi=0500.251, RSKangXi=72.12
232BB CJK UNIFIED IDEOGRAPH-#232BB, IRGKangXi=0500.251, RSKangXi=72.12
232BC CJK UNIFIED IDEOGRAPH-#232BC, IRGKangXi=0500.251, RSKangXi=72.12
232BD CJK UNIFIED IDEOGRAPH-#232BD, IRGKangXi=0500.251, RSKangXi=72.12
232BE CJK UNIFIED IDEOGRAPH-#232BE, IRGKangXi=0500.251, RSKangXi=72.12
232BF CJK UNIFIED IDEOGRAPH-#232BF, IRGKangXi=0500.251, RSKangXi=72.12
232C0 CJK UNIFIED IDEOGRAPH-#232C0, IRGKangXi=0500.251, RSKangXi=72.12
232C1 CJK UNIFIED IDEOGRAPH-#232C1, IRGKangXi=0500.251, RSKangXi=72.12
232C2 CJK UNIFIED IDEOGRAPH-#232C2, IRGKangXi=0500.251, RSKangXi=72.12
232C3 CJK UNIFIED IDEOGRAPH-#232C3, IRGKangXi=0500.251, RSKangXi=72.12
232C4 CJK UNIFIED IDEOGRAPH-#232C4, IRGKangXi=0500.251, RSKangXi=72.12
232C5 CJK UNIFIED IDEOGRAPH-#232C5, IRGKangXi=0500.251, RSKangXi=72.12
232C6 CJK UNIFIED IDEOGRAPH-#232C6, IRGKangXi=0500.251, RSKangXi=72.12
232C7 CJK UNIFIED IDEOGRAPH-#232C7, IRGKangXi=0500.251, RSKangXi=72.11
232C8 CJK UNIFIED IDEOGRAPH-#232C8, IRGKangXi=0500.251, RSKangXi=72.12
232C9 CJK UNIFIED IDEOGRAPH-#232C9, IRGKangXi=0500.300, RSKangXi=72.13
232CA CJK UNIFIED IDEOGRAPH-#232CA, IRGKangXi=0500.350, RSKangXi=72.13
232CB CJK UNIFIED IDEOGRAPH-#232CB, IRGKangXi=0500.390, RSKangXi=72.13
232CC CJK UNIFIED IDEOGRAPH-#232CC, IRGKangXi=0500.400, RSKangXi=72.13
232CD CJK UNIFIED IDEOGRAPH-#232CD, IRGKangXi=0500.430, RSKangXi=72.13
232CE CJK UNIFIED IDEOGRAPH-#232CE, IRGKangXi=0500.440, RSKangXi=72.13
232CF CJK UNIFIED IDEOGRAPH-#232CF, IRGKangXi=0500.450, RSKangXi=72.13
232D0 CJK UNIFIED IDEOGRAPH-#232D0, IRGKangXi=0500.460, RSKangXi=72.13
232D1 CJK UNIFIED IDEOGRAPH-#232D1, IRGKangXi=0500.461, RSKangXi=72.13
232D2 CJK UNIFIED IDEOGRAPH-#232D2, IRGKangXi=0500.461, RSKangXi=72.13
232D3 CJK UNIFIED IDEOGRAPH-#232D3, IRGKangXi=0500.461, RSKangXi=72.13
232D4 CJK UNIFIED IDEOGRAPH-#232D4, IRGKangXi=0500.461, RSKangXi=72.13
232D5 CJK UNIFIED IDEOGRAPH-#232D5, IRGKangXi=0500.461, RSKangXi=72.13
232D6 CJK UNIFIED IDEOGRAPH-#232D6, IRGKangXi=0500.461, RSKangXi=72.13
232D7 CJK UNIFIED IDEOGRAPH-#232D7, IRGKangXi=0500.461, RSKangXi=72.13
232D8 CJK UNIFIED IDEOGRAPH-#232D8, IRGKangXi=0500.461, RSKangXi=72.13
232D9 CJK UNIFIED IDEOGRAPH-#232D9, IRGKangXi=0500.461, RSKangXi=72.13
232DA CJK UNIFIED IDEOGRAPH-#232DA, IRGKangXi=0500.461, RSKangXi=72.13
232DB CJK UNIFIED IDEOGRAPH-#232DB, IRGKangXi=0500.461, RSKangXi=72.13
232DC CJK UNIFIED IDEOGRAPH-#232DC, IRGKangXi=0500.461, RSKangXi=72.13
232DD CJK UNIFIED IDEOGRAPH-#232DD, IRGKangXi=0500.461, RSKangXi=72.13
232DE CJK UNIFIED IDEOGRAPH-#232DE, IRGKangXi=0501.050, RSKangXi=72.14
232DF CJK UNIFIED IDEOGRAPH-#232DF, IRGKangXi=0501.060, RSKangXi=72.14
232E0 CJK UNIFIED IDEOGRAPH-#232E0, IRGKangXi=0501.131, RSKangXi=72.14
232E1 CJK UNIFIED IDEOGRAPH-#232E1, IRGKangXi=0501.131, RSKangXi=72.14
232E2 CJK UNIFIED IDEOGRAPH-#232E2, IRGKangXi=0501.131, RSKangXi=72.14
232E3 CJK UNIFIED IDEOGRAPH-#232E3, IRGKangXi=0501.131, RSKangXi=72.14
232E4 CJK UNIFIED IDEOGRAPH-#232E4, IRGKangXi=0501.131, RSKangXi=72.14
232E5 CJK UNIFIED IDEOGRAPH-#232E5, IRGKangXi=0501.131, RSKangXi=72.14
232E6 CJK UNIFIED IDEOGRAPH-#232E6, IRGKangXi=0501.131, RSKangXi=72.14
232E7 CJK UNIFIED IDEOGRAPH-#232E7, IRGKangXi=0501.131, RSKangXi=72.14
232E8 CJK UNIFIED IDEOGRAPH-#232E8, IRGKangXi=0501.131, RSKangXi=72.14
232E9 CJK UNIFIED IDEOGRAPH-#232E9, IRGKangXi=0501.131, RSKangXi=72.14
232EA CJK UNIFIED IDEOGRAPH-#232EA, IRGKangXi=0501.131, RSKangXi=72.14
232EB CJK UNIFIED IDEOGRAPH-#232EB, IRGKangXi=0501.131, RSKangXi=72.14
232EC CJK UNIFIED IDEOGRAPH-#232EC, IRGKangXi=0501.131, RSKangXi=72.14
232ED CJK UNIFIED IDEOGRAPH-#232ED, IRGKangXi=0501.131, RSKangXi=72.14
232EE CJK UNIFIED IDEOGRAPH-#232EE, IRGKangXi=0501.131, RSKangXi=72.14
232EF CJK UNIFIED IDEOGRAPH-#232EF, IRGKangXi=0501.131, RSKangXi=72.14
232F0 CJK UNIFIED IDEOGRAPH-#232F0, IRGKangXi=0501.131, RSKangXi=72.14
232F1 CJK UNIFIED IDEOGRAPH-#232F1, IRGKangXi=0501.131, RSKangXi=72.14
232F2 CJK UNIFIED IDEOGRAPH-#232F2, IRGKangXi=0501.140, RSKangXi=72.15
232F3 CJK UNIFIED IDEOGRAPH-#232F3, IRGKangXi=0501.150, RSKangXi=72.15
232F4 CJK UNIFIED IDEOGRAPH-#232F4, IRGKangXi=0501.160, RSKangXi=72.15
232F5 CJK UNIFIED IDEOGRAPH-#232F5, IRGKangXi=0501.190, RSKangXi=72.15
232F6 CJK UNIFIED IDEOGRAPH-#232F6, IRGKangXi=0501.220, RSKangXi=72.15
232F7 CJK UNIFIED IDEOGRAPH-#232F7, IRGKangXi=0501.260, RSKangXi=72.15
232F8 CJK UNIFIED IDEOGRAPH-#232F8, IRGKangXi=0501.270, RSKangXi=72.15
232F9 CJK UNIFIED IDEOGRAPH-#232F9, IRGKangXi=0501.280, RSKangXi=72.15
232FA CJK UNIFIED IDEOGRAPH-#232FA, IRGKangXi=0501.281, RSKangXi=72.15
232FB CJK UNIFIED IDEOGRAPH-#232FB, IRGKangXi=0501.281, RSKangXi=72.15
232FC CJK UNIFIED IDEOGRAPH-#232FC, IRGKangXi=0501.281, RSKangXi=72.15
232FD CJK UNIFIED IDEOGRAPH-#232FD, IRGKangXi=0501.281, RSKangXi=72.15
232FE CJK UNIFIED IDEOGRAPH-#232FE, IRGKangXi=0501.281, RSKangXi=72.15
232FF CJK UNIFIED IDEOGRAPH-#232FF, IRGKangXi=0501.360, RSKangXi=72.16
23300 CJK UNIFIED IDEOGRAPH-#23300, IRGKangXi=0501.361, RSKangXi=72.16
23301 CJK UNIFIED IDEOGRAPH-#23301, IRGKangXi=0501.361, RSKangXi=72.16
23302 CJK UNIFIED IDEOGRAPH-#23302, IRGKangXi=0501.361, RSKangXi=72.16
23303 CJK UNIFIED IDEOGRAPH-#23303, IRGKangXi=0501.361, RSKangXi=72.16
23304 CJK UNIFIED IDEOGRAPH-#23304, IRGKangXi=0501.361, RSKangXi=72.16
23305 CJK UNIFIED IDEOGRAPH-#23305, IRGKangXi=0501.361, RSKangXi=72.16
23306 CJK UNIFIED IDEOGRAPH-#23306, IRGKangXi=0501.361, RSKangXi=72.16
23307 CJK UNIFIED IDEOGRAPH-#23307, IRGKangXi=0501.361, RSKangXi=72.16
23308 CJK UNIFIED IDEOGRAPH-#23308, IRGKangXi=0501.380, RSKangXi=72.17
23309 CJK UNIFIED IDEOGRAPH-#23309, IRGKangXi=0501.381, RSKangXi=72.17
2330A CJK UNIFIED IDEOGRAPH-#2330A, IRGKangXi=0501.381, RSKangXi=72.17
2330B CJK UNIFIED IDEOGRAPH-#2330B, IRGKangXi=0501.381, RSKangXi=72.17
2330C CJK UNIFIED IDEOGRAPH-#2330C, IRGKangXi=0501.381, RSKangXi=72.17
2330D CJK UNIFIED IDEOGRAPH-#2330D, IRGKangXi=0501.400, RSKangXi=72.18
2330E CJK UNIFIED IDEOGRAPH-#2330E, IRGKangXi=0501.411, RSKangXi=72.18
2330F CJK UNIFIED IDEOGRAPH-#2330F, IRGKangXi=0501.411, RSKangXi=72.18
23310 CJK UNIFIED IDEOGRAPH-#23310, IRGKangXi=0501.411, RSKangXi=72.18
23311 CJK UNIFIED IDEOGRAPH-#23311, IRGKangXi=0501.411, RSKangXi=72.18
23312 CJK UNIFIED IDEOGRAPH-#23312, IRGKangXi=0501.411, RSKangXi=72.18
23313 CJK UNIFIED IDEOGRAPH-#23313, IRGKangXi=0501.411, RSKangXi=72.18
23314 CJK UNIFIED IDEOGRAPH-#23314, IRGKangXi=0501.411, RSKangXi=72.18
23315 CJK UNIFIED IDEOGRAPH-#23315, IRGKangXi=0501.411, RSKangXi=72.18
23316 CJK UNIFIED IDEOGRAPH-#23316, IRGKangXi=0501.460, RSKangXi=72.19
23317 CJK UNIFIED IDEOGRAPH-#23317, IRGKangXi=0501.470, RSKangXi=72.20
23318 CJK UNIFIED IDEOGRAPH-#23318, IRGKangXi=0501.500, RSKangXi=72.20
23319 CJK UNIFIED IDEOGRAPH-#23319, IRGKangXi=0501.501, RSKangXi=72.20
2331A CJK UNIFIED IDEOGRAPH-#2331A, IRGKangXi=0501.501, RSKangXi=149.17
2331B CJK UNIFIED IDEOGRAPH-#2331B, IRGKangXi=0501.501, RSKangXi=72.20
2331C CJK UNIFIED IDEOGRAPH-#2331C, IRGKangXi=0501.530, RSKangXi=72.21
2331D CJK UNIFIED IDEOGRAPH-#2331D, IRGKangXi=0501.531, RSKangXi=72.21
2331E CJK UNIFIED IDEOGRAPH-#2331E, IRGKangXi=0501.531, RSKangXi=123.21
2331F CJK UNIFIED IDEOGRAPH-#2331F, IRGKangXi=0501.540, RSKangXi=72.24
23320 CJK UNIFIED IDEOGRAPH-#23320, IRGKangXi=0501.541, RSKangXi=72.32
23321 CJK UNIFIED IDEOGRAPH-#23321, IRGKangXi=0502.050, RSKangXi=73.3
23322 CJK UNIFIED IDEOGRAPH-#23322, IRGKangXi=0502.061, RSKangXi=73.3
23323 CJK UNIFIED IDEOGRAPH-#23323, IRGKangXi=0502.070, RSKangXi=73.4
23324 CJK UNIFIED IDEOGRAPH-#23324, IRGKangXi=0502.081, RSKangXi=73.4
23325 CJK UNIFIED IDEOGRAPH-#23325, IRGKangXi=0502.081, RSKangXi=73.4
23326 CJK UNIFIED IDEOGRAPH-#23326, IRGKangXi=0502.081, RSKangXi=73.4
23327 CJK UNIFIED IDEOGRAPH-#23327, IRGKangXi=0502.090, RSKangXi=73.5
23328 CJK UNIFIED IDEOGRAPH-#23328, IRGKangXi=0502.110, RSKangXi=73.5
23329 CJK UNIFIED IDEOGRAPH-#23329, IRGKangXi=0502.111, RSKangXi=73.5
2332A CJK UNIFIED IDEOGRAPH-#2332A, IRGKangXi=0502.111, RSKangXi=73.5
2332B CJK UNIFIED IDEOGRAPH-#2332B, IRGKangXi=0502.111, RSKangXi=73.5
2332C CJK UNIFIED IDEOGRAPH-#2332C, IRGKangXi=0502.111, RSKangXi=73.5
2332D CJK UNIFIED IDEOGRAPH-#2332D, IRGKangXi=0503.010, RSKangXi=73.6
2332E CJK UNIFIED IDEOGRAPH-#2332E, IRGKangXi=0503.011, RSKangXi=73.6
2332F CJK UNIFIED IDEOGRAPH-#2332F, IRGKangXi=0503.011, RSKangXi=73.6
23330 CJK UNIFIED IDEOGRAPH-#23330, IRGKangXi=0503.011, RSKangXi=73.6
23331 CJK UNIFIED IDEOGRAPH-#23331, IRGKangXi=0503.011, RSKangXi=73.6
23332 CJK UNIFIED IDEOGRAPH-#23332, IRGKangXi=0503.011, RSKangXi=73.6
23333 CJK UNIFIED IDEOGRAPH-#23333, IRGKangXi=0503.011, RSKangXi=73.6
23334 CJK UNIFIED IDEOGRAPH-#23334, IRGKangXi=0503.011, RSKangXi=73.6
23335 CJK UNIFIED IDEOGRAPH-#23335, IRGKangXi=0503.011, RSKangXi=73.6
23336 CJK UNIFIED IDEOGRAPH-#23336, IRGKangXi=0503.011, RSKangXi=73.6
23337 CJK UNIFIED IDEOGRAPH-#23337, IRGKangXi=0503.021, RSKangXi=73.7
23338 CJK UNIFIED IDEOGRAPH-#23338, IRGKangXi=0503.021, RSKangXi=73.7
23339 CJK UNIFIED IDEOGRAPH-#23339, IRGKangXi=0503.021, RSKangXi=73.7
2333A CJK UNIFIED IDEOGRAPH-#2333A, IRGKangXi=0503.021, RSKangXi=73.7
2333B CJK UNIFIED IDEOGRAPH-#2333B, IRGKangXi=0503.071, RSKangXi=73.8
2333C CJK UNIFIED IDEOGRAPH-#2333C, IRGKangXi=0503.071, RSKangXi=73.8
2333D CJK UNIFIED IDEOGRAPH-#2333D, IRGKangXi=0503.071, RSKangXi=73.8
2333E CJK UNIFIED IDEOGRAPH-#2333E, IRGKangXi=0504.010, RSKangXi=73.9
2333F CJK UNIFIED IDEOGRAPH-#2333F, IRGKangXi=0504.011, RSKangXi=73.9
23340 CJK UNIFIED IDEOGRAPH-#23340, IRGKangXi=0504.011, RSKangXi=73.9
23341 CJK UNIFIED IDEOGRAPH-#23341, IRGKangXi=0504.011, RSKangXi=73.9
23342 CJK UNIFIED IDEOGRAPH-#23342, IRGKangXi=0504.011, RSKangXi=73.9
23343 CJK UNIFIED IDEOGRAPH-#23343, IRGKangXi=0504.040, RSKangXi=73.10
23344 CJK UNIFIED IDEOGRAPH-#23344, IRGKangXi=0504.050, RSKangXi=73.10
23345 CJK UNIFIED IDEOGRAPH-#23345, IRGKangXi=0504.051, RSKangXi=73.10
23346 CJK UNIFIED IDEOGRAPH-#23346, IRGKangXi=0504.060, RSKangXi=73.11
23347 CJK UNIFIED IDEOGRAPH-#23347, IRGKangXi=0504.070, RSKangXi=73.11
23348 CJK UNIFIED IDEOGRAPH-#23348, IRGKangXi=0504.080, RSKangXi=73.11
23349 CJK UNIFIED IDEOGRAPH-#23349, IRGKangXi=0504.081, RSKangXi=73.11
2334A CJK UNIFIED IDEOGRAPH-#2334A, IRGKangXi=0504.081, RSKangXi=73.11
2334B CJK UNIFIED IDEOGRAPH-#2334B, IRGKangXi=0504.091, RSKangXi=73.12
2334C CJK UNIFIED IDEOGRAPH-#2334C, IRGKangXi=0504.091, RSKangXi=73.12
2334D CJK UNIFIED IDEOGRAPH-#2334D, IRGKangXi=0504.091, RSKangXi=73.12
2334E CJK UNIFIED IDEOGRAPH-#2334E, IRGKangXi=0504.091, RSKangXi=73.12
2334F CJK UNIFIED IDEOGRAPH-#2334F, IRGKangXi=0504.100, RSKangXi=73.13
23350 CJK UNIFIED IDEOGRAPH-#23350, IRGKangXi=0504.111, RSKangXi=73.13
23351 CJK UNIFIED IDEOGRAPH-#23351, IRGKangXi=0504.120, RSKangXi=73.14
23352 CJK UNIFIED IDEOGRAPH-#23352, IRGKangXi=0504.121, RSKangXi=73.14
23353 CJK UNIFIED IDEOGRAPH-#23353, IRGKangXi=0504.121, RSKangXi=73.14
23354 CJK UNIFIED IDEOGRAPH-#23354, IRGKangXi=0504.121, RSKangXi=73.14
23355 CJK UNIFIED IDEOGRAPH-#23355, IRGKangXi=0504.121, RSKangXi=73.14
23356 CJK UNIFIED IDEOGRAPH-#23356, IRGKangXi=0504.130, RSKangXi=73.15
23357 CJK UNIFIED IDEOGRAPH-#23357, IRGKangXi=0504.131, RSKangXi=73.15
23358 CJK UNIFIED IDEOGRAPH-#23358, IRGKangXi=0504.140, RSKangXi=73.16
23359 CJK UNIFIED IDEOGRAPH-#23359, IRGKangXi=0504.150, RSKangXi=73.16
2335A CJK UNIFIED IDEOGRAPH-#2335A, IRGKangXi=0504.161, RSKangXi=73.20
2335B CJK UNIFIED IDEOGRAPH-#2335B, IRGKangXi=0504.170, RSKangXi=73.24
2335C CJK UNIFIED IDEOGRAPH-#2335C, IRGKangXi=0504.180, RSKangXi=73.31
2335D CJK UNIFIED IDEOGRAPH-#2335D, IRGKangXi=0504.191, RSKangXi=74.1
2335E CJK UNIFIED IDEOGRAPH-#2335E, IRGKangXi=0504.220, RSKangXi=74.2
2335F CJK UNIFIED IDEOGRAPH-#2335F, IRGKangXi=0504.230, RSKangXi=74.3
23360 CJK UNIFIED IDEOGRAPH-#23360, IRGKangXi=0504.240, RSKangXi=74.3
23361 CJK UNIFIED IDEOGRAPH-#23361, IRGKangXi=0504.250, RSKangXi=74.3
23362 CJK UNIFIED IDEOGRAPH-#23362, IRGKangXi=0504.260, RSKangXi=74.3
23363 CJK UNIFIED IDEOGRAPH-#23363, IRGKangXi=0504.270, RSKangXi=74.3
23364 CJK UNIFIED IDEOGRAPH-#23364, IRGKangXi=0505.041, RSKangXi=74.4
23365 CJK UNIFIED IDEOGRAPH-#23365, IRGKangXi=0505.060, RSKangXi=74.5
23366 CJK UNIFIED IDEOGRAPH-#23366, IRGKangXi=0505.070, RSKangXi=74.5
23367 CJK UNIFIED IDEOGRAPH-#23367, IRGKangXi=0505.110, RSKangXi=74.5
23368 CJK UNIFIED IDEOGRAPH-#23368, IRGKangXi=0505.111, RSKangXi=130.5
23369 CJK UNIFIED IDEOGRAPH-#23369, IRGKangXi=0505.111, RSKangXi=74.5
2336A CJK UNIFIED IDEOGRAPH-#2336A, IRGKangXi=0505.111, RSKangXi=74.5
2336B CJK UNIFIED IDEOGRAPH-#2336B, IRGKangXi=0505.111, RSKangXi=74.5
2336C CJK UNIFIED IDEOGRAPH-#2336C, IRGKangXi=0505.111, RSKangXi=74.5
2336D CJK UNIFIED IDEOGRAPH-#2336D, IRGKangXi=0505.140, RSKangXi=74.6
2336E CJK UNIFIED IDEOGRAPH-#2336E, IRGKangXi=0505.180, RSKangXi=74.6
2336F CJK UNIFIED IDEOGRAPH-#2336F, IRGKangXi=0505.211, RSKangXi=130.6
23370 CJK UNIFIED IDEOGRAPH-#23370, IRGKangXi=0505.211, RSKangXi=130.6
23371 CJK UNIFIED IDEOGRAPH-#23371, IRGKangXi=0506.011, RSKangXi=74.7
23372 CJK UNIFIED IDEOGRAPH-#23372, IRGKangXi=0506.011, RSKangXi=74.7
23373 CJK UNIFIED IDEOGRAPH-#23373, IRGKangXi=0506.011, RSKangXi=74.7
23374 CJK UNIFIED IDEOGRAPH-#23374, IRGKangXi=0506.011, RSKangXi=74.7
23375 CJK UNIFIED IDEOGRAPH-#23375, IRGKangXi=0506.011, RSKangXi=74.7
23376 CJK UNIFIED IDEOGRAPH-#23376, IRGKangXi=0506.011, RSKangXi=74.7
23377 CJK UNIFIED IDEOGRAPH-#23377, IRGKangXi=0506.050, RSKangXi=74.8
23378 CJK UNIFIED IDEOGRAPH-#23378, IRGKangXi=0506.060, RSKangXi=74.8
23379 CJK UNIFIED IDEOGRAPH-#23379, IRGKangXi=0506.160, RSKangXi=74.8
2337A CJK UNIFIED IDEOGRAPH-#2337A, IRGKangXi=0506.170, RSKangXi=74.8
2337B CJK UNIFIED IDEOGRAPH-#2337B, IRGKangXi=0506.171, RSKangXi=74.8
2337C CJK UNIFIED IDEOGRAPH-#2337C, IRGKangXi=0506.171, RSKangXi=74.8
2337D CJK UNIFIED IDEOGRAPH-#2337D, IRGKangXi=0506.171, RSKangXi=74.8
2337E CJK UNIFIED IDEOGRAPH-#2337E, IRGKangXi=0506.171, RSKangXi=74.8
2337F CJK UNIFIED IDEOGRAPH-#2337F, IRGKangXi=0506.171, RSKangXi=74.8
23380 CJK UNIFIED IDEOGRAPH-#23380, IRGKangXi=0506.171, RSKangXi=74.8
23381 CJK UNIFIED IDEOGRAPH-#23381, IRGKangXi=0506.171, RSKangXi=74.8
23382 CJK UNIFIED IDEOGRAPH-#23382, IRGKangXi=0506.171, RSKangXi=74.8
23383 CJK UNIFIED IDEOGRAPH-#23383, IRGKangXi=0506.171, RSKangXi=74.8
23384 CJK UNIFIED IDEOGRAPH-#23384, IRGKangXi=0506.180, RSKangXi=74.9
23385 CJK UNIFIED IDEOGRAPH-#23385, IRGKangXi=0506.200, RSKangXi=74.9
23386 CJK UNIFIED IDEOGRAPH-#23386, IRGKangXi=0506.211, RSKangXi=74.9, Def{animals with short hair}
23387 CJK UNIFIED IDEOGRAPH-#23387, IRGKangXi=0506.211, RSKangXi=74.9
23388 CJK UNIFIED IDEOGRAPH-#23388, IRGKangXi=0506.211, RSKangXi=74.9
23389 CJK UNIFIED IDEOGRAPH-#23389, IRGKangXi=0506.211, RSKangXi=74.9
2338A CJK UNIFIED IDEOGRAPH-#2338A, IRGKangXi=0506.211, RSKangXi=74.9
2338B CJK UNIFIED IDEOGRAPH-#2338B, IRGKangXi=0506.211, RSKangXi=74.9
2338C CJK UNIFIED IDEOGRAPH-#2338C, IRGKangXi=0506.211, RSKangXi=74.9
2338D CJK UNIFIED IDEOGRAPH-#2338D, IRGKangXi=0506.220, RSKangXi=74.10
2338E CJK UNIFIED IDEOGRAPH-#2338E, IRGKangXi=0506.250, RSKangXi=74.10
2338F CJK UNIFIED IDEOGRAPH-#2338F, IRGKangXi=0506.251, RSKangXi=74.10
23390 CJK UNIFIED IDEOGRAPH-#23390, IRGKangXi=0506.251, RSKangXi=74.10
23391 CJK UNIFIED IDEOGRAPH-#23391, IRGKangXi=0506.251, RSKangXi=74.10
23392 CJK UNIFIED IDEOGRAPH-#23392, IRGKangXi=0506.260, RSKangXi=74.11
23393 CJK UNIFIED IDEOGRAPH-#23393, IRGKangXi=0506.270, RSKangXi=74.11
23394 CJK UNIFIED IDEOGRAPH-#23394, IRGKangXi=0506.280, RSKangXi=74.11
23395 CJK UNIFIED IDEOGRAPH-#23395, IRGKangXi=0506.281, RSKangXi=74.11
23396 CJK UNIFIED IDEOGRAPH-#23396, IRGKangXi=0506.281, RSKangXi=74.11
23397 CJK UNIFIED IDEOGRAPH-#23397, IRGKangXi=0506.281, RSKangXi=74.11
23398 CJK UNIFIED IDEOGRAPH-#23398, IRGKangXi=0506.281, RSKangXi=74.11
23399 CJK UNIFIED IDEOGRAPH-#23399, IRGKangXi=0506.281, RSKangXi=74.11
2339A CJK UNIFIED IDEOGRAPH-#2339A, IRGKangXi=0506.300, RSKangXi=74.12
2339B CJK UNIFIED IDEOGRAPH-#2339B, IRGKangXi=0506.320, RSKangXi=74.12
2339C CJK UNIFIED IDEOGRAPH-#2339C, IRGKangXi=0506.340, RSKangXi=74.13
2339D CJK UNIFIED IDEOGRAPH-#2339D, IRGKangXi=0506.341, RSKangXi=74.12
2339E CJK UNIFIED IDEOGRAPH-#2339E, IRGKangXi=0506.341, RSKangXi=74.12
2339F CJK UNIFIED IDEOGRAPH-#2339F, IRGKangXi=0506.341, RSKangXi=74.12
233A0 CJK UNIFIED IDEOGRAPH-#233A0, IRGKangXi=0506.341, RSKangXi=74.12
233A1 CJK UNIFIED IDEOGRAPH-#233A1, IRGKangXi=0506.341, RSKangXi=74.12
233A2 CJK UNIFIED IDEOGRAPH-#233A2, IRGKangXi=0506.341, RSKangXi=74.12
233A3 CJK UNIFIED IDEOGRAPH-#233A3, IRGKangXi=0506.350, RSKangXi=74.13
233A4 CJK UNIFIED IDEOGRAPH-#233A4, IRGKangXi=0507.010, RSKangXi=74.13
233A5 CJK UNIFIED IDEOGRAPH-#233A5, IRGKangXi=0507.011, RSKangXi=74.13
233A6 CJK UNIFIED IDEOGRAPH-#233A6, IRGKangXi=0507.011, RSKangXi=74.13
233A7 CJK UNIFIED IDEOGRAPH-#233A7, IRGKangXi=0507.011, RSKangXi=74.13
233A8 CJK UNIFIED IDEOGRAPH-#233A8, IRGKangXi=0507.011, RSKangXi=74.13
233A9 CJK UNIFIED IDEOGRAPH-#233A9, IRGKangXi=0507.020, RSKangXi=74.14
233AA CJK UNIFIED IDEOGRAPH-#233AA, IRGKangXi=0507.031, RSKangXi=74.14
233AB CJK UNIFIED IDEOGRAPH-#233AB, IRGKangXi=0507.031, RSKangXi=74.14
233AC CJK UNIFIED IDEOGRAPH-#233AC, IRGKangXi=0507.031, RSKangXi=74.14
233AD CJK UNIFIED IDEOGRAPH-#233AD, IRGKangXi=0507.031, RSKangXi=74.14
233AE CJK UNIFIED IDEOGRAPH-#233AE, IRGKangXi=0507.050, RSKangXi=74.16
233AF CJK UNIFIED IDEOGRAPH-#233AF, IRGKangXi=0507.051, RSKangXi=74.16
233B0 CJK UNIFIED IDEOGRAPH-#233B0, IRGKangXi=0507.051, RSKangXi=74.18
233B1 CJK UNIFIED IDEOGRAPH-#233B1, IRGKangXi=0507.051, RSKangXi=74.19
233B2 CJK UNIFIED IDEOGRAPH-#233B2, IRGKangXi=0507.060, RSKangXi=74.20
233B3 CJK UNIFIED IDEOGRAPH-#233B3, IRGKangXi=0509.020, RSKangXi=75.0
233B4 CJK UNIFIED IDEOGRAPH-#233B4, IRGKangXi=0509.030, RSKangXi=75.0, Def{stump of a tree}
233B5 CJK UNIFIED IDEOGRAPH-#233B5, IRGKangXi=0509.040, RSKangXi=75.1
233B6 CJK UNIFIED IDEOGRAPH-#233B6, IRGKangXi=0509.121, RSKangXi=75.1
233B7 CJK UNIFIED IDEOGRAPH-#233B7, IRGKangXi=0509.121, RSKangXi=75.1
233B8 CJK UNIFIED IDEOGRAPH-#233B8, IRGKangXi=0510.020, RSKangXi=75.2
233B9 CJK UNIFIED IDEOGRAPH-#233B9, IRGKangXi=0510.140, RSKangXi=75.2
233BA CJK UNIFIED IDEOGRAPH-#233BA, IRGKangXi=0510.181, RSKangXi=75.2
233BB CJK UNIFIED IDEOGRAPH-#233BB, IRGKangXi=0510.181, RSKangXi=75.2
233BC CJK UNIFIED IDEOGRAPH-#233BC, IRGKangXi=0510.181, RSKangXi=75.2
233BD CJK UNIFIED IDEOGRAPH-#233BD, IRGKangXi=0510.181, RSKangXi=75.2
233BE CJK UNIFIED IDEOGRAPH-#233BE, IRGKangXi=0510.181, RSKangXi=75.2
233BF CJK UNIFIED IDEOGRAPH-#233BF, IRGKangXi=0510.181, RSKangXi=75.2
233C0 CJK UNIFIED IDEOGRAPH-#233C0, IRGKangXi=0510.181, RSKangXi=75.2
233C1 CJK UNIFIED IDEOGRAPH-#233C1, IRGKangXi=0511.150, RSKangXi=75.3
233C2 CJK UNIFIED IDEOGRAPH-#233C2, IRGKangXi=0512.030, RSKangXi=75.3
233C3 CJK UNIFIED IDEOGRAPH-#233C3, IRGKangXi=0512.080, RSKangXi=75.3
233C4 CJK UNIFIED IDEOGRAPH-#233C4, IRGKangXi=0513.010, RSKangXi=75.3
233C5 CJK UNIFIED IDEOGRAPH-#233C5, IRGKangXi=0513.011, RSKangXi=75.3
233C6 CJK UNIFIED IDEOGRAPH-#233C6, IRGKangXi=0513.011, RSKangXi=75.3
233C7 CJK UNIFIED IDEOGRAPH-#233C7, IRGKangXi=0513.011, RSKangXi=75.3
233C8 CJK UNIFIED IDEOGRAPH-#233C8, IRGKangXi=0513.011, RSKangXi=75.3
233C9 CJK UNIFIED IDEOGRAPH-#233C9, IRGKangXi=0513.011, RSKangXi=75.3
233CA CJK UNIFIED IDEOGRAPH-#233CA, IRGKangXi=0513.011, RSKangXi=75.3
233CB CJK UNIFIED IDEOGRAPH-#233CB, IRGKangXi=0513.011, RSKangXi=75.3
233CC CJK UNIFIED IDEOGRAPH-#233CC, IRGKangXi=0513.011, RSKangXi=75.3
233CD CJK UNIFIED IDEOGRAPH-#233CD, IRGKangXi=0513.011, RSKangXi=75.3
233CE CJK UNIFIED IDEOGRAPH-#233CE, IRGKangXi=0513.011, RSKangXi=75.3
233CF CJK UNIFIED IDEOGRAPH-#233CF, IRGKangXi=0513.011, RSKangXi=75.3
233D0 CJK UNIFIED IDEOGRAPH-#233D0, IRGKangXi=0513.011, RSKangXi=75.3
233D1 CJK UNIFIED IDEOGRAPH-#233D1, IRGKangXi=0513.011, RSKangXi=75.3
233D2 CJK UNIFIED IDEOGRAPH-#233D2, IRGKangXi=0513.011, RSKangXi=75.3
233D3 CJK UNIFIED IDEOGRAPH-#233D3, IRGKangXi=0513.011, RSKangXi=75.3
233D4 CJK UNIFIED IDEOGRAPH-#233D4, IRGKangXi=0513.040, RSKangXi=75.4
233D5 CJK UNIFIED IDEOGRAPH-#233D5, IRGKangXi=0513.070, RSKangXi=75.4
233D6 CJK UNIFIED IDEOGRAPH-#233D6, IRGKangXi=0514.040, RSKangXi=75.4
233D7 CJK UNIFIED IDEOGRAPH-#233D7, IRGKangXi=0514.090, RSKangXi=75.4
233D8 CJK UNIFIED IDEOGRAPH-#233D8, IRGKangXi=0514.220, RSKangXi=75.4
233D9 CJK UNIFIED IDEOGRAPH-#233D9, IRGKangXi=0514.250, RSKangXi=75.4
233DA CJK UNIFIED IDEOGRAPH-#233DA, IRGKangXi=0515.030, RSKangXi=75.4
233DB CJK UNIFIED IDEOGRAPH-#233DB, IRGKangXi=0515.110, RSKangXi=75.4
233DC CJK UNIFIED IDEOGRAPH-#233DC, IRGKangXi=0515.140, RSKangXi=75.4
233DD CJK UNIFIED IDEOGRAPH-#233DD, IRGKangXi=0516.010, RSKangXi=75.4
233DE CJK UNIFIED IDEOGRAPH-#233DE, IRGKangXi=0516.020, RSKangXi=75.4
233DF CJK UNIFIED IDEOGRAPH-#233DF, IRGKangXi=0516.040, RSKangXi=75.4
233E0 CJK UNIFIED IDEOGRAPH-#233E0, IRGKangXi=0516.160, RSKangXi=75.4
233E1 CJK UNIFIED IDEOGRAPH-#233E1, IRGKangXi=0517.010, RSKangXi=75.4
233E2 CJK UNIFIED IDEOGRAPH-#233E2, IRGKangXi=0517.011, RSKangXi=75.4
233E3 CJK UNIFIED IDEOGRAPH-#233E3, IRGKangXi=0517.011, RSKangXi=75.4
233E4 CJK UNIFIED IDEOGRAPH-#233E4, IRGKangXi=0517.011, RSKangXi=75.4
233E5 CJK UNIFIED IDEOGRAPH-#233E5, IRGKangXi=0517.011, RSKangXi=75.4
233E6 CJK UNIFIED IDEOGRAPH-#233E6, IRGKangXi=0517.011, RSKangXi=75.4
233E7 CJK UNIFIED IDEOGRAPH-#233E7, IRGKangXi=0517.011, RSKangXi=75.4
233E8 CJK UNIFIED IDEOGRAPH-#233E8, IRGKangXi=0517.011, RSKangXi=75.4
233E9 CJK UNIFIED IDEOGRAPH-#233E9, IRGKangXi=0517.011, RSKangXi=75.4
233EA CJK UNIFIED IDEOGRAPH-#233EA, IRGKangXi=0517.011, RSKangXi=75.4
233EB CJK UNIFIED IDEOGRAPH-#233EB, IRGKangXi=0517.011, RSKangXi=75.4
233EC CJK UNIFIED IDEOGRAPH-#233EC, IRGKangXi=0517.011, RSKangXi=75.4
233ED CJK UNIFIED IDEOGRAPH-#233ED, IRGKangXi=0517.011, RSKangXi=75.4
233EE CJK UNIFIED IDEOGRAPH-#233EE, IRGKangXi=0517.011, RSKangXi=75.4
233EF CJK UNIFIED IDEOGRAPH-#233EF, IRGKangXi=0517.011, RSKangXi=75.4
233F0 CJK UNIFIED IDEOGRAPH-#233F0, IRGKangXi=0517.011, RSKangXi=75.4
233F1 CJK UNIFIED IDEOGRAPH-#233F1, IRGKangXi=0517.011, RSKangXi=75.4
233F2 CJK UNIFIED IDEOGRAPH-#233F2, IRGKangXi=0517.011, RSKangXi=75.4
233F3 CJK UNIFIED IDEOGRAPH-#233F3, IRGKangXi=0517.011, RSKangXi=75.4
233F4 CJK UNIFIED IDEOGRAPH-#233F4, IRGKangXi=0517.011, RSKangXi=75.4, Def{(Cant.) a kind of fruit}
233F5 CJK UNIFIED IDEOGRAPH-#233F5, IRGKangXi=0517.011, RSKangXi=75.4
233F6 CJK UNIFIED IDEOGRAPH-#233F6, IRGKangXi=0517.011, RSKangXi=75.4
233F7 CJK UNIFIED IDEOGRAPH-#233F7, IRGKangXi=0517.011, RSKangXi=75.4
233F8 CJK UNIFIED IDEOGRAPH-#233F8, IRGKangXi=0517.011, RSKangXi=75.4
233F9 CJK UNIFIED IDEOGRAPH-#233F9, IRGKangXi=0517.011, RSKangXi=75.4
233FA CJK UNIFIED IDEOGRAPH-#233FA, IRGKangXi=0517.011, RSKangXi=75.4
233FB CJK UNIFIED IDEOGRAPH-#233FB, IRGKangXi=0517.011, RSKangXi=75.4
233FC CJK UNIFIED IDEOGRAPH-#233FC, IRGKangXi=0517.011, RSKangXi=75.4
233FD CJK UNIFIED IDEOGRAPH-#233FD, IRGKangXi=0517.011, RSKangXi=75.4
233FE CJK UNIFIED IDEOGRAPH-#233FE, IRGKangXi=0517.011, RSKangXi=75.4, Def{(J) non-standard variant of 材 U+6750, material, stuff; timber; talent; (Cant.) a peg, row of pegs}
233FF CJK UNIFIED IDEOGRAPH-#233FF, IRGKangXi=0517.011, RSKangXi=75.4
23400 CJK UNIFIED IDEOGRAPH-#23400, IRGKangXi=0517.011, RSKangXi=75.4
23401 CJK UNIFIED IDEOGRAPH-#23401, IRGKangXi=0517.011, RSKangXi=75.4
23402 CJK UNIFIED IDEOGRAPH-#23402, IRGKangXi=0517.011, RSKangXi=75.4
23403 CJK UNIFIED IDEOGRAPH-#23403, IRGKangXi=0517.011, RSKangXi=75.4
23404 CJK UNIFIED IDEOGRAPH-#23404, IRGKangXi=0517.011, RSKangXi=75.4
23405 CJK UNIFIED IDEOGRAPH-#23405, IRGKangXi=0517.011, RSKangXi=75.4
23406 CJK UNIFIED IDEOGRAPH-#23406, IRGKangXi=0517.011, RSKangXi=75.4
23407 CJK UNIFIED IDEOGRAPH-#23407, IRGKangXi=0517.011, RSKangXi=75.4
23408 CJK UNIFIED IDEOGRAPH-#23408, IRGKangXi=0518.010, RSKangXi=75.5
23409 CJK UNIFIED IDEOGRAPH-#23409, IRGKangXi=0518.070, RSKangXi=75.5
2340A CJK UNIFIED IDEOGRAPH-#2340A, IRGKangXi=0518.090, RSKangXi=75.5
2340B CJK UNIFIED IDEOGRAPH-#2340B, IRGKangXi=0518.160, RSKangXi=75.5
2340C CJK UNIFIED IDEOGRAPH-#2340C, IRGKangXi=0518.190, RSKangXi=75.5
2340D CJK UNIFIED IDEOGRAPH-#2340D, IRGKangXi=0520.100, RSKangXi=75.5
2340E CJK UNIFIED IDEOGRAPH-#2340E, IRGKangXi=0520.110, RSKangXi=75.5
2340F CJK UNIFIED IDEOGRAPH-#2340F, IRGKangXi=0520.130, RSKangXi=75.5
23410 CJK UNIFIED IDEOGRAPH-#23410, IRGKangXi=0520.170, RSKangXi=75.5
23411 CJK UNIFIED IDEOGRAPH-#23411, IRGKangXi=0521.050, RSKangXi=75.5
23412 CJK UNIFIED IDEOGRAPH-#23412, IRGKangXi=0521.100, RSKangXi=75.5
23413 CJK UNIFIED IDEOGRAPH-#23413, IRGKangXi=0521.120, RSKangXi=75.5
23414 CJK UNIFIED IDEOGRAPH-#23414, IRGKangXi=0521.121, RSKangXi=75.5
23415 CJK UNIFIED IDEOGRAPH-#23415, IRGKangXi=0521.121, RSKangXi=75.5
23416 CJK UNIFIED IDEOGRAPH-#23416, IRGKangXi=0521.121, RSKangXi=75.5
23417 CJK UNIFIED IDEOGRAPH-#23417, IRGKangXi=0521.121, RSKangXi=75.5
23418 CJK UNIFIED IDEOGRAPH-#23418, IRGKangXi=0521.121, RSKangXi=75.5
23419 CJK UNIFIED IDEOGRAPH-#23419, IRGKangXi=0521.121, RSKangXi=75.5
2341A CJK UNIFIED IDEOGRAPH-#2341A, IRGKangXi=0521.121, RSKangXi=75.5
2341B CJK UNIFIED IDEOGRAPH-#2341B, IRGKangXi=0521.121, RSKangXi=75.5
2341C CJK UNIFIED IDEOGRAPH-#2341C, IRGKangXi=0521.121, RSKangXi=75.5
2341D CJK UNIFIED IDEOGRAPH-#2341D, IRGKangXi=0521.121, RSKangXi=75.5
2341E CJK UNIFIED IDEOGRAPH-#2341E, IRGKangXi=0521.121, RSKangXi=75.5
2341F CJK UNIFIED IDEOGRAPH-#2341F, IRGKangXi=0521.121, RSKangXi=75.5
23420 CJK UNIFIED IDEOGRAPH-#23420, IRGKangXi=0521.121, RSKangXi=75.5
23421 CJK UNIFIED IDEOGRAPH-#23421, IRGKangXi=0521.121, RSKangXi=75.5
23422 CJK UNIFIED IDEOGRAPH-#23422, IRGKangXi=0521.121, RSKangXi=75.5
23423 CJK UNIFIED IDEOGRAPH-#23423, IRGKangXi=0521.121, RSKangXi=75.5
23424 CJK UNIFIED IDEOGRAPH-#23424, IRGKangXi=0521.121, RSKangXi=75.5
23425 CJK UNIFIED IDEOGRAPH-#23425, IRGKangXi=0521.121, RSKangXi=75.5
23426 CJK UNIFIED IDEOGRAPH-#23426, IRGKangXi=0521.121, RSKangXi=75.5
23427 CJK UNIFIED IDEOGRAPH-#23427, IRGKangXi=0521.121, RSKangXi=75.5
23428 CJK UNIFIED IDEOGRAPH-#23428, IRGKangXi=0521.121, RSKangXi=75.5
23429 CJK UNIFIED IDEOGRAPH-#23429, IRGKangXi=0521.121, RSKangXi=75.5
2342A CJK UNIFIED IDEOGRAPH-#2342A, IRGKangXi=0521.121, RSKangXi=75.5
2342B CJK UNIFIED IDEOGRAPH-#2342B, IRGKangXi=0521.121, RSKangXi=75.5
2342C CJK UNIFIED IDEOGRAPH-#2342C, IRGKangXi=0521.121, RSKangXi=75.5
2342D CJK UNIFIED IDEOGRAPH-#2342D, IRGKangXi=0521.121, RSKangXi=75.5
2342E CJK UNIFIED IDEOGRAPH-#2342E, IRGKangXi=0521.121, RSKangXi=75.5
2342F CJK UNIFIED IDEOGRAPH-#2342F, IRGKangXi=0521.121, RSKangXi=75.5
23430 CJK UNIFIED IDEOGRAPH-#23430, IRGKangXi=0521.121, RSKangXi=75.5
23431 CJK UNIFIED IDEOGRAPH-#23431, IRGKangXi=0521.121, RSKangXi=75.5
23432 CJK UNIFIED IDEOGRAPH-#23432, IRGKangXi=0521.121, RSKangXi=75.5
23433 CJK UNIFIED IDEOGRAPH-#23433, IRGKangXi=0521.121, RSKangXi=75.5
23434 CJK UNIFIED IDEOGRAPH-#23434, IRGKangXi=0521.121, RSKangXi=75.5
23435 CJK UNIFIED IDEOGRAPH-#23435, IRGKangXi=0522.040, RSKangXi=75.6
23436 CJK UNIFIED IDEOGRAPH-#23436, IRGKangXi=0522.120, RSKangXi=75.6
23437 CJK UNIFIED IDEOGRAPH-#23437, IRGKangXi=0522.130, RSKangXi=75.6
23438 CJK UNIFIED IDEOGRAPH-#23438, IRGKangXi=0522.200, RSKangXi=75.6
23439 CJK UNIFIED IDEOGRAPH-#23439, IRGKangXi=0523.100, RSKangXi=75.6
2343A CJK UNIFIED IDEOGRAPH-#2343A, IRGKangXi=0524.060, RSKangXi=75.6
2343B CJK UNIFIED IDEOGRAPH-#2343B, IRGKangXi=0524.080, RSKangXi=75.6
2343C CJK UNIFIED IDEOGRAPH-#2343C, IRGKangXi=0526.060, RSKangXi=75.6
2343D CJK UNIFIED IDEOGRAPH-#2343D, IRGKangXi=0526.070, RSKangXi=75.6
2343E CJK UNIFIED IDEOGRAPH-#2343E, IRGKangXi=0526.130, RSKangXi=75.6
2343F CJK UNIFIED IDEOGRAPH-#2343F, IRGKangXi=0526.140, RSKangXi=75.6
23440 CJK UNIFIED IDEOGRAPH-#23440, IRGKangXi=0526.160, RSKangXi=75.6
23441 CJK UNIFIED IDEOGRAPH-#23441, IRGKangXi=0526.170, RSKangXi=75.6, Def{to leap, skip}
23442 CJK UNIFIED IDEOGRAPH-#23442, IRGKangXi=0526.180, RSKangXi=75.6
23443 CJK UNIFIED IDEOGRAPH-#23443, IRGKangXi=0526.190, RSKangXi=75.6
23444 CJK UNIFIED IDEOGRAPH-#23444, IRGKangXi=0526.200, RSKangXi=75.6
23445 CJK UNIFIED IDEOGRAPH-#23445, IRGKangXi=0526.210, RSKangXi=75.6
23446 CJK UNIFIED IDEOGRAPH-#23446, IRGKangXi=0526.211, RSKangXi=75.6
23447 CJK UNIFIED IDEOGRAPH-#23447, IRGKangXi=0526.211, RSKangXi=75.6
23448 CJK UNIFIED IDEOGRAPH-#23448, IRGKangXi=0526.211, RSKangXi=75.6
23449 CJK UNIFIED IDEOGRAPH-#23449, IRGKangXi=0526.211, RSKangXi=75.6
2344A CJK UNIFIED IDEOGRAPH-#2344A, IRGKangXi=0526.211, RSKangXi=75.6
2344B CJK UNIFIED IDEOGRAPH-#2344B, IRGKangXi=0526.211, RSKangXi=75.6
2344C CJK UNIFIED IDEOGRAPH-#2344C, IRGKangXi=0526.211, RSKangXi=75.6
2344D CJK UNIFIED IDEOGRAPH-#2344D, IRGKangXi=0526.211, RSKangXi=75.6
2344E CJK UNIFIED IDEOGRAPH-#2344E, IRGKangXi=0526.211, RSKangXi=75.6
2344F CJK UNIFIED IDEOGRAPH-#2344F, IRGKangXi=0526.211, RSKangXi=75.6
23450 CJK UNIFIED IDEOGRAPH-#23450, IRGKangXi=0526.211, RSKangXi=75.6
23451 CJK UNIFIED IDEOGRAPH-#23451, IRGKangXi=0526.211, RSKangXi=75.6
23452 CJK UNIFIED IDEOGRAPH-#23452, IRGKangXi=0526.211, RSKangXi=75.6
23453 CJK UNIFIED IDEOGRAPH-#23453, IRGKangXi=0526.211, RSKangXi=75.6
23454 CJK UNIFIED IDEOGRAPH-#23454, IRGKangXi=0526.211, RSKangXi=75.6
23455 CJK UNIFIED IDEOGRAPH-#23455, IRGKangXi=0526.211, RSKangXi=75.6
23456 CJK UNIFIED IDEOGRAPH-#23456, IRGKangXi=0526.211, RSKangXi=75.6
23457 CJK UNIFIED IDEOGRAPH-#23457, IRGKangXi=0526.211, RSKangXi=75.6
23458 CJK UNIFIED IDEOGRAPH-#23458, IRGKangXi=0526.211, RSKangXi=75.6
23459 CJK UNIFIED IDEOGRAPH-#23459, IRGKangXi=0526.211, RSKangXi=75.6
2345A CJK UNIFIED IDEOGRAPH-#2345A, IRGKangXi=0526.211, RSKangXi=75.6
2345B CJK UNIFIED IDEOGRAPH-#2345B, IRGKangXi=0526.211, RSKangXi=75.6
2345C CJK UNIFIED IDEOGRAPH-#2345C, IRGKangXi=0526.211, RSKangXi=75.6
2345D CJK UNIFIED IDEOGRAPH-#2345D, IRGKangXi=0526.211, RSKangXi=75.6
2345E CJK UNIFIED IDEOGRAPH-#2345E, IRGKangXi=0526.211, RSKangXi=75.6
2345F CJK UNIFIED IDEOGRAPH-#2345F, IRGKangXi=0526.211, RSKangXi=75.6
23460 CJK UNIFIED IDEOGRAPH-#23460, IRGKangXi=0526.211, RSKangXi=75.6
23461 CJK UNIFIED IDEOGRAPH-#23461, IRGKangXi=0526.211, RSKangXi=75.6
23462 CJK UNIFIED IDEOGRAPH-#23462, IRGKangXi=0526.211, RSKangXi=75.6
23463 CJK UNIFIED IDEOGRAPH-#23463, IRGKangXi=0526.211, RSKangXi=75.6
23464 CJK UNIFIED IDEOGRAPH-#23464, IRGKangXi=0526.211, RSKangXi=75.6
23465 CJK UNIFIED IDEOGRAPH-#23465, IRGKangXi=0526.211, RSKangXi=75.6
23466 CJK UNIFIED IDEOGRAPH-#23466, IRGKangXi=0526.211, RSKangXi=75.6
23467 CJK UNIFIED IDEOGRAPH-#23467, IRGKangXi=0526.211, RSKangXi=32.7
23468 CJK UNIFIED IDEOGRAPH-#23468, IRGKangXi=0526.211, RSKangXi=75.6
23469 CJK UNIFIED IDEOGRAPH-#23469, IRGKangXi=0526.211, RSKangXi=75.6
2346A CJK UNIFIED IDEOGRAPH-#2346A, IRGKangXi=0526.211, RSKangXi=75.6
2346B CJK UNIFIED IDEOGRAPH-#2346B, IRGKangXi=0526.211, RSKangXi=75.6
2346C CJK UNIFIED IDEOGRAPH-#2346C, IRGKangXi=0526.211, RSKangXi=75.6
2346D CJK UNIFIED IDEOGRAPH-#2346D, IRGKangXi=0526.211, RSKangXi=75.6
2346E CJK UNIFIED IDEOGRAPH-#2346E, IRGKangXi=0526.211, RSKangXi=75.6
2346F CJK UNIFIED IDEOGRAPH-#2346F, IRGKangXi=0526.211, RSKangXi=75.6
23470 CJK UNIFIED IDEOGRAPH-#23470, IRGKangXi=0526.211, RSKangXi=75.6
23471 CJK UNIFIED IDEOGRAPH-#23471, IRGKangXi=0526.211, RSKangXi=75.6
23472 CJK UNIFIED IDEOGRAPH-#23472, IRGKangXi=0526.211, RSKangXi=75.6
23473 CJK UNIFIED IDEOGRAPH-#23473, IRGKangXi=0526.211, RSKangXi=75.6
23474 CJK UNIFIED IDEOGRAPH-#23474, IRGKangXi=0526.211, RSKangXi=75.6
23475 CJK UNIFIED IDEOGRAPH-#23475, IRGKangXi=0526.211, RSKangXi=75.6
23476 CJK UNIFIED IDEOGRAPH-#23476, IRGKangXi=0526.211, RSKangXi=75.6
23477 CJK UNIFIED IDEOGRAPH-#23477, IRGKangXi=0526.211, RSKangXi=75.6
23478 CJK UNIFIED IDEOGRAPH-#23478, IRGKangXi=0526.211, RSKangXi=75.6
23479 CJK UNIFIED IDEOGRAPH-#23479, IRGKangXi=0526.211, RSKangXi=75.6
2347A CJK UNIFIED IDEOGRAPH-#2347A, IRGKangXi=0526.211, RSKangXi=75.6
2347B CJK UNIFIED IDEOGRAPH-#2347B, IRGKangXi=0526.211, RSKangXi=75.6
2347C CJK UNIFIED IDEOGRAPH-#2347C, IRGKangXi=0526.211, RSKangXi=75.6
2347D CJK UNIFIED IDEOGRAPH-#2347D, IRGKangXi=0526.211, RSKangXi=75.6
2347E CJK UNIFIED IDEOGRAPH-#2347E, IRGKangXi=0526.211, RSKangXi=75.6
2347F CJK UNIFIED IDEOGRAPH-#2347F, IRGKangXi=0527.080, RSKangXi=75.7
23480 CJK UNIFIED IDEOGRAPH-#23480, IRGKangXi=0528.060, RSKangXi=75.7
23481 CJK UNIFIED IDEOGRAPH-#23481, IRGKangXi=0528.160, RSKangXi=75.7
23482 CJK UNIFIED IDEOGRAPH-#23482, IRGKangXi=0530.020, RSKangXi=75.7
23483 CJK UNIFIED IDEOGRAPH-#23483, IRGKangXi=0530.030, RSKangXi=75.7
23484 CJK UNIFIED IDEOGRAPH-#23484, IRGKangXi=0530.090, RSKangXi=75.7
23485 CJK UNIFIED IDEOGRAPH-#23485, IRGKangXi=0531.010, RSKangXi=75.7
23486 CJK UNIFIED IDEOGRAPH-#23486, IRGKangXi=0531.050, RSKangXi=75.7
23487 CJK UNIFIED IDEOGRAPH-#23487, IRGKangXi=0531.110, RSKangXi=75.7
23488 CJK UNIFIED IDEOGRAPH-#23488, IRGKangXi=0531.120, RSKangXi=75.7
23489 CJK UNIFIED IDEOGRAPH-#23489, IRGKangXi=0531.130, RSKangXi=75.7
2348A CJK UNIFIED IDEOGRAPH-#2348A, IRGKangXi=0531.131, RSKangXi=75.7
2348B CJK UNIFIED IDEOGRAPH-#2348B, IRGKangXi=0531.131, RSKangXi=75.7
2348C CJK UNIFIED IDEOGRAPH-#2348C, IRGKangXi=0531.131, RSKangXi=75.7
2348D CJK UNIFIED IDEOGRAPH-#2348D, IRGKangXi=0531.131, RSKangXi=75.7
2348E CJK UNIFIED IDEOGRAPH-#2348E, IRGKangXi=0531.131, RSKangXi=75.7
2348F CJK UNIFIED IDEOGRAPH-#2348F, IRGKangXi=0531.131, RSKangXi=75.7
23490 CJK UNIFIED IDEOGRAPH-#23490, IRGKangXi=0531.131, RSKangXi=75.7
23491 CJK UNIFIED IDEOGRAPH-#23491, IRGKangXi=0531.131, RSKangXi=75.7
23492 CJK UNIFIED IDEOGRAPH-#23492, IRGKangXi=0531.131, RSKangXi=75.7
23493 CJK UNIFIED IDEOGRAPH-#23493, IRGKangXi=0531.131, RSKangXi=75.7
23494 CJK UNIFIED IDEOGRAPH-#23494, IRGKangXi=0531.131, RSKangXi=75.7
23495 CJK UNIFIED IDEOGRAPH-#23495, IRGKangXi=0531.131, RSKangXi=75.7
23496 CJK UNIFIED IDEOGRAPH-#23496, IRGKangXi=0531.131, RSKangXi=75.7
23497 CJK UNIFIED IDEOGRAPH-#23497, IRGKangXi=0531.131, RSKangXi=75.7
23498 CJK UNIFIED IDEOGRAPH-#23498, IRGKangXi=0531.131, RSKangXi=75.7
23499 CJK UNIFIED IDEOGRAPH-#23499, IRGKangXi=0531.131, RSKangXi=75.7
2349A CJK UNIFIED IDEOGRAPH-#2349A, IRGKangXi=0531.131, RSKangXi=75.7
2349B CJK UNIFIED IDEOGRAPH-#2349B, IRGKangXi=0531.131, RSKangXi=75.7
2349C CJK UNIFIED IDEOGRAPH-#2349C, IRGKangXi=0531.131, RSKangXi=75.7
2349D CJK UNIFIED IDEOGRAPH-#2349D, IRGKangXi=0531.131, RSKangXi=75.7
2349E CJK UNIFIED IDEOGRAPH-#2349E, IRGKangXi=0531.131, RSKangXi=75.7
2349F CJK UNIFIED IDEOGRAPH-#2349F, IRGKangXi=0531.131, RSKangXi=75.7
234A0 CJK UNIFIED IDEOGRAPH-#234A0, IRGKangXi=0531.131, RSKangXi=75.7
234A1 CJK UNIFIED IDEOGRAPH-#234A1, IRGKangXi=0531.131, RSKangXi=75.7
234A2 CJK UNIFIED IDEOGRAPH-#234A2, IRGKangXi=0531.131, RSKangXi=75.7
234A3 CJK UNIFIED IDEOGRAPH-#234A3, IRGKangXi=0531.131, RSKangXi=75.7
234A4 CJK UNIFIED IDEOGRAPH-#234A4, IRGKangXi=0531.131, RSKangXi=75.7
234A5 CJK UNIFIED IDEOGRAPH-#234A5, IRGKangXi=0531.131, RSKangXi=75.7
234A6 CJK UNIFIED IDEOGRAPH-#234A6, IRGKangXi=0531.131, RSKangXi=75.7
234A7 CJK UNIFIED IDEOGRAPH-#234A7, IRGKangXi=0531.131, RSKangXi=75.7
234A8 CJK UNIFIED IDEOGRAPH-#234A8, IRGKangXi=0531.131, RSKangXi=75.7
234A9 CJK UNIFIED IDEOGRAPH-#234A9, IRGKangXi=0531.131, RSKangXi=75.7
234AA CJK UNIFIED IDEOGRAPH-#234AA, IRGKangXi=0531.131, RSKangXi=75.7
234AB CJK UNIFIED IDEOGRAPH-#234AB, IRGKangXi=0531.131, RSKangXi=75.7
234AC CJK UNIFIED IDEOGRAPH-#234AC, IRGKangXi=0531.131, RSKangXi=75.7
234AD CJK UNIFIED IDEOGRAPH-#234AD, IRGKangXi=0531.131, RSKangXi=75.7
234AE CJK UNIFIED IDEOGRAPH-#234AE, IRGKangXi=0531.131, RSKangXi=75.7
234AF CJK UNIFIED IDEOGRAPH-#234AF, IRGKangXi=0531.131, RSKangXi=75.7
234B0 CJK UNIFIED IDEOGRAPH-#234B0, IRGKangXi=0531.131, RSKangXi=75.7
234B1 CJK UNIFIED IDEOGRAPH-#234B1, IRGKangXi=0531.131, RSKangXi=75.7
234B2 CJK UNIFIED IDEOGRAPH-#234B2, IRGKangXi=0531.131, RSKangXi=75.7
234B3 CJK UNIFIED IDEOGRAPH-#234B3, IRGKangXi=0531.131, RSKangXi=75.7
234B4 CJK UNIFIED IDEOGRAPH-#234B4, IRGKangXi=0531.131, RSKangXi=75.7
234B5 CJK UNIFIED IDEOGRAPH-#234B5, IRGKangXi=0531.131, RSKangXi=75.7
234B6 CJK UNIFIED IDEOGRAPH-#234B6, IRGKangXi=0531.131, RSKangXi=75.7
234B7 CJK UNIFIED IDEOGRAPH-#234B7, IRGKangXi=0531.131, RSKangXi=75.7
234B8 CJK UNIFIED IDEOGRAPH-#234B8, IRGKangXi=0531.131, RSKangXi=75.7
234B9 CJK UNIFIED IDEOGRAPH-#234B9, IRGKangXi=0531.131, RSKangXi=75.7
234BA CJK UNIFIED IDEOGRAPH-#234BA, IRGKangXi=0531.131, RSKangXi=75.7
234BB CJK UNIFIED IDEOGRAPH-#234BB, IRGKangXi=0531.131, RSKangXi=75.7
234BC CJK UNIFIED IDEOGRAPH-#234BC, IRGKangXi=0531.131, RSKangXi=75.7
234BD CJK UNIFIED IDEOGRAPH-#234BD, IRGKangXi=0531.131, RSKangXi=75.7
234BE CJK UNIFIED IDEOGRAPH-#234BE, IRGKangXi=0531.131, RSKangXi=75.7
234BF CJK UNIFIED IDEOGRAPH-#234BF, IRGKangXi=0531.131, RSKangXi=75.7
234C0 CJK UNIFIED IDEOGRAPH-#234C0, IRGKangXi=0531.131, RSKangXi=75.7
234C1 CJK UNIFIED IDEOGRAPH-#234C1, IRGKangXi=0532.010, RSKangXi=75.8
234C2 CJK UNIFIED IDEOGRAPH-#234C2, IRGKangXi=0532.130, RSKangXi=75.8
234C3 CJK UNIFIED IDEOGRAPH-#234C3, IRGKangXi=0532.150, RSKangXi=75.8
234C4 CJK UNIFIED IDEOGRAPH-#234C4, IRGKangXi=0532.160, RSKangXi=75.8
234C5 CJK UNIFIED IDEOGRAPH-#234C5, IRGKangXi=0533.010, RSKangXi=75.8
234C6 CJK UNIFIED IDEOGRAPH-#234C6, IRGKangXi=0533.030, RSKangXi=75.8
234C7 CJK UNIFIED IDEOGRAPH-#234C7, IRGKangXi=0533.040, RSKangXi=75.8
234C8 CJK UNIFIED IDEOGRAPH-#234C8, IRGKangXi=0533.090, RSKangXi=75.8
234C9 CJK UNIFIED IDEOGRAPH-#234C9, IRGKangXi=0533.110, RSKangXi=75.8
234CA CJK UNIFIED IDEOGRAPH-#234CA, IRGKangXi=0533.220, RSKangXi=75.8
234CB CJK UNIFIED IDEOGRAPH-#234CB, IRGKangXi=0533.230, RSKangXi=75.8
234CC CJK UNIFIED IDEOGRAPH-#234CC, IRGKangXi=0534.010, RSKangXi=75.8, Def{a well-sweep}
234CD CJK UNIFIED IDEOGRAPH-#234CD, IRGKangXi=0534.090, RSKangXi=75.8
234CE CJK UNIFIED IDEOGRAPH-#234CE, IRGKangXi=0534.100, RSKangXi=75.8
234CF CJK UNIFIED IDEOGRAPH-#234CF, IRGKangXi=0534.120, RSKangXi=75.8
234D0 CJK UNIFIED IDEOGRAPH-#234D0, IRGKangXi=0534.130, RSKangXi=75.8
234D1 CJK UNIFIED IDEOGRAPH-#234D1, IRGKangXi=0534.210, RSKangXi=75.8
234D2 CJK UNIFIED IDEOGRAPH-#234D2, IRGKangXi=0534.220, RSKangXi=75.8
234D3 CJK UNIFIED IDEOGRAPH-#234D3, IRGKangXi=0534.230, RSKangXi=75.8
234D4 CJK UNIFIED IDEOGRAPH-#234D4, IRGKangXi=0534.260, RSKangXi=75.8
234D5 CJK UNIFIED IDEOGRAPH-#234D5, IRGKangXi=0535.090, RSKangXi=75.8
234D6 CJK UNIFIED IDEOGRAPH-#234D6, IRGKangXi=0535.120, RSKangXi=75.8
234D7 CJK UNIFIED IDEOGRAPH-#234D7, IRGKangXi=0535.180, RSKangXi=75.8
234D8 CJK UNIFIED IDEOGRAPH-#234D8, IRGKangXi=0536.040, RSKangXi=75.8
234D9 CJK UNIFIED IDEOGRAPH-#234D9, IRGKangXi=0537.010, RSKangXi=75.8
234DA CJK UNIFIED IDEOGRAPH-#234DA, IRGKangXi=0537.030, RSKangXi=75.8
234DB CJK UNIFIED IDEOGRAPH-#234DB, IRGKangXi=0537.050, RSKangXi=75.8
234DC CJK UNIFIED IDEOGRAPH-#234DC, IRGKangXi=0537.070, RSKangXi=75.8
234DD CJK UNIFIED IDEOGRAPH-#234DD, IRGKangXi=0537.080, RSKangXi=75.8
234DE CJK UNIFIED IDEOGRAPH-#234DE, IRGKangXi=0537.100, RSKangXi=75.8
234DF CJK UNIFIED IDEOGRAPH-#234DF, IRGKangXi=0537.110, RSKangXi=75.8
234E0 CJK UNIFIED IDEOGRAPH-#234E0, IRGKangXi=0537.120, RSKangXi=75.8
234E1 CJK UNIFIED IDEOGRAPH-#234E1, IRGKangXi=0537.130, RSKangXi=75.8
234E2 CJK UNIFIED IDEOGRAPH-#234E2, IRGKangXi=0537.131, RSKangXi=75.8
234E3 CJK UNIFIED IDEOGRAPH-#234E3, IRGKangXi=0537.131, RSKangXi=75.8
234E4 CJK UNIFIED IDEOGRAPH-#234E4, IRGKangXi=0537.131, RSKangXi=75.8
234E5 CJK UNIFIED IDEOGRAPH-#234E5, IRGKangXi=0537.131, RSKangXi=75.8
234E6 CJK UNIFIED IDEOGRAPH-#234E6, IRGKangXi=0537.131, RSKangXi=75.8
234E7 CJK UNIFIED IDEOGRAPH-#234E7, IRGKangXi=0537.131, RSKangXi=75.8
234E8 CJK UNIFIED IDEOGRAPH-#234E8, IRGKangXi=0537.131, RSKangXi=75.8
234E9 CJK UNIFIED IDEOGRAPH-#234E9, IRGKangXi=0537.131, RSKangXi=75.8
234EA CJK UNIFIED IDEOGRAPH-#234EA, IRGKangXi=0537.131, RSKangXi=75.8
234EB CJK UNIFIED IDEOGRAPH-#234EB, IRGKangXi=0537.131, RSKangXi=75.8
234EC CJK UNIFIED IDEOGRAPH-#234EC, IRGKangXi=0537.131, RSKangXi=75.8
234ED CJK UNIFIED IDEOGRAPH-#234ED, IRGKangXi=0537.131, RSKangXi=75.8
234EE CJK UNIFIED IDEOGRAPH-#234EE, IRGKangXi=0537.131, RSKangXi=75.8
234EF CJK UNIFIED IDEOGRAPH-#234EF, IRGKangXi=0537.131, RSKangXi=75.8
234F0 CJK UNIFIED IDEOGRAPH-#234F0, IRGKangXi=0537.131, RSKangXi=75.8
234F1 CJK UNIFIED IDEOGRAPH-#234F1, IRGKangXi=0537.131, RSKangXi=75.8
234F2 CJK UNIFIED IDEOGRAPH-#234F2, IRGKangXi=0537.131, RSKangXi=75.8
234F3 CJK UNIFIED IDEOGRAPH-#234F3, IRGKangXi=0537.131, RSKangXi=75.8
234F4 CJK UNIFIED IDEOGRAPH-#234F4, IRGKangXi=0537.131, RSKangXi=75.8
234F5 CJK UNIFIED IDEOGRAPH-#234F5, IRGKangXi=0537.131, RSKangXi=75.8
234F6 CJK UNIFIED IDEOGRAPH-#234F6, IRGKangXi=0537.131, RSKangXi=75.8
234F7 CJK UNIFIED IDEOGRAPH-#234F7, IRGKangXi=0537.131, RSKangXi=75.8
234F8 CJK UNIFIED IDEOGRAPH-#234F8, IRGKangXi=0537.131, RSKangXi=75.8
234F9 CJK UNIFIED IDEOGRAPH-#234F9, IRGKangXi=0537.131, RSKangXi=75.8
234FA CJK UNIFIED IDEOGRAPH-#234FA, IRGKangXi=0537.131, RSKangXi=75.8
234FB CJK UNIFIED IDEOGRAPH-#234FB, IRGKangXi=0537.131, RSKangXi=75.8
234FC CJK UNIFIED IDEOGRAPH-#234FC, IRGKangXi=0537.131, RSKangXi=75.8
234FD CJK UNIFIED IDEOGRAPH-#234FD, IRGKangXi=0537.131, RSKangXi=75.8
234FE CJK UNIFIED IDEOGRAPH-#234FE, IRGKangXi=0537.131, RSKangXi=75.8
234FF CJK UNIFIED IDEOGRAPH-#234FF, IRGKangXi=0537.131, RSKangXi=75.8
23500 CJK UNIFIED IDEOGRAPH-#23500, IRGKangXi=0537.131, RSKangXi=75.8
23501 CJK UNIFIED IDEOGRAPH-#23501, IRGKangXi=0537.131, RSKangXi=75.8
23502 CJK UNIFIED IDEOGRAPH-#23502, IRGKangXi=0537.131, RSKangXi=75.8
23503 CJK UNIFIED IDEOGRAPH-#23503, IRGKangXi=0537.131, RSKangXi=75.8
23504 CJK UNIFIED IDEOGRAPH-#23504, IRGKangXi=0537.131, RSKangXi=75.8
23505 CJK UNIFIED IDEOGRAPH-#23505, IRGKangXi=0537.131, RSKangXi=75.8
23506 CJK UNIFIED IDEOGRAPH-#23506, IRGKangXi=0537.131, RSKangXi=75.8
23507 CJK UNIFIED IDEOGRAPH-#23507, IRGKangXi=0537.131, RSKangXi=75.8
23508 CJK UNIFIED IDEOGRAPH-#23508, IRGKangXi=0537.131, RSKangXi=75.8
23509 CJK UNIFIED IDEOGRAPH-#23509, IRGKangXi=0537.131, RSKangXi=75.8
2350A CJK UNIFIED IDEOGRAPH-#2350A, IRGKangXi=0537.131, RSKangXi=75.8
2350B CJK UNIFIED IDEOGRAPH-#2350B, IRGKangXi=0537.131, RSKangXi=75.8
2350C CJK UNIFIED IDEOGRAPH-#2350C, IRGKangXi=0537.131, RSKangXi=75.8
2350D CJK UNIFIED IDEOGRAPH-#2350D, IRGKangXi=0537.131, RSKangXi=75.8
2350E CJK UNIFIED IDEOGRAPH-#2350E, IRGKangXi=0537.131, RSKangXi=75.8
2350F CJK UNIFIED IDEOGRAPH-#2350F, IRGKangXi=0537.131, RSKangXi=75.8
23510 CJK UNIFIED IDEOGRAPH-#23510, IRGKangXi=0537.131, RSKangXi=75.8
23511 CJK UNIFIED IDEOGRAPH-#23511, IRGKangXi=0537.131, RSKangXi=75.8
23512 CJK UNIFIED IDEOGRAPH-#23512, IRGKangXi=0537.131, RSKangXi=75.8
23513 CJK UNIFIED IDEOGRAPH-#23513, IRGKangXi=0537.131, RSKangXi=75.8
23514 CJK UNIFIED IDEOGRAPH-#23514, IRGKangXi=0537.131, RSKangXi=75.8
23515 CJK UNIFIED IDEOGRAPH-#23515, IRGKangXi=0537.131, RSKangXi=75.8
23516 CJK UNIFIED IDEOGRAPH-#23516, IRGKangXi=0537.131, RSKangXi=75.8
23517 CJK UNIFIED IDEOGRAPH-#23517, IRGKangXi=0537.131, RSKangXi=75.8
23518 CJK UNIFIED IDEOGRAPH-#23518, IRGKangXi=0537.131, RSKangXi=75.8
23519 CJK UNIFIED IDEOGRAPH-#23519, IRGKangXi=0537.131, RSKangXi=75.8
2351A CJK UNIFIED IDEOGRAPH-#2351A, IRGKangXi=0537.131, RSKangXi=75.8
2351B CJK UNIFIED IDEOGRAPH-#2351B, IRGKangXi=0537.131, RSKangXi=75.8
2351C CJK UNIFIED IDEOGRAPH-#2351C, IRGKangXi=0537.131, RSKangXi=75.8
2351D CJK UNIFIED IDEOGRAPH-#2351D, IRGKangXi=0537.131, RSKangXi=75.8
2351E CJK UNIFIED IDEOGRAPH-#2351E, IRGKangXi=0537.131, RSKangXi=75.8
2351F CJK UNIFIED IDEOGRAPH-#2351F, IRGKangXi=0537.131, RSKangXi=75.8
23520 CJK UNIFIED IDEOGRAPH-#23520, IRGKangXi=0537.131, RSKangXi=75.8
23521 CJK UNIFIED IDEOGRAPH-#23521, IRGKangXi=0537.131, RSKangXi=75.8
23522 CJK UNIFIED IDEOGRAPH-#23522, IRGKangXi=0537.131, RSKangXi=75.8
23523 CJK UNIFIED IDEOGRAPH-#23523, IRGKangXi=0537.131, RSKangXi=75.8
23524 CJK UNIFIED IDEOGRAPH-#23524, IRGKangXi=0537.131, RSKangXi=75.8
23525 CJK UNIFIED IDEOGRAPH-#23525, IRGKangXi=0537.131, RSKangXi=75.8
23526 CJK UNIFIED IDEOGRAPH-#23526, IRGKangXi=0537.131, RSKangXi=75.8
23527 CJK UNIFIED IDEOGRAPH-#23527, IRGKangXi=0537.131, RSKangXi=75.8
23528 CJK UNIFIED IDEOGRAPH-#23528, IRGKangXi=0537.131, RSKangXi=75.8, Def{(Cant.) to be entangled, twisted; (of alcohol and tobacco) to be strong}
23529 CJK UNIFIED IDEOGRAPH-#23529, IRGKangXi=0537.131, RSKangXi=75.8
2352A CJK UNIFIED IDEOGRAPH-#2352A, IRGKangXi=0537.131, RSKangXi=75.8
2352B CJK UNIFIED IDEOGRAPH-#2352B, IRGKangXi=0537.131, RSKangXi=75.8
2352C CJK UNIFIED IDEOGRAPH-#2352C, IRGKangXi=0537.131, RSKangXi=75.8
2352D CJK UNIFIED IDEOGRAPH-#2352D, IRGKangXi=0537.131, RSKangXi=75.8
2352E CJK UNIFIED IDEOGRAPH-#2352E, IRGKangXi=0537.131, RSKangXi=75.8
2352F CJK UNIFIED IDEOGRAPH-#2352F, IRGKangXi=0537.131, RSKangXi=75.8
23530 CJK UNIFIED IDEOGRAPH-#23530, IRGKangXi=0537.131, RSKangXi=75.8
23531 CJK UNIFIED IDEOGRAPH-#23531, IRGKangXi=0537.140, RSKangXi=75.9
23532 CJK UNIFIED IDEOGRAPH-#23532, IRGKangXi=0537.150, RSKangXi=75.9
23533 CJK UNIFIED IDEOGRAPH-#23533, IRGKangXi=0537.220, RSKangXi=75.9
23534 CJK UNIFIED IDEOGRAPH-#23534, IRGKangXi=0537.250, RSKangXi=75.9
23535 CJK UNIFIED IDEOGRAPH-#23535, IRGKangXi=0538.130, RSKangXi=75.9
23536 CJK UNIFIED IDEOGRAPH-#23536, IRGKangXi=0538.170, RSKangXi=75.9
23537 CJK UNIFIED IDEOGRAPH-#23537, IRGKangXi=0538.190, RSKangXi=75.9
23538 CJK UNIFIED IDEOGRAPH-#23538, IRGKangXi=0538.200, RSKangXi=75.9
23539 CJK UNIFIED IDEOGRAPH-#23539, IRGKangXi=0538.220, RSKangXi=75.9
2353A CJK UNIFIED IDEOGRAPH-#2353A, IRGKangXi=0538.240, RSKangXi=75.9
2353B CJK UNIFIED IDEOGRAPH-#2353B, IRGKangXi=0538.370, RSKangXi=75.9
2353C CJK UNIFIED IDEOGRAPH-#2353C, IRGKangXi=0539.030, RSKangXi=75.9, Def{a cane, rod, pole, staff}
2353D CJK UNIFIED IDEOGRAPH-#2353D, IRGKangXi=0539.060, RSKangXi=75.9
2353E CJK UNIFIED IDEOGRAPH-#2353E, IRGKangXi=0539.100, RSKangXi=75.9
2353F CJK UNIFIED IDEOGRAPH-#2353F, IRGKangXi=0539.140, RSKangXi=75.9
23540 CJK UNIFIED IDEOGRAPH-#23540, IRGKangXi=0539.170, RSKangXi=75.9
23541 CJK UNIFIED IDEOGRAPH-#23541, IRGKangXi=0539.190, RSKangXi=75.9
23542 CJK UNIFIED IDEOGRAPH-#23542, IRGKangXi=0540.010, RSKangXi=75.9
23543 CJK UNIFIED IDEOGRAPH-#23543, IRGKangXi=0540.020, RSKangXi=75.9
23544 CJK UNIFIED IDEOGRAPH-#23544, IRGKangXi=0540.040, RSKangXi=75.9
23545 CJK UNIFIED IDEOGRAPH-#23545, IRGKangXi=0540.050, RSKangXi=75.9
23546 CJK UNIFIED IDEOGRAPH-#23546, IRGKangXi=0540.090, RSKangXi=75.9
23547 CJK UNIFIED IDEOGRAPH-#23547, IRGKangXi=0540.190, RSKangXi=75.9
23548 CJK UNIFIED IDEOGRAPH-#23548, IRGKangXi=0540.200, RSKangXi=75.9
23549 CJK UNIFIED IDEOGRAPH-#23549, IRGKangXi=0540.230, RSKangXi=75.9
2354A CJK UNIFIED IDEOGRAPH-#2354A, IRGKangXi=0541.130, RSKangXi=75.9
2354B CJK UNIFIED IDEOGRAPH-#2354B, IRGKangXi=0542.040, RSKangXi=75.9
2354C CJK UNIFIED IDEOGRAPH-#2354C, IRGKangXi=0542.100, RSKangXi=75.9
2354D CJK UNIFIED IDEOGRAPH-#2354D, IRGKangXi=0542.120, RSKangXi=75.9
2354E CJK UNIFIED IDEOGRAPH-#2354E, IRGKangXi=0542.130, RSKangXi=75.9
2354F CJK UNIFIED IDEOGRAPH-#2354F, IRGKangXi=0542.140, RSKangXi=75.9
23550 CJK UNIFIED IDEOGRAPH-#23550, IRGKangXi=0542.160, RSKangXi=75.9
23551 CJK UNIFIED IDEOGRAPH-#23551, IRGKangXi=0542.170, RSKangXi=75.9
23552 CJK UNIFIED IDEOGRAPH-#23552, IRGKangXi=0542.180, RSKangXi=75.9
23553 CJK UNIFIED IDEOGRAPH-#23553, IRGKangXi=0542.190, RSKangXi=75.9
23554 CJK UNIFIED IDEOGRAPH-#23554, IRGKangXi=0542.191, RSKangXi=75.9
23555 CJK UNIFIED IDEOGRAPH-#23555, IRGKangXi=0542.191, RSKangXi=75.9
23556 CJK UNIFIED IDEOGRAPH-#23556, IRGKangXi=0542.191, RSKangXi=75.9
23557 CJK UNIFIED IDEOGRAPH-#23557, IRGKangXi=0542.191, RSKangXi=75.9
23558 CJK UNIFIED IDEOGRAPH-#23558, IRGKangXi=0542.191, RSKangXi=75.9
23559 CJK UNIFIED IDEOGRAPH-#23559, IRGKangXi=0542.191, RSKangXi=75.9
2355A CJK UNIFIED IDEOGRAPH-#2355A, IRGKangXi=0542.191, RSKangXi=75.9
2355B CJK UNIFIED IDEOGRAPH-#2355B, IRGKangXi=0542.191, RSKangXi=75.9
2355C CJK UNIFIED IDEOGRAPH-#2355C, IRGKangXi=0542.191, RSKangXi=75.9
2355D CJK UNIFIED IDEOGRAPH-#2355D, IRGKangXi=0542.191, RSKangXi=75.9
2355E CJK UNIFIED IDEOGRAPH-#2355E, IRGKangXi=0542.191, RSKangXi=75.9
2355F CJK UNIFIED IDEOGRAPH-#2355F, IRGKangXi=0542.191, RSKangXi=75.9
23560 CJK UNIFIED IDEOGRAPH-#23560, IRGKangXi=0542.191, RSKangXi=75.9
23561 CJK UNIFIED IDEOGRAPH-#23561, IRGKangXi=0542.191, RSKangXi=75.9
23562 CJK UNIFIED IDEOGRAPH-#23562, IRGKangXi=0542.191, RSKangXi=75.9
23563 CJK UNIFIED IDEOGRAPH-#23563, IRGKangXi=0542.191
23564 CJK UNIFIED IDEOGRAPH-#23564, IRGKangXi=0542.191, RSKangXi=75.10
23565 CJK UNIFIED IDEOGRAPH-#23565, IRGKangXi=0542.191, RSKangXi=75.9
23566 CJK UNIFIED IDEOGRAPH-#23566, IRGKangXi=0542.191, RSKangXi=75.9
23567 CJK UNIFIED IDEOGRAPH-#23567, IRGKangXi=0542.191, RSKangXi=75.9
23568 CJK UNIFIED IDEOGRAPH-#23568, IRGKangXi=0542.191, RSKangXi=75.9
23569 CJK UNIFIED IDEOGRAPH-#23569, IRGKangXi=0542.191, RSKangXi=75.9
2356A CJK UNIFIED IDEOGRAPH-#2356A, IRGKangXi=0542.191, RSKangXi=75.9
2356B CJK UNIFIED IDEOGRAPH-#2356B, IRGKangXi=0542.191, RSKangXi=75.9
2356C CJK UNIFIED IDEOGRAPH-#2356C, IRGKangXi=0542.191, RSKangXi=75.9
2356D CJK UNIFIED IDEOGRAPH-#2356D, IRGKangXi=0542.191, RSKangXi=75.9
2356E CJK UNIFIED IDEOGRAPH-#2356E, IRGKangXi=0542.191, RSKangXi=75.9
2356F CJK UNIFIED IDEOGRAPH-#2356F, IRGKangXi=0542.191, RSKangXi=75.9
23570 CJK UNIFIED IDEOGRAPH-#23570, IRGKangXi=0542.191, RSKangXi=75.9
23571 CJK UNIFIED IDEOGRAPH-#23571, IRGKangXi=0542.191, RSKangXi=75.9
23572 CJK UNIFIED IDEOGRAPH-#23572, IRGKangXi=0542.191, RSKangXi=75.9
23573 CJK UNIFIED IDEOGRAPH-#23573, IRGKangXi=0542.191, RSKangXi=75.9
23574 CJK UNIFIED IDEOGRAPH-#23574, IRGKangXi=0542.191, RSKangXi=75.9
23575 CJK UNIFIED IDEOGRAPH-#23575, IRGKangXi=0542.191, RSKangXi=75.9
23576 CJK UNIFIED IDEOGRAPH-#23576, IRGKangXi=0542.191, RSKangXi=75.9
23577 CJK UNIFIED IDEOGRAPH-#23577, IRGKangXi=0542.191, RSKangXi=75.9
23578 CJK UNIFIED IDEOGRAPH-#23578, IRGKangXi=0542.191, RSKangXi=75.9
23579 CJK UNIFIED IDEOGRAPH-#23579, IRGKangXi=0542.191, RSKangXi=75.9
2357A CJK UNIFIED IDEOGRAPH-#2357A, IRGKangXi=0542.191, RSKangXi=75.9
2357B CJK UNIFIED IDEOGRAPH-#2357B, IRGKangXi=0542.191, RSKangXi=75.9
2357C CJK UNIFIED IDEOGRAPH-#2357C, IRGKangXi=0542.191, RSKangXi=75.9
2357D CJK UNIFIED IDEOGRAPH-#2357D, IRGKangXi=0542.191, RSKangXi=75.9
2357E CJK UNIFIED IDEOGRAPH-#2357E, IRGKangXi=0542.191, RSKangXi=75.9
2357F CJK UNIFIED IDEOGRAPH-#2357F, IRGKangXi=0542.191, RSKangXi=75.9
23580 CJK UNIFIED IDEOGRAPH-#23580, IRGKangXi=0542.191, RSKangXi=75.9
23581 CJK UNIFIED IDEOGRAPH-#23581, IRGKangXi=0542.191, RSKangXi=75.9
23582 CJK UNIFIED IDEOGRAPH-#23582, IRGKangXi=0542.191, RSKangXi=75.9
23583 CJK UNIFIED IDEOGRAPH-#23583, IRGKangXi=0542.191, RSKangXi=75.9
23584 CJK UNIFIED IDEOGRAPH-#23584, IRGKangXi=0542.191, RSKangXi=75.9
23585 CJK UNIFIED IDEOGRAPH-#23585, IRGKangXi=0542.191, RSKangXi=75.9
23586 CJK UNIFIED IDEOGRAPH-#23586, IRGKangXi=0542.191, RSKangXi=75.9
23587 CJK UNIFIED IDEOGRAPH-#23587, IRGKangXi=0542.191, RSKangXi=75.9
23588 CJK UNIFIED IDEOGRAPH-#23588, IRGKangXi=0542.191, RSKangXi=75.9
23589 CJK UNIFIED IDEOGRAPH-#23589, IRGKangXi=0542.191, RSKangXi=75.9
2358A CJK UNIFIED IDEOGRAPH-#2358A, IRGKangXi=0542.191, RSKangXi=75.9
2358B CJK UNIFIED IDEOGRAPH-#2358B, IRGKangXi=0542.191, RSKangXi=75.9
2358C CJK UNIFIED IDEOGRAPH-#2358C, IRGKangXi=0542.191, RSKangXi=75.9
2358D CJK UNIFIED IDEOGRAPH-#2358D, IRGKangXi=0542.191, RSKangXi=75.9
2358E CJK UNIFIED IDEOGRAPH-#2358E, IRGKangXi=0542.191, RSKangXi=75.9
2358F CJK UNIFIED IDEOGRAPH-#2358F, IRGKangXi=0542.191, RSKangXi=75.9
23590 CJK UNIFIED IDEOGRAPH-#23590, IRGKangXi=0542.191, RSKangXi=75.9
23591 CJK UNIFIED IDEOGRAPH-#23591, IRGKangXi=0542.191, RSKangXi=75.9
23592 CJK UNIFIED IDEOGRAPH-#23592, IRGKangXi=0542.191, RSKangXi=75.9
23593 CJK UNIFIED IDEOGRAPH-#23593, IRGKangXi=0542.191, RSKangXi=75.9
23594 CJK UNIFIED IDEOGRAPH-#23594, IRGKangXi=0542.191, RSKangXi=75.9
23595 CJK UNIFIED IDEOGRAPH-#23595, IRGKangXi=0542.191, RSKangXi=75.9, Def{(Cant.) the back of a chair for one to lean against}
23596 CJK UNIFIED IDEOGRAPH-#23596, IRGKangXi=0542.191, RSKangXi=75.9
23597 CJK UNIFIED IDEOGRAPH-#23597, IRGKangXi=0542.191, RSKangXi=75.9
23598 CJK UNIFIED IDEOGRAPH-#23598, IRGKangXi=0542.191, RSKangXi=75.9
23599 CJK UNIFIED IDEOGRAPH-#23599, IRGKangXi=0542.191, RSKangXi=75.9
2359A CJK UNIFIED IDEOGRAPH-#2359A, IRGKangXi=0542.191, RSKangXi=75.9
2359B CJK UNIFIED IDEOGRAPH-#2359B, IRGKangXi=0542.191, RSKangXi=75.9
2359C CJK UNIFIED IDEOGRAPH-#2359C, IRGKangXi=0542.191, RSKangXi=75.9
2359D CJK UNIFIED IDEOGRAPH-#2359D, IRGKangXi=0542.191, RSKangXi=75.9
2359E CJK UNIFIED IDEOGRAPH-#2359E, IRGKangXi=0542.191, RSKangXi=75.9
2359F CJK UNIFIED IDEOGRAPH-#2359F, IRGKangXi=0542.191, RSKangXi=75.9
235A0 CJK UNIFIED IDEOGRAPH-#235A0, IRGKangXi=0542.191, RSKangXi=75.9
235A1 CJK UNIFIED IDEOGRAPH-#235A1, IRGKangXi=0542.191, RSKangXi=75.9
235A2 CJK UNIFIED IDEOGRAPH-#235A2, IRGKangXi=0542.191, RSKangXi=75.9
235A3 CJK UNIFIED IDEOGRAPH-#235A3, IRGKangXi=0542.191, RSKangXi=75.9
235A4 CJK UNIFIED IDEOGRAPH-#235A4, IRGKangXi=0542.191, RSKangXi=75.9
235A5 CJK UNIFIED IDEOGRAPH-#235A5, IRGKangXi=0542.191, RSKangXi=75.9
235A6 CJK UNIFIED IDEOGRAPH-#235A6, IRGKangXi=0542.191, RSKangXi=75.9
235A7 CJK UNIFIED IDEOGRAPH-#235A7, IRGKangXi=0542.191, RSKangXi=75.9
235A8 CJK UNIFIED IDEOGRAPH-#235A8, IRGKangXi=0542.191, RSKangXi=75.9
235A9 CJK UNIFIED IDEOGRAPH-#235A9, IRGKangXi=0542.191, RSKangXi=75.9
235AA CJK UNIFIED IDEOGRAPH-#235AA, IRGKangXi=0543.010, RSKangXi=75.10
235AB CJK UNIFIED IDEOGRAPH-#235AB, IRGKangXi=0543.080, RSKangXi=75.10
235AC CJK UNIFIED IDEOGRAPH-#235AC, IRGKangXi=0543.100, RSKangXi=75.10
235AD CJK UNIFIED IDEOGRAPH-#235AD, IRGKangXi=0543.140, RSKangXi=75.10
235AE CJK UNIFIED IDEOGRAPH-#235AE, IRGKangXi=0543.160, RSKangXi=75.10
235AF CJK UNIFIED IDEOGRAPH-#235AF, IRGKangXi=0543.170, RSKangXi=75.10
235B0 CJK UNIFIED IDEOGRAPH-#235B0, IRGKangXi=0543.240, RSKangXi=75.10
235B1 CJK UNIFIED IDEOGRAPH-#235B1, IRGKangXi=0543.290, RSKangXi=75.10
235B2 CJK UNIFIED IDEOGRAPH-#235B2, IRGKangXi=0543.310, RSKangXi=75.10
235B3 CJK UNIFIED IDEOGRAPH-#235B3, IRGKangXi=0544.040, RSKangXi=75.10
235B4 CJK UNIFIED IDEOGRAPH-#235B4, IRGKangXi=0544.110, RSKangXi=75.10
235B5 CJK UNIFIED IDEOGRAPH-#235B5, IRGKangXi=0544.120, RSKangXi=75.10
235B6 CJK UNIFIED IDEOGRAPH-#235B6, IRGKangXi=0544.130, RSKangXi=75.10
235B7 CJK UNIFIED IDEOGRAPH-#235B7, IRGKangXi=0544.140, RSKangXi=75.10
235B8 CJK UNIFIED IDEOGRAPH-#235B8, IRGKangXi=0544.150, RSKangXi=75.10
235B9 CJK UNIFIED IDEOGRAPH-#235B9, IRGKangXi=0545.020, RSKangXi=75.10
235BA CJK UNIFIED IDEOGRAPH-#235BA, IRGKangXi=0545.110, RSKangXi=75.10
235BB CJK UNIFIED IDEOGRAPH-#235BB, IRGKangXi=0545.210, RSKangXi=75.10
235BC CJK UNIFIED IDEOGRAPH-#235BC, IRGKangXi=0545.240, RSKangXi=75.10
235BD CJK UNIFIED IDEOGRAPH-#235BD, IRGKangXi=0545.250, RSKangXi=75.10
235BE CJK UNIFIED IDEOGRAPH-#235BE, IRGKangXi=0546.010, RSKangXi=75.10
235BF CJK UNIFIED IDEOGRAPH-#235BF, IRGKangXi=0546.030, RSKangXi=75.10
235C0 CJK UNIFIED IDEOGRAPH-#235C0, IRGKangXi=0546.180, RSKangXi=75.10
235C1 CJK UNIFIED IDEOGRAPH-#235C1, IRGKangXi=0546.200, RSKangXi=75.10
235C2 CJK UNIFIED IDEOGRAPH-#235C2, IRGKangXi=0546.210, RSKangXi=75.10
235C3 CJK UNIFIED IDEOGRAPH-#235C3, IRGKangXi=0546.220, RSKangXi=75.10
235C4 CJK UNIFIED IDEOGRAPH-#235C4, IRGKangXi=0546.251, RSKangXi=75.10
235C5 CJK UNIFIED IDEOGRAPH-#235C5, IRGKangXi=0546.251, RSKangXi=75.10
235C6 CJK UNIFIED IDEOGRAPH-#235C6, IRGKangXi=0546.251, RSKangXi=75.10
235C7 CJK UNIFIED IDEOGRAPH-#235C7, IRGKangXi=0546.251, RSKangXi=75.10
235C8 CJK UNIFIED IDEOGRAPH-#235C8, IRGKangXi=0546.251, RSKangXi=75.10
235C9 CJK UNIFIED IDEOGRAPH-#235C9, IRGKangXi=0546.251, RSKangXi=75.10
235CA CJK UNIFIED IDEOGRAPH-#235CA, IRGKangXi=0546.251, RSKangXi=75.10
235CB CJK UNIFIED IDEOGRAPH-#235CB, IRGKangXi=0546.251, RSKangXi=75.10
235CC CJK UNIFIED IDEOGRAPH-#235CC, IRGKangXi=0546.251, RSKangXi=75.10
235CD CJK UNIFIED IDEOGRAPH-#235CD, IRGKangXi=0546.251, RSKangXi=75.10
235CE CJK UNIFIED IDEOGRAPH-#235CE, IRGKangXi=0546.251, RSKangXi=75.10
235CF CJK UNIFIED IDEOGRAPH-#235CF, IRGKangXi=0546.251, RSKangXi=75.10
235D0 CJK UNIFIED IDEOGRAPH-#235D0, IRGKangXi=0546.251, RSKangXi=75.10
235D1 CJK UNIFIED IDEOGRAPH-#235D1, IRGKangXi=0546.251, RSKangXi=75.10
235D2 CJK UNIFIED IDEOGRAPH-#235D2, IRGKangXi=0546.251, RSKangXi=75.10
235D3 CJK UNIFIED IDEOGRAPH-#235D3, IRGKangXi=0546.251, RSKangXi=75.10
235D4 CJK UNIFIED IDEOGRAPH-#235D4, IRGKangXi=0546.251, RSKangXi=75.10
235D5 CJK UNIFIED IDEOGRAPH-#235D5, IRGKangXi=0546.251, RSKangXi=75.10
235D6 CJK UNIFIED IDEOGRAPH-#235D6, IRGKangXi=0546.251, RSKangXi=75.10
235D7 CJK UNIFIED IDEOGRAPH-#235D7, IRGKangXi=0546.251, RSKangXi=75.10
235D8 CJK UNIFIED IDEOGRAPH-#235D8, IRGKangXi=0546.251, RSKangXi=75.10
235D9 CJK UNIFIED IDEOGRAPH-#235D9, IRGKangXi=0546.251, RSKangXi=75.10
235DA CJK UNIFIED IDEOGRAPH-#235DA, IRGKangXi=0546.251, RSKangXi=75.10
235DB CJK UNIFIED IDEOGRAPH-#235DB, IRGKangXi=0546.251, RSKangXi=75.10
235DC CJK UNIFIED IDEOGRAPH-#235DC, IRGKangXi=0546.251, RSKangXi=75.10
235DD CJK UNIFIED IDEOGRAPH-#235DD, IRGKangXi=0546.251, RSKangXi=75.10
235DE CJK UNIFIED IDEOGRAPH-#235DE, IRGKangXi=0546.251, RSKangXi=75.10
235DF CJK UNIFIED IDEOGRAPH-#235DF, IRGKangXi=0546.251, RSKangXi=75.10
235E0 CJK UNIFIED IDEOGRAPH-#235E0, IRGKangXi=0546.251, RSKangXi=75.10
235E1 CJK UNIFIED IDEOGRAPH-#235E1, IRGKangXi=0546.251, RSKangXi=75.10
235E2 CJK UNIFIED IDEOGRAPH-#235E2, IRGKangXi=0546.251, RSKangXi=75.10
235E3 CJK UNIFIED IDEOGRAPH-#235E3, IRGKangXi=0546.251, RSKangXi=75.10
235E4 CJK UNIFIED IDEOGRAPH-#235E4, IRGKangXi=0546.251, RSKangXi=75.10
235E5 CJK UNIFIED IDEOGRAPH-#235E5, IRGKangXi=0546.251, RSKangXi=75.10
235E6 CJK UNIFIED IDEOGRAPH-#235E6, IRGKangXi=0546.251, RSKangXi=75.10
235E7 CJK UNIFIED IDEOGRAPH-#235E7, IRGKangXi=0546.251, RSKangXi=75.10
235E8 CJK UNIFIED IDEOGRAPH-#235E8, IRGKangXi=0546.251, RSKangXi=75.10
235E9 CJK UNIFIED IDEOGRAPH-#235E9, IRGKangXi=0546.251, RSKangXi=75.10
235EA CJK UNIFIED IDEOGRAPH-#235EA, IRGKangXi=0546.251, RSKangXi=75.10
235EB CJK UNIFIED IDEOGRAPH-#235EB, IRGKangXi=0546.251, RSKangXi=75.10
235EC CJK UNIFIED IDEOGRAPH-#235EC, IRGKangXi=0546.251, RSKangXi=75.10
235ED CJK UNIFIED IDEOGRAPH-#235ED, IRGKangXi=0546.251, RSKangXi=75.10
235EE CJK UNIFIED IDEOGRAPH-#235EE, IRGKangXi=0546.251, RSKangXi=75.10
235EF CJK UNIFIED IDEOGRAPH-#235EF, IRGKangXi=0546.251, RSKangXi=75.10
235F0 CJK UNIFIED IDEOGRAPH-#235F0, IRGKangXi=0546.251, RSKangXi=75.10
235F1 CJK UNIFIED IDEOGRAPH-#235F1, IRGKangXi=0546.251, RSKangXi=75.10
235F2 CJK UNIFIED IDEOGRAPH-#235F2, IRGKangXi=0546.251, RSKangXi=75.10
235F3 CJK UNIFIED IDEOGRAPH-#235F3, IRGKangXi=0546.251, RSKangXi=75.10
235F4 CJK UNIFIED IDEOGRAPH-#235F4, IRGKangXi=0546.251, RSKangXi=75.10
235F5 CJK UNIFIED IDEOGRAPH-#235F5, IRGKangXi=0546.251, RSKangXi=75.10
235F6 CJK UNIFIED IDEOGRAPH-#235F6, IRGKangXi=0546.251, RSKangXi=75.10
235F7 CJK UNIFIED IDEOGRAPH-#235F7, IRGKangXi=0546.251, RSKangXi=75.10
235F8 CJK UNIFIED IDEOGRAPH-#235F8, IRGKangXi=0546.251, RSKangXi=75.10
235F9 CJK UNIFIED IDEOGRAPH-#235F9, IRGKangXi=0546.251, RSKangXi=75.10
235FA CJK UNIFIED IDEOGRAPH-#235FA, IRGKangXi=0546.251, RSKangXi=75.10
235FB CJK UNIFIED IDEOGRAPH-#235FB, IRGKangXi=0546.251, RSKangXi=75.10
235FC CJK UNIFIED IDEOGRAPH-#235FC, IRGKangXi=0546.251, RSKangXi=75.10
235FD CJK UNIFIED IDEOGRAPH-#235FD, IRGKangXi=0546.251, RSKangXi=75.10
235FE CJK UNIFIED IDEOGRAPH-#235FE, IRGKangXi=0546.251, RSKangXi=75.10
235FF CJK UNIFIED IDEOGRAPH-#235FF, IRGKangXi=0546.251, RSKangXi=75.10
23600 CJK UNIFIED IDEOGRAPH-#23600, IRGKangXi=0546.251, RSKangXi=75.10
23601 CJK UNIFIED IDEOGRAPH-#23601, IRGKangXi=0546.251, RSKangXi=75.10
23602 CJK UNIFIED IDEOGRAPH-#23602, IRGKangXi=0546.251, RSKangXi=75.10
23603 CJK UNIFIED IDEOGRAPH-#23603, IRGKangXi=0546.251, RSKangXi=75.10
23604 CJK UNIFIED IDEOGRAPH-#23604, IRGKangXi=0546.251, RSKangXi=75.10
23605 CJK UNIFIED IDEOGRAPH-#23605, IRGKangXi=0546.251, RSKangXi=75.10
23606 CJK UNIFIED IDEOGRAPH-#23606, IRGKangXi=0546.251, RSKangXi=75.10
23607 CJK UNIFIED IDEOGRAPH-#23607, IRGKangXi=0546.251, RSKangXi=75.10
23608 CJK UNIFIED IDEOGRAPH-#23608, IRGKangXi=0546.251, RSKangXi=75.10
23609 CJK UNIFIED IDEOGRAPH-#23609, IRGKangXi=0546.251, RSKangXi=75.10
2360A CJK UNIFIED IDEOGRAPH-#2360A, IRGKangXi=0546.251, RSKangXi=75.10
2360B CJK UNIFIED IDEOGRAPH-#2360B, IRGKangXi=0546.251, RSKangXi=75.10
2360C CJK UNIFIED IDEOGRAPH-#2360C, IRGKangXi=0546.251, RSKangXi=75.10
2360D CJK UNIFIED IDEOGRAPH-#2360D, IRGKangXi=0546.251, RSKangXi=75.10
2360E CJK UNIFIED IDEOGRAPH-#2360E, IRGKangXi=0546.251, RSKangXi=75.10
2360F CJK UNIFIED IDEOGRAPH-#2360F, IRGKangXi=0546.251, RSKangXi=75.10
23610 CJK UNIFIED IDEOGRAPH-#23610, IRGKangXi=0546.251, RSKangXi=75.10
23611 CJK UNIFIED IDEOGRAPH-#23611, IRGKangXi=0546.251, RSKangXi=75.10
23612 CJK UNIFIED IDEOGRAPH-#23612, IRGKangXi=0546.251, RSKangXi=75.10
23613 CJK UNIFIED IDEOGRAPH-#23613, IRGKangXi=0546.251, RSKangXi=75.10
23614 CJK UNIFIED IDEOGRAPH-#23614, IRGKangXi=0546.251, RSKangXi=75.10
23615 CJK UNIFIED IDEOGRAPH-#23615, IRGKangXi=0547.030, RSKangXi=75.11
23616 CJK UNIFIED IDEOGRAPH-#23616, IRGKangXi=0547.080, RSKangXi=75.11
23617 CJK UNIFIED IDEOGRAPH-#23617, IRGKangXi=0547.150, RSKangXi=75.11, Def{a tree a thousand feet high}
23618 CJK UNIFIED IDEOGRAPH-#23618, IRGKangXi=0547.200, RSKangXi=75.11
23619 CJK UNIFIED IDEOGRAPH-#23619, IRGKangXi=0548.080, RSKangXi=75.11
2361A CJK UNIFIED IDEOGRAPH-#2361A, IRGKangXi=0548.100, RSKangXi=75.11, Def{(Cant.) a bar; to bolt, lock}
2361B CJK UNIFIED IDEOGRAPH-#2361B, IRGKangXi=0549.020, RSKangXi=75.11
2361C CJK UNIFIED IDEOGRAPH-#2361C, IRGKangXi=0549.030, RSKangXi=75.11
2361D CJK UNIFIED IDEOGRAPH-#2361D, IRGKangXi=0549.070, RSKangXi=75.11
2361E CJK UNIFIED IDEOGRAPH-#2361E, IRGKangXi=0549.090, RSKangXi=75.11
2361F CJK UNIFIED IDEOGRAPH-#2361F, IRGKangXi=0549.110, RSKangXi=75.11
23620 CJK UNIFIED IDEOGRAPH-#23620, IRGKangXi=0549.140, RSKangXi=75.11
23621 CJK UNIFIED IDEOGRAPH-#23621, IRGKangXi=0549.180, RSKangXi=75.11
23622 CJK UNIFIED IDEOGRAPH-#23622, IRGKangXi=0549.200, RSKangXi=75.11
23623 CJK UNIFIED IDEOGRAPH-#23623, IRGKangXi=0549.240, RSKangXi=75.11
23624 CJK UNIFIED IDEOGRAPH-#23624, IRGKangXi=0549.250, RSKangXi=75.11
23625 CJK UNIFIED IDEOGRAPH-#23625, IRGKangXi=0549.300, RSKangXi=75.11
23626 CJK UNIFIED IDEOGRAPH-#23626, IRGKangXi=0550.010, RSKangXi=75.11, Def{ebony}
23627 CJK UNIFIED IDEOGRAPH-#23627, IRGKangXi=0550.020, RSKangXi=75.11
23628 CJK UNIFIED IDEOGRAPH-#23628, IRGKangXi=0550.110, RSKangXi=75.11
23629 CJK UNIFIED IDEOGRAPH-#23629, IRGKangXi=0550.140, RSKangXi=75.11
2362A CJK UNIFIED IDEOGRAPH-#2362A, IRGKangXi=0550.160, RSKangXi=75.11
2362B CJK UNIFIED IDEOGRAPH-#2362B, IRGKangXi=0550.180, RSKangXi=75.11
2362C CJK UNIFIED IDEOGRAPH-#2362C, IRGKangXi=0551.060, RSKangXi=75.11
2362D CJK UNIFIED IDEOGRAPH-#2362D, IRGKangXi=0551.090, RSKangXi=75.11
2362E CJK UNIFIED IDEOGRAPH-#2362E, IRGKangXi=0551.120, RSKangXi=75.11
2362F CJK UNIFIED IDEOGRAPH-#2362F, IRGKangXi=0551.130, RSKangXi=75.11
23630 CJK UNIFIED IDEOGRAPH-#23630, IRGKangXi=0551.140, RSKangXi=75.11
23631 CJK UNIFIED IDEOGRAPH-#23631, IRGKangXi=0551.150, RSKangXi=75.11
23632 CJK UNIFIED IDEOGRAPH-#23632, IRGKangXi=0551.160, RSKangXi=75.11
23633 CJK UNIFIED IDEOGRAPH-#23633, IRGKangXi=0551.180, RSKangXi=75.11
23634 CJK UNIFIED IDEOGRAPH-#23634, IRGKangXi=0551.181, RSKangXi=75.11
23635 CJK UNIFIED IDEOGRAPH-#23635, IRGKangXi=0551.181, RSKangXi=75.11
23636 CJK UNIFIED IDEOGRAPH-#23636, IRGKangXi=0551.181, RSKangXi=75.11
23637 CJK UNIFIED IDEOGRAPH-#23637, IRGKangXi=0551.181, RSKangXi=75.11
23638 CJK UNIFIED IDEOGRAPH-#23638, IRGKangXi=0551.181, RSKangXi=75.11
23639 CJK UNIFIED IDEOGRAPH-#23639, IRGKangXi=0551.181, RSKangXi=75.11
2363A CJK UNIFIED IDEOGRAPH-#2363A, IRGKangXi=0551.181, RSKangXi=75.11
2363B CJK UNIFIED IDEOGRAPH-#2363B, IRGKangXi=0551.181, RSKangXi=75.11
2363C CJK UNIFIED IDEOGRAPH-#2363C, IRGKangXi=0551.181, RSKangXi=75.11
2363D CJK UNIFIED IDEOGRAPH-#2363D, IRGKangXi=0551.181, RSKangXi=75.11
2363E CJK UNIFIED IDEOGRAPH-#2363E, IRGKangXi=0551.181, RSKangXi=75.11
2363F CJK UNIFIED IDEOGRAPH-#2363F, IRGKangXi=0551.181, RSKangXi=75.11
23640 CJK UNIFIED IDEOGRAPH-#23640, IRGKangXi=0551.181, RSKangXi=75.11
23641 CJK UNIFIED IDEOGRAPH-#23641, IRGKangXi=0551.181, RSKangXi=75.11
23642 CJK UNIFIED IDEOGRAPH-#23642, IRGKangXi=0551.181, RSKangXi=75.11
23643 CJK UNIFIED IDEOGRAPH-#23643, IRGKangXi=0551.181, RSKangXi=75.11
23644 CJK UNIFIED IDEOGRAPH-#23644, IRGKangXi=0551.181, RSKangXi=75.11
23645 CJK UNIFIED IDEOGRAPH-#23645, IRGKangXi=0551.181, RSKangXi=75.11
23646 CJK UNIFIED IDEOGRAPH-#23646, IRGKangXi=0551.181, RSKangXi=75.11
23647 CJK UNIFIED IDEOGRAPH-#23647, IRGKangXi=0551.181, RSKangXi=75.11
23648 CJK UNIFIED IDEOGRAPH-#23648, IRGKangXi=0551.181, RSKangXi=75.11
23649 CJK UNIFIED IDEOGRAPH-#23649, IRGKangXi=0551.181, RSKangXi=75.11
2364A CJK UNIFIED IDEOGRAPH-#2364A, IRGKangXi=0551.181, RSKangXi=75.11
2364B CJK UNIFIED IDEOGRAPH-#2364B, IRGKangXi=0551.181, RSKangXi=75.11
2364C CJK UNIFIED IDEOGRAPH-#2364C, IRGKangXi=0551.181, RSKangXi=75.11
2364D CJK UNIFIED IDEOGRAPH-#2364D, IRGKangXi=0551.181, RSKangXi=75.11
2364E CJK UNIFIED IDEOGRAPH-#2364E, IRGKangXi=0551.181, RSKangXi=75.11
2364F CJK UNIFIED IDEOGRAPH-#2364F, IRGKangXi=0551.181, RSKangXi=75.11
23650 CJK UNIFIED IDEOGRAPH-#23650, IRGKangXi=0551.181, RSKangXi=75.11
23651 CJK UNIFIED IDEOGRAPH-#23651, IRGKangXi=0551.181, RSKangXi=75.11
23652 CJK UNIFIED IDEOGRAPH-#23652, IRGKangXi=0551.181, RSKangXi=75.12
23653 CJK UNIFIED IDEOGRAPH-#23653, IRGKangXi=0551.181, RSKangXi=75.11
23654 CJK UNIFIED IDEOGRAPH-#23654, IRGKangXi=0551.181, RSKangXi=75.11
23655 CJK UNIFIED IDEOGRAPH-#23655, IRGKangXi=0551.181, RSKangXi=75.11
23656 CJK UNIFIED IDEOGRAPH-#23656, IRGKangXi=0551.181, RSKangXi=75.11
23657 CJK UNIFIED IDEOGRAPH-#23657, IRGKangXi=0551.181, RSKangXi=75.11
23658 CJK UNIFIED IDEOGRAPH-#23658, IRGKangXi=0551.181, RSKangXi=75.11
23659 CJK UNIFIED IDEOGRAPH-#23659, IRGKangXi=0551.181, RSKangXi=75.11
2365A CJK UNIFIED IDEOGRAPH-#2365A, IRGKangXi=0551.181, RSKangXi=75.11
2365B CJK UNIFIED IDEOGRAPH-#2365B, IRGKangXi=0551.181, RSKangXi=75.11
2365C CJK UNIFIED IDEOGRAPH-#2365C, IRGKangXi=0551.181, RSKangXi=75.11
2365D CJK UNIFIED IDEOGRAPH-#2365D, IRGKangXi=0551.181, RSKangXi=75.11
2365E CJK UNIFIED IDEOGRAPH-#2365E, IRGKangXi=0551.181, RSKangXi=75.11
2365F CJK UNIFIED IDEOGRAPH-#2365F, IRGKangXi=0551.181, RSKangXi=75.11
23660 CJK UNIFIED IDEOGRAPH-#23660, IRGKangXi=0551.181, RSKangXi=75.11
23661 CJK UNIFIED IDEOGRAPH-#23661, IRGKangXi=0551.181, RSKangXi=75.11
23662 CJK UNIFIED IDEOGRAPH-#23662, IRGKangXi=0551.181, RSKangXi=75.11
23663 CJK UNIFIED IDEOGRAPH-#23663, IRGKangXi=0551.181, RSKangXi=75.11
23664 CJK UNIFIED IDEOGRAPH-#23664, IRGKangXi=0551.181, RSKangXi=75.11
23665 CJK UNIFIED IDEOGRAPH-#23665, IRGKangXi=0551.181, RSKangXi=75.11
23666 CJK UNIFIED IDEOGRAPH-#23666, IRGKangXi=0551.181, RSKangXi=75.11
23667 CJK UNIFIED IDEOGRAPH-#23667, IRGKangXi=0551.181, RSKangXi=75.11
23668 CJK UNIFIED IDEOGRAPH-#23668, IRGKangXi=0551.181, RSKangXi=75.11
23669 CJK UNIFIED IDEOGRAPH-#23669, IRGKangXi=0551.181, RSKangXi=75.11
2366A CJK UNIFIED IDEOGRAPH-#2366A, IRGKangXi=0551.181, RSKangXi=75.11
2366B CJK UNIFIED IDEOGRAPH-#2366B, IRGKangXi=0551.181, RSKangXi=75.11
2366C CJK UNIFIED IDEOGRAPH-#2366C, IRGKangXi=0551.181, RSKangXi=75.11
2366D CJK UNIFIED IDEOGRAPH-#2366D, IRGKangXi=0551.181, RSKangXi=75.11
2366E CJK UNIFIED IDEOGRAPH-#2366E, IRGKangXi=0551.181, RSKangXi=75.11
2366F CJK UNIFIED IDEOGRAPH-#2366F, IRGKangXi=0551.181, RSKangXi=75.11
23670 CJK UNIFIED IDEOGRAPH-#23670, IRGKangXi=0551.181, RSKangXi=75.11
23671 CJK UNIFIED IDEOGRAPH-#23671, IRGKangXi=0551.181, RSKangXi=75.11
23672 CJK UNIFIED IDEOGRAPH-#23672, IRGKangXi=0551.181, RSKangXi=75.11
23673 CJK UNIFIED IDEOGRAPH-#23673, IRGKangXi=0551.181, RSKangXi=75.11
23674 CJK UNIFIED IDEOGRAPH-#23674, IRGKangXi=0551.181, RSKangXi=75.11
23675 CJK UNIFIED IDEOGRAPH-#23675, IRGKangXi=0551.181, RSKangXi=75.11
23676 CJK UNIFIED IDEOGRAPH-#23676, IRGKangXi=0551.181, RSKangXi=75.11
23677 CJK UNIFIED IDEOGRAPH-#23677, IRGKangXi=0551.181, RSKangXi=75.11
23678 CJK UNIFIED IDEOGRAPH-#23678, IRGKangXi=0551.181, RSKangXi=75.11
23679 CJK UNIFIED IDEOGRAPH-#23679, IRGKangXi=0551.181, RSKangXi=75.11
2367A CJK UNIFIED IDEOGRAPH-#2367A, IRGKangXi=0551.181, RSKangXi=75.11
2367B CJK UNIFIED IDEOGRAPH-#2367B, IRGKangXi=0551.230, RSKangXi=75.12
2367C CJK UNIFIED IDEOGRAPH-#2367C, IRGKangXi=0551.260, RSKangXi=75.12
2367D CJK UNIFIED IDEOGRAPH-#2367D, IRGKangXi=0551.270, RSKangXi=75.12
2367E CJK UNIFIED IDEOGRAPH-#2367E, IRGKangXi=0552.070, RSKangXi=75.12
2367F CJK UNIFIED IDEOGRAPH-#2367F, IRGKangXi=0552.130, RSKangXi=75.12
23680 CJK UNIFIED IDEOGRAPH-#23680, IRGKangXi=0552.140, RSKangXi=75.12
23681 CJK UNIFIED IDEOGRAPH-#23681, IRGKangXi=0552.150, RSKangXi=75.12
23682 CJK UNIFIED IDEOGRAPH-#23682, IRGKangXi=0552.190, RSKangXi=75.12
23683 CJK UNIFIED IDEOGRAPH-#23683, IRGKangXi=0552.220, RSKangXi=75.12
23684 CJK UNIFIED IDEOGRAPH-#23684, IRGKangXi=0552.240, RSKangXi=75.12
23685 CJK UNIFIED IDEOGRAPH-#23685, IRGKangXi=0552.270, RSKangXi=75.12
23686 CJK UNIFIED IDEOGRAPH-#23686, IRGKangXi=0553.050, RSKangXi=75.12
23687 CJK UNIFIED IDEOGRAPH-#23687, IRGKangXi=0553.110, RSKangXi=75.12
23688 CJK UNIFIED IDEOGRAPH-#23688, IRGKangXi=0553.150, RSKangXi=75.12
23689 CJK UNIFIED IDEOGRAPH-#23689, IRGKangXi=0553.210, RSKangXi=75.12
2368A CJK UNIFIED IDEOGRAPH-#2368A, IRGKangXi=0553.240, RSKangXi=75.12
2368B CJK UNIFIED IDEOGRAPH-#2368B, IRGKangXi=0553.260, RSKangXi=75.12
2368C CJK UNIFIED IDEOGRAPH-#2368C, IRGKangXi=0553.290, RSKangXi=75.12
2368D CJK UNIFIED IDEOGRAPH-#2368D, IRGKangXi=0554.010, RSKangXi=75.12
2368E CJK UNIFIED IDEOGRAPH-#2368E, IRGKangXi=0554.060, RSKangXi=75.12
2368F CJK UNIFIED IDEOGRAPH-#2368F, IRGKangXi=0554.100, RSKangXi=75.12
23690 CJK UNIFIED IDEOGRAPH-#23690, IRGKangXi=0554.140, RSKangXi=75.12
23691 CJK UNIFIED IDEOGRAPH-#23691, IRGKangXi=0554.160, RSKangXi=75.12
23692 CJK UNIFIED IDEOGRAPH-#23692, IRGKangXi=0554.180, RSKangXi=75.12
23693 CJK UNIFIED IDEOGRAPH-#23693, IRGKangXi=0554.190, RSKangXi=75.12
23694 CJK UNIFIED IDEOGRAPH-#23694, IRGKangXi=0554.200, RSKangXi=75.12
23695 CJK UNIFIED IDEOGRAPH-#23695, IRGKangXi=0554.240, RSKangXi=75.12, Def{(Cant.) to wave, beckon with the hand}
23696 CJK UNIFIED IDEOGRAPH-#23696, IRGKangXi=0554.250, RSKangXi=75.12
23697 CJK UNIFIED IDEOGRAPH-#23697, IRGKangXi=0554.260, RSKangXi=75.12
23698 CJK UNIFIED IDEOGRAPH-#23698, IRGKangXi=0554.270, RSKangXi=75.12
23699 CJK UNIFIED IDEOGRAPH-#23699, IRGKangXi=0554.290, RSKangXi=75.12
2369A CJK UNIFIED IDEOGRAPH-#2369A, IRGKangXi=0555.010, RSKangXi=75.12
2369B CJK UNIFIED IDEOGRAPH-#2369B, IRGKangXi=0555.060, RSKangXi=75.12
2369C CJK UNIFIED IDEOGRAPH-#2369C, IRGKangXi=0555.070, RSKangXi=75.12
2369D CJK UNIFIED IDEOGRAPH-#2369D, IRGKangXi=0555.080, RSKangXi=75.12
2369E CJK UNIFIED IDEOGRAPH-#2369E, IRGKangXi=0555.090, RSKangXi=75.12
2369F CJK UNIFIED IDEOGRAPH-#2369F, IRGKangXi=0555.120, RSKangXi=75.12
236A0 CJK UNIFIED IDEOGRAPH-#236A0, IRGKangXi=0555.130, RSKangXi=75.12
236A1 CJK UNIFIED IDEOGRAPH-#236A1, IRGKangXi=0555.180, RSKangXi=75.12
236A2 CJK UNIFIED IDEOGRAPH-#236A2, IRGKangXi=0555.200, RSKangXi=75.12
236A3 CJK UNIFIED IDEOGRAPH-#236A3, IRGKangXi=0555.210, RSKangXi=75.12
236A4 CJK UNIFIED IDEOGRAPH-#236A4, IRGKangXi=0555.220, RSKangXi=75.12
236A5 CJK UNIFIED IDEOGRAPH-#236A5, IRGKangXi=0555.230, RSKangXi=75.12
236A6 CJK UNIFIED IDEOGRAPH-#236A6, IRGKangXi=0555.240, RSKangXi=75.12
236A7 CJK UNIFIED IDEOGRAPH-#236A7, IRGKangXi=0555.250, RSKangXi=75.12
236A8 CJK UNIFIED IDEOGRAPH-#236A8, IRGKangXi=0555.270, RSKangXi=75.12
236A9 CJK UNIFIED IDEOGRAPH-#236A9, IRGKangXi=0555.300, RSKangXi=75.12
236AA CJK UNIFIED IDEOGRAPH-#236AA, IRGKangXi=0555.310, RSKangXi=75.12
236AB CJK UNIFIED IDEOGRAPH-#236AB, IRGKangXi=0555.311, RSKangXi=75.12
236AC CJK UNIFIED IDEOGRAPH-#236AC, IRGKangXi=0555.311, RSKangXi=75.12
236AD CJK UNIFIED IDEOGRAPH-#236AD, IRGKangXi=0555.311, RSKangXi=75.12
236AE CJK UNIFIED IDEOGRAPH-#236AE, IRGKangXi=0555.311, RSKangXi=75.12
236AF CJK UNIFIED IDEOGRAPH-#236AF, IRGKangXi=0555.311, RSKangXi=75.12
236B0 CJK UNIFIED IDEOGRAPH-#236B0, IRGKangXi=0555.311, RSKangXi=75.12
236B1 CJK UNIFIED IDEOGRAPH-#236B1, IRGKangXi=0555.311, RSKangXi=75.12
236B2 CJK UNIFIED IDEOGRAPH-#236B2, IRGKangXi=0555.311, RSKangXi=75.12
236B3 CJK UNIFIED IDEOGRAPH-#236B3, IRGKangXi=0555.311, RSKangXi=75.12
236B4 CJK UNIFIED IDEOGRAPH-#236B4, IRGKangXi=0555.311, RSKangXi=75.12
236B5 CJK UNIFIED IDEOGRAPH-#236B5, IRGKangXi=0555.311, RSKangXi=75.12
236B6 CJK UNIFIED IDEOGRAPH-#236B6, IRGKangXi=0555.311, RSKangXi=75.12
236B7 CJK UNIFIED IDEOGRAPH-#236B7, IRGKangXi=0555.311, RSKangXi=75.12
236B8 CJK UNIFIED IDEOGRAPH-#236B8, IRGKangXi=0555.311, RSKangXi=75.12
236B9 CJK UNIFIED IDEOGRAPH-#236B9, IRGKangXi=0555.311, RSKangXi=75.12
236BA CJK UNIFIED IDEOGRAPH-#236BA, IRGKangXi=0555.311, RSKangXi=75.12, Def{(Cant.) a young chicken}
236BB CJK UNIFIED IDEOGRAPH-#236BB, IRGKangXi=0555.311, RSKangXi=75.12
236BC CJK UNIFIED IDEOGRAPH-#236BC, IRGKangXi=0555.311, RSKangXi=75.12
236BD CJK UNIFIED IDEOGRAPH-#236BD, IRGKangXi=0555.311, RSKangXi=75.12
236BE CJK UNIFIED IDEOGRAPH-#236BE, IRGKangXi=0555.311, RSKangXi=75.12
236BF CJK UNIFIED IDEOGRAPH-#236BF, IRGKangXi=0555.311, RSKangXi=75.12
236C0 CJK UNIFIED IDEOGRAPH-#236C0, IRGKangXi=0555.311, RSKangXi=75.12
236C1 CJK UNIFIED IDEOGRAPH-#236C1, IRGKangXi=0555.311, RSKangXi=75.12
236C2 CJK UNIFIED IDEOGRAPH-#236C2, IRGKangXi=0555.311, RSKangXi=75.12
236C3 CJK UNIFIED IDEOGRAPH-#236C3, IRGKangXi=0555.311, RSKangXi=75.12
236C4 CJK UNIFIED IDEOGRAPH-#236C4, IRGKangXi=0555.311, RSKangXi=75.12
236C5 CJK UNIFIED IDEOGRAPH-#236C5, IRGKangXi=0555.311, RSKangXi=75.12
236C6 CJK UNIFIED IDEOGRAPH-#236C6, IRGKangXi=0555.311, RSKangXi=75.12
236C7 CJK UNIFIED IDEOGRAPH-#236C7, IRGKangXi=0555.311, RSKangXi=75.12
236C8 CJK UNIFIED IDEOGRAPH-#236C8, IRGKangXi=0555.311, RSKangXi=75.12
236C9 CJK UNIFIED IDEOGRAPH-#236C9, IRGKangXi=0555.311, RSKangXi=75.12
236CA CJK UNIFIED IDEOGRAPH-#236CA, IRGKangXi=0555.311, RSKangXi=75.12
236CB CJK UNIFIED IDEOGRAPH-#236CB, IRGKangXi=0555.311, RSKangXi=75.12
236CC CJK UNIFIED IDEOGRAPH-#236CC, IRGKangXi=0555.311, RSKangXi=75.12
236CD CJK UNIFIED IDEOGRAPH-#236CD, IRGKangXi=0555.311, RSKangXi=75.12
236CE CJK UNIFIED IDEOGRAPH-#236CE, IRGKangXi=0555.311, RSKangXi=75.12
236CF CJK UNIFIED IDEOGRAPH-#236CF, IRGKangXi=0555.311, RSKangXi=75.12
236D0 CJK UNIFIED IDEOGRAPH-#236D0, IRGKangXi=0555.311, RSKangXi=75.12
236D1 CJK UNIFIED IDEOGRAPH-#236D1, IRGKangXi=0555.311, RSKangXi=75.12
236D2 CJK UNIFIED IDEOGRAPH-#236D2, IRGKangXi=0555.311, RSKangXi=75.12
236D3 CJK UNIFIED IDEOGRAPH-#236D3, IRGKangXi=0555.311, RSKangXi=75.12
236D4 CJK UNIFIED IDEOGRAPH-#236D4, IRGKangXi=0555.311, RSKangXi=75.12
236D5 CJK UNIFIED IDEOGRAPH-#236D5, IRGKangXi=0555.311, RSKangXi=75.12
236D6 CJK UNIFIED IDEOGRAPH-#236D6, IRGKangXi=0555.311, RSKangXi=75.12
236D7 CJK UNIFIED IDEOGRAPH-#236D7, IRGKangXi=0555.311, RSKangXi=75.12
236D8 CJK UNIFIED IDEOGRAPH-#236D8, IRGKangXi=0555.311, RSKangXi=75.12
236D9 CJK UNIFIED IDEOGRAPH-#236D9, IRGKangXi=0555.311, RSKangXi=75.12
236DA CJK UNIFIED IDEOGRAPH-#236DA, IRGKangXi=0555.311, RSKangXi=75.12
236DB CJK UNIFIED IDEOGRAPH-#236DB, IRGKangXi=0555.311, RSKangXi=75.12
236DC CJK UNIFIED IDEOGRAPH-#236DC, IRGKangXi=0555.311, RSKangXi=75.12
236DD CJK UNIFIED IDEOGRAPH-#236DD, IRGKangXi=0555.311, RSKangXi=75.12
236DE CJK UNIFIED IDEOGRAPH-#236DE, IRGKangXi=0555.311, RSKangXi=75.12
236DF CJK UNIFIED IDEOGRAPH-#236DF, IRGKangXi=0555.311, RSKangXi=75.12
236E0 CJK UNIFIED IDEOGRAPH-#236E0, IRGKangXi=0555.311, RSKangXi=75.12
236E1 CJK UNIFIED IDEOGRAPH-#236E1, IRGKangXi=0555.311, RSKangXi=75.12
236E2 CJK UNIFIED IDEOGRAPH-#236E2, IRGKangXi=0555.311, RSKangXi=75.12
236E3 CJK UNIFIED IDEOGRAPH-#236E3, IRGKangXi=0555.311, RSKangXi=75.12
236E4 CJK UNIFIED IDEOGRAPH-#236E4, IRGKangXi=0555.311, RSKangXi=75.12
236E5 CJK UNIFIED IDEOGRAPH-#236E5, IRGKangXi=0555.311, RSKangXi=75.12
236E6 CJK UNIFIED IDEOGRAPH-#236E6, IRGKangXi=0555.311, RSKangXi=75.12
236E7 CJK UNIFIED IDEOGRAPH-#236E7, IRGKangXi=0555.311, RSKangXi=75.12
236E8 CJK UNIFIED IDEOGRAPH-#236E8, IRGKangXi=0555.311, RSKangXi=75.12
236E9 CJK UNIFIED IDEOGRAPH-#236E9, IRGKangXi=0555.311, RSKangXi=75.12
236EA CJK UNIFIED IDEOGRAPH-#236EA, IRGKangXi=0555.311, RSKangXi=75.12
236EB CJK UNIFIED IDEOGRAPH-#236EB, IRGKangXi=0555.311, RSKangXi=75.12
236EC CJK UNIFIED IDEOGRAPH-#236EC, IRGKangXi=0555.311, RSKangXi=75.12
236ED CJK UNIFIED IDEOGRAPH-#236ED, IRGKangXi=0555.311, RSKangXi=75.12
236EE CJK UNIFIED IDEOGRAPH-#236EE, IRGKangXi=0555.311, RSKangXi=75.12
236EF CJK UNIFIED IDEOGRAPH-#236EF, IRGKangXi=0555.311, RSKangXi=75.12
236F0 CJK UNIFIED IDEOGRAPH-#236F0, IRGKangXi=0555.311, RSKangXi=75.13
236F1 CJK UNIFIED IDEOGRAPH-#236F1, IRGKangXi=0555.370, RSKangXi=75.13
236F2 CJK UNIFIED IDEOGRAPH-#236F2, IRGKangXi=0555.380, RSKangXi=75.13
236F3 CJK UNIFIED IDEOGRAPH-#236F3, IRGKangXi=0556.030, RSKangXi=75.13
236F4 CJK UNIFIED IDEOGRAPH-#236F4, IRGKangXi=0556.050, RSKangXi=75.13
236F5 CJK UNIFIED IDEOGRAPH-#236F5, IRGKangXi=0556.060, RSKangXi=75.13
236F6 CJK UNIFIED IDEOGRAPH-#236F6, IRGKangXi=0556.090, RSKangXi=75.13
236F7 CJK UNIFIED IDEOGRAPH-#236F7, IRGKangXi=0556.170, RSKangXi=75.13
236F8 CJK UNIFIED IDEOGRAPH-#236F8, IRGKangXi=0556.190, RSKangXi=75.13
236F9 CJK UNIFIED IDEOGRAPH-#236F9, IRGKangXi=0556.290, RSKangXi=75.13
236FA CJK UNIFIED IDEOGRAPH-#236FA, IRGKangXi=0556.320, RSKangXi=75.13
236FB CJK UNIFIED IDEOGRAPH-#236FB, IRGKangXi=0557.070, RSKangXi=75.13
236FC CJK UNIFIED IDEOGRAPH-#236FC, IRGKangXi=0557.130, RSKangXi=75.13
236FD CJK UNIFIED IDEOGRAPH-#236FD, IRGKangXi=0557.200, RSKangXi=75.13
236FE CJK UNIFIED IDEOGRAPH-#236FE, IRGKangXi=0557.210, RSKangXi=75.13
236FF CJK UNIFIED IDEOGRAPH-#236FF, IRGKangXi=0557.240, RSKangXi=75.13
23700 CJK UNIFIED IDEOGRAPH-#23700, IRGKangXi=0557.260, RSKangXi=75.13
23701 CJK UNIFIED IDEOGRAPH-#23701, IRGKangXi=0558.010, RSKangXi=75.13
23702 CJK UNIFIED IDEOGRAPH-#23702, IRGKangXi=0558.030, RSKangXi=75.13
23703 CJK UNIFIED IDEOGRAPH-#23703, IRGKangXi=0558.040, RSKangXi=75.13
23704 CJK UNIFIED IDEOGRAPH-#23704, IRGKangXi=0558.050, RSKangXi=75.13
23705 CJK UNIFIED IDEOGRAPH-#23705, IRGKangXi=0558.060, RSKangXi=75.13
23706 CJK UNIFIED IDEOGRAPH-#23706, IRGKangXi=0558.070, RSKangXi=75.13
23707 CJK UNIFIED IDEOGRAPH-#23707, IRGKangXi=0558.080, RSKangXi=75.13
23708 CJK UNIFIED IDEOGRAPH-#23708, IRGKangXi=0558.090, RSKangXi=75.13
23709 CJK UNIFIED IDEOGRAPH-#23709, IRGKangXi=0558.091, RSKangXi=75.13
2370A CJK UNIFIED IDEOGRAPH-#2370A, IRGKangXi=0558.091, RSKangXi=75.13
2370B CJK UNIFIED IDEOGRAPH-#2370B, IRGKangXi=0558.091, RSKangXi=75.13
2370C CJK UNIFIED IDEOGRAPH-#2370C, IRGKangXi=0558.091, RSKangXi=75.13
2370D CJK UNIFIED IDEOGRAPH-#2370D, IRGKangXi=0558.091, RSKangXi=75.13
2370E CJK UNIFIED IDEOGRAPH-#2370E, IRGKangXi=0558.091, RSKangXi=75.13
2370F CJK UNIFIED IDEOGRAPH-#2370F, IRGKangXi=0558.091, RSKangXi=75.13
23710 CJK UNIFIED IDEOGRAPH-#23710, IRGKangXi=0558.091, RSKangXi=75.13
23711 CJK UNIFIED IDEOGRAPH-#23711, IRGKangXi=0558.091, RSKangXi=75.13
23712 CJK UNIFIED IDEOGRAPH-#23712, IRGKangXi=0558.091, RSKangXi=75.13
23713 CJK UNIFIED IDEOGRAPH-#23713, IRGKangXi=0558.091, RSKangXi=75.13
23714 CJK UNIFIED IDEOGRAPH-#23714, IRGKangXi=0558.091, RSKangXi=75.13
23715 CJK UNIFIED IDEOGRAPH-#23715, IRGKangXi=0558.091, RSKangXi=75.13
23716 CJK UNIFIED IDEOGRAPH-#23716, IRGKangXi=0558.091, RSKangXi=75.13
23717 CJK UNIFIED IDEOGRAPH-#23717, IRGKangXi=0558.091, RSKangXi=75.13
23718 CJK UNIFIED IDEOGRAPH-#23718, IRGKangXi=0558.091, RSKangXi=75.13
23719 CJK UNIFIED IDEOGRAPH-#23719, IRGKangXi=0558.091, RSKangXi=75.13
2371A CJK UNIFIED IDEOGRAPH-#2371A, IRGKangXi=0558.091, RSKangXi=75.13
2371B CJK UNIFIED IDEOGRAPH-#2371B, IRGKangXi=0558.091, RSKangXi=75.13
2371C CJK UNIFIED IDEOGRAPH-#2371C, IRGKangXi=0558.091, RSKangXi=75.13
2371D CJK UNIFIED IDEOGRAPH-#2371D, IRGKangXi=0558.091, RSKangXi=75.13
2371E CJK UNIFIED IDEOGRAPH-#2371E, IRGKangXi=0558.091, RSKangXi=75.13
2371F CJK UNIFIED IDEOGRAPH-#2371F, IRGKangXi=0558.091, RSKangXi=75.13
23720 CJK UNIFIED IDEOGRAPH-#23720, IRGKangXi=0558.091, RSKangXi=75.13
23721 CJK UNIFIED IDEOGRAPH-#23721, IRGKangXi=0558.091, RSKangXi=75.13
23722 CJK UNIFIED IDEOGRAPH-#23722, IRGKangXi=0558.091, RSKangXi=114.12
23723 CJK UNIFIED IDEOGRAPH-#23723, IRGKangXi=0558.091, RSKangXi=75.13
23724 CJK UNIFIED IDEOGRAPH-#23724, IRGKangXi=0558.091, RSKangXi=75.13
23725 CJK UNIFIED IDEOGRAPH-#23725, IRGKangXi=0558.091, RSKangXi=75.13
23726 CJK UNIFIED IDEOGRAPH-#23726, IRGKangXi=0558.091, RSKangXi=75.13
23727 CJK UNIFIED IDEOGRAPH-#23727, IRGKangXi=0558.091, RSKangXi=75.13
23728 CJK UNIFIED IDEOGRAPH-#23728, IRGKangXi=0558.091, RSKangXi=75.13
23729 CJK UNIFIED IDEOGRAPH-#23729, IRGKangXi=0558.091, RSKangXi=75.13
2372A CJK UNIFIED IDEOGRAPH-#2372A, IRGKangXi=0558.091, RSKangXi=75.13
2372B CJK UNIFIED IDEOGRAPH-#2372B, IRGKangXi=0558.091, RSKangXi=75.13
2372C CJK UNIFIED IDEOGRAPH-#2372C, IRGKangXi=0558.091, RSKangXi=75.13
2372D CJK UNIFIED IDEOGRAPH-#2372D, IRGKangXi=0558.091, RSKangXi=75.13
2372E CJK UNIFIED IDEOGRAPH-#2372E, IRGKangXi=0558.091, RSKangXi=75.13
2372F CJK UNIFIED IDEOGRAPH-#2372F, IRGKangXi=0558.091, RSKangXi=75.13
23730 CJK UNIFIED IDEOGRAPH-#23730, IRGKangXi=0558.091, RSKangXi=75.13
23731 CJK UNIFIED IDEOGRAPH-#23731, IRGKangXi=0558.091, RSKangXi=75.13
23732 CJK UNIFIED IDEOGRAPH-#23732, IRGKangXi=0558.091, RSKangXi=75.13
23733 CJK UNIFIED IDEOGRAPH-#23733, IRGKangXi=0558.091, RSKangXi=75.13
23734 CJK UNIFIED IDEOGRAPH-#23734, IRGKangXi=0558.091, RSKangXi=75.13
23735 CJK UNIFIED IDEOGRAPH-#23735, IRGKangXi=0558.091, RSKangXi=75.13
23736 CJK UNIFIED IDEOGRAPH-#23736, IRGKangXi=0558.091, RSKangXi=75.13
23737 CJK UNIFIED IDEOGRAPH-#23737, IRGKangXi=0558.091, RSKangXi=75.13
23738 CJK UNIFIED IDEOGRAPH-#23738, IRGKangXi=0558.091, RSKangXi=75.13
23739 CJK UNIFIED IDEOGRAPH-#23739, IRGKangXi=0558.091, RSKangXi=75.13
2373A CJK UNIFIED IDEOGRAPH-#2373A, IRGKangXi=0558.091, RSKangXi=75.13
2373B CJK UNIFIED IDEOGRAPH-#2373B, IRGKangXi=0558.091, RSKangXi=75.13
2373C CJK UNIFIED IDEOGRAPH-#2373C, IRGKangXi=0558.091, RSKangXi=75.13
2373D CJK UNIFIED IDEOGRAPH-#2373D, IRGKangXi=0558.091, RSKangXi=75.13
2373E CJK UNIFIED IDEOGRAPH-#2373E, IRGKangXi=0558.091, RSKangXi=5.13
2373F CJK UNIFIED IDEOGRAPH-#2373F, IRGKangXi=0558.091, RSKangXi=75.13
23740 CJK UNIFIED IDEOGRAPH-#23740, IRGKangXi=0558.091, RSKangXi=75.13
23741 CJK UNIFIED IDEOGRAPH-#23741, IRGKangXi=0558.100, RSKangXi=75.14
23742 CJK UNIFIED IDEOGRAPH-#23742, IRGKangXi=0558.140, RSKangXi=75.14
23743 CJK UNIFIED IDEOGRAPH-#23743, IRGKangXi=0558.160, RSKangXi=75.14
23744 CJK UNIFIED IDEOGRAPH-#23744, IRGKangXi=0558.170, RSKangXi=75.14
23745 CJK UNIFIED IDEOGRAPH-#23745, IRGKangXi=0558.180, RSKangXi=75.14
23746 CJK UNIFIED IDEOGRAPH-#23746, IRGKangXi=0558.190, RSKangXi=75.14
23747 CJK UNIFIED IDEOGRAPH-#23747, IRGKangXi=0558.210, RSKangXi=75.14
23748 CJK UNIFIED IDEOGRAPH-#23748, IRGKangXi=0558.220, RSKangXi=75.14
23749 CJK UNIFIED IDEOGRAPH-#23749, IRGKangXi=0558.230, RSKangXi=75.14
2374A CJK UNIFIED IDEOGRAPH-#2374A, IRGKangXi=0558.240, RSKangXi=75.14
2374B CJK UNIFIED IDEOGRAPH-#2374B, IRGKangXi=0558.260, RSKangXi=75.14
2374C CJK UNIFIED IDEOGRAPH-#2374C, IRGKangXi=0558.290, RSKangXi=75.14
2374D CJK UNIFIED IDEOGRAPH-#2374D, IRGKangXi=0558.320, RSKangXi=75.14
2374E CJK UNIFIED IDEOGRAPH-#2374E, IRGKangXi=0558.340, RSKangXi=75.14
2374F CJK UNIFIED IDEOGRAPH-#2374F, IRGKangXi=0558.350, RSKangXi=75.14
23750 CJK UNIFIED IDEOGRAPH-#23750, IRGKangXi=0558.380, RSKangXi=75.14
23751 CJK UNIFIED IDEOGRAPH-#23751, IRGKangXi=0558.410, RSKangXi=75.14
23752 CJK UNIFIED IDEOGRAPH-#23752, IRGKangXi=0558.420, RSKangXi=75.14
23753 CJK UNIFIED IDEOGRAPH-#23753, IRGKangXi=0559.060, RSKangXi=75.14
23754 CJK UNIFIED IDEOGRAPH-#23754, IRGKangXi=0559.070, RSKangXi=75.14
23755 CJK UNIFIED IDEOGRAPH-#23755, IRGKangXi=0559.100, RSKangXi=75.14
23756 CJK UNIFIED IDEOGRAPH-#23756, IRGKangXi=0559.160, RSKangXi=75.14
23757 CJK UNIFIED IDEOGRAPH-#23757, IRGKangXi=0559.170, RSKangXi=75.14
23758 CJK UNIFIED IDEOGRAPH-#23758, IRGKangXi=0559.180, RSKangXi=75.14
23759 CJK UNIFIED IDEOGRAPH-#23759, IRGKangXi=0559.190, RSKangXi=75.15
2375A CJK UNIFIED IDEOGRAPH-#2375A, IRGKangXi=0559.210, RSKangXi=75.14
2375B CJK UNIFIED IDEOGRAPH-#2375B, IRGKangXi=0559.220, RSKangXi=75.14
2375C CJK UNIFIED IDEOGRAPH-#2375C, IRGKangXi=0559.230, RSKangXi=75.14
2375D CJK UNIFIED IDEOGRAPH-#2375D, IRGKangXi=0559.240, RSKangXi=75.14
2375E CJK UNIFIED IDEOGRAPH-#2375E, IRGKangXi=0559.260, RSKangXi=75.14
2375F CJK UNIFIED IDEOGRAPH-#2375F, IRGKangXi=0559.261, RSKangXi=75.14
23760 CJK UNIFIED IDEOGRAPH-#23760, IRGKangXi=0559.261, RSKangXi=75.14
23761 CJK UNIFIED IDEOGRAPH-#23761, IRGKangXi=0559.261, RSKangXi=75.14
23762 CJK UNIFIED IDEOGRAPH-#23762, IRGKangXi=0559.261, RSKangXi=75.14
23763 CJK UNIFIED IDEOGRAPH-#23763, IRGKangXi=0559.261, RSKangXi=75.14
23764 CJK UNIFIED IDEOGRAPH-#23764, IRGKangXi=0559.261, RSKangXi=75.14
23765 CJK UNIFIED IDEOGRAPH-#23765, IRGKangXi=0559.261, RSKangXi=75.14
23766 CJK UNIFIED IDEOGRAPH-#23766, IRGKangXi=0559.261, RSKangXi=75.14
23767 CJK UNIFIED IDEOGRAPH-#23767, IRGKangXi=0559.261, RSKangXi=75.14
23768 CJK UNIFIED IDEOGRAPH-#23768, IRGKangXi=0559.261, RSKangXi=75.14
23769 CJK UNIFIED IDEOGRAPH-#23769, IRGKangXi=0559.261, RSKangXi=75.14
2376A CJK UNIFIED IDEOGRAPH-#2376A, IRGKangXi=0559.261, RSKangXi=75.14
2376B CJK UNIFIED IDEOGRAPH-#2376B, IRGKangXi=0559.261, RSKangXi=75.14
2376C CJK UNIFIED IDEOGRAPH-#2376C, IRGKangXi=0559.261, RSKangXi=75.14
2376D CJK UNIFIED IDEOGRAPH-#2376D, IRGKangXi=0559.261, RSKangXi=75.14
2376E CJK UNIFIED IDEOGRAPH-#2376E, IRGKangXi=0559.261, RSKangXi=75.14
2376F CJK UNIFIED IDEOGRAPH-#2376F, IRGKangXi=0559.261, RSKangXi=75.14
23770 CJK UNIFIED IDEOGRAPH-#23770, IRGKangXi=0559.261, RSKangXi=75.14
23771 CJK UNIFIED IDEOGRAPH-#23771, IRGKangXi=0559.261, RSKangXi=75.14
23772 CJK UNIFIED IDEOGRAPH-#23772, IRGKangXi=0559.261, RSKangXi=75.14
23773 CJK UNIFIED IDEOGRAPH-#23773, IRGKangXi=0559.261, RSKangXi=75.14
23774 CJK UNIFIED IDEOGRAPH-#23774, IRGKangXi=0559.261, RSKangXi=75.14
23775 CJK UNIFIED IDEOGRAPH-#23775, IRGKangXi=0559.261, RSKangXi=75.14
23776 CJK UNIFIED IDEOGRAPH-#23776, IRGKangXi=0559.261, RSKangXi=75.14
23777 CJK UNIFIED IDEOGRAPH-#23777, IRGKangXi=0559.261, RSKangXi=75.14
23778 CJK UNIFIED IDEOGRAPH-#23778, IRGKangXi=0559.261, RSKangXi=75.14
23779 CJK UNIFIED IDEOGRAPH-#23779, IRGKangXi=0559.261, RSKangXi=75.14
2377A CJK UNIFIED IDEOGRAPH-#2377A, IRGKangXi=0559.261, RSKangXi=75.14
2377B CJK UNIFIED IDEOGRAPH-#2377B, IRGKangXi=0559.261, RSKangXi=75.14
2377C CJK UNIFIED IDEOGRAPH-#2377C, IRGKangXi=0559.261, RSKangXi=75.14
2377D CJK UNIFIED IDEOGRAPH-#2377D, IRGKangXi=0559.261, RSKangXi=75.14
2377E CJK UNIFIED IDEOGRAPH-#2377E, IRGKangXi=0559.261, RSKangXi=75.14
2377F CJK UNIFIED IDEOGRAPH-#2377F, IRGKangXi=0559.261, RSKangXi=75.14
23780 CJK UNIFIED IDEOGRAPH-#23780, IRGKangXi=0559.261, RSKangXi=75.14
23781 CJK UNIFIED IDEOGRAPH-#23781, IRGKangXi=0559.261, RSKangXi=75.14
23782 CJK UNIFIED IDEOGRAPH-#23782, IRGKangXi=0559.261, RSKangXi=75.14
23783 CJK UNIFIED IDEOGRAPH-#23783, IRGKangXi=0559.261, RSKangXi=75.14
23784 CJK UNIFIED IDEOGRAPH-#23784, IRGKangXi=0559.261, RSKangXi=75.14
23785 CJK UNIFIED IDEOGRAPH-#23785, IRGKangXi=0559.261, RSKangXi=75.14
23786 CJK UNIFIED IDEOGRAPH-#23786, IRGKangXi=0559.261, RSKangXi=75.14
23787 CJK UNIFIED IDEOGRAPH-#23787, IRGKangXi=0559.261, RSKangXi=75.14
23788 CJK UNIFIED IDEOGRAPH-#23788, IRGKangXi=0559.261, RSKangXi=75.14
23789 CJK UNIFIED IDEOGRAPH-#23789, IRGKangXi=0559.261, RSKangXi=75.14
2378A CJK UNIFIED IDEOGRAPH-#2378A, IRGKangXi=0559.261, RSKangXi=75.14
2378B CJK UNIFIED IDEOGRAPH-#2378B, IRGKangXi=0559.261, RSKangXi=75.14
2378C CJK UNIFIED IDEOGRAPH-#2378C, IRGKangXi=0559.261, RSKangXi=75.14
2378D CJK UNIFIED IDEOGRAPH-#2378D, IRGKangXi=0559.261, RSKangXi=75.14
2378E CJK UNIFIED IDEOGRAPH-#2378E, IRGKangXi=0559.261, RSKangXi=75.14
2378F CJK UNIFIED IDEOGRAPH-#2378F, IRGKangXi=0559.261, RSKangXi=112.13
23790 CJK UNIFIED IDEOGRAPH-#23790, IRGKangXi=0559.270, RSKangXi=75.15
23791 CJK UNIFIED IDEOGRAPH-#23791, IRGKangXi=0559.340, RSKangXi=75.15
23792 CJK UNIFIED IDEOGRAPH-#23792, IRGKangXi=0559.350, RSKangXi=75.15
23793 CJK UNIFIED IDEOGRAPH-#23793, IRGKangXi=0560.010, RSKangXi=75.15
23794 CJK UNIFIED IDEOGRAPH-#23794, IRGKangXi=0560.060, RSKangXi=75.15
23795 CJK UNIFIED IDEOGRAPH-#23795, IRGKangXi=0560.090, RSKangXi=75.15
23796 CJK UNIFIED IDEOGRAPH-#23796, IRGKangXi=0560.170, RSKangXi=75.15
23797 CJK UNIFIED IDEOGRAPH-#23797, IRGKangXi=0560.210, RSKangXi=75.15
23798 CJK UNIFIED IDEOGRAPH-#23798, IRGKangXi=0560.260, RSKangXi=75.15
23799 CJK UNIFIED IDEOGRAPH-#23799, IRGKangXi=0560.270, RSKangXi=75.15
2379A CJK UNIFIED IDEOGRAPH-#2379A, IRGKangXi=0561.050, RSKangXi=75.15
2379B CJK UNIFIED IDEOGRAPH-#2379B, IRGKangXi=0561.060, RSKangXi=75.15
2379C CJK UNIFIED IDEOGRAPH-#2379C, IRGKangXi=0561.070, RSKangXi=75.15
2379D CJK UNIFIED IDEOGRAPH-#2379D, IRGKangXi=0561.080, RSKangXi=75.15
2379E CJK UNIFIED IDEOGRAPH-#2379E, IRGKangXi=0561.100, RSKangXi=75.15
2379F CJK UNIFIED IDEOGRAPH-#2379F, IRGKangXi=0561.110, RSKangXi=75.15
237A0 CJK UNIFIED IDEOGRAPH-#237A0, IRGKangXi=0561.111, RSKangXi=75.15
237A1 CJK UNIFIED IDEOGRAPH-#237A1, IRGKangXi=0561.111, RSKangXi=75.15
237A2 CJK UNIFIED IDEOGRAPH-#237A2, IRGKangXi=0561.111, RSKangXi=75.15
237A3 CJK UNIFIED IDEOGRAPH-#237A3, IRGKangXi=0561.111, RSKangXi=75.15
237A4 CJK UNIFIED IDEOGRAPH-#237A4, IRGKangXi=0561.111, RSKangXi=75.15
237A5 CJK UNIFIED IDEOGRAPH-#237A5, IRGKangXi=0561.111, RSKangXi=75.15
237A6 CJK UNIFIED IDEOGRAPH-#237A6, IRGKangXi=0561.111, RSKangXi=75.15
237A7 CJK UNIFIED IDEOGRAPH-#237A7, IRGKangXi=0561.111, RSKangXi=75.15
237A8 CJK UNIFIED IDEOGRAPH-#237A8, IRGKangXi=0561.111, RSKangXi=75.15
237A9 CJK UNIFIED IDEOGRAPH-#237A9, IRGKangXi=0561.111, RSKangXi=75.15
237AA CJK UNIFIED IDEOGRAPH-#237AA, IRGKangXi=0561.111, RSKangXi=75.15
237AB CJK UNIFIED IDEOGRAPH-#237AB, IRGKangXi=0561.111, RSKangXi=75.15
237AC CJK UNIFIED IDEOGRAPH-#237AC, IRGKangXi=0561.111, RSKangXi=75.15
237AD CJK UNIFIED IDEOGRAPH-#237AD, IRGKangXi=0561.111, RSKangXi=75.15
237AE CJK UNIFIED IDEOGRAPH-#237AE, IRGKangXi=0561.111, RSKangXi=75.15
237AF CJK UNIFIED IDEOGRAPH-#237AF, IRGKangXi=0561.111, RSKangXi=75.15
237B0 CJK UNIFIED IDEOGRAPH-#237B0, IRGKangXi=0561.111, RSKangXi=75.15
237B1 CJK UNIFIED IDEOGRAPH-#237B1, IRGKangXi=0561.111, RSKangXi=75.15
237B2 CJK UNIFIED IDEOGRAPH-#237B2, IRGKangXi=0561.111, RSKangXi=75.15
237B3 CJK UNIFIED IDEOGRAPH-#237B3, IRGKangXi=0561.111, RSKangXi=75.15
237B4 CJK UNIFIED IDEOGRAPH-#237B4, IRGKangXi=0561.111, RSKangXi=75.15
237B5 CJK UNIFIED IDEOGRAPH-#237B5, IRGKangXi=0561.111, RSKangXi=75.15
237B6 CJK UNIFIED IDEOGRAPH-#237B6, IRGKangXi=0561.111, RSKangXi=75.15
237B7 CJK UNIFIED IDEOGRAPH-#237B7, IRGKangXi=0561.111, RSKangXi=75.15
237B8 CJK UNIFIED IDEOGRAPH-#237B8, IRGKangXi=0561.111, RSKangXi=75.15
237B9 CJK UNIFIED IDEOGRAPH-#237B9, IRGKangXi=0561.111, RSKangXi=75.15
237BA CJK UNIFIED IDEOGRAPH-#237BA, IRGKangXi=0561.111, RSKangXi=75.15
237BB CJK UNIFIED IDEOGRAPH-#237BB, IRGKangXi=0561.111, RSKangXi=75.15
237BC CJK UNIFIED IDEOGRAPH-#237BC, IRGKangXi=0561.111, RSKangXi=75.15
237BD CJK UNIFIED IDEOGRAPH-#237BD, IRGKangXi=0561.111, RSKangXi=75.15
237BE CJK UNIFIED IDEOGRAPH-#237BE, IRGKangXi=0561.111, RSKangXi=75.15
237BF CJK UNIFIED IDEOGRAPH-#237BF, IRGKangXi=0561.111, RSKangXi=75.15
237C0 CJK UNIFIED IDEOGRAPH-#237C0, IRGKangXi=0561.111, RSKangXi=75.15
237C1 CJK UNIFIED IDEOGRAPH-#237C1, IRGKangXi=0561.111, RSKangXi=75.15
237C2 CJK UNIFIED IDEOGRAPH-#237C2, IRGKangXi=0561.111, RSKangXi=75.15
237C3 CJK UNIFIED IDEOGRAPH-#237C3, IRGKangXi=0561.111, RSKangXi=75.15
237C4 CJK UNIFIED IDEOGRAPH-#237C4, IRGKangXi=0561.170, RSKangXi=75.16
237C5 CJK UNIFIED IDEOGRAPH-#237C5, IRGKangXi=0561.190, RSKangXi=75.16
237C6 CJK UNIFIED IDEOGRAPH-#237C6, IRGKangXi=0561.200, RSKangXi=75.16
237C7 CJK UNIFIED IDEOGRAPH-#237C7, IRGKangXi=0561.220, RSKangXi=75.16
237C8 CJK UNIFIED IDEOGRAPH-#237C8, IRGKangXi=0561.250, RSKangXi=75.16
237C9 CJK UNIFIED IDEOGRAPH-#237C9, IRGKangXi=0561.270, RSKangXi=75.16
237CA CJK UNIFIED IDEOGRAPH-#237CA, IRGKangXi=0561.280, RSKangXi=75.16
237CB CJK UNIFIED IDEOGRAPH-#237CB, IRGKangXi=0561.310, RSKangXi=75.16
237CC CJK UNIFIED IDEOGRAPH-#237CC, IRGKangXi=0561.360, RSKangXi=75.16
237CD CJK UNIFIED IDEOGRAPH-#237CD, IRGKangXi=0561.370, RSKangXi=75.16
237CE CJK UNIFIED IDEOGRAPH-#237CE, IRGKangXi=0562.030, RSKangXi=75.16
237CF CJK UNIFIED IDEOGRAPH-#237CF, IRGKangXi=0562.070, RSKangXi=75.16
237D0 CJK UNIFIED IDEOGRAPH-#237D0, IRGKangXi=0562.080, RSKangXi=75.16
237D1 CJK UNIFIED IDEOGRAPH-#237D1, IRGKangXi=0562.090, RSKangXi=75.15
237D2 CJK UNIFIED IDEOGRAPH-#237D2, IRGKangXi=0562.100, RSKangXi=75.16
237D3 CJK UNIFIED IDEOGRAPH-#237D3, IRGKangXi=0562.101, RSKangXi=75.16
237D4 CJK UNIFIED IDEOGRAPH-#237D4, IRGKangXi=0562.101, RSKangXi=75.16
237D5 CJK UNIFIED IDEOGRAPH-#237D5, IRGKangXi=0562.101, RSKangXi=75.16
237D6 CJK UNIFIED IDEOGRAPH-#237D6, IRGKangXi=0562.101, RSKangXi=75.16
237D7 CJK UNIFIED IDEOGRAPH-#237D7, IRGKangXi=0562.101, RSKangXi=75.16
237D8 CJK UNIFIED IDEOGRAPH-#237D8, IRGKangXi=0562.101, RSKangXi=75.16
237D9 CJK UNIFIED IDEOGRAPH-#237D9, IRGKangXi=0562.101, RSKangXi=75.16
237DA CJK UNIFIED IDEOGRAPH-#237DA, IRGKangXi=0562.101, RSKangXi=75.16
237DB CJK UNIFIED IDEOGRAPH-#237DB, IRGKangXi=0562.101, RSKangXi=75.16
237DC CJK UNIFIED IDEOGRAPH-#237DC, IRGKangXi=0562.101, RSKangXi=75.16
237DD CJK UNIFIED IDEOGRAPH-#237DD, IRGKangXi=0562.101, RSKangXi=75.16
237DE CJK UNIFIED IDEOGRAPH-#237DE, IRGKangXi=0562.101, RSKangXi=75.16
237DF CJK UNIFIED IDEOGRAPH-#237DF, IRGKangXi=0562.101, RSKangXi=75.16
237E0 CJK UNIFIED IDEOGRAPH-#237E0, IRGKangXi=0562.101, RSKangXi=75.16
237E1 CJK UNIFIED IDEOGRAPH-#237E1, IRGKangXi=0562.101, RSKangXi=75.16
237E2 CJK UNIFIED IDEOGRAPH-#237E2, IRGKangXi=0562.101, RSKangXi=75.16
237E3 CJK UNIFIED IDEOGRAPH-#237E3, IRGKangXi=0562.101, RSKangXi=75.16
237E4 CJK UNIFIED IDEOGRAPH-#237E4, IRGKangXi=0562.101, RSKangXi=75.16
237E5 CJK UNIFIED IDEOGRAPH-#237E5, IRGKangXi=0562.101, RSKangXi=75.16
237E6 CJK UNIFIED IDEOGRAPH-#237E6, IRGKangXi=0562.101, RSKangXi=75.16
237E7 CJK UNIFIED IDEOGRAPH-#237E7, IRGKangXi=0562.101, RSKangXi=75.16
237E8 CJK UNIFIED IDEOGRAPH-#237E8, IRGKangXi=0562.101, RSKangXi=75.16
237E9 CJK UNIFIED IDEOGRAPH-#237E9, IRGKangXi=0562.101, RSKangXi=75.16
237EA CJK UNIFIED IDEOGRAPH-#237EA, IRGKangXi=0562.101, RSKangXi=75.16
237EB CJK UNIFIED IDEOGRAPH-#237EB, IRGKangXi=0562.101, RSKangXi=75.16
237EC CJK UNIFIED IDEOGRAPH-#237EC, IRGKangXi=0562.101, RSKangXi=75.16, Def{same as 欄 U+6B04, a railing, balustrade; an animal pan}
237ED CJK UNIFIED IDEOGRAPH-#237ED, IRGKangXi=0562.101, RSKangXi=75.16
237EE CJK UNIFIED IDEOGRAPH-#237EE, IRGKangXi=0562.101, RSKangXi=75.16
237EF CJK UNIFIED IDEOGRAPH-#237EF, IRGKangXi=0562.110, RSKangXi=75.17
237F0 CJK UNIFIED IDEOGRAPH-#237F0, IRGKangXi=0562.120, RSKangXi=75.17
237F1 CJK UNIFIED IDEOGRAPH-#237F1, IRGKangXi=0562.130, RSKangXi=75.17, Def{Zelkova tree}
237F2 CJK UNIFIED IDEOGRAPH-#237F2, IRGKangXi=0562.140, RSKangXi=75.17
237F3 CJK UNIFIED IDEOGRAPH-#237F3, IRGKangXi=0562.160, RSKangXi=75.17
237F4 CJK UNIFIED IDEOGRAPH-#237F4, IRGKangXi=0562.210, RSKangXi=75.17
237F5 CJK UNIFIED IDEOGRAPH-#237F5, IRGKangXi=0562.240, RSKangXi=75.17
237F6 CJK UNIFIED IDEOGRAPH-#237F6, IRGKangXi=0562.270, RSKangXi=75.17
237F7 CJK UNIFIED IDEOGRAPH-#237F7, IRGKangXi=0562.290, RSKangXi=75.17
237F8 CJK UNIFIED IDEOGRAPH-#237F8, IRGKangXi=0562.300, RSKangXi=75.17
237F9 CJK UNIFIED IDEOGRAPH-#237F9, IRGKangXi=0562.310, RSKangXi=75.17
237FA CJK UNIFIED IDEOGRAPH-#237FA, IRGKangXi=0563.020, RSKangXi=75.17
237FB CJK UNIFIED IDEOGRAPH-#237FB, IRGKangXi=0563.030, RSKangXi=75.17
237FC CJK UNIFIED IDEOGRAPH-#237FC, IRGKangXi=0563.040, RSKangXi=75.17
237FD CJK UNIFIED IDEOGRAPH-#237FD, IRGKangXi=0563.050, RSKangXi=75.17
237FE CJK UNIFIED IDEOGRAPH-#237FE, IRGKangXi=0563.060, RSKangXi=75.17
237FF CJK UNIFIED IDEOGRAPH-#237FF, IRGKangXi=0563.061, RSKangXi=75.17
23800 CJK UNIFIED IDEOGRAPH-#23800, IRGKangXi=0563.061, RSKangXi=75.17
23801 CJK UNIFIED IDEOGRAPH-#23801, IRGKangXi=0563.061, RSKangXi=75.17
23802 CJK UNIFIED IDEOGRAPH-#23802, IRGKangXi=0563.061, RSKangXi=75.18
23803 CJK UNIFIED IDEOGRAPH-#23803, IRGKangXi=0563.061, RSKangXi=75.17
23804 CJK UNIFIED IDEOGRAPH-#23804, IRGKangXi=0563.061, RSKangXi=75.17
23805 CJK UNIFIED IDEOGRAPH-#23805, IRGKangXi=0563.061, RSKangXi=75.17
23806 CJK UNIFIED IDEOGRAPH-#23806, IRGKangXi=0563.061, RSKangXi=75.17
23807 CJK UNIFIED IDEOGRAPH-#23807, IRGKangXi=0563.061, RSKangXi=75.17
23808 CJK UNIFIED IDEOGRAPH-#23808, IRGKangXi=0563.061, RSKangXi=75.17
23809 CJK UNIFIED IDEOGRAPH-#23809, IRGKangXi=0563.061, RSKangXi=75.17
2380A CJK UNIFIED IDEOGRAPH-#2380A, IRGKangXi=0563.061, RSKangXi=75.17
2380B CJK UNIFIED IDEOGRAPH-#2380B, IRGKangXi=0563.061, RSKangXi=75.17
2380C CJK UNIFIED IDEOGRAPH-#2380C, IRGKangXi=0563.061, RSKangXi=75.17
2380D CJK UNIFIED IDEOGRAPH-#2380D, IRGKangXi=0563.061, RSKangXi=75.17
2380E CJK UNIFIED IDEOGRAPH-#2380E, IRGKangXi=0563.061, RSKangXi=75.17
2380F CJK UNIFIED IDEOGRAPH-#2380F, IRGKangXi=0563.061, RSKangXi=75.17
23810 CJK UNIFIED IDEOGRAPH-#23810, IRGKangXi=0563.061, RSKangXi=75.17
23811 CJK UNIFIED IDEOGRAPH-#23811, IRGKangXi=0563.061, RSKangXi=75.17
23812 CJK UNIFIED IDEOGRAPH-#23812, IRGKangXi=0563.061, RSKangXi=75.17
23813 CJK UNIFIED IDEOGRAPH-#23813, IRGKangXi=0563.061, RSKangXi=75.17
23814 CJK UNIFIED IDEOGRAPH-#23814, IRGKangXi=0563.061, RSKangXi=75.17
23815 CJK UNIFIED IDEOGRAPH-#23815, IRGKangXi=0563.061, RSKangXi=75.17
23816 CJK UNIFIED IDEOGRAPH-#23816, IRGKangXi=0563.061, RSKangXi=75.17
23817 CJK UNIFIED IDEOGRAPH-#23817, IRGKangXi=0563.061, RSKangXi=75.17
23818 CJK UNIFIED IDEOGRAPH-#23818, IRGKangXi=0563.061, RSKangXi=75.17
23819 CJK UNIFIED IDEOGRAPH-#23819, IRGKangXi=0563.070, RSKangXi=75.18
2381A CJK UNIFIED IDEOGRAPH-#2381A, IRGKangXi=0563.090, RSKangXi=75.18
2381B CJK UNIFIED IDEOGRAPH-#2381B, IRGKangXi=0563.100, RSKangXi=75.18
2381C CJK UNIFIED IDEOGRAPH-#2381C, IRGKangXi=0563.110, RSKangXi=75.18
2381D CJK UNIFIED IDEOGRAPH-#2381D, IRGKangXi=0563.130, RSKangXi=75.18
2381E CJK UNIFIED IDEOGRAPH-#2381E, IRGKangXi=0563.150, RSKangXi=75.18
2381F CJK UNIFIED IDEOGRAPH-#2381F, IRGKangXi=0563.160, RSKangXi=75.18
23820 CJK UNIFIED IDEOGRAPH-#23820, IRGKangXi=0563.200, RSKangXi=75.18
23821 CJK UNIFIED IDEOGRAPH-#23821, IRGKangXi=0563.230, RSKangXi=75.18
23822 CJK UNIFIED IDEOGRAPH-#23822, IRGKangXi=0563.231, RSKangXi=75.18
23823 CJK UNIFIED IDEOGRAPH-#23823, IRGKangXi=0563.231, RSKangXi=75.18
23824 CJK UNIFIED IDEOGRAPH-#23824, IRGKangXi=0563.231, RSKangXi=75.18
23825 CJK UNIFIED IDEOGRAPH-#23825, IRGKangXi=0563.231, RSKangXi=75.18
23826 CJK UNIFIED IDEOGRAPH-#23826, IRGKangXi=0563.231, RSKangXi=75.18
23827 CJK UNIFIED IDEOGRAPH-#23827, IRGKangXi=0563.231, RSKangXi=75.18
23828 CJK UNIFIED IDEOGRAPH-#23828, IRGKangXi=0563.231, RSKangXi=75.18
23829 CJK UNIFIED IDEOGRAPH-#23829, IRGKangXi=0563.231, RSKangXi=75.18
2382A CJK UNIFIED IDEOGRAPH-#2382A, IRGKangXi=0563.231, RSKangXi=75.18
2382B CJK UNIFIED IDEOGRAPH-#2382B, IRGKangXi=0563.231, RSKangXi=75.18
2382C CJK UNIFIED IDEOGRAPH-#2382C, IRGKangXi=0563.231, RSKangXi=75.18
2382D CJK UNIFIED IDEOGRAPH-#2382D, IRGKangXi=0563.231, RSKangXi=75.18
2382E CJK UNIFIED IDEOGRAPH-#2382E, IRGKangXi=0563.231, RSKangXi=75.18
2382F CJK UNIFIED IDEOGRAPH-#2382F, IRGKangXi=0563.231, RSKangXi=75.18
23830 CJK UNIFIED IDEOGRAPH-#23830, IRGKangXi=0563.231, RSKangXi=75.18
23831 CJK UNIFIED IDEOGRAPH-#23831, IRGKangXi=0563.231, RSKangXi=75.18
23832 CJK UNIFIED IDEOGRAPH-#23832, IRGKangXi=0563.231, RSKangXi=75.18
23833 CJK UNIFIED IDEOGRAPH-#23833, IRGKangXi=0563.231, RSKangXi=75.18
23834 CJK UNIFIED IDEOGRAPH-#23834, IRGKangXi=0563.231, RSKangXi=75.18
23835 CJK UNIFIED IDEOGRAPH-#23835, IRGKangXi=0563.231, RSKangXi=75.18
23836 CJK UNIFIED IDEOGRAPH-#23836, IRGKangXi=0563.231, RSKangXi=75.18
23837 CJK UNIFIED IDEOGRAPH-#23837, IRGKangXi=0563.250, RSKangXi=75.19
23838 CJK UNIFIED IDEOGRAPH-#23838, IRGKangXi=0563.260, RSKangXi=75.19
23839 CJK UNIFIED IDEOGRAPH-#23839, IRGKangXi=0563.270, RSKangXi=75.19
2383A CJK UNIFIED IDEOGRAPH-#2383A, IRGKangXi=0563.290, RSKangXi=75.19
2383B CJK UNIFIED IDEOGRAPH-#2383B, IRGKangXi=0563.300, RSKangXi=75.19
2383C CJK UNIFIED IDEOGRAPH-#2383C, IRGKangXi=0563.350, RSKangXi=75.19
2383D CJK UNIFIED IDEOGRAPH-#2383D, IRGKangXi=0563.360, RSKangXi=75.19, Def{same as 欛 U+6B1B, a handle}
2383E CJK UNIFIED IDEOGRAPH-#2383E, IRGKangXi=0563.370, RSKangXi=75.19
2383F CJK UNIFIED IDEOGRAPH-#2383F, IRGKangXi=0564.020, RSKangXi=75.19
23840 CJK UNIFIED IDEOGRAPH-#23840, IRGKangXi=0564.030, RSKangXi=75.19
23841 CJK UNIFIED IDEOGRAPH-#23841, IRGKangXi=0564.031, RSKangXi=75.19
23842 CJK UNIFIED IDEOGRAPH-#23842, IRGKangXi=0564.031, RSKangXi=75.19
23843 CJK UNIFIED IDEOGRAPH-#23843, IRGKangXi=0564.031, RSKangXi=75.19
23844 CJK UNIFIED IDEOGRAPH-#23844, IRGKangXi=0564.031, RSKangXi=75.19
23845 CJK UNIFIED IDEOGRAPH-#23845, IRGKangXi=0564.031, RSKangXi=75.19
23846 CJK UNIFIED IDEOGRAPH-#23846, IRGKangXi=0564.031, RSKangXi=75.19
23847 CJK UNIFIED IDEOGRAPH-#23847, IRGKangXi=0564.031, RSKangXi=75.19
23848 CJK UNIFIED IDEOGRAPH-#23848, IRGKangXi=0564.031, RSKangXi=75.19
23849 CJK UNIFIED IDEOGRAPH-#23849, IRGKangXi=0564.031, RSKangXi=75.19
2384A CJK UNIFIED IDEOGRAPH-#2384A, IRGKangXi=0564.031, RSKangXi=75.19
2384B CJK UNIFIED IDEOGRAPH-#2384B, IRGKangXi=0564.050, RSKangXi=75.20
2384C CJK UNIFIED IDEOGRAPH-#2384C, IRGKangXi=0564.070, RSKangXi=75.20
2384D CJK UNIFIED IDEOGRAPH-#2384D, IRGKangXi=0564.080, RSKangXi=75.20
2384E CJK UNIFIED IDEOGRAPH-#2384E, IRGKangXi=0564.090, RSKangXi=75.20
2384F CJK UNIFIED IDEOGRAPH-#2384F, IRGKangXi=0564.091, RSKangXi=75.20
23850 CJK UNIFIED IDEOGRAPH-#23850, IRGKangXi=0564.091, RSKangXi=75.20
23851 CJK UNIFIED IDEOGRAPH-#23851, IRGKangXi=0564.091, RSKangXi=75.20
23852 CJK UNIFIED IDEOGRAPH-#23852, IRGKangXi=0564.091, RSKangXi=75.20
23853 CJK UNIFIED IDEOGRAPH-#23853, IRGKangXi=0564.091, RSKangXi=75.20
23854 CJK UNIFIED IDEOGRAPH-#23854, IRGKangXi=0564.091, RSKangXi=75.20
23855 CJK UNIFIED IDEOGRAPH-#23855, IRGKangXi=0564.091, RSKangXi=75.20
23856 CJK UNIFIED IDEOGRAPH-#23856, IRGKangXi=0564.091, RSKangXi=75.20
23857 CJK UNIFIED IDEOGRAPH-#23857, IRGKangXi=0564.091, RSKangXi=75.20
23858 CJK UNIFIED IDEOGRAPH-#23858, IRGKangXi=0564.091, RSKangXi=75.20
23859 CJK UNIFIED IDEOGRAPH-#23859, IRGKangXi=0564.091, RSKangXi=75.20
2385A CJK UNIFIED IDEOGRAPH-#2385A, IRGKangXi=0564.091, RSKangXi=75.20
2385B CJK UNIFIED IDEOGRAPH-#2385B, IRGKangXi=0564.091, RSKangXi=75.20
2385C CJK UNIFIED IDEOGRAPH-#2385C, IRGKangXi=0564.091, RSKangXi=75.20
2385D CJK UNIFIED IDEOGRAPH-#2385D, IRGKangXi=0564.091, RSKangXi=75.20
2385E CJK UNIFIED IDEOGRAPH-#2385E, IRGKangXi=0564.110, RSKangXi=75.21
2385F CJK UNIFIED IDEOGRAPH-#2385F, IRGKangXi=0564.120, RSKangXi=75.21
23860 CJK UNIFIED IDEOGRAPH-#23860, IRGKangXi=0564.180, RSKangXi=75.21
23861 CJK UNIFIED IDEOGRAPH-#23861, IRGKangXi=0564.181, RSKangXi=75.21
23862 CJK UNIFIED IDEOGRAPH-#23862, IRGKangXi=0564.181, RSKangXi=75.21
23863 CJK UNIFIED IDEOGRAPH-#23863, IRGKangXi=0564.181, RSKangXi=75.21
23864 CJK UNIFIED IDEOGRAPH-#23864, IRGKangXi=0564.181, RSKangXi=75.21
23865 CJK UNIFIED IDEOGRAPH-#23865, IRGKangXi=0564.181, RSKangXi=75.21
23866 CJK UNIFIED IDEOGRAPH-#23866, IRGKangXi=0564.181, RSKangXi=75.21
23867 CJK UNIFIED IDEOGRAPH-#23867, IRGKangXi=0564.181, RSKangXi=75.21
23868 CJK UNIFIED IDEOGRAPH-#23868, IRGKangXi=0564.181, RSKangXi=75.21
23869 CJK UNIFIED IDEOGRAPH-#23869, IRGKangXi=0564.190, RSKangXi=75.22
2386A CJK UNIFIED IDEOGRAPH-#2386A, IRGKangXi=0564.220, RSKangXi=75.22
2386B CJK UNIFIED IDEOGRAPH-#2386B, IRGKangXi=0564.230, RSKangXi=75.22
2386C CJK UNIFIED IDEOGRAPH-#2386C, IRGKangXi=0564.231, RSKangXi=75.22
2386D CJK UNIFIED IDEOGRAPH-#2386D, IRGKangXi=0564.231, RSKangXi=75.22
2386E CJK UNIFIED IDEOGRAPH-#2386E, IRGKangXi=0564.231, RSKangXi=75.22
2386F CJK UNIFIED IDEOGRAPH-#2386F, IRGKangXi=0564.231, RSKangXi=75.22
23870 CJK UNIFIED IDEOGRAPH-#23870, IRGKangXi=0564.231, RSKangXi=75.22
23871 CJK UNIFIED IDEOGRAPH-#23871, IRGKangXi=0564.231, RSKangXi=75.22
23872 CJK UNIFIED IDEOGRAPH-#23872, IRGKangXi=0564.231, RSKangXi=75.23
23873 CJK UNIFIED IDEOGRAPH-#23873, IRGKangXi=0564.231, RSKangXi=36.24
23874 CJK UNIFIED IDEOGRAPH-#23874, IRGKangXi=0564.231, RSKangXi=75.23
23875 CJK UNIFIED IDEOGRAPH-#23875, IRGKangXi=0564.231, RSKangXi=75.23
23876 CJK UNIFIED IDEOGRAPH-#23876, IRGKangXi=0564.240, RSKangXi=75.24
23877 CJK UNIFIED IDEOGRAPH-#23877, IRGKangXi=0564.250, RSKangXi=75.24
23878 CJK UNIFIED IDEOGRAPH-#23878, IRGKangXi=0564.261, RSKangXi=75.24
23879 CJK UNIFIED IDEOGRAPH-#23879, IRGKangXi=0564.261, RSKangXi=75.25
2387A CJK UNIFIED IDEOGRAPH-#2387A, IRGKangXi=0564.270, RSKangXi=75.26
2387B CJK UNIFIED IDEOGRAPH-#2387B, IRGKangXi=0564.271, RSKangXi=75.26
2387C CJK UNIFIED IDEOGRAPH-#2387C, IRGKangXi=0564.280, RSKangXi=75.27
2387D CJK UNIFIED IDEOGRAPH-#2387D, IRGKangXi=0564.281, RSKangXi=75.28
2387E CJK UNIFIED IDEOGRAPH-#2387E, IRGKangXi=0564.281, RSKangXi=75.28
2387F CJK UNIFIED IDEOGRAPH-#2387F, IRGKangXi=0564.281, RSKangXi=75.30
23880 CJK UNIFIED IDEOGRAPH-#23880, IRGKangXi=0565.061, RSKangXi=76.2
23881 CJK UNIFIED IDEOGRAPH-#23881, IRGKangXi=0565.070, RSKangXi=76.3
23882 CJK UNIFIED IDEOGRAPH-#23882, IRGKangXi=0565.080, RSKangXi=76.3
23883 CJK UNIFIED IDEOGRAPH-#23883, IRGKangXi=0565.100, RSKangXi=76.3
23884 CJK UNIFIED IDEOGRAPH-#23884, IRGKangXi=0565.110, RSKangXi=76.3
23885 CJK UNIFIED IDEOGRAPH-#23885, IRGKangXi=0565.120, RSKangXi=76.3
23886 CJK UNIFIED IDEOGRAPH-#23886, IRGKangXi=0565.130, RSKangXi=76.3
23887 CJK UNIFIED IDEOGRAPH-#23887, IRGKangXi=0565.150, RSKangXi=76.3
23888 CJK UNIFIED IDEOGRAPH-#23888, IRGKangXi=0565.151, RSKangXi=76.3
23889 CJK UNIFIED IDEOGRAPH-#23889, IRGKangXi=0566.010, RSKangXi=76.4
2388A CJK UNIFIED IDEOGRAPH-#2388A, IRGKangXi=0566.020, RSKangXi=76.4
2388B CJK UNIFIED IDEOGRAPH-#2388B, IRGKangXi=0566.030, RSKangXi=76.4
2388C CJK UNIFIED IDEOGRAPH-#2388C, IRGKangXi=0566.050, RSKangXi=76.4
2388D CJK UNIFIED IDEOGRAPH-#2388D, IRGKangXi=0566.060, RSKangXi=76.4
2388E CJK UNIFIED IDEOGRAPH-#2388E, IRGKangXi=0566.070, RSKangXi=76.4
2388F CJK UNIFIED IDEOGRAPH-#2388F, IRGKangXi=0566.090, RSKangXi=76.4
23890 CJK UNIFIED IDEOGRAPH-#23890, IRGKangXi=0566.110, RSKangXi=76.4
23891 CJK UNIFIED IDEOGRAPH-#23891, IRGKangXi=0566.140, RSKangXi=76.4
23892 CJK UNIFIED IDEOGRAPH-#23892, IRGKangXi=0566.160, RSKangXi=76.4
23893 CJK UNIFIED IDEOGRAPH-#23893, IRGKangXi=0566.180, RSKangXi=76.4
23894 CJK UNIFIED IDEOGRAPH-#23894, IRGKangXi=0566.181, RSKangXi=76.4
23895 CJK UNIFIED IDEOGRAPH-#23895, IRGKangXi=0566.181, RSKangXi=76.4
23896 CJK UNIFIED IDEOGRAPH-#23896, IRGKangXi=0566.181, RSKangXi=76.4
23897 CJK UNIFIED IDEOGRAPH-#23897, IRGKangXi=0566.190, RSKangXi=76.5
23898 CJK UNIFIED IDEOGRAPH-#23898, IRGKangXi=0566.200, RSKangXi=76.5
23899 CJK UNIFIED IDEOGRAPH-#23899, IRGKangXi=0566.230, RSKangXi=76.5
2389A CJK UNIFIED IDEOGRAPH-#2389A, IRGKangXi=0566.250, RSKangXi=76.5
2389B CJK UNIFIED IDEOGRAPH-#2389B, IRGKangXi=0566.260, RSKangXi=76.5
2389C CJK UNIFIED IDEOGRAPH-#2389C, IRGKangXi=0566.290, RSKangXi=76.5
2389D CJK UNIFIED IDEOGRAPH-#2389D, IRGKangXi=0566.320, RSKangXi=76.5
2389E CJK UNIFIED IDEOGRAPH-#2389E, IRGKangXi=0567.010, RSKangXi=76.5
2389F CJK UNIFIED IDEOGRAPH-#2389F, IRGKangXi=0567.030, RSKangXi=76.5
238A0 CJK UNIFIED IDEOGRAPH-#238A0, IRGKangXi=0567.040, RSKangXi=76.5
238A1 CJK UNIFIED IDEOGRAPH-#238A1, IRGKangXi=0567.050, RSKangXi=76.5
238A2 CJK UNIFIED IDEOGRAPH-#238A2, IRGKangXi=0567.060, RSKangXi=76.5
238A3 CJK UNIFIED IDEOGRAPH-#238A3, IRGKangXi=0567.061, RSKangXi=76.5
238A4 CJK UNIFIED IDEOGRAPH-#238A4, IRGKangXi=0567.061, RSKangXi=76.5
238A5 CJK UNIFIED IDEOGRAPH-#238A5, IRGKangXi=0567.061, RSKangXi=76.5
238A6 CJK UNIFIED IDEOGRAPH-#238A6, IRGKangXi=0567.061, RSKangXi=76.5
238A7 CJK UNIFIED IDEOGRAPH-#238A7, IRGKangXi=0567.070, RSKangXi=76.6
238A8 CJK UNIFIED IDEOGRAPH-#238A8, IRGKangXi=0567.090, RSKangXi=76.6
238A9 CJK UNIFIED IDEOGRAPH-#238A9, IRGKangXi=0567.100, RSKangXi=76.6
238AA CJK UNIFIED IDEOGRAPH-#238AA, IRGKangXi=0567.120, RSKangXi=76.6
238AB CJK UNIFIED IDEOGRAPH-#238AB, IRGKangXi=0567.130, RSKangXi=76.6
238AC CJK UNIFIED IDEOGRAPH-#238AC, IRGKangXi=0567.140, RSKangXi=76.6
238AD CJK UNIFIED IDEOGRAPH-#238AD, IRGKangXi=0567.160, RSKangXi=76.6
238AE CJK UNIFIED IDEOGRAPH-#238AE, IRGKangXi=0567.170, RSKangXi=76.6
238AF CJK UNIFIED IDEOGRAPH-#238AF, IRGKangXi=0567.180, RSKangXi=76.6
238B0 CJK UNIFIED IDEOGRAPH-#238B0, IRGKangXi=0567.230, RSKangXi=76.6
238B1 CJK UNIFIED IDEOGRAPH-#238B1, IRGKangXi=0567.280, RSKangXi=76.6
238B2 CJK UNIFIED IDEOGRAPH-#238B2, IRGKangXi=0567.300, RSKangXi=76.6
238B3 CJK UNIFIED IDEOGRAPH-#238B3, IRGKangXi=0567.310, RSKangXi=76.6
238B4 CJK UNIFIED IDEOGRAPH-#238B4, IRGKangXi=0567.320, RSKangXi=76.6
238B5 CJK UNIFIED IDEOGRAPH-#238B5, IRGKangXi=0567.321, RSKangXi=76.6
238B6 CJK UNIFIED IDEOGRAPH-#238B6, IRGKangXi=0567.321, RSKangXi=76.6
238B7 CJK UNIFIED IDEOGRAPH-#238B7, IRGKangXi=0567.321, RSKangXi=76.6
238B8 CJK UNIFIED IDEOGRAPH-#238B8, IRGKangXi=0567.321, RSKangXi=76.6
238B9 CJK UNIFIED IDEOGRAPH-#238B9, IRGKangXi=0567.321, RSKangXi=76.6
238BA CJK UNIFIED IDEOGRAPH-#238BA, IRGKangXi=0567.340, RSKangXi=76.7
238BB CJK UNIFIED IDEOGRAPH-#238BB, IRGKangXi=0567.350, RSKangXi=76.7
238BC CJK UNIFIED IDEOGRAPH-#238BC, IRGKangXi=0567.390, RSKangXi=76.7
238BD CJK UNIFIED IDEOGRAPH-#238BD, IRGKangXi=0568.080, RSKangXi=76.7
238BE CJK UNIFIED IDEOGRAPH-#238BE, IRGKangXi=0568.081, RSKangXi=96.7
238BF CJK UNIFIED IDEOGRAPH-#238BF, IRGKangXi=0568.081, RSKangXi=76.7
238C0 CJK UNIFIED IDEOGRAPH-#238C0, IRGKangXi=0568.081, RSKangXi=76.7
238C1 CJK UNIFIED IDEOGRAPH-#238C1, IRGKangXi=0568.081, RSKangXi=76.7
238C2 CJK UNIFIED IDEOGRAPH-#238C2, IRGKangXi=0568.081, RSKangXi=76.7
238C3 CJK UNIFIED IDEOGRAPH-#238C3, IRGKangXi=0568.081, RSKangXi=76.7
238C4 CJK UNIFIED IDEOGRAPH-#238C4, IRGKangXi=0568.081, RSKangXi=76.7
238C5 CJK UNIFIED IDEOGRAPH-#238C5, IRGKangXi=0568.081, RSKangXi=76.7
238C6 CJK UNIFIED IDEOGRAPH-#238C6, IRGKangXi=0568.081, RSKangXi=76.7
238C7 CJK UNIFIED IDEOGRAPH-#238C7, IRGKangXi=0568.081, RSKangXi=76.7
238C8 CJK UNIFIED IDEOGRAPH-#238C8, IRGKangXi=0568.120, RSKangXi=76.8
238C9 CJK UNIFIED IDEOGRAPH-#238C9, IRGKangXi=0568.150, RSKangXi=76.8
238CA CJK UNIFIED IDEOGRAPH-#238CA, IRGKangXi=0568.180, RSKangXi=76.8
238CB CJK UNIFIED IDEOGRAPH-#238CB, IRGKangXi=0568.190, RSKangXi=76.8
238CC CJK UNIFIED IDEOGRAPH-#238CC, IRGKangXi=0569.020, RSKangXi=76.8
238CD CJK UNIFIED IDEOGRAPH-#238CD, IRGKangXi=0569.040, RSKangXi=76.8
238CE CJK UNIFIED IDEOGRAPH-#238CE, IRGKangXi=0569.050, RSKangXi=76.8
238CF CJK UNIFIED IDEOGRAPH-#238CF, IRGKangXi=0569.060, RSKangXi=76.8
238D0 CJK UNIFIED IDEOGRAPH-#238D0, IRGKangXi=0569.080, RSKangXi=76.8
238D1 CJK UNIFIED IDEOGRAPH-#238D1, IRGKangXi=0569.090, RSKangXi=76.8
238D2 CJK UNIFIED IDEOGRAPH-#238D2, IRGKangXi=0569.100, RSKangXi=76.8
238D3 CJK UNIFIED IDEOGRAPH-#238D3, IRGKangXi=0569.110, RSKangXi=76.8
238D4 CJK UNIFIED IDEOGRAPH-#238D4, IRGKangXi=0569.111, RSKangXi=76.8
238D5 CJK UNIFIED IDEOGRAPH-#238D5, IRGKangXi=0569.111, RSKangXi=76.8
238D6 CJK UNIFIED IDEOGRAPH-#238D6, IRGKangXi=0569.111, RSKangXi=76.8
238D7 CJK UNIFIED IDEOGRAPH-#238D7, IRGKangXi=0569.111, RSKangXi=76.8
238D8 CJK UNIFIED IDEOGRAPH-#238D8, IRGKangXi=0569.111, RSKangXi=76.8
238D9 CJK UNIFIED IDEOGRAPH-#238D9, IRGKangXi=0569.111, RSKangXi=76.8
238DA CJK UNIFIED IDEOGRAPH-#238DA, IRGKangXi=0569.111, RSKangXi=76.8
238DB CJK UNIFIED IDEOGRAPH-#238DB, IRGKangXi=0569.111, RSKangXi=76.8
238DC CJK UNIFIED IDEOGRAPH-#238DC, IRGKangXi=0569.111, RSKangXi=76.8
238DD CJK UNIFIED IDEOGRAPH-#238DD, IRGKangXi=0569.130, RSKangXi=76.9
238DE CJK UNIFIED IDEOGRAPH-#238DE, IRGKangXi=0569.140, RSKangXi=76.9
238DF CJK UNIFIED IDEOGRAPH-#238DF, IRGKangXi=0569.150, RSKangXi=76.9
238E0 CJK UNIFIED IDEOGRAPH-#238E0, IRGKangXi=0570.030, RSKangXi=76.9
238E1 CJK UNIFIED IDEOGRAPH-#238E1, IRGKangXi=0570.040, RSKangXi=76.9
238E2 CJK UNIFIED IDEOGRAPH-#238E2, IRGKangXi=0570.070, RSKangXi=76.9
238E3 CJK UNIFIED IDEOGRAPH-#238E3, IRGKangXi=0570.090, RSKangXi=76.9
238E4 CJK UNIFIED IDEOGRAPH-#238E4, IRGKangXi=0570.140, RSKangXi=76.9
238E5 CJK UNIFIED IDEOGRAPH-#238E5, IRGKangXi=0570.160, RSKangXi=76.9
238E6 CJK UNIFIED IDEOGRAPH-#238E6, IRGKangXi=0570.190, RSKangXi=76.9
238E7 CJK UNIFIED IDEOGRAPH-#238E7, IRGKangXi=0570.200, RSKangXi=76.9
238E8 CJK UNIFIED IDEOGRAPH-#238E8, IRGKangXi=0570.210, RSKangXi=76.9
238E9 CJK UNIFIED IDEOGRAPH-#238E9, IRGKangXi=0570.220, RSKangXi=76.9
238EA CJK UNIFIED IDEOGRAPH-#238EA, IRGKangXi=0570.221, RSKangXi=76.9
238EB CJK UNIFIED IDEOGRAPH-#238EB, IRGKangXi=0570.221, RSKangXi=76.9
238EC CJK UNIFIED IDEOGRAPH-#238EC, IRGKangXi=0570.221, RSKangXi=154.6
238ED CJK UNIFIED IDEOGRAPH-#238ED, IRGKangXi=0570.221, RSKangXi=76.9
238EE CJK UNIFIED IDEOGRAPH-#238EE, IRGKangXi=0570.221, RSKangXi=76.9
238EF CJK UNIFIED IDEOGRAPH-#238EF, IRGKangXi=0570.221, RSKangXi=76.9
238F0 CJK UNIFIED IDEOGRAPH-#238F0, IRGKangXi=0570.221, RSKangXi=76.9
238F1 CJK UNIFIED IDEOGRAPH-#238F1, IRGKangXi=0570.221, RSKangXi=76.9
238F2 CJK UNIFIED IDEOGRAPH-#238F2, IRGKangXi=0570.230, RSKangXi=76.10
238F3 CJK UNIFIED IDEOGRAPH-#238F3, IRGKangXi=0570.240, RSKangXi=76.10
238F4 CJK UNIFIED IDEOGRAPH-#238F4, IRGKangXi=0570.250, RSKangXi=76.10
238F5 CJK UNIFIED IDEOGRAPH-#238F5, IRGKangXi=0570.260, RSKangXi=76.10
238F6 CJK UNIFIED IDEOGRAPH-#238F6, IRGKangXi=0570.280, RSKangXi=76.10
238F7 CJK UNIFIED IDEOGRAPH-#238F7, IRGKangXi=0570.290, RSKangXi=76.10
238F8 CJK UNIFIED IDEOGRAPH-#238F8, IRGKangXi=0570.310, RSKangXi=76.10
238F9 CJK UNIFIED IDEOGRAPH-#238F9, IRGKangXi=0571.020, RSKangXi=76.10
238FA CJK UNIFIED IDEOGRAPH-#238FA, IRGKangXi=0571.050, RSKangXi=76.10
238FB CJK UNIFIED IDEOGRAPH-#238FB, IRGKangXi=0571.110, RSKangXi=76.10
238FC CJK UNIFIED IDEOGRAPH-#238FC, IRGKangXi=0571.120, RSKangXi=76.10
238FD CJK UNIFIED IDEOGRAPH-#238FD, IRGKangXi=0571.130, RSKangXi=76.10
238FE CJK UNIFIED IDEOGRAPH-#238FE, IRGKangXi=0571.140, RSKangXi=76.10
238FF CJK UNIFIED IDEOGRAPH-#238FF, IRGKangXi=0571.150, RSKangXi=76.10
23900 CJK UNIFIED IDEOGRAPH-#23900, IRGKangXi=0571.160, RSKangXi=76.10
23901 CJK UNIFIED IDEOGRAPH-#23901, IRGKangXi=0571.170, RSKangXi=76.10
23902 CJK UNIFIED IDEOGRAPH-#23902, IRGKangXi=0571.180, RSKangXi=76.10
23903 CJK UNIFIED IDEOGRAPH-#23903, IRGKangXi=0571.190, RSKangXi=76.10
23904 CJK UNIFIED IDEOGRAPH-#23904, IRGKangXi=0571.191, RSKangXi=76.10
23905 CJK UNIFIED IDEOGRAPH-#23905, IRGKangXi=0571.191, RSKangXi=76.10
23906 CJK UNIFIED IDEOGRAPH-#23906, IRGKangXi=0571.191, RSKangXi=76.10
23907 CJK UNIFIED IDEOGRAPH-#23907, IRGKangXi=0571.191, RSKangXi=76.10
23908 CJK UNIFIED IDEOGRAPH-#23908, IRGKangXi=0571.200, RSKangXi=76.11
23909 CJK UNIFIED IDEOGRAPH-#23909, IRGKangXi=0571.210, RSKangXi=76.11
2390A CJK UNIFIED IDEOGRAPH-#2390A, IRGKangXi=0571.220, RSKangXi=76.11
2390B CJK UNIFIED IDEOGRAPH-#2390B, IRGKangXi=0572.020, RSKangXi=76.11
2390C CJK UNIFIED IDEOGRAPH-#2390C, IRGKangXi=0572.030, RSKangXi=76.11
2390D CJK UNIFIED IDEOGRAPH-#2390D, IRGKangXi=0572.040, RSKangXi=76.11
2390E CJK UNIFIED IDEOGRAPH-#2390E, IRGKangXi=0572.060, RSKangXi=76.11
2390F CJK UNIFIED IDEOGRAPH-#2390F, IRGKangXi=0572.070, RSKangXi=76.11
23910 CJK UNIFIED IDEOGRAPH-#23910, IRGKangXi=0572.080, RSKangXi=76.11
23911 CJK UNIFIED IDEOGRAPH-#23911, IRGKangXi=0572.090, RSKangXi=76.11
23912 CJK UNIFIED IDEOGRAPH-#23912, IRGKangXi=0572.100, RSKangXi=76.11
23913 CJK UNIFIED IDEOGRAPH-#23913, IRGKangXi=0572.101, RSKangXi=76.11
23914 CJK UNIFIED IDEOGRAPH-#23914, IRGKangXi=0572.101, RSKangXi=76.11
23915 CJK UNIFIED IDEOGRAPH-#23915, IRGKangXi=0572.101, RSKangXi=76.11
23916 CJK UNIFIED IDEOGRAPH-#23916, IRGKangXi=0572.101, RSKangXi=76.11
23917 CJK UNIFIED IDEOGRAPH-#23917, IRGKangXi=0572.101, RSKangXi=76.11
23918 CJK UNIFIED IDEOGRAPH-#23918, IRGKangXi=0572.170, RSKangXi=76.12
23919 CJK UNIFIED IDEOGRAPH-#23919, IRGKangXi=0572.190, RSKangXi=76.12
2391A CJK UNIFIED IDEOGRAPH-#2391A, IRGKangXi=0572.210, RSKangXi=76.12
2391B CJK UNIFIED IDEOGRAPH-#2391B, IRGKangXi=0572.211, RSKangXi=76.12
2391C CJK UNIFIED IDEOGRAPH-#2391C, IRGKangXi=0572.220, RSKangXi=76.12
2391D CJK UNIFIED IDEOGRAPH-#2391D, IRGKangXi=0572.221, RSKangXi=76.12
2391E CJK UNIFIED IDEOGRAPH-#2391E, IRGKangXi=0572.221, RSKangXi=76.12
2391F CJK UNIFIED IDEOGRAPH-#2391F, IRGKangXi=0572.221, RSKangXi=76.12
23920 CJK UNIFIED IDEOGRAPH-#23920, IRGKangXi=0572.250, RSKangXi=76.13
23921 CJK UNIFIED IDEOGRAPH-#23921, IRGKangXi=0572.260, RSKangXi=76.13
23922 CJK UNIFIED IDEOGRAPH-#23922, IRGKangXi=0572.280, RSKangXi=76.13
23923 CJK UNIFIED IDEOGRAPH-#23923, IRGKangXi=0572.330, RSKangXi=76.13
23924 CJK UNIFIED IDEOGRAPH-#23924, IRGKangXi=0572.331, RSKangXi=76.13
23925 CJK UNIFIED IDEOGRAPH-#23925, IRGKangXi=0572.331, RSKangXi=76.13
23926 CJK UNIFIED IDEOGRAPH-#23926, IRGKangXi=0572.331, RSKangXi=76.13
23927 CJK UNIFIED IDEOGRAPH-#23927, IRGKangXi=0572.331, RSKangXi=76.13
23928 CJK UNIFIED IDEOGRAPH-#23928, IRGKangXi=0572.350, RSKangXi=76.14
23929 CJK UNIFIED IDEOGRAPH-#23929, IRGKangXi=0572.360, RSKangXi=76.14
2392A CJK UNIFIED IDEOGRAPH-#2392A, IRGKangXi=0573.011, RSKangXi=76.14
2392B CJK UNIFIED IDEOGRAPH-#2392B, IRGKangXi=0573.011, RSKangXi=76.14
2392C CJK UNIFIED IDEOGRAPH-#2392C, IRGKangXi=0573.040, RSKangXi=76.15
2392D CJK UNIFIED IDEOGRAPH-#2392D, IRGKangXi=0573.041, RSKangXi=76.15
2392E CJK UNIFIED IDEOGRAPH-#2392E, IRGKangXi=0573.041, RSKangXi=76.15
2392F CJK UNIFIED IDEOGRAPH-#2392F, IRGKangXi=0573.041, RSKangXi=76.15
23930 CJK UNIFIED IDEOGRAPH-#23930, IRGKangXi=0573.041, RSKangXi=76.15
23931 CJK UNIFIED IDEOGRAPH-#23931, IRGKangXi=0573.060, RSKangXi=76.16
23932 CJK UNIFIED IDEOGRAPH-#23932, IRGKangXi=0573.070, RSKangXi=76.16
23933 CJK UNIFIED IDEOGRAPH-#23933, IRGKangXi=0573.071, RSKangXi=76.16
23934 CJK UNIFIED IDEOGRAPH-#23934, IRGKangXi=0573.080, RSKangXi=76.17
23935 CJK UNIFIED IDEOGRAPH-#23935, IRGKangXi=0573.090, RSKangXi=76.17
23936 CJK UNIFIED IDEOGRAPH-#23936, IRGKangXi=0573.100, RSKangXi=76.18
23937 CJK UNIFIED IDEOGRAPH-#23937, IRGKangXi=0573.110, RSKangXi=76.17
23938 CJK UNIFIED IDEOGRAPH-#23938, IRGKangXi=0573.111, RSKangXi=76.17
23939 CJK UNIFIED IDEOGRAPH-#23939, IRGKangXi=0573.140, RSKangXi=76.18
2393A CJK UNIFIED IDEOGRAPH-#2393A, IRGKangXi=0573.160, RSKangXi=76.18
2393B CJK UNIFIED IDEOGRAPH-#2393B, IRGKangXi=0573.170, RSKangXi=76.18
2393C CJK UNIFIED IDEOGRAPH-#2393C, IRGKangXi=0573.180, RSKangXi=76.18
2393D CJK UNIFIED IDEOGRAPH-#2393D, IRGKangXi=0573.191, RSKangXi=76.19
2393E CJK UNIFIED IDEOGRAPH-#2393E, IRGKangXi=0573.191, RSKangXi=76.20
2393F CJK UNIFIED IDEOGRAPH-#2393F, IRGKangXi=0573.200, RSKangXi=76.21
23940 CJK UNIFIED IDEOGRAPH-#23940, IRGKangXi=0573.210, RSKangXi=76.21
23941 CJK UNIFIED IDEOGRAPH-#23941, IRGKangXi=0573.230, RSKangXi=76.22
23942 CJK UNIFIED IDEOGRAPH-#23942, IRGKangXi=0574.010, RSKangXi=77.0
23943 CJK UNIFIED IDEOGRAPH-#23943, IRGKangXi=0574.070, RSKangXi=77.1
23944 CJK UNIFIED IDEOGRAPH-#23944, IRGKangXi=0574.080, RSKangXi=77.1
23945 CJK UNIFIED IDEOGRAPH-#23945, IRGKangXi=0574.110, RSKangXi=77.2
23946 CJK UNIFIED IDEOGRAPH-#23946, IRGKangXi=0574.111, RSKangXi=77.2
23947 CJK UNIFIED IDEOGRAPH-#23947, IRGKangXi=0574.120, RSKangXi=77.3
23948 CJK UNIFIED IDEOGRAPH-#23948, IRGKangXi=0574.130, RSKangXi=77.3
23949 CJK UNIFIED IDEOGRAPH-#23949, IRGKangXi=0574.140, RSKangXi=77.4
2394A CJK UNIFIED IDEOGRAPH-#2394A, IRGKangXi=0575.010, RSKangXi=77.3
2394B CJK UNIFIED IDEOGRAPH-#2394B, IRGKangXi=0575.020, RSKangXi=77.3
2394C CJK UNIFIED IDEOGRAPH-#2394C, IRGKangXi=0575.030, RSKangXi=77.3
2394D CJK UNIFIED IDEOGRAPH-#2394D, IRGKangXi=0575.040, RSKangXi=77.4
2394E CJK UNIFIED IDEOGRAPH-#2394E, IRGKangXi=0575.050, RSKangXi=77.4
2394F CJK UNIFIED IDEOGRAPH-#2394F, IRGKangXi=0575.060, RSKangXi=77.4
23950 CJK UNIFIED IDEOGRAPH-#23950, IRGKangXi=0575.070, RSKangXi=77.4
23951 CJK UNIFIED IDEOGRAPH-#23951, IRGKangXi=0575.080, RSKangXi=77.4
23952 CJK UNIFIED IDEOGRAPH-#23952, IRGKangXi=0576.010, RSKangXi=77.4
23953 CJK UNIFIED IDEOGRAPH-#23953, IRGKangXi=0576.030, RSKangXi=77.4
23954 CJK UNIFIED IDEOGRAPH-#23954, IRGKangXi=0576.050, RSKangXi=77.4
23955 CJK UNIFIED IDEOGRAPH-#23955, IRGKangXi=0576.060, RSKangXi=77.4
23956 CJK UNIFIED IDEOGRAPH-#23956, IRGKangXi=0576.070, RSKangXi=77.4
23957 CJK UNIFIED IDEOGRAPH-#23957, IRGKangXi=0576.080, RSKangXi=77.4
23958 CJK UNIFIED IDEOGRAPH-#23958, IRGKangXi=0576.090, RSKangXi=77.4
23959 CJK UNIFIED IDEOGRAPH-#23959, IRGKangXi=0576.100, RSKangXi=77.4
2395A CJK UNIFIED IDEOGRAPH-#2395A, IRGKangXi=0576.101, RSKangXi=77.4
2395B CJK UNIFIED IDEOGRAPH-#2395B, IRGKangXi=0576.101, RSKangXi=77.4
2395C CJK UNIFIED IDEOGRAPH-#2395C, IRGKangXi=0576.101, RSKangXi=77.4
2395D CJK UNIFIED IDEOGRAPH-#2395D, IRGKangXi=0576.101, RSKangXi=77.4
2395E CJK UNIFIED IDEOGRAPH-#2395E, IRGKangXi=0576.101, RSKangXi=77.4
2395F CJK UNIFIED IDEOGRAPH-#2395F, IRGKangXi=0576.101, RSKangXi=77.4
23960 CJK UNIFIED IDEOGRAPH-#23960, IRGKangXi=0576.101, RSKangXi=77.4
23961 CJK UNIFIED IDEOGRAPH-#23961, IRGKangXi=0576.101, RSKangXi=77.4
23962 CJK UNIFIED IDEOGRAPH-#23962, IRGKangXi=0576.140, RSKangXi=77.5
23963 CJK UNIFIED IDEOGRAPH-#23963, IRGKangXi=0576.150, RSKangXi=77.5
23964 CJK UNIFIED IDEOGRAPH-#23964, IRGKangXi=0576.151, RSKangXi=77.5
23965 CJK UNIFIED IDEOGRAPH-#23965, IRGKangXi=0576.151, RSKangXi=24.6
23966 CJK UNIFIED IDEOGRAPH-#23966, IRGKangXi=0576.170, RSKangXi=77.6
23967 CJK UNIFIED IDEOGRAPH-#23967, IRGKangXi=0576.190, RSKangXi=77.6
23968 CJK UNIFIED IDEOGRAPH-#23968, IRGKangXi=0576.200, RSKangXi=77.6
23969 CJK UNIFIED IDEOGRAPH-#23969, IRGKangXi=0576.210, RSKangXi=77.6
2396A CJK UNIFIED IDEOGRAPH-#2396A, IRGKangXi=0576.220, RSKangXi=77.6
2396B CJK UNIFIED IDEOGRAPH-#2396B, IRGKangXi=0576.230, RSKangXi=77.6
2396C CJK UNIFIED IDEOGRAPH-#2396C, IRGKangXi=0576.240, RSKangXi=77.6
2396D CJK UNIFIED IDEOGRAPH-#2396D, IRGKangXi=0576.250, RSKangXi=77.6
2396E CJK UNIFIED IDEOGRAPH-#2396E, IRGKangXi=0576.251, RSKangXi=77.6
2396F CJK UNIFIED IDEOGRAPH-#2396F, IRGKangXi=0576.251, RSKangXi=77.6
23970 CJK UNIFIED IDEOGRAPH-#23970, IRGKangXi=0576.251, RSKangXi=77.6
23971 CJK UNIFIED IDEOGRAPH-#23971, IRGKangXi=0576.251, RSKangXi=77.6
23972 CJK UNIFIED IDEOGRAPH-#23972, IRGKangXi=0576.251, RSKangXi=59.7
23973 CJK UNIFIED IDEOGRAPH-#23973, IRGKangXi=0576.260, RSKangXi=77.7
23974 CJK UNIFIED IDEOGRAPH-#23974, IRGKangXi=0576.270, RSKangXi=77.7
23975 CJK UNIFIED IDEOGRAPH-#23975, IRGKangXi=0576.271, RSKangXi=77.7
23976 CJK UNIFIED IDEOGRAPH-#23976, IRGKangXi=0576.271, RSKangXi=77.7
23977 CJK UNIFIED IDEOGRAPH-#23977, IRGKangXi=0576.271, RSKangXi=77.7
23978 CJK UNIFIED IDEOGRAPH-#23978, IRGKangXi=0576.271, RSKangXi=77.7
23979 CJK UNIFIED IDEOGRAPH-#23979, IRGKangXi=0576.280, RSKangXi=77.8
2397A CJK UNIFIED IDEOGRAPH-#2397A, IRGKangXi=0576.310, RSKangXi=77.8
2397B CJK UNIFIED IDEOGRAPH-#2397B, IRGKangXi=0576.320, RSKangXi=77.8
2397C CJK UNIFIED IDEOGRAPH-#2397C, IRGKangXi=0576.330, RSKangXi=77.8
2397D CJK UNIFIED IDEOGRAPH-#2397D, IRGKangXi=0576.340, RSKangXi=77.8
2397E CJK UNIFIED IDEOGRAPH-#2397E, IRGKangXi=0576.350, RSKangXi=77.8
2397F CJK UNIFIED IDEOGRAPH-#2397F, IRGKangXi=0576.360, RSKangXi=77.8
23980 CJK UNIFIED IDEOGRAPH-#23980, IRGKangXi=0576.370, RSKangXi=77.8
23981 CJK UNIFIED IDEOGRAPH-#23981, IRGKangXi=0576.390, RSKangXi=77.8
23982 CJK UNIFIED IDEOGRAPH-#23982, IRGKangXi=0576.400, RSKangXi=77.8
23983 CJK UNIFIED IDEOGRAPH-#23983, IRGKangXi=0576.410, RSKangXi=77.8
23984 CJK UNIFIED IDEOGRAPH-#23984, IRGKangXi=0576.420, RSKangXi=77.8
23985 CJK UNIFIED IDEOGRAPH-#23985, IRGKangXi=0576.421, RSKangXi=77.8
23986 CJK UNIFIED IDEOGRAPH-#23986, IRGKangXi=0576.421, RSKangXi=77.8
23987 CJK UNIFIED IDEOGRAPH-#23987, IRGKangXi=0577.050, RSKangXi=77.9
23988 CJK UNIFIED IDEOGRAPH-#23988, IRGKangXi=0577.060, RSKangXi=77.9
23989 CJK UNIFIED IDEOGRAPH-#23989, IRGKangXi=0577.070, RSKangXi=77.9
2398A CJK UNIFIED IDEOGRAPH-#2398A, IRGKangXi=0577.071, RSKangXi=77.9
2398B CJK UNIFIED IDEOGRAPH-#2398B, IRGKangXi=0577.071, RSKangXi=211.0
2398C CJK UNIFIED IDEOGRAPH-#2398C, IRGKangXi=0577.071, RSKangXi=77.9
2398D CJK UNIFIED IDEOGRAPH-#2398D, IRGKangXi=0577.071, RSKangXi=77.9
2398E CJK UNIFIED IDEOGRAPH-#2398E, IRGKangXi=0577.071, RSKangXi=77.9
2398F CJK UNIFIED IDEOGRAPH-#2398F, IRGKangXi=0577.071, RSKangXi=56.10
23990 CJK UNIFIED IDEOGRAPH-#23990, IRGKangXi=0577.081, RSKangXi=77.10
23991 CJK UNIFIED IDEOGRAPH-#23991, IRGKangXi=0577.081, RSKangXi=77.10
23992 CJK UNIFIED IDEOGRAPH-#23992, IRGKangXi=0577.081, RSKangXi=77.10
23993 CJK UNIFIED IDEOGRAPH-#23993, IRGKangXi=0577.081, RSKangXi=77.10
23994 CJK UNIFIED IDEOGRAPH-#23994, IRGKangXi=0577.100, RSKangXi=77.11
23995 CJK UNIFIED IDEOGRAPH-#23995, IRGKangXi=0577.110, RSKangXi=77.11
23996 CJK UNIFIED IDEOGRAPH-#23996, IRGKangXi=0577.120, RSKangXi=77.11
23997 CJK UNIFIED IDEOGRAPH-#23997, IRGKangXi=0577.130, RSKangXi=77.11
23998 CJK UNIFIED IDEOGRAPH-#23998, IRGKangXi=0577.131, RSKangXi=77.11
23999 CJK UNIFIED IDEOGRAPH-#23999, IRGKangXi=0577.131, RSKangXi=77.11
2399A CJK UNIFIED IDEOGRAPH-#2399A, IRGKangXi=0577.131, RSKangXi=77.11
2399B CJK UNIFIED IDEOGRAPH-#2399B, IRGKangXi=0577.131, RSKangXi=77.11
2399C CJK UNIFIED IDEOGRAPH-#2399C, IRGKangXi=0577.160, RSKangXi=77.12
2399D CJK UNIFIED IDEOGRAPH-#2399D, IRGKangXi=0578.010, RSKangXi=77.12
2399E CJK UNIFIED IDEOGRAPH-#2399E, IRGKangXi=0578.020, RSKangXi=77.12
2399F CJK UNIFIED IDEOGRAPH-#2399F, IRGKangXi=0578.021, RSKangXi=77.12
239A0 CJK UNIFIED IDEOGRAPH-#239A0, IRGKangXi=0578.021, RSKangXi=77.12
239A1 CJK UNIFIED IDEOGRAPH-#239A1, IRGKangXi=0578.030, RSKangXi=77.13
239A2 CJK UNIFIED IDEOGRAPH-#239A2, IRGKangXi=0578.040, RSKangXi=77.13
239A3 CJK UNIFIED IDEOGRAPH-#239A3, IRGKangXi=0578.050, RSKangXi=77.13
239A4 CJK UNIFIED IDEOGRAPH-#239A4, IRGKangXi=0578.051, RSKangXi=77.13
239A5 CJK UNIFIED IDEOGRAPH-#239A5, IRGKangXi=0578.051, RSKangXi=77.13
239A6 CJK UNIFIED IDEOGRAPH-#239A6, IRGKangXi=0578.090, RSKangXi=77.14
239A7 CJK UNIFIED IDEOGRAPH-#239A7, IRGKangXi=0578.100, RSKangXi=77.14
239A8 CJK UNIFIED IDEOGRAPH-#239A8, IRGKangXi=0578.110, RSKangXi=77.14
239A9 CJK UNIFIED IDEOGRAPH-#239A9, IRGKangXi=0578.111, RSKangXi=77.14
239AA CJK UNIFIED IDEOGRAPH-#239AA, IRGKangXi=0578.111, RSKangXi=77.14
239AB CJK UNIFIED IDEOGRAPH-#239AB, IRGKangXi=0578.111, RSKangXi=77.14
239AC CJK UNIFIED IDEOGRAPH-#239AC, IRGKangXi=0578.111, RSKangXi=77.15
239AD CJK UNIFIED IDEOGRAPH-#239AD, IRGKangXi=0578.111, RSKangXi=46.16
239AE CJK UNIFIED IDEOGRAPH-#239AE, IRGKangXi=0578.111, RSKangXi=77.17
239AF CJK UNIFIED IDEOGRAPH-#239AF, IRGKangXi=0578.120, RSKangXi=77.18
239B0 CJK UNIFIED IDEOGRAPH-#239B0, IRGKangXi=0578.121, RSKangXi=77.18
239B1 CJK UNIFIED IDEOGRAPH-#239B1, IRGKangXi=0578.130, RSKangXi=77.19
239B2 CJK UNIFIED IDEOGRAPH-#239B2, IRGKangXi=0578.131, RSKangXi=77.19
239B3 CJK UNIFIED IDEOGRAPH-#239B3, IRGKangXi=0578.140, RSKangXi=77.20
239B4 CJK UNIFIED IDEOGRAPH-#239B4, IRGKangXi=0578.141, RSKangXi=77.20
239B5 CJK UNIFIED IDEOGRAPH-#239B5, IRGKangXi=0578.170, RSKangXi=78.0
239B6 CJK UNIFIED IDEOGRAPH-#239B6, IRGKangXi=0578.190, RSKangXi=78.0
239B7 CJK UNIFIED IDEOGRAPH-#239B7, IRGKangXi=0578.200, RSKangXi=78.1
239B8 CJK UNIFIED IDEOGRAPH-#239B8, IRGKangXi=0578.250, RSKangXi=78.2
239B9 CJK UNIFIED IDEOGRAPH-#239B9, IRGKangXi=0578.260, RSKangXi=78.2
239BA CJK UNIFIED IDEOGRAPH-#239BA, IRGKangXi=0578.270, RSKangXi=78.2
239BB CJK UNIFIED IDEOGRAPH-#239BB, IRGKangXi=0579.010, RSKangXi=78.2
239BC CJK UNIFIED IDEOGRAPH-#239BC, IRGKangXi=0579.020, RSKangXi=78.2
239BD CJK UNIFIED IDEOGRAPH-#239BD, IRGKangXi=0579.030, RSKangXi=78.2
239BE CJK UNIFIED IDEOGRAPH-#239BE, IRGKangXi=0579.031, RSKangXi=78.2
239BF CJK UNIFIED IDEOGRAPH-#239BF, IRGKangXi=0579.040, RSKangXi=78.3
239C0 CJK UNIFIED IDEOGRAPH-#239C0, IRGKangXi=0579.050, RSKangXi=78.3
239C1 CJK UNIFIED IDEOGRAPH-#239C1, IRGKangXi=0579.060, RSKangXi=78.3
239C2 CJK UNIFIED IDEOGRAPH-#239C2, IRGKangXi=0579.070, RSKangXi=78.3, Def{(Cant.) untidy}
239C3 CJK UNIFIED IDEOGRAPH-#239C3, IRGKangXi=0579.080, RSKangXi=78.3
239C4 CJK UNIFIED IDEOGRAPH-#239C4, IRGKangXi=0579.090, RSKangXi=78.3
239C5 CJK UNIFIED IDEOGRAPH-#239C5, IRGKangXi=0579.100, RSKangXi=78.3
239C6 CJK UNIFIED IDEOGRAPH-#239C6, IRGKangXi=0579.110, RSKangXi=78.3
239C7 CJK UNIFIED IDEOGRAPH-#239C7, IRGKangXi=0579.120, RSKangXi=78.3
239C8 CJK UNIFIED IDEOGRAPH-#239C8, IRGKangXi=0579.121, RSKangXi=78.3
239C9 CJK UNIFIED IDEOGRAPH-#239C9, IRGKangXi=0579.140, RSKangXi=78.4
239CA CJK UNIFIED IDEOGRAPH-#239CA, IRGKangXi=0579.170, RSKangXi=78.4
239CB CJK UNIFIED IDEOGRAPH-#239CB, IRGKangXi=0579.180, RSKangXi=78.4
239CC CJK UNIFIED IDEOGRAPH-#239CC, IRGKangXi=0579.190, RSKangXi=78.4
239CD CJK UNIFIED IDEOGRAPH-#239CD, IRGKangXi=0579.220, RSKangXi=78.4
239CE CJK UNIFIED IDEOGRAPH-#239CE, IRGKangXi=0579.230, RSKangXi=78.4
239CF CJK UNIFIED IDEOGRAPH-#239CF, IRGKangXi=0579.240, RSKangXi=78.4
239D0 CJK UNIFIED IDEOGRAPH-#239D0, IRGKangXi=0579.250, RSKangXi=78.4
239D1 CJK UNIFIED IDEOGRAPH-#239D1, IRGKangXi=0579.260, RSKangXi=78.4
239D2 CJK UNIFIED IDEOGRAPH-#239D2, IRGKangXi=0579.280, RSKangXi=78.4
239D3 CJK UNIFIED IDEOGRAPH-#239D3, IRGKangXi=0579.290, RSKangXi=78.4
239D4 CJK UNIFIED IDEOGRAPH-#239D4, IRGKangXi=0579.300, RSKangXi=78.4
239D5 CJK UNIFIED IDEOGRAPH-#239D5, IRGKangXi=0579.310, RSKangXi=78.4
239D6 CJK UNIFIED IDEOGRAPH-#239D6, IRGKangXi=0579.320, RSKangXi=78.4
239D7 CJK UNIFIED IDEOGRAPH-#239D7, IRGKangXi=0579.331, RSKangXi=78.4
239D8 CJK UNIFIED IDEOGRAPH-#239D8, IRGKangXi=0579.331, RSKangXi=78.4
239D9 CJK UNIFIED IDEOGRAPH-#239D9, IRGKangXi=0579.331, RSKangXi=78.4
239DA CJK UNIFIED IDEOGRAPH-#239DA, IRGKangXi=0579.331, RSKangXi=78.4
239DB CJK UNIFIED IDEOGRAPH-#239DB, IRGKangXi=0579.331, RSKangXi=78.4
239DC CJK UNIFIED IDEOGRAPH-#239DC, IRGKangXi=0579.331, RSKangXi=78.4
239DD CJK UNIFIED IDEOGRAPH-#239DD, IRGKangXi=0579.400, RSKangXi=78.5
239DE CJK UNIFIED IDEOGRAPH-#239DE, IRGKangXi=0579.430, RSKangXi=78.5
239DF CJK UNIFIED IDEOGRAPH-#239DF, IRGKangXi=0579.440, RSKangXi=78.5
239E0 CJK UNIFIED IDEOGRAPH-#239E0, IRGKangXi=0579.480, RSKangXi=78.5
239E1 CJK UNIFIED IDEOGRAPH-#239E1, IRGKangXi=0579.490, RSKangXi=78.5
239E2 CJK UNIFIED IDEOGRAPH-#239E2, IRGKangXi=0579.500, RSKangXi=78.5
239E3 CJK UNIFIED IDEOGRAPH-#239E3, IRGKangXi=0579.520, RSKangXi=78.5
239E4 CJK UNIFIED IDEOGRAPH-#239E4, IRGKangXi=0579.530, RSKangXi=78.5
239E5 CJK UNIFIED IDEOGRAPH-#239E5, IRGKangXi=0579.550, RSKangXi=78.5
239E6 CJK UNIFIED IDEOGRAPH-#239E6, IRGKangXi=0579.560, RSKangXi=78.5
239E7 CJK UNIFIED IDEOGRAPH-#239E7, IRGKangXi=0579.570, RSKangXi=78.5
239E8 CJK UNIFIED IDEOGRAPH-#239E8, IRGKangXi=0579.580, RSKangXi=78.5
239E9 CJK UNIFIED IDEOGRAPH-#239E9, IRGKangXi=0579.590, RSKangXi=78.5
239EA CJK UNIFIED IDEOGRAPH-#239EA, IRGKangXi=0580.020, RSKangXi=78.5
239EB CJK UNIFIED IDEOGRAPH-#239EB, IRGKangXi=0580.030, RSKangXi=78.5
239EC CJK UNIFIED IDEOGRAPH-#239EC, IRGKangXi=0580.050, RSKangXi=78.5
239ED CJK UNIFIED IDEOGRAPH-#239ED, IRGKangXi=0580.060, RSKangXi=78.5
239EE CJK UNIFIED IDEOGRAPH-#239EE, IRGKangXi=0580.070, RSKangXi=78.5
239EF CJK UNIFIED IDEOGRAPH-#239EF, IRGKangXi=0580.071, RSKangXi=78.5
239F0 CJK UNIFIED IDEOGRAPH-#239F0, IRGKangXi=0580.080, RSKangXi=78.5
239F1 CJK UNIFIED IDEOGRAPH-#239F1, IRGKangXi=0580.081, RSKangXi=78.5
239F2 CJK UNIFIED IDEOGRAPH-#239F2, IRGKangXi=0580.090, RSKangXi=78.6
239F3 CJK UNIFIED IDEOGRAPH-#239F3, IRGKangXi=0580.100, RSKangXi=78.6
239F4 CJK UNIFIED IDEOGRAPH-#239F4, IRGKangXi=0580.110, RSKangXi=78.6
239F5 CJK UNIFIED IDEOGRAPH-#239F5, IRGKangXi=0580.130, RSKangXi=78.6
239F6 CJK UNIFIED IDEOGRAPH-#239F6, IRGKangXi=0580.140, RSKangXi=78.6
239F7 CJK UNIFIED IDEOGRAPH-#239F7, IRGKangXi=0580.150, RSKangXi=78.6
239F8 CJK UNIFIED IDEOGRAPH-#239F8, IRGKangXi=0580.170, RSKangXi=78.6
239F9 CJK UNIFIED IDEOGRAPH-#239F9, IRGKangXi=0580.180, RSKangXi=78.6
239FA CJK UNIFIED IDEOGRAPH-#239FA, IRGKangXi=0580.190, RSKangXi=78.6
239FB CJK UNIFIED IDEOGRAPH-#239FB, IRGKangXi=0580.200, RSKangXi=78.6
239FC CJK UNIFIED IDEOGRAPH-#239FC, IRGKangXi=0580.210, RSKangXi=78.6
239FD CJK UNIFIED IDEOGRAPH-#239FD, IRGKangXi=0580.230, RSKangXi=78.6
239FE CJK UNIFIED IDEOGRAPH-#239FE, IRGKangXi=0580.240, RSKangXi=78.6
239FF CJK UNIFIED IDEOGRAPH-#239FF, IRGKangXi=0580.260, RSKangXi=78.6
23A00 CJK UNIFIED IDEOGRAPH-#23A00, IRGKangXi=0580.270, RSKangXi=78.6
23A01 CJK UNIFIED IDEOGRAPH-#23A01, IRGKangXi=0580.290, RSKangXi=78.6
23A02 CJK UNIFIED IDEOGRAPH-#23A02, IRGKangXi=0580.291, RSKangXi=78.6
23A03 CJK UNIFIED IDEOGRAPH-#23A03, IRGKangXi=0580.291, RSKangXi=78.6
23A04 CJK UNIFIED IDEOGRAPH-#23A04, IRGKangXi=0580.291, RSKangXi=78.6
23A05 CJK UNIFIED IDEOGRAPH-#23A05, IRGKangXi=0580.300, RSKangXi=78.7
23A06 CJK UNIFIED IDEOGRAPH-#23A06, IRGKangXi=0580.310, RSKangXi=78.7
23A07 CJK UNIFIED IDEOGRAPH-#23A07, IRGKangXi=0580.330, RSKangXi=78.7
23A08 CJK UNIFIED IDEOGRAPH-#23A08, IRGKangXi=0580.350, RSKangXi=78.7
23A09 CJK UNIFIED IDEOGRAPH-#23A09, IRGKangXi=0580.360, RSKangXi=78.7
23A0A CJK UNIFIED IDEOGRAPH-#23A0A, IRGKangXi=0580.370, RSKangXi=78.7
23A0B CJK UNIFIED IDEOGRAPH-#23A0B, IRGKangXi=0581.010, RSKangXi=78.7
23A0C CJK UNIFIED IDEOGRAPH-#23A0C, IRGKangXi=0581.030, RSKangXi=78.7
23A0D CJK UNIFIED IDEOGRAPH-#23A0D, IRGKangXi=0581.060, RSKangXi=78.7
23A0E CJK UNIFIED IDEOGRAPH-#23A0E, IRGKangXi=0581.100, RSKangXi=78.7
23A0F CJK UNIFIED IDEOGRAPH-#23A0F, IRGKangXi=0581.110, RSKangXi=78.7
23A10 CJK UNIFIED IDEOGRAPH-#23A10, IRGKangXi=0581.120, RSKangXi=78.7
23A11 CJK UNIFIED IDEOGRAPH-#23A11, IRGKangXi=0581.130, RSKangXi=78.7
23A12 CJK UNIFIED IDEOGRAPH-#23A12, IRGKangXi=0581.131, RSKangXi=78.7
23A13 CJK UNIFIED IDEOGRAPH-#23A13, IRGKangXi=0581.131, RSKangXi=78.7
23A14 CJK UNIFIED IDEOGRAPH-#23A14, IRGKangXi=0581.131, RSKangXi=78.7
23A15 CJK UNIFIED IDEOGRAPH-#23A15, IRGKangXi=0581.131, RSKangXi=78.7
23A16 CJK UNIFIED IDEOGRAPH-#23A16, IRGKangXi=0581.140, RSKangXi=78.8
23A17 CJK UNIFIED IDEOGRAPH-#23A17, IRGKangXi=0581.160, RSKangXi=78.8
23A18 CJK UNIFIED IDEOGRAPH-#23A18, IRGKangXi=0581.170, RSKangXi=78.8
23A19 CJK UNIFIED IDEOGRAPH-#23A19, IRGKangXi=0581.180, RSKangXi=78.8
23A1A CJK UNIFIED IDEOGRAPH-#23A1A, IRGKangXi=0581.190, RSKangXi=78.8
23A1B CJK UNIFIED IDEOGRAPH-#23A1B, IRGKangXi=0581.210, RSKangXi=78.8
23A1C CJK UNIFIED IDEOGRAPH-#23A1C, IRGKangXi=0581.220, RSKangXi=78.8
23A1D CJK UNIFIED IDEOGRAPH-#23A1D, IRGKangXi=0581.230, RSKangXi=78.8
23A1E CJK UNIFIED IDEOGRAPH-#23A1E, IRGKangXi=0581.240, RSKangXi=78.8
23A1F CJK UNIFIED IDEOGRAPH-#23A1F, IRGKangXi=0581.250, RSKangXi=78.8
23A20 CJK UNIFIED IDEOGRAPH-#23A20, IRGKangXi=0581.260, RSKangXi=78.8
23A21 CJK UNIFIED IDEOGRAPH-#23A21, IRGKangXi=0581.270, RSKangXi=78.8
23A22 CJK UNIFIED IDEOGRAPH-#23A22, IRGKangXi=0581.280, RSKangXi=78.8
23A23 CJK UNIFIED IDEOGRAPH-#23A23, IRGKangXi=0581.300, RSKangXi=78.8
23A24 CJK UNIFIED IDEOGRAPH-#23A24, IRGKangXi=0581.310, RSKangXi=78.8
23A25 CJK UNIFIED IDEOGRAPH-#23A25, IRGKangXi=0581.340, RSKangXi=78.8
23A26 CJK UNIFIED IDEOGRAPH-#23A26, IRGKangXi=0582.040, RSKangXi=78.8
23A27 CJK UNIFIED IDEOGRAPH-#23A27, IRGKangXi=0582.041, RSKangXi=78.8
23A28 CJK UNIFIED IDEOGRAPH-#23A28, IRGKangXi=0582.041, RSKangXi=78.8
23A29 CJK UNIFIED IDEOGRAPH-#23A29, IRGKangXi=0582.041, RSKangXi=78.8
23A2A CJK UNIFIED IDEOGRAPH-#23A2A, IRGKangXi=0582.041, RSKangXi=78.8
23A2B CJK UNIFIED IDEOGRAPH-#23A2B, IRGKangXi=0582.041, RSKangXi=78.8
23A2C CJK UNIFIED IDEOGRAPH-#23A2C, IRGKangXi=0582.041, RSKangXi=78.8
23A2D CJK UNIFIED IDEOGRAPH-#23A2D, IRGKangXi=0582.041, RSKangXi=78.8
23A2E CJK UNIFIED IDEOGRAPH-#23A2E, IRGKangXi=0582.041, RSKangXi=78.8
23A2F CJK UNIFIED IDEOGRAPH-#23A2F, IRGKangXi=0582.041, RSKangXi=78.8
23A30 CJK UNIFIED IDEOGRAPH-#23A30, IRGKangXi=0582.041, RSKangXi=78.8
23A31 CJK UNIFIED IDEOGRAPH-#23A31, IRGKangXi=0582.070, RSKangXi=78.9
23A32 CJK UNIFIED IDEOGRAPH-#23A32, IRGKangXi=0582.090, RSKangXi=78.9
23A33 CJK UNIFIED IDEOGRAPH-#23A33, IRGKangXi=0582.110, RSKangXi=78.9
23A34 CJK UNIFIED IDEOGRAPH-#23A34, IRGKangXi=0582.130, RSKangXi=78.9
23A35 CJK UNIFIED IDEOGRAPH-#23A35, IRGKangXi=0582.150, RSKangXi=78.9
23A36 CJK UNIFIED IDEOGRAPH-#23A36, IRGKangXi=0582.160, RSKangXi=78.9
23A37 CJK UNIFIED IDEOGRAPH-#23A37, IRGKangXi=0582.170, RSKangXi=78.9
23A38 CJK UNIFIED IDEOGRAPH-#23A38, IRGKangXi=0582.180, RSKangXi=78.9
23A39 CJK UNIFIED IDEOGRAPH-#23A39, IRGKangXi=0582.190, RSKangXi=78.9
23A3A CJK UNIFIED IDEOGRAPH-#23A3A, IRGKangXi=0582.200, RSKangXi=78.9
23A3B CJK UNIFIED IDEOGRAPH-#23A3B, IRGKangXi=0582.210, RSKangXi=78.9
23A3C CJK UNIFIED IDEOGRAPH-#23A3C, IRGKangXi=0582.211, RSKangXi=78.9
23A3D CJK UNIFIED IDEOGRAPH-#23A3D, IRGKangXi=0582.211, RSKangXi=78.9
23A3E CJK UNIFIED IDEOGRAPH-#23A3E, IRGKangXi=0582.211, RSKangXi=78.9
23A3F CJK UNIFIED IDEOGRAPH-#23A3F, IRGKangXi=0582.211, RSKangXi=78.9
23A40 CJK UNIFIED IDEOGRAPH-#23A40, IRGKangXi=0582.211, RSKangXi=78.9
23A41 CJK UNIFIED IDEOGRAPH-#23A41, IRGKangXi=0582.211, RSKangXi=78.9
23A42 CJK UNIFIED IDEOGRAPH-#23A42, IRGKangXi=0582.211, RSKangXi=78.9
23A43 CJK UNIFIED IDEOGRAPH-#23A43, IRGKangXi=0582.211, RSKangXi=78.9
23A44 CJK UNIFIED IDEOGRAPH-#23A44, IRGKangXi=0582.270, RSKangXi=78.10
23A45 CJK UNIFIED IDEOGRAPH-#23A45, IRGKangXi=0582.280, RSKangXi=78.10
23A46 CJK UNIFIED IDEOGRAPH-#23A46, IRGKangXi=0582.320, RSKangXi=78.10
23A47 CJK UNIFIED IDEOGRAPH-#23A47, IRGKangXi=0582.330, RSKangXi=78.10
23A48 CJK UNIFIED IDEOGRAPH-#23A48, IRGKangXi=0582.340, RSKangXi=78.10
23A49 CJK UNIFIED IDEOGRAPH-#23A49, IRGKangXi=0582.350, RSKangXi=78.10
23A4A CJK UNIFIED IDEOGRAPH-#23A4A, IRGKangXi=0582.351, RSKangXi=78.10
23A4B CJK UNIFIED IDEOGRAPH-#23A4B, IRGKangXi=0582.351, RSKangXi=78.10
23A4C CJK UNIFIED IDEOGRAPH-#23A4C, IRGKangXi=0582.351, RSKangXi=78.10
23A4D CJK UNIFIED IDEOGRAPH-#23A4D, IRGKangXi=0582.360, RSKangXi=78.11
23A4E CJK UNIFIED IDEOGRAPH-#23A4E, IRGKangXi=0583.020, RSKangXi=78.11
23A4F CJK UNIFIED IDEOGRAPH-#23A4F, IRGKangXi=0583.030, RSKangXi=78.11
23A50 CJK UNIFIED IDEOGRAPH-#23A50, IRGKangXi=0583.040, RSKangXi=78.11
23A51 CJK UNIFIED IDEOGRAPH-#23A51, IRGKangXi=0583.050, RSKangXi=78.11
23A52 CJK UNIFIED IDEOGRAPH-#23A52, IRGKangXi=0583.070, RSKangXi=78.11
23A53 CJK UNIFIED IDEOGRAPH-#23A53, IRGKangXi=0583.080, RSKangXi=78.11
23A54 CJK UNIFIED IDEOGRAPH-#23A54, IRGKangXi=0583.090, RSKangXi=78.11
23A55 CJK UNIFIED IDEOGRAPH-#23A55, IRGKangXi=0583.110, RSKangXi=78.11
23A56 CJK UNIFIED IDEOGRAPH-#23A56, IRGKangXi=0583.120, RSKangXi=78.11
23A57 CJK UNIFIED IDEOGRAPH-#23A57, IRGKangXi=0583.130, RSKangXi=78.11
23A58 CJK UNIFIED IDEOGRAPH-#23A58, IRGKangXi=0583.141, RSKangXi=78.11
23A59 CJK UNIFIED IDEOGRAPH-#23A59, IRGKangXi=0583.141, RSKangXi=78.11
23A5A CJK UNIFIED IDEOGRAPH-#23A5A, IRGKangXi=0583.141, RSKangXi=78.11
23A5B CJK UNIFIED IDEOGRAPH-#23A5B, IRGKangXi=0583.141, RSKangXi=78.11
23A5C CJK UNIFIED IDEOGRAPH-#23A5C, IRGKangXi=0583.141, RSKangXi=78.11
23A5D CJK UNIFIED IDEOGRAPH-#23A5D, IRGKangXi=0583.160, RSKangXi=78.12
23A5E CJK UNIFIED IDEOGRAPH-#23A5E, IRGKangXi=0583.170, RSKangXi=78.12
23A5F CJK UNIFIED IDEOGRAPH-#23A5F, IRGKangXi=0583.200, RSKangXi=78.12
23A60 CJK UNIFIED IDEOGRAPH-#23A60, IRGKangXi=0583.210, RSKangXi=78.12
23A61 CJK UNIFIED IDEOGRAPH-#23A61, IRGKangXi=0583.220, RSKangXi=78.12
23A62 CJK UNIFIED IDEOGRAPH-#23A62, IRGKangXi=0583.230, RSKangXi=78.12
23A63 CJK UNIFIED IDEOGRAPH-#23A63, IRGKangXi=0583.280, RSKangXi=78.12
23A64 CJK UNIFIED IDEOGRAPH-#23A64, IRGKangXi=0583.301, RSKangXi=78.12
23A65 CJK UNIFIED IDEOGRAPH-#23A65, IRGKangXi=0583.301, RSKangXi=78.12
23A66 CJK UNIFIED IDEOGRAPH-#23A66, IRGKangXi=0583.301, RSKangXi=78.12
23A67 CJK UNIFIED IDEOGRAPH-#23A67, IRGKangXi=0583.301, RSKangXi=78.12
23A68 CJK UNIFIED IDEOGRAPH-#23A68, IRGKangXi=0583.310, RSKangXi=78.13
23A69 CJK UNIFIED IDEOGRAPH-#23A69, IRGKangXi=0583.340, RSKangXi=78.13
23A6A CJK UNIFIED IDEOGRAPH-#23A6A, IRGKangXi=0583.350, RSKangXi=78.13
23A6B CJK UNIFIED IDEOGRAPH-#23A6B, IRGKangXi=0583.370, RSKangXi=78.13
23A6C CJK UNIFIED IDEOGRAPH-#23A6C, IRGKangXi=0583.390, RSKangXi=78.13
23A6D CJK UNIFIED IDEOGRAPH-#23A6D, IRGKangXi=0583.400, RSKangXi=78.13
23A6E CJK UNIFIED IDEOGRAPH-#23A6E, IRGKangXi=0583.401, RSKangXi=78.13
23A6F CJK UNIFIED IDEOGRAPH-#23A6F, IRGKangXi=0583.410, RSKangXi=78.14
23A70 CJK UNIFIED IDEOGRAPH-#23A70, IRGKangXi=0583.420, RSKangXi=78.14
23A71 CJK UNIFIED IDEOGRAPH-#23A71, IRGKangXi=0583.430, RSKangXi=78.14
23A72 CJK UNIFIED IDEOGRAPH-#23A72, IRGKangXi=0583.450, RSKangXi=78.14
23A73 CJK UNIFIED IDEOGRAPH-#23A73, IRGKangXi=0583.460, RSKangXi=78.14
23A74 CJK UNIFIED IDEOGRAPH-#23A74, IRGKangXi=0584.010, RSKangXi=78.14
23A75 CJK UNIFIED IDEOGRAPH-#23A75, IRGKangXi=0584.011, RSKangXi=78.14
23A76 CJK UNIFIED IDEOGRAPH-#23A76, IRGKangXi=0584.011, RSKangXi=78.14
23A77 CJK UNIFIED IDEOGRAPH-#23A77, IRGKangXi=0584.040, RSKangXi=78.15
23A78 CJK UNIFIED IDEOGRAPH-#23A78, IRGKangXi=0584.041, RSKangXi=78.15
23A79 CJK UNIFIED IDEOGRAPH-#23A79, IRGKangXi=0584.060, RSKangXi=78.16
23A7A CJK UNIFIED IDEOGRAPH-#23A7A, IRGKangXi=0584.080, RSKangXi=78.16
23A7B CJK UNIFIED IDEOGRAPH-#23A7B, IRGKangXi=0584.090, RSKangXi=78.16
23A7C CJK UNIFIED IDEOGRAPH-#23A7C, IRGKangXi=0584.100, RSKangXi=78.17
23A7D CJK UNIFIED IDEOGRAPH-#23A7D, IRGKangXi=0584.121, RSKangXi=78.17
23A7E CJK UNIFIED IDEOGRAPH-#23A7E, IRGKangXi=0584.130, RSKangXi=78.18
23A7F CJK UNIFIED IDEOGRAPH-#23A7F, IRGKangXi=0584.150, RSKangXi=78.19
23A80 CJK UNIFIED IDEOGRAPH-#23A80, IRGKangXi=0584.160, RSKangXi=78.19
23A81 CJK UNIFIED IDEOGRAPH-#23A81, IRGKangXi=0584.161, RSKangXi=78.19
23A82 CJK UNIFIED IDEOGRAPH-#23A82, IRGKangXi=0584.210, RSKangXi=79.4
23A83 CJK UNIFIED IDEOGRAPH-#23A83, IRGKangXi=0584.211, RSKangXi=79.4
23A84 CJK UNIFIED IDEOGRAPH-#23A84, IRGKangXi=0584.211, RSKangXi=79.4
23A85 CJK UNIFIED IDEOGRAPH-#23A85, IRGKangXi=0584.240, RSKangXi=79.5
23A86 CJK UNIFIED IDEOGRAPH-#23A86, IRGKangXi=0584.250, RSKangXi=79.5
23A87 CJK UNIFIED IDEOGRAPH-#23A87, IRGKangXi=0584.261, RSKangXi=79.5
23A88 CJK UNIFIED IDEOGRAPH-#23A88, IRGKangXi=0584.270, RSKangXi=79.6
23A89 CJK UNIFIED IDEOGRAPH-#23A89, IRGKangXi=0585.021, RSKangXi=79.6
23A8A CJK UNIFIED IDEOGRAPH-#23A8A, IRGKangXi=0585.021, RSKangXi=79.6
23A8B CJK UNIFIED IDEOGRAPH-#23A8B, IRGKangXi=0585.030, RSKangXi=79.7
23A8C CJK UNIFIED IDEOGRAPH-#23A8C, IRGKangXi=0585.040, RSKangXi=79.7
23A8D CJK UNIFIED IDEOGRAPH-#23A8D, IRGKangXi=0585.080, RSKangXi=79.7
23A8E CJK UNIFIED IDEOGRAPH-#23A8E, IRGKangXi=0585.090, RSKangXi=79.7
23A8F CJK UNIFIED IDEOGRAPH-#23A8F, IRGKangXi=0585.100, RSKangXi=79.7
23A90 CJK UNIFIED IDEOGRAPH-#23A90, IRGKangXi=0586.010, RSKangXi=79.7
23A91 CJK UNIFIED IDEOGRAPH-#23A91, IRGKangXi=0586.011, RSKangXi=79.7
23A92 CJK UNIFIED IDEOGRAPH-#23A92, IRGKangXi=0586.011, RSKangXi=79.7
23A93 CJK UNIFIED IDEOGRAPH-#23A93, IRGKangXi=0586.011, RSKangXi=79.7
23A94 CJK UNIFIED IDEOGRAPH-#23A94, IRGKangXi=0586.011, RSKangXi=79.7
23A95 CJK UNIFIED IDEOGRAPH-#23A95, IRGKangXi=0586.011, RSKangXi=79.7
23A96 CJK UNIFIED IDEOGRAPH-#23A96, IRGKangXi=0586.011, RSKangXi=79.7
23A97 CJK UNIFIED IDEOGRAPH-#23A97, IRGKangXi=0586.011, RSKangXi=79.7
23A98 CJK UNIFIED IDEOGRAPH-#23A98, IRGKangXi=0586.011, RSKangXi=79.7
23A99 CJK UNIFIED IDEOGRAPH-#23A99, IRGKangXi=0586.070, RSKangXi=79.8
23A9A CJK UNIFIED IDEOGRAPH-#23A9A, IRGKangXi=0586.071, RSKangXi=79.8
23A9B CJK UNIFIED IDEOGRAPH-#23A9B, IRGKangXi=0586.071, RSKangXi=79.8
23A9C CJK UNIFIED IDEOGRAPH-#23A9C, IRGKangXi=0586.071, RSKangXi=79.8
23A9D CJK UNIFIED IDEOGRAPH-#23A9D, IRGKangXi=0586.071, RSKangXi=79.8
23A9E CJK UNIFIED IDEOGRAPH-#23A9E, IRGKangXi=0586.071, RSKangXi=79.8
23A9F CJK UNIFIED IDEOGRAPH-#23A9F, IRGKangXi=0586.071, RSKangXi=79.8
23AA0 CJK UNIFIED IDEOGRAPH-#23AA0, IRGKangXi=0586.100, RSKangXi=79.9, Def{to attack}
23AA1 CJK UNIFIED IDEOGRAPH-#23AA1, IRGKangXi=0586.110, RSKangXi=79.9
23AA2 CJK UNIFIED IDEOGRAPH-#23AA2, IRGKangXi=0587.010, RSKangXi=79.9
23AA3 CJK UNIFIED IDEOGRAPH-#23AA3, IRGKangXi=0587.020, RSKangXi=79.9
23AA4 CJK UNIFIED IDEOGRAPH-#23AA4, IRGKangXi=0587.030, RSKangXi=79.9
23AA5 CJK UNIFIED IDEOGRAPH-#23AA5, IRGKangXi=0587.031, RSKangXi=79.9
23AA6 CJK UNIFIED IDEOGRAPH-#23AA6, IRGKangXi=0587.031, RSKangXi=79.9
23AA7 CJK UNIFIED IDEOGRAPH-#23AA7, IRGKangXi=0587.031, RSKangXi=79.9
23AA8 CJK UNIFIED IDEOGRAPH-#23AA8, IRGKangXi=0587.031, RSKangXi=79.9
23AA9 CJK UNIFIED IDEOGRAPH-#23AA9, IRGKangXi=0587.031, RSKangXi=79.9
23AAA CJK UNIFIED IDEOGRAPH-#23AAA, IRGKangXi=0587.031, RSKangXi=79.9
23AAB CJK UNIFIED IDEOGRAPH-#23AAB, IRGKangXi=0587.031, RSKangXi=79.9
23AAC CJK UNIFIED IDEOGRAPH-#23AAC, IRGKangXi=0587.031, RSKangXi=79.9
23AAD CJK UNIFIED IDEOGRAPH-#23AAD, IRGKangXi=0587.031, RSKangXi=109.8
23AAE CJK UNIFIED IDEOGRAPH-#23AAE, IRGKangXi=0587.040, RSKangXi=79.10
23AAF CJK UNIFIED IDEOGRAPH-#23AAF, IRGKangXi=0587.050, RSKangXi=79.10
23AB0 CJK UNIFIED IDEOGRAPH-#23AB0, IRGKangXi=0587.060, RSKangXi=79.10
23AB1 CJK UNIFIED IDEOGRAPH-#23AB1, IRGKangXi=0587.080, RSKangXi=79.10
23AB2 CJK UNIFIED IDEOGRAPH-#23AB2, IRGKangXi=0587.110, RSKangXi=79.10
23AB3 CJK UNIFIED IDEOGRAPH-#23AB3, IRGKangXi=0587.120, RSKangXi=79.10
23AB4 CJK UNIFIED IDEOGRAPH-#23AB4, IRGKangXi=0587.121, RSKangXi=79.10
23AB5 CJK UNIFIED IDEOGRAPH-#23AB5, IRGKangXi=0587.121, RSKangXi=79.10
23AB6 CJK UNIFIED IDEOGRAPH-#23AB6, IRGKangXi=0587.130, RSKangXi=79.11
23AB7 CJK UNIFIED IDEOGRAPH-#23AB7, IRGKangXi=0587.160, RSKangXi=79.11
23AB8 CJK UNIFIED IDEOGRAPH-#23AB8, IRGKangXi=0587.170, RSKangXi=79.11
23AB9 CJK UNIFIED IDEOGRAPH-#23AB9, IRGKangXi=0587.180, RSKangXi=79.11
23ABA CJK UNIFIED IDEOGRAPH-#23ABA, IRGKangXi=0587.181, RSKangXi=79.11
23ABB CJK UNIFIED IDEOGRAPH-#23ABB, IRGKangXi=0587.190, RSKangXi=79.12
23ABC CJK UNIFIED IDEOGRAPH-#23ABC, IRGKangXi=0587.210, RSKangXi=79.12
23ABD CJK UNIFIED IDEOGRAPH-#23ABD, IRGKangXi=0587.230, RSKangXi=79.12
23ABE CJK UNIFIED IDEOGRAPH-#23ABE, IRGKangXi=0587.250, RSKangXi=79.12
23ABF CJK UNIFIED IDEOGRAPH-#23ABF, IRGKangXi=0587.280, RSKangXi=79.12
23AC0 CJK UNIFIED IDEOGRAPH-#23AC0, IRGKangXi=0587.290, RSKangXi=79.12
23AC1 CJK UNIFIED IDEOGRAPH-#23AC1, IRGKangXi=0588.010, RSKangXi=79.12
23AC2 CJK UNIFIED IDEOGRAPH-#23AC2, IRGKangXi=0588.011, RSKangXi=79.12
23AC3 CJK UNIFIED IDEOGRAPH-#23AC3, IRGKangXi=0588.011, RSKangXi=79.12
23AC4 CJK UNIFIED IDEOGRAPH-#23AC4, IRGKangXi=0588.011, RSKangXi=79.12
23AC5 CJK UNIFIED IDEOGRAPH-#23AC5, IRGKangXi=0588.011, RSKangXi=79.12
23AC6 CJK UNIFIED IDEOGRAPH-#23AC6, IRGKangXi=0588.011, RSKangXi=79.12
23AC7 CJK UNIFIED IDEOGRAPH-#23AC7, IRGKangXi=0588.011, RSKangXi=79.12
23AC8 CJK UNIFIED IDEOGRAPH-#23AC8, IRGKangXi=0588.011, RSKangXi=79.12
23AC9 CJK UNIFIED IDEOGRAPH-#23AC9, IRGKangXi=0588.011, RSKangXi=79.12
23ACA CJK UNIFIED IDEOGRAPH-#23ACA, IRGKangXi=0588.011, RSKangXi=79.12
23ACB CJK UNIFIED IDEOGRAPH-#23ACB, IRGKangXi=0588.011, RSKangXi=79.12
23ACC CJK UNIFIED IDEOGRAPH-#23ACC, IRGKangXi=0588.020, RSKangXi=79.13
23ACD CJK UNIFIED IDEOGRAPH-#23ACD, IRGKangXi=0588.031, RSKangXi=79.13
23ACE CJK UNIFIED IDEOGRAPH-#23ACE, IRGKangXi=0588.031, RSKangXi=79.13
23ACF CJK UNIFIED IDEOGRAPH-#23ACF, IRGKangXi=0588.031, RSKangXi=79.13
23AD0 CJK UNIFIED IDEOGRAPH-#23AD0, IRGKangXi=0588.040, RSKangXi=79.14
23AD1 CJK UNIFIED IDEOGRAPH-#23AD1, IRGKangXi=0588.050, RSKangXi=79.14
23AD2 CJK UNIFIED IDEOGRAPH-#23AD2, IRGKangXi=0588.060, RSKangXi=79.14
23AD3 CJK UNIFIED IDEOGRAPH-#23AD3, IRGKangXi=0588.070, RSKangXi=79.14
23AD4 CJK UNIFIED IDEOGRAPH-#23AD4, IRGKangXi=0588.081, RSKangXi=79.14
23AD5 CJK UNIFIED IDEOGRAPH-#23AD5, IRGKangXi=0588.081, RSKangXi=79.14
23AD6 CJK UNIFIED IDEOGRAPH-#23AD6, IRGKangXi=0588.081, RSKangXi=79.14
23AD7 CJK UNIFIED IDEOGRAPH-#23AD7, IRGKangXi=0588.081, RSKangXi=79.14
23AD8 CJK UNIFIED IDEOGRAPH-#23AD8, IRGKangXi=0588.100, RSKangXi=79.15
23AD9 CJK UNIFIED IDEOGRAPH-#23AD9, IRGKangXi=0588.110, RSKangXi=79.15
23ADA CJK UNIFIED IDEOGRAPH-#23ADA, IRGKangXi=0588.120, RSKangXi=79.15
23ADB CJK UNIFIED IDEOGRAPH-#23ADB, IRGKangXi=0588.121, RSKangXi=79.15
23ADC CJK UNIFIED IDEOGRAPH-#23ADC, IRGKangXi=0588.121, RSKangXi=79.15
23ADD CJK UNIFIED IDEOGRAPH-#23ADD, IRGKangXi=0588.121, RSKangXi=79.15
23ADE CJK UNIFIED IDEOGRAPH-#23ADE, IRGKangXi=0588.130, RSKangXi=79.16
23ADF CJK UNIFIED IDEOGRAPH-#23ADF, IRGKangXi=0588.140, RSKangXi=79.16
23AE0 CJK UNIFIED IDEOGRAPH-#23AE0, IRGKangXi=0588.141, RSKangXi=79.17
23AE1 CJK UNIFIED IDEOGRAPH-#23AE1, IRGKangXi=0588.150, RSKangXi=79.17
23AE2 CJK UNIFIED IDEOGRAPH-#23AE2, IRGKangXi=0588.160, RSKangXi=79.19
23AE3 CJK UNIFIED IDEOGRAPH-#23AE3, IRGKangXi=0588.180, RSKangXi=79.19
23AE4 CJK UNIFIED IDEOGRAPH-#23AE4, IRGKangXi=0588.190, RSKangXi=79.19
23AE5 CJK UNIFIED IDEOGRAPH-#23AE5, IRGKangXi=0588.200, RSKangXi=79.19
23AE6 CJK UNIFIED IDEOGRAPH-#23AE6, IRGKangXi=0588.210, RSKangXi=79.20
23AE7 CJK UNIFIED IDEOGRAPH-#23AE7, IRGKangXi=0588.220, RSKangXi=79.20
23AE8 CJK UNIFIED IDEOGRAPH-#23AE8, IRGKangXi=0588.221, RSKangXi=79.20
23AE9 CJK UNIFIED IDEOGRAPH-#23AE9, IRGKangXi=0588.221, RSKangXi=79.21
23AEA CJK UNIFIED IDEOGRAPH-#23AEA, IRGKangXi=0588.221, RSKangXi=79.23
23AEB CJK UNIFIED IDEOGRAPH-#23AEB, IRGKangXi=0588.221, RSKangXi=79.23
23AEC CJK UNIFIED IDEOGRAPH-#23AEC, IRGKangXi=0589.010, RSKangXi=80.0
23AED CJK UNIFIED IDEOGRAPH-#23AED, IRGKangXi=0589.030, RSKangXi=80.2
23AEE CJK UNIFIED IDEOGRAPH-#23AEE, IRGKangXi=0589.041, RSKangXi=80.3
23AEF CJK UNIFIED IDEOGRAPH-#23AEF, IRGKangXi=0590.010, RSKangXi=80.4
23AF0 CJK UNIFIED IDEOGRAPH-#23AF0, IRGKangXi=0590.020, RSKangXi=80.4
23AF1 CJK UNIFIED IDEOGRAPH-#23AF1, IRGKangXi=0590.021, RSKangXi=80.4
23AF2 CJK UNIFIED IDEOGRAPH-#23AF2, IRGKangXi=0590.021, RSKangXi=80.4
23AF3 CJK UNIFIED IDEOGRAPH-#23AF3, IRGKangXi=0590.021, RSKangXi=80.5
23AF4 CJK UNIFIED IDEOGRAPH-#23AF4, IRGKangXi=0590.030, RSKangXi=80.6
23AF5 CJK UNIFIED IDEOGRAPH-#23AF5, IRGKangXi=0590.040, RSKangXi=80.7
23AF6 CJK UNIFIED IDEOGRAPH-#23AF6, IRGKangXi=0590.050, RSKangXi=80.7
23AF7 CJK UNIFIED IDEOGRAPH-#23AF7, IRGKangXi=0590.051, RSKangXi=80.7
23AF8 CJK UNIFIED IDEOGRAPH-#23AF8, IRGKangXi=0590.051, RSKangXi=80.7
23AF9 CJK UNIFIED IDEOGRAPH-#23AF9, IRGKangXi=0590.061, RSKangXi=80.9
23AFA CJK UNIFIED IDEOGRAPH-#23AFA, IRGKangXi=0590.070, RSKangXi=80.10
23AFB CJK UNIFIED IDEOGRAPH-#23AFB, IRGKangXi=0590.080, RSKangXi=80.10
23AFC CJK UNIFIED IDEOGRAPH-#23AFC, IRGKangXi=0590.081, RSKangXi=80.10
23AFD CJK UNIFIED IDEOGRAPH-#23AFD, IRGKangXi=0590.081, RSKangXi=80.12
23AFE CJK UNIFIED IDEOGRAPH-#23AFE, IRGKangXi=0590.081, RSKangXi=80.12
23AFF CJK UNIFIED IDEOGRAPH-#23AFF, IRGKangXi=0590.081, RSKangXi=80.13
23B00 CJK UNIFIED IDEOGRAPH-#23B00, IRGKangXi=0590.081, RSKangXi=80.15
23B01 CJK UNIFIED IDEOGRAPH-#23B01, IRGKangXi=0590.081, RSKangXi=80.18
23B02 CJK UNIFIED IDEOGRAPH-#23B02, IRGKangXi=0590.111, RSKangXi=81.3
23B03 CJK UNIFIED IDEOGRAPH-#23B03, IRGKangXi=0590.111, RSKangXi=81.3
23B04 CJK UNIFIED IDEOGRAPH-#23B04, IRGKangXi=0591.010, RSKangXi=81.4
23B05 CJK UNIFIED IDEOGRAPH-#23B05, IRGKangXi=0591.020, RSKangXi=81.4
23B06 CJK UNIFIED IDEOGRAPH-#23B06, IRGKangXi=0591.030, RSKangXi=81.4
23B07 CJK UNIFIED IDEOGRAPH-#23B07, IRGKangXi=0591.031, RSKangXi=81.4
23B08 CJK UNIFIED IDEOGRAPH-#23B08, IRGKangXi=0591.080, RSKangXi=81.6
23B09 CJK UNIFIED IDEOGRAPH-#23B09, IRGKangXi=0591.090, RSKangXi=81.6
23B0A CJK UNIFIED IDEOGRAPH-#23B0A, IRGKangXi=0591.100, RSKangXi=81.6
23B0B CJK UNIFIED IDEOGRAPH-#23B0B, IRGKangXi=0591.110, RSKangXi=81.7
23B0C CJK UNIFIED IDEOGRAPH-#23B0C, IRGKangXi=0591.120, RSKangXi=81.7
23B0D CJK UNIFIED IDEOGRAPH-#23B0D, IRGKangXi=0591.121, RSKangXi=81.9
23B0E CJK UNIFIED IDEOGRAPH-#23B0E, IRGKangXi=0591.130, RSKangXi=81.10
23B0F CJK UNIFIED IDEOGRAPH-#23B0F, IRGKangXi=0591.140, RSKangXi=81.10
23B10 CJK UNIFIED IDEOGRAPH-#23B10, IRGKangXi=0591.150, RSKangXi=81.10
23B11 CJK UNIFIED IDEOGRAPH-#23B11, IRGKangXi=0591.151, RSKangXi=81.10
23B12 CJK UNIFIED IDEOGRAPH-#23B12, IRGKangXi=0591.151, RSKangXi=81.11
23B13 CJK UNIFIED IDEOGRAPH-#23B13, IRGKangXi=0591.160, RSKangXi=81.12
23B14 CJK UNIFIED IDEOGRAPH-#23B14, IRGKangXi=0591.170, RSKangXi=81.12
23B15 CJK UNIFIED IDEOGRAPH-#23B15, IRGKangXi=0591.190, RSKangXi=81.13
23B16 CJK UNIFIED IDEOGRAPH-#23B16, IRGKangXi=0591.200, RSKangXi=81.15
23B17 CJK UNIFIED IDEOGRAPH-#23B17, IRGKangXi=0591.201, RSKangXi=81.16
23B18 CJK UNIFIED IDEOGRAPH-#23B18, IRGKangXi=0591.201, RSKangXi=81.16
23B19 CJK UNIFIED IDEOGRAPH-#23B19, IRGKangXi=0591.201, RSKangXi=81.18
23B1A CJK UNIFIED IDEOGRAPH-#23B1A, IRGKangXi=0591.210, RSKangXi=81.23
23B1B CJK UNIFIED IDEOGRAPH-#23B1B, IRGKangXi=0592.010, RSKangXi=82.0
23B1C CJK UNIFIED IDEOGRAPH-#23B1C, IRGKangXi=0592.020, RSKangXi=82.2
23B1D CJK UNIFIED IDEOGRAPH-#23B1D, IRGKangXi=0592.031, RSKangXi=82.2
23B1E CJK UNIFIED IDEOGRAPH-#23B1E, IRGKangXi=0592.031, RSKangXi=82.2
23B1F CJK UNIFIED IDEOGRAPH-#23B1F, IRGKangXi=0592.031, RSKangXi=82.2
23B20 CJK UNIFIED IDEOGRAPH-#23B20, IRGKangXi=0592.031, RSKangXi=82.2
23B21 CJK UNIFIED IDEOGRAPH-#23B21, IRGKangXi=0592.040, RSKangXi=82.3
23B22 CJK UNIFIED IDEOGRAPH-#23B22, IRGKangXi=0592.050, RSKangXi=82.3
23B23 CJK UNIFIED IDEOGRAPH-#23B23, IRGKangXi=0592.060, RSKangXi=82.3
23B24 CJK UNIFIED IDEOGRAPH-#23B24, IRGKangXi=0592.061, RSKangXi=82.3
23B25 CJK UNIFIED IDEOGRAPH-#23B25, IRGKangXi=0592.061, RSKangXi=82.3
23B26 CJK UNIFIED IDEOGRAPH-#23B26, IRGKangXi=0592.061, RSKangXi=82.3
23B27 CJK UNIFIED IDEOGRAPH-#23B27, IRGKangXi=0592.061, RSKangXi=82.3
23B28 CJK UNIFIED IDEOGRAPH-#23B28, IRGKangXi=0592.061, RSKangXi=82.3
23B29 CJK UNIFIED IDEOGRAPH-#23B29, IRGKangXi=0592.070, RSKangXi=82.4
23B2A CJK UNIFIED IDEOGRAPH-#23B2A, IRGKangXi=0592.100, RSKangXi=82.4
23B2B CJK UNIFIED IDEOGRAPH-#23B2B, IRGKangXi=0592.110, RSKangXi=82.4
23B2C CJK UNIFIED IDEOGRAPH-#23B2C, IRGKangXi=0592.130, RSKangXi=82.4
23B2D CJK UNIFIED IDEOGRAPH-#23B2D, IRGKangXi=0592.140, RSKangXi=82.4
23B2E CJK UNIFIED IDEOGRAPH-#23B2E, IRGKangXi=0592.160, RSKangXi=82.4
23B2F CJK UNIFIED IDEOGRAPH-#23B2F, IRGKangXi=0592.161, RSKangXi=82.4
23B30 CJK UNIFIED IDEOGRAPH-#23B30, IRGKangXi=0592.161, RSKangXi=82.4
23B31 CJK UNIFIED IDEOGRAPH-#23B31, IRGKangXi=0592.161, RSKangXi=82.4
23B32 CJK UNIFIED IDEOGRAPH-#23B32, IRGKangXi=0592.161, RSKangXi=82.4
23B33 CJK UNIFIED IDEOGRAPH-#23B33, IRGKangXi=0592.161, RSKangXi=82.4
23B34 CJK UNIFIED IDEOGRAPH-#23B34, IRGKangXi=0592.161, RSKangXi=82.4
23B35 CJK UNIFIED IDEOGRAPH-#23B35, IRGKangXi=0592.161, RSKangXi=82.4
23B36 CJK UNIFIED IDEOGRAPH-#23B36, IRGKangXi=0592.161, RSKangXi=82.4
23B37 CJK UNIFIED IDEOGRAPH-#23B37, IRGKangXi=0592.161, RSKangXi=82.4
23B38 CJK UNIFIED IDEOGRAPH-#23B38, IRGKangXi=0592.170, RSKangXi=82.5
23B39 CJK UNIFIED IDEOGRAPH-#23B39, IRGKangXi=0592.180, RSKangXi=82.5
23B3A CJK UNIFIED IDEOGRAPH-#23B3A, IRGKangXi=0592.190, RSKangXi=82.5
23B3B CJK UNIFIED IDEOGRAPH-#23B3B, IRGKangXi=0592.200, RSKangXi=82.5
23B3C CJK UNIFIED IDEOGRAPH-#23B3C, IRGKangXi=0592.220, RSKangXi=82.5
23B3D CJK UNIFIED IDEOGRAPH-#23B3D, IRGKangXi=0592.230, RSKangXi=82.5
23B3E CJK UNIFIED IDEOGRAPH-#23B3E, IRGKangXi=0592.240, RSKangXi=82.5
23B3F CJK UNIFIED IDEOGRAPH-#23B3F, IRGKangXi=0592.260, RSKangXi=82.5
23B40 CJK UNIFIED IDEOGRAPH-#23B40, IRGKangXi=0592.280, RSKangXi=82.5
23B41 CJK UNIFIED IDEOGRAPH-#23B41, IRGKangXi=0592.290, RSKangXi=82.5
23B42 CJK UNIFIED IDEOGRAPH-#23B42, IRGKangXi=0592.300, RSKangXi=82.5
23B43 CJK UNIFIED IDEOGRAPH-#23B43, IRGKangXi=0592.301, RSKangXi=82.5
23B44 CJK UNIFIED IDEOGRAPH-#23B44, IRGKangXi=0592.310, RSKangXi=82.5
23B45 CJK UNIFIED IDEOGRAPH-#23B45, IRGKangXi=0592.320, RSKangXi=82.5
23B46 CJK UNIFIED IDEOGRAPH-#23B46, IRGKangXi=0592.330, RSKangXi=82.5
23B47 CJK UNIFIED IDEOGRAPH-#23B47, IRGKangXi=0592.340, RSKangXi=82.5
23B48 CJK UNIFIED IDEOGRAPH-#23B48, IRGKangXi=0592.341, RSKangXi=82.5
23B49 CJK UNIFIED IDEOGRAPH-#23B49, IRGKangXi=0592.341, RSKangXi=82.5
23B4A CJK UNIFIED IDEOGRAPH-#23B4A, IRGKangXi=0592.341, RSKangXi=82.5
23B4B CJK UNIFIED IDEOGRAPH-#23B4B, IRGKangXi=0592.341, RSKangXi=82.5
23B4C CJK UNIFIED IDEOGRAPH-#23B4C, IRGKangXi=0592.341, RSKangXi=82.5
23B4D CJK UNIFIED IDEOGRAPH-#23B4D, IRGKangXi=0592.341, RSKangXi=82.5
23B4E CJK UNIFIED IDEOGRAPH-#23B4E, IRGKangXi=0592.341, RSKangXi=82.5
23B4F CJK UNIFIED IDEOGRAPH-#23B4F, IRGKangXi=0592.341, RSKangXi=82.5
23B50 CJK UNIFIED IDEOGRAPH-#23B50, IRGKangXi=0592.341, RSKangXi=82.5
23B51 CJK UNIFIED IDEOGRAPH-#23B51, IRGKangXi=0592.341, RSKangXi=82.5
23B52 CJK UNIFIED IDEOGRAPH-#23B52, IRGKangXi=0592.341, RSKangXi=82.5
23B53 CJK UNIFIED IDEOGRAPH-#23B53, IRGKangXi=0592.341, RSKangXi=82.5
23B54 CJK UNIFIED IDEOGRAPH-#23B54, IRGKangXi=0592.341, RSKangXi=82.5
23B55 CJK UNIFIED IDEOGRAPH-#23B55, IRGKangXi=0592.341, RSKangXi=82.5
23B56 CJK UNIFIED IDEOGRAPH-#23B56, IRGKangXi=0592.341, RSKangXi=82.5
23B57 CJK UNIFIED IDEOGRAPH-#23B57, IRGKangXi=0592.341, RSKangXi=82.5
23B58 CJK UNIFIED IDEOGRAPH-#23B58, IRGKangXi=0592.341, RSKangXi=82.5
23B59 CJK UNIFIED IDEOGRAPH-#23B59, IRGKangXi=0592.341, RSKangXi=82.5
23B5A CJK UNIFIED IDEOGRAPH-#23B5A, IRGKangXi=0592.341, RSKangXi=82.5
23B5B CJK UNIFIED IDEOGRAPH-#23B5B, IRGKangXi=0592.341, RSKangXi=82.5
23B5C CJK UNIFIED IDEOGRAPH-#23B5C, IRGKangXi=0592.370, RSKangXi=82.6
23B5D CJK UNIFIED IDEOGRAPH-#23B5D, IRGKangXi=0592.380, RSKangXi=82.6
23B5E CJK UNIFIED IDEOGRAPH-#23B5E, IRGKangXi=0593.020, RSKangXi=82.6
23B5F CJK UNIFIED IDEOGRAPH-#23B5F, IRGKangXi=0593.040, RSKangXi=82.6
23B60 CJK UNIFIED IDEOGRAPH-#23B60, IRGKangXi=0593.050, RSKangXi=82.6
23B61 CJK UNIFIED IDEOGRAPH-#23B61, IRGKangXi=0593.060, RSKangXi=82.6
23B62 CJK UNIFIED IDEOGRAPH-#23B62, IRGKangXi=0593.070, RSKangXi=82.6
23B63 CJK UNIFIED IDEOGRAPH-#23B63, IRGKangXi=0593.080, RSKangXi=82.6
23B64 CJK UNIFIED IDEOGRAPH-#23B64, IRGKangXi=0593.091, RSKangXi=82.6
23B65 CJK UNIFIED IDEOGRAPH-#23B65, IRGKangXi=0593.091, RSKangXi=82.6
23B66 CJK UNIFIED IDEOGRAPH-#23B66, IRGKangXi=0593.091, RSKangXi=82.6
23B67 CJK UNIFIED IDEOGRAPH-#23B67, IRGKangXi=0593.091, RSKangXi=82.6
23B68 CJK UNIFIED IDEOGRAPH-#23B68, IRGKangXi=0593.091, RSKangXi=82.6
23B69 CJK UNIFIED IDEOGRAPH-#23B69, IRGKangXi=0593.091, RSKangXi=82.6
23B6A CJK UNIFIED IDEOGRAPH-#23B6A, IRGKangXi=0593.091, RSKangXi=82.6
23B6B CJK UNIFIED IDEOGRAPH-#23B6B, IRGKangXi=0593.091, RSKangXi=82.6
23B6C CJK UNIFIED IDEOGRAPH-#23B6C, IRGKangXi=0593.091, RSKangXi=82.6
23B6D CJK UNIFIED IDEOGRAPH-#23B6D, IRGKangXi=0593.091, RSKangXi=82.6
23B6E CJK UNIFIED IDEOGRAPH-#23B6E, IRGKangXi=0593.091, RSKangXi=82.6
23B6F CJK UNIFIED IDEOGRAPH-#23B6F, IRGKangXi=0593.091, RSKangXi=82.6
23B70 CJK UNIFIED IDEOGRAPH-#23B70, IRGKangXi=0593.091, RSKangXi=82.6
23B71 CJK UNIFIED IDEOGRAPH-#23B71, IRGKangXi=0593.150, RSKangXi=82.7
23B72 CJK UNIFIED IDEOGRAPH-#23B72, IRGKangXi=0593.160, RSKangXi=82.7
23B73 CJK UNIFIED IDEOGRAPH-#23B73, IRGKangXi=0593.180, RSKangXi=82.7
23B74 CJK UNIFIED IDEOGRAPH-#23B74, IRGKangXi=0593.200, RSKangXi=82.7
23B75 CJK UNIFIED IDEOGRAPH-#23B75, IRGKangXi=0593.210, RSKangXi=82.7
23B76 CJK UNIFIED IDEOGRAPH-#23B76, IRGKangXi=0593.220, RSKangXi=82.7
23B77 CJK UNIFIED IDEOGRAPH-#23B77, IRGKangXi=0593.230, RSKangXi=82.7
23B78 CJK UNIFIED IDEOGRAPH-#23B78, IRGKangXi=0593.240, RSKangXi=82.7
23B79 CJK UNIFIED IDEOGRAPH-#23B79, IRGKangXi=0593.280, RSKangXi=82.7
23B7A CJK UNIFIED IDEOGRAPH-#23B7A, IRGKangXi=0594.010, RSKangXi=82.7
23B7B CJK UNIFIED IDEOGRAPH-#23B7B, IRGKangXi=0594.020, RSKangXi=82.7
23B7C CJK UNIFIED IDEOGRAPH-#23B7C, IRGKangXi=0594.030, RSKangXi=82.7
23B7D CJK UNIFIED IDEOGRAPH-#23B7D, IRGKangXi=0594.031, RSKangXi=82.7
23B7E CJK UNIFIED IDEOGRAPH-#23B7E, IRGKangXi=0594.031, RSKangXi=82.7
23B7F CJK UNIFIED IDEOGRAPH-#23B7F, IRGKangXi=0594.031, RSKangXi=82.7
23B80 CJK UNIFIED IDEOGRAPH-#23B80, IRGKangXi=0594.031, RSKangXi=82.7
23B81 CJK UNIFIED IDEOGRAPH-#23B81, IRGKangXi=0594.031, RSKangXi=82.7
23B82 CJK UNIFIED IDEOGRAPH-#23B82, IRGKangXi=0594.031, RSKangXi=82.7
23B83 CJK UNIFIED IDEOGRAPH-#23B83, IRGKangXi=0594.031, RSKangXi=82.7
23B84 CJK UNIFIED IDEOGRAPH-#23B84, IRGKangXi=0594.031, RSKangXi=82.7
23B85 CJK UNIFIED IDEOGRAPH-#23B85, IRGKangXi=0594.031, RSKangXi=82.7
23B86 CJK UNIFIED IDEOGRAPH-#23B86, IRGKangXi=0594.031, RSKangXi=82.7
23B87 CJK UNIFIED IDEOGRAPH-#23B87, IRGKangXi=0594.031, RSKangXi=82.7
23B88 CJK UNIFIED IDEOGRAPH-#23B88, IRGKangXi=0594.070, RSKangXi=82.8
23B89 CJK UNIFIED IDEOGRAPH-#23B89, IRGKangXi=0594.080, RSKangXi=82.8
23B8A CJK UNIFIED IDEOGRAPH-#23B8A, IRGKangXi=0594.090, RSKangXi=82.8
23B8B CJK UNIFIED IDEOGRAPH-#23B8B, IRGKangXi=0594.100, RSKangXi=82.8
23B8C CJK UNIFIED IDEOGRAPH-#23B8C, IRGKangXi=0594.150, RSKangXi=82.8
23B8D CJK UNIFIED IDEOGRAPH-#23B8D, IRGKangXi=0594.160, RSKangXi=82.8
23B8E CJK UNIFIED IDEOGRAPH-#23B8E, IRGKangXi=0594.180, RSKangXi=82.8
23B8F CJK UNIFIED IDEOGRAPH-#23B8F, IRGKangXi=0594.200, RSKangXi=82.8
23B90 CJK UNIFIED IDEOGRAPH-#23B90, IRGKangXi=0594.210, RSKangXi=82.8
23B91 CJK UNIFIED IDEOGRAPH-#23B91, IRGKangXi=0594.220, RSKangXi=82.8
23B92 CJK UNIFIED IDEOGRAPH-#23B92, IRGKangXi=0594.230, RSKangXi=82.8
23B93 CJK UNIFIED IDEOGRAPH-#23B93, IRGKangXi=0594.240, RSKangXi=82.8
23B94 CJK UNIFIED IDEOGRAPH-#23B94, IRGKangXi=0594.250, RSKangXi=82.8
23B95 CJK UNIFIED IDEOGRAPH-#23B95, IRGKangXi=0594.260, RSKangXi=82.8
23B96 CJK UNIFIED IDEOGRAPH-#23B96, IRGKangXi=0594.261, RSKangXi=82.8
23B97 CJK UNIFIED IDEOGRAPH-#23B97, IRGKangXi=0594.261, RSKangXi=82.8
23B98 CJK UNIFIED IDEOGRAPH-#23B98, IRGKangXi=0594.261, RSKangXi=82.8
23B99 CJK UNIFIED IDEOGRAPH-#23B99, IRGKangXi=0594.261, RSKangXi=82.8
23B9A CJK UNIFIED IDEOGRAPH-#23B9A, IRGKangXi=0594.261, RSKangXi=82.8
23B9B CJK UNIFIED IDEOGRAPH-#23B9B, IRGKangXi=0594.261, RSKangXi=82.8
23B9C CJK UNIFIED IDEOGRAPH-#23B9C, IRGKangXi=0594.261, RSKangXi=82.8
23B9D CJK UNIFIED IDEOGRAPH-#23B9D, IRGKangXi=0594.261, RSKangXi=82.8
23B9E CJK UNIFIED IDEOGRAPH-#23B9E, IRGKangXi=0594.261, RSKangXi=82.8
23B9F CJK UNIFIED IDEOGRAPH-#23B9F, IRGKangXi=0594.261, RSKangXi=82.8
23BA0 CJK UNIFIED IDEOGRAPH-#23BA0, IRGKangXi=0594.261, RSKangXi=82.8
23BA1 CJK UNIFIED IDEOGRAPH-#23BA1, IRGKangXi=0594.261, RSKangXi=82.8
23BA2 CJK UNIFIED IDEOGRAPH-#23BA2, IRGKangXi=0594.261, RSKangXi=82.8
23BA3 CJK UNIFIED IDEOGRAPH-#23BA3, IRGKangXi=0594.261, RSKangXi=82.8
23BA4 CJK UNIFIED IDEOGRAPH-#23BA4, IRGKangXi=0594.261, RSKangXi=82.8
23BA5 CJK UNIFIED IDEOGRAPH-#23BA5, IRGKangXi=0594.261, RSKangXi=82.8
23BA6 CJK UNIFIED IDEOGRAPH-#23BA6, IRGKangXi=0594.261, RSKangXi=82.8
23BA7 CJK UNIFIED IDEOGRAPH-#23BA7, IRGKangXi=0594.270, RSKangXi=82.8
23BA8 CJK UNIFIED IDEOGRAPH-#23BA8, IRGKangXi=0594.280, RSKangXi=82.9
23BA9 CJK UNIFIED IDEOGRAPH-#23BA9, IRGKangXi=0594.300, RSKangXi=82.9
23BAA CJK UNIFIED IDEOGRAPH-#23BAA, IRGKangXi=0594.310, RSKangXi=82.9
23BAB CJK UNIFIED IDEOGRAPH-#23BAB, IRGKangXi=0594.340, RSKangXi=82.9
23BAC CJK UNIFIED IDEOGRAPH-#23BAC, IRGKangXi=0594.360, RSKangXi=82.9
23BAD CJK UNIFIED IDEOGRAPH-#23BAD, IRGKangXi=0595.020, RSKangXi=82.9
23BAE CJK UNIFIED IDEOGRAPH-#23BAE, IRGKangXi=0595.060, RSKangXi=82.9
23BAF CJK UNIFIED IDEOGRAPH-#23BAF, IRGKangXi=0595.070, RSKangXi=82.9
23BB0 CJK UNIFIED IDEOGRAPH-#23BB0, IRGKangXi=0595.080, RSKangXi=82.9
23BB1 CJK UNIFIED IDEOGRAPH-#23BB1, IRGKangXi=0595.090, RSKangXi=82.9
23BB2 CJK UNIFIED IDEOGRAPH-#23BB2, IRGKangXi=0595.100, RSKangXi=82.9
23BB3 CJK UNIFIED IDEOGRAPH-#23BB3, IRGKangXi=0595.110, RSKangXi=82.9
23BB4 CJK UNIFIED IDEOGRAPH-#23BB4, IRGKangXi=0595.120, RSKangXi=82.9
23BB5 CJK UNIFIED IDEOGRAPH-#23BB5, IRGKangXi=0595.131, RSKangXi=82.9
23BB6 CJK UNIFIED IDEOGRAPH-#23BB6, IRGKangXi=0595.131, RSKangXi=82.9
23BB7 CJK UNIFIED IDEOGRAPH-#23BB7, IRGKangXi=0595.131, RSKangXi=82.9
23BB8 CJK UNIFIED IDEOGRAPH-#23BB8, IRGKangXi=0595.131, RSKangXi=82.9
23BB9 CJK UNIFIED IDEOGRAPH-#23BB9, IRGKangXi=0595.131, RSKangXi=82.9
23BBA CJK UNIFIED IDEOGRAPH-#23BBA, IRGKangXi=0595.131, RSKangXi=82.9
23BBB CJK UNIFIED IDEOGRAPH-#23BBB, IRGKangXi=0595.131, RSKangXi=82.9
23BBC CJK UNIFIED IDEOGRAPH-#23BBC, IRGKangXi=0595.131, RSKangXi=82.9
23BBD CJK UNIFIED IDEOGRAPH-#23BBD, IRGKangXi=0595.131, RSKangXi=82.9
23BBE CJK UNIFIED IDEOGRAPH-#23BBE, IRGKangXi=0595.131, RSKangXi=82.9
23BBF CJK UNIFIED IDEOGRAPH-#23BBF, IRGKangXi=0595.131, RSKangXi=82.9
23BC0 CJK UNIFIED IDEOGRAPH-#23BC0, IRGKangXi=0595.131, RSKangXi=82.9
23BC1 CJK UNIFIED IDEOGRAPH-#23BC1, IRGKangXi=0595.131, RSKangXi=82.9
23BC2 CJK UNIFIED IDEOGRAPH-#23BC2, IRGKangXi=0595.131, RSKangXi=82.9
23BC3 CJK UNIFIED IDEOGRAPH-#23BC3, IRGKangXi=0595.131, RSKangXi=82.9
23BC4 CJK UNIFIED IDEOGRAPH-#23BC4, IRGKangXi=0595.131, RSKangXi=82.9
23BC5 CJK UNIFIED IDEOGRAPH-#23BC5, IRGKangXi=0595.150, RSKangXi=82.10
23BC6 CJK UNIFIED IDEOGRAPH-#23BC6, IRGKangXi=0595.170, RSKangXi=82.10
23BC7 CJK UNIFIED IDEOGRAPH-#23BC7, IRGKangXi=0595.180, RSKangXi=82.10
23BC8 CJK UNIFIED IDEOGRAPH-#23BC8, IRGKangXi=0595.200, RSKangXi=82.10
23BC9 CJK UNIFIED IDEOGRAPH-#23BC9, IRGKangXi=0595.210, RSKangXi=82.10
23BCA CJK UNIFIED IDEOGRAPH-#23BCA, IRGKangXi=0595.240, RSKangXi=82.10
23BCB CJK UNIFIED IDEOGRAPH-#23BCB, IRGKangXi=0595.270, RSKangXi=82.10
23BCC CJK UNIFIED IDEOGRAPH-#23BCC, IRGKangXi=0595.280, RSKangXi=82.10
23BCD CJK UNIFIED IDEOGRAPH-#23BCD, IRGKangXi=0595.290, RSKangXi=82.10
23BCE CJK UNIFIED IDEOGRAPH-#23BCE, IRGKangXi=0595.300, RSKangXi=82.10
23BCF CJK UNIFIED IDEOGRAPH-#23BCF, IRGKangXi=0595.310, RSKangXi=82.10
23BD0 CJK UNIFIED IDEOGRAPH-#23BD0, IRGKangXi=0595.320, RSKangXi=82.10
23BD1 CJK UNIFIED IDEOGRAPH-#23BD1, IRGKangXi=0595.330, RSKangXi=82.10
23BD2 CJK UNIFIED IDEOGRAPH-#23BD2, IRGKangXi=0595.340, RSKangXi=82.10
23BD3 CJK UNIFIED IDEOGRAPH-#23BD3, IRGKangXi=0595.350, RSKangXi=82.10
23BD4 CJK UNIFIED IDEOGRAPH-#23BD4, IRGKangXi=0595.351, RSKangXi=82.10
23BD5 CJK UNIFIED IDEOGRAPH-#23BD5, IRGKangXi=0595.351, RSKangXi=82.10
23BD6 CJK UNIFIED IDEOGRAPH-#23BD6, IRGKangXi=0595.351, RSKangXi=82.10
23BD7 CJK UNIFIED IDEOGRAPH-#23BD7, IRGKangXi=0595.351, RSKangXi=82.10
23BD8 CJK UNIFIED IDEOGRAPH-#23BD8, IRGKangXi=0595.351, RSKangXi=82.10
23BD9 CJK UNIFIED IDEOGRAPH-#23BD9, IRGKangXi=0595.351, RSKangXi=82.10
23BDA CJK UNIFIED IDEOGRAPH-#23BDA, IRGKangXi=0595.351, RSKangXi=82.10
23BDB CJK UNIFIED IDEOGRAPH-#23BDB, IRGKangXi=0595.351, RSKangXi=82.10
23BDC CJK UNIFIED IDEOGRAPH-#23BDC, IRGKangXi=0595.351, RSKangXi=82.10
23BDD CJK UNIFIED IDEOGRAPH-#23BDD, IRGKangXi=0595.351, RSKangXi=82.10
23BDE CJK UNIFIED IDEOGRAPH-#23BDE, IRGKangXi=0595.351, RSKangXi=82.10
23BDF CJK UNIFIED IDEOGRAPH-#23BDF, IRGKangXi=0595.351, RSKangXi=82.10
23BE0 CJK UNIFIED IDEOGRAPH-#23BE0, IRGKangXi=0595.351, RSKangXi=82.10
23BE1 CJK UNIFIED IDEOGRAPH-#23BE1, IRGKangXi=0595.351, RSKangXi=82.10
23BE2 CJK UNIFIED IDEOGRAPH-#23BE2, IRGKangXi=0595.351, RSKangXi=82.10
23BE3 CJK UNIFIED IDEOGRAPH-#23BE3, IRGKangXi=0595.351, RSKangXi=82.11
23BE4 CJK UNIFIED IDEOGRAPH-#23BE4, IRGKangXi=0595.360, RSKangXi=82.11
23BE5 CJK UNIFIED IDEOGRAPH-#23BE5, IRGKangXi=0595.380, RSKangXi=82.11
23BE6 CJK UNIFIED IDEOGRAPH-#23BE6, IRGKangXi=0595.390, RSKangXi=82.11
23BE7 CJK UNIFIED IDEOGRAPH-#23BE7, IRGKangXi=0595.400, RSKangXi=82.11
23BE8 CJK UNIFIED IDEOGRAPH-#23BE8, IRGKangXi=0595.410, RSKangXi=82.11
23BE9 CJK UNIFIED IDEOGRAPH-#23BE9, IRGKangXi=0595.420, RSKangXi=82.11
23BEA CJK UNIFIED IDEOGRAPH-#23BEA, IRGKangXi=0595.430, RSKangXi=82.11
23BEB CJK UNIFIED IDEOGRAPH-#23BEB, IRGKangXi=0596.010, RSKangXi=82.11
23BEC CJK UNIFIED IDEOGRAPH-#23BEC, IRGKangXi=0596.020, RSKangXi=82.11
23BED CJK UNIFIED IDEOGRAPH-#23BED, IRGKangXi=0596.030, RSKangXi=82.11
23BEE CJK UNIFIED IDEOGRAPH-#23BEE, IRGKangXi=0596.040, RSKangXi=82.11
23BEF CJK UNIFIED IDEOGRAPH-#23BEF, IRGKangXi=0596.050, RSKangXi=82.11
23BF0 CJK UNIFIED IDEOGRAPH-#23BF0, IRGKangXi=0596.060, RSKangXi=82.11
23BF1 CJK UNIFIED IDEOGRAPH-#23BF1, IRGKangXi=0596.070, RSKangXi=82.11
23BF2 CJK UNIFIED IDEOGRAPH-#23BF2, IRGKangXi=0596.080, RSKangXi=82.11
23BF3 CJK UNIFIED IDEOGRAPH-#23BF3, IRGKangXi=0596.081, RSKangXi=82.11
23BF4 CJK UNIFIED IDEOGRAPH-#23BF4, IRGKangXi=0596.081, RSKangXi=82.11
23BF5 CJK UNIFIED IDEOGRAPH-#23BF5, IRGKangXi=0596.081, RSKangXi=82.11
23BF6 CJK UNIFIED IDEOGRAPH-#23BF6, IRGKangXi=0596.081, RSKangXi=82.11
23BF7 CJK UNIFIED IDEOGRAPH-#23BF7, IRGKangXi=0596.081, RSKangXi=82.11
23BF8 CJK UNIFIED IDEOGRAPH-#23BF8, IRGKangXi=0596.090, RSKangXi=82.12
23BF9 CJK UNIFIED IDEOGRAPH-#23BF9, IRGKangXi=0596.100, RSKangXi=82.12
23BFA CJK UNIFIED IDEOGRAPH-#23BFA, IRGKangXi=0596.140, RSKangXi=82.12
23BFB CJK UNIFIED IDEOGRAPH-#23BFB, IRGKangXi=0596.150, RSKangXi=82.12
23BFC CJK UNIFIED IDEOGRAPH-#23BFC, IRGKangXi=0596.170, RSKangXi=82.12
23BFD CJK UNIFIED IDEOGRAPH-#23BFD, IRGKangXi=0596.210, RSKangXi=82.12
23BFE CJK UNIFIED IDEOGRAPH-#23BFE, IRGKangXi=0596.230, RSKangXi=82.12
23BFF CJK UNIFIED IDEOGRAPH-#23BFF, IRGKangXi=0596.231, RSKangXi=92.12
23C00 CJK UNIFIED IDEOGRAPH-#23C00, IRGKangXi=0596.231, RSKangXi=82.12
23C01 CJK UNIFIED IDEOGRAPH-#23C01, IRGKangXi=0596.231, RSKangXi=82.12
23C02 CJK UNIFIED IDEOGRAPH-#23C02, IRGKangXi=0596.231, RSKangXi=82.12
23C03 CJK UNIFIED IDEOGRAPH-#23C03, IRGKangXi=0596.231, RSKangXi=82.12
23C04 CJK UNIFIED IDEOGRAPH-#23C04, IRGKangXi=0596.231, RSKangXi=82.12
23C05 CJK UNIFIED IDEOGRAPH-#23C05, IRGKangXi=0596.231, RSKangXi=82.12
23C06 CJK UNIFIED IDEOGRAPH-#23C06, IRGKangXi=0596.231, RSKangXi=82.12
23C07 CJK UNIFIED IDEOGRAPH-#23C07, IRGKangXi=0596.231, RSKangXi=82.12
23C08 CJK UNIFIED IDEOGRAPH-#23C08, IRGKangXi=0596.231, RSKangXi=82.12
23C09 CJK UNIFIED IDEOGRAPH-#23C09, IRGKangXi=0596.231, RSKangXi=82.12
23C0A CJK UNIFIED IDEOGRAPH-#23C0A, IRGKangXi=0596.240, RSKangXi=82.13
23C0B CJK UNIFIED IDEOGRAPH-#23C0B, IRGKangXi=0596.250, RSKangXi=82.13
23C0C CJK UNIFIED IDEOGRAPH-#23C0C, IRGKangXi=0596.260, RSKangXi=82.13
23C0D CJK UNIFIED IDEOGRAPH-#23C0D, IRGKangXi=0596.290, RSKangXi=82.13
23C0E CJK UNIFIED IDEOGRAPH-#23C0E, IRGKangXi=0596.300, RSKangXi=82.13
23C0F CJK UNIFIED IDEOGRAPH-#23C0F, IRGKangXi=0596.301, RSKangXi=82.13
23C10 CJK UNIFIED IDEOGRAPH-#23C10, IRGKangXi=0596.310, RSKangXi=82.13
23C11 CJK UNIFIED IDEOGRAPH-#23C11, IRGKangXi=0596.311, RSKangXi=82.13
23C12 CJK UNIFIED IDEOGRAPH-#23C12, IRGKangXi=0596.311, RSKangXi=82.13
23C13 CJK UNIFIED IDEOGRAPH-#23C13, IRGKangXi=0596.311, RSKangXi=82.13
23C14 CJK UNIFIED IDEOGRAPH-#23C14, IRGKangXi=0596.311, RSKangXi=82.13
23C15 CJK UNIFIED IDEOGRAPH-#23C15, IRGKangXi=0596.311, RSKangXi=82.13
23C16 CJK UNIFIED IDEOGRAPH-#23C16, IRGKangXi=0596.311, RSKangXi=82.13
23C17 CJK UNIFIED IDEOGRAPH-#23C17, IRGKangXi=0596.311, RSKangXi=82.13
23C18 CJK UNIFIED IDEOGRAPH-#23C18, IRGKangXi=0596.311, RSKangXi=82.13
23C19 CJK UNIFIED IDEOGRAPH-#23C19, IRGKangXi=0596.311, RSKangXi=82.13
23C1A CJK UNIFIED IDEOGRAPH-#23C1A, IRGKangXi=0596.320, RSKangXi=82.14
23C1B CJK UNIFIED IDEOGRAPH-#23C1B, IRGKangXi=0596.340, RSKangXi=82.14
23C1C CJK UNIFIED IDEOGRAPH-#23C1C, IRGKangXi=0596.350, RSKangXi=82.14
23C1D CJK UNIFIED IDEOGRAPH-#23C1D, IRGKangXi=0596.370, RSKangXi=82.14
23C1E CJK UNIFIED IDEOGRAPH-#23C1E, IRGKangXi=0596.390, RSKangXi=82.14
23C1F CJK UNIFIED IDEOGRAPH-#23C1F, IRGKangXi=0596.400, RSKangXi=82.14
23C20 CJK UNIFIED IDEOGRAPH-#23C20, IRGKangXi=0596.410, RSKangXi=82.14
23C21 CJK UNIFIED IDEOGRAPH-#23C21, IRGKangXi=0597.010, RSKangXi=82.14
23C22 CJK UNIFIED IDEOGRAPH-#23C22, IRGKangXi=0597.011, RSKangXi=82.14
23C23 CJK UNIFIED IDEOGRAPH-#23C23, IRGKangXi=0597.011, RSKangXi=82.14
23C24 CJK UNIFIED IDEOGRAPH-#23C24, IRGKangXi=0597.011, RSKangXi=82.14
23C25 CJK UNIFIED IDEOGRAPH-#23C25, IRGKangXi=0597.011, RSKangXi=82.14
23C26 CJK UNIFIED IDEOGRAPH-#23C26, IRGKangXi=0597.011, RSKangXi=82.14
23C27 CJK UNIFIED IDEOGRAPH-#23C27, IRGKangXi=0597.011, RSKangXi=82.14
23C28 CJK UNIFIED IDEOGRAPH-#23C28, IRGKangXi=0597.011, RSKangXi=82.14
23C29 CJK UNIFIED IDEOGRAPH-#23C29, IRGKangXi=0597.011, RSKangXi=82.14
23C2A CJK UNIFIED IDEOGRAPH-#23C2A, IRGKangXi=0597.011, RSKangXi=82.14
23C2B CJK UNIFIED IDEOGRAPH-#23C2B, IRGKangXi=0597.020, RSKangXi=82.15
23C2C CJK UNIFIED IDEOGRAPH-#23C2C, IRGKangXi=0597.030, RSKangXi=82.15
23C2D CJK UNIFIED IDEOGRAPH-#23C2D, IRGKangXi=0597.060, RSKangXi=82.15
23C2E CJK UNIFIED IDEOGRAPH-#23C2E, IRGKangXi=0597.070, RSKangXi=82.15
23C2F CJK UNIFIED IDEOGRAPH-#23C2F, IRGKangXi=0597.071, RSKangXi=82.15
23C30 CJK UNIFIED IDEOGRAPH-#23C30, IRGKangXi=0597.071, RSKangXi=82.15
23C31 CJK UNIFIED IDEOGRAPH-#23C31, IRGKangXi=0597.071, RSKangXi=82.16
23C32 CJK UNIFIED IDEOGRAPH-#23C32, IRGKangXi=0597.071, RSKangXi=82.16
23C33 CJK UNIFIED IDEOGRAPH-#23C33, IRGKangXi=0597.071, RSKangXi=82.16
23C34 CJK UNIFIED IDEOGRAPH-#23C34, IRGKangXi=0597.071, RSKangXi=82.16
23C35 CJK UNIFIED IDEOGRAPH-#23C35, IRGKangXi=0597.071, RSKangXi=82.16
23C36 CJK UNIFIED IDEOGRAPH-#23C36, IRGKangXi=0597.080, RSKangXi=82.17
23C37 CJK UNIFIED IDEOGRAPH-#23C37, IRGKangXi=0597.090, RSKangXi=82.17
23C38 CJK UNIFIED IDEOGRAPH-#23C38, IRGKangXi=0597.100, RSKangXi=82.17
23C39 CJK UNIFIED IDEOGRAPH-#23C39, IRGKangXi=0597.101, RSKangXi=82.17
23C3A CJK UNIFIED IDEOGRAPH-#23C3A, IRGKangXi=0597.101, RSKangXi=82.17
23C3B CJK UNIFIED IDEOGRAPH-#23C3B, IRGKangXi=0597.110, RSKangXi=82.18
23C3C CJK UNIFIED IDEOGRAPH-#23C3C, IRGKangXi=0597.120, RSKangXi=82.18
23C3D CJK UNIFIED IDEOGRAPH-#23C3D, IRGKangXi=0597.131, RSKangXi=82.18
23C3E CJK UNIFIED IDEOGRAPH-#23C3E, IRGKangXi=0597.131, RSKangXi=82.18
23C3F CJK UNIFIED IDEOGRAPH-#23C3F, IRGKangXi=0597.140, RSKangXi=82.19
23C40 CJK UNIFIED IDEOGRAPH-#23C40, IRGKangXi=0597.150, RSKangXi=82.19
23C41 CJK UNIFIED IDEOGRAPH-#23C41, IRGKangXi=0597.151, RSKangXi=82.19
23C42 CJK UNIFIED IDEOGRAPH-#23C42, IRGKangXi=0597.161, RSKangXi=82.22
23C43 CJK UNIFIED IDEOGRAPH-#23C43, IRGKangXi=0597.161, RSKangXi=82.22
23C44 CJK UNIFIED IDEOGRAPH-#23C44, IRGKangXi=0597.170, RSKangXi=82.24
23C45 CJK UNIFIED IDEOGRAPH-#23C45, IRGKangXi=0598.050, RSKangXi=83.4
23C46 CJK UNIFIED IDEOGRAPH-#23C46, IRGKangXi=0598.051, RSKangXi=83.4
23C47 CJK UNIFIED IDEOGRAPH-#23C47, IRGKangXi=0598.060, RSKangXi=83.5
23C48 CJK UNIFIED IDEOGRAPH-#23C48, IRGKangXi=0598.070, RSKangXi=83.5
23C49 CJK UNIFIED IDEOGRAPH-#23C49, IRGKangXi=0598.080, RSKangXi=83.5
23C4A CJK UNIFIED IDEOGRAPH-#23C4A, IRGKangXi=0598.081, RSKangXi=83.5
23C4B CJK UNIFIED IDEOGRAPH-#23C4B, IRGKangXi=0598.100, RSKangXi=83.7
23C4C CJK UNIFIED IDEOGRAPH-#23C4C, IRGKangXi=0598.101, RSKangXi=83.7
23C4D CJK UNIFIED IDEOGRAPH-#23C4D, IRGKangXi=0598.101, RSKangXi=83.7
23C4E CJK UNIFIED IDEOGRAPH-#23C4E, IRGKangXi=0598.101, RSKangXi=83.7
23C4F CJK UNIFIED IDEOGRAPH-#23C4F, IRGKangXi=0598.110, RSKangXi=83.9
23C50 CJK UNIFIED IDEOGRAPH-#23C50, IRGKangXi=0598.120, RSKangXi=83.10
23C51 CJK UNIFIED IDEOGRAPH-#23C51, IRGKangXi=0599.010, RSKangXi=83.12
23C52 CJK UNIFIED IDEOGRAPH-#23C52, IRGKangXi=0599.011, RSKangXi=83.13
23C53 CJK UNIFIED IDEOGRAPH-#23C53, IRGKangXi=0599.020, RSKangXi=83.14
23C54 CJK UNIFIED IDEOGRAPH-#23C54, IRGKangXi=0599.021, RSKangXi=83.14
23C55 CJK UNIFIED IDEOGRAPH-#23C55, IRGKangXi=0599.040, RSKangXi=84.2
23C56 CJK UNIFIED IDEOGRAPH-#23C56, IRGKangXi=0599.041, RSKangXi=84.2
23C57 CJK UNIFIED IDEOGRAPH-#23C57, IRGKangXi=0599.041, RSKangXi=84.3
23C58 CJK UNIFIED IDEOGRAPH-#23C58, IRGKangXi=0599.041, RSKangXi=84.3
23C59 CJK UNIFIED IDEOGRAPH-#23C59, IRGKangXi=0599.070, RSKangXi=84.4
23C5A CJK UNIFIED IDEOGRAPH-#23C5A, IRGKangXi=0599.080, RSKangXi=84.4
23C5B CJK UNIFIED IDEOGRAPH-#23C5B, IRGKangXi=0599.090, RSKangXi=84.4
23C5C CJK UNIFIED IDEOGRAPH-#23C5C, IRGKangXi=0599.110, RSKangXi=84.5
23C5D CJK UNIFIED IDEOGRAPH-#23C5D, IRGKangXi=0599.111, RSKangXi=84.5
23C5E CJK UNIFIED IDEOGRAPH-#23C5E, IRGKangXi=0599.111, RSKangXi=84.5
23C5F CJK UNIFIED IDEOGRAPH-#23C5F, IRGKangXi=0599.111, RSKangXi=84.5
23C60 CJK UNIFIED IDEOGRAPH-#23C60, IRGKangXi=0599.111, RSKangXi=84.5
23C61 CJK UNIFIED IDEOGRAPH-#23C61, IRGKangXi=0599.150, RSKangXi=84.6
23C62 CJK UNIFIED IDEOGRAPH-#23C62, IRGKangXi=0600.011, RSKangXi=84.8
23C63 CJK UNIFIED IDEOGRAPH-#23C63, IRGKangXi=0600.011, RSKangXi=84.7
23C64 CJK UNIFIED IDEOGRAPH-#23C64, IRGKangXi=0600.011, RSKangXi=84.8
23C65 CJK UNIFIED IDEOGRAPH-#23C65, IRGKangXi=0600.011, RSKangXi=84.8
23C66 CJK UNIFIED IDEOGRAPH-#23C66, IRGKangXi=0600.020, RSKangXi=84.9
23C67 CJK UNIFIED IDEOGRAPH-#23C67, IRGKangXi=0600.021, RSKangXi=84.9
23C68 CJK UNIFIED IDEOGRAPH-#23C68, IRGKangXi=0600.021, RSKangXi=84.9
23C69 CJK UNIFIED IDEOGRAPH-#23C69, IRGKangXi=0600.040, RSKangXi=84.10
23C6A CJK UNIFIED IDEOGRAPH-#23C6A, IRGKangXi=0600.050, RSKangXi=84.11
23C6B CJK UNIFIED IDEOGRAPH-#23C6B, IRGKangXi=0600.051, RSKangXi=84.11
23C6C CJK UNIFIED IDEOGRAPH-#23C6C, IRGKangXi=0600.051, RSKangXi=84.13
23C6D CJK UNIFIED IDEOGRAPH-#23C6D, IRGKangXi=0600.051, RSKangXi=84.13
23C6E CJK UNIFIED IDEOGRAPH-#23C6E, IRGKangXi=0600.051, RSKangXi=84.14
23C6F CJK UNIFIED IDEOGRAPH-#23C6F, IRGKangXi=0600.060, RSKangXi=84.17
23C70 CJK UNIFIED IDEOGRAPH-#23C70, IRGKangXi=0600.061, RSKangXi=84.17
23C71 CJK UNIFIED IDEOGRAPH-#23C71, IRGKangXi=0603.011, RSKangXi=85.0
23C72 CJK UNIFIED IDEOGRAPH-#23C72, IRGKangXi=0603.051, RSKangXi=85.1
23C73 CJK UNIFIED IDEOGRAPH-#23C73, IRGKangXi=0603.051, RSKangXi=85.1
23C74 CJK UNIFIED IDEOGRAPH-#23C74, IRGKangXi=0603.051, RSKangXi=85.1
23C75 CJK UNIFIED IDEOGRAPH-#23C75, IRGKangXi=0603.080, RSKangXi=85.2
23C76 CJK UNIFIED IDEOGRAPH-#23C76, IRGKangXi=0603.100, RSKangXi=85.2
23C77 CJK UNIFIED IDEOGRAPH-#23C77, IRGKangXi=0604.090, RSKangXi=85.2
23C78 CJK UNIFIED IDEOGRAPH-#23C78, IRGKangXi=0604.091, RSKangXi=85.2
23C79 CJK UNIFIED IDEOGRAPH-#23C79, IRGKangXi=0604.091, RSKangXi=85.2
23C7A CJK UNIFIED IDEOGRAPH-#23C7A, IRGKangXi=0604.091, RSKangXi=85.2
23C7B CJK UNIFIED IDEOGRAPH-#23C7B, IRGKangXi=0604.091, RSKangXi=85.2
23C7C CJK UNIFIED IDEOGRAPH-#23C7C, IRGKangXi=0604.091, RSKangXi=85.2
23C7D CJK UNIFIED IDEOGRAPH-#23C7D, IRGKangXi=0604.091, RSKangXi=85.2
23C7E CJK UNIFIED IDEOGRAPH-#23C7E, IRGKangXi=0604.091, RSKangXi=85.2
23C7F CJK UNIFIED IDEOGRAPH-#23C7F, IRGKangXi=0604.091, RSKangXi=85.2
23C80 CJK UNIFIED IDEOGRAPH-#23C80, IRGKangXi=0604.130, RSKangXi=85.3
23C81 CJK UNIFIED IDEOGRAPH-#23C81, IRGKangXi=0607.010, RSKangXi=85.3
23C82 CJK UNIFIED IDEOGRAPH-#23C82, IRGKangXi=0607.020, RSKangXi=85.3
23C83 CJK UNIFIED IDEOGRAPH-#23C83, IRGKangXi=0607.040, RSKangXi=85.3
23C84 CJK UNIFIED IDEOGRAPH-#23C84, IRGKangXi=0607.050, RSKangXi=85.3
23C85 CJK UNIFIED IDEOGRAPH-#23C85, IRGKangXi=0607.051, RSKangXi=85.3
23C86 CJK UNIFIED IDEOGRAPH-#23C86, IRGKangXi=0607.051, RSKangXi=85.3
23C87 CJK UNIFIED IDEOGRAPH-#23C87, IRGKangXi=0607.051, RSKangXi=85.3
23C88 CJK UNIFIED IDEOGRAPH-#23C88, IRGKangXi=0607.051, RSKangXi=85.3
23C89 CJK UNIFIED IDEOGRAPH-#23C89, IRGKangXi=0607.051, RSKangXi=85.3
23C8A CJK UNIFIED IDEOGRAPH-#23C8A, IRGKangXi=0607.051, RSKangXi=85.3
23C8B CJK UNIFIED IDEOGRAPH-#23C8B, IRGKangXi=0607.051, RSKangXi=85.3
23C8C CJK UNIFIED IDEOGRAPH-#23C8C, IRGKangXi=0607.051, RSKangXi=85.3
23C8D CJK UNIFIED IDEOGRAPH-#23C8D, IRGKangXi=0607.051, RSKangXi=85.3
23C8E CJK UNIFIED IDEOGRAPH-#23C8E, IRGKangXi=0608.070, RSKangXi=85.4
23C8F CJK UNIFIED IDEOGRAPH-#23C8F, IRGKangXi=0608.100, RSKangXi=85.4
23C90 CJK UNIFIED IDEOGRAPH-#23C90, IRGKangXi=0611.010, RSKangXi=85.4
23C91 CJK UNIFIED IDEOGRAPH-#23C91, IRGKangXi=0611.020, RSKangXi=85.4
23C92 CJK UNIFIED IDEOGRAPH-#23C92, IRGKangXi=0611.060, RSKangXi=85.4
23C93 CJK UNIFIED IDEOGRAPH-#23C93, IRGKangXi=0612.020, RSKangXi=85.4
23C94 CJK UNIFIED IDEOGRAPH-#23C94, IRGKangXi=0612.060, RSKangXi=85.4
23C95 CJK UNIFIED IDEOGRAPH-#23C95, IRGKangXi=0612.100, RSKangXi=85.4
23C96 CJK UNIFIED IDEOGRAPH-#23C96, IRGKangXi=0612.110, RSKangXi=85.4
23C97 CJK UNIFIED IDEOGRAPH-#23C97, IRGKangXi=0612.121, RSKangXi=85.4
23C98 CJK UNIFIED IDEOGRAPH-#23C98, IRGKangXi=0612.121, RSKangXi=85.4
23C99 CJK UNIFIED IDEOGRAPH-#23C99, IRGKangXi=0612.121, RSKangXi=85.4
23C9A CJK UNIFIED IDEOGRAPH-#23C9A, IRGKangXi=0612.121, RSKangXi=85.4
23C9B CJK UNIFIED IDEOGRAPH-#23C9B, IRGKangXi=0612.121, RSKangXi=85.4
23C9C CJK UNIFIED IDEOGRAPH-#23C9C, IRGKangXi=0612.121, RSKangXi=85.4
23C9D CJK UNIFIED IDEOGRAPH-#23C9D, IRGKangXi=0612.121, RSKangXi=85.4
23C9E CJK UNIFIED IDEOGRAPH-#23C9E, IRGKangXi=0612.121, RSKangXi=85.4
23C9F CJK UNIFIED IDEOGRAPH-#23C9F, IRGKangXi=0612.121, RSKangXi=85.4
23CA0 CJK UNIFIED IDEOGRAPH-#23CA0, IRGKangXi=0612.121, RSKangXi=85.4
23CA1 CJK UNIFIED IDEOGRAPH-#23CA1, IRGKangXi=0612.121, RSKangXi=85.4
23CA2 CJK UNIFIED IDEOGRAPH-#23CA2, IRGKangXi=0612.121, RSKangXi=85.4
23CA3 CJK UNIFIED IDEOGRAPH-#23CA3, IRGKangXi=0612.121, RSKangXi=85.4
23CA4 CJK UNIFIED IDEOGRAPH-#23CA4, IRGKangXi=0612.121, RSKangXi=85.4
23CA5 CJK UNIFIED IDEOGRAPH-#23CA5, IRGKangXi=0612.121, RSKangXi=85.4
23CA6 CJK UNIFIED IDEOGRAPH-#23CA6, IRGKangXi=0612.121, RSKangXi=85.4
23CA7 CJK UNIFIED IDEOGRAPH-#23CA7, IRGKangXi=0612.121, RSKangXi=85.4
23CA8 CJK UNIFIED IDEOGRAPH-#23CA8, IRGKangXi=0612.121, RSKangXi=85.4
23CA9 CJK UNIFIED IDEOGRAPH-#23CA9, IRGKangXi=0612.121, RSKangXi=85.4
23CAA CJK UNIFIED IDEOGRAPH-#23CAA, IRGKangXi=0612.121, RSKangXi=85.4
23CAB CJK UNIFIED IDEOGRAPH-#23CAB, IRGKangXi=0612.121, RSKangXi=85.4
23CAC CJK UNIFIED IDEOGRAPH-#23CAC, IRGKangXi=0612.121, RSKangXi=85.4
23CAD CJK UNIFIED IDEOGRAPH-#23CAD, IRGKangXi=0612.121, RSKangXi=85.4
23CAE CJK UNIFIED IDEOGRAPH-#23CAE, IRGKangXi=0612.121, RSKangXi=85.4
23CAF CJK UNIFIED IDEOGRAPH-#23CAF, IRGKangXi=0612.121, RSKangXi=85.4
23CB0 CJK UNIFIED IDEOGRAPH-#23CB0, IRGKangXi=0612.121, RSKangXi=85.4
23CB1 CJK UNIFIED IDEOGRAPH-#23CB1, IRGKangXi=0612.121, RSKangXi=85.4
23CB2 CJK UNIFIED IDEOGRAPH-#23CB2, IRGKangXi=0613.030, RSKangXi=85.5
23CB3 CJK UNIFIED IDEOGRAPH-#23CB3, IRGKangXi=0613.130, RSKangXi=85.5
23CB4 CJK UNIFIED IDEOGRAPH-#23CB4, IRGKangXi=0614.030, RSKangXi=85.5
23CB5 CJK UNIFIED IDEOGRAPH-#23CB5, IRGKangXi=0614.150, RSKangXi=85.5
23CB6 CJK UNIFIED IDEOGRAPH-#23CB6, IRGKangXi=0615.060, RSKangXi=85.5
23CB7 CJK UNIFIED IDEOGRAPH-#23CB7, IRGKangXi=0615.070, RSKangXi=85.5, Def{(Cant.) sticky; not smooth; slow}
23CB8 CJK UNIFIED IDEOGRAPH-#23CB8, IRGKangXi=0616.070, RSKangXi=85.5
23CB9 CJK UNIFIED IDEOGRAPH-#23CB9, IRGKangXi=0616.150, RSKangXi=85.5
23CBA CJK UNIFIED IDEOGRAPH-#23CBA, IRGKangXi=0617.020, RSKangXi=85.5
23CBB CJK UNIFIED IDEOGRAPH-#23CBB, IRGKangXi=0618.010, RSKangXi=85.5
23CBC CJK UNIFIED IDEOGRAPH-#23CBC, IRGKangXi=0618.030, RSKangXi=85.5
23CBD CJK UNIFIED IDEOGRAPH-#23CBD, IRGKangXi=0618.110, RSKangXi=85.5
23CBE CJK UNIFIED IDEOGRAPH-#23CBE, IRGKangXi=0619.030, RSKangXi=85.5
23CBF CJK UNIFIED IDEOGRAPH-#23CBF, IRGKangXi=0619.050, RSKangXi=85.5
23CC0 CJK UNIFIED IDEOGRAPH-#23CC0, IRGKangXi=0619.060, RSKangXi=85.5
23CC1 CJK UNIFIED IDEOGRAPH-#23CC1, IRGKangXi=0619.070, RSKangXi=85.5
23CC2 CJK UNIFIED IDEOGRAPH-#23CC2, IRGKangXi=0619.080, RSKangXi=85.5
23CC3 CJK UNIFIED IDEOGRAPH-#23CC3, IRGKangXi=0619.100, RSKangXi=85.5
23CC4 CJK UNIFIED IDEOGRAPH-#23CC4, IRGKangXi=0619.110, RSKangXi=85.5
23CC5 CJK UNIFIED IDEOGRAPH-#23CC5, IRGKangXi=0619.120, RSKangXi=85.5
23CC6 CJK UNIFIED IDEOGRAPH-#23CC6, IRGKangXi=0619.121, RSKangXi=85.5
23CC7 CJK UNIFIED IDEOGRAPH-#23CC7, IRGKangXi=0619.121, RSKangXi=85.5
23CC8 CJK UNIFIED IDEOGRAPH-#23CC8, IRGKangXi=0619.121, RSKangXi=85.5
23CC9 CJK UNIFIED IDEOGRAPH-#23CC9, IRGKangXi=0619.121, RSKangXi=85.5
23CCA CJK UNIFIED IDEOGRAPH-#23CCA, IRGKangXi=0619.121, RSKangXi=85.5
23CCB CJK UNIFIED IDEOGRAPH-#23CCB, IRGKangXi=0619.121, RSKangXi=85.5
23CCC CJK UNIFIED IDEOGRAPH-#23CCC, IRGKangXi=0619.121, RSKangXi=85.5
23CCD CJK UNIFIED IDEOGRAPH-#23CCD, IRGKangXi=0619.121, RSKangXi=85.5
23CCE CJK UNIFIED IDEOGRAPH-#23CCE, IRGKangXi=0619.121, RSKangXi=85.5
23CCF CJK UNIFIED IDEOGRAPH-#23CCF, IRGKangXi=0619.121, RSKangXi=85.5
23CD0 CJK UNIFIED IDEOGRAPH-#23CD0, IRGKangXi=0619.121, RSKangXi=85.5
23CD1 CJK UNIFIED IDEOGRAPH-#23CD1, IRGKangXi=0619.121, RSKangXi=85.5
23CD2 CJK UNIFIED IDEOGRAPH-#23CD2, IRGKangXi=0619.121, RSKangXi=85.5
23CD3 CJK UNIFIED IDEOGRAPH-#23CD3, IRGKangXi=0619.121, RSKangXi=85.5
23CD4 CJK UNIFIED IDEOGRAPH-#23CD4, IRGKangXi=0619.121, RSKangXi=85.5
23CD5 CJK UNIFIED IDEOGRAPH-#23CD5, IRGKangXi=0619.121, RSKangXi=85.5
23CD6 CJK UNIFIED IDEOGRAPH-#23CD6, IRGKangXi=0619.121, RSKangXi=85.5
23CD7 CJK UNIFIED IDEOGRAPH-#23CD7, IRGKangXi=0619.121, RSKangXi=85.5
23CD8 CJK UNIFIED IDEOGRAPH-#23CD8, IRGKangXi=0619.121, RSKangXi=85.5
23CD9 CJK UNIFIED IDEOGRAPH-#23CD9, IRGKangXi=0619.121, RSKangXi=85.5
23CDA CJK UNIFIED IDEOGRAPH-#23CDA, IRGKangXi=0619.121, RSKangXi=85.5
23CDB CJK UNIFIED IDEOGRAPH-#23CDB, IRGKangXi=0619.121, RSKangXi=85.5
23CDC CJK UNIFIED IDEOGRAPH-#23CDC, IRGKangXi=0619.121, RSKangXi=85.5
23CDD CJK UNIFIED IDEOGRAPH-#23CDD, IRGKangXi=0619.121, RSKangXi=85.5
23CDE CJK UNIFIED IDEOGRAPH-#23CDE, IRGKangXi=0619.121, RSKangXi=85.5
23CDF CJK UNIFIED IDEOGRAPH-#23CDF, IRGKangXi=0619.121, RSKangXi=85.5
23CE0 CJK UNIFIED IDEOGRAPH-#23CE0, IRGKangXi=0619.121, RSKangXi=85.5
23CE1 CJK UNIFIED IDEOGRAPH-#23CE1, IRGKangXi=0619.121, RSKangXi=85.5
23CE2 CJK UNIFIED IDEOGRAPH-#23CE2, IRGKangXi=0619.121, RSKangXi=85.5
23CE3 CJK UNIFIED IDEOGRAPH-#23CE3, IRGKangXi=0619.121, RSKangXi=85.5
23CE4 CJK UNIFIED IDEOGRAPH-#23CE4, IRGKangXi=0619.190, RSKangXi=85.6
23CE5 CJK UNIFIED IDEOGRAPH-#23CE5, IRGKangXi=0619.210, RSKangXi=85.6
23CE6 CJK UNIFIED IDEOGRAPH-#23CE6, IRGKangXi=0619.330, RSKangXi=85.6
23CE7 CJK UNIFIED IDEOGRAPH-#23CE7, IRGKangXi=0621.010, RSKangXi=85.6
23CE8 CJK UNIFIED IDEOGRAPH-#23CE8, IRGKangXi=0621.030, RSKangXi=85.6, Def{to store up, pile up}
23CE9 CJK UNIFIED IDEOGRAPH-#23CE9, IRGKangXi=0621.070, RSKangXi=85.6
23CEA CJK UNIFIED IDEOGRAPH-#23CEA, IRGKangXi=0621.240, RSKangXi=85.6
23CEB CJK UNIFIED IDEOGRAPH-#23CEB, IRGKangXi=0622.010, RSKangXi=85.6
23CEC CJK UNIFIED IDEOGRAPH-#23CEC, IRGKangXi=0622.050, RSKangXi=85.6
23CED CJK UNIFIED IDEOGRAPH-#23CED, IRGKangXi=0622.190, RSKangXi=85.6
23CEE CJK UNIFIED IDEOGRAPH-#23CEE, IRGKangXi=0623.060, RSKangXi=85.6
23CEF CJK UNIFIED IDEOGRAPH-#23CEF, IRGKangXi=0623.070, RSKangXi=85.6
23CF0 CJK UNIFIED IDEOGRAPH-#23CF0, IRGKangXi=0623.080, RSKangXi=85.6
23CF1 CJK UNIFIED IDEOGRAPH-#23CF1, IRGKangXi=0623.090, RSKangXi=85.6
23CF2 CJK UNIFIED IDEOGRAPH-#23CF2, IRGKangXi=0623.100, RSKangXi=85.6
23CF3 CJK UNIFIED IDEOGRAPH-#23CF3, IRGKangXi=0623.110, RSKangXi=85.6
23CF4 CJK UNIFIED IDEOGRAPH-#23CF4, IRGKangXi=0623.120, RSKangXi=85.6
23CF5 CJK UNIFIED IDEOGRAPH-#23CF5, IRGKangXi=0623.140, RSKangXi=85.6
23CF6 CJK UNIFIED IDEOGRAPH-#23CF6, IRGKangXi=0623.160, RSKangXi=85.6
23CF7 CJK UNIFIED IDEOGRAPH-#23CF7, IRGKangXi=0623.170, RSKangXi=85.6
23CF8 CJK UNIFIED IDEOGRAPH-#23CF8, IRGKangXi=0623.171, RSKangXi=85.6
23CF9 CJK UNIFIED IDEOGRAPH-#23CF9, IRGKangXi=0623.171, RSKangXi=85.6
23CFA CJK UNIFIED IDEOGRAPH-#23CFA, IRGKangXi=0623.171, RSKangXi=85.6
23CFB CJK UNIFIED IDEOGRAPH-#23CFB, IRGKangXi=0623.171, RSKangXi=85.6
23CFC CJK UNIFIED IDEOGRAPH-#23CFC, IRGKangXi=0623.171, RSKangXi=85.6, Def{(Cant.) salivating}
23CFD CJK UNIFIED IDEOGRAPH-#23CFD, IRGKangXi=0623.171, RSKangXi=85.6
23CFE CJK UNIFIED IDEOGRAPH-#23CFE, IRGKangXi=0623.171, RSKangXi=85.6
23CFF CJK UNIFIED IDEOGRAPH-#23CFF, IRGKangXi=0623.171, RSKangXi=85.6
23D00 CJK UNIFIED IDEOGRAPH-#23D00, IRGKangXi=0623.171, RSKangXi=85.6
23D01 CJK UNIFIED IDEOGRAPH-#23D01, IRGKangXi=0623.171, RSKangXi=85.6
23D02 CJK UNIFIED IDEOGRAPH-#23D02, IRGKangXi=0623.171, RSKangXi=85.6
23D03 CJK UNIFIED IDEOGRAPH-#23D03, IRGKangXi=0623.171, RSKangXi=85.6
23D04 CJK UNIFIED IDEOGRAPH-#23D04, IRGKangXi=0623.171, RSKangXi=85.6
23D05 CJK UNIFIED IDEOGRAPH-#23D05, IRGKangXi=0623.171, RSKangXi=85.6
23D06 CJK UNIFIED IDEOGRAPH-#23D06, IRGKangXi=0623.171, RSKangXi=85.6
23D07 CJK UNIFIED IDEOGRAPH-#23D07, IRGKangXi=0623.171, RSKangXi=85.6
23D08 CJK UNIFIED IDEOGRAPH-#23D08, IRGKangXi=0623.171, RSKangXi=85.6
23D09 CJK UNIFIED IDEOGRAPH-#23D09, IRGKangXi=0623.171, RSKangXi=85.6
23D0A CJK UNIFIED IDEOGRAPH-#23D0A, IRGKangXi=0623.171, RSKangXi=85.6
23D0B CJK UNIFIED IDEOGRAPH-#23D0B, IRGKangXi=0623.171, RSKangXi=85.6
23D0C CJK UNIFIED IDEOGRAPH-#23D0C, IRGKangXi=0623.171, RSKangXi=85.6
23D0D CJK UNIFIED IDEOGRAPH-#23D0D, IRGKangXi=0623.171, RSKangXi=85.6
23D0E CJK UNIFIED IDEOGRAPH-#23D0E, IRGKangXi=0623.171, RSKangXi=85.6
23D0F CJK UNIFIED IDEOGRAPH-#23D0F, IRGKangXi=0623.171, RSKangXi=85.6
23D10 CJK UNIFIED IDEOGRAPH-#23D10, IRGKangXi=0623.171, RSKangXi=85.6
23D11 CJK UNIFIED IDEOGRAPH-#23D11, IRGKangXi=0623.171, RSKangXi=85.6
23D12 CJK UNIFIED IDEOGRAPH-#23D12, IRGKangXi=0623.171, RSKangXi=85.6
23D13 CJK UNIFIED IDEOGRAPH-#23D13, IRGKangXi=0623.171, RSKangXi=85.6, Def{北𣴓省, Bắc Kạn Province in northern Vietnam}
23D14 CJK UNIFIED IDEOGRAPH-#23D14, IRGKangXi=0623.171, RSKangXi=85.6
23D15 CJK UNIFIED IDEOGRAPH-#23D15, IRGKangXi=0623.171, RSKangXi=85.6
23D16 CJK UNIFIED IDEOGRAPH-#23D16, IRGKangXi=0623.171, RSKangXi=85.6
23D17 CJK UNIFIED IDEOGRAPH-#23D17, IRGKangXi=0623.171, RSKangXi=85.6
23D18 CJK UNIFIED IDEOGRAPH-#23D18, IRGKangXi=0623.171, RSKangXi=85.6
23D19 CJK UNIFIED IDEOGRAPH-#23D19, IRGKangXi=0623.171, RSKangXi=85.6
23D1A CJK UNIFIED IDEOGRAPH-#23D1A, IRGKangXi=0623.171, RSKangXi=85.6
23D1B CJK UNIFIED IDEOGRAPH-#23D1B, IRGKangXi=0623.171, RSKangXi=85.6
23D1C CJK UNIFIED IDEOGRAPH-#23D1C, IRGKangXi=0623.171, RSKangXi=85.6
23D1D CJK UNIFIED IDEOGRAPH-#23D1D, IRGKangXi=0623.171, RSKangXi=85.6
23D1E CJK UNIFIED IDEOGRAPH-#23D1E, IRGKangXi=0623.220, RSKangXi=85.7
23D1F CJK UNIFIED IDEOGRAPH-#23D1F, IRGKangXi=0624.050, RSKangXi=85.7
23D20 CJK UNIFIED IDEOGRAPH-#23D20, IRGKangXi=0624.140, RSKangXi=85.7
23D21 CJK UNIFIED IDEOGRAPH-#23D21, IRGKangXi=0624.160, RSKangXi=85.7
23D22 CJK UNIFIED IDEOGRAPH-#23D22, IRGKangXi=0624.200, RSKangXi=85.7
23D23 CJK UNIFIED IDEOGRAPH-#23D23, IRGKangXi=0625.030, RSKangXi=85.7
23D24 CJK UNIFIED IDEOGRAPH-#23D24, IRGKangXi=0625.070, RSKangXi=85.7
23D25 CJK UNIFIED IDEOGRAPH-#23D25, IRGKangXi=0625.190, RSKangXi=85.7
23D26 CJK UNIFIED IDEOGRAPH-#23D26, IRGKangXi=0625.270, RSKangXi=85.7
23D27 CJK UNIFIED IDEOGRAPH-#23D27, IRGKangXi=0625.280, RSKangXi=85.7
23D28 CJK UNIFIED IDEOGRAPH-#23D28, IRGKangXi=0626.070, RSKangXi=85.7
23D29 CJK UNIFIED IDEOGRAPH-#23D29, IRGKangXi=0626.090, RSKangXi=85.7
23D2A CJK UNIFIED IDEOGRAPH-#23D2A, IRGKangXi=0626.100, RSKangXi=85.7
23D2B CJK UNIFIED IDEOGRAPH-#23D2B, IRGKangXi=0627.080, RSKangXi=85.7
23D2C CJK UNIFIED IDEOGRAPH-#23D2C, IRGKangXi=0627.090, RSKangXi=85.7
23D2D CJK UNIFIED IDEOGRAPH-#23D2D, IRGKangXi=0627.100, RSKangXi=85.7
23D2E CJK UNIFIED IDEOGRAPH-#23D2E, IRGKangXi=0627.110, RSKangXi=85.7
23D2F CJK UNIFIED IDEOGRAPH-#23D2F, IRGKangXi=0627.120, RSKangXi=85.7
23D30 CJK UNIFIED IDEOGRAPH-#23D30, IRGKangXi=0627.130, RSKangXi=85.7
23D31 CJK UNIFIED IDEOGRAPH-#23D31, IRGKangXi=0627.140, RSKangXi=85.7
23D32 CJK UNIFIED IDEOGRAPH-#23D32, IRGKangXi=0627.150, RSKangXi=85.7
23D33 CJK UNIFIED IDEOGRAPH-#23D33, IRGKangXi=0627.160, RSKangXi=85.7
23D34 CJK UNIFIED IDEOGRAPH-#23D34, IRGKangXi=0627.170, RSKangXi=85.7
23D35 CJK UNIFIED IDEOGRAPH-#23D35, IRGKangXi=0627.180, RSKangXi=85.7
23D36 CJK UNIFIED IDEOGRAPH-#23D36, IRGKangXi=0627.190, RSKangXi=85.7
23D37 CJK UNIFIED IDEOGRAPH-#23D37, IRGKangXi=0627.200, RSKangXi=85.7
23D38 CJK UNIFIED IDEOGRAPH-#23D38, IRGKangXi=0627.220, RSKangXi=85.7
23D39 CJK UNIFIED IDEOGRAPH-#23D39, IRGKangXi=0627.230, RSKangXi=85.7
23D3A CJK UNIFIED IDEOGRAPH-#23D3A, IRGKangXi=0627.240, RSKangXi=85.7
23D3B CJK UNIFIED IDEOGRAPH-#23D3B, IRGKangXi=0627.250, RSKangXi=85.7
23D3C CJK UNIFIED IDEOGRAPH-#23D3C, IRGKangXi=0627.260, RSKangXi=85.7
23D3D CJK UNIFIED IDEOGRAPH-#23D3D, IRGKangXi=0627.290, RSKangXi=85.7
23D3E CJK UNIFIED IDEOGRAPH-#23D3E, IRGKangXi=0627.300, RSKangXi=85.7
23D3F CJK UNIFIED IDEOGRAPH-#23D3F, IRGKangXi=0627.310, RSKangXi=85.7
23D40 CJK UNIFIED IDEOGRAPH-#23D40, IRGKangXi=0627.311, RSKangXi=85.7
23D41 CJK UNIFIED IDEOGRAPH-#23D41, IRGKangXi=0627.311, RSKangXi=85.7
23D42 CJK UNIFIED IDEOGRAPH-#23D42, IRGKangXi=0627.311, RSKangXi=85.7
23D43 CJK UNIFIED IDEOGRAPH-#23D43, IRGKangXi=0627.311, RSKangXi=85.7
23D44 CJK UNIFIED IDEOGRAPH-#23D44, IRGKangXi=0627.311, RSKangXi=85.7
23D45 CJK UNIFIED IDEOGRAPH-#23D45, IRGKangXi=0627.311, RSKangXi=85.7
23D46 CJK UNIFIED IDEOGRAPH-#23D46, IRGKangXi=0627.311, RSKangXi=85.7
23D47 CJK UNIFIED IDEOGRAPH-#23D47, IRGKangXi=0627.311, RSKangXi=85.7
23D48 CJK UNIFIED IDEOGRAPH-#23D48, IRGKangXi=0627.311, RSKangXi=85.7
23D49 CJK UNIFIED IDEOGRAPH-#23D49, IRGKangXi=0627.311, RSKangXi=85.7
23D4A CJK UNIFIED IDEOGRAPH-#23D4A, IRGKangXi=0627.311, RSKangXi=85.7
23D4B CJK UNIFIED IDEOGRAPH-#23D4B, IRGKangXi=0627.311, RSKangXi=85.7
23D4C CJK UNIFIED IDEOGRAPH-#23D4C, IRGKangXi=0627.311, RSKangXi=85.7
23D4D CJK UNIFIED IDEOGRAPH-#23D4D, IRGKangXi=0627.311, RSKangXi=85.7
23D4E CJK UNIFIED IDEOGRAPH-#23D4E, IRGKangXi=0627.311, RSKangXi=85.7
23D4F CJK UNIFIED IDEOGRAPH-#23D4F, IRGKangXi=0627.311, RSKangXi=85.7
23D50 CJK UNIFIED IDEOGRAPH-#23D50, IRGKangXi=0627.311, RSKangXi=85.7
23D51 CJK UNIFIED IDEOGRAPH-#23D51, IRGKangXi=0627.311, RSKangXi=85.7
23D52 CJK UNIFIED IDEOGRAPH-#23D52, IRGKangXi=0627.311, RSKangXi=85.7
23D53 CJK UNIFIED IDEOGRAPH-#23D53, IRGKangXi=0627.311, RSKangXi=85.7
23D54 CJK UNIFIED IDEOGRAPH-#23D54, IRGKangXi=0627.311, RSKangXi=85.7
23D55 CJK UNIFIED IDEOGRAPH-#23D55, IRGKangXi=0627.311, RSKangXi=85.7
23D56 CJK UNIFIED IDEOGRAPH-#23D56, IRGKangXi=0627.311, RSKangXi=85.7
23D57 CJK UNIFIED IDEOGRAPH-#23D57, IRGKangXi=0627.311, RSKangXi=85.7
23D58 CJK UNIFIED IDEOGRAPH-#23D58, IRGKangXi=0627.311, RSKangXi=85.7
23D59 CJK UNIFIED IDEOGRAPH-#23D59, IRGKangXi=0627.311, RSKangXi=85.7
23D5A CJK UNIFIED IDEOGRAPH-#23D5A, IRGKangXi=0627.311, RSKangXi=85.7
23D5B CJK UNIFIED IDEOGRAPH-#23D5B, IRGKangXi=0627.311, RSKangXi=85.7
23D5C CJK UNIFIED IDEOGRAPH-#23D5C, IRGKangXi=0627.311, RSKangXi=85.7
23D5D CJK UNIFIED IDEOGRAPH-#23D5D, IRGKangXi=0627.311, RSKangXi=85.7
23D5E CJK UNIFIED IDEOGRAPH-#23D5E, IRGKangXi=0627.311, RSKangXi=85.7
23D5F CJK UNIFIED IDEOGRAPH-#23D5F, IRGKangXi=0627.311, RSKangXi=85.7
23D60 CJK UNIFIED IDEOGRAPH-#23D60, IRGKangXi=0627.311, RSKangXi=85.7
23D61 CJK UNIFIED IDEOGRAPH-#23D61, IRGKangXi=0627.311, RSKangXi=85.7
23D62 CJK UNIFIED IDEOGRAPH-#23D62, IRGKangXi=0627.311, RSKangXi=85.7
23D63 CJK UNIFIED IDEOGRAPH-#23D63, IRGKangXi=0627.311, RSKangXi=85.7
23D64 CJK UNIFIED IDEOGRAPH-#23D64, IRGKangXi=0627.311, RSKangXi=85.7
23D65 CJK UNIFIED IDEOGRAPH-#23D65, IRGKangXi=0627.311, RSKangXi=85.7
23D66 CJK UNIFIED IDEOGRAPH-#23D66, IRGKangXi=0627.311, RSKangXi=85.7
23D67 CJK UNIFIED IDEOGRAPH-#23D67, IRGKangXi=0627.311, RSKangXi=85.7
23D68 CJK UNIFIED IDEOGRAPH-#23D68, IRGKangXi=0627.311, RSKangXi=85.7
23D69 CJK UNIFIED IDEOGRAPH-#23D69, IRGKangXi=0627.311, RSKangXi=85.7
23D6A CJK UNIFIED IDEOGRAPH-#23D6A, IRGKangXi=0627.311, RSKangXi=85.7
23D6B CJK UNIFIED IDEOGRAPH-#23D6B, IRGKangXi=0627.311, RSKangXi=85.7
23D6C CJK UNIFIED IDEOGRAPH-#23D6C, IRGKangXi=0627.311, RSKangXi=85.7
23D6D CJK UNIFIED IDEOGRAPH-#23D6D, IRGKangXi=0627.311, RSKangXi=85.7
23D6E CJK UNIFIED IDEOGRAPH-#23D6E, IRGKangXi=0627.311, RSKangXi=85.7
23D6F CJK UNIFIED IDEOGRAPH-#23D6F, IRGKangXi=0627.311, RSKangXi=85.7
23D70 CJK UNIFIED IDEOGRAPH-#23D70, IRGKangXi=0627.311, RSKangXi=85.7
23D71 CJK UNIFIED IDEOGRAPH-#23D71, IRGKangXi=0627.311, RSKangXi=85.7
23D72 CJK UNIFIED IDEOGRAPH-#23D72, IRGKangXi=0627.311, RSKangXi=85.7
23D73 CJK UNIFIED IDEOGRAPH-#23D73, IRGKangXi=0627.311, RSKangXi=85.7
23D74 CJK UNIFIED IDEOGRAPH-#23D74, IRGKangXi=0627.311, RSKangXi=85.7
23D75 CJK UNIFIED IDEOGRAPH-#23D75, IRGKangXi=0627.311, RSKangXi=85.7
23D76 CJK UNIFIED IDEOGRAPH-#23D76, IRGKangXi=0627.311, RSKangXi=85.7
23D77 CJK UNIFIED IDEOGRAPH-#23D77, IRGKangXi=0627.370, RSKangXi=85.8
23D78 CJK UNIFIED IDEOGRAPH-#23D78, IRGKangXi=0628.010, RSKangXi=85.8
23D79 CJK UNIFIED IDEOGRAPH-#23D79, IRGKangXi=0628.050, RSKangXi=85.8
23D7A CJK UNIFIED IDEOGRAPH-#23D7A, IRGKangXi=0628.080, RSKangXi=85.8
23D7B CJK UNIFIED IDEOGRAPH-#23D7B, IRGKangXi=0628.090, RSKangXi=85.8
23D7C CJK UNIFIED IDEOGRAPH-#23D7C, IRGKangXi=0628.100, RSKangXi=85.8
23D7D CJK UNIFIED IDEOGRAPH-#23D7D, IRGKangXi=0628.160, RSKangXi=85.8
23D7E CJK UNIFIED IDEOGRAPH-#23D7E, IRGKangXi=0628.170, RSKangXi=85.8
23D7F CJK UNIFIED IDEOGRAPH-#23D7F, IRGKangXi=0628.290, RSKangXi=85.8
23D80 CJK UNIFIED IDEOGRAPH-#23D80, IRGKangXi=0629.030, RSKangXi=85.8
23D81 CJK UNIFIED IDEOGRAPH-#23D81, IRGKangXi=0629.060, RSKangXi=85.8
23D82 CJK UNIFIED IDEOGRAPH-#23D82, IRGKangXi=0629.150, RSKangXi=85.8
23D83 CJK UNIFIED IDEOGRAPH-#23D83, IRGKangXi=0629.280, RSKangXi=85.8
23D84 CJK UNIFIED IDEOGRAPH-#23D84, IRGKangXi=0630.030, RSKangXi=85.8
23D85 CJK UNIFIED IDEOGRAPH-#23D85, IRGKangXi=0630.060, RSKangXi=85.8
23D86 CJK UNIFIED IDEOGRAPH-#23D86, IRGKangXi=0630.080, RSKangXi=85.8
23D87 CJK UNIFIED IDEOGRAPH-#23D87, IRGKangXi=0630.110, RSKangXi=85.8
23D88 CJK UNIFIED IDEOGRAPH-#23D88, IRGKangXi=0630.140, RSKangXi=85.8
23D89 CJK UNIFIED IDEOGRAPH-#23D89, IRGKangXi=0630.160, RSKangXi=85.8
23D8A CJK UNIFIED IDEOGRAPH-#23D8A, IRGKangXi=0630.170, RSKangXi=85.8
23D8B CJK UNIFIED IDEOGRAPH-#23D8B, IRGKangXi=0630.210, RSKangXi=85.8
23D8C CJK UNIFIED IDEOGRAPH-#23D8C, IRGKangXi=0631.030, RSKangXi=85.8
23D8D CJK UNIFIED IDEOGRAPH-#23D8D, IRGKangXi=0631.040, RSKangXi=85.8
23D8E CJK UNIFIED IDEOGRAPH-#23D8E, IRGKangXi=0631.050, RSKangXi=85.8
23D8F CJK UNIFIED IDEOGRAPH-#23D8F, IRGKangXi=0631.080, RSKangXi=85.8
23D90 CJK UNIFIED IDEOGRAPH-#23D90, IRGKangXi=0631.160, RSKangXi=85.8
23D91 CJK UNIFIED IDEOGRAPH-#23D91, IRGKangXi=0632.030, RSKangXi=85.8
23D92 CJK UNIFIED IDEOGRAPH-#23D92, IRGKangXi=0632.120, RSKangXi=85.8
23D93 CJK UNIFIED IDEOGRAPH-#23D93, IRGKangXi=0633.010, RSKangXi=85.8
23D94 CJK UNIFIED IDEOGRAPH-#23D94, IRGKangXi=0633.030, RSKangXi=85.8
23D95 CJK UNIFIED IDEOGRAPH-#23D95, IRGKangXi=0633.050, RSKangXi=85.8
23D96 CJK UNIFIED IDEOGRAPH-#23D96, IRGKangXi=0633.070, RSKangXi=85.8
23D97 CJK UNIFIED IDEOGRAPH-#23D97, IRGKangXi=0633.090, RSKangXi=85.8
23D98 CJK UNIFIED IDEOGRAPH-#23D98, IRGKangXi=0633.110, RSKangXi=85.8
23D99 CJK UNIFIED IDEOGRAPH-#23D99, IRGKangXi=0633.120, RSKangXi=85.8
23D9A CJK UNIFIED IDEOGRAPH-#23D9A, IRGKangXi=0633.130, RSKangXi=85.8
23D9B CJK UNIFIED IDEOGRAPH-#23D9B, IRGKangXi=0633.140, RSKangXi=85.8
23D9C CJK UNIFIED IDEOGRAPH-#23D9C, IRGKangXi=0633.150, RSKangXi=85.8
23D9D CJK UNIFIED IDEOGRAPH-#23D9D, IRGKangXi=0633.170, RSKangXi=85.8
23D9E CJK UNIFIED IDEOGRAPH-#23D9E, IRGKangXi=0633.190, RSKangXi=85.8
23D9F CJK UNIFIED IDEOGRAPH-#23D9F, IRGKangXi=0633.220, RSKangXi=85.8
23DA0 CJK UNIFIED IDEOGRAPH-#23DA0, IRGKangXi=0633.230, RSKangXi=85.8
23DA1 CJK UNIFIED IDEOGRAPH-#23DA1, IRGKangXi=0633.280, RSKangXi=85.8
23DA2 CJK UNIFIED IDEOGRAPH-#23DA2, IRGKangXi=0633.300, RSKangXi=85.8
23DA3 CJK UNIFIED IDEOGRAPH-#23DA3, IRGKangXi=0633.310, RSKangXi=85.8
23DA4 CJK UNIFIED IDEOGRAPH-#23DA4, IRGKangXi=0633.340, RSKangXi=85.8
23DA5 CJK UNIFIED IDEOGRAPH-#23DA5, IRGKangXi=0633.350, RSKangXi=85.8
23DA6 CJK UNIFIED IDEOGRAPH-#23DA6, IRGKangXi=0633.370, RSKangXi=85.8
23DA7 CJK UNIFIED IDEOGRAPH-#23DA7, IRGKangXi=0633.371, RSKangXi=85.8
23DA8 CJK UNIFIED IDEOGRAPH-#23DA8, IRGKangXi=0633.371, RSKangXi=85.8
23DA9 CJK UNIFIED IDEOGRAPH-#23DA9, IRGKangXi=0633.371, RSKangXi=85.8
23DAA CJK UNIFIED IDEOGRAPH-#23DAA, IRGKangXi=0633.371, RSKangXi=85.8
23DAB CJK UNIFIED IDEOGRAPH-#23DAB, IRGKangXi=0633.371, RSKangXi=85.8
23DAC CJK UNIFIED IDEOGRAPH-#23DAC, IRGKangXi=0633.371, RSKangXi=85.8
23DAD CJK UNIFIED IDEOGRAPH-#23DAD, IRGKangXi=0633.371, RSKangXi=85.8
23DAE CJK UNIFIED IDEOGRAPH-#23DAE, IRGKangXi=0633.371, RSKangXi=85.8
23DAF CJK UNIFIED IDEOGRAPH-#23DAF, IRGKangXi=0633.371, RSKangXi=85.8
23DB0 CJK UNIFIED IDEOGRAPH-#23DB0, IRGKangXi=0633.371, RSKangXi=85.8
23DB1 CJK UNIFIED IDEOGRAPH-#23DB1, IRGKangXi=0633.371, RSKangXi=85.8
23DB2 CJK UNIFIED IDEOGRAPH-#23DB2, IRGKangXi=0633.371, RSKangXi=85.8
23DB3 CJK UNIFIED IDEOGRAPH-#23DB3, IRGKangXi=0633.371, RSKangXi=85.8
23DB4 CJK UNIFIED IDEOGRAPH-#23DB4, IRGKangXi=0633.371, RSKangXi=85.8
23DB5 CJK UNIFIED IDEOGRAPH-#23DB5, IRGKangXi=0633.371, RSKangXi=85.8
23DB6 CJK UNIFIED IDEOGRAPH-#23DB6, IRGKangXi=0633.371, RSKangXi=85.8
23DB7 CJK UNIFIED IDEOGRAPH-#23DB7, IRGKangXi=0633.371, RSKangXi=85.8
23DB8 CJK UNIFIED IDEOGRAPH-#23DB8, IRGKangXi=0633.371, RSKangXi=85.8
23DB9 CJK UNIFIED IDEOGRAPH-#23DB9, IRGKangXi=0633.371, RSKangXi=85.8
23DBA CJK UNIFIED IDEOGRAPH-#23DBA, IRGKangXi=0633.371, RSKangXi=85.8
23DBB CJK UNIFIED IDEOGRAPH-#23DBB, IRGKangXi=0633.371, RSKangXi=85.8
23DBC CJK UNIFIED IDEOGRAPH-#23DBC, IRGKangXi=0633.371, RSKangXi=85.8
23DBD CJK UNIFIED IDEOGRAPH-#23DBD, IRGKangXi=0633.371, RSKangXi=85.8
23DBE CJK UNIFIED IDEOGRAPH-#23DBE, IRGKangXi=0633.371, RSKangXi=85.8
23DBF CJK UNIFIED IDEOGRAPH-#23DBF, IRGKangXi=0633.371, RSKangXi=85.8
23DC0 CJK UNIFIED IDEOGRAPH-#23DC0, IRGKangXi=0633.371, RSKangXi=85.8
23DC1 CJK UNIFIED IDEOGRAPH-#23DC1, IRGKangXi=0633.371, RSKangXi=85.8
23DC2 CJK UNIFIED IDEOGRAPH-#23DC2, IRGKangXi=0633.371, RSKangXi=85.8
23DC3 CJK UNIFIED IDEOGRAPH-#23DC3, IRGKangXi=0633.371, RSKangXi=85.8
23DC4 CJK UNIFIED IDEOGRAPH-#23DC4, IRGKangXi=0633.371, RSKangXi=85.8
23DC5 CJK UNIFIED IDEOGRAPH-#23DC5, IRGKangXi=0633.371, RSKangXi=85.8
23DC6 CJK UNIFIED IDEOGRAPH-#23DC6, IRGKangXi=0633.371, RSKangXi=85.8
23DC7 CJK UNIFIED IDEOGRAPH-#23DC7, IRGKangXi=0633.371, RSKangXi=85.8
23DC8 CJK UNIFIED IDEOGRAPH-#23DC8, IRGKangXi=0633.371, RSKangXi=85.8
23DC9 CJK UNIFIED IDEOGRAPH-#23DC9, IRGKangXi=0633.371, RSKangXi=85.8
23DCA CJK UNIFIED IDEOGRAPH-#23DCA, IRGKangXi=0633.371, RSKangXi=85.8
23DCB CJK UNIFIED IDEOGRAPH-#23DCB, IRGKangXi=0633.371, RSKangXi=85.8
23DCC CJK UNIFIED IDEOGRAPH-#23DCC, IRGKangXi=0633.371, RSKangXi=85.8
23DCD CJK UNIFIED IDEOGRAPH-#23DCD, IRGKangXi=0633.371, RSKangXi=85.8
23DCE CJK UNIFIED IDEOGRAPH-#23DCE, IRGKangXi=0633.371, RSKangXi=85.8
23DCF CJK UNIFIED IDEOGRAPH-#23DCF, IRGKangXi=0633.371, RSKangXi=85.8
23DD0 CJK UNIFIED IDEOGRAPH-#23DD0, IRGKangXi=0633.371, RSKangXi=85.8
23DD1 CJK UNIFIED IDEOGRAPH-#23DD1, IRGKangXi=0633.371, RSKangXi=85.8
23DD2 CJK UNIFIED IDEOGRAPH-#23DD2, IRGKangXi=0633.371, RSKangXi=85.8
23DD3 CJK UNIFIED IDEOGRAPH-#23DD3, IRGKangXi=0633.371, RSKangXi=85.8
23DD4 CJK UNIFIED IDEOGRAPH-#23DD4, IRGKangXi=0633.371, RSKangXi=85.8
23DD5 CJK UNIFIED IDEOGRAPH-#23DD5, IRGKangXi=0633.371, RSKangXi=85.8
23DD6 CJK UNIFIED IDEOGRAPH-#23DD6, IRGKangXi=0633.371, RSKangXi=85.8
23DD7 CJK UNIFIED IDEOGRAPH-#23DD7, IRGKangXi=0633.371, RSKangXi=85.8
23DD8 CJK UNIFIED IDEOGRAPH-#23DD8, IRGKangXi=0633.371, RSKangXi=85.8
23DD9 CJK UNIFIED IDEOGRAPH-#23DD9, IRGKangXi=0633.371, RSKangXi=85.8
23DDA CJK UNIFIED IDEOGRAPH-#23DDA, IRGKangXi=0633.371, RSKangXi=85.7
23DDB CJK UNIFIED IDEOGRAPH-#23DDB, IRGKangXi=0633.371, RSKangXi=85.8
23DDC CJK UNIFIED IDEOGRAPH-#23DDC, IRGKangXi=0633.371, RSKangXi=85.8
23DDD CJK UNIFIED IDEOGRAPH-#23DDD, IRGKangXi=0633.371, RSKangXi=85.8
23DDE CJK UNIFIED IDEOGRAPH-#23DDE, IRGKangXi=0633.371, RSKangXi=85.8
23DDF CJK UNIFIED IDEOGRAPH-#23DDF, IRGKangXi=0633.371, RSKangXi=85.8
23DE0 CJK UNIFIED IDEOGRAPH-#23DE0, IRGKangXi=0633.371, RSKangXi=85.8
23DE1 CJK UNIFIED IDEOGRAPH-#23DE1, IRGKangXi=0633.371, RSKangXi=85.8
23DE2 CJK UNIFIED IDEOGRAPH-#23DE2, IRGKangXi=0633.371, RSKangXi=85.8
23DE3 CJK UNIFIED IDEOGRAPH-#23DE3, IRGKangXi=0633.371, RSKangXi=85.8
23DE4 CJK UNIFIED IDEOGRAPH-#23DE4, IRGKangXi=0633.371, RSKangXi=85.8
23DE5 CJK UNIFIED IDEOGRAPH-#23DE5, IRGKangXi=0633.371, RSKangXi=85.8
23DE6 CJK UNIFIED IDEOGRAPH-#23DE6, IRGKangXi=0633.371, RSKangXi=85.8
23DE7 CJK UNIFIED IDEOGRAPH-#23DE7, IRGKangXi=0633.371, RSKangXi=85.8
23DE8 CJK UNIFIED IDEOGRAPH-#23DE8, IRGKangXi=0633.371, RSKangXi=85.8
23DE9 CJK UNIFIED IDEOGRAPH-#23DE9, IRGKangXi=0633.371, RSKangXi=85.8
23DEA CJK UNIFIED IDEOGRAPH-#23DEA, IRGKangXi=0633.371, RSKangXi=85.8
23DEB CJK UNIFIED IDEOGRAPH-#23DEB, IRGKangXi=0633.371, RSKangXi=85.8
23DEC CJK UNIFIED IDEOGRAPH-#23DEC, IRGKangXi=0633.371, RSKangXi=85.8
23DED CJK UNIFIED IDEOGRAPH-#23DED, IRGKangXi=0633.371, RSKangXi=85.8
23DEE CJK UNIFIED IDEOGRAPH-#23DEE, IRGKangXi=0633.371, RSKangXi=85.8
23DEF CJK UNIFIED IDEOGRAPH-#23DEF, IRGKangXi=0633.371, RSKangXi=85.8
23DF0 CJK UNIFIED IDEOGRAPH-#23DF0, IRGKangXi=0633.371, RSKangXi=85.8
23DF1 CJK UNIFIED IDEOGRAPH-#23DF1, IRGKangXi=0633.371, RSKangXi=85.8
23DF2 CJK UNIFIED IDEOGRAPH-#23DF2, IRGKangXi=0633.371, RSKangXi=85.8
23DF3 CJK UNIFIED IDEOGRAPH-#23DF3, IRGKangXi=0633.371, RSKangXi=85.8
23DF4 CJK UNIFIED IDEOGRAPH-#23DF4, IRGKangXi=0633.371, RSKangXi=85.8
23DF5 CJK UNIFIED IDEOGRAPH-#23DF5, IRGKangXi=0633.371, RSKangXi=85.8
23DF6 CJK UNIFIED IDEOGRAPH-#23DF6, IRGKangXi=0633.371, RSKangXi=85.8
23DF7 CJK UNIFIED IDEOGRAPH-#23DF7, IRGKangXi=0633.371, RSKangXi=85.8
23DF8 CJK UNIFIED IDEOGRAPH-#23DF8, IRGKangXi=0633.371, RSKangXi=85.8
23DF9 CJK UNIFIED IDEOGRAPH-#23DF9, IRGKangXi=0633.371, RSKangXi=85.8
23DFA CJK UNIFIED IDEOGRAPH-#23DFA, IRGKangXi=0633.371, RSKangXi=85.8
23DFB CJK UNIFIED IDEOGRAPH-#23DFB, IRGKangXi=0633.371, RSKangXi=85.8
23DFC CJK UNIFIED IDEOGRAPH-#23DFC, IRGKangXi=0633.390, RSKangXi=85.9
23DFD CJK UNIFIED IDEOGRAPH-#23DFD, IRGKangXi=0634.150, RSKangXi=85.9
23DFE CJK UNIFIED IDEOGRAPH-#23DFE, IRGKangXi=0635.220, RSKangXi=85.9
23DFF CJK UNIFIED IDEOGRAPH-#23DFF, IRGKangXi=0636.050, RSKangXi=85.9
23E00 CJK UNIFIED IDEOGRAPH-#23E00, IRGKangXi=0636.060, RSKangXi=85.9
23E01 CJK UNIFIED IDEOGRAPH-#23E01, IRGKangXi=0636.130, RSKangXi=85.9
23E02 CJK UNIFIED IDEOGRAPH-#23E02, IRGKangXi=0636.140, RSKangXi=85.9
23E03 CJK UNIFIED IDEOGRAPH-#23E03, IRGKangXi=0636.170, RSKangXi=85.9
23E04 CJK UNIFIED IDEOGRAPH-#23E04, IRGKangXi=0636.190, RSKangXi=85.9
23E05 CJK UNIFIED IDEOGRAPH-#23E05, IRGKangXi=0636.200, RSKangXi=85.9
23E06 CJK UNIFIED IDEOGRAPH-#23E06, IRGKangXi=0636.300, RSKangXi=85.9
23E07 CJK UNIFIED IDEOGRAPH-#23E07, IRGKangXi=0637.020, RSKangXi=85.9
23E08 CJK UNIFIED IDEOGRAPH-#23E08, IRGKangXi=0637.070, RSKangXi=85.9
23E09 CJK UNIFIED IDEOGRAPH-#23E09, IRGKangXi=0637.100, RSKangXi=85.9
23E0A CJK UNIFIED IDEOGRAPH-#23E0A, IRGKangXi=0637.130, RSKangXi=85.8
23E0B CJK UNIFIED IDEOGRAPH-#23E0B, IRGKangXi=0637.140, RSKangXi=85.9
23E0C CJK UNIFIED IDEOGRAPH-#23E0C, IRGKangXi=0638.010, RSKangXi=85.9
23E0D CJK UNIFIED IDEOGRAPH-#23E0D, IRGKangXi=0638.020, RSKangXi=85.9
23E0E CJK UNIFIED IDEOGRAPH-#23E0E, IRGKangXi=0638.130, RSKangXi=85.9
23E0F CJK UNIFIED IDEOGRAPH-#23E0F, IRGKangXi=0638.220, RSKangXi=85.9
23E10 CJK UNIFIED IDEOGRAPH-#23E10, IRGKangXi=0638.230, RSKangXi=85.9
23E11 CJK UNIFIED IDEOGRAPH-#23E11, IRGKangXi=0638.250, RSKangXi=85.9
23E12 CJK UNIFIED IDEOGRAPH-#23E12, IRGKangXi=0638.270, RSKangXi=85.9
23E13 CJK UNIFIED IDEOGRAPH-#23E13, IRGKangXi=0638.280, RSKangXi=85.9
23E14 CJK UNIFIED IDEOGRAPH-#23E14, IRGKangXi=0638.290, RSKangXi=85.9
23E15 CJK UNIFIED IDEOGRAPH-#23E15, IRGKangXi=0638.300, RSKangXi=85.9
23E16 CJK UNIFIED IDEOGRAPH-#23E16, IRGKangXi=0638.310, RSKangXi=85.9
23E17 CJK UNIFIED IDEOGRAPH-#23E17, IRGKangXi=0638.320, RSKangXi=85.9
23E18 CJK UNIFIED IDEOGRAPH-#23E18, IRGKangXi=0638.330, RSKangXi=85.9
23E19 CJK UNIFIED IDEOGRAPH-#23E19, IRGKangXi=0638.350, RSKangXi=85.9
23E1A CJK UNIFIED IDEOGRAPH-#23E1A, IRGKangXi=0639.010, RSKangXi=85.9
23E1B CJK UNIFIED IDEOGRAPH-#23E1B, IRGKangXi=0639.020, RSKangXi=85.9
23E1C CJK UNIFIED IDEOGRAPH-#23E1C, IRGKangXi=0639.030, RSKangXi=85.9
23E1D CJK UNIFIED IDEOGRAPH-#23E1D, IRGKangXi=0639.040, RSKangXi=85.9
23E1E CJK UNIFIED IDEOGRAPH-#23E1E, IRGKangXi=0639.060, RSKangXi=85.9
23E1F CJK UNIFIED IDEOGRAPH-#23E1F, IRGKangXi=0639.070, RSKangXi=85.9
23E20 CJK UNIFIED IDEOGRAPH-#23E20, IRGKangXi=0639.080, RSKangXi=85.9
23E21 CJK UNIFIED IDEOGRAPH-#23E21, IRGKangXi=0639.100, RSKangXi=85.9
23E22 CJK UNIFIED IDEOGRAPH-#23E22, IRGKangXi=0639.110, RSKangXi=85.9
23E23 CJK UNIFIED IDEOGRAPH-#23E23, IRGKangXi=0639.111, RSKangXi=85.9
23E24 CJK UNIFIED IDEOGRAPH-#23E24, IRGKangXi=0639.111, RSKangXi=85.9
23E25 CJK UNIFIED IDEOGRAPH-#23E25, IRGKangXi=0639.111, RSKangXi=85.9
23E26 CJK UNIFIED IDEOGRAPH-#23E26, IRGKangXi=0639.111, RSKangXi=85.9
23E27 CJK UNIFIED IDEOGRAPH-#23E27, IRGKangXi=0639.111, RSKangXi=85.9
23E28 CJK UNIFIED IDEOGRAPH-#23E28, IRGKangXi=0639.111, RSKangXi=85.9
23E29 CJK UNIFIED IDEOGRAPH-#23E29, IRGKangXi=0639.111, RSKangXi=85.9
23E2A CJK UNIFIED IDEOGRAPH-#23E2A, IRGKangXi=0639.111, RSKangXi=85.9
23E2B CJK UNIFIED IDEOGRAPH-#23E2B, IRGKangXi=0639.111, RSKangXi=85.9
23E2C CJK UNIFIED IDEOGRAPH-#23E2C, IRGKangXi=0639.111, RSKangXi=85.9
23E2D CJK UNIFIED IDEOGRAPH-#23E2D, IRGKangXi=0639.111, RSKangXi=85.9
23E2E CJK UNIFIED IDEOGRAPH-#23E2E, IRGKangXi=0639.111, RSKangXi=85.9
23E2F CJK UNIFIED IDEOGRAPH-#23E2F, IRGKangXi=0639.111, RSKangXi=85.9
23E30 CJK UNIFIED IDEOGRAPH-#23E30, IRGKangXi=0639.111, RSKangXi=85.9
23E31 CJK UNIFIED IDEOGRAPH-#23E31, IRGKangXi=0639.111, RSKangXi=85.9
23E32 CJK UNIFIED IDEOGRAPH-#23E32, IRGKangXi=0639.111, RSKangXi=85.9
23E33 CJK UNIFIED IDEOGRAPH-#23E33, IRGKangXi=0639.111, RSKangXi=85.9
23E34 CJK UNIFIED IDEOGRAPH-#23E34, IRGKangXi=0639.111, RSKangXi=85.9
23E35 CJK UNIFIED IDEOGRAPH-#23E35, IRGKangXi=0639.111, RSKangXi=85.9
23E36 CJK UNIFIED IDEOGRAPH-#23E36, IRGKangXi=0639.111, RSKangXi=85.9
23E37 CJK UNIFIED IDEOGRAPH-#23E37, IRGKangXi=0639.111, RSKangXi=85.9
23E38 CJK UNIFIED IDEOGRAPH-#23E38, IRGKangXi=0639.111, RSKangXi=85.9
23E39 CJK UNIFIED IDEOGRAPH-#23E39, IRGKangXi=0639.111, RSKangXi=85.9
23E3A CJK UNIFIED IDEOGRAPH-#23E3A, IRGKangXi=0639.111, RSKangXi=85.9
23E3B CJK UNIFIED IDEOGRAPH-#23E3B, IRGKangXi=0639.111, RSKangXi=85.9
23E3C CJK UNIFIED IDEOGRAPH-#23E3C, IRGKangXi=0639.111, RSKangXi=85.9
23E3D CJK UNIFIED IDEOGRAPH-#23E3D, IRGKangXi=0639.111, RSKangXi=85.9
23E3E CJK UNIFIED IDEOGRAPH-#23E3E, IRGKangXi=0639.111, RSKangXi=85.9
23E3F CJK UNIFIED IDEOGRAPH-#23E3F, IRGKangXi=0639.111, RSKangXi=85.9
23E40 CJK UNIFIED IDEOGRAPH-#23E40, IRGKangXi=0639.111, RSKangXi=85.9
23E41 CJK UNIFIED IDEOGRAPH-#23E41, IRGKangXi=0639.111, RSKangXi=85.9
23E42 CJK UNIFIED IDEOGRAPH-#23E42, IRGKangXi=0639.111, RSKangXi=85.9
23E43 CJK UNIFIED IDEOGRAPH-#23E43, IRGKangXi=0639.111, RSKangXi=85.9
23E44 CJK UNIFIED IDEOGRAPH-#23E44, IRGKangXi=0639.111, RSKangXi=85.9
23E45 CJK UNIFIED IDEOGRAPH-#23E45, IRGKangXi=0639.111, RSKangXi=85.9
23E46 CJK UNIFIED IDEOGRAPH-#23E46, IRGKangXi=0639.111, RSKangXi=85.9
23E47 CJK UNIFIED IDEOGRAPH-#23E47, IRGKangXi=0639.111, RSKangXi=85.9
23E48 CJK UNIFIED IDEOGRAPH-#23E48, IRGKangXi=0639.111, RSKangXi=85.9
23E49 CJK UNIFIED IDEOGRAPH-#23E49, IRGKangXi=0639.111, RSKangXi=85.9
23E4A CJK UNIFIED IDEOGRAPH-#23E4A, IRGKangXi=0639.111, RSKangXi=85.9
23E4B CJK UNIFIED IDEOGRAPH-#23E4B, IRGKangXi=0639.111, RSKangXi=85.9
23E4C CJK UNIFIED IDEOGRAPH-#23E4C, IRGKangXi=0639.111, RSKangXi=85.9
23E4D CJK UNIFIED IDEOGRAPH-#23E4D, IRGKangXi=0639.111, RSKangXi=85.9
23E4E CJK UNIFIED IDEOGRAPH-#23E4E, IRGKangXi=0639.111, RSKangXi=85.9
23E4F CJK UNIFIED IDEOGRAPH-#23E4F, IRGKangXi=0639.111, RSKangXi=85.9
23E50 CJK UNIFIED IDEOGRAPH-#23E50, IRGKangXi=0639.111, RSKangXi=85.9
23E51 CJK UNIFIED IDEOGRAPH-#23E51, IRGKangXi=0639.111, RSKangXi=85.9
23E52 CJK UNIFIED IDEOGRAPH-#23E52, IRGKangXi=0639.111, RSKangXi=85.9
23E53 CJK UNIFIED IDEOGRAPH-#23E53, IRGKangXi=0639.111, RSKangXi=85.9
23E54 CJK UNIFIED IDEOGRAPH-#23E54, IRGKangXi=0639.111, RSKangXi=85.9
23E55 CJK UNIFIED IDEOGRAPH-#23E55, IRGKangXi=0639.111, RSKangXi=85.9
23E56 CJK UNIFIED IDEOGRAPH-#23E56, IRGKangXi=0639.111, RSKangXi=85.9
23E57 CJK UNIFIED IDEOGRAPH-#23E57, IRGKangXi=0639.111, RSKangXi=85.9
23E58 CJK UNIFIED IDEOGRAPH-#23E58, IRGKangXi=0639.111, RSKangXi=85.9
23E59 CJK UNIFIED IDEOGRAPH-#23E59, IRGKangXi=0639.111, RSKangXi=85.9
23E5A CJK UNIFIED IDEOGRAPH-#23E5A, IRGKangXi=0639.111, RSKangXi=85.9
23E5B CJK UNIFIED IDEOGRAPH-#23E5B, IRGKangXi=0639.111, RSKangXi=85.9
23E5C CJK UNIFIED IDEOGRAPH-#23E5C, IRGKangXi=0639.111, RSKangXi=85.9
23E5D CJK UNIFIED IDEOGRAPH-#23E5D, IRGKangXi=0639.140, RSKangXi=85.10
23E5E CJK UNIFIED IDEOGRAPH-#23E5E, IRGKangXi=0639.230, RSKangXi=85.10
23E5F CJK UNIFIED IDEOGRAPH-#23E5F, IRGKangXi=0639.280, RSKangXi=85.10
23E60 CJK UNIFIED IDEOGRAPH-#23E60, IRGKangXi=0639.300, RSKangXi=85.10
23E61 CJK UNIFIED IDEOGRAPH-#23E61, IRGKangXi=0640.010, RSKangXi=85.10
23E62 CJK UNIFIED IDEOGRAPH-#23E62, IRGKangXi=0640.050, RSKangXi=85.10
23E63 CJK UNIFIED IDEOGRAPH-#23E63, IRGKangXi=0640.070, RSKangXi=85.10
23E64 CJK UNIFIED IDEOGRAPH-#23E64, IRGKangXi=0640.090, RSKangXi=85.10
23E65 CJK UNIFIED IDEOGRAPH-#23E65, IRGKangXi=0640.160, RSKangXi=85.10
23E66 CJK UNIFIED IDEOGRAPH-#23E66, IRGKangXi=0640.240, RSKangXi=85.10
23E67 CJK UNIFIED IDEOGRAPH-#23E67, IRGKangXi=0640.280, RSKangXi=85.10
23E68 CJK UNIFIED IDEOGRAPH-#23E68, IRGKangXi=0640.320, RSKangXi=85.10
23E69 CJK UNIFIED IDEOGRAPH-#23E69, IRGKangXi=0641.050, RSKangXi=85.10
23E6A CJK UNIFIED IDEOGRAPH-#23E6A, IRGKangXi=0641.060, RSKangXi=85.10
23E6B CJK UNIFIED IDEOGRAPH-#23E6B, IRGKangXi=0641.170, RSKangXi=85.10
23E6C CJK UNIFIED IDEOGRAPH-#23E6C, IRGKangXi=0641.220, RSKangXi=85.10
23E6D CJK UNIFIED IDEOGRAPH-#23E6D, IRGKangXi=0641.280, RSKangXi=85.10
23E6E CJK UNIFIED IDEOGRAPH-#23E6E, IRGKangXi=0642.070, RSKangXi=85.10
23E6F CJK UNIFIED IDEOGRAPH-#23E6F, IRGKangXi=0642.100, RSKangXi=85.10
23E70 CJK UNIFIED IDEOGRAPH-#23E70, IRGKangXi=0642.120, RSKangXi=85.10
23E71 CJK UNIFIED IDEOGRAPH-#23E71, IRGKangXi=0642.180, RSKangXi=85.10
23E72 CJK UNIFIED IDEOGRAPH-#23E72, IRGKangXi=0643.010, RSKangXi=85.10
23E73 CJK UNIFIED IDEOGRAPH-#23E73, IRGKangXi=0643.080, RSKangXi=85.10
23E74 CJK UNIFIED IDEOGRAPH-#23E74, IRGKangXi=0643.090, RSKangXi=85.10
23E75 CJK UNIFIED IDEOGRAPH-#23E75, IRGKangXi=0643.100, RSKangXi=85.10
23E76 CJK UNIFIED IDEOGRAPH-#23E76, IRGKangXi=0643.110, RSKangXi=85.10
23E77 CJK UNIFIED IDEOGRAPH-#23E77, IRGKangXi=0643.120, RSKangXi=85.10
23E78 CJK UNIFIED IDEOGRAPH-#23E78, IRGKangXi=0643.130, RSKangXi=85.10
23E79 CJK UNIFIED IDEOGRAPH-#23E79, IRGKangXi=0643.140, RSKangXi=85.10
23E7A CJK UNIFIED IDEOGRAPH-#23E7A, IRGKangXi=0643.150, RSKangXi=85.10
23E7B CJK UNIFIED IDEOGRAPH-#23E7B, IRGKangXi=0643.170, RSKangXi=85.10
23E7C CJK UNIFIED IDEOGRAPH-#23E7C, IRGKangXi=0643.180, RSKangXi=85.10
23E7D CJK UNIFIED IDEOGRAPH-#23E7D, IRGKangXi=0643.200, RSKangXi=85.10
23E7E CJK UNIFIED IDEOGRAPH-#23E7E, IRGKangXi=0643.210, RSKangXi=85.10
23E7F CJK UNIFIED IDEOGRAPH-#23E7F, IRGKangXi=0643.220, RSKangXi=85.10
23E80 CJK UNIFIED IDEOGRAPH-#23E80, IRGKangXi=0643.230, RSKangXi=85.10
23E81 CJK UNIFIED IDEOGRAPH-#23E81, IRGKangXi=0643.240, RSKangXi=85.10
23E82 CJK UNIFIED IDEOGRAPH-#23E82, IRGKangXi=0643.241, RSKangXi=85.10
23E83 CJK UNIFIED IDEOGRAPH-#23E83, IRGKangXi=0643.241, RSKangXi=85.10
23E84 CJK UNIFIED IDEOGRAPH-#23E84, IRGKangXi=0643.241, RSKangXi=85.10
23E85 CJK UNIFIED IDEOGRAPH-#23E85, IRGKangXi=0643.241, RSKangXi=85.10
23E86 CJK UNIFIED IDEOGRAPH-#23E86, IRGKangXi=0643.241, RSKangXi=85.10
23E87 CJK UNIFIED IDEOGRAPH-#23E87, IRGKangXi=0643.241, RSKangXi=85.10
23E88 CJK UNIFIED IDEOGRAPH-#23E88, IRGKangXi=0643.241, RSKangXi=85.10
23E89 CJK UNIFIED IDEOGRAPH-#23E89, IRGKangXi=0643.241, RSKangXi=85.10
23E8A CJK UNIFIED IDEOGRAPH-#23E8A, IRGKangXi=0643.241, RSKangXi=85.10
23E8B CJK UNIFIED IDEOGRAPH-#23E8B, IRGKangXi=0643.241, RSKangXi=85.10
23E8C CJK UNIFIED IDEOGRAPH-#23E8C, IRGKangXi=0643.241, RSKangXi=85.10
23E8D CJK UNIFIED IDEOGRAPH-#23E8D, IRGKangXi=0643.241, RSKangXi=85.10
23E8E CJK UNIFIED IDEOGRAPH-#23E8E, IRGKangXi=0643.241, RSKangXi=85.10
23E8F CJK UNIFIED IDEOGRAPH-#23E8F, IRGKangXi=0643.241, RSKangXi=85.10
23E90 CJK UNIFIED IDEOGRAPH-#23E90, IRGKangXi=0643.241, RSKangXi=85.10
23E91 CJK UNIFIED IDEOGRAPH-#23E91, IRGKangXi=0643.241, RSKangXi=85.10
23E92 CJK UNIFIED IDEOGRAPH-#23E92, IRGKangXi=0643.241, RSKangXi=85.10
23E93 CJK UNIFIED IDEOGRAPH-#23E93, IRGKangXi=0643.241, RSKangXi=85.10
23E94 CJK UNIFIED IDEOGRAPH-#23E94, IRGKangXi=0643.241, RSKangXi=85.10
23E95 CJK UNIFIED IDEOGRAPH-#23E95, IRGKangXi=0643.241, RSKangXi=85.10
23E96 CJK UNIFIED IDEOGRAPH-#23E96, IRGKangXi=0643.241, RSKangXi=85.10
23E97 CJK UNIFIED IDEOGRAPH-#23E97, IRGKangXi=0643.241, RSKangXi=85.10
23E98 CJK UNIFIED IDEOGRAPH-#23E98, IRGKangXi=0643.241, RSKangXi=85.10
23E99 CJK UNIFIED IDEOGRAPH-#23E99, IRGKangXi=0643.241, RSKangXi=85.10
23E9A CJK UNIFIED IDEOGRAPH-#23E9A, IRGKangXi=0643.241, RSKangXi=85.10
23E9B CJK UNIFIED IDEOGRAPH-#23E9B, IRGKangXi=0643.241, RSKangXi=85.10
23E9C CJK UNIFIED IDEOGRAPH-#23E9C, IRGKangXi=0643.241, RSKangXi=85.10
23E9D CJK UNIFIED IDEOGRAPH-#23E9D, IRGKangXi=0643.241, RSKangXi=85.10
23E9E CJK UNIFIED IDEOGRAPH-#23E9E, IRGKangXi=0643.241, RSKangXi=85.10
23E9F CJK UNIFIED IDEOGRAPH-#23E9F, IRGKangXi=0643.241, RSKangXi=85.10
23EA0 CJK UNIFIED IDEOGRAPH-#23EA0, IRGKangXi=0643.241, RSKangXi=85.10
23EA1 CJK UNIFIED IDEOGRAPH-#23EA1, IRGKangXi=0643.241, RSKangXi=85.10
23EA2 CJK UNIFIED IDEOGRAPH-#23EA2, IRGKangXi=0643.241, RSKangXi=85.10
23EA3 CJK UNIFIED IDEOGRAPH-#23EA3, IRGKangXi=0643.241, RSKangXi=85.10
23EA4 CJK UNIFIED IDEOGRAPH-#23EA4, IRGKangXi=0643.241, RSKangXi=85.10
23EA5 CJK UNIFIED IDEOGRAPH-#23EA5, IRGKangXi=0643.241, RSKangXi=85.10
23EA6 CJK UNIFIED IDEOGRAPH-#23EA6, IRGKangXi=0643.241, RSKangXi=85.10
23EA7 CJK UNIFIED IDEOGRAPH-#23EA7, IRGKangXi=0643.241, RSKangXi=85.10
23EA8 CJK UNIFIED IDEOGRAPH-#23EA8, IRGKangXi=0643.241, RSKangXi=85.10
23EA9 CJK UNIFIED IDEOGRAPH-#23EA9, IRGKangXi=0643.241, RSKangXi=85.10
23EAA CJK UNIFIED IDEOGRAPH-#23EAA, IRGKangXi=0643.241, RSKangXi=85.10
23EAB CJK UNIFIED IDEOGRAPH-#23EAB, IRGKangXi=0643.241, RSKangXi=85.10
23EAC CJK UNIFIED IDEOGRAPH-#23EAC, IRGKangXi=0643.241, RSKangXi=85.10
23EAD CJK UNIFIED IDEOGRAPH-#23EAD, IRGKangXi=0643.241, RSKangXi=85.10
23EAE CJK UNIFIED IDEOGRAPH-#23EAE, IRGKangXi=0643.241, RSKangXi=85.10
23EAF CJK UNIFIED IDEOGRAPH-#23EAF, IRGKangXi=0643.241, RSKangXi=85.10
23EB0 CJK UNIFIED IDEOGRAPH-#23EB0, IRGKangXi=0643.241, RSKangXi=85.10
23EB1 CJK UNIFIED IDEOGRAPH-#23EB1, IRGKangXi=0643.241, RSKangXi=85.10
23EB2 CJK UNIFIED IDEOGRAPH-#23EB2, IRGKangXi=0643.241, RSKangXi=85.10
23EB3 CJK UNIFIED IDEOGRAPH-#23EB3, IRGKangXi=0643.241, RSKangXi=85.10
23EB4 CJK UNIFIED IDEOGRAPH-#23EB4, IRGKangXi=0643.241, RSKangXi=85.10
23EB5 CJK UNIFIED IDEOGRAPH-#23EB5, IRGKangXi=0643.241, RSKangXi=85.10
23EB6 CJK UNIFIED IDEOGRAPH-#23EB6, IRGKangXi=0643.241, RSKangXi=85.10
23EB7 CJK UNIFIED IDEOGRAPH-#23EB7, IRGKangXi=0643.241, RSKangXi=85.10
23EB8 CJK UNIFIED IDEOGRAPH-#23EB8, IRGKangXi=0643.241, RSKangXi=85.10
23EB9 CJK UNIFIED IDEOGRAPH-#23EB9, IRGKangXi=0643.241, RSKangXi=85.10
23EBA CJK UNIFIED IDEOGRAPH-#23EBA, IRGKangXi=0643.241, RSKangXi=85.10
23EBB CJK UNIFIED IDEOGRAPH-#23EBB, IRGKangXi=0643.241, RSKangXi=85.10
23EBC CJK UNIFIED IDEOGRAPH-#23EBC, IRGKangXi=0643.241, RSKangXi=85.10
23EBD CJK UNIFIED IDEOGRAPH-#23EBD, IRGKangXi=0643.241, RSKangXi=85.10
23EBE CJK UNIFIED IDEOGRAPH-#23EBE, IRGKangXi=0643.241, RSKangXi=85.10
23EBF CJK UNIFIED IDEOGRAPH-#23EBF, IRGKangXi=0643.241, RSKangXi=85.10
23EC0 CJK UNIFIED IDEOGRAPH-#23EC0, IRGKangXi=0643.241, RSKangXi=85.10
23EC1 CJK UNIFIED IDEOGRAPH-#23EC1, IRGKangXi=0643.241, RSKangXi=85.10
23EC2 CJK UNIFIED IDEOGRAPH-#23EC2, IRGKangXi=0643.241, RSKangXi=85.10
23EC3 CJK UNIFIED IDEOGRAPH-#23EC3, IRGKangXi=0643.241, RSKangXi=85.10
23EC4 CJK UNIFIED IDEOGRAPH-#23EC4, IRGKangXi=0643.241, RSKangXi=85.10
23EC5 CJK UNIFIED IDEOGRAPH-#23EC5, IRGKangXi=0643.241, RSKangXi=85.10
23EC6 CJK UNIFIED IDEOGRAPH-#23EC6, IRGKangXi=0643.241, RSKangXi=85.10
23EC7 CJK UNIFIED IDEOGRAPH-#23EC7, IRGKangXi=0643.241, RSKangXi=85.10
23EC8 CJK UNIFIED IDEOGRAPH-#23EC8, IRGKangXi=0643.241, RSKangXi=85.10
23EC9 CJK UNIFIED IDEOGRAPH-#23EC9, IRGKangXi=0643.241, RSKangXi=85.10
23ECA CJK UNIFIED IDEOGRAPH-#23ECA, IRGKangXi=0643.241, RSKangXi=85.10
23ECB CJK UNIFIED IDEOGRAPH-#23ECB, IRGKangXi=0643.241, RSKangXi=85.10
23ECC CJK UNIFIED IDEOGRAPH-#23ECC, IRGKangXi=0643.241, RSKangXi=85.10
23ECD CJK UNIFIED IDEOGRAPH-#23ECD, IRGKangXi=0643.300, RSKangXi=85.11
23ECE CJK UNIFIED IDEOGRAPH-#23ECE, IRGKangXi=0643.320, RSKangXi=85.11
23ECF CJK UNIFIED IDEOGRAPH-#23ECF, IRGKangXi=0643.330, RSKangXi=85.11
23ED0 CJK UNIFIED IDEOGRAPH-#23ED0, IRGKangXi=0643.340, RSKangXi=85.11
23ED1 CJK UNIFIED IDEOGRAPH-#23ED1, IRGKangXi=0644.010, RSKangXi=85.11
23ED2 CJK UNIFIED IDEOGRAPH-#23ED2, IRGKangXi=0644.090, RSKangXi=85.11
23ED3 CJK UNIFIED IDEOGRAPH-#23ED3, IRGKangXi=0644.100, RSKangXi=85.11
23ED4 CJK UNIFIED IDEOGRAPH-#23ED4, IRGKangXi=0644.230, RSKangXi=85.11
23ED5 CJK UNIFIED IDEOGRAPH-#23ED5, IRGKangXi=0644.260, RSKangXi=85.11
23ED6 CJK UNIFIED IDEOGRAPH-#23ED6, IRGKangXi=0645.010, RSKangXi=85.11
23ED7 CJK UNIFIED IDEOGRAPH-#23ED7, IRGKangXi=0645.110, RSKangXi=85.11
23ED8 CJK UNIFIED IDEOGRAPH-#23ED8, IRGKangXi=0645.140, RSKangXi=85.11
23ED9 CJK UNIFIED IDEOGRAPH-#23ED9, IRGKangXi=0645.180, RSKangXi=85.11
23EDA CJK UNIFIED IDEOGRAPH-#23EDA, IRGKangXi=0645.190, RSKangXi=85.11
23EDB CJK UNIFIED IDEOGRAPH-#23EDB, IRGKangXi=0645.210, RSKangXi=85.11
23EDC CJK UNIFIED IDEOGRAPH-#23EDC, IRGKangXi=0645.220, RSKangXi=85.11
23EDD CJK UNIFIED IDEOGRAPH-#23EDD, IRGKangXi=0645.260, RSKangXi=85.11
23EDE CJK UNIFIED IDEOGRAPH-#23EDE, IRGKangXi=0646.010, RSKangXi=85.11
23EDF CJK UNIFIED IDEOGRAPH-#23EDF, IRGKangXi=0646.060, RSKangXi=85.11
23EE0 CJK UNIFIED IDEOGRAPH-#23EE0, IRGKangXi=0646.090, RSKangXi=85.11
23EE1 CJK UNIFIED IDEOGRAPH-#23EE1, IRGKangXi=0646.160, RSKangXi=85.11
23EE2 CJK UNIFIED IDEOGRAPH-#23EE2, IRGKangXi=0646.250, RSKangXi=85.11
23EE3 CJK UNIFIED IDEOGRAPH-#23EE3, IRGKangXi=0646.310, RSKangXi=85.11
23EE4 CJK UNIFIED IDEOGRAPH-#23EE4, IRGKangXi=0648.090, RSKangXi=85.11
23EE5 CJK UNIFIED IDEOGRAPH-#23EE5, IRGKangXi=0648.120, RSKangXi=85.11
23EE6 CJK UNIFIED IDEOGRAPH-#23EE6, IRGKangXi=0648.130, RSKangXi=85.11
23EE7 CJK UNIFIED IDEOGRAPH-#23EE7, IRGKangXi=0648.140, RSKangXi=85.11
23EE8 CJK UNIFIED IDEOGRAPH-#23EE8, IRGKangXi=0648.150, RSKangXi=85.11
23EE9 CJK UNIFIED IDEOGRAPH-#23EE9, IRGKangXi=0648.170, RSKangXi=85.11
23EEA CJK UNIFIED IDEOGRAPH-#23EEA, IRGKangXi=0648.180, RSKangXi=85.11
23EEB CJK UNIFIED IDEOGRAPH-#23EEB, IRGKangXi=0648.190, RSKangXi=85.11
23EEC CJK UNIFIED IDEOGRAPH-#23EEC, IRGKangXi=0648.210, RSKangXi=85.11
23EED CJK UNIFIED IDEOGRAPH-#23EED, IRGKangXi=0648.220, RSKangXi=85.11
23EEE CJK UNIFIED IDEOGRAPH-#23EEE, IRGKangXi=0648.230, RSKangXi=85.11
23EEF CJK UNIFIED IDEOGRAPH-#23EEF, IRGKangXi=0648.250, RSKangXi=85.11
23EF0 CJK UNIFIED IDEOGRAPH-#23EF0, IRGKangXi=0648.260, RSKangXi=85.11
23EF1 CJK UNIFIED IDEOGRAPH-#23EF1, IRGKangXi=0648.270, RSKangXi=85.11
23EF2 CJK UNIFIED IDEOGRAPH-#23EF2, IRGKangXi=0648.280, RSKangXi=85.11
23EF3 CJK UNIFIED IDEOGRAPH-#23EF3, IRGKangXi=0648.281, RSKangXi=85.11
23EF4 CJK UNIFIED IDEOGRAPH-#23EF4, IRGKangXi=0648.281, RSKangXi=85.12
23EF5 CJK UNIFIED IDEOGRAPH-#23EF5, IRGKangXi=0648.281, RSKangXi=85.11
23EF6 CJK UNIFIED IDEOGRAPH-#23EF6, IRGKangXi=0648.281, RSKangXi=85.11
23EF7 CJK UNIFIED IDEOGRAPH-#23EF7, IRGKangXi=0648.281, RSKangXi=85.11
23EF8 CJK UNIFIED IDEOGRAPH-#23EF8, IRGKangXi=0648.281, RSKangXi=85.11
23EF9 CJK UNIFIED IDEOGRAPH-#23EF9, IRGKangXi=0648.281, RSKangXi=85.11
23EFA CJK UNIFIED IDEOGRAPH-#23EFA, IRGKangXi=0648.281, RSKangXi=85.11
23EFB CJK UNIFIED IDEOGRAPH-#23EFB, IRGKangXi=0648.281, RSKangXi=85.11
23EFC CJK UNIFIED IDEOGRAPH-#23EFC, IRGKangXi=0648.281, RSKangXi=85.11
23EFD CJK UNIFIED IDEOGRAPH-#23EFD, IRGKangXi=0648.281, RSKangXi=85.11
23EFE CJK UNIFIED IDEOGRAPH-#23EFE, IRGKangXi=0648.281, RSKangXi=85.11
23EFF CJK UNIFIED IDEOGRAPH-#23EFF, IRGKangXi=0648.281, RSKangXi=85.11
23F00 CJK UNIFIED IDEOGRAPH-#23F00, IRGKangXi=0648.281, RSKangXi=85.11
23F01 CJK UNIFIED IDEOGRAPH-#23F01, IRGKangXi=0648.281, RSKangXi=85.11
23F02 CJK UNIFIED IDEOGRAPH-#23F02, IRGKangXi=0648.281, RSKangXi=85.11
23F03 CJK UNIFIED IDEOGRAPH-#23F03, IRGKangXi=0648.281, RSKangXi=85.11
23F04 CJK UNIFIED IDEOGRAPH-#23F04, IRGKangXi=0648.281, RSKangXi=85.11
23F05 CJK UNIFIED IDEOGRAPH-#23F05, IRGKangXi=0648.281, RSKangXi=85.11
23F06 CJK UNIFIED IDEOGRAPH-#23F06, IRGKangXi=0648.281, RSKangXi=85.11
23F07 CJK UNIFIED IDEOGRAPH-#23F07, IRGKangXi=0648.281, RSKangXi=85.11
23F08 CJK UNIFIED IDEOGRAPH-#23F08, IRGKangXi=0648.281, RSKangXi=85.11
23F09 CJK UNIFIED IDEOGRAPH-#23F09, IRGKangXi=0648.281, RSKangXi=85.11
23F0A CJK UNIFIED IDEOGRAPH-#23F0A, IRGKangXi=0648.281, RSKangXi=85.11
23F0B CJK UNIFIED IDEOGRAPH-#23F0B, IRGKangXi=0648.281, RSKangXi=85.11
23F0C CJK UNIFIED IDEOGRAPH-#23F0C, IRGKangXi=0648.281, RSKangXi=85.11
23F0D CJK UNIFIED IDEOGRAPH-#23F0D, IRGKangXi=0648.281, RSKangXi=85.11
23F0E CJK UNIFIED IDEOGRAPH-#23F0E, IRGKangXi=0648.281, RSKangXi=85.11
23F0F CJK UNIFIED IDEOGRAPH-#23F0F, IRGKangXi=0648.281, RSKangXi=85.11
23F10 CJK UNIFIED IDEOGRAPH-#23F10, IRGKangXi=0648.281, RSKangXi=85.11
23F11 CJK UNIFIED IDEOGRAPH-#23F11, IRGKangXi=0648.281, RSKangXi=85.11
23F12 CJK UNIFIED IDEOGRAPH-#23F12, IRGKangXi=0648.281, RSKangXi=85.11
23F13 CJK UNIFIED IDEOGRAPH-#23F13, IRGKangXi=0648.281, RSKangXi=85.11
23F14 CJK UNIFIED IDEOGRAPH-#23F14, IRGKangXi=0648.281, RSKangXi=85.11
23F15 CJK UNIFIED IDEOGRAPH-#23F15, IRGKangXi=0648.281, RSKangXi=85.11
23F16 CJK UNIFIED IDEOGRAPH-#23F16, IRGKangXi=0648.281, RSKangXi=85.11
23F17 CJK UNIFIED IDEOGRAPH-#23F17, IRGKangXi=0648.281, RSKangXi=85.11
23F18 CJK UNIFIED IDEOGRAPH-#23F18, IRGKangXi=0648.281, RSKangXi=85.11
23F19 CJK UNIFIED IDEOGRAPH-#23F19, IRGKangXi=0648.281, RSKangXi=58.12
23F1A CJK UNIFIED IDEOGRAPH-#23F1A, IRGKangXi=0648.281, RSKangXi=85.11
23F1B CJK UNIFIED IDEOGRAPH-#23F1B, IRGKangXi=0648.281, RSKangXi=85.11
23F1C CJK UNIFIED IDEOGRAPH-#23F1C, IRGKangXi=0648.281, RSKangXi=85.11
23F1D CJK UNIFIED IDEOGRAPH-#23F1D, IRGKangXi=0648.281, RSKangXi=85.11
23F1E CJK UNIFIED IDEOGRAPH-#23F1E, IRGKangXi=0648.281, RSKangXi=85.11
23F1F CJK UNIFIED IDEOGRAPH-#23F1F, IRGKangXi=0648.281, RSKangXi=85.11
23F20 CJK UNIFIED IDEOGRAPH-#23F20, IRGKangXi=0648.281, RSKangXi=85.11
23F21 CJK UNIFIED IDEOGRAPH-#23F21, IRGKangXi=0648.281, RSKangXi=85.11
23F22 CJK UNIFIED IDEOGRAPH-#23F22, IRGKangXi=0648.281, RSKangXi=85.11
23F23 CJK UNIFIED IDEOGRAPH-#23F23, IRGKangXi=0648.281, RSKangXi=85.11
23F24 CJK UNIFIED IDEOGRAPH-#23F24, IRGKangXi=0648.281, RSKangXi=85.11
23F25 CJK UNIFIED IDEOGRAPH-#23F25, IRGKangXi=0648.281, RSKangXi=85.11
23F26 CJK UNIFIED IDEOGRAPH-#23F26, IRGKangXi=0648.281, RSKangXi=85.11
23F27 CJK UNIFIED IDEOGRAPH-#23F27, IRGKangXi=0648.281, RSKangXi=85.11
23F28 CJK UNIFIED IDEOGRAPH-#23F28, IRGKangXi=0648.281, RSKangXi=85.11
23F29 CJK UNIFIED IDEOGRAPH-#23F29, IRGKangXi=0648.281, RSKangXi=85.11
23F2A CJK UNIFIED IDEOGRAPH-#23F2A, IRGKangXi=0648.281, RSKangXi=85.11
23F2B CJK UNIFIED IDEOGRAPH-#23F2B, IRGKangXi=0648.281, RSKangXi=85.11
23F2C CJK UNIFIED IDEOGRAPH-#23F2C, IRGKangXi=0648.281, RSKangXi=85.11
23F2D CJK UNIFIED IDEOGRAPH-#23F2D, IRGKangXi=0648.281, RSKangXi=85.11
23F2E CJK UNIFIED IDEOGRAPH-#23F2E, IRGKangXi=0648.281, RSKangXi=85.11
23F2F CJK UNIFIED IDEOGRAPH-#23F2F, IRGKangXi=0648.281, RSKangXi=85.11
23F30 CJK UNIFIED IDEOGRAPH-#23F30, IRGKangXi=0648.281, RSKangXi=85.11
23F31 CJK UNIFIED IDEOGRAPH-#23F31, IRGKangXi=0648.281, RSKangXi=85.11
23F32 CJK UNIFIED IDEOGRAPH-#23F32, IRGKangXi=0648.281, RSKangXi=85.11
23F33 CJK UNIFIED IDEOGRAPH-#23F33, IRGKangXi=0648.281, RSKangXi=85.11
23F34 CJK UNIFIED IDEOGRAPH-#23F34, IRGKangXi=0648.281, RSKangXi=85.11
23F35 CJK UNIFIED IDEOGRAPH-#23F35, IRGKangXi=0648.281, RSKangXi=85.11
23F36 CJK UNIFIED IDEOGRAPH-#23F36, IRGKangXi=0648.281, RSKangXi=85.11
23F37 CJK UNIFIED IDEOGRAPH-#23F37, IRGKangXi=0648.281, RSKangXi=85.11
23F38 CJK UNIFIED IDEOGRAPH-#23F38, IRGKangXi=0648.281, RSKangXi=85.11
23F39 CJK UNIFIED IDEOGRAPH-#23F39, IRGKangXi=0648.281, RSKangXi=85.11
23F3A CJK UNIFIED IDEOGRAPH-#23F3A, IRGKangXi=0648.281, RSKangXi=85.11
23F3B CJK UNIFIED IDEOGRAPH-#23F3B, IRGKangXi=0648.281, RSKangXi=85.11
23F3C CJK UNIFIED IDEOGRAPH-#23F3C, IRGKangXi=0648.281, RSKangXi=85.11
23F3D CJK UNIFIED IDEOGRAPH-#23F3D, IRGKangXi=0648.281, RSKangXi=85.11
23F3E CJK UNIFIED IDEOGRAPH-#23F3E, IRGKangXi=0648.281, RSKangXi=85.11
23F3F CJK UNIFIED IDEOGRAPH-#23F3F, IRGKangXi=0648.281, RSKangXi=85.11
23F40 CJK UNIFIED IDEOGRAPH-#23F40, IRGKangXi=0648.281, RSKangXi=85.11
23F41 CJK UNIFIED IDEOGRAPH-#23F41, IRGKangXi=0648.281, RSKangXi=85.11
23F42 CJK UNIFIED IDEOGRAPH-#23F42, IRGKangXi=0648.281, RSKangXi=85.11
23F43 CJK UNIFIED IDEOGRAPH-#23F43, IRGKangXi=0648.310, RSKangXi=85.12
23F44 CJK UNIFIED IDEOGRAPH-#23F44, IRGKangXi=0648.330, RSKangXi=85.12
23F45 CJK UNIFIED IDEOGRAPH-#23F45, IRGKangXi=0648.390, RSKangXi=85.12
23F46 CJK UNIFIED IDEOGRAPH-#23F46, IRGKangXi=0649.060, RSKangXi=85.12
23F47 CJK UNIFIED IDEOGRAPH-#23F47, IRGKangXi=0649.130, RSKangXi=85.12
23F48 CJK UNIFIED IDEOGRAPH-#23F48, IRGKangXi=0649.140, RSKangXi=85.12
23F49 CJK UNIFIED IDEOGRAPH-#23F49, IRGKangXi=0649.150, RSKangXi=85.12
23F4A CJK UNIFIED IDEOGRAPH-#23F4A, IRGKangXi=0649.190, RSKangXi=85.12
23F4B CJK UNIFIED IDEOGRAPH-#23F4B, IRGKangXi=0649.260, RSKangXi=85.12
23F4C CJK UNIFIED IDEOGRAPH-#23F4C, IRGKangXi=0649.270, RSKangXi=85.12
23F4D CJK UNIFIED IDEOGRAPH-#23F4D, IRGKangXi=0650.030, RSKangXi=85.12
23F4E CJK UNIFIED IDEOGRAPH-#23F4E, IRGKangXi=0650.050, RSKangXi=85.12
23F4F CJK UNIFIED IDEOGRAPH-#23F4F, IRGKangXi=0650.060, RSKangXi=85.12
23F50 CJK UNIFIED IDEOGRAPH-#23F50, IRGKangXi=0650.150, RSKangXi=85.12
23F51 CJK UNIFIED IDEOGRAPH-#23F51, IRGKangXi=0650.160, RSKangXi=85.12
23F52 CJK UNIFIED IDEOGRAPH-#23F52, IRGKangXi=0650.170, RSKangXi=85.12
23F53 CJK UNIFIED IDEOGRAPH-#23F53, IRGKangXi=0650.200, RSKangXi=85.12
23F54 CJK UNIFIED IDEOGRAPH-#23F54, IRGKangXi=0650.210, RSKangXi=85.12
23F55 CJK UNIFIED IDEOGRAPH-#23F55, IRGKangXi=0650.260, RSKangXi=85.12
23F56 CJK UNIFIED IDEOGRAPH-#23F56, IRGKangXi=0651.030, RSKangXi=85.12
23F57 CJK UNIFIED IDEOGRAPH-#23F57, IRGKangXi=0651.050, RSKangXi=85.12
23F58 CJK UNIFIED IDEOGRAPH-#23F58, IRGKangXi=0651.080, RSKangXi=85.12
23F59 CJK UNIFIED IDEOGRAPH-#23F59, IRGKangXi=0651.100, RSKangXi=85.12
23F5A CJK UNIFIED IDEOGRAPH-#23F5A, IRGKangXi=0651.120, RSKangXi=85.12
23F5B CJK UNIFIED IDEOGRAPH-#23F5B, IRGKangXi=0651.150, RSKangXi=85.12
23F5C CJK UNIFIED IDEOGRAPH-#23F5C, IRGKangXi=0651.160, RSKangXi=85.12
23F5D CJK UNIFIED IDEOGRAPH-#23F5D, IRGKangXi=0651.180, RSKangXi=85.12
23F5E CJK UNIFIED IDEOGRAPH-#23F5E, IRGKangXi=0651.330, RSKangXi=85.12
23F5F CJK UNIFIED IDEOGRAPH-#23F5F, IRGKangXi=0651.340, RSKangXi=85.12
23F60 CJK UNIFIED IDEOGRAPH-#23F60, IRGKangXi=0651.350, RSKangXi=85.12
23F61 CJK UNIFIED IDEOGRAPH-#23F61, IRGKangXi=0652.020, RSKangXi=85.12
23F62 CJK UNIFIED IDEOGRAPH-#23F62, IRGKangXi=0652.030, RSKangXi=85.12
23F63 CJK UNIFIED IDEOGRAPH-#23F63, IRGKangXi=0652.110, RSKangXi=85.12
23F64 CJK UNIFIED IDEOGRAPH-#23F64, IRGKangXi=0652.120, RSKangXi=85.12
23F65 CJK UNIFIED IDEOGRAPH-#23F65, IRGKangXi=0652.130, RSKangXi=85.12
23F66 CJK UNIFIED IDEOGRAPH-#23F66, IRGKangXi=0652.140, RSKangXi=85.12
23F67 CJK UNIFIED IDEOGRAPH-#23F67, IRGKangXi=0652.150, RSKangXi=85.12
23F68 CJK UNIFIED IDEOGRAPH-#23F68, IRGKangXi=0652.160, RSKangXi=85.12
23F69 CJK UNIFIED IDEOGRAPH-#23F69, IRGKangXi=0652.170, RSKangXi=85.12
23F6A CJK UNIFIED IDEOGRAPH-#23F6A, IRGKangXi=0652.180, RSKangXi=85.12
23F6B CJK UNIFIED IDEOGRAPH-#23F6B, IRGKangXi=0652.200, RSKangXi=85.12
23F6C CJK UNIFIED IDEOGRAPH-#23F6C, IRGKangXi=0652.220, RSKangXi=85.12
23F6D CJK UNIFIED IDEOGRAPH-#23F6D, IRGKangXi=0652.230, RSKangXi=85.12
23F6E CJK UNIFIED IDEOGRAPH-#23F6E, IRGKangXi=0652.240, RSKangXi=85.12
23F6F CJK UNIFIED IDEOGRAPH-#23F6F, IRGKangXi=0652.250, RSKangXi=85.12
23F70 CJK UNIFIED IDEOGRAPH-#23F70, IRGKangXi=0652.260, RSKangXi=85.12
23F71 CJK UNIFIED IDEOGRAPH-#23F71, IRGKangXi=0652.270, RSKangXi=85.12
23F72 CJK UNIFIED IDEOGRAPH-#23F72, IRGKangXi=0652.280, RSKangXi=85.12
23F73 CJK UNIFIED IDEOGRAPH-#23F73, IRGKangXi=0652.290, RSKangXi=85.12
23F74 CJK UNIFIED IDEOGRAPH-#23F74, IRGKangXi=0652.300, RSKangXi=85.12
23F75 CJK UNIFIED IDEOGRAPH-#23F75, IRGKangXi=0652.310, RSKangXi=85.12
23F76 CJK UNIFIED IDEOGRAPH-#23F76, IRGKangXi=0652.320, RSKangXi=85.12
23F77 CJK UNIFIED IDEOGRAPH-#23F77, IRGKangXi=0652.321, RSKangXi=85.12
23F78 CJK UNIFIED IDEOGRAPH-#23F78, IRGKangXi=0652.321, RSKangXi=85.12
23F79 CJK UNIFIED IDEOGRAPH-#23F79, IRGKangXi=0652.321, RSKangXi=85.12
23F7A CJK UNIFIED IDEOGRAPH-#23F7A, IRGKangXi=0652.321, RSKangXi=85.12
23F7B CJK UNIFIED IDEOGRAPH-#23F7B, IRGKangXi=0652.321, RSKangXi=85.12
23F7C CJK UNIFIED IDEOGRAPH-#23F7C, IRGKangXi=0652.321, RSKangXi=85.12
23F7D CJK UNIFIED IDEOGRAPH-#23F7D, IRGKangXi=0652.321, RSKangXi=85.12
23F7E CJK UNIFIED IDEOGRAPH-#23F7E, IRGKangXi=0652.321, RSKangXi=85.12
23F7F CJK UNIFIED IDEOGRAPH-#23F7F, IRGKangXi=0652.321, RSKangXi=85.12
23F80 CJK UNIFIED IDEOGRAPH-#23F80, IRGKangXi=0652.321, RSKangXi=85.12
23F81 CJK UNIFIED IDEOGRAPH-#23F81, IRGKangXi=0652.321, RSKangXi=85.12
23F82 CJK UNIFIED IDEOGRAPH-#23F82, IRGKangXi=0652.321, RSKangXi=85.12
23F83 CJK UNIFIED IDEOGRAPH-#23F83, IRGKangXi=0652.321, RSKangXi=85.12
23F84 CJK UNIFIED IDEOGRAPH-#23F84, IRGKangXi=0652.321, RSKangXi=85.12
23F85 CJK UNIFIED IDEOGRAPH-#23F85, IRGKangXi=0652.321, RSKangXi=85.12
23F86 CJK UNIFIED IDEOGRAPH-#23F86, IRGKangXi=0652.321, RSKangXi=85.12
23F87 CJK UNIFIED IDEOGRAPH-#23F87, IRGKangXi=0652.321, RSKangXi=85.12
23F88 CJK UNIFIED IDEOGRAPH-#23F88, IRGKangXi=0652.321, RSKangXi=85.12
23F89 CJK UNIFIED IDEOGRAPH-#23F89, IRGKangXi=0652.321, RSKangXi=85.12
23F8A CJK UNIFIED IDEOGRAPH-#23F8A, IRGKangXi=0652.321, RSKangXi=85.12
23F8B CJK UNIFIED IDEOGRAPH-#23F8B, IRGKangXi=0652.321, RSKangXi=85.12
23F8C CJK UNIFIED IDEOGRAPH-#23F8C, IRGKangXi=0652.321, RSKangXi=85.12
23F8D CJK UNIFIED IDEOGRAPH-#23F8D, IRGKangXi=0652.321, RSKangXi=85.12
23F8E CJK UNIFIED IDEOGRAPH-#23F8E, IRGKangXi=0652.321, RSKangXi=85.12
23F8F CJK UNIFIED IDEOGRAPH-#23F8F, IRGKangXi=0652.321, RSKangXi=85.12
23F90 CJK UNIFIED IDEOGRAPH-#23F90, IRGKangXi=0652.321, RSKangXi=85.12
23F91 CJK UNIFIED IDEOGRAPH-#23F91, IRGKangXi=0652.321, RSKangXi=85.12
23F92 CJK UNIFIED IDEOGRAPH-#23F92, IRGKangXi=0652.321, RSKangXi=85.12
23F93 CJK UNIFIED IDEOGRAPH-#23F93, IRGKangXi=0652.321, RSKangXi=85.12
23F94 CJK UNIFIED IDEOGRAPH-#23F94, IRGKangXi=0652.321, RSKangXi=85.12
23F95 CJK UNIFIED IDEOGRAPH-#23F95, IRGKangXi=0652.321, RSKangXi=85.12
23F96 CJK UNIFIED IDEOGRAPH-#23F96, IRGKangXi=0652.321, RSKangXi=85.12
23F97 CJK UNIFIED IDEOGRAPH-#23F97, IRGKangXi=0652.321, RSKangXi=85.12
23F98 CJK UNIFIED IDEOGRAPH-#23F98, IRGKangXi=0652.321, RSKangXi=85.12
23F99 CJK UNIFIED IDEOGRAPH-#23F99, IRGKangXi=0652.321, RSKangXi=85.12
23F9A CJK UNIFIED IDEOGRAPH-#23F9A, IRGKangXi=0652.321, RSKangXi=85.12
23F9B CJK UNIFIED IDEOGRAPH-#23F9B, IRGKangXi=0652.321, RSKangXi=85.12
23F9C CJK UNIFIED IDEOGRAPH-#23F9C, IRGKangXi=0652.321, RSKangXi=85.12
23F9D CJK UNIFIED IDEOGRAPH-#23F9D, IRGKangXi=0652.321, RSKangXi=85.12
23F9E CJK UNIFIED IDEOGRAPH-#23F9E, IRGKangXi=0652.321, RSKangXi=85.12
23F9F CJK UNIFIED IDEOGRAPH-#23F9F, IRGKangXi=0652.321, RSKangXi=85.12
23FA0 CJK UNIFIED IDEOGRAPH-#23FA0, IRGKangXi=0652.321, RSKangXi=85.12
23FA1 CJK UNIFIED IDEOGRAPH-#23FA1, IRGKangXi=0652.321, RSKangXi=85.12
23FA2 CJK UNIFIED IDEOGRAPH-#23FA2, IRGKangXi=0652.321, RSKangXi=85.12
23FA3 CJK UNIFIED IDEOGRAPH-#23FA3, IRGKangXi=0652.321, RSKangXi=85.12
23FA4 CJK UNIFIED IDEOGRAPH-#23FA4, IRGKangXi=0652.321, RSKangXi=85.12
23FA5 CJK UNIFIED IDEOGRAPH-#23FA5, IRGKangXi=0652.321, RSKangXi=85.12
23FA6 CJK UNIFIED IDEOGRAPH-#23FA6, IRGKangXi=0652.321, RSKangXi=85.12
23FA7 CJK UNIFIED IDEOGRAPH-#23FA7, IRGKangXi=0652.321, RSKangXi=85.12
23FA8 CJK UNIFIED IDEOGRAPH-#23FA8, IRGKangXi=0652.321, RSKangXi=85.12
23FA9 CJK UNIFIED IDEOGRAPH-#23FA9, IRGKangXi=0652.321, RSKangXi=85.13
23FAA CJK UNIFIED IDEOGRAPH-#23FAA, IRGKangXi=0652.321, RSKangXi=85.12
23FAB CJK UNIFIED IDEOGRAPH-#23FAB, IRGKangXi=0652.321, RSKangXi=85.12
23FAC CJK UNIFIED IDEOGRAPH-#23FAC, IRGKangXi=0652.321, RSKangXi=85.12
23FAD CJK UNIFIED IDEOGRAPH-#23FAD, IRGKangXi=0652.321, RSKangXi=85.12
23FAE CJK UNIFIED IDEOGRAPH-#23FAE, IRGKangXi=0652.321, RSKangXi=85.12
23FAF CJK UNIFIED IDEOGRAPH-#23FAF, IRGKangXi=0652.321, RSKangXi=85.12
23FB0 CJK UNIFIED IDEOGRAPH-#23FB0, IRGKangXi=0652.321, RSKangXi=85.12
23FB1 CJK UNIFIED IDEOGRAPH-#23FB1, IRGKangXi=0652.321, RSKangXi=85.12
23FB2 CJK UNIFIED IDEOGRAPH-#23FB2, IRGKangXi=0652.321, RSKangXi=85.12
23FB3 CJK UNIFIED IDEOGRAPH-#23FB3, IRGKangXi=0652.321, RSKangXi=85.12
23FB4 CJK UNIFIED IDEOGRAPH-#23FB4, IRGKangXi=0652.321, RSKangXi=85.12
23FB5 CJK UNIFIED IDEOGRAPH-#23FB5, IRGKangXi=0652.321, RSKangXi=85.12
23FB6 CJK UNIFIED IDEOGRAPH-#23FB6, IRGKangXi=0652.321, RSKangXi=85.12
23FB7 CJK UNIFIED IDEOGRAPH-#23FB7, IRGKangXi=0652.321, RSKangXi=85.12
23FB8 CJK UNIFIED IDEOGRAPH-#23FB8, IRGKangXi=0652.321, RSKangXi=85.12
23FB9 CJK UNIFIED IDEOGRAPH-#23FB9, IRGKangXi=0652.321, RSKangXi=85.12
23FBA CJK UNIFIED IDEOGRAPH-#23FBA, IRGKangXi=0652.321, RSKangXi=85.12
23FBB CJK UNIFIED IDEOGRAPH-#23FBB, IRGKangXi=0652.321, RSKangXi=85.12
23FBC CJK UNIFIED IDEOGRAPH-#23FBC, IRGKangXi=0652.321, RSKangXi=85.12
23FBD CJK UNIFIED IDEOGRAPH-#23FBD, IRGKangXi=0652.321, RSKangXi=85.12
23FBE CJK UNIFIED IDEOGRAPH-#23FBE, IRGKangXi=0652.321, RSKangXi=85.12
23FBF CJK UNIFIED IDEOGRAPH-#23FBF, IRGKangXi=0652.321, RSKangXi=85.12
23FC0 CJK UNIFIED IDEOGRAPH-#23FC0, IRGKangXi=0652.321, RSKangXi=85.14
23FC1 CJK UNIFIED IDEOGRAPH-#23FC1, IRGKangXi=0652.321, RSKangXi=85.12
23FC2 CJK UNIFIED IDEOGRAPH-#23FC2, IRGKangXi=0652.321, RSKangXi=85.12
23FC3 CJK UNIFIED IDEOGRAPH-#23FC3, IRGKangXi=0652.321, RSKangXi=85.12
23FC4 CJK UNIFIED IDEOGRAPH-#23FC4, IRGKangXi=0652.321, RSKangXi=85.12
23FC5 CJK UNIFIED IDEOGRAPH-#23FC5, IRGKangXi=0652.330, RSKangXi=85.13
23FC6 CJK UNIFIED IDEOGRAPH-#23FC6, IRGKangXi=0652.340, RSKangXi=85.13
23FC7 CJK UNIFIED IDEOGRAPH-#23FC7, IRGKangXi=0652.350, RSKangXi=85.13
23FC8 CJK UNIFIED IDEOGRAPH-#23FC8, IRGKangXi=0652.410, RSKangXi=85.13
23FC9 CJK UNIFIED IDEOGRAPH-#23FC9, IRGKangXi=0653.020, RSKangXi=85.13
23FCA CJK UNIFIED IDEOGRAPH-#23FCA, IRGKangXi=0653.060, RSKangXi=85.13
23FCB CJK UNIFIED IDEOGRAPH-#23FCB, IRGKangXi=0653.090, RSKangXi=85.13
23FCC CJK UNIFIED IDEOGRAPH-#23FCC, IRGKangXi=0653.130, RSKangXi=85.13
23FCD CJK UNIFIED IDEOGRAPH-#23FCD, IRGKangXi=0653.330, RSKangXi=85.13
23FCE CJK UNIFIED IDEOGRAPH-#23FCE, IRGKangXi=0653.350, RSKangXi=85.13
23FCF CJK UNIFIED IDEOGRAPH-#23FCF, IRGKangXi=0654.020, RSKangXi=85.13
23FD0 CJK UNIFIED IDEOGRAPH-#23FD0, IRGKangXi=0654.040, RSKangXi=85.13
23FD1 CJK UNIFIED IDEOGRAPH-#23FD1, IRGKangXi=0654.090, RSKangXi=85.13
23FD2 CJK UNIFIED IDEOGRAPH-#23FD2, IRGKangXi=0654.100, RSKangXi=85.13
23FD3 CJK UNIFIED IDEOGRAPH-#23FD3, IRGKangXi=0654.110, RSKangXi=85.13
23FD4 CJK UNIFIED IDEOGRAPH-#23FD4, IRGKangXi=0654.140, RSKangXi=85.13
23FD5 CJK UNIFIED IDEOGRAPH-#23FD5, IRGKangXi=0654.230, RSKangXi=85.13
23FD6 CJK UNIFIED IDEOGRAPH-#23FD6, IRGKangXi=0654.260, RSKangXi=85.13
23FD7 CJK UNIFIED IDEOGRAPH-#23FD7, IRGKangXi=0654.310, RSKangXi=85.13
23FD8 CJK UNIFIED IDEOGRAPH-#23FD8, IRGKangXi=0654.320, RSKangXi=85.13
23FD9 CJK UNIFIED IDEOGRAPH-#23FD9, IRGKangXi=0655.050, RSKangXi=85.13
23FDA CJK UNIFIED IDEOGRAPH-#23FDA, IRGKangXi=0655.060, RSKangXi=85.13
23FDB CJK UNIFIED IDEOGRAPH-#23FDB, IRGKangXi=0655.080, RSKangXi=85.13
23FDC CJK UNIFIED IDEOGRAPH-#23FDC, IRGKangXi=0655.090, RSKangXi=85.13
23FDD CJK UNIFIED IDEOGRAPH-#23FDD, IRGKangXi=0655.110, RSKangXi=85.13
23FDE CJK UNIFIED IDEOGRAPH-#23FDE, IRGKangXi=0655.120, RSKangXi=85.13
23FDF CJK UNIFIED IDEOGRAPH-#23FDF, IRGKangXi=0655.130, RSKangXi=85.13
23FE0 CJK UNIFIED IDEOGRAPH-#23FE0, IRGKangXi=0655.140, RSKangXi=85.13
23FE1 CJK UNIFIED IDEOGRAPH-#23FE1, IRGKangXi=0655.150, RSKangXi=85.13
23FE2 CJK UNIFIED IDEOGRAPH-#23FE2, IRGKangXi=0655.160, RSKangXi=85.13
23FE3 CJK UNIFIED IDEOGRAPH-#23FE3, IRGKangXi=0655.170, RSKangXi=85.13
23FE4 CJK UNIFIED IDEOGRAPH-#23FE4, IRGKangXi=0655.180, RSKangXi=85.13
23FE5 CJK UNIFIED IDEOGRAPH-#23FE5, IRGKangXi=0655.190, RSKangXi=85.13
23FE6 CJK UNIFIED IDEOGRAPH-#23FE6, IRGKangXi=0655.201, RSKangXi=85.13
23FE7 CJK UNIFIED IDEOGRAPH-#23FE7, IRGKangXi=0655.201, RSKangXi=85.13
23FE8 CJK UNIFIED IDEOGRAPH-#23FE8, IRGKangXi=0655.201, RSKangXi=85.13
23FE9 CJK UNIFIED IDEOGRAPH-#23FE9, IRGKangXi=0655.201, RSKangXi=85.13
23FEA CJK UNIFIED IDEOGRAPH-#23FEA, IRGKangXi=0655.201, RSKangXi=85.13
23FEB CJK UNIFIED IDEOGRAPH-#23FEB, IRGKangXi=0655.201, RSKangXi=85.13
23FEC CJK UNIFIED IDEOGRAPH-#23FEC, IRGKangXi=0655.201, RSKangXi=85.13
23FED CJK UNIFIED IDEOGRAPH-#23FED, IRGKangXi=0655.201, RSKangXi=85.13
23FEE CJK UNIFIED IDEOGRAPH-#23FEE, IRGKangXi=0655.201, RSKangXi=85.13
23FEF CJK UNIFIED IDEOGRAPH-#23FEF, IRGKangXi=0655.201, RSKangXi=85.13
23FF0 CJK UNIFIED IDEOGRAPH-#23FF0, IRGKangXi=0655.201, RSKangXi=85.13
23FF1 CJK UNIFIED IDEOGRAPH-#23FF1, IRGKangXi=0655.201, RSKangXi=85.13
23FF2 CJK UNIFIED IDEOGRAPH-#23FF2, IRGKangXi=0655.201, RSKangXi=85.13
23FF3 CJK UNIFIED IDEOGRAPH-#23FF3, IRGKangXi=0655.201, RSKangXi=85.13
23FF4 CJK UNIFIED IDEOGRAPH-#23FF4, IRGKangXi=0655.201, RSKangXi=85.13
23FF5 CJK UNIFIED IDEOGRAPH-#23FF5, IRGKangXi=0655.201, RSKangXi=85.13
23FF6 CJK UNIFIED IDEOGRAPH-#23FF6, IRGKangXi=0655.201, RSKangXi=85.13
23FF7 CJK UNIFIED IDEOGRAPH-#23FF7, IRGKangXi=0655.201, RSKangXi=85.13
23FF8 CJK UNIFIED IDEOGRAPH-#23FF8, IRGKangXi=0655.201, RSKangXi=85.13
23FF9 CJK UNIFIED IDEOGRAPH-#23FF9, IRGKangXi=0655.201, RSKangXi=85.13
23FFA CJK UNIFIED IDEOGRAPH-#23FFA, IRGKangXi=0655.201, RSKangXi=85.13
23FFB CJK UNIFIED IDEOGRAPH-#23FFB, IRGKangXi=0655.201, RSKangXi=85.13
23FFC CJK UNIFIED IDEOGRAPH-#23FFC, IRGKangXi=0655.201, RSKangXi=85.13
23FFD CJK UNIFIED IDEOGRAPH-#23FFD, IRGKangXi=0655.201, RSKangXi=85.13
23FFE CJK UNIFIED IDEOGRAPH-#23FFE, IRGKangXi=0655.201, RSKangXi=85.13
23FFF CJK UNIFIED IDEOGRAPH-#23FFF, IRGKangXi=0655.201, RSKangXi=85.13
24000 CJK UNIFIED IDEOGRAPH-#24000, IRGKangXi=0655.201, RSKangXi=85.13
24001 CJK UNIFIED IDEOGRAPH-#24001, IRGKangXi=0655.201, RSKangXi=85.13
24002 CJK UNIFIED IDEOGRAPH-#24002, IRGKangXi=0655.201, RSKangXi=85.13
24003 CJK UNIFIED IDEOGRAPH-#24003, IRGKangXi=0655.201, RSKangXi=85.13
24004 CJK UNIFIED IDEOGRAPH-#24004, IRGKangXi=0655.201, RSKangXi=85.13
24005 CJK UNIFIED IDEOGRAPH-#24005, IRGKangXi=0655.201, RSKangXi=85.13
24006 CJK UNIFIED IDEOGRAPH-#24006, IRGKangXi=0655.201, RSKangXi=85.13
24007 CJK UNIFIED IDEOGRAPH-#24007, IRGKangXi=0655.201, RSKangXi=85.13
24008 CJK UNIFIED IDEOGRAPH-#24008, IRGKangXi=0655.201, RSKangXi=85.13
24009 CJK UNIFIED IDEOGRAPH-#24009, IRGKangXi=0655.201, RSKangXi=85.13
2400A CJK UNIFIED IDEOGRAPH-#2400A, IRGKangXi=0655.201, RSKangXi=85.13
2400B CJK UNIFIED IDEOGRAPH-#2400B, IRGKangXi=0655.201, RSKangXi=85.13
2400C CJK UNIFIED IDEOGRAPH-#2400C, IRGKangXi=0655.201, RSKangXi=85.13
2400D CJK UNIFIED IDEOGRAPH-#2400D, IRGKangXi=0655.201, RSKangXi=85.13
2400E CJK UNIFIED IDEOGRAPH-#2400E, IRGKangXi=0655.201, RSKangXi=85.13
2400F CJK UNIFIED IDEOGRAPH-#2400F, IRGKangXi=0655.201, RSKangXi=85.13
24010 CJK UNIFIED IDEOGRAPH-#24010, IRGKangXi=0655.201, RSKangXi=85.13
24011 CJK UNIFIED IDEOGRAPH-#24011, IRGKangXi=0655.201, RSKangXi=85.13
24012 CJK UNIFIED IDEOGRAPH-#24012, IRGKangXi=0655.201, RSKangXi=85.13
24013 CJK UNIFIED IDEOGRAPH-#24013, IRGKangXi=0655.201, RSKangXi=85.13
24014 CJK UNIFIED IDEOGRAPH-#24014, IRGKangXi=0655.201, RSKangXi=85.13
24015 CJK UNIFIED IDEOGRAPH-#24015, IRGKangXi=0655.201, RSKangXi=85.13
24016 CJK UNIFIED IDEOGRAPH-#24016, IRGKangXi=0655.201, RSKangXi=85.13
24017 CJK UNIFIED IDEOGRAPH-#24017, IRGKangXi=0655.201, RSKangXi=85.13
24018 CJK UNIFIED IDEOGRAPH-#24018, IRGKangXi=0655.201, RSKangXi=85.13
24019 CJK UNIFIED IDEOGRAPH-#24019, IRGKangXi=0655.201, RSKangXi=85.13
2401A CJK UNIFIED IDEOGRAPH-#2401A, IRGKangXi=0655.201, RSKangXi=85.13
2401B CJK UNIFIED IDEOGRAPH-#2401B, IRGKangXi=0655.201, RSKangXi=85.13
2401C CJK UNIFIED IDEOGRAPH-#2401C, IRGKangXi=0655.201, RSKangXi=85.13
2401D CJK UNIFIED IDEOGRAPH-#2401D, IRGKangXi=0655.201, RSKangXi=85.13
2401E CJK UNIFIED IDEOGRAPH-#2401E, IRGKangXi=0655.201, RSKangXi=85.13
2401F CJK UNIFIED IDEOGRAPH-#2401F, IRGKangXi=0655.201, RSKangXi=85.13
24020 CJK UNIFIED IDEOGRAPH-#24020, IRGKangXi=0655.201, RSKangXi=85.13
24021 CJK UNIFIED IDEOGRAPH-#24021, IRGKangXi=0655.201, RSKangXi=85.13
24022 CJK UNIFIED IDEOGRAPH-#24022, IRGKangXi=0655.201, RSKangXi=48.13
24023 CJK UNIFIED IDEOGRAPH-#24023, IRGKangXi=0655.340, RSKangXi=85.14
24024 CJK UNIFIED IDEOGRAPH-#24024, IRGKangXi=0656.040, RSKangXi=85.14
24025 CJK UNIFIED IDEOGRAPH-#24025, IRGKangXi=0656.050, RSKangXi=85.14
24026 CJK UNIFIED IDEOGRAPH-#24026, IRGKangXi=0656.110, RSKangXi=85.14
24027 CJK UNIFIED IDEOGRAPH-#24027, IRGKangXi=0656.170, RSKangXi=85.14
24028 CJK UNIFIED IDEOGRAPH-#24028, IRGKangXi=0657.010, RSKangXi=85.14
24029 CJK UNIFIED IDEOGRAPH-#24029, IRGKangXi=0657.040, RSKangXi=85.14
2402A CJK UNIFIED IDEOGRAPH-#2402A, IRGKangXi=0657.050, RSKangXi=85.14
2402B CJK UNIFIED IDEOGRAPH-#2402B, IRGKangXi=0657.130, RSKangXi=85.14
2402C CJK UNIFIED IDEOGRAPH-#2402C, IRGKangXi=0657.140, RSKangXi=85.14
2402D CJK UNIFIED IDEOGRAPH-#2402D, IRGKangXi=0657.170, RSKangXi=85.14
2402E CJK UNIFIED IDEOGRAPH-#2402E, IRGKangXi=0657.180, RSKangXi=85.14
2402F CJK UNIFIED IDEOGRAPH-#2402F, IRGKangXi=0657.190, RSKangXi=85.14
24030 CJK UNIFIED IDEOGRAPH-#24030, IRGKangXi=0657.250, RSKangXi=85.14
24031 CJK UNIFIED IDEOGRAPH-#24031, IRGKangXi=0657.270, RSKangXi=85.14
24032 CJK UNIFIED IDEOGRAPH-#24032, IRGKangXi=0657.310, RSKangXi=85.14
24033 CJK UNIFIED IDEOGRAPH-#24033, IRGKangXi=0657.320, RSKangXi=85.14
24034 CJK UNIFIED IDEOGRAPH-#24034, IRGKangXi=0657.330, RSKangXi=85.14
24035 CJK UNIFIED IDEOGRAPH-#24035, IRGKangXi=0657.340, RSKangXi=85.14
24036 CJK UNIFIED IDEOGRAPH-#24036, IRGKangXi=0657.350, RSKangXi=85.14
24037 CJK UNIFIED IDEOGRAPH-#24037, IRGKangXi=0657.360, RSKangXi=85.14
24038 CJK UNIFIED IDEOGRAPH-#24038, IRGKangXi=0657.361, RSKangXi=85.14
24039 CJK UNIFIED IDEOGRAPH-#24039, IRGKangXi=0657.361, RSKangXi=85.14
2403A CJK UNIFIED IDEOGRAPH-#2403A, IRGKangXi=0657.361, RSKangXi=85.14
2403B CJK UNIFIED IDEOGRAPH-#2403B, IRGKangXi=0657.361, RSKangXi=85.14
2403C CJK UNIFIED IDEOGRAPH-#2403C, IRGKangXi=0657.361, RSKangXi=85.14
2403D CJK UNIFIED IDEOGRAPH-#2403D, IRGKangXi=0657.361, RSKangXi=85.14
2403E CJK UNIFIED IDEOGRAPH-#2403E, IRGKangXi=0657.361, RSKangXi=85.14
2403F CJK UNIFIED IDEOGRAPH-#2403F, IRGKangXi=0657.361, RSKangXi=85.14
24040 CJK UNIFIED IDEOGRAPH-#24040, IRGKangXi=0657.361, RSKangXi=85.14
24041 CJK UNIFIED IDEOGRAPH-#24041, IRGKangXi=0657.361, RSKangXi=85.14
24042 CJK UNIFIED IDEOGRAPH-#24042, IRGKangXi=0657.361, RSKangXi=85.14
24043 CJK UNIFIED IDEOGRAPH-#24043, IRGKangXi=0657.361, RSKangXi=85.14
24044 CJK UNIFIED IDEOGRAPH-#24044, IRGKangXi=0657.361, RSKangXi=85.14
24045 CJK UNIFIED IDEOGRAPH-#24045, IRGKangXi=0657.361, RSKangXi=85.14
24046 CJK UNIFIED IDEOGRAPH-#24046, IRGKangXi=0657.361, RSKangXi=85.14
24047 CJK UNIFIED IDEOGRAPH-#24047, IRGKangXi=0657.361, RSKangXi=85.14
24048 CJK UNIFIED IDEOGRAPH-#24048, IRGKangXi=0657.361, RSKangXi=85.14
24049 CJK UNIFIED IDEOGRAPH-#24049, IRGKangXi=0657.361, RSKangXi=85.14
2404A CJK UNIFIED IDEOGRAPH-#2404A, IRGKangXi=0657.361, RSKangXi=85.14
2404B CJK UNIFIED IDEOGRAPH-#2404B, IRGKangXi=0657.361, RSKangXi=85.14
2404C CJK UNIFIED IDEOGRAPH-#2404C, IRGKangXi=0657.361, RSKangXi=85.14
2404D CJK UNIFIED IDEOGRAPH-#2404D, IRGKangXi=0657.361, RSKangXi=85.14
2404E CJK UNIFIED IDEOGRAPH-#2404E, IRGKangXi=0657.361, RSKangXi=85.14
2404F CJK UNIFIED IDEOGRAPH-#2404F, IRGKangXi=0657.361, RSKangXi=85.14
24050 CJK UNIFIED IDEOGRAPH-#24050, IRGKangXi=0657.361, RSKangXi=85.14
24051 CJK UNIFIED IDEOGRAPH-#24051, IRGKangXi=0657.361, RSKangXi=85.14
24052 CJK UNIFIED IDEOGRAPH-#24052, IRGKangXi=0657.361, RSKangXi=85.14
24053 CJK UNIFIED IDEOGRAPH-#24053, IRGKangXi=0657.361, RSKangXi=85.14
24054 CJK UNIFIED IDEOGRAPH-#24054, IRGKangXi=0657.361, RSKangXi=85.14
24055 CJK UNIFIED IDEOGRAPH-#24055, IRGKangXi=0657.361, RSKangXi=85.14
24056 CJK UNIFIED IDEOGRAPH-#24056, IRGKangXi=0657.361, RSKangXi=85.14
24057 CJK UNIFIED IDEOGRAPH-#24057, IRGKangXi=0657.361, RSKangXi=85.14
24058 CJK UNIFIED IDEOGRAPH-#24058, IRGKangXi=0657.361, RSKangXi=85.14
24059 CJK UNIFIED IDEOGRAPH-#24059, IRGKangXi=0657.361, RSKangXi=85.14
2405A CJK UNIFIED IDEOGRAPH-#2405A, IRGKangXi=0657.361, RSKangXi=85.14
2405B CJK UNIFIED IDEOGRAPH-#2405B, IRGKangXi=0657.361, RSKangXi=85.14
2405C CJK UNIFIED IDEOGRAPH-#2405C, IRGKangXi=0657.361, RSKangXi=85.14
2405D CJK UNIFIED IDEOGRAPH-#2405D, IRGKangXi=0657.361, RSKangXi=85.14
2405E CJK UNIFIED IDEOGRAPH-#2405E, IRGKangXi=0657.361, RSKangXi=85.15
2405F CJK UNIFIED IDEOGRAPH-#2405F, IRGKangXi=0657.361, RSKangXi=85.14
24060 CJK UNIFIED IDEOGRAPH-#24060, IRGKangXi=0657.361, RSKangXi=85.14
24061 CJK UNIFIED IDEOGRAPH-#24061, IRGKangXi=0658.010, RSKangXi=85.15
24062 CJK UNIFIED IDEOGRAPH-#24062, IRGKangXi=0658.030, RSKangXi=85.15
24063 CJK UNIFIED IDEOGRAPH-#24063, IRGKangXi=0658.090, RSKangXi=85.15
24064 CJK UNIFIED IDEOGRAPH-#24064, IRGKangXi=0658.100, RSKangXi=85.15
24065 CJK UNIFIED IDEOGRAPH-#24065, IRGKangXi=0658.110, RSKangXi=85.15
24066 CJK UNIFIED IDEOGRAPH-#24066, IRGKangXi=0658.130, RSKangXi=85.15
24067 CJK UNIFIED IDEOGRAPH-#24067, IRGKangXi=0658.150, RSKangXi=85.15
24068 CJK UNIFIED IDEOGRAPH-#24068, IRGKangXi=0658.180, RSKangXi=85.15
24069 CJK UNIFIED IDEOGRAPH-#24069, IRGKangXi=0658.200, RSKangXi=85.15
2406A CJK UNIFIED IDEOGRAPH-#2406A, IRGKangXi=0658.210, RSKangXi=85.15
2406B CJK UNIFIED IDEOGRAPH-#2406B, IRGKangXi=0658.220, RSKangXi=85.15
2406C CJK UNIFIED IDEOGRAPH-#2406C, IRGKangXi=0658.230, RSKangXi=85.15
2406D CJK UNIFIED IDEOGRAPH-#2406D, IRGKangXi=0658.240, RSKangXi=85.15
2406E CJK UNIFIED IDEOGRAPH-#2406E, IRGKangXi=0658.250, RSKangXi=85.15
2406F CJK UNIFIED IDEOGRAPH-#2406F, IRGKangXi=0658.270, RSKangXi=85.15
24070 CJK UNIFIED IDEOGRAPH-#24070, IRGKangXi=0658.280, RSKangXi=85.15
24071 CJK UNIFIED IDEOGRAPH-#24071, IRGKangXi=0658.320, RSKangXi=85.15
24072 CJK UNIFIED IDEOGRAPH-#24072, IRGKangXi=0658.330, RSKangXi=85.15
24073 CJK UNIFIED IDEOGRAPH-#24073, IRGKangXi=0658.350, RSKangXi=85.15
24074 CJK UNIFIED IDEOGRAPH-#24074, IRGKangXi=0658.360, RSKangXi=85.15
24075 CJK UNIFIED IDEOGRAPH-#24075, IRGKangXi=0659.020, RSKangXi=85.15
24076 CJK UNIFIED IDEOGRAPH-#24076, IRGKangXi=0659.030, RSKangXi=85.15
24077 CJK UNIFIED IDEOGRAPH-#24077, IRGKangXi=0659.070, RSKangXi=85.15
24078 CJK UNIFIED IDEOGRAPH-#24078, IRGKangXi=0659.080, RSKangXi=85.15
24079 CJK UNIFIED IDEOGRAPH-#24079, IRGKangXi=0659.090, RSKangXi=85.15
2407A CJK UNIFIED IDEOGRAPH-#2407A, IRGKangXi=0659.150, RSKangXi=85.15
2407B CJK UNIFIED IDEOGRAPH-#2407B, IRGKangXi=0659.160, RSKangXi=85.15
2407C CJK UNIFIED IDEOGRAPH-#2407C, IRGKangXi=0659.170, RSKangXi=85.15
2407D CJK UNIFIED IDEOGRAPH-#2407D, IRGKangXi=0659.180, RSKangXi=85.15
2407E CJK UNIFIED IDEOGRAPH-#2407E, IRGKangXi=0659.190, RSKangXi=85.15
2407F CJK UNIFIED IDEOGRAPH-#2407F, IRGKangXi=0659.210, RSKangXi=85.15
24080 CJK UNIFIED IDEOGRAPH-#24080, IRGKangXi=0659.220, RSKangXi=85.15
24081 CJK UNIFIED IDEOGRAPH-#24081, IRGKangXi=0659.230, RSKangXi=85.15
24082 CJK UNIFIED IDEOGRAPH-#24082, IRGKangXi=0659.240, RSKangXi=85.15
24083 CJK UNIFIED IDEOGRAPH-#24083, IRGKangXi=0659.250, RSKangXi=85.15
24084 CJK UNIFIED IDEOGRAPH-#24084, IRGKangXi=0659.260, RSKangXi=85.15
24085 CJK UNIFIED IDEOGRAPH-#24085, IRGKangXi=0659.270, RSKangXi=85.15
24086 CJK UNIFIED IDEOGRAPH-#24086, IRGKangXi=0659.280, RSKangXi=85.15
24087 CJK UNIFIED IDEOGRAPH-#24087, IRGKangXi=0659.290, RSKangXi=85.15
24088 CJK UNIFIED IDEOGRAPH-#24088, IRGKangXi=0659.291, RSKangXi=85.15
24089 CJK UNIFIED IDEOGRAPH-#24089, IRGKangXi=0659.291, RSKangXi=85.15
2408A CJK UNIFIED IDEOGRAPH-#2408A, IRGKangXi=0659.291, RSKangXi=85.15
2408B CJK UNIFIED IDEOGRAPH-#2408B, IRGKangXi=0659.291, RSKangXi=85.15
2408C CJK UNIFIED IDEOGRAPH-#2408C, IRGKangXi=0659.291, RSKangXi=85.15
2408D CJK UNIFIED IDEOGRAPH-#2408D, IRGKangXi=0659.291, RSKangXi=85.15
2408E CJK UNIFIED IDEOGRAPH-#2408E, IRGKangXi=0659.291, RSKangXi=85.15
2408F CJK UNIFIED IDEOGRAPH-#2408F, IRGKangXi=0659.291, RSKangXi=85.15
24090 CJK UNIFIED IDEOGRAPH-#24090, IRGKangXi=0659.291, RSKangXi=85.15
24091 CJK UNIFIED IDEOGRAPH-#24091, IRGKangXi=0659.291, RSKangXi=85.15
24092 CJK UNIFIED IDEOGRAPH-#24092, IRGKangXi=0659.291, RSKangXi=85.15
24093 CJK UNIFIED IDEOGRAPH-#24093, IRGKangXi=0659.291, RSKangXi=85.15
24094 CJK UNIFIED IDEOGRAPH-#24094, IRGKangXi=0659.291, RSKangXi=85.15
24095 CJK UNIFIED IDEOGRAPH-#24095, IRGKangXi=0659.291, RSKangXi=85.15
24096 CJK UNIFIED IDEOGRAPH-#24096, IRGKangXi=0659.291, RSKangXi=85.15
24097 CJK UNIFIED IDEOGRAPH-#24097, IRGKangXi=0659.291, RSKangXi=85.15
24098 CJK UNIFIED IDEOGRAPH-#24098, IRGKangXi=0659.291, RSKangXi=85.15
24099 CJK UNIFIED IDEOGRAPH-#24099, IRGKangXi=0659.291, RSKangXi=85.15
2409A CJK UNIFIED IDEOGRAPH-#2409A, IRGKangXi=0659.291, RSKangXi=85.15
2409B CJK UNIFIED IDEOGRAPH-#2409B, IRGKangXi=0659.291, RSKangXi=85.15
2409C CJK UNIFIED IDEOGRAPH-#2409C, IRGKangXi=0659.291, RSKangXi=85.15
2409D CJK UNIFIED IDEOGRAPH-#2409D, IRGKangXi=0659.291, RSKangXi=85.16
2409E CJK UNIFIED IDEOGRAPH-#2409E, IRGKangXi=0659.291, RSKangXi=85.15
2409F CJK UNIFIED IDEOGRAPH-#2409F, IRGKangXi=0659.291, RSKangXi=85.15
240A0 CJK UNIFIED IDEOGRAPH-#240A0, IRGKangXi=0659.291, RSKangXi=85.15
240A1 CJK UNIFIED IDEOGRAPH-#240A1, IRGKangXi=0659.291, RSKangXi=85.16
240A2 CJK UNIFIED IDEOGRAPH-#240A2, IRGKangXi=0659.291, RSKangXi=85.15
240A3 CJK UNIFIED IDEOGRAPH-#240A3, IRGKangXi=0659.291, RSKangXi=85.15
240A4 CJK UNIFIED IDEOGRAPH-#240A4, IRGKangXi=0659.291, RSKangXi=85.15
240A5 CJK UNIFIED IDEOGRAPH-#240A5, IRGKangXi=0659.291, RSKangXi=85.15
240A6 CJK UNIFIED IDEOGRAPH-#240A6, IRGKangXi=0659.291, RSKangXi=85.15
240A7 CJK UNIFIED IDEOGRAPH-#240A7, IRGKangXi=0659.291, RSKangXi=85.15
240A8 CJK UNIFIED IDEOGRAPH-#240A8, IRGKangXi=0659.291, RSKangXi=85.15
240A9 CJK UNIFIED IDEOGRAPH-#240A9, IRGKangXi=0659.291, RSKangXi=85.15
240AA CJK UNIFIED IDEOGRAPH-#240AA, IRGKangXi=0659.291, RSKangXi=85.15
240AB CJK UNIFIED IDEOGRAPH-#240AB, IRGKangXi=0659.291, RSKangXi=85.15
240AC CJK UNIFIED IDEOGRAPH-#240AC, IRGKangXi=0659.291, RSKangXi=85.15
240AD CJK UNIFIED IDEOGRAPH-#240AD, IRGKangXi=0659.291, RSKangXi=85.15
240AE CJK UNIFIED IDEOGRAPH-#240AE, IRGKangXi=0659.291, RSKangXi=85.15
240AF CJK UNIFIED IDEOGRAPH-#240AF, IRGKangXi=0659.291, RSKangXi=85.15
240B0 CJK UNIFIED IDEOGRAPH-#240B0, IRGKangXi=0659.291, RSKangXi=85.15
240B1 CJK UNIFIED IDEOGRAPH-#240B1, IRGKangXi=0659.291, RSKangXi=85.15
240B2 CJK UNIFIED IDEOGRAPH-#240B2, IRGKangXi=0659.291, RSKangXi=85.15
240B3 CJK UNIFIED IDEOGRAPH-#240B3, IRGKangXi=0659.300, RSKangXi=85.16
240B4 CJK UNIFIED IDEOGRAPH-#240B4, IRGKangXi=0659.310, RSKangXi=85.16
240B5 CJK UNIFIED IDEOGRAPH-#240B5, IRGKangXi=0659.330, RSKangXi=85.16
240B6 CJK UNIFIED IDEOGRAPH-#240B6, IRGKangXi=0659.350, RSKangXi=85.16
240B7 CJK UNIFIED IDEOGRAPH-#240B7, IRGKangXi=0659.360, RSKangXi=85.16
240B8 CJK UNIFIED IDEOGRAPH-#240B8, IRGKangXi=0659.380, RSKangXi=85.16
240B9 CJK UNIFIED IDEOGRAPH-#240B9, IRGKangXi=0659.390, RSKangXi=85.16
240BA CJK UNIFIED IDEOGRAPH-#240BA, IRGKangXi=0659.440, RSKangXi=85.16
240BB CJK UNIFIED IDEOGRAPH-#240BB, IRGKangXi=0659.470, RSKangXi=85.16
240BC CJK UNIFIED IDEOGRAPH-#240BC, IRGKangXi=0660.010, RSKangXi=85.16
240BD CJK UNIFIED IDEOGRAPH-#240BD, IRGKangXi=0660.020, RSKangXi=85.16
240BE CJK UNIFIED IDEOGRAPH-#240BE, IRGKangXi=0660.030, RSKangXi=85.16
240BF CJK UNIFIED IDEOGRAPH-#240BF, IRGKangXi=0660.110, RSKangXi=85.16
240C0 CJK UNIFIED IDEOGRAPH-#240C0, IRGKangXi=0660.120, RSKangXi=85.16
240C1 CJK UNIFIED IDEOGRAPH-#240C1, IRGKangXi=0660.220, RSKangXi=85.16
240C2 CJK UNIFIED IDEOGRAPH-#240C2, IRGKangXi=0660.250, RSKangXi=85.16
240C3 CJK UNIFIED IDEOGRAPH-#240C3, IRGKangXi=0660.260, RSKangXi=85.16
240C4 CJK UNIFIED IDEOGRAPH-#240C4, IRGKangXi=0660.270, RSKangXi=85.16
240C5 CJK UNIFIED IDEOGRAPH-#240C5, IRGKangXi=0660.271, RSKangXi=85.16
240C6 CJK UNIFIED IDEOGRAPH-#240C6, IRGKangXi=0660.271, RSKangXi=85.16
240C7 CJK UNIFIED IDEOGRAPH-#240C7, IRGKangXi=0660.271, RSKangXi=85.16
240C8 CJK UNIFIED IDEOGRAPH-#240C8, IRGKangXi=0660.271, RSKangXi=85.16
240C9 CJK UNIFIED IDEOGRAPH-#240C9, IRGKangXi=0660.271, RSKangXi=85.16
240CA CJK UNIFIED IDEOGRAPH-#240CA, IRGKangXi=0660.271, RSKangXi=85.16
240CB CJK UNIFIED IDEOGRAPH-#240CB, IRGKangXi=0660.271, RSKangXi=85.16
240CC CJK UNIFIED IDEOGRAPH-#240CC, IRGKangXi=0660.271, RSKangXi=85.16
240CD CJK UNIFIED IDEOGRAPH-#240CD, IRGKangXi=0660.271, RSKangXi=85.16
240CE CJK UNIFIED IDEOGRAPH-#240CE, IRGKangXi=0660.271, RSKangXi=85.16
240CF CJK UNIFIED IDEOGRAPH-#240CF, IRGKangXi=0660.271, RSKangXi=85.16
240D0 CJK UNIFIED IDEOGRAPH-#240D0, IRGKangXi=0660.271, RSKangXi=85.16
240D1 CJK UNIFIED IDEOGRAPH-#240D1, IRGKangXi=0660.271, RSKangXi=85.16
240D2 CJK UNIFIED IDEOGRAPH-#240D2, IRGKangXi=0660.271, RSKangXi=85.16
240D3 CJK UNIFIED IDEOGRAPH-#240D3, IRGKangXi=0660.271, RSKangXi=85.16
240D4 CJK UNIFIED IDEOGRAPH-#240D4, IRGKangXi=0660.271, RSKangXi=85.16
240D5 CJK UNIFIED IDEOGRAPH-#240D5, IRGKangXi=0660.271, RSKangXi=85.16
240D6 CJK UNIFIED IDEOGRAPH-#240D6, IRGKangXi=0660.271, RSKangXi=85.16
240D7 CJK UNIFIED IDEOGRAPH-#240D7, IRGKangXi=0660.271, RSKangXi=85.16
240D8 CJK UNIFIED IDEOGRAPH-#240D8, IRGKangXi=0660.271, RSKangXi=85.16
240D9 CJK UNIFIED IDEOGRAPH-#240D9, IRGKangXi=0660.271, RSKangXi=85.16
240DA CJK UNIFIED IDEOGRAPH-#240DA, IRGKangXi=0660.271, RSKangXi=85.16
240DB CJK UNIFIED IDEOGRAPH-#240DB, IRGKangXi=0660.271, RSKangXi=85.16
240DC CJK UNIFIED IDEOGRAPH-#240DC, IRGKangXi=0660.271, RSKangXi=85.16
240DD CJK UNIFIED IDEOGRAPH-#240DD, IRGKangXi=0660.271, RSKangXi=85.16
240DE CJK UNIFIED IDEOGRAPH-#240DE, IRGKangXi=0660.271, RSKangXi=85.16
240DF CJK UNIFIED IDEOGRAPH-#240DF, IRGKangXi=0660.271, RSKangXi=85.16
240E0 CJK UNIFIED IDEOGRAPH-#240E0, IRGKangXi=0660.271, RSKangXi=85.16
240E1 CJK UNIFIED IDEOGRAPH-#240E1, IRGKangXi=0660.271, RSKangXi=85.16
240E2 CJK UNIFIED IDEOGRAPH-#240E2, IRGKangXi=0660.271, RSKangXi=85.16
240E3 CJK UNIFIED IDEOGRAPH-#240E3, IRGKangXi=0660.271, RSKangXi=85.16
240E4 CJK UNIFIED IDEOGRAPH-#240E4, IRGKangXi=0660.271, RSKangXi=85.16
240E5 CJK UNIFIED IDEOGRAPH-#240E5, IRGKangXi=0660.271, RSKangXi=85.16
240E6 CJK UNIFIED IDEOGRAPH-#240E6, IRGKangXi=0660.271, RSKangXi=85.16
240E7 CJK UNIFIED IDEOGRAPH-#240E7, IRGKangXi=0660.271, RSKangXi=85.16
240E8 CJK UNIFIED IDEOGRAPH-#240E8, IRGKangXi=0660.290, RSKangXi=85.17
240E9 CJK UNIFIED IDEOGRAPH-#240E9, IRGKangXi=0660.300, RSKangXi=85.17
240EA CJK UNIFIED IDEOGRAPH-#240EA, IRGKangXi=0661.050, RSKangXi=85.17
240EB CJK UNIFIED IDEOGRAPH-#240EB, IRGKangXi=0661.060, RSKangXi=85.17
240EC CJK UNIFIED IDEOGRAPH-#240EC, IRGKangXi=0661.080, RSKangXi=85.17
240ED CJK UNIFIED IDEOGRAPH-#240ED, IRGKangXi=0661.090, RSKangXi=85.17
240EE CJK UNIFIED IDEOGRAPH-#240EE, IRGKangXi=0661.100, RSKangXi=85.17
240EF CJK UNIFIED IDEOGRAPH-#240EF, IRGKangXi=0661.120, RSKangXi=85.17
240F0 CJK UNIFIED IDEOGRAPH-#240F0, IRGKangXi=0661.140, RSKangXi=85.17
240F1 CJK UNIFIED IDEOGRAPH-#240F1, IRGKangXi=0661.170, RSKangXi=85.17
240F2 CJK UNIFIED IDEOGRAPH-#240F2, IRGKangXi=0661.180, RSKangXi=85.17
240F3 CJK UNIFIED IDEOGRAPH-#240F3, IRGKangXi=0661.190, RSKangXi=85.17
240F4 CJK UNIFIED IDEOGRAPH-#240F4, IRGKangXi=0661.200, RSKangXi=85.17
240F5 CJK UNIFIED IDEOGRAPH-#240F5, IRGKangXi=0661.260, RSKangXi=85.17
240F6 CJK UNIFIED IDEOGRAPH-#240F6, IRGKangXi=0661.270, RSKangXi=85.17, Def{swept away, as by a flood; soaked, saturated; to settle, as with alum; to strain; to drain off}
240F7 CJK UNIFIED IDEOGRAPH-#240F7, IRGKangXi=0661.280, RSKangXi=85.17
240F8 CJK UNIFIED IDEOGRAPH-#240F8, IRGKangXi=0662.030, RSKangXi=85.17
240F9 CJK UNIFIED IDEOGRAPH-#240F9, IRGKangXi=0662.040, RSKangXi=85.17
240FA CJK UNIFIED IDEOGRAPH-#240FA, IRGKangXi=0662.050, RSKangXi=85.17
240FB CJK UNIFIED IDEOGRAPH-#240FB, IRGKangXi=0662.060, RSKangXi=85.17
240FC CJK UNIFIED IDEOGRAPH-#240FC, IRGKangXi=0662.080, RSKangXi=85.17
240FD CJK UNIFIED IDEOGRAPH-#240FD, IRGKangXi=0662.090, RSKangXi=85.17
240FE CJK UNIFIED IDEOGRAPH-#240FE, IRGKangXi=0662.100, RSKangXi=85.17
240FF CJK UNIFIED IDEOGRAPH-#240FF, IRGKangXi=0662.101, RSKangXi=85.17
24100 CJK UNIFIED IDEOGRAPH-#24100, IRGKangXi=0662.101, RSKangXi=85.17
24101 CJK UNIFIED IDEOGRAPH-#24101, IRGKangXi=0662.101, RSKangXi=85.17
24102 CJK UNIFIED IDEOGRAPH-#24102, IRGKangXi=0662.101, RSKangXi=85.17
24103 CJK UNIFIED IDEOGRAPH-#24103, IRGKangXi=0662.101, RSKangXi=85.17
24104 CJK UNIFIED IDEOGRAPH-#24104, IRGKangXi=0662.101, RSKangXi=85.17
24105 CJK UNIFIED IDEOGRAPH-#24105, IRGKangXi=0662.101, RSKangXi=85.17
24106 CJK UNIFIED IDEOGRAPH-#24106, IRGKangXi=0662.101, RSKangXi=85.17
24107 CJK UNIFIED IDEOGRAPH-#24107, IRGKangXi=0662.101, RSKangXi=85.17
24108 CJK UNIFIED IDEOGRAPH-#24108, IRGKangXi=0662.101, RSKangXi=85.17
24109 CJK UNIFIED IDEOGRAPH-#24109, IRGKangXi=0662.101, RSKangXi=85.17
2410A CJK UNIFIED IDEOGRAPH-#2410A, IRGKangXi=0662.101, RSKangXi=85.17
2410B CJK UNIFIED IDEOGRAPH-#2410B, IRGKangXi=0662.101, RSKangXi=85.17
2410C CJK UNIFIED IDEOGRAPH-#2410C, IRGKangXi=0662.101, RSKangXi=85.17
2410D CJK UNIFIED IDEOGRAPH-#2410D, IRGKangXi=0662.101, RSKangXi=85.17
2410E CJK UNIFIED IDEOGRAPH-#2410E, IRGKangXi=0662.120, RSKangXi=85.18
2410F CJK UNIFIED IDEOGRAPH-#2410F, IRGKangXi=0662.140, RSKangXi=85.18
24110 CJK UNIFIED IDEOGRAPH-#24110, IRGKangXi=0662.160, RSKangXi=85.18
24111 CJK UNIFIED IDEOGRAPH-#24111, IRGKangXi=0662.230, RSKangXi=85.18
24112 CJK UNIFIED IDEOGRAPH-#24112, IRGKangXi=0662.270, RSKangXi=85.18
24113 CJK UNIFIED IDEOGRAPH-#24113, IRGKangXi=0662.280, RSKangXi=85.18
24114 CJK UNIFIED IDEOGRAPH-#24114, IRGKangXi=0662.300, RSKangXi=85.18
24115 CJK UNIFIED IDEOGRAPH-#24115, IRGKangXi=0662.310, RSKangXi=85.18
24116 CJK UNIFIED IDEOGRAPH-#24116, IRGKangXi=0662.330, RSKangXi=85.18
24117 CJK UNIFIED IDEOGRAPH-#24117, IRGKangXi=0663.020, RSKangXi=85.18
24118 CJK UNIFIED IDEOGRAPH-#24118, IRGKangXi=0663.030, RSKangXi=85.18
24119 CJK UNIFIED IDEOGRAPH-#24119, IRGKangXi=0663.040, RSKangXi=85.18
2411A CJK UNIFIED IDEOGRAPH-#2411A, IRGKangXi=0663.050, RSKangXi=85.18
2411B CJK UNIFIED IDEOGRAPH-#2411B, IRGKangXi=0663.070, RSKangXi=85.18
2411C CJK UNIFIED IDEOGRAPH-#2411C, IRGKangXi=0663.080, RSKangXi=85.18
2411D CJK UNIFIED IDEOGRAPH-#2411D, IRGKangXi=0663.090, RSKangXi=85.18
2411E CJK UNIFIED IDEOGRAPH-#2411E, IRGKangXi=0663.091, RSKangXi=85.18
2411F CJK UNIFIED IDEOGRAPH-#2411F, IRGKangXi=0663.091, RSKangXi=85.18
24120 CJK UNIFIED IDEOGRAPH-#24120, IRGKangXi=0663.091, RSKangXi=85.18
24121 CJK UNIFIED IDEOGRAPH-#24121, IRGKangXi=0663.091, RSKangXi=85.18
24122 CJK UNIFIED IDEOGRAPH-#24122, IRGKangXi=0663.091, RSKangXi=85.18
24123 CJK UNIFIED IDEOGRAPH-#24123, IRGKangXi=0663.091, RSKangXi=85.18
24124 CJK UNIFIED IDEOGRAPH-#24124, IRGKangXi=0663.091, RSKangXi=85.18
24125 CJK UNIFIED IDEOGRAPH-#24125, IRGKangXi=0663.091, RSKangXi=85.18
24126 CJK UNIFIED IDEOGRAPH-#24126, IRGKangXi=0663.091, RSKangXi=85.18
24127 CJK UNIFIED IDEOGRAPH-#24127, IRGKangXi=0663.091, RSKangXi=85.18
24128 CJK UNIFIED IDEOGRAPH-#24128, IRGKangXi=0663.091, RSKangXi=85.18
24129 CJK UNIFIED IDEOGRAPH-#24129, IRGKangXi=0663.091, RSKangXi=85.18
2412A CJK UNIFIED IDEOGRAPH-#2412A, IRGKangXi=0663.091, RSKangXi=85.18
2412B CJK UNIFIED IDEOGRAPH-#2412B, IRGKangXi=0663.091, RSKangXi=85.18
2412C CJK UNIFIED IDEOGRAPH-#2412C, IRGKangXi=0663.091, RSKangXi=85.18
2412D CJK UNIFIED IDEOGRAPH-#2412D, IRGKangXi=0663.091, RSKangXi=85.18
2412E CJK UNIFIED IDEOGRAPH-#2412E, IRGKangXi=0663.091, RSKangXi=85.18
2412F CJK UNIFIED IDEOGRAPH-#2412F, IRGKangXi=0663.091, RSKangXi=85.18
24130 CJK UNIFIED IDEOGRAPH-#24130, IRGKangXi=0663.091, RSKangXi=85.18
24131 CJK UNIFIED IDEOGRAPH-#24131, IRGKangXi=0663.091, RSKangXi=85.18
24132 CJK UNIFIED IDEOGRAPH-#24132, IRGKangXi=0663.091, RSKangXi=85.18
24133 CJK UNIFIED IDEOGRAPH-#24133, IRGKangXi=0663.091, RSKangXi=85.18
24134 CJK UNIFIED IDEOGRAPH-#24134, IRGKangXi=0663.091, RSKangXi=85.18
24135 CJK UNIFIED IDEOGRAPH-#24135, IRGKangXi=0663.100, RSKangXi=85.18
24136 CJK UNIFIED IDEOGRAPH-#24136, IRGKangXi=0663.160, RSKangXi=85.19
24137 CJK UNIFIED IDEOGRAPH-#24137, IRGKangXi=0663.180, RSKangXi=85.19
24138 CJK UNIFIED IDEOGRAPH-#24138, IRGKangXi=0663.191, RSKangXi=85.19
24139 CJK UNIFIED IDEOGRAPH-#24139, IRGKangXi=0663.200, RSKangXi=85.19
2413A CJK UNIFIED IDEOGRAPH-#2413A, IRGKangXi=0663.240, RSKangXi=85.19
2413B CJK UNIFIED IDEOGRAPH-#2413B, IRGKangXi=0663.250, RSKangXi=85.19
2413C CJK UNIFIED IDEOGRAPH-#2413C, IRGKangXi=0663.260, RSKangXi=85.19
2413D CJK UNIFIED IDEOGRAPH-#2413D, IRGKangXi=0663.270, RSKangXi=85.19
2413E CJK UNIFIED IDEOGRAPH-#2413E, IRGKangXi=0663.271, RSKangXi=85.19
2413F CJK UNIFIED IDEOGRAPH-#2413F, IRGKangXi=0663.271, RSKangXi=85.19
24140 CJK UNIFIED IDEOGRAPH-#24140, IRGKangXi=0663.271, RSKangXi=85.19
24141 CJK UNIFIED IDEOGRAPH-#24141, IRGKangXi=0663.271, RSKangXi=85.19
24142 CJK UNIFIED IDEOGRAPH-#24142, IRGKangXi=0663.271, RSKangXi=85.19
24143 CJK UNIFIED IDEOGRAPH-#24143, IRGKangXi=0663.271, RSKangXi=85.19
24144 CJK UNIFIED IDEOGRAPH-#24144, IRGKangXi=0663.271, RSKangXi=85.19
24145 CJK UNIFIED IDEOGRAPH-#24145, IRGKangXi=0663.271, RSKangXi=85.19
24146 CJK UNIFIED IDEOGRAPH-#24146, IRGKangXi=0663.271, RSKangXi=85.19
24147 CJK UNIFIED IDEOGRAPH-#24147, IRGKangXi=0663.271, RSKangXi=85.19
24148 CJK UNIFIED IDEOGRAPH-#24148, IRGKangXi=0663.271, RSKangXi=85.19
24149 CJK UNIFIED IDEOGRAPH-#24149, IRGKangXi=0663.271, RSKangXi=85.19
2414A CJK UNIFIED IDEOGRAPH-#2414A, IRGKangXi=0663.320, RSKangXi=85.20
2414B CJK UNIFIED IDEOGRAPH-#2414B, IRGKangXi=0663.330, RSKangXi=85.20
2414C CJK UNIFIED IDEOGRAPH-#2414C, IRGKangXi=0663.340, RSKangXi=85.20
2414D CJK UNIFIED IDEOGRAPH-#2414D, IRGKangXi=0663.350, RSKangXi=85.20
2414E CJK UNIFIED IDEOGRAPH-#2414E, IRGKangXi=0663.370, RSKangXi=85.20
2414F CJK UNIFIED IDEOGRAPH-#2414F, IRGKangXi=0663.380, RSKangXi=85.20
24150 CJK UNIFIED IDEOGRAPH-#24150, IRGKangXi=0663.390, RSKangXi=85.20
24151 CJK UNIFIED IDEOGRAPH-#24151, IRGKangXi=0663.400, RSKangXi=85.20
24152 CJK UNIFIED IDEOGRAPH-#24152, IRGKangXi=0663.410, RSKangXi=85.20
24153 CJK UNIFIED IDEOGRAPH-#24153, IRGKangXi=0663.420, RSKangXi=85.20
24154 CJK UNIFIED IDEOGRAPH-#24154, IRGKangXi=0663.421, RSKangXi=85.20
24155 CJK UNIFIED IDEOGRAPH-#24155, IRGKangXi=0663.421, RSKangXi=85.20
24156 CJK UNIFIED IDEOGRAPH-#24156, IRGKangXi=0663.421, RSKangXi=85.20
24157 CJK UNIFIED IDEOGRAPH-#24157, IRGKangXi=0663.421, RSKangXi=85.20
24158 CJK UNIFIED IDEOGRAPH-#24158, IRGKangXi=0663.421, RSKangXi=85.20
24159 CJK UNIFIED IDEOGRAPH-#24159, IRGKangXi=0663.421, RSKangXi=85.20
2415A CJK UNIFIED IDEOGRAPH-#2415A, IRGKangXi=0663.421, RSKangXi=85.20
2415B CJK UNIFIED IDEOGRAPH-#2415B, IRGKangXi=0663.421, RSKangXi=85.20
2415C CJK UNIFIED IDEOGRAPH-#2415C, IRGKangXi=0663.421, RSKangXi=85.20
2415D CJK UNIFIED IDEOGRAPH-#2415D, IRGKangXi=0663.421, RSKangXi=85.20
2415E CJK UNIFIED IDEOGRAPH-#2415E, IRGKangXi=0663.421, RSKangXi=85.20
2415F CJK UNIFIED IDEOGRAPH-#2415F, IRGKangXi=0663.421, RSKangXi=85.20
24160 CJK UNIFIED IDEOGRAPH-#24160, IRGKangXi=0663.430, RSKangXi=85.21
24161 CJK UNIFIED IDEOGRAPH-#24161, IRGKangXi=0663.450, RSKangXi=85.21
24162 CJK UNIFIED IDEOGRAPH-#24162, IRGKangXi=0664.020, RSKangXi=85.21
24163 CJK UNIFIED IDEOGRAPH-#24163, IRGKangXi=0664.060, RSKangXi=85.21
24164 CJK UNIFIED IDEOGRAPH-#24164, IRGKangXi=0664.070, RSKangXi=85.21
24165 CJK UNIFIED IDEOGRAPH-#24165, IRGKangXi=0664.081, RSKangXi=85.21
24166 CJK UNIFIED IDEOGRAPH-#24166, IRGKangXi=0664.081, RSKangXi=85.21
24167 CJK UNIFIED IDEOGRAPH-#24167, IRGKangXi=0664.081, RSKangXi=85.21
24168 CJK UNIFIED IDEOGRAPH-#24168, IRGKangXi=0664.081, RSKangXi=85.21
24169 CJK UNIFIED IDEOGRAPH-#24169, IRGKangXi=0664.110, RSKangXi=85.22
2416A CJK UNIFIED IDEOGRAPH-#2416A, IRGKangXi=0664.120, RSKangXi=85.22
2416B CJK UNIFIED IDEOGRAPH-#2416B, IRGKangXi=0664.130, RSKangXi=85.22
2416C CJK UNIFIED IDEOGRAPH-#2416C, IRGKangXi=0664.131, RSKangXi=85.22
2416D CJK UNIFIED IDEOGRAPH-#2416D, IRGKangXi=0664.131, RSKangXi=85.22
2416E CJK UNIFIED IDEOGRAPH-#2416E, IRGKangXi=0664.131, RSKangXi=85.22
2416F CJK UNIFIED IDEOGRAPH-#2416F, IRGKangXi=0664.131, RSKangXi=85.22
24170 CJK UNIFIED IDEOGRAPH-#24170, IRGKangXi=0664.140, RSKangXi=85.23
24171 CJK UNIFIED IDEOGRAPH-#24171, IRGKangXi=0664.150, RSKangXi=85.23
24172 CJK UNIFIED IDEOGRAPH-#24172, IRGKangXi=0664.180, RSKangXi=85.23
24173 CJK UNIFIED IDEOGRAPH-#24173, IRGKangXi=0664.220, RSKangXi=85.23
24174 CJK UNIFIED IDEOGRAPH-#24174, IRGKangXi=0664.230, RSKangXi=85.23
24175 CJK UNIFIED IDEOGRAPH-#24175, IRGKangXi=0664.231, RSKangXi=85.23
24176 CJK UNIFIED IDEOGRAPH-#24176, IRGKangXi=0664.231, RSKangXi=85.23
24177 CJK UNIFIED IDEOGRAPH-#24177, IRGKangXi=0664.240, RSKangXi=85.24
24178 CJK UNIFIED IDEOGRAPH-#24178, IRGKangXi=0664.260, RSKangXi=85.24
24179 CJK UNIFIED IDEOGRAPH-#24179, IRGKangXi=0664.270, RSKangXi=85.24
2417A CJK UNIFIED IDEOGRAPH-#2417A, IRGKangXi=0664.281, RSKangXi=85.24
2417B CJK UNIFIED IDEOGRAPH-#2417B, IRGKangXi=0664.281, RSKangXi=85.24
2417C CJK UNIFIED IDEOGRAPH-#2417C, IRGKangXi=0664.290, RSKangXi=85.25
2417D CJK UNIFIED IDEOGRAPH-#2417D, IRGKangXi=0664.291, RSKangXi=85.25
2417E CJK UNIFIED IDEOGRAPH-#2417E, IRGKangXi=0664.291, RSKangXi=85.26
2417F CJK UNIFIED IDEOGRAPH-#2417F, IRGKangXi=0664.291, RSKangXi=85.27
24180 CJK UNIFIED IDEOGRAPH-#24180, IRGKangXi=0664.320, RSKangXi=85.30
24181 CJK UNIFIED IDEOGRAPH-#24181, IRGKangXi=0664.321, RSKangXi=85.32
24182 CJK UNIFIED IDEOGRAPH-#24182, IRGKangXi=0665.040, RSKangXi=86.1
24183 CJK UNIFIED IDEOGRAPH-#24183, IRGKangXi=0665.070, RSKangXi=86.2
24184 CJK UNIFIED IDEOGRAPH-#24184, IRGKangXi=0666.030, RSKangXi=86.2
24185 CJK UNIFIED IDEOGRAPH-#24185, IRGKangXi=0666.040, RSKangXi=86.2
24186 CJK UNIFIED IDEOGRAPH-#24186, IRGKangXi=0666.050, RSKangXi=86.2
24187 CJK UNIFIED IDEOGRAPH-#24187, IRGKangXi=0666.061, RSKangXi=86.2
24188 CJK UNIFIED IDEOGRAPH-#24188, IRGKangXi=0666.061, RSKangXi=86.2
24189 CJK UNIFIED IDEOGRAPH-#24189, IRGKangXi=0666.061, RSKangXi=86.2
2418A CJK UNIFIED IDEOGRAPH-#2418A, IRGKangXi=0666.061, RSKangXi=86.2
2418B CJK UNIFIED IDEOGRAPH-#2418B, IRGKangXi=0666.061, RSKangXi=86.2
2418C CJK UNIFIED IDEOGRAPH-#2418C, IRGKangXi=0666.061, RSKangXi=86.2
2418D CJK UNIFIED IDEOGRAPH-#2418D, IRGKangXi=0666.150, RSKangXi=86.3, Def{red; communist, 'red'; bare}
2418E CJK UNIFIED IDEOGRAPH-#2418E, IRGKangXi=0666.210, RSKangXi=86.3
2418F CJK UNIFIED IDEOGRAPH-#2418F, IRGKangXi=0666.230, RSKangXi=86.3
24190 CJK UNIFIED IDEOGRAPH-#24190, IRGKangXi=0666.240, RSKangXi=86.3
24191 CJK UNIFIED IDEOGRAPH-#24191, IRGKangXi=0666.250, RSKangXi=86.3
24192 CJK UNIFIED IDEOGRAPH-#24192, IRGKangXi=0666.260, RSKangXi=86.3
24193 CJK UNIFIED IDEOGRAPH-#24193, IRGKangXi=0666.261, RSKangXi=86.3
24194 CJK UNIFIED IDEOGRAPH-#24194, IRGKangXi=0666.261, RSKangXi=86.3
24195 CJK UNIFIED IDEOGRAPH-#24195, IRGKangXi=0666.261, RSKangXi=86.3
24196 CJK UNIFIED IDEOGRAPH-#24196, IRGKangXi=0666.261, RSKangXi=86.3
24197 CJK UNIFIED IDEOGRAPH-#24197, IRGKangXi=0666.261, RSKangXi=86.3
24198 CJK UNIFIED IDEOGRAPH-#24198, IRGKangXi=0666.261, RSKangXi=86.3
24199 CJK UNIFIED IDEOGRAPH-#24199, IRGKangXi=0666.261, RSKangXi=86.3
2419A CJK UNIFIED IDEOGRAPH-#2419A, IRGKangXi=0666.261, RSKangXi=86.3
2419B CJK UNIFIED IDEOGRAPH-#2419B, IRGKangXi=0666.261, RSKangXi=86.3
2419C CJK UNIFIED IDEOGRAPH-#2419C, IRGKangXi=0666.261, RSKangXi=86.3
2419D CJK UNIFIED IDEOGRAPH-#2419D, IRGKangXi=0667.030, RSKangXi=86.4
2419E CJK UNIFIED IDEOGRAPH-#2419E, IRGKangXi=0667.060, RSKangXi=86.4
2419F CJK UNIFIED IDEOGRAPH-#2419F, IRGKangXi=0668.030, RSKangXi=86.4
241A0 CJK UNIFIED IDEOGRAPH-#241A0, IRGKangXi=0668.031, RSKangXi=86.4
241A1 CJK UNIFIED IDEOGRAPH-#241A1, IRGKangXi=0668.031, RSKangXi=86.4
241A2 CJK UNIFIED IDEOGRAPH-#241A2, IRGKangXi=0668.031, RSKangXi=86.4
241A3 CJK UNIFIED IDEOGRAPH-#241A3, IRGKangXi=0668.031, RSKangXi=86.4, Def{(Cant.) to cook in boiling water}
241A4 CJK UNIFIED IDEOGRAPH-#241A4, IRGKangXi=0668.031, RSKangXi=86.4
241A5 CJK UNIFIED IDEOGRAPH-#241A5, IRGKangXi=0668.031, RSKangXi=86.4
241A6 CJK UNIFIED IDEOGRAPH-#241A6, IRGKangXi=0668.031, RSKangXi=86.4
241A7 CJK UNIFIED IDEOGRAPH-#241A7, IRGKangXi=0668.031, RSKangXi=86.4
241A8 CJK UNIFIED IDEOGRAPH-#241A8, IRGKangXi=0668.031, RSKangXi=86.4
241A9 CJK UNIFIED IDEOGRAPH-#241A9, IRGKangXi=0668.031, RSKangXi=86.4
241AA CJK UNIFIED IDEOGRAPH-#241AA, IRGKangXi=0668.031, RSKangXi=86.4
241AB CJK UNIFIED IDEOGRAPH-#241AB, IRGKangXi=0668.031, RSKangXi=86.4
241AC CJK UNIFIED IDEOGRAPH-#241AC, IRGKangXi=0668.031, RSKangXi=86.4
241AD CJK UNIFIED IDEOGRAPH-#241AD, IRGKangXi=0668.031, RSKangXi=86.4
241AE CJK UNIFIED IDEOGRAPH-#241AE, IRGKangXi=0668.031, RSKangXi=86.4
241AF CJK UNIFIED IDEOGRAPH-#241AF, IRGKangXi=0668.031, RSKangXi=86.4
241B0 CJK UNIFIED IDEOGRAPH-#241B0, IRGKangXi=0668.031, RSKangXi=86.4
241B1 CJK UNIFIED IDEOGRAPH-#241B1, IRGKangXi=0668.031, RSKangXi=86.4
241B2 CJK UNIFIED IDEOGRAPH-#241B2, IRGKangXi=0668.031, RSKangXi=86.4
241B3 CJK UNIFIED IDEOGRAPH-#241B3, IRGKangXi=0668.031, RSKangXi=86.4
241B4 CJK UNIFIED IDEOGRAPH-#241B4, IRGKangXi=0668.031, RSKangXi=86.4
241B5 CJK UNIFIED IDEOGRAPH-#241B5, IRGKangXi=0668.031, RSKangXi=86.4
241B6 CJK UNIFIED IDEOGRAPH-#241B6, IRGKangXi=0668.031, RSKangXi=86.4
241B7 CJK UNIFIED IDEOGRAPH-#241B7, IRGKangXi=0668.031, RSKangXi=86.4
241B8 CJK UNIFIED IDEOGRAPH-#241B8, IRGKangXi=0668.031, RSKangXi=86.4
241B9 CJK UNIFIED IDEOGRAPH-#241B9, IRGKangXi=0668.031, RSKangXi=86.4
241BA CJK UNIFIED IDEOGRAPH-#241BA, IRGKangXi=0668.031, RSKangXi=86.4
241BB CJK UNIFIED IDEOGRAPH-#241BB, IRGKangXi=0668.031, RSKangXi=86.4
241BC CJK UNIFIED IDEOGRAPH-#241BC, IRGKangXi=0668.090, RSKangXi=86.5
241BD CJK UNIFIED IDEOGRAPH-#241BD, IRGKangXi=0668.210, RSKangXi=86.5
241BE CJK UNIFIED IDEOGRAPH-#241BE, IRGKangXi=0668.220, RSKangXi=86.5
241BF CJK UNIFIED IDEOGRAPH-#241BF, IRGKangXi=0669.070, RSKangXi=86.5
241C0 CJK UNIFIED IDEOGRAPH-#241C0, IRGKangXi=0669.080, RSKangXi=86.5
241C1 CJK UNIFIED IDEOGRAPH-#241C1, IRGKangXi=0669.100, RSKangXi=86.5
241C2 CJK UNIFIED IDEOGRAPH-#241C2, IRGKangXi=0669.101, RSKangXi=86.5
241C3 CJK UNIFIED IDEOGRAPH-#241C3, IRGKangXi=0669.101, RSKangXi=86.5
241C4 CJK UNIFIED IDEOGRAPH-#241C4, IRGKangXi=0669.101, RSKangXi=86.5
241C5 CJK UNIFIED IDEOGRAPH-#241C5, IRGKangXi=0669.101, RSKangXi=86.5
241C6 CJK UNIFIED IDEOGRAPH-#241C6, IRGKangXi=0669.101, RSKangXi=86.5
241C7 CJK UNIFIED IDEOGRAPH-#241C7, IRGKangXi=0669.101, RSKangXi=86.5
241C8 CJK UNIFIED IDEOGRAPH-#241C8, IRGKangXi=0669.101, RSKangXi=86.5
241C9 CJK UNIFIED IDEOGRAPH-#241C9, IRGKangXi=0669.101, RSKangXi=86.5
241CA CJK UNIFIED IDEOGRAPH-#241CA, IRGKangXi=0669.101, RSKangXi=86.5
241CB CJK UNIFIED IDEOGRAPH-#241CB, IRGKangXi=0669.101, RSKangXi=86.5
241CC CJK UNIFIED IDEOGRAPH-#241CC, IRGKangXi=0669.101, RSKangXi=86.5
241CD CJK UNIFIED IDEOGRAPH-#241CD, IRGKangXi=0669.101, RSKangXi=86.5
241CE CJK UNIFIED IDEOGRAPH-#241CE, IRGKangXi=0669.101, RSKangXi=86.5
241CF CJK UNIFIED IDEOGRAPH-#241CF, IRGKangXi=0669.101, RSKangXi=86.5
241D0 CJK UNIFIED IDEOGRAPH-#241D0, IRGKangXi=0669.101, RSKangXi=86.5
241D1 CJK UNIFIED IDEOGRAPH-#241D1, IRGKangXi=0669.101, RSKangXi=86.5
241D2 CJK UNIFIED IDEOGRAPH-#241D2, IRGKangXi=0669.101, RSKangXi=86.5
241D3 CJK UNIFIED IDEOGRAPH-#241D3, IRGKangXi=0669.101, RSKangXi=86.5
241D4 CJK UNIFIED IDEOGRAPH-#241D4, IRGKangXi=0669.101, RSKangXi=86.5
241D5 CJK UNIFIED IDEOGRAPH-#241D5, IRGKangXi=0669.101, RSKangXi=86.5
241D6 CJK UNIFIED IDEOGRAPH-#241D6, IRGKangXi=0669.101, RSKangXi=86.5
241D7 CJK UNIFIED IDEOGRAPH-#241D7, IRGKangXi=0669.101, RSKangXi=86.5
241D8 CJK UNIFIED IDEOGRAPH-#241D8, IRGKangXi=0669.101, RSKangXi=86.5
241D9 CJK UNIFIED IDEOGRAPH-#241D9, IRGKangXi=0669.101, RSKangXi=86.5
241DA CJK UNIFIED IDEOGRAPH-#241DA, IRGKangXi=0669.101, RSKangXi=86.5
241DB CJK UNIFIED IDEOGRAPH-#241DB, IRGKangXi=0669.101, RSKangXi=86.5
241DC CJK UNIFIED IDEOGRAPH-#241DC, IRGKangXi=0669.101, RSKangXi=86.5
241DD CJK UNIFIED IDEOGRAPH-#241DD, IRGKangXi=0669.101, RSKangXi=86.5
241DE CJK UNIFIED IDEOGRAPH-#241DE, IRGKangXi=0669.101, RSKangXi=86.5
241DF CJK UNIFIED IDEOGRAPH-#241DF, IRGKangXi=0669.101, RSKangXi=86.5
241E0 CJK UNIFIED IDEOGRAPH-#241E0, IRGKangXi=0669.101, RSKangXi=86.5
241E1 CJK UNIFIED IDEOGRAPH-#241E1, IRGKangXi=0669.101, RSKangXi=86.5
241E2 CJK UNIFIED IDEOGRAPH-#241E2, IRGKangXi=0669.101, RSKangXi=86.5
241E3 CJK UNIFIED IDEOGRAPH-#241E3, IRGKangXi=0669.101, RSKangXi=86.5
241E4 CJK UNIFIED IDEOGRAPH-#241E4, IRGKangXi=0669.101, RSKangXi=86.5
241E5 CJK UNIFIED IDEOGRAPH-#241E5, IRGKangXi=0669.101, RSKangXi=86.5
241E6 CJK UNIFIED IDEOGRAPH-#241E6, IRGKangXi=0669.101, RSKangXi=86.5
241E7 CJK UNIFIED IDEOGRAPH-#241E7, IRGKangXi=0669.101, RSKangXi=86.5
241E8 CJK UNIFIED IDEOGRAPH-#241E8, IRGKangXi=0669.101, RSKangXi=86.5
241E9 CJK UNIFIED IDEOGRAPH-#241E9, IRGKangXi=0669.101, RSKangXi=86.5
241EA CJK UNIFIED IDEOGRAPH-#241EA, IRGKangXi=0669.101, RSKangXi=86.5
241EB CJK UNIFIED IDEOGRAPH-#241EB, IRGKangXi=0669.101, RSKangXi=86.5
241EC CJK UNIFIED IDEOGRAPH-#241EC, IRGKangXi=0669.101, RSKangXi=86.5
241ED CJK UNIFIED IDEOGRAPH-#241ED, IRGKangXi=0669.101, RSKangXi=86.5
241EE CJK UNIFIED IDEOGRAPH-#241EE, IRGKangXi=0669.101, RSKangXi=86.5
241EF CJK UNIFIED IDEOGRAPH-#241EF, IRGKangXi=0669.140, RSKangXi=86.6
241F0 CJK UNIFIED IDEOGRAPH-#241F0, IRGKangXi=0669.180, RSKangXi=86.6
241F1 CJK UNIFIED IDEOGRAPH-#241F1, IRGKangXi=0669.230, RSKangXi=86.6
241F2 CJK UNIFIED IDEOGRAPH-#241F2, IRGKangXi=0670.080, RSKangXi=86.6
241F3 CJK UNIFIED IDEOGRAPH-#241F3, IRGKangXi=0670.140, RSKangXi=86.6
241F4 CJK UNIFIED IDEOGRAPH-#241F4, IRGKangXi=0670.160, RSKangXi=86.6
241F5 CJK UNIFIED IDEOGRAPH-#241F5, IRGKangXi=0670.200, RSKangXi=86.6
241F6 CJK UNIFIED IDEOGRAPH-#241F6, IRGKangXi=0671.020, RSKangXi=86.6
241F7 CJK UNIFIED IDEOGRAPH-#241F7, IRGKangXi=0671.080, RSKangXi=86.6
241F8 CJK UNIFIED IDEOGRAPH-#241F8, IRGKangXi=0671.081, RSKangXi=86.6
241F9 CJK UNIFIED IDEOGRAPH-#241F9, IRGKangXi=0671.081, RSKangXi=86.6
241FA CJK UNIFIED IDEOGRAPH-#241FA, IRGKangXi=0671.081, RSKangXi=86.6
241FB CJK UNIFIED IDEOGRAPH-#241FB, IRGKangXi=0671.081, RSKangXi=86.6
241FC CJK UNIFIED IDEOGRAPH-#241FC, IRGKangXi=0671.081, RSKangXi=86.6
241FD CJK UNIFIED IDEOGRAPH-#241FD, IRGKangXi=0671.081, RSKangXi=86.6
241FE CJK UNIFIED IDEOGRAPH-#241FE, IRGKangXi=0671.081, RSKangXi=86.6, Def{brilliant}
241FF CJK UNIFIED IDEOGRAPH-#241FF, IRGKangXi=0671.081, RSKangXi=86.6
24200 CJK UNIFIED IDEOGRAPH-#24200, IRGKangXi=0671.081, RSKangXi=86.6
24201 CJK UNIFIED IDEOGRAPH-#24201, IRGKangXi=0671.081, RSKangXi=86.6
24202 CJK UNIFIED IDEOGRAPH-#24202, IRGKangXi=0671.081, RSKangXi=86.6
24203 CJK UNIFIED IDEOGRAPH-#24203, IRGKangXi=0671.081, RSKangXi=86.6
24204 CJK UNIFIED IDEOGRAPH-#24204, IRGKangXi=0671.081, RSKangXi=86.6
24205 CJK UNIFIED IDEOGRAPH-#24205, IRGKangXi=0671.081, RSKangXi=86.6
24206 CJK UNIFIED IDEOGRAPH-#24206, IRGKangXi=0671.081, RSKangXi=86.6
24207 CJK UNIFIED IDEOGRAPH-#24207, IRGKangXi=0671.081, RSKangXi=86.6
24208 CJK UNIFIED IDEOGRAPH-#24208, IRGKangXi=0671.081, RSKangXi=86.6
24209 CJK UNIFIED IDEOGRAPH-#24209, IRGKangXi=0671.081, RSKangXi=86.6
2420A CJK UNIFIED IDEOGRAPH-#2420A, IRGKangXi=0671.081, RSKangXi=86.6
2420B CJK UNIFIED IDEOGRAPH-#2420B, IRGKangXi=0671.081
2420C CJK UNIFIED IDEOGRAPH-#2420C, IRGKangXi=0671.081
2420D CJK UNIFIED IDEOGRAPH-#2420D, IRGKangXi=0671.081
2420E CJK UNIFIED IDEOGRAPH-#2420E, IRGKangXi=0671.081, RSKangXi=86.6
2420F CJK UNIFIED IDEOGRAPH-#2420F, IRGKangXi=0671.081, RSKangXi=86.6
24210 CJK UNIFIED IDEOGRAPH-#24210, IRGKangXi=0671.081, RSKangXi=86.6
24211 CJK UNIFIED IDEOGRAPH-#24211, IRGKangXi=0671.081, RSKangXi=86.6
24212 CJK UNIFIED IDEOGRAPH-#24212, IRGKangXi=0671.081, RSKangXi=86.6
24213 CJK UNIFIED IDEOGRAPH-#24213, IRGKangXi=0671.081, RSKangXi=86.6
24214 CJK UNIFIED IDEOGRAPH-#24214, IRGKangXi=0671.081, RSKangXi=86.6
24215 CJK UNIFIED IDEOGRAPH-#24215, IRGKangXi=0671.081, RSKangXi=86.6
24216 CJK UNIFIED IDEOGRAPH-#24216, IRGKangXi=0671.081, RSKangXi=86.6
24217 CJK UNIFIED IDEOGRAPH-#24217, IRGKangXi=0671.081, RSKangXi=86.6
24218 CJK UNIFIED IDEOGRAPH-#24218, IRGKangXi=0671.081, RSKangXi=86.6
24219 CJK UNIFIED IDEOGRAPH-#24219, IRGKangXi=0671.081, RSKangXi=86.6
2421A CJK UNIFIED IDEOGRAPH-#2421A, IRGKangXi=0671.081, RSKangXi=86.6
2421B CJK UNIFIED IDEOGRAPH-#2421B, IRGKangXi=0671.081, RSKangXi=86.6
2421C CJK UNIFIED IDEOGRAPH-#2421C, IRGKangXi=0671.081, RSKangXi=86.6
2421D CJK UNIFIED IDEOGRAPH-#2421D, IRGKangXi=0671.081, RSKangXi=86.6
2421E CJK UNIFIED IDEOGRAPH-#2421E, IRGKangXi=0671.081, RSKangXi=86.6
2421F CJK UNIFIED IDEOGRAPH-#2421F, IRGKangXi=0671.081, RSKangXi=86.6
24220 CJK UNIFIED IDEOGRAPH-#24220, IRGKangXi=0671.081, RSKangXi=86.6
24221 CJK UNIFIED IDEOGRAPH-#24221, IRGKangXi=0671.081, RSKangXi=86.6
24222 CJK UNIFIED IDEOGRAPH-#24222, IRGKangXi=0671.081, RSKangXi=86.6
24223 CJK UNIFIED IDEOGRAPH-#24223, IRGKangXi=0671.081, RSKangXi=86.6
24224 CJK UNIFIED IDEOGRAPH-#24224, IRGKangXi=0671.081, RSKangXi=86.6
24225 CJK UNIFIED IDEOGRAPH-#24225, IRGKangXi=0671.090, RSKangXi=86.7
24226 CJK UNIFIED IDEOGRAPH-#24226, IRGKangXi=0671.110, RSKangXi=86.7
24227 CJK UNIFIED IDEOGRAPH-#24227, IRGKangXi=0671.260, RSKangXi=86.7
24228 CJK UNIFIED IDEOGRAPH-#24228, IRGKangXi=0671.270, RSKangXi=86.7
24229 CJK UNIFIED IDEOGRAPH-#24229, IRGKangXi=0672.020, RSKangXi=86.7
2422A CJK UNIFIED IDEOGRAPH-#2422A, IRGKangXi=0672.030, RSKangXi=86.7
2422B CJK UNIFIED IDEOGRAPH-#2422B, IRGKangXi=0672.100, RSKangXi=86.7
2422C CJK UNIFIED IDEOGRAPH-#2422C, IRGKangXi=0673.040, RSKangXi=86.7
2422D CJK UNIFIED IDEOGRAPH-#2422D, IRGKangXi=0673.060, RSKangXi=86.7
2422E CJK UNIFIED IDEOGRAPH-#2422E, IRGKangXi=0673.070, RSKangXi=86.7
2422F CJK UNIFIED IDEOGRAPH-#2422F, IRGKangXi=0673.080, RSKangXi=86.7
24230 CJK UNIFIED IDEOGRAPH-#24230, IRGKangXi=0673.090, RSKangXi=86.7
24231 CJK UNIFIED IDEOGRAPH-#24231, IRGKangXi=0673.100, RSKangXi=86.7
24232 CJK UNIFIED IDEOGRAPH-#24232, IRGKangXi=0673.110, RSKangXi=86.7
24233 CJK UNIFIED IDEOGRAPH-#24233, IRGKangXi=0673.111, RSKangXi=86.7
24234 CJK UNIFIED IDEOGRAPH-#24234, IRGKangXi=0673.111, RSKangXi=86.7
24235 CJK UNIFIED IDEOGRAPH-#24235, IRGKangXi=0673.111, RSKangXi=86.7
24236 CJK UNIFIED IDEOGRAPH-#24236, IRGKangXi=0673.111, RSKangXi=86.7
24237 CJK UNIFIED IDEOGRAPH-#24237, IRGKangXi=0673.111, RSKangXi=86.7
24238 CJK UNIFIED IDEOGRAPH-#24238, IRGKangXi=0673.111, RSKangXi=86.7
24239 CJK UNIFIED IDEOGRAPH-#24239, IRGKangXi=0673.111, RSKangXi=86.7
2423A CJK UNIFIED IDEOGRAPH-#2423A, IRGKangXi=0673.111, RSKangXi=86.7
2423B CJK UNIFIED IDEOGRAPH-#2423B, IRGKangXi=0673.111, RSKangXi=86.7
2423C CJK UNIFIED IDEOGRAPH-#2423C, IRGKangXi=0673.111, RSKangXi=86.7
2423D CJK UNIFIED IDEOGRAPH-#2423D, IRGKangXi=0673.111, RSKangXi=86.7
2423E CJK UNIFIED IDEOGRAPH-#2423E, IRGKangXi=0673.111, RSKangXi=86.7
2423F CJK UNIFIED IDEOGRAPH-#2423F, IRGKangXi=0673.111, RSKangXi=86.7
24240 CJK UNIFIED IDEOGRAPH-#24240, IRGKangXi=0673.111, RSKangXi=86.7
24241 CJK UNIFIED IDEOGRAPH-#24241, IRGKangXi=0673.111, RSKangXi=86.7
24242 CJK UNIFIED IDEOGRAPH-#24242, IRGKangXi=0673.111, RSKangXi=86.7
24243 CJK UNIFIED IDEOGRAPH-#24243, IRGKangXi=0673.111, RSKangXi=86.7
24244 CJK UNIFIED IDEOGRAPH-#24244, IRGKangXi=0673.111, RSKangXi=86.7
24245 CJK UNIFIED IDEOGRAPH-#24245, IRGKangXi=0673.111, RSKangXi=86.7
24246 CJK UNIFIED IDEOGRAPH-#24246, IRGKangXi=0673.111, RSKangXi=86.7
24247 CJK UNIFIED IDEOGRAPH-#24247, IRGKangXi=0673.111, RSKangXi=86.7
24248 CJK UNIFIED IDEOGRAPH-#24248, IRGKangXi=0673.111, RSKangXi=86.7
24249 CJK UNIFIED IDEOGRAPH-#24249, IRGKangXi=0673.111, RSKangXi=86.7
2424A CJK UNIFIED IDEOGRAPH-#2424A, IRGKangXi=0673.111, RSKangXi=86.7
2424B CJK UNIFIED IDEOGRAPH-#2424B, IRGKangXi=0673.111, RSKangXi=86.7
2424C CJK UNIFIED IDEOGRAPH-#2424C, IRGKangXi=0673.111, RSKangXi=86.7
2424D CJK UNIFIED IDEOGRAPH-#2424D, IRGKangXi=0673.111, RSKangXi=86.7
2424E CJK UNIFIED IDEOGRAPH-#2424E, IRGKangXi=0673.111, RSKangXi=86.7
2424F CJK UNIFIED IDEOGRAPH-#2424F, IRGKangXi=0673.111, RSKangXi=86.7
24250 CJK UNIFIED IDEOGRAPH-#24250, IRGKangXi=0673.111, RSKangXi=86.7
24251 CJK UNIFIED IDEOGRAPH-#24251, IRGKangXi=0673.111, RSKangXi=86.7
24252 CJK UNIFIED IDEOGRAPH-#24252, IRGKangXi=0673.111, RSKangXi=86.7
24253 CJK UNIFIED IDEOGRAPH-#24253, IRGKangXi=0673.111, RSKangXi=86.7
24254 CJK UNIFIED IDEOGRAPH-#24254, IRGKangXi=0673.111, RSKangXi=86.7
24255 CJK UNIFIED IDEOGRAPH-#24255, IRGKangXi=0673.111, RSKangXi=86.7
24256 CJK UNIFIED IDEOGRAPH-#24256, IRGKangXi=0673.111, RSKangXi=86.7
24257 CJK UNIFIED IDEOGRAPH-#24257, IRGKangXi=0673.111, RSKangXi=86.7
24258 CJK UNIFIED IDEOGRAPH-#24258, IRGKangXi=0673.111, RSKangXi=86.7
24259 CJK UNIFIED IDEOGRAPH-#24259, IRGKangXi=0673.111, RSKangXi=86.7
2425A CJK UNIFIED IDEOGRAPH-#2425A, IRGKangXi=0673.111, RSKangXi=86.7
2425B CJK UNIFIED IDEOGRAPH-#2425B, IRGKangXi=0673.111, RSKangXi=86.7
2425C CJK UNIFIED IDEOGRAPH-#2425C, IRGKangXi=0673.111, RSKangXi=86.7
2425D CJK UNIFIED IDEOGRAPH-#2425D, IRGKangXi=0673.111, RSKangXi=86.7
2425E CJK UNIFIED IDEOGRAPH-#2425E, IRGKangXi=0673.111, RSKangXi=86.7
2425F CJK UNIFIED IDEOGRAPH-#2425F, IRGKangXi=0673.111, RSKangXi=86.7
24260 CJK UNIFIED IDEOGRAPH-#24260, IRGKangXi=0673.111, RSKangXi=86.7
24261 CJK UNIFIED IDEOGRAPH-#24261, IRGKangXi=0673.220, RSKangXi=86.7
24262 CJK UNIFIED IDEOGRAPH-#24262, IRGKangXi=0673.230, RSKangXi=86.8
24263 CJK UNIFIED IDEOGRAPH-#24263, IRGKangXi=0674.070, RSKangXi=86.8
24264 CJK UNIFIED IDEOGRAPH-#24264, IRGKangXi=0674.110, RSKangXi=86.8
24265 CJK UNIFIED IDEOGRAPH-#24265, IRGKangXi=0674.130, RSKangXi=86.8
24266 CJK UNIFIED IDEOGRAPH-#24266, IRGKangXi=0674.190, RSKangXi=86.8
24267 CJK UNIFIED IDEOGRAPH-#24267, IRGKangXi=0674.220, RSKangXi=86.8
24268 CJK UNIFIED IDEOGRAPH-#24268, IRGKangXi=0675.010, RSKangXi=86.8
24269 CJK UNIFIED IDEOGRAPH-#24269, IRGKangXi=0675.030, RSKangXi=86.8
2426A CJK UNIFIED IDEOGRAPH-#2426A, IRGKangXi=0675.070, RSKangXi=86.8
2426B CJK UNIFIED IDEOGRAPH-#2426B, IRGKangXi=0675.100, RSKangXi=86.8
2426C CJK UNIFIED IDEOGRAPH-#2426C, IRGKangXi=0675.140, RSKangXi=86.8
2426D CJK UNIFIED IDEOGRAPH-#2426D, IRGKangXi=0675.170, RSKangXi=86.8
2426E CJK UNIFIED IDEOGRAPH-#2426E, IRGKangXi=0675.180, RSKangXi=86.8
2426F CJK UNIFIED IDEOGRAPH-#2426F, IRGKangXi=0675.190, RSKangXi=86.8
24270 CJK UNIFIED IDEOGRAPH-#24270, IRGKangXi=0675.191, RSKangXi=86.8
24271 CJK UNIFIED IDEOGRAPH-#24271, IRGKangXi=0675.191, RSKangXi=86.8
24272 CJK UNIFIED IDEOGRAPH-#24272, IRGKangXi=0675.191, RSKangXi=86.8
24273 CJK UNIFIED IDEOGRAPH-#24273, IRGKangXi=0675.191, RSKangXi=86.8
24274 CJK UNIFIED IDEOGRAPH-#24274, IRGKangXi=0675.191, RSKangXi=86.8
24275 CJK UNIFIED IDEOGRAPH-#24275, IRGKangXi=0675.191, RSKangXi=86.8
24276 CJK UNIFIED IDEOGRAPH-#24276, IRGKangXi=0675.191, RSKangXi=86.8
24277 CJK UNIFIED IDEOGRAPH-#24277, IRGKangXi=0675.191, RSKangXi=86.8
24278 CJK UNIFIED IDEOGRAPH-#24278, IRGKangXi=0675.191, RSKangXi=86.8
24279 CJK UNIFIED IDEOGRAPH-#24279, IRGKangXi=0675.191, RSKangXi=86.8
2427A CJK UNIFIED IDEOGRAPH-#2427A, IRGKangXi=0675.191, RSKangXi=86.8
2427B CJK UNIFIED IDEOGRAPH-#2427B, IRGKangXi=0675.191, RSKangXi=86.8
2427C CJK UNIFIED IDEOGRAPH-#2427C, IRGKangXi=0675.191, RSKangXi=86.8
2427D CJK UNIFIED IDEOGRAPH-#2427D, IRGKangXi=0675.191, RSKangXi=86.8
2427E CJK UNIFIED IDEOGRAPH-#2427E, IRGKangXi=0675.191, RSKangXi=86.8
2427F CJK UNIFIED IDEOGRAPH-#2427F, IRGKangXi=0675.191, RSKangXi=86.8
24280 CJK UNIFIED IDEOGRAPH-#24280, IRGKangXi=0675.191, RSKangXi=86.8
24281 CJK UNIFIED IDEOGRAPH-#24281, IRGKangXi=0675.191, RSKangXi=86.8
24282 CJK UNIFIED IDEOGRAPH-#24282, IRGKangXi=0675.191, RSKangXi=86.8
24283 CJK UNIFIED IDEOGRAPH-#24283, IRGKangXi=0675.191, RSKangXi=86.8
24284 CJK UNIFIED IDEOGRAPH-#24284, IRGKangXi=0675.191, RSKangXi=86.8
24285 CJK UNIFIED IDEOGRAPH-#24285, IRGKangXi=0675.191, RSKangXi=86.8
24286 CJK UNIFIED IDEOGRAPH-#24286, IRGKangXi=0675.191, RSKangXi=86.8
24287 CJK UNIFIED IDEOGRAPH-#24287, IRGKangXi=0675.191, RSKangXi=86.8
24288 CJK UNIFIED IDEOGRAPH-#24288, IRGKangXi=0675.191, RSKangXi=86.8
24289 CJK UNIFIED IDEOGRAPH-#24289, IRGKangXi=0675.191, RSKangXi=86.8
2428A CJK UNIFIED IDEOGRAPH-#2428A, IRGKangXi=0675.191, RSKangXi=86.8
2428B CJK UNIFIED IDEOGRAPH-#2428B, IRGKangXi=0675.191, RSKangXi=86.8
2428C CJK UNIFIED IDEOGRAPH-#2428C, IRGKangXi=0675.191, RSKangXi=86.8
2428D CJK UNIFIED IDEOGRAPH-#2428D, IRGKangXi=0675.191, RSKangXi=86.8
2428E CJK UNIFIED IDEOGRAPH-#2428E, IRGKangXi=0675.191, RSKangXi=86.8
2428F CJK UNIFIED IDEOGRAPH-#2428F, IRGKangXi=0675.191, RSKangXi=86.8
24290 CJK UNIFIED IDEOGRAPH-#24290, IRGKangXi=0675.191, RSKangXi=86.8
24291 CJK UNIFIED IDEOGRAPH-#24291, IRGKangXi=0675.191, RSKangXi=86.8
24292 CJK UNIFIED IDEOGRAPH-#24292, IRGKangXi=0675.191, RSKangXi=86.8, Def{(Cant.) to scald with boiling water}
24293 CJK UNIFIED IDEOGRAPH-#24293, IRGKangXi=0675.191, RSKangXi=86.8
24294 CJK UNIFIED IDEOGRAPH-#24294, IRGKangXi=0675.191, RSKangXi=86.8
24295 CJK UNIFIED IDEOGRAPH-#24295, IRGKangXi=0675.191, RSKangXi=86.8
24296 CJK UNIFIED IDEOGRAPH-#24296, IRGKangXi=0675.191, RSKangXi=86.8
24297 CJK UNIFIED IDEOGRAPH-#24297, IRGKangXi=0675.191, RSKangXi=86.8
24298 CJK UNIFIED IDEOGRAPH-#24298, IRGKangXi=0675.191, RSKangXi=86.8
24299 CJK UNIFIED IDEOGRAPH-#24299, IRGKangXi=0675.191, RSKangXi=86.8
2429A CJK UNIFIED IDEOGRAPH-#2429A, IRGKangXi=0675.191, RSKangXi=86.8
2429B CJK UNIFIED IDEOGRAPH-#2429B, IRGKangXi=0675.191, RSKangXi=86.8
2429C CJK UNIFIED IDEOGRAPH-#2429C, IRGKangXi=0675.191, RSKangXi=86.8
2429D CJK UNIFIED IDEOGRAPH-#2429D, IRGKangXi=0675.191, RSKangXi=86.8
2429E CJK UNIFIED IDEOGRAPH-#2429E, IRGKangXi=0675.191, RSKangXi=86.8
2429F CJK UNIFIED IDEOGRAPH-#2429F, IRGKangXi=0675.191, RSKangXi=86.8
242A0 CJK UNIFIED IDEOGRAPH-#242A0, IRGKangXi=0675.191, RSKangXi=86.8
242A1 CJK UNIFIED IDEOGRAPH-#242A1, IRGKangXi=0675.191, RSKangXi=86.8
242A2 CJK UNIFIED IDEOGRAPH-#242A2, IRGKangXi=0675.191, RSKangXi=86.8
242A3 CJK UNIFIED IDEOGRAPH-#242A3, IRGKangXi=0675.191, RSKangXi=86.8
242A4 CJK UNIFIED IDEOGRAPH-#242A4, IRGKangXi=0675.191, RSKangXi=86.8
242A5 CJK UNIFIED IDEOGRAPH-#242A5, IRGKangXi=0675.191, RSKangXi=86.8
242A6 CJK UNIFIED IDEOGRAPH-#242A6, IRGKangXi=0675.191, RSKangXi=86.8
242A7 CJK UNIFIED IDEOGRAPH-#242A7, IRGKangXi=0675.191, RSKangXi=86.8
242A8 CJK UNIFIED IDEOGRAPH-#242A8, IRGKangXi=0675.191, RSKangXi=86.8
242A9 CJK UNIFIED IDEOGRAPH-#242A9, IRGKangXi=0675.191, RSKangXi=86.8
242AA CJK UNIFIED IDEOGRAPH-#242AA, IRGKangXi=0675.191, RSKangXi=86.8
242AB CJK UNIFIED IDEOGRAPH-#242AB, IRGKangXi=0675.191, RSKangXi=86.8
242AC CJK UNIFIED IDEOGRAPH-#242AC, IRGKangXi=0675.191, RSKangXi=86.8
242AD CJK UNIFIED IDEOGRAPH-#242AD, IRGKangXi=0675.191, RSKangXi=86.8
242AE CJK UNIFIED IDEOGRAPH-#242AE, IRGKangXi=0675.191, RSKangXi=86.8
242AF CJK UNIFIED IDEOGRAPH-#242AF, IRGKangXi=0675.191, RSKangXi=86.8
242B0 CJK UNIFIED IDEOGRAPH-#242B0, IRGKangXi=0675.191, RSKangXi=86.8
242B1 CJK UNIFIED IDEOGRAPH-#242B1, IRGKangXi=0675.191, RSKangXi=86.8
242B2 CJK UNIFIED IDEOGRAPH-#242B2, IRGKangXi=0675.200, RSKangXi=86.9
242B3 CJK UNIFIED IDEOGRAPH-#242B3, IRGKangXi=0675.250, RSKangXi=86.9
242B4 CJK UNIFIED IDEOGRAPH-#242B4, IRGKangXi=0676.090, RSKangXi=86.9
242B5 CJK UNIFIED IDEOGRAPH-#242B5, IRGKangXi=0676.190, RSKangXi=86.9
242B6 CJK UNIFIED IDEOGRAPH-#242B6, IRGKangXi=0676.200, RSKangXi=86.9
242B7 CJK UNIFIED IDEOGRAPH-#242B7, IRGKangXi=0676.210, RSKangXi=86.9
242B8 CJK UNIFIED IDEOGRAPH-#242B8, IRGKangXi=0677.050, RSKangXi=86.9
242B9 CJK UNIFIED IDEOGRAPH-#242B9, IRGKangXi=0677.060, RSKangXi=86.9
242BA CJK UNIFIED IDEOGRAPH-#242BA, IRGKangXi=0677.160, RSKangXi=86.9
242BB CJK UNIFIED IDEOGRAPH-#242BB, IRGKangXi=0677.190, RSKangXi=86.9
242BC CJK UNIFIED IDEOGRAPH-#242BC, IRGKangXi=0677.220, RSKangXi=86.9
242BD CJK UNIFIED IDEOGRAPH-#242BD, IRGKangXi=0677.270, RSKangXi=86.9
242BE CJK UNIFIED IDEOGRAPH-#242BE, IRGKangXi=0677.310, RSKangXi=86.9
242BF CJK UNIFIED IDEOGRAPH-#242BF, IRGKangXi=0677.320, RSKangXi=86.9
242C0 CJK UNIFIED IDEOGRAPH-#242C0, IRGKangXi=0678.050, RSKangXi=86.9
242C1 CJK UNIFIED IDEOGRAPH-#242C1, IRGKangXi=0678.080, RSKangXi=86.9
242C2 CJK UNIFIED IDEOGRAPH-#242C2, IRGKangXi=0678.100, RSKangXi=86.9
242C3 CJK UNIFIED IDEOGRAPH-#242C3, IRGKangXi=0678.110, RSKangXi=86.9
242C4 CJK UNIFIED IDEOGRAPH-#242C4, IRGKangXi=0678.120, RSKangXi=86.9
242C5 CJK UNIFIED IDEOGRAPH-#242C5, IRGKangXi=0678.130, RSKangXi=86.9
242C6 CJK UNIFIED IDEOGRAPH-#242C6, IRGKangXi=0678.150, RSKangXi=86.9
242C7 CJK UNIFIED IDEOGRAPH-#242C7, IRGKangXi=0678.160, RSKangXi=86.9
242C8 CJK UNIFIED IDEOGRAPH-#242C8, IRGKangXi=0678.161, RSKangXi=86.9
242C9 CJK UNIFIED IDEOGRAPH-#242C9, IRGKangXi=0678.161, RSKangXi=86.9
242CA CJK UNIFIED IDEOGRAPH-#242CA, IRGKangXi=0678.161, RSKangXi=86.9
242CB CJK UNIFIED IDEOGRAPH-#242CB, IRGKangXi=0678.161, RSKangXi=86.9
242CC CJK UNIFIED IDEOGRAPH-#242CC, IRGKangXi=0678.161, RSKangXi=86.9
242CD CJK UNIFIED IDEOGRAPH-#242CD, IRGKangXi=0678.161, RSKangXi=86.9
242CE CJK UNIFIED IDEOGRAPH-#242CE, IRGKangXi=0678.161, RSKangXi=86.9
242CF CJK UNIFIED IDEOGRAPH-#242CF, IRGKangXi=0678.161, RSKangXi=86.9
242D0 CJK UNIFIED IDEOGRAPH-#242D0, IRGKangXi=0678.161, RSKangXi=86.9
242D1 CJK UNIFIED IDEOGRAPH-#242D1, IRGKangXi=0678.161, RSKangXi=86.9
242D2 CJK UNIFIED IDEOGRAPH-#242D2, IRGKangXi=0678.161, RSKangXi=86.9
242D3 CJK UNIFIED IDEOGRAPH-#242D3, IRGKangXi=0678.161, RSKangXi=86.9
242D4 CJK UNIFIED IDEOGRAPH-#242D4, IRGKangXi=0678.161, RSKangXi=86.9
242D5 CJK UNIFIED IDEOGRAPH-#242D5, IRGKangXi=0678.161, RSKangXi=86.9
242D6 CJK UNIFIED IDEOGRAPH-#242D6, IRGKangXi=0678.161, RSKangXi=86.9
242D7 CJK UNIFIED IDEOGRAPH-#242D7, IRGKangXi=0678.161, RSKangXi=86.9
242D8 CJK UNIFIED IDEOGRAPH-#242D8, IRGKangXi=0678.161, RSKangXi=86.9
242D9 CJK UNIFIED IDEOGRAPH-#242D9, IRGKangXi=0678.161, RSKangXi=86.9
242DA CJK UNIFIED IDEOGRAPH-#242DA, IRGKangXi=0678.161, RSKangXi=86.9
242DB CJK UNIFIED IDEOGRAPH-#242DB, IRGKangXi=0678.161, RSKangXi=86.9
242DC CJK UNIFIED IDEOGRAPH-#242DC, IRGKangXi=0678.161, RSKangXi=86.9
242DD CJK UNIFIED IDEOGRAPH-#242DD, IRGKangXi=0678.161, RSKangXi=86.9
242DE CJK UNIFIED IDEOGRAPH-#242DE, IRGKangXi=0678.161, RSKangXi=86.9
242DF CJK UNIFIED IDEOGRAPH-#242DF, IRGKangXi=0678.161, RSKangXi=86.9
242E0 CJK UNIFIED IDEOGRAPH-#242E0, IRGKangXi=0678.161, RSKangXi=86.9
242E1 CJK UNIFIED IDEOGRAPH-#242E1, IRGKangXi=0678.161, RSKangXi=86.9
242E2 CJK UNIFIED IDEOGRAPH-#242E2, IRGKangXi=0678.161, RSKangXi=86.9
242E3 CJK UNIFIED IDEOGRAPH-#242E3, IRGKangXi=0678.161, RSKangXi=86.9
242E4 CJK UNIFIED IDEOGRAPH-#242E4, IRGKangXi=0678.161, RSKangXi=86.9
242E5 CJK UNIFIED IDEOGRAPH-#242E5, IRGKangXi=0678.161, RSKangXi=86.9
242E6 CJK UNIFIED IDEOGRAPH-#242E6, IRGKangXi=0678.161, RSKangXi=86.9
242E7 CJK UNIFIED IDEOGRAPH-#242E7, IRGKangXi=0678.161, RSKangXi=86.9
242E8 CJK UNIFIED IDEOGRAPH-#242E8, IRGKangXi=0678.161, RSKangXi=86.9
242E9 CJK UNIFIED IDEOGRAPH-#242E9, IRGKangXi=0678.161, RSKangXi=86.9
242EA CJK UNIFIED IDEOGRAPH-#242EA, IRGKangXi=0678.161, RSKangXi=86.9
242EB CJK UNIFIED IDEOGRAPH-#242EB, IRGKangXi=0678.161, RSKangXi=86.9
242EC CJK UNIFIED IDEOGRAPH-#242EC, IRGKangXi=0678.161, RSKangXi=86.9
242ED CJK UNIFIED IDEOGRAPH-#242ED, IRGKangXi=0678.161, RSKangXi=86.9
242EE CJK UNIFIED IDEOGRAPH-#242EE, IRGKangXi=0678.161, RSKangXi=86.9
242EF CJK UNIFIED IDEOGRAPH-#242EF, IRGKangXi=0678.161, RSKangXi=86.9
242F0 CJK UNIFIED IDEOGRAPH-#242F0, IRGKangXi=0678.161, RSKangXi=86.9
242F1 CJK UNIFIED IDEOGRAPH-#242F1, IRGKangXi=0678.161, RSKangXi=86.9
242F2 CJK UNIFIED IDEOGRAPH-#242F2, IRGKangXi=0678.161, RSKangXi=86.9
242F3 CJK UNIFIED IDEOGRAPH-#242F3, IRGKangXi=0678.161, RSKangXi=195.0
242F4 CJK UNIFIED IDEOGRAPH-#242F4, IRGKangXi=0678.161, RSKangXi=86.9
242F5 CJK UNIFIED IDEOGRAPH-#242F5, IRGKangXi=0678.161, RSKangXi=86.9
242F6 CJK UNIFIED IDEOGRAPH-#242F6, IRGKangXi=0678.161, RSKangXi=86.9
242F7 CJK UNIFIED IDEOGRAPH-#242F7, IRGKangXi=0678.161, RSKangXi=86.9
242F8 CJK UNIFIED IDEOGRAPH-#242F8, IRGKangXi=0678.161, RSKangXi=86.9
242F9 CJK UNIFIED IDEOGRAPH-#242F9, IRGKangXi=0678.161, RSKangXi=86.9
242FA CJK UNIFIED IDEOGRAPH-#242FA, IRGKangXi=0678.161, RSKangXi=86.9
242FB CJK UNIFIED IDEOGRAPH-#242FB, IRGKangXi=0678.161, RSKangXi=86.9
242FC CJK UNIFIED IDEOGRAPH-#242FC, IRGKangXi=0678.161, RSKangXi=86.9
242FD CJK UNIFIED IDEOGRAPH-#242FD, IRGKangXi=0678.161, RSKangXi=86.9
242FE CJK UNIFIED IDEOGRAPH-#242FE, IRGKangXi=0678.161, RSKangXi=86.9
242FF CJK UNIFIED IDEOGRAPH-#242FF, IRGKangXi=0678.161, RSKangXi=86.9
24300 CJK UNIFIED IDEOGRAPH-#24300, IRGKangXi=0678.161, RSKangXi=86.9
24301 CJK UNIFIED IDEOGRAPH-#24301, IRGKangXi=0678.161, RSKangXi=86.9
24302 CJK UNIFIED IDEOGRAPH-#24302, IRGKangXi=0678.161, RSKangXi=86.9
24303 CJK UNIFIED IDEOGRAPH-#24303, IRGKangXi=0678.161, RSKangXi=86.9
24304 CJK UNIFIED IDEOGRAPH-#24304, IRGKangXi=0678.161, RSKangXi=86.9
24305 CJK UNIFIED IDEOGRAPH-#24305, IRGKangXi=0678.161, RSKangXi=86.9
24306 CJK UNIFIED IDEOGRAPH-#24306, IRGKangXi=0678.161, RSKangXi=86.9
24307 CJK UNIFIED IDEOGRAPH-#24307, IRGKangXi=0678.161, RSKangXi=86.10
24308 CJK UNIFIED IDEOGRAPH-#24308, IRGKangXi=0678.210, RSKangXi=86.10
24309 CJK UNIFIED IDEOGRAPH-#24309, IRGKangXi=0678.240, RSKangXi=86.10
2430A CJK UNIFIED IDEOGRAPH-#2430A, IRGKangXi=0678.310, RSKangXi=86.10
2430B CJK UNIFIED IDEOGRAPH-#2430B, IRGKangXi=0678.370, RSKangXi=86.10
2430C CJK UNIFIED IDEOGRAPH-#2430C, IRGKangXi=0679.020, RSKangXi=86.10
2430D CJK UNIFIED IDEOGRAPH-#2430D, IRGKangXi=0679.050, RSKangXi=86.10, Def{(Cant.) to fry}
2430E CJK UNIFIED IDEOGRAPH-#2430E, IRGKangXi=0679.130, RSKangXi=86.10
2430F CJK UNIFIED IDEOGRAPH-#2430F, IRGKangXi=0679.180, RSKangXi=86.10
24310 CJK UNIFIED IDEOGRAPH-#24310, IRGKangXi=0680.010, RSKangXi=86.10
24311 CJK UNIFIED IDEOGRAPH-#24311, IRGKangXi=0680.020, RSKangXi=86.10
24312 CJK UNIFIED IDEOGRAPH-#24312, IRGKangXi=0680.030, RSKangXi=86.10
24313 CJK UNIFIED IDEOGRAPH-#24313, IRGKangXi=0680.060, RSKangXi=86.10
24314 CJK UNIFIED IDEOGRAPH-#24314, IRGKangXi=0680.070, RSKangXi=86.10
24315 CJK UNIFIED IDEOGRAPH-#24315, IRGKangXi=0680.080, RSKangXi=86.10
24316 CJK UNIFIED IDEOGRAPH-#24316, IRGKangXi=0680.090, RSKangXi=86.10
24317 CJK UNIFIED IDEOGRAPH-#24317, IRGKangXi=0680.100, RSKangXi=86.10
24318 CJK UNIFIED IDEOGRAPH-#24318, IRGKangXi=0680.101, RSKangXi=86.10
24319 CJK UNIFIED IDEOGRAPH-#24319, IRGKangXi=0680.101, RSKangXi=86.10
2431A CJK UNIFIED IDEOGRAPH-#2431A, IRGKangXi=0680.101, RSKangXi=86.10
2431B CJK UNIFIED IDEOGRAPH-#2431B, IRGKangXi=0680.101, RSKangXi=86.10
2431C CJK UNIFIED IDEOGRAPH-#2431C, IRGKangXi=0680.101, RSKangXi=86.10
2431D CJK UNIFIED IDEOGRAPH-#2431D, IRGKangXi=0680.101, RSKangXi=86.10
2431E CJK UNIFIED IDEOGRAPH-#2431E, IRGKangXi=0680.101, RSKangXi=86.10
2431F CJK UNIFIED IDEOGRAPH-#2431F, IRGKangXi=0680.101, RSKangXi=86.10
24320 CJK UNIFIED IDEOGRAPH-#24320, IRGKangXi=0680.101, RSKangXi=86.10
24321 CJK UNIFIED IDEOGRAPH-#24321, IRGKangXi=0680.101, RSKangXi=86.10
24322 CJK UNIFIED IDEOGRAPH-#24322, IRGKangXi=0680.101, RSKangXi=86.10
24323 CJK UNIFIED IDEOGRAPH-#24323, IRGKangXi=0680.101, RSKangXi=86.10
24324 CJK UNIFIED IDEOGRAPH-#24324, IRGKangXi=0680.101, RSKangXi=86.10
24325 CJK UNIFIED IDEOGRAPH-#24325, IRGKangXi=0680.101, RSKangXi=86.10
24326 CJK UNIFIED IDEOGRAPH-#24326, IRGKangXi=0680.101, RSKangXi=86.10
24327 CJK UNIFIED IDEOGRAPH-#24327, IRGKangXi=0680.101, RSKangXi=86.10
24328 CJK UNIFIED IDEOGRAPH-#24328, IRGKangXi=0680.101, RSKangXi=86.10
24329 CJK UNIFIED IDEOGRAPH-#24329, IRGKangXi=0680.101, RSKangXi=86.10
2432A CJK UNIFIED IDEOGRAPH-#2432A, IRGKangXi=0680.101, RSKangXi=86.10
2432B CJK UNIFIED IDEOGRAPH-#2432B, IRGKangXi=0680.101, RSKangXi=86.10
2432C CJK UNIFIED IDEOGRAPH-#2432C, IRGKangXi=0680.101, RSKangXi=86.10
2432D CJK UNIFIED IDEOGRAPH-#2432D, IRGKangXi=0680.101, RSKangXi=86.10
2432E CJK UNIFIED IDEOGRAPH-#2432E, IRGKangXi=0680.101, RSKangXi=86.10
2432F CJK UNIFIED IDEOGRAPH-#2432F, IRGKangXi=0680.101, RSKangXi=86.10
24330 CJK UNIFIED IDEOGRAPH-#24330, IRGKangXi=0680.101, RSKangXi=86.10
24331 CJK UNIFIED IDEOGRAPH-#24331, IRGKangXi=0680.101, RSKangXi=86.10
24332 CJK UNIFIED IDEOGRAPH-#24332, IRGKangXi=0680.101, RSKangXi=86.11
24333 CJK UNIFIED IDEOGRAPH-#24333, IRGKangXi=0680.101, RSKangXi=86.10
24334 CJK UNIFIED IDEOGRAPH-#24334, IRGKangXi=0680.101, RSKangXi=86.10
24335 CJK UNIFIED IDEOGRAPH-#24335, IRGKangXi=0680.101, RSKangXi=86.10
24336 CJK UNIFIED IDEOGRAPH-#24336, IRGKangXi=0680.101, RSKangXi=86.10
24337 CJK UNIFIED IDEOGRAPH-#24337, IRGKangXi=0680.101, RSKangXi=86.10
24338 CJK UNIFIED IDEOGRAPH-#24338, IRGKangXi=0680.101, RSKangXi=86.10
24339 CJK UNIFIED IDEOGRAPH-#24339, IRGKangXi=0680.101, RSKangXi=86.10
2433A CJK UNIFIED IDEOGRAPH-#2433A, IRGKangXi=0680.101, RSKangXi=86.10
2433B CJK UNIFIED IDEOGRAPH-#2433B, IRGKangXi=0680.101, RSKangXi=86.10
2433C CJK UNIFIED IDEOGRAPH-#2433C, IRGKangXi=0680.101, RSKangXi=86.10
2433D CJK UNIFIED IDEOGRAPH-#2433D, IRGKangXi=0680.101, RSKangXi=86.10
2433E CJK UNIFIED IDEOGRAPH-#2433E, IRGKangXi=0680.101, RSKangXi=86.10
2433F CJK UNIFIED IDEOGRAPH-#2433F, IRGKangXi=0680.101, RSKangXi=86.10
24340 CJK UNIFIED IDEOGRAPH-#24340, IRGKangXi=0680.101, RSKangXi=86.10
24341 CJK UNIFIED IDEOGRAPH-#24341, IRGKangXi=0680.101, RSKangXi=86.10
24342 CJK UNIFIED IDEOGRAPH-#24342, IRGKangXi=0680.101, RSKangXi=86.10
24343 CJK UNIFIED IDEOGRAPH-#24343, IRGKangXi=0680.101, RSKangXi=86.10
24344 CJK UNIFIED IDEOGRAPH-#24344, IRGKangXi=0680.101, RSKangXi=86.10
24345 CJK UNIFIED IDEOGRAPH-#24345, IRGKangXi=0680.101, RSKangXi=86.10
24346 CJK UNIFIED IDEOGRAPH-#24346, IRGKangXi=0680.101, RSKangXi=86.10
24347 CJK UNIFIED IDEOGRAPH-#24347, IRGKangXi=0680.101, RSKangXi=86.10
24348 CJK UNIFIED IDEOGRAPH-#24348, IRGKangXi=0680.101, RSKangXi=86.10
24349 CJK UNIFIED IDEOGRAPH-#24349, IRGKangXi=0680.101, RSKangXi=86.10
2434A CJK UNIFIED IDEOGRAPH-#2434A, IRGKangXi=0680.101, RSKangXi=86.10
2434B CJK UNIFIED IDEOGRAPH-#2434B, IRGKangXi=0680.101, RSKangXi=86.10
2434C CJK UNIFIED IDEOGRAPH-#2434C, IRGKangXi=0680.101, RSKangXi=86.10
2434D CJK UNIFIED IDEOGRAPH-#2434D, IRGKangXi=0680.101, RSKangXi=86.10
2434E CJK UNIFIED IDEOGRAPH-#2434E, IRGKangXi=0680.101, RSKangXi=86.10
2434F CJK UNIFIED IDEOGRAPH-#2434F, IRGKangXi=0680.101, RSKangXi=86.9
24350 CJK UNIFIED IDEOGRAPH-#24350, IRGKangXi=0680.110, RSKangXi=86.11
24351 CJK UNIFIED IDEOGRAPH-#24351, IRGKangXi=0680.141, RSKangXi=86.11
24352 CJK UNIFIED IDEOGRAPH-#24352, IRGKangXi=0680.190, RSKangXi=86.11
24353 CJK UNIFIED IDEOGRAPH-#24353, IRGKangXi=0680.230, RSKangXi=86.11
24354 CJK UNIFIED IDEOGRAPH-#24354, IRGKangXi=0680.270, RSKangXi=86.11
24355 CJK UNIFIED IDEOGRAPH-#24355, IRGKangXi=0680.280, RSKangXi=86.11, Def{to gather wood for a burnt sacrifice to Heaven}
24356 CJK UNIFIED IDEOGRAPH-#24356, IRGKangXi=0680.370, RSKangXi=86.11
24357 CJK UNIFIED IDEOGRAPH-#24357, IRGKangXi=0681.050, RSKangXi=86.11
24358 CJK UNIFIED IDEOGRAPH-#24358, IRGKangXi=0681.070, RSKangXi=86.11
24359 CJK UNIFIED IDEOGRAPH-#24359, IRGKangXi=0681.100, RSKangXi=86.11
2435A CJK UNIFIED IDEOGRAPH-#2435A, IRGKangXi=0681.110, RSKangXi=86.11
2435B CJK UNIFIED IDEOGRAPH-#2435B, IRGKangXi=0681.120, RSKangXi=86.11
2435C CJK UNIFIED IDEOGRAPH-#2435C, IRGKangXi=0681.130, RSKangXi=86.11
2435D CJK UNIFIED IDEOGRAPH-#2435D, IRGKangXi=0681.140, RSKangXi=86.11
2435E CJK UNIFIED IDEOGRAPH-#2435E, IRGKangXi=0681.141, RSKangXi=86.11
2435F CJK UNIFIED IDEOGRAPH-#2435F, IRGKangXi=0681.141, RSKangXi=86.11
24360 CJK UNIFIED IDEOGRAPH-#24360, IRGKangXi=0681.141, RSKangXi=86.11, Def{hot (in temperature)}
24361 CJK UNIFIED IDEOGRAPH-#24361, IRGKangXi=0681.141, RSKangXi=86.11
24362 CJK UNIFIED IDEOGRAPH-#24362, IRGKangXi=0681.141, RSKangXi=86.11
24363 CJK UNIFIED IDEOGRAPH-#24363, IRGKangXi=0681.141, RSKangXi=86.11
24364 CJK UNIFIED IDEOGRAPH-#24364, IRGKangXi=0681.141, RSKangXi=86.11, Def{a flaming explosion, a flash}
24365 CJK UNIFIED IDEOGRAPH-#24365, IRGKangXi=0681.141, RSKangXi=86.11
24366 CJK UNIFIED IDEOGRAPH-#24366, IRGKangXi=0681.141, RSKangXi=86.11
24367 CJK UNIFIED IDEOGRAPH-#24367, IRGKangXi=0681.141, RSKangXi=86.11
24368 CJK UNIFIED IDEOGRAPH-#24368, IRGKangXi=0681.141, RSKangXi=86.11
24369 CJK UNIFIED IDEOGRAPH-#24369, IRGKangXi=0681.141, RSKangXi=86.12
2436A CJK UNIFIED IDEOGRAPH-#2436A, IRGKangXi=0681.141, RSKangXi=86.11
2436B CJK UNIFIED IDEOGRAPH-#2436B, IRGKangXi=0681.141, RSKangXi=86.11
2436C CJK UNIFIED IDEOGRAPH-#2436C, IRGKangXi=0681.141, RSKangXi=86.11
2436D CJK UNIFIED IDEOGRAPH-#2436D, IRGKangXi=0681.141, RSKangXi=86.11
2436E CJK UNIFIED IDEOGRAPH-#2436E, IRGKangXi=0681.141, RSKangXi=86.11
2436F CJK UNIFIED IDEOGRAPH-#2436F, IRGKangXi=0681.141, RSKangXi=86.11
24370 CJK UNIFIED IDEOGRAPH-#24370, IRGKangXi=0681.141, RSKangXi=86.11
24371 CJK UNIFIED IDEOGRAPH-#24371, IRGKangXi=0681.141, RSKangXi=86.11
24372 CJK UNIFIED IDEOGRAPH-#24372, IRGKangXi=0681.141, RSKangXi=86.11
24373 CJK UNIFIED IDEOGRAPH-#24373, IRGKangXi=0681.141, RSKangXi=86.11
24374 CJK UNIFIED IDEOGRAPH-#24374, IRGKangXi=0681.141, RSKangXi=86.11
24375 CJK UNIFIED IDEOGRAPH-#24375, IRGKangXi=0681.141, RSKangXi=86.11
24376 CJK UNIFIED IDEOGRAPH-#24376, IRGKangXi=0681.141, RSKangXi=86.11
24377 CJK UNIFIED IDEOGRAPH-#24377, IRGKangXi=0681.141, RSKangXi=86.11
24378 CJK UNIFIED IDEOGRAPH-#24378, IRGKangXi=0681.141, RSKangXi=86.11
24379 CJK UNIFIED IDEOGRAPH-#24379, IRGKangXi=0681.141, RSKangXi=86.11
2437A CJK UNIFIED IDEOGRAPH-#2437A, IRGKangXi=0681.141, RSKangXi=86.11
2437B CJK UNIFIED IDEOGRAPH-#2437B, IRGKangXi=0681.141, RSKangXi=86.11
2437C CJK UNIFIED IDEOGRAPH-#2437C, IRGKangXi=0681.141, RSKangXi=86.11
2437D CJK UNIFIED IDEOGRAPH-#2437D, IRGKangXi=0681.141, RSKangXi=86.11
2437E CJK UNIFIED IDEOGRAPH-#2437E, IRGKangXi=0681.141, RSKangXi=86.11
2437F CJK UNIFIED IDEOGRAPH-#2437F, IRGKangXi=0681.141, RSKangXi=86.11
24380 CJK UNIFIED IDEOGRAPH-#24380, IRGKangXi=0681.141, RSKangXi=140.10
24381 CJK UNIFIED IDEOGRAPH-#24381, IRGKangXi=0681.141, RSKangXi=86.11
24382 CJK UNIFIED IDEOGRAPH-#24382, IRGKangXi=0681.141, RSKangXi=176.6
24383 CJK UNIFIED IDEOGRAPH-#24383, IRGKangXi=0681.141, RSKangXi=86.11
24384 CJK UNIFIED IDEOGRAPH-#24384, IRGKangXi=0681.141, RSKangXi=86.11
24385 CJK UNIFIED IDEOGRAPH-#24385, IRGKangXi=0681.141, RSKangXi=86.11
24386 CJK UNIFIED IDEOGRAPH-#24386, IRGKangXi=0681.141, RSKangXi=86.11
24387 CJK UNIFIED IDEOGRAPH-#24387, IRGKangXi=0681.141, RSKangXi=86.11
24388 CJK UNIFIED IDEOGRAPH-#24388, IRGKangXi=0681.141, RSKangXi=86.11
24389 CJK UNIFIED IDEOGRAPH-#24389, IRGKangXi=0681.141, RSKangXi=86.11
2438A CJK UNIFIED IDEOGRAPH-#2438A, IRGKangXi=0681.141, RSKangXi=86.11
2438B CJK UNIFIED IDEOGRAPH-#2438B, IRGKangXi=0681.141, RSKangXi=86.11
2438C CJK UNIFIED IDEOGRAPH-#2438C, IRGKangXi=0681.141, RSKangXi=86.11
2438D CJK UNIFIED IDEOGRAPH-#2438D, IRGKangXi=0681.141, RSKangXi=86.11
2438E CJK UNIFIED IDEOGRAPH-#2438E, IRGKangXi=0681.141, RSKangXi=86.11
2438F CJK UNIFIED IDEOGRAPH-#2438F, IRGKangXi=0681.141, RSKangXi=86.11
24390 CJK UNIFIED IDEOGRAPH-#24390, IRGKangXi=0681.141, RSKangXi=86.11
24391 CJK UNIFIED IDEOGRAPH-#24391, IRGKangXi=0681.141, RSKangXi=86.11
24392 CJK UNIFIED IDEOGRAPH-#24392, IRGKangXi=0681.141, RSKangXi=86.11
24393 CJK UNIFIED IDEOGRAPH-#24393, IRGKangXi=0681.141, RSKangXi=86.11
24394 CJK UNIFIED IDEOGRAPH-#24394, IRGKangXi=0681.141, RSKangXi=86.11
24395 CJK UNIFIED IDEOGRAPH-#24395, IRGKangXi=0681.141, RSKangXi=86.11
24396 CJK UNIFIED IDEOGRAPH-#24396, IRGKangXi=0681.141, RSKangXi=86.11
24397 CJK UNIFIED IDEOGRAPH-#24397, IRGKangXi=0681.141, RSKangXi=86.11
24398 CJK UNIFIED IDEOGRAPH-#24398, IRGKangXi=0681.141, RSKangXi=86.11
24399 CJK UNIFIED IDEOGRAPH-#24399, IRGKangXi=0681.141, RSKangXi=86.11
2439A CJK UNIFIED IDEOGRAPH-#2439A, IRGKangXi=0681.141, RSKangXi=86.11
2439B CJK UNIFIED IDEOGRAPH-#2439B, IRGKangXi=0681.141, RSKangXi=86.11
2439C CJK UNIFIED IDEOGRAPH-#2439C, IRGKangXi=0681.141, RSKangXi=86.11
2439D CJK UNIFIED IDEOGRAPH-#2439D, IRGKangXi=0681.160, RSKangXi=86.12
2439E CJK UNIFIED IDEOGRAPH-#2439E, IRGKangXi=0681.190, RSKangXi=86.12
2439F CJK UNIFIED IDEOGRAPH-#2439F, IRGKangXi=0682.050, RSKangXi=86.12
243A0 CJK UNIFIED IDEOGRAPH-#243A0, IRGKangXi=0682.060, RSKangXi=86.12
243A1 CJK UNIFIED IDEOGRAPH-#243A1, IRGKangXi=0682.090, RSKangXi=86.12
243A2 CJK UNIFIED IDEOGRAPH-#243A2, IRGKangXi=0682.110, RSKangXi=86.12
243A3 CJK UNIFIED IDEOGRAPH-#243A3, IRGKangXi=0682.170, RSKangXi=86.12
243A4 CJK UNIFIED IDEOGRAPH-#243A4, IRGKangXi=0682.200, RSKangXi=86.12
243A5 CJK UNIFIED IDEOGRAPH-#243A5, IRGKangXi=0682.230, RSKangXi=86.12
243A6 CJK UNIFIED IDEOGRAPH-#243A6, IRGKangXi=0683.040, RSKangXi=86.12
243A7 CJK UNIFIED IDEOGRAPH-#243A7, IRGKangXi=0683.070, RSKangXi=86.12
243A8 CJK UNIFIED IDEOGRAPH-#243A8, IRGKangXi=0683.100, RSKangXi=86.12
243A9 CJK UNIFIED IDEOGRAPH-#243A9, IRGKangXi=0683.110, RSKangXi=86.12
243AA CJK UNIFIED IDEOGRAPH-#243AA, IRGKangXi=0683.140, RSKangXi=86.12
243AB CJK UNIFIED IDEOGRAPH-#243AB, IRGKangXi=0683.150, RSKangXi=86.12
243AC CJK UNIFIED IDEOGRAPH-#243AC, IRGKangXi=0683.200, RSKangXi=86.12
243AD CJK UNIFIED IDEOGRAPH-#243AD, IRGKangXi=0683.210, RSKangXi=86.12
243AE CJK UNIFIED IDEOGRAPH-#243AE, IRGKangXi=0684.020, RSKangXi=86.12
243AF CJK UNIFIED IDEOGRAPH-#243AF, IRGKangXi=0684.040, RSKangXi=86.12
243B0 CJK UNIFIED IDEOGRAPH-#243B0, IRGKangXi=0684.050, RSKangXi=86.12
243B1 CJK UNIFIED IDEOGRAPH-#243B1, IRGKangXi=0684.070, RSKangXi=86.12, Def{to make chowder}
243B2 CJK UNIFIED IDEOGRAPH-#243B2, IRGKangXi=0684.100, RSKangXi=86.12
243B3 CJK UNIFIED IDEOGRAPH-#243B3, IRGKangXi=0684.110, RSKangXi=86.12
243B4 CJK UNIFIED IDEOGRAPH-#243B4, IRGKangXi=0684.120, RSKangXi=86.12
243B5 CJK UNIFIED IDEOGRAPH-#243B5, IRGKangXi=0684.130, RSKangXi=86.12
243B6 CJK UNIFIED IDEOGRAPH-#243B6, IRGKangXi=0684.140, RSKangXi=86.12
243B7 CJK UNIFIED IDEOGRAPH-#243B7, IRGKangXi=0684.150, RSKangXi=86.12
243B8 CJK UNIFIED IDEOGRAPH-#243B8, IRGKangXi=0684.160, RSKangXi=86.12
243B9 CJK UNIFIED IDEOGRAPH-#243B9, IRGKangXi=0684.161
243BA CJK UNIFIED IDEOGRAPH-#243BA, IRGKangXi=0684.161, RSKangXi=86.12
243BB CJK UNIFIED IDEOGRAPH-#243BB, IRGKangXi=0684.161, RSKangXi=86.12
243BC CJK UNIFIED IDEOGRAPH-#243BC, IRGKangXi=0684.161, RSKangXi=86.12
243BD CJK UNIFIED IDEOGRAPH-#243BD, IRGKangXi=0684.161, RSKangXi=86.12
243BE CJK UNIFIED IDEOGRAPH-#243BE, IRGKangXi=0684.161, RSKangXi=86.12
243BF CJK UNIFIED IDEOGRAPH-#243BF, IRGKangXi=0684.161, RSKangXi=86.12
243C0 CJK UNIFIED IDEOGRAPH-#243C0, IRGKangXi=0684.161, RSKangXi=86.12
243C1 CJK UNIFIED IDEOGRAPH-#243C1, IRGKangXi=0684.161, RSKangXi=86.12
243C2 CJK UNIFIED IDEOGRAPH-#243C2, IRGKangXi=0684.161, RSKangXi=86.12
243C3 CJK UNIFIED IDEOGRAPH-#243C3, IRGKangXi=0684.161, RSKangXi=86.12
243C4 CJK UNIFIED IDEOGRAPH-#243C4, IRGKangXi=0684.161, RSKangXi=86.12
243C5 CJK UNIFIED IDEOGRAPH-#243C5, IRGKangXi=0684.161, RSKangXi=86.12
243C6 CJK UNIFIED IDEOGRAPH-#243C6, IRGKangXi=0684.161, RSKangXi=86.12
243C7 CJK UNIFIED IDEOGRAPH-#243C7, IRGKangXi=0684.161, RSKangXi=86.12
243C8 CJK UNIFIED IDEOGRAPH-#243C8, IRGKangXi=0684.161, RSKangXi=86.12
243C9 CJK UNIFIED IDEOGRAPH-#243C9, IRGKangXi=0684.161, RSKangXi=86.12
243CA CJK UNIFIED IDEOGRAPH-#243CA, IRGKangXi=0684.161, RSKangXi=86.12
243CB CJK UNIFIED IDEOGRAPH-#243CB, IRGKangXi=0684.161, RSKangXi=86.12
243CC CJK UNIFIED IDEOGRAPH-#243CC, IRGKangXi=0684.161, RSKangXi=86.12
243CD CJK UNIFIED IDEOGRAPH-#243CD, IRGKangXi=0684.161, RSKangXi=86.12
243CE CJK UNIFIED IDEOGRAPH-#243CE, IRGKangXi=0684.161, RSKangXi=86.12
243CF CJK UNIFIED IDEOGRAPH-#243CF, IRGKangXi=0684.161, RSKangXi=86.12
243D0 CJK UNIFIED IDEOGRAPH-#243D0, IRGKangXi=0684.161, RSKangXi=86.12
243D1 CJK UNIFIED IDEOGRAPH-#243D1, IRGKangXi=0684.161, RSKangXi=86.12
243D2 CJK UNIFIED IDEOGRAPH-#243D2, IRGKangXi=0684.161, RSKangXi=86.12
243D3 CJK UNIFIED IDEOGRAPH-#243D3, IRGKangXi=0684.161, RSKangXi=86.12
243D4 CJK UNIFIED IDEOGRAPH-#243D4, IRGKangXi=0684.161, RSKangXi=86.12
243D5 CJK UNIFIED IDEOGRAPH-#243D5, IRGKangXi=0684.161, RSKangXi=86.12
243D6 CJK UNIFIED IDEOGRAPH-#243D6, IRGKangXi=0684.161, RSKangXi=86.12
243D7 CJK UNIFIED IDEOGRAPH-#243D7, IRGKangXi=0684.161, RSKangXi=86.12
243D8 CJK UNIFIED IDEOGRAPH-#243D8, IRGKangXi=0684.161, RSKangXi=86.12
243D9 CJK UNIFIED IDEOGRAPH-#243D9, IRGKangXi=0684.161, RSKangXi=86.12
243DA CJK UNIFIED IDEOGRAPH-#243DA, IRGKangXi=0684.161, RSKangXi=86.12
243DB CJK UNIFIED IDEOGRAPH-#243DB, IRGKangXi=0684.161, RSKangXi=86.12
243DC CJK UNIFIED IDEOGRAPH-#243DC, IRGKangXi=0684.161, RSKangXi=86.12
243DD CJK UNIFIED IDEOGRAPH-#243DD, IRGKangXi=0684.161, RSKangXi=86.12
243DE CJK UNIFIED IDEOGRAPH-#243DE, IRGKangXi=0684.161, RSKangXi=86.12
243DF CJK UNIFIED IDEOGRAPH-#243DF, IRGKangXi=0684.161, RSKangXi=86.12
243E0 CJK UNIFIED IDEOGRAPH-#243E0, IRGKangXi=0684.161, RSKangXi=37.13
243E1 CJK UNIFIED IDEOGRAPH-#243E1, IRGKangXi=0684.161, RSKangXi=86.12
243E2 CJK UNIFIED IDEOGRAPH-#243E2, IRGKangXi=0684.161, RSKangXi=86.12
243E3 CJK UNIFIED IDEOGRAPH-#243E3, IRGKangXi=0684.161, RSKangXi=86.12
243E4 CJK UNIFIED IDEOGRAPH-#243E4, IRGKangXi=0684.161, RSKangXi=86.12
243E5 CJK UNIFIED IDEOGRAPH-#243E5, IRGKangXi=0684.161, RSKangXi=86.12
243E6 CJK UNIFIED IDEOGRAPH-#243E6, IRGKangXi=0684.161, RSKangXi=86.12
243E7 CJK UNIFIED IDEOGRAPH-#243E7, IRGKangXi=0684.161, RSKangXi=86.12
243E8 CJK UNIFIED IDEOGRAPH-#243E8, IRGKangXi=0684.161, RSKangXi=86.12
243E9 CJK UNIFIED IDEOGRAPH-#243E9, IRGKangXi=0684.161, RSKangXi=86.12
243EA CJK UNIFIED IDEOGRAPH-#243EA, IRGKangXi=0684.161, RSKangXi=86.12
243EB CJK UNIFIED IDEOGRAPH-#243EB, IRGKangXi=0684.161, RSKangXi=86.12
243EC CJK UNIFIED IDEOGRAPH-#243EC, IRGKangXi=0684.161, RSKangXi=86.12
243ED CJK UNIFIED IDEOGRAPH-#243ED, IRGKangXi=0684.161, RSKangXi=86.12
243EE CJK UNIFIED IDEOGRAPH-#243EE, IRGKangXi=0684.161, RSKangXi=86.12
243EF CJK UNIFIED IDEOGRAPH-#243EF, IRGKangXi=0684.161, RSKangXi=86.12
243F0 CJK UNIFIED IDEOGRAPH-#243F0, IRGKangXi=0684.161, RSKangXi=86.12
243F1 CJK UNIFIED IDEOGRAPH-#243F1, IRGKangXi=0684.161, RSKangXi=86.12
243F2 CJK UNIFIED IDEOGRAPH-#243F2, IRGKangXi=0684.161, RSKangXi=86.12, Def{to set on fire}
243F3 CJK UNIFIED IDEOGRAPH-#243F3, IRGKangXi=0684.161, RSKangXi=86.12
243F4 CJK UNIFIED IDEOGRAPH-#243F4, IRGKangXi=0684.161, RSKangXi=86.12
243F5 CJK UNIFIED IDEOGRAPH-#243F5, IRGKangXi=0684.220, RSKangXi=86.13
243F6 CJK UNIFIED IDEOGRAPH-#243F6, IRGKangXi=0684.230, RSKangXi=86.13
243F7 CJK UNIFIED IDEOGRAPH-#243F7, IRGKangXi=0684.260, RSKangXi=86.13
243F8 CJK UNIFIED IDEOGRAPH-#243F8, IRGKangXi=0684.270, RSKangXi=86.13
243F9 CJK UNIFIED IDEOGRAPH-#243F9, IRGKangXi=0685.040, RSKangXi=86.13
243FA CJK UNIFIED IDEOGRAPH-#243FA, IRGKangXi=0685.100, RSKangXi=86.13
243FB CJK UNIFIED IDEOGRAPH-#243FB, IRGKangXi=0685.130, RSKangXi=86.13
243FC CJK UNIFIED IDEOGRAPH-#243FC, IRGKangXi=0685.150, RSKangXi=86.13
243FD CJK UNIFIED IDEOGRAPH-#243FD, IRGKangXi=0685.160, RSKangXi=86.13
243FE CJK UNIFIED IDEOGRAPH-#243FE, IRGKangXi=0685.170, RSKangXi=86.13
243FF CJK UNIFIED IDEOGRAPH-#243FF, IRGKangXi=0685.180, RSKangXi=86.13
24400 CJK UNIFIED IDEOGRAPH-#24400, IRGKangXi=0685.200, RSKangXi=86.13
24401 CJK UNIFIED IDEOGRAPH-#24401, IRGKangXi=0685.201, RSKangXi=86.13
24402 CJK UNIFIED IDEOGRAPH-#24402, IRGKangXi=0685.201, RSKangXi=86.13
24403 CJK UNIFIED IDEOGRAPH-#24403, IRGKangXi=0685.201, RSKangXi=86.13
24404 CJK UNIFIED IDEOGRAPH-#24404, IRGKangXi=0685.201, RSKangXi=86.13
24405 CJK UNIFIED IDEOGRAPH-#24405, IRGKangXi=0685.201, RSKangXi=86.13
24406 CJK UNIFIED IDEOGRAPH-#24406, IRGKangXi=0685.201, RSKangXi=86.13
24407 CJK UNIFIED IDEOGRAPH-#24407, IRGKangXi=0685.201, RSKangXi=86.13
24408 CJK UNIFIED IDEOGRAPH-#24408, IRGKangXi=0685.201, RSKangXi=86.13
24409 CJK UNIFIED IDEOGRAPH-#24409, IRGKangXi=0685.201, RSKangXi=86.13
2440A CJK UNIFIED IDEOGRAPH-#2440A, IRGKangXi=0685.201, RSKangXi=86.13
2440B CJK UNIFIED IDEOGRAPH-#2440B, IRGKangXi=0685.201, RSKangXi=86.13
2440C CJK UNIFIED IDEOGRAPH-#2440C, IRGKangXi=0685.201, RSKangXi=86.13
2440D CJK UNIFIED IDEOGRAPH-#2440D, IRGKangXi=0685.201, RSKangXi=86.13
2440E CJK UNIFIED IDEOGRAPH-#2440E, IRGKangXi=0685.201, RSKangXi=86.13
2440F CJK UNIFIED IDEOGRAPH-#2440F, IRGKangXi=0685.201, RSKangXi=86.13
24410 CJK UNIFIED IDEOGRAPH-#24410, IRGKangXi=0685.201, RSKangXi=86.13
24411 CJK UNIFIED IDEOGRAPH-#24411, IRGKangXi=0685.201, RSKangXi=86.13
24412 CJK UNIFIED IDEOGRAPH-#24412, IRGKangXi=0685.201, RSKangXi=86.13
24413 CJK UNIFIED IDEOGRAPH-#24413, IRGKangXi=0685.201, RSKangXi=86.13
24414 CJK UNIFIED IDEOGRAPH-#24414, IRGKangXi=0685.201, RSKangXi=86.13
24415 CJK UNIFIED IDEOGRAPH-#24415, IRGKangXi=0685.201, RSKangXi=86.13
24416 CJK UNIFIED IDEOGRAPH-#24416, IRGKangXi=0685.201, RSKangXi=86.13
24417 CJK UNIFIED IDEOGRAPH-#24417, IRGKangXi=0685.201, RSKangXi=86.13
24418 CJK UNIFIED IDEOGRAPH-#24418, IRGKangXi=0685.201, RSKangXi=86.13
24419 CJK UNIFIED IDEOGRAPH-#24419, IRGKangXi=0685.201, RSKangXi=86.13
2441A CJK UNIFIED IDEOGRAPH-#2441A, IRGKangXi=0685.201, RSKangXi=86.13
2441B CJK UNIFIED IDEOGRAPH-#2441B, IRGKangXi=0685.201, RSKangXi=86.13
2441C CJK UNIFIED IDEOGRAPH-#2441C, IRGKangXi=0685.201, RSKangXi=86.13
2441D CJK UNIFIED IDEOGRAPH-#2441D, IRGKangXi=0685.201, RSKangXi=86.13
2441E CJK UNIFIED IDEOGRAPH-#2441E, IRGKangXi=0685.201, RSKangXi=86.13
2441F CJK UNIFIED IDEOGRAPH-#2441F, IRGKangXi=0685.201, RSKangXi=86.13
24420 CJK UNIFIED IDEOGRAPH-#24420, IRGKangXi=0685.201, RSKangXi=86.13
24421 CJK UNIFIED IDEOGRAPH-#24421, IRGKangXi=0685.201, RSKangXi=86.13
24422 CJK UNIFIED IDEOGRAPH-#24422, IRGKangXi=0685.201, RSKangXi=86.13
24423 CJK UNIFIED IDEOGRAPH-#24423, IRGKangXi=0685.201, RSKangXi=86.13
24424 CJK UNIFIED IDEOGRAPH-#24424, IRGKangXi=0685.201, RSKangXi=86.14
24425 CJK UNIFIED IDEOGRAPH-#24425, IRGKangXi=0685.201, RSKangXi=86.14
24426 CJK UNIFIED IDEOGRAPH-#24426, IRGKangXi=0685.210, RSKangXi=86.14
24427 CJK UNIFIED IDEOGRAPH-#24427, IRGKangXi=0685.220, RSKangXi=86.14
24428 CJK UNIFIED IDEOGRAPH-#24428, IRGKangXi=0685.250, RSKangXi=86.14
24429 CJK UNIFIED IDEOGRAPH-#24429, IRGKangXi=0685.260, RSKangXi=86.14
2442A CJK UNIFIED IDEOGRAPH-#2442A, IRGKangXi=0685.280, RSKangXi=86.14
2442B CJK UNIFIED IDEOGRAPH-#2442B, IRGKangXi=0685.300, RSKangXi=86.14
2442C CJK UNIFIED IDEOGRAPH-#2442C, IRGKangXi=0685.320, RSKangXi=86.14
2442D CJK UNIFIED IDEOGRAPH-#2442D, IRGKangXi=0685.340, RSKangXi=86.14
2442E CJK UNIFIED IDEOGRAPH-#2442E, IRGKangXi=0686.030, RSKangXi=86.14
2442F CJK UNIFIED IDEOGRAPH-#2442F, IRGKangXi=0686.050, RSKangXi=86.14
24430 CJK UNIFIED IDEOGRAPH-#24430, IRGKangXi=0686.060, RSKangXi=86.14
24431 CJK UNIFIED IDEOGRAPH-#24431, IRGKangXi=0686.070, RSKangXi=86.14
24432 CJK UNIFIED IDEOGRAPH-#24432, IRGKangXi=0686.080, RSKangXi=86.14
24433 CJK UNIFIED IDEOGRAPH-#24433, IRGKangXi=0686.100, RSKangXi=86.14
24434 CJK UNIFIED IDEOGRAPH-#24434, IRGKangXi=0686.111, RSKangXi=86.14
24435 CJK UNIFIED IDEOGRAPH-#24435, IRGKangXi=0686.111, RSKangXi=86.14
24436 CJK UNIFIED IDEOGRAPH-#24436, IRGKangXi=0686.111, RSKangXi=86.14
24437 CJK UNIFIED IDEOGRAPH-#24437, IRGKangXi=0686.111, RSKangXi=86.14
24438 CJK UNIFIED IDEOGRAPH-#24438, IRGKangXi=0686.111, RSKangXi=86.14
24439 CJK UNIFIED IDEOGRAPH-#24439, IRGKangXi=0686.111, RSKangXi=86.14
2443A CJK UNIFIED IDEOGRAPH-#2443A, IRGKangXi=0686.111, RSKangXi=86.14
2443B CJK UNIFIED IDEOGRAPH-#2443B, IRGKangXi=0686.111, RSKangXi=86.14
2443C CJK UNIFIED IDEOGRAPH-#2443C, IRGKangXi=0686.111, RSKangXi=86.14
2443D CJK UNIFIED IDEOGRAPH-#2443D, IRGKangXi=0686.111, RSKangXi=86.14
2443E CJK UNIFIED IDEOGRAPH-#2443E, IRGKangXi=0686.111, RSKangXi=86.14
2443F CJK UNIFIED IDEOGRAPH-#2443F, IRGKangXi=0686.111, RSKangXi=86.14
24440 CJK UNIFIED IDEOGRAPH-#24440, IRGKangXi=0686.111, RSKangXi=86.14
24441 CJK UNIFIED IDEOGRAPH-#24441, IRGKangXi=0686.111, RSKangXi=86.14
24442 CJK UNIFIED IDEOGRAPH-#24442, IRGKangXi=0686.111, RSKangXi=86.14
24443 CJK UNIFIED IDEOGRAPH-#24443, IRGKangXi=0686.111, RSKangXi=130.14
24444 CJK UNIFIED IDEOGRAPH-#24444, IRGKangXi=0686.111, RSKangXi=86.14
24445 CJK UNIFIED IDEOGRAPH-#24445, IRGKangXi=0686.111, RSKangXi=86.14
24446 CJK UNIFIED IDEOGRAPH-#24446, IRGKangXi=0686.111, RSKangXi=86.14
24447 CJK UNIFIED IDEOGRAPH-#24447, IRGKangXi=0686.111, RSKangXi=86.14
24448 CJK UNIFIED IDEOGRAPH-#24448, IRGKangXi=0686.111, RSKangXi=86.14
24449 CJK UNIFIED IDEOGRAPH-#24449, IRGKangXi=0686.111, RSKangXi=86.14
2444A CJK UNIFIED IDEOGRAPH-#2444A, IRGKangXi=0686.111, RSKangXi=86.14
2444B CJK UNIFIED IDEOGRAPH-#2444B, IRGKangXi=0686.111, RSKangXi=86.14
2444C CJK UNIFIED IDEOGRAPH-#2444C, IRGKangXi=0686.111, RSKangXi=86.14
2444D CJK UNIFIED IDEOGRAPH-#2444D, IRGKangXi=0686.111, RSKangXi=86.14
2444E CJK UNIFIED IDEOGRAPH-#2444E, IRGKangXi=0686.111, RSKangXi=86.14
2444F CJK UNIFIED IDEOGRAPH-#2444F, IRGKangXi=0686.111, RSKangXi=86.14
24450 CJK UNIFIED IDEOGRAPH-#24450, IRGKangXi=0686.111, RSKangXi=86.14
24451 CJK UNIFIED IDEOGRAPH-#24451, IRGKangXi=0686.111, RSKangXi=86.14
24452 CJK UNIFIED IDEOGRAPH-#24452, IRGKangXi=0686.130, RSKangXi=86.15
24453 CJK UNIFIED IDEOGRAPH-#24453, IRGKangXi=0686.140, RSKangXi=86.15
24454 CJK UNIFIED IDEOGRAPH-#24454, IRGKangXi=0686.180, RSKangXi=86.15
24455 CJK UNIFIED IDEOGRAPH-#24455, IRGKangXi=0686.230, RSKangXi=86.15, Def{smoke, fog, vapor; smoke, cure}
24456 CJK UNIFIED IDEOGRAPH-#24456, IRGKangXi=0686.260, RSKangXi=86.15
24457 CJK UNIFIED IDEOGRAPH-#24457, IRGKangXi=0686.270, RSKangXi=86.15
24458 CJK UNIFIED IDEOGRAPH-#24458, IRGKangXi=0686.271, RSKangXi=86.15
24459 CJK UNIFIED IDEOGRAPH-#24459, IRGKangXi=0686.271, RSKangXi=86.15
2445A CJK UNIFIED IDEOGRAPH-#2445A, IRGKangXi=0686.271, RSKangXi=86.15
2445B CJK UNIFIED IDEOGRAPH-#2445B, IRGKangXi=0686.271, RSKangXi=86.15
2445C CJK UNIFIED IDEOGRAPH-#2445C, IRGKangXi=0686.271, RSKangXi=86.15
2445D CJK UNIFIED IDEOGRAPH-#2445D, IRGKangXi=0686.271, RSKangXi=86.15
2445E CJK UNIFIED IDEOGRAPH-#2445E, IRGKangXi=0686.271, RSKangXi=86.15
2445F CJK UNIFIED IDEOGRAPH-#2445F, IRGKangXi=0686.271, RSKangXi=86.15
24460 CJK UNIFIED IDEOGRAPH-#24460, IRGKangXi=0686.271, RSKangXi=86.15
24461 CJK UNIFIED IDEOGRAPH-#24461, IRGKangXi=0686.271, RSKangXi=86.15
24462 CJK UNIFIED IDEOGRAPH-#24462, IRGKangXi=0686.271, RSKangXi=86.15
24463 CJK UNIFIED IDEOGRAPH-#24463, IRGKangXi=0686.271, RSKangXi=86.15
24464 CJK UNIFIED IDEOGRAPH-#24464, IRGKangXi=0686.271, RSKangXi=86.15
24465 CJK UNIFIED IDEOGRAPH-#24465, IRGKangXi=0686.271, RSKangXi=86.15
24466 CJK UNIFIED IDEOGRAPH-#24466, IRGKangXi=0686.271, RSKangXi=86.15
24467 CJK UNIFIED IDEOGRAPH-#24467, IRGKangXi=0686.271, RSKangXi=86.15
24468 CJK UNIFIED IDEOGRAPH-#24468, IRGKangXi=0686.271, RSKangXi=86.15
24469 CJK UNIFIED IDEOGRAPH-#24469, IRGKangXi=0686.271, RSKangXi=86.15
2446A CJK UNIFIED IDEOGRAPH-#2446A, IRGKangXi=0686.271, RSKangXi=86.15
2446B CJK UNIFIED IDEOGRAPH-#2446B, IRGKangXi=0686.271, RSKangXi=86.15
2446C CJK UNIFIED IDEOGRAPH-#2446C, IRGKangXi=0686.271, RSKangXi=86.15
2446D CJK UNIFIED IDEOGRAPH-#2446D, IRGKangXi=0686.271, RSKangXi=86.15
2446E CJK UNIFIED IDEOGRAPH-#2446E, IRGKangXi=0686.271, RSKangXi=86.15
2446F CJK UNIFIED IDEOGRAPH-#2446F, IRGKangXi=0686.271, RSKangXi=86.15
24470 CJK UNIFIED IDEOGRAPH-#24470, IRGKangXi=0686.271, RSKangXi=86.15
24471 CJK UNIFIED IDEOGRAPH-#24471, IRGKangXi=0686.271, RSKangXi=86.15
24472 CJK UNIFIED IDEOGRAPH-#24472, IRGKangXi=0686.271, RSKangXi=86.15
24473 CJK UNIFIED IDEOGRAPH-#24473, IRGKangXi=0686.280, RSKangXi=86.16
24474 CJK UNIFIED IDEOGRAPH-#24474, IRGKangXi=0686.290, RSKangXi=86.16
24475 CJK UNIFIED IDEOGRAPH-#24475, IRGKangXi=0686.320, RSKangXi=86.16
24476 CJK UNIFIED IDEOGRAPH-#24476, IRGKangXi=0686.330, RSKangXi=86.16
24477 CJK UNIFIED IDEOGRAPH-#24477, IRGKangXi=0686.350, RSKangXi=86.16
24478 CJK UNIFIED IDEOGRAPH-#24478, IRGKangXi=0686.360, RSKangXi=86.16
24479 CJK UNIFIED IDEOGRAPH-#24479, IRGKangXi=0686.370, RSKangXi=86.16
2447A CJK UNIFIED IDEOGRAPH-#2447A, IRGKangXi=0687.060, RSKangXi=86.16
2447B CJK UNIFIED IDEOGRAPH-#2447B, IRGKangXi=0687.080, RSKangXi=86.16
2447C CJK UNIFIED IDEOGRAPH-#2447C, IRGKangXi=0687.110, RSKangXi=86.16
2447D CJK UNIFIED IDEOGRAPH-#2447D, IRGKangXi=0687.120, RSKangXi=86.16
2447E CJK UNIFIED IDEOGRAPH-#2447E, IRGKangXi=0687.130, RSKangXi=86.16
2447F CJK UNIFIED IDEOGRAPH-#2447F, IRGKangXi=0687.140, RSKangXi=86.16
24480 CJK UNIFIED IDEOGRAPH-#24480, IRGKangXi=0687.150, RSKangXi=86.16
24481 CJK UNIFIED IDEOGRAPH-#24481, IRGKangXi=0687.160, RSKangXi=86.16
24482 CJK UNIFIED IDEOGRAPH-#24482, IRGKangXi=0687.170, RSKangXi=86.16
24483 CJK UNIFIED IDEOGRAPH-#24483, IRGKangXi=0687.171, RSKangXi=86.16
24484 CJK UNIFIED IDEOGRAPH-#24484, IRGKangXi=0687.171, RSKangXi=86.16
24485 CJK UNIFIED IDEOGRAPH-#24485, IRGKangXi=0687.171, RSKangXi=86.16
24486 CJK UNIFIED IDEOGRAPH-#24486, IRGKangXi=0687.171, RSKangXi=86.16
24487 CJK UNIFIED IDEOGRAPH-#24487, IRGKangXi=0687.171, RSKangXi=86.16
24488 CJK UNIFIED IDEOGRAPH-#24488, IRGKangXi=0687.171, RSKangXi=86.16
24489 CJK UNIFIED IDEOGRAPH-#24489, IRGKangXi=0687.171, RSKangXi=86.16
2448A CJK UNIFIED IDEOGRAPH-#2448A, IRGKangXi=0687.171, RSKangXi=86.16
2448B CJK UNIFIED IDEOGRAPH-#2448B, IRGKangXi=0687.171, RSKangXi=86.16
2448C CJK UNIFIED IDEOGRAPH-#2448C, IRGKangXi=0687.171, RSKangXi=86.16
2448D CJK UNIFIED IDEOGRAPH-#2448D, IRGKangXi=0687.171, RSKangXi=86.16
2448E CJK UNIFIED IDEOGRAPH-#2448E, IRGKangXi=0687.171, RSKangXi=86.16
2448F CJK UNIFIED IDEOGRAPH-#2448F, IRGKangXi=0687.171, RSKangXi=86.16
24490 CJK UNIFIED IDEOGRAPH-#24490, IRGKangXi=0687.171, RSKangXi=86.16
24491 CJK UNIFIED IDEOGRAPH-#24491, IRGKangXi=0687.171, RSKangXi=86.16
24492 CJK UNIFIED IDEOGRAPH-#24492, IRGKangXi=0687.171, RSKangXi=86.16
24493 CJK UNIFIED IDEOGRAPH-#24493, IRGKangXi=0687.171, RSKangXi=86.16
24494 CJK UNIFIED IDEOGRAPH-#24494, IRGKangXi=0687.171, RSKangXi=86.16
24495 CJK UNIFIED IDEOGRAPH-#24495, IRGKangXi=0687.171, RSKangXi=86.16
24496 CJK UNIFIED IDEOGRAPH-#24496, IRGKangXi=0687.171, RSKangXi=86.16
24497 CJK UNIFIED IDEOGRAPH-#24497, IRGKangXi=0687.171, RSKangXi=86.16
24498 CJK UNIFIED IDEOGRAPH-#24498, IRGKangXi=0687.171, RSKangXi=86.16
24499 CJK UNIFIED IDEOGRAPH-#24499, IRGKangXi=0687.171, RSKangXi=86.16
2449A CJK UNIFIED IDEOGRAPH-#2449A, IRGKangXi=0687.171, RSKangXi=86.16
2449B CJK UNIFIED IDEOGRAPH-#2449B, IRGKangXi=0687.171, RSKangXi=86.16
2449C CJK UNIFIED IDEOGRAPH-#2449C, IRGKangXi=0687.171, RSKangXi=86.16
2449D CJK UNIFIED IDEOGRAPH-#2449D, IRGKangXi=0687.171, RSKangXi=86.16
2449E CJK UNIFIED IDEOGRAPH-#2449E, IRGKangXi=0687.171, RSKangXi=86.16
2449F CJK UNIFIED IDEOGRAPH-#2449F, IRGKangXi=0687.171, RSKangXi=86.16
244A0 CJK UNIFIED IDEOGRAPH-#244A0, IRGKangXi=0687.171, RSKangXi=86.16
244A1 CJK UNIFIED IDEOGRAPH-#244A1, IRGKangXi=0687.180, RSKangXi=86.17
244A2 CJK UNIFIED IDEOGRAPH-#244A2, IRGKangXi=0687.200, RSKangXi=86.17
244A3 CJK UNIFIED IDEOGRAPH-#244A3, IRGKangXi=0687.210, RSKangXi=86.17
244A4 CJK UNIFIED IDEOGRAPH-#244A4, IRGKangXi=0687.230, RSKangXi=86.17
244A5 CJK UNIFIED IDEOGRAPH-#244A5, IRGKangXi=0687.260, RSKangXi=86.17
244A6 CJK UNIFIED IDEOGRAPH-#244A6, IRGKangXi=0687.270, RSKangXi=86.17
244A7 CJK UNIFIED IDEOGRAPH-#244A7, IRGKangXi=0687.280, RSKangXi=86.17
244A8 CJK UNIFIED IDEOGRAPH-#244A8, IRGKangXi=0687.281, RSKangXi=86.16
244A9 CJK UNIFIED IDEOGRAPH-#244A9, IRGKangXi=0687.281, RSKangXi=86.18
244AA CJK UNIFIED IDEOGRAPH-#244AA, IRGKangXi=0687.281, RSKangXi=86.17
244AB CJK UNIFIED IDEOGRAPH-#244AB, IRGKangXi=0687.281, RSKangXi=86.17
244AC CJK UNIFIED IDEOGRAPH-#244AC, IRGKangXi=0687.281, RSKangXi=86.17
244AD CJK UNIFIED IDEOGRAPH-#244AD, IRGKangXi=0687.281, RSKangXi=86.17
244AE CJK UNIFIED IDEOGRAPH-#244AE, IRGKangXi=0687.281, RSKangXi=86.17
244AF CJK UNIFIED IDEOGRAPH-#244AF, IRGKangXi=0687.281, RSKangXi=86.17
244B0 CJK UNIFIED IDEOGRAPH-#244B0, IRGKangXi=0687.281, RSKangXi=86.17
244B1 CJK UNIFIED IDEOGRAPH-#244B1, IRGKangXi=0687.281, RSKangXi=86.17
244B2 CJK UNIFIED IDEOGRAPH-#244B2, IRGKangXi=0687.281, RSKangXi=86.17
244B3 CJK UNIFIED IDEOGRAPH-#244B3, IRGKangXi=0687.281, RSKangXi=86.17
244B4 CJK UNIFIED IDEOGRAPH-#244B4, IRGKangXi=0687.281, RSKangXi=86.17
244B5 CJK UNIFIED IDEOGRAPH-#244B5, IRGKangXi=0687.281, RSKangXi=86.17
244B6 CJK UNIFIED IDEOGRAPH-#244B6, IRGKangXi=0687.281, RSKangXi=86.17
244B7 CJK UNIFIED IDEOGRAPH-#244B7, IRGKangXi=0687.281, RSKangXi=86.17
244B8 CJK UNIFIED IDEOGRAPH-#244B8, IRGKangXi=0687.281, RSKangXi=86.17
244B9 CJK UNIFIED IDEOGRAPH-#244B9, IRGKangXi=0687.281, RSKangXi=86.17
244BA CJK UNIFIED IDEOGRAPH-#244BA, IRGKangXi=0687.310, RSKangXi=86.18
244BB CJK UNIFIED IDEOGRAPH-#244BB, IRGKangXi=0687.320, RSKangXi=86.18
244BC CJK UNIFIED IDEOGRAPH-#244BC, IRGKangXi=0687.350, RSKangXi=86.18
244BD CJK UNIFIED IDEOGRAPH-#244BD, IRGKangXi=0688.010, RSKangXi=86.18
244BE CJK UNIFIED IDEOGRAPH-#244BE, IRGKangXi=0688.020, RSKangXi=86.18
244BF CJK UNIFIED IDEOGRAPH-#244BF, IRGKangXi=0688.021, RSKangXi=86.18
244C0 CJK UNIFIED IDEOGRAPH-#244C0, IRGKangXi=0688.021, RSKangXi=86.18
244C1 CJK UNIFIED IDEOGRAPH-#244C1, IRGKangXi=0688.021, RSKangXi=86.18
244C2 CJK UNIFIED IDEOGRAPH-#244C2, IRGKangXi=0688.021, RSKangXi=86.18
244C3 CJK UNIFIED IDEOGRAPH-#244C3, IRGKangXi=0688.021, RSKangXi=86.18
244C4 CJK UNIFIED IDEOGRAPH-#244C4, IRGKangXi=0688.021, RSKangXi=86.18
244C5 CJK UNIFIED IDEOGRAPH-#244C5, IRGKangXi=0688.021, RSKangXi=86.18
244C6 CJK UNIFIED IDEOGRAPH-#244C6, IRGKangXi=0688.021, RSKangXi=86.18
244C7 CJK UNIFIED IDEOGRAPH-#244C7, IRGKangXi=0688.021, RSKangXi=86.18
244C8 CJK UNIFIED IDEOGRAPH-#244C8, IRGKangXi=0688.040, RSKangXi=86.19
244C9 CJK UNIFIED IDEOGRAPH-#244C9, IRGKangXi=0688.050, RSKangXi=86.19
244CA CJK UNIFIED IDEOGRAPH-#244CA, IRGKangXi=0688.090, RSKangXi=86.19
244CB CJK UNIFIED IDEOGRAPH-#244CB, IRGKangXi=0688.091, RSKangXi=86.19
244CC CJK UNIFIED IDEOGRAPH-#244CC, IRGKangXi=0688.091, RSKangXi=86.19
244CD CJK UNIFIED IDEOGRAPH-#244CD, IRGKangXi=0688.091, RSKangXi=86.19
244CE CJK UNIFIED IDEOGRAPH-#244CE, IRGKangXi=0688.091, RSKangXi=86.19
244CF CJK UNIFIED IDEOGRAPH-#244CF, IRGKangXi=0688.091, RSKangXi=130.19
244D0 CJK UNIFIED IDEOGRAPH-#244D0, IRGKangXi=0688.091, RSKangXi=86.19
244D1 CJK UNIFIED IDEOGRAPH-#244D1, IRGKangXi=0688.091, RSKangXi=86.19
244D2 CJK UNIFIED IDEOGRAPH-#244D2, IRGKangXi=0688.091, RSKangXi=86.19
244D3 CJK UNIFIED IDEOGRAPH-#244D3, IRGKangXi=0688.091, RSKangXi=86.19, Def{smoky or burning smell}
244D4 CJK UNIFIED IDEOGRAPH-#244D4, IRGKangXi=0688.091, RSKangXi=86.19
244D5 CJK UNIFIED IDEOGRAPH-#244D5, IRGKangXi=0688.091, RSKangXi=86.19
244D6 CJK UNIFIED IDEOGRAPH-#244D6, IRGKangXi=0688.091, RSKangXi=86.19
244D7 CJK UNIFIED IDEOGRAPH-#244D7, IRGKangXi=0688.110, RSKangXi=86.20
244D8 CJK UNIFIED IDEOGRAPH-#244D8, IRGKangXi=0688.111, RSKangXi=86.20
244D9 CJK UNIFIED IDEOGRAPH-#244D9, IRGKangXi=0688.111, RSKangXi=86.20
244DA CJK UNIFIED IDEOGRAPH-#244DA, IRGKangXi=0688.111, RSKangXi=86.20
244DB CJK UNIFIED IDEOGRAPH-#244DB, IRGKangXi=0688.111, RSKangXi=86.20
244DC CJK UNIFIED IDEOGRAPH-#244DC, IRGKangXi=0688.130, RSKangXi=86.21
244DD CJK UNIFIED IDEOGRAPH-#244DD, IRGKangXi=0688.150, RSKangXi=86.21
244DE CJK UNIFIED IDEOGRAPH-#244DE, IRGKangXi=0688.151, RSKangXi=86.21
244DF CJK UNIFIED IDEOGRAPH-#244DF, IRGKangXi=0688.151, RSKangXi=134.18
244E0 CJK UNIFIED IDEOGRAPH-#244E0, IRGKangXi=0688.151, RSKangXi=86.21
244E1 CJK UNIFIED IDEOGRAPH-#244E1, IRGKangXi=0688.151, RSKangXi=86.21
244E2 CJK UNIFIED IDEOGRAPH-#244E2, IRGKangXi=0688.151, RSKangXi=86.21
244E3 CJK UNIFIED IDEOGRAPH-#244E3, IRGKangXi=0688.161, RSKangXi=86.21
244E4 CJK UNIFIED IDEOGRAPH-#244E4, IRGKangXi=0688.161, RSKangXi=86.22
244E5 CJK UNIFIED IDEOGRAPH-#244E5, IRGKangXi=0688.161, RSKangXi=86.22
244E6 CJK UNIFIED IDEOGRAPH-#244E6, IRGKangXi=0688.170, RSKangXi=86.23
244E7 CJK UNIFIED IDEOGRAPH-#244E7, IRGKangXi=0688.171, RSKangXi=86.23
244E8 CJK UNIFIED IDEOGRAPH-#244E8, IRGKangXi=0688.171, RSKangXi=86.23
244E9 CJK UNIFIED IDEOGRAPH-#244E9, IRGKangXi=0688.171, RSKangXi=86.23
244EA CJK UNIFIED IDEOGRAPH-#244EA, IRGKangXi=0688.190, RSKangXi=86.24
244EB CJK UNIFIED IDEOGRAPH-#244EB, IRGKangXi=0688.200, RSKangXi=86.25
244EC CJK UNIFIED IDEOGRAPH-#244EC, IRGKangXi=0688.201, RSKangXi=86.24
244ED CJK UNIFIED IDEOGRAPH-#244ED, IRGKangXi=0688.230, RSKangXi=86.26
244EE CJK UNIFIED IDEOGRAPH-#244EE, IRGKangXi=0688.250, RSKangXi=86.29
244EF CJK UNIFIED IDEOGRAPH-#244EF, IRGKangXi=0688.280, RSKangXi=87.0
244F0 CJK UNIFIED IDEOGRAPH-#244F0, IRGKangXi=0688.281, RSKangXi=87.0
244F1 CJK UNIFIED IDEOGRAPH-#244F1, IRGKangXi=0688.281, RSKangXi=87.1
244F2 CJK UNIFIED IDEOGRAPH-#244F2, IRGKangXi=0688.290, RSKangXi=87.3
244F3 CJK UNIFIED IDEOGRAPH-#244F3, IRGKangXi=0688.300, RSKangXi=87.3
244F4 CJK UNIFIED IDEOGRAPH-#244F4, IRGKangXi=0688.301, RSKangXi=87.3
244F5 CJK UNIFIED IDEOGRAPH-#244F5, IRGKangXi=0688.301, RSKangXi=87.3
244F6 CJK UNIFIED IDEOGRAPH-#244F6, IRGKangXi=0688.310, RSKangXi=87.4
244F7 CJK UNIFIED IDEOGRAPH-#244F7, IRGKangXi=0688.370, RSKangXi=87.4
244F8 CJK UNIFIED IDEOGRAPH-#244F8, IRGKangXi=0688.380, RSKangXi=87.4
244F9 CJK UNIFIED IDEOGRAPH-#244F9, IRGKangXi=0688.381, RSKangXi=87.4
244FA CJK UNIFIED IDEOGRAPH-#244FA, IRGKangXi=0688.381, RSKangXi=87.4
244FB CJK UNIFIED IDEOGRAPH-#244FB, IRGKangXi=0688.381, RSKangXi=87.4
244FC CJK UNIFIED IDEOGRAPH-#244FC, IRGKangXi=0688.381, RSKangXi=87.4
244FD CJK UNIFIED IDEOGRAPH-#244FD, IRGKangXi=0688.390, RSKangXi=87.5
244FE CJK UNIFIED IDEOGRAPH-#244FE, IRGKangXi=0688.400, RSKangXi=87.5
244FF CJK UNIFIED IDEOGRAPH-#244FF, IRGKangXi=0689.010, RSKangXi=87.5
24500 CJK UNIFIED IDEOGRAPH-#24500, IRGKangXi=0689.060, RSKangXi=87.5
24501 CJK UNIFIED IDEOGRAPH-#24501, IRGKangXi=0689.070, RSKangXi=87.5
24502 CJK UNIFIED IDEOGRAPH-#24502, IRGKangXi=0689.071, RSKangXi=87.5
24503 CJK UNIFIED IDEOGRAPH-#24503, IRGKangXi=0689.071, RSKangXi=87.5
24504 CJK UNIFIED IDEOGRAPH-#24504, IRGKangXi=0689.071, RSKangXi=87.5
24505 CJK UNIFIED IDEOGRAPH-#24505, IRGKangXi=0689.071, RSKangXi=87.5
24506 CJK UNIFIED IDEOGRAPH-#24506, IRGKangXi=0689.071, RSKangXi=87.5
24507 CJK UNIFIED IDEOGRAPH-#24507, IRGKangXi=0689.071, RSKangXi=87.5
24508 CJK UNIFIED IDEOGRAPH-#24508, IRGKangXi=0689.071, RSKangXi=87.5
24509 CJK UNIFIED IDEOGRAPH-#24509, IRGKangXi=0689.071, RSKangXi=87.5
2450A CJK UNIFIED IDEOGRAPH-#2450A, IRGKangXi=0689.071, RSKangXi=87.5
2450B CJK UNIFIED IDEOGRAPH-#2450B, IRGKangXi=0689.071, RSKangXi=87.5
2450C CJK UNIFIED IDEOGRAPH-#2450C, IRGKangXi=0689.080, RSKangXi=87.6
2450D CJK UNIFIED IDEOGRAPH-#2450D, IRGKangXi=0689.090, RSKangXi=87.6
2450E CJK UNIFIED IDEOGRAPH-#2450E, IRGKangXi=0689.091, RSKangXi=87.6
2450F CJK UNIFIED IDEOGRAPH-#2450F, IRGKangXi=0689.091, RSKangXi=87.6
24510 CJK UNIFIED IDEOGRAPH-#24510, IRGKangXi=0689.100, RSKangXi=87.7
24511 CJK UNIFIED IDEOGRAPH-#24511, IRGKangXi=0689.110, RSKangXi=87.7
24512 CJK UNIFIED IDEOGRAPH-#24512, IRGKangXi=0689.120, RSKangXi=87.7
24513 CJK UNIFIED IDEOGRAPH-#24513, IRGKangXi=0689.121, RSKangXi=87.7
24514 CJK UNIFIED IDEOGRAPH-#24514, IRGKangXi=0689.160, RSKangXi=87.8, Def{to govern}
24515 CJK UNIFIED IDEOGRAPH-#24515, IRGKangXi=0689.190, RSKangXi=87.8
24516 CJK UNIFIED IDEOGRAPH-#24516, IRGKangXi=0689.191, RSKangXi=87.8
24517 CJK UNIFIED IDEOGRAPH-#24517, IRGKangXi=0689.191, RSKangXi=31.9
24518 CJK UNIFIED IDEOGRAPH-#24518, IRGKangXi=0689.191, RSKangXi=87.8
24519 CJK UNIFIED IDEOGRAPH-#24519, IRGKangXi=0689.191, RSKangXi=87.8
2451A CJK UNIFIED IDEOGRAPH-#2451A, IRGKangXi=0689.191, RSKangXi=87.8
2451B CJK UNIFIED IDEOGRAPH-#2451B, IRGKangXi=0689.191, RSKangXi=87.8
2451C CJK UNIFIED IDEOGRAPH-#2451C, IRGKangXi=0689.191, RSKangXi=87.9
2451D CJK UNIFIED IDEOGRAPH-#2451D, IRGKangXi=0689.191, RSKangXi=87.9
2451E CJK UNIFIED IDEOGRAPH-#2451E, IRGKangXi=0689.191, RSKangXi=87.9
2451F CJK UNIFIED IDEOGRAPH-#2451F, IRGKangXi=0689.191, RSKangXi=87.9
24520 CJK UNIFIED IDEOGRAPH-#24520, IRGKangXi=0689.191, RSKangXi=87.9
24521 CJK UNIFIED IDEOGRAPH-#24521, IRGKangXi=0689.191, RSKangXi=87.9
24522 CJK UNIFIED IDEOGRAPH-#24522, IRGKangXi=0689.200, RSKangXi=87.10
24523 CJK UNIFIED IDEOGRAPH-#24523, IRGKangXi=0689.210, RSKangXi=87.10
24524 CJK UNIFIED IDEOGRAPH-#24524, IRGKangXi=0689.220, RSKangXi=87.10
24525 CJK UNIFIED IDEOGRAPH-#24525, IRGKangXi=0689.221, RSKangXi=87.10
24526 CJK UNIFIED IDEOGRAPH-#24526, IRGKangXi=0689.221, RSKangXi=87.10
24527 CJK UNIFIED IDEOGRAPH-#24527, IRGKangXi=0689.230, RSKangXi=87.11
24528 CJK UNIFIED IDEOGRAPH-#24528, IRGKangXi=0689.240, RSKangXi=87.11
24529 CJK UNIFIED IDEOGRAPH-#24529, IRGKangXi=0689.250, RSKangXi=87.11
2452A CJK UNIFIED IDEOGRAPH-#2452A, IRGKangXi=0689.260, RSKangXi=87.11
2452B CJK UNIFIED IDEOGRAPH-#2452B, IRGKangXi=0689.261, RSKangXi=87.11
2452C CJK UNIFIED IDEOGRAPH-#2452C, IRGKangXi=0689.261, RSKangXi=87.11
2452D CJK UNIFIED IDEOGRAPH-#2452D, IRGKangXi=0689.261, RSKangXi=87.11
2452E CJK UNIFIED IDEOGRAPH-#2452E, IRGKangXi=0689.270, RSKangXi=87.12
2452F CJK UNIFIED IDEOGRAPH-#2452F, IRGKangXi=0689.271, RSKangXi=87.12
24530 CJK UNIFIED IDEOGRAPH-#24530, IRGKangXi=0689.271, RSKangXi=87.12
24531 CJK UNIFIED IDEOGRAPH-#24531, IRGKangXi=0689.271, RSKangXi=87.12
24532 CJK UNIFIED IDEOGRAPH-#24532, IRGKangXi=0689.280, RSKangXi=87.13
24533 CJK UNIFIED IDEOGRAPH-#24533, IRGKangXi=0689.281, RSKangXi=87.13
24534 CJK UNIFIED IDEOGRAPH-#24534, IRGKangXi=0689.281, RSKangXi=87.13
24535 CJK UNIFIED IDEOGRAPH-#24535, IRGKangXi=0689.281, RSKangXi=87.13
24536 CJK UNIFIED IDEOGRAPH-#24536, IRGKangXi=0689.281, RSKangXi=87.13
24537 CJK UNIFIED IDEOGRAPH-#24537, IRGKangXi=0689.281, RSKangXi=87.13
24538 CJK UNIFIED IDEOGRAPH-#24538, IRGKangXi=0689.281, RSKangXi=87.13
24539 CJK UNIFIED IDEOGRAPH-#24539, IRGKangXi=0689.340, RSKangXi=87.14
2453A CJK UNIFIED IDEOGRAPH-#2453A, IRGKangXi=0689.341, RSKangXi=87.15
2453B CJK UNIFIED IDEOGRAPH-#2453B, IRGKangXi=0689.341, RSKangXi=87.14
2453C CJK UNIFIED IDEOGRAPH-#2453C, IRGKangXi=0689.341, RSKangXi=87.13
2453D CJK UNIFIED IDEOGRAPH-#2453D, IRGKangXi=0689.341, RSKangXi=87.14
2453E CJK UNIFIED IDEOGRAPH-#2453E, IRGKangXi=0689.341, RSKangXi=87.14
2453F CJK UNIFIED IDEOGRAPH-#2453F, IRGKangXi=0689.341, RSKangXi=87.15
24540 CJK UNIFIED IDEOGRAPH-#24540, IRGKangXi=0689.341, RSKangXi=87.15
24541 CJK UNIFIED IDEOGRAPH-#24541, IRGKangXi=0689.341, RSKangXi=121.13
24542 CJK UNIFIED IDEOGRAPH-#24542, IRGKangXi=0689.341, RSKangXi=87.16
24543 CJK UNIFIED IDEOGRAPH-#24543, IRGKangXi=0689.341, RSKangXi=87.16
24544 CJK UNIFIED IDEOGRAPH-#24544, IRGKangXi=0689.341, RSKangXi=87.16
24545 CJK UNIFIED IDEOGRAPH-#24545, IRGKangXi=0689.341, RSKangXi=87.16
24546 CJK UNIFIED IDEOGRAPH-#24546, IRGKangXi=0689.341, RSKangXi=87.16
24547 CJK UNIFIED IDEOGRAPH-#24547, IRGKangXi=0689.341, RSKangXi=87.17
24548 CJK UNIFIED IDEOGRAPH-#24548, IRGKangXi=0689.341, RSKangXi=87.19
24549 CJK UNIFIED IDEOGRAPH-#24549, IRGKangXi=0689.341, RSKangXi=87.19
2454A CJK UNIFIED IDEOGRAPH-#2454A, IRGKangXi=0689.341, RSKangXi=87.19
2454B CJK UNIFIED IDEOGRAPH-#2454B, IRGKangXi=0689.341, RSKangXi=87.20
2454C CJK UNIFIED IDEOGRAPH-#2454C, IRGKangXi=0689.341, RSKangXi=87.21
2454D CJK UNIFIED IDEOGRAPH-#2454D, IRGKangXi=0689.341, RSKangXi=87.21
2454E CJK UNIFIED IDEOGRAPH-#2454E, IRGKangXi=0690.011, RSKangXi=88.3
2454F CJK UNIFIED IDEOGRAPH-#2454F, IRGKangXi=0690.011, RSKangXi=88.3
24550 CJK UNIFIED IDEOGRAPH-#24550, IRGKangXi=0690.020, RSKangXi=88.4
24551 CJK UNIFIED IDEOGRAPH-#24551, IRGKangXi=0690.031, RSKangXi=88.4
24552 CJK UNIFIED IDEOGRAPH-#24552, IRGKangXi=0690.031, RSKangXi=88.5
24553 CJK UNIFIED IDEOGRAPH-#24553, IRGKangXi=0690.060, RSKangXi=88.6
24554 CJK UNIFIED IDEOGRAPH-#24554, IRGKangXi=0690.061, RSKangXi=88.6
24555 CJK UNIFIED IDEOGRAPH-#24555, IRGKangXi=0690.070, RSKangXi=88.7
24556 CJK UNIFIED IDEOGRAPH-#24556, IRGKangXi=0690.081, RSKangXi=88.8
24557 CJK UNIFIED IDEOGRAPH-#24557, IRGKangXi=0690.081, RSKangXi=88.8
24558 CJK UNIFIED IDEOGRAPH-#24558, IRGKangXi=0690.090, RSKangXi=88.9
24559 CJK UNIFIED IDEOGRAPH-#24559, IRGKangXi=0690.121, RSKangXi=88.10
2455A CJK UNIFIED IDEOGRAPH-#2455A, IRGKangXi=0690.121, RSKangXi=88.10
2455B CJK UNIFIED IDEOGRAPH-#2455B, IRGKangXi=0690.121, RSKangXi=88.12
2455C CJK UNIFIED IDEOGRAPH-#2455C, IRGKangXi=0690.131, RSKangXi=89.1
2455D CJK UNIFIED IDEOGRAPH-#2455D, IRGKangXi=0690.150, RSKangXi=89.4
2455E CJK UNIFIED IDEOGRAPH-#2455E, IRGKangXi=0690.170, RSKangXi=89.5
2455F CJK UNIFIED IDEOGRAPH-#2455F, IRGKangXi=0690.180, RSKangXi=89.5
24560 CJK UNIFIED IDEOGRAPH-#24560, IRGKangXi=0690.200, RSKangXi=89.6
24561 CJK UNIFIED IDEOGRAPH-#24561, IRGKangXi=0690.201, RSKangXi=89.6
24562 CJK UNIFIED IDEOGRAPH-#24562, IRGKangXi=0690.210, RSKangXi=89.7
24563 CJK UNIFIED IDEOGRAPH-#24563, IRGKangXi=0691.010, RSKangXi=89.8
24564 CJK UNIFIED IDEOGRAPH-#24564, IRGKangXi=0691.020, RSKangXi=89.9
24565 CJK UNIFIED IDEOGRAPH-#24565, IRGKangXi=0691.030, RSKangXi=89.9
24566 CJK UNIFIED IDEOGRAPH-#24566, IRGKangXi=0691.050, RSKangXi=89.11
24567 CJK UNIFIED IDEOGRAPH-#24567, IRGKangXi=0691.070, RSKangXi=89.11
24568 CJK UNIFIED IDEOGRAPH-#24568, IRGKangXi=0691.080, RSKangXi=89.11
24569 CJK UNIFIED IDEOGRAPH-#24569, IRGKangXi=0691.081, RSKangXi=89.12
2456A CJK UNIFIED IDEOGRAPH-#2456A, IRGKangXi=0691.110, RSKangXi=90.0
2456B CJK UNIFIED IDEOGRAPH-#2456B, IRGKangXi=0691.111, RSKangXi=90.1
2456C CJK UNIFIED IDEOGRAPH-#2456C, IRGKangXi=0691.111, RSKangXi=90.1
2456D CJK UNIFIED IDEOGRAPH-#2456D, IRGKangXi=0691.120, RSKangXi=90.2, Def{to get hold of, take}
2456E CJK UNIFIED IDEOGRAPH-#2456E, IRGKangXi=0691.130, RSKangXi=90.3
2456F CJK UNIFIED IDEOGRAPH-#2456F, IRGKangXi=0691.140, RSKangXi=90.4, Def{a syrupy liquid}
24570 CJK UNIFIED IDEOGRAPH-#24570, IRGKangXi=0691.160, RSKangXi=90.4
24571 CJK UNIFIED IDEOGRAPH-#24571, IRGKangXi=0691.170, RSKangXi=90.4
24572 CJK UNIFIED IDEOGRAPH-#24572, IRGKangXi=0691.200, RSKangXi=90.5
24573 CJK UNIFIED IDEOGRAPH-#24573, IRGKangXi=0691.210, RSKangXi=90.5
24574 CJK UNIFIED IDEOGRAPH-#24574, IRGKangXi=0691.220, RSKangXi=90.5
24575 CJK UNIFIED IDEOGRAPH-#24575, IRGKangXi=0691.230, RSKangXi=90.5
24576 CJK UNIFIED IDEOGRAPH-#24576, IRGKangXi=0691.240, RSKangXi=90.6
24577 CJK UNIFIED IDEOGRAPH-#24577, IRGKangXi=0692.010, RSKangXi=90.6
24578 CJK UNIFIED IDEOGRAPH-#24578, IRGKangXi=0692.021, RSKangXi=90.6
24579 CJK UNIFIED IDEOGRAPH-#24579, IRGKangXi=0692.021, RSKangXi=90.6
2457A CJK UNIFIED IDEOGRAPH-#2457A, IRGKangXi=0692.021, RSKangXi=90.6
2457B CJK UNIFIED IDEOGRAPH-#2457B, IRGKangXi=0692.030, RSKangXi=90.7
2457C CJK UNIFIED IDEOGRAPH-#2457C, IRGKangXi=0692.040, RSKangXi=90.7
2457D CJK UNIFIED IDEOGRAPH-#2457D, IRGKangXi=0692.050, RSKangXi=90.7
2457E CJK UNIFIED IDEOGRAPH-#2457E, IRGKangXi=0692.060, RSKangXi=90.7
2457F CJK UNIFIED IDEOGRAPH-#2457F, IRGKangXi=0692.071, RSKangXi=90.7
24580 CJK UNIFIED IDEOGRAPH-#24580, IRGKangXi=0692.071, RSKangXi=90.7
24581 CJK UNIFIED IDEOGRAPH-#24581, IRGKangXi=0692.071, RSKangXi=90.7
24582 CJK UNIFIED IDEOGRAPH-#24582, IRGKangXi=0692.071, RSKangXi=90.7
24583 CJK UNIFIED IDEOGRAPH-#24583, IRGKangXi=0692.071, RSKangXi=90.7
24584 CJK UNIFIED IDEOGRAPH-#24584, IRGKangXi=0692.090, RSKangXi=90.8
24585 CJK UNIFIED IDEOGRAPH-#24585, IRGKangXi=0692.100, RSKangXi=90.8
24586 CJK UNIFIED IDEOGRAPH-#24586, IRGKangXi=0692.110, RSKangXi=90.8
24587 CJK UNIFIED IDEOGRAPH-#24587, IRGKangXi=0692.120, RSKangXi=90.8
24588 CJK UNIFIED IDEOGRAPH-#24588, IRGKangXi=0692.130, RSKangXi=90.8
24589 CJK UNIFIED IDEOGRAPH-#24589, IRGKangXi=0692.140, RSKangXi=90.8
2458A CJK UNIFIED IDEOGRAPH-#2458A, IRGKangXi=0692.141, RSKangXi=90.8
2458B CJK UNIFIED IDEOGRAPH-#2458B, IRGKangXi=0692.141, RSKangXi=90.8
2458C CJK UNIFIED IDEOGRAPH-#2458C, IRGKangXi=0692.150, RSKangXi=90.9
2458D CJK UNIFIED IDEOGRAPH-#2458D, IRGKangXi=0692.170, RSKangXi=90.9
2458E CJK UNIFIED IDEOGRAPH-#2458E, IRGKangXi=0692.171, RSKangXi=90.9
2458F CJK UNIFIED IDEOGRAPH-#2458F, IRGKangXi=0692.190, RSKangXi=90.10
24590 CJK UNIFIED IDEOGRAPH-#24590, IRGKangXi=0692.200, RSKangXi=90.10
24591 CJK UNIFIED IDEOGRAPH-#24591, IRGKangXi=0692.201, RSKangXi=90.10
24592 CJK UNIFIED IDEOGRAPH-#24592, IRGKangXi=0692.201, RSKangXi=90.10
24593 CJK UNIFIED IDEOGRAPH-#24593, IRGKangXi=0692.210, RSKangXi=90.11
24594 CJK UNIFIED IDEOGRAPH-#24594, IRGKangXi=0692.221, RSKangXi=90.11
24595 CJK UNIFIED IDEOGRAPH-#24595, IRGKangXi=0692.221, RSKangXi=90.11
24596 CJK UNIFIED IDEOGRAPH-#24596, IRGKangXi=0692.230, RSKangXi=90.12
24597 CJK UNIFIED IDEOGRAPH-#24597, IRGKangXi=0692.240, RSKangXi=90.12
24598 CJK UNIFIED IDEOGRAPH-#24598, IRGKangXi=0692.250, RSKangXi=90.12
24599 CJK UNIFIED IDEOGRAPH-#24599, IRGKangXi=0692.251, RSKangXi=90.12
2459A CJK UNIFIED IDEOGRAPH-#2459A, IRGKangXi=0692.251, RSKangXi=90.12
2459B CJK UNIFIED IDEOGRAPH-#2459B, IRGKangXi=0692.251, RSKangXi=90.12
2459C CJK UNIFIED IDEOGRAPH-#2459C, IRGKangXi=0692.260, RSKangXi=90.13
2459D CJK UNIFIED IDEOGRAPH-#2459D, IRGKangXi=0692.270, RSKangXi=90.13
2459E CJK UNIFIED IDEOGRAPH-#2459E, IRGKangXi=0692.280, RSKangXi=90.13
2459F CJK UNIFIED IDEOGRAPH-#2459F, IRGKangXi=0692.301, RSKangXi=90.13
245A0 CJK UNIFIED IDEOGRAPH-#245A0, IRGKangXi=0692.310, RSKangXi=90.15
245A1 CJK UNIFIED IDEOGRAPH-#245A1, IRGKangXi=0692.311, RSKangXi=90.15
245A2 CJK UNIFIED IDEOGRAPH-#245A2, IRGKangXi=0692.320, RSKangXi=90.16
245A3 CJK UNIFIED IDEOGRAPH-#245A3, IRGKangXi=0692.330, RSKangXi=90.18
245A4 CJK UNIFIED IDEOGRAPH-#245A4, IRGKangXi=0692.331, RSKangXi=90.19
245A5 CJK UNIFIED IDEOGRAPH-#245A5, IRGKangXi=0692.331, RSKangXi=90.23
245A6 CJK UNIFIED IDEOGRAPH-#245A6, IRGKangXi=0692.340, RSKangXi=90.24
245A7 CJK UNIFIED IDEOGRAPH-#245A7, IRGKangXi=0692.350, RSKangXi=90.24
245A8 CJK UNIFIED IDEOGRAPH-#245A8, IRGKangXi=0692.361, RSKangXi=91.1
245A9 CJK UNIFIED IDEOGRAPH-#245A9, IRGKangXi=0693.010, RSKangXi=91.3
245AA CJK UNIFIED IDEOGRAPH-#245AA, IRGKangXi=0693.020, RSKangXi=91.3
245AB CJK UNIFIED IDEOGRAPH-#245AB, IRGKangXi=0693.021, RSKangXi=91.3
245AC CJK UNIFIED IDEOGRAPH-#245AC, IRGKangXi=0693.040, RSKangXi=91.4
245AD CJK UNIFIED IDEOGRAPH-#245AD, IRGKangXi=0693.050, RSKangXi=91.4
245AE CJK UNIFIED IDEOGRAPH-#245AE, IRGKangXi=0693.060, RSKangXi=91.4
245AF CJK UNIFIED IDEOGRAPH-#245AF, IRGKangXi=0693.090, RSKangXi=91.4
245B0 CJK UNIFIED IDEOGRAPH-#245B0, IRGKangXi=0693.100, RSKangXi=91.4
245B1 CJK UNIFIED IDEOGRAPH-#245B1, IRGKangXi=0693.110, RSKangXi=91.5
245B2 CJK UNIFIED IDEOGRAPH-#245B2, IRGKangXi=0693.120, RSKangXi=91.5
245B3 CJK UNIFIED IDEOGRAPH-#245B3, IRGKangXi=0693.130, RSKangXi=91.5
245B4 CJK UNIFIED IDEOGRAPH-#245B4, IRGKangXi=0693.140, RSKangXi=91.5
245B5 CJK UNIFIED IDEOGRAPH-#245B5, IRGKangXi=0693.161, RSKangXi=91.5
245B6 CJK UNIFIED IDEOGRAPH-#245B6, IRGKangXi=0693.161, RSKangXi=91.5
245B7 CJK UNIFIED IDEOGRAPH-#245B7, IRGKangXi=0693.161, RSKangXi=91.5
245B8 CJK UNIFIED IDEOGRAPH-#245B8, IRGKangXi=0693.161, RSKangXi=91.5
245B9 CJK UNIFIED IDEOGRAPH-#245B9, IRGKangXi=0693.161, RSKangXi=91.5
245BA CJK UNIFIED IDEOGRAPH-#245BA, IRGKangXi=0693.190, RSKangXi=91.6
245BB CJK UNIFIED IDEOGRAPH-#245BB, IRGKangXi=0693.200, RSKangXi=91.6
245BC CJK UNIFIED IDEOGRAPH-#245BC, IRGKangXi=0693.210, RSKangXi=91.6
245BD CJK UNIFIED IDEOGRAPH-#245BD, IRGKangXi=0693.220, RSKangXi=91.6
245BE CJK UNIFIED IDEOGRAPH-#245BE, IRGKangXi=0693.231, RSKangXi=91.6
245BF CJK UNIFIED IDEOGRAPH-#245BF, IRGKangXi=0693.231, RSKangXi=91.6
245C0 CJK UNIFIED IDEOGRAPH-#245C0, IRGKangXi=0693.240, RSKangXi=91.7
245C1 CJK UNIFIED IDEOGRAPH-#245C1, IRGKangXi=0693.250, RSKangXi=91.7
245C2 CJK UNIFIED IDEOGRAPH-#245C2, IRGKangXi=0693.270, RSKangXi=91.7
245C3 CJK UNIFIED IDEOGRAPH-#245C3, IRGKangXi=0693.271, RSKangXi=91.7
245C4 CJK UNIFIED IDEOGRAPH-#245C4, IRGKangXi=0693.271, RSKangXi=91.7
245C5 CJK UNIFIED IDEOGRAPH-#245C5, IRGKangXi=0693.271, RSKangXi=91.7
245C6 CJK UNIFIED IDEOGRAPH-#245C6, IRGKangXi=0693.271, RSKangXi=91.7
245C7 CJK UNIFIED IDEOGRAPH-#245C7, IRGKangXi=0693.300, RSKangXi=91.8
245C8 CJK UNIFIED IDEOGRAPH-#245C8, IRGKangXi=0693.310, RSKangXi=91.8, Def{(Cant.) to squeeze in, to stuff in}
245C9 CJK UNIFIED IDEOGRAPH-#245C9, IRGKangXi=0693.320, RSKangXi=91.8
245CA CJK UNIFIED IDEOGRAPH-#245CA, IRGKangXi=0693.330, RSKangXi=91.8
245CB CJK UNIFIED IDEOGRAPH-#245CB, IRGKangXi=0693.350, RSKangXi=91.8
245CC CJK UNIFIED IDEOGRAPH-#245CC, IRGKangXi=0693.360, RSKangXi=91.8
245CD CJK UNIFIED IDEOGRAPH-#245CD, IRGKangXi=0693.370, RSKangXi=91.8
245CE CJK UNIFIED IDEOGRAPH-#245CE, IRGKangXi=0693.380, RSKangXi=91.8
245CF CJK UNIFIED IDEOGRAPH-#245CF, IRGKangXi=0693.390, RSKangXi=91.8
245D0 CJK UNIFIED IDEOGRAPH-#245D0, IRGKangXi=0693.391, RSKangXi=91.8
245D1 CJK UNIFIED IDEOGRAPH-#245D1, IRGKangXi=0693.391, RSKangXi=91.8
245D2 CJK UNIFIED IDEOGRAPH-#245D2, IRGKangXi=0693.391, RSKangXi=91.8
245D3 CJK UNIFIED IDEOGRAPH-#245D3, IRGKangXi=0693.391, RSKangXi=91.8
245D4 CJK UNIFIED IDEOGRAPH-#245D4, IRGKangXi=0693.391, RSKangXi=91.8
245D5 CJK UNIFIED IDEOGRAPH-#245D5, IRGKangXi=0693.391, RSKangXi=91.8
245D6 CJK UNIFIED IDEOGRAPH-#245D6, IRGKangXi=0693.391, RSKangXi=91.8
245D7 CJK UNIFIED IDEOGRAPH-#245D7, IRGKangXi=0693.391, RSKangXi=91.8
245D8 CJK UNIFIED IDEOGRAPH-#245D8, IRGKangXi=0693.400, RSKangXi=91.9
245D9 CJK UNIFIED IDEOGRAPH-#245D9, IRGKangXi=0693.410, RSKangXi=91.9
245DA CJK UNIFIED IDEOGRAPH-#245DA, IRGKangXi=0693.430, RSKangXi=91.9
245DB CJK UNIFIED IDEOGRAPH-#245DB, IRGKangXi=0693.440, RSKangXi=91.9
245DC CJK UNIFIED IDEOGRAPH-#245DC, IRGKangXi=0694.040, RSKangXi=91.9
245DD CJK UNIFIED IDEOGRAPH-#245DD, IRGKangXi=0694.041, RSKangXi=91.9
245DE CJK UNIFIED IDEOGRAPH-#245DE, IRGKangXi=0694.041, RSKangXi=91.9
245DF CJK UNIFIED IDEOGRAPH-#245DF, IRGKangXi=0694.041, RSKangXi=91.9
245E0 CJK UNIFIED IDEOGRAPH-#245E0, IRGKangXi=0694.041, RSKangXi=91.9
245E1 CJK UNIFIED IDEOGRAPH-#245E1, IRGKangXi=0694.041, RSKangXi=91.9
245E2 CJK UNIFIED IDEOGRAPH-#245E2, IRGKangXi=0694.050, RSKangXi=91.10
245E3 CJK UNIFIED IDEOGRAPH-#245E3, IRGKangXi=0694.090, RSKangXi=91.10
245E4 CJK UNIFIED IDEOGRAPH-#245E4, IRGKangXi=0694.091, RSKangXi=91.10
245E5 CJK UNIFIED IDEOGRAPH-#245E5, IRGKangXi=0694.091, RSKangXi=91.10
245E6 CJK UNIFIED IDEOGRAPH-#245E6, IRGKangXi=0694.091, RSKangXi=91.10
245E7 CJK UNIFIED IDEOGRAPH-#245E7, IRGKangXi=0694.091, RSKangXi=91.10
245E8 CJK UNIFIED IDEOGRAPH-#245E8, IRGKangXi=0694.100, RSKangXi=91.11
245E9 CJK UNIFIED IDEOGRAPH-#245E9, IRGKangXi=0694.120, RSKangXi=91.11
245EA CJK UNIFIED IDEOGRAPH-#245EA, IRGKangXi=0694.130, RSKangXi=91.11
245EB CJK UNIFIED IDEOGRAPH-#245EB, IRGKangXi=0694.140, RSKangXi=91.11
245EC CJK UNIFIED IDEOGRAPH-#245EC, IRGKangXi=0694.150, RSKangXi=91.11
245ED CJK UNIFIED IDEOGRAPH-#245ED, IRGKangXi=0694.160, RSKangXi=91.11
245EE CJK UNIFIED IDEOGRAPH-#245EE, IRGKangXi=0694.170, RSKangXi=91.11
245EF CJK UNIFIED IDEOGRAPH-#245EF, IRGKangXi=0694.190, RSKangXi=91.11
245F0 CJK UNIFIED IDEOGRAPH-#245F0, IRGKangXi=0694.191, RSKangXi=91.11
245F1 CJK UNIFIED IDEOGRAPH-#245F1, IRGKangXi=0694.191, RSKangXi=91.11
245F2 CJK UNIFIED IDEOGRAPH-#245F2, IRGKangXi=0694.191, RSKangXi=91.11
245F3 CJK UNIFIED IDEOGRAPH-#245F3, IRGKangXi=0694.200, RSKangXi=91.12
245F4 CJK UNIFIED IDEOGRAPH-#245F4, IRGKangXi=0694.210, RSKangXi=91.12
245F5 CJK UNIFIED IDEOGRAPH-#245F5, IRGKangXi=0694.220, RSKangXi=91.12
245F6 CJK UNIFIED IDEOGRAPH-#245F6, IRGKangXi=0694.230, RSKangXi=91.12
245F7 CJK UNIFIED IDEOGRAPH-#245F7, IRGKangXi=0694.240, RSKangXi=91.12
245F8 CJK UNIFIED IDEOGRAPH-#245F8, IRGKangXi=0694.250, RSKangXi=91.12
245F9 CJK UNIFIED IDEOGRAPH-#245F9, IRGKangXi=0694.251, RSKangXi=91.12
245FA CJK UNIFIED IDEOGRAPH-#245FA, IRGKangXi=0694.260, RSKangXi=91.13
245FB CJK UNIFIED IDEOGRAPH-#245FB, IRGKangXi=0694.270, RSKangXi=91.13
245FC CJK UNIFIED IDEOGRAPH-#245FC, IRGKangXi=0694.281, RSKangXi=91.13
245FD CJK UNIFIED IDEOGRAPH-#245FD, IRGKangXi=0694.281, RSKangXi=91.13
245FE CJK UNIFIED IDEOGRAPH-#245FE, IRGKangXi=0694.281, RSKangXi=91.13
245FF CJK UNIFIED IDEOGRAPH-#245FF, IRGKangXi=0694.300, RSKangXi=91.14
24600 CJK UNIFIED IDEOGRAPH-#24600, IRGKangXi=0694.310, RSKangXi=91.14
24601 CJK UNIFIED IDEOGRAPH-#24601, IRGKangXi=0694.311, RSKangXi=91.14
24602 CJK UNIFIED IDEOGRAPH-#24602, IRGKangXi=0694.311, RSKangXi=91.14
24603 CJK UNIFIED IDEOGRAPH-#24603, IRGKangXi=0695.010, RSKangXi=91.16
24604 CJK UNIFIED IDEOGRAPH-#24604, IRGKangXi=0695.021, RSKangXi=91.17
24605 CJK UNIFIED IDEOGRAPH-#24605, IRGKangXi=0695.060, RSKangXi=92.3, Def{a very young child}
24606 CJK UNIFIED IDEOGRAPH-#24606, IRGKangXi=0695.061, RSKangXi=92.4
24607 CJK UNIFIED IDEOGRAPH-#24607, IRGKangXi=0695.061, RSKangXi=92.5
24608 CJK UNIFIED IDEOGRAPH-#24608, IRGKangXi=0695.080, RSKangXi=92.6
24609 CJK UNIFIED IDEOGRAPH-#24609, IRGKangXi=0695.081, RSKangXi=92.6
2460A CJK UNIFIED IDEOGRAPH-#2460A, IRGKangXi=0695.081, RSKangXi=92.7
2460B CJK UNIFIED IDEOGRAPH-#2460B, IRGKangXi=0695.081, RSKangXi=92.7
2460C CJK UNIFIED IDEOGRAPH-#2460C, IRGKangXi=0695.090, RSKangXi=92.8
2460D CJK UNIFIED IDEOGRAPH-#2460D, IRGKangXi=0695.101, RSKangXi=92.8
2460E CJK UNIFIED IDEOGRAPH-#2460E, IRGKangXi=0695.101, RSKangXi=92.8
2460F CJK UNIFIED IDEOGRAPH-#2460F, IRGKangXi=0695.101, RSKangXi=92.8
24610 CJK UNIFIED IDEOGRAPH-#24610, IRGKangXi=0695.110, RSKangXi=92.9
24611 CJK UNIFIED IDEOGRAPH-#24611, IRGKangXi=0695.120, RSKangXi=92.10
24612 CJK UNIFIED IDEOGRAPH-#24612, IRGKangXi=0695.121, RSKangXi=92.11
24613 CJK UNIFIED IDEOGRAPH-#24613, IRGKangXi=0695.121, RSKangXi=92.14
24614 CJK UNIFIED IDEOGRAPH-#24614, IRGKangXi=0697.011, RSKangXi=93.1
24615 CJK UNIFIED IDEOGRAPH-#24615, IRGKangXi=0697.071, RSKangXi=93.2
24616 CJK UNIFIED IDEOGRAPH-#24616, IRGKangXi=0697.071, RSKangXi=93.2
24617 CJK UNIFIED IDEOGRAPH-#24617, IRGKangXi=0697.071, RSKangXi=93.2
24618 CJK UNIFIED IDEOGRAPH-#24618, IRGKangXi=0698.040, RSKangXi=93.3, Def{cattle, domestic animals}
24619 CJK UNIFIED IDEOGRAPH-#24619, IRGKangXi=0698.041, RSKangXi=93.3
2461A CJK UNIFIED IDEOGRAPH-#2461A, IRGKangXi=0698.041, RSKangXi=93.3
2461B CJK UNIFIED IDEOGRAPH-#2461B, IRGKangXi=0698.041, RSKangXi=93.3
2461C CJK UNIFIED IDEOGRAPH-#2461C, IRGKangXi=0698.060, RSKangXi=93.4
2461D CJK UNIFIED IDEOGRAPH-#2461D, IRGKangXi=0698.110, RSKangXi=93.4
2461E CJK UNIFIED IDEOGRAPH-#2461E, IRGKangXi=0698.130, RSKangXi=93.4
2461F CJK UNIFIED IDEOGRAPH-#2461F, IRGKangXi=0698.140, RSKangXi=93.4
24620 CJK UNIFIED IDEOGRAPH-#24620, IRGKangXi=0698.150, RSKangXi=93.4
24621 CJK UNIFIED IDEOGRAPH-#24621, IRGKangXi=0699.010, RSKangXi=93.4
24622 CJK UNIFIED IDEOGRAPH-#24622, IRGKangXi=0699.040, RSKangXi=93.4
24623 CJK UNIFIED IDEOGRAPH-#24623, IRGKangXi=0699.050, RSKangXi=93.4
24624 CJK UNIFIED IDEOGRAPH-#24624, IRGKangXi=0699.060, RSKangXi=93.4
24625 CJK UNIFIED IDEOGRAPH-#24625, IRGKangXi=0699.070, RSKangXi=93.4
24626 CJK UNIFIED IDEOGRAPH-#24626, IRGKangXi=0699.080, RSKangXi=93.4
24627 CJK UNIFIED IDEOGRAPH-#24627, IRGKangXi=0699.110, RSKangXi=93.4
24628 CJK UNIFIED IDEOGRAPH-#24628, IRGKangXi=0699.111, RSKangXi=93.4
24629 CJK UNIFIED IDEOGRAPH-#24629, IRGKangXi=0699.111, RSKangXi=93.4
2462A CJK UNIFIED IDEOGRAPH-#2462A, IRGKangXi=0699.111, RSKangXi=93.4
2462B CJK UNIFIED IDEOGRAPH-#2462B, IRGKangXi=0699.111, RSKangXi=93.4
2462C CJK UNIFIED IDEOGRAPH-#2462C, IRGKangXi=0699.111, RSKangXi=93.4
2462D CJK UNIFIED IDEOGRAPH-#2462D, IRGKangXi=0699.111, RSKangXi=93.4
2462E CJK UNIFIED IDEOGRAPH-#2462E, IRGKangXi=0699.111, RSKangXi=93.4
2462F CJK UNIFIED IDEOGRAPH-#2462F, IRGKangXi=0699.111, RSKangXi=93.4
24630 CJK UNIFIED IDEOGRAPH-#24630, IRGKangXi=0699.111, RSKangXi=93.4
24631 CJK UNIFIED IDEOGRAPH-#24631, IRGKangXi=0699.111, RSKangXi=93.4
24632 CJK UNIFIED IDEOGRAPH-#24632, IRGKangXi=0699.111, RSKangXi=93.4
24633 CJK UNIFIED IDEOGRAPH-#24633, IRGKangXi=0699.111, RSKangXi=93.4
24634 CJK UNIFIED IDEOGRAPH-#24634, IRGKangXi=0699.111, RSKangXi=93.4
24635 CJK UNIFIED IDEOGRAPH-#24635, IRGKangXi=0699.111, RSKangXi=93.4
24636 CJK UNIFIED IDEOGRAPH-#24636, IRGKangXi=0699.111, RSKangXi=93.4
24637 CJK UNIFIED IDEOGRAPH-#24637, IRGKangXi=0699.111, RSKangXi=93.4
24638 CJK UNIFIED IDEOGRAPH-#24638, IRGKangXi=0699.140, RSKangXi=93.5
24639 CJK UNIFIED IDEOGRAPH-#24639, IRGKangXi=0699.170, RSKangXi=93.5
2463A CJK UNIFIED IDEOGRAPH-#2463A, IRGKangXi=0699.180, RSKangXi=93.5
2463B CJK UNIFIED IDEOGRAPH-#2463B, IRGKangXi=0699.200, RSKangXi=93.5
2463C CJK UNIFIED IDEOGRAPH-#2463C, IRGKangXi=0699.210, RSKangXi=93.5
2463D CJK UNIFIED IDEOGRAPH-#2463D, IRGKangXi=0699.230, RSKangXi=93.5
2463E CJK UNIFIED IDEOGRAPH-#2463E, IRGKangXi=0699.250, RSKangXi=93.5
2463F CJK UNIFIED IDEOGRAPH-#2463F, IRGKangXi=0700.020, RSKangXi=93.5
24640 CJK UNIFIED IDEOGRAPH-#24640, IRGKangXi=0700.060, RSKangXi=93.5
24641 CJK UNIFIED IDEOGRAPH-#24641, IRGKangXi=0700.061, RSKangXi=93.5
24642 CJK UNIFIED IDEOGRAPH-#24642, IRGKangXi=0700.061, RSKangXi=93.5
24643 CJK UNIFIED IDEOGRAPH-#24643, IRGKangXi=0700.061, RSKangXi=93.5
24644 CJK UNIFIED IDEOGRAPH-#24644, IRGKangXi=0700.061, RSKangXi=93.5
24645 CJK UNIFIED IDEOGRAPH-#24645, IRGKangXi=0700.061, RSKangXi=93.5
24646 CJK UNIFIED IDEOGRAPH-#24646, IRGKangXi=0700.061, RSKangXi=93.5
24647 CJK UNIFIED IDEOGRAPH-#24647, IRGKangXi=0700.061, RSKangXi=93.5
24648 CJK UNIFIED IDEOGRAPH-#24648, IRGKangXi=0700.061, RSKangXi=93.5
24649 CJK UNIFIED IDEOGRAPH-#24649, IRGKangXi=0700.061, RSKangXi=93.5
2464A CJK UNIFIED IDEOGRAPH-#2464A, IRGKangXi=0700.061, RSKangXi=93.5
2464B CJK UNIFIED IDEOGRAPH-#2464B, IRGKangXi=0700.061, RSKangXi=93.5
2464C CJK UNIFIED IDEOGRAPH-#2464C, IRGKangXi=0700.061, RSKangXi=93.5
2464D CJK UNIFIED IDEOGRAPH-#2464D, IRGKangXi=0700.061, RSKangXi=93.5
2464E CJK UNIFIED IDEOGRAPH-#2464E, IRGKangXi=0700.061, RSKangXi=93.5
2464F CJK UNIFIED IDEOGRAPH-#2464F, IRGKangXi=0700.061, RSKangXi=93.5
24650 CJK UNIFIED IDEOGRAPH-#24650, IRGKangXi=0700.061, RSKangXi=93.5
24651 CJK UNIFIED IDEOGRAPH-#24651, IRGKangXi=0700.070, RSKangXi=93.6
24652 CJK UNIFIED IDEOGRAPH-#24652, IRGKangXi=0700.100, RSKangXi=93.6
24653 CJK UNIFIED IDEOGRAPH-#24653, IRGKangXi=0700.140, RSKangXi=93.6
24654 CJK UNIFIED IDEOGRAPH-#24654, IRGKangXi=0700.150, RSKangXi=93.6
24655 CJK UNIFIED IDEOGRAPH-#24655, IRGKangXi=0700.160, RSKangXi=93.6
24656 CJK UNIFIED IDEOGRAPH-#24656, IRGKangXi=0700.180, RSKangXi=93.6
24657 CJK UNIFIED IDEOGRAPH-#24657, IRGKangXi=0700.210, RSKangXi=93.6
24658 CJK UNIFIED IDEOGRAPH-#24658, IRGKangXi=0700.220, RSKangXi=93.6
24659 CJK UNIFIED IDEOGRAPH-#24659, IRGKangXi=0700.221, RSKangXi=93.6
2465A CJK UNIFIED IDEOGRAPH-#2465A, IRGKangXi=0700.221, RSKangXi=93.6
2465B CJK UNIFIED IDEOGRAPH-#2465B, IRGKangXi=0700.230, RSKangXi=93.7
2465C CJK UNIFIED IDEOGRAPH-#2465C, IRGKangXi=0700.290, RSKangXi=93.7
2465D CJK UNIFIED IDEOGRAPH-#2465D, IRGKangXi=0701.010, RSKangXi=93.7
2465E CJK UNIFIED IDEOGRAPH-#2465E, IRGKangXi=0701.060, RSKangXi=93.7
2465F CJK UNIFIED IDEOGRAPH-#2465F, IRGKangXi=0701.090, RSKangXi=93.7
24660 CJK UNIFIED IDEOGRAPH-#24660, IRGKangXi=0701.100, RSKangXi=93.7
24661 CJK UNIFIED IDEOGRAPH-#24661, IRGKangXi=0701.120, RSKangXi=93.7
24662 CJK UNIFIED IDEOGRAPH-#24662, IRGKangXi=0701.130, RSKangXi=93.7
24663 CJK UNIFIED IDEOGRAPH-#24663, IRGKangXi=0701.150, RSKangXi=93.7
24664 CJK UNIFIED IDEOGRAPH-#24664, IRGKangXi=0701.160, RSKangXi=93.7
24665 CJK UNIFIED IDEOGRAPH-#24665, IRGKangXi=0701.171, RSKangXi=93.7
24666 CJK UNIFIED IDEOGRAPH-#24666, IRGKangXi=0701.171, RSKangXi=93.7
24667 CJK UNIFIED IDEOGRAPH-#24667, IRGKangXi=0701.171, RSKangXi=93.7
24668 CJK UNIFIED IDEOGRAPH-#24668, IRGKangXi=0701.171, RSKangXi=93.7
24669 CJK UNIFIED IDEOGRAPH-#24669, IRGKangXi=0701.171, RSKangXi=93.7
2466A CJK UNIFIED IDEOGRAPH-#2466A, IRGKangXi=0701.171, RSKangXi=93.7
2466B CJK UNIFIED IDEOGRAPH-#2466B, IRGKangXi=0701.171, RSKangXi=93.7
2466C CJK UNIFIED IDEOGRAPH-#2466C, IRGKangXi=0701.171, RSKangXi=93.7
2466D CJK UNIFIED IDEOGRAPH-#2466D, IRGKangXi=0701.171, RSKangXi=93.7
2466E CJK UNIFIED IDEOGRAPH-#2466E, IRGKangXi=0701.171, RSKangXi=93.7
2466F CJK UNIFIED IDEOGRAPH-#2466F, IRGKangXi=0701.171, RSKangXi=93.8
24670 CJK UNIFIED IDEOGRAPH-#24670, IRGKangXi=0701.180, RSKangXi=93.8
24671 CJK UNIFIED IDEOGRAPH-#24671, IRGKangXi=0701.190, RSKangXi=93.8
24672 CJK UNIFIED IDEOGRAPH-#24672, IRGKangXi=0702.010, RSKangXi=93.8
24673 CJK UNIFIED IDEOGRAPH-#24673, IRGKangXi=0702.020, RSKangXi=93.8
24674 CJK UNIFIED IDEOGRAPH-#24674, IRGKangXi=0702.030, RSKangXi=93.8, Def{(Cant.) gore}
24675 CJK UNIFIED IDEOGRAPH-#24675, IRGKangXi=0702.070, RSKangXi=93.8
24676 CJK UNIFIED IDEOGRAPH-#24676, IRGKangXi=0702.141, RSKangXi=93.8
24677 CJK UNIFIED IDEOGRAPH-#24677, IRGKangXi=0702.141, RSKangXi=93.8
24678 CJK UNIFIED IDEOGRAPH-#24678, IRGKangXi=0702.141, RSKangXi=93.8
24679 CJK UNIFIED IDEOGRAPH-#24679, IRGKangXi=0702.141, RSKangXi=93.8
2467A CJK UNIFIED IDEOGRAPH-#2467A, IRGKangXi=0702.141, RSKangXi=93.8
2467B CJK UNIFIED IDEOGRAPH-#2467B, IRGKangXi=0702.141, RSKangXi=93.8
2467C CJK UNIFIED IDEOGRAPH-#2467C, IRGKangXi=0702.141, RSKangXi=93.8
2467D CJK UNIFIED IDEOGRAPH-#2467D, IRGKangXi=0702.141, RSKangXi=93.8
2467E CJK UNIFIED IDEOGRAPH-#2467E, IRGKangXi=0702.141, RSKangXi=93.8
2467F CJK UNIFIED IDEOGRAPH-#2467F, IRGKangXi=0702.141, RSKangXi=93.8
24680 CJK UNIFIED IDEOGRAPH-#24680, IRGKangXi=0702.141, RSKangXi=93.8
24681 CJK UNIFIED IDEOGRAPH-#24681, IRGKangXi=0702.141, RSKangXi=93.8
24682 CJK UNIFIED IDEOGRAPH-#24682, IRGKangXi=0702.141, RSKangXi=93.8
24683 CJK UNIFIED IDEOGRAPH-#24683, IRGKangXi=0702.141, RSKangXi=93.8
24684 CJK UNIFIED IDEOGRAPH-#24684, IRGKangXi=0702.141, RSKangXi=93.8
24685 CJK UNIFIED IDEOGRAPH-#24685, IRGKangXi=0702.141, RSKangXi=93.8
24686 CJK UNIFIED IDEOGRAPH-#24686, IRGKangXi=0702.141, RSKangXi=93.8
24687 CJK UNIFIED IDEOGRAPH-#24687, IRGKangXi=0702.141, RSKangXi=93.8
24688 CJK UNIFIED IDEOGRAPH-#24688, IRGKangXi=0702.141, RSKangXi=93.8
24689 CJK UNIFIED IDEOGRAPH-#24689, IRGKangXi=0702.141, RSKangXi=93.8
2468A CJK UNIFIED IDEOGRAPH-#2468A, IRGKangXi=0702.141, RSKangXi=93.8
2468B CJK UNIFIED IDEOGRAPH-#2468B, IRGKangXi=0702.141, RSKangXi=93.8
2468C CJK UNIFIED IDEOGRAPH-#2468C, IRGKangXi=0702.141, RSKangXi=93.8
2468D CJK UNIFIED IDEOGRAPH-#2468D, IRGKangXi=0702.150, RSKangXi=93.9
2468E CJK UNIFIED IDEOGRAPH-#2468E, IRGKangXi=0702.170, RSKangXi=93.9
2468F CJK UNIFIED IDEOGRAPH-#2468F, IRGKangXi=0702.200, RSKangXi=93.9
24690 CJK UNIFIED IDEOGRAPH-#24690, IRGKangXi=0702.210, RSKangXi=93.9
24691 CJK UNIFIED IDEOGRAPH-#24691, IRGKangXi=0702.220, RSKangXi=93.9
24692 CJK UNIFIED IDEOGRAPH-#24692, IRGKangXi=0702.240, RSKangXi=93.9
24693 CJK UNIFIED IDEOGRAPH-#24693, IRGKangXi=0702.250, RSKangXi=93.9
24694 CJK UNIFIED IDEOGRAPH-#24694, IRGKangXi=0702.280, RSKangXi=93.9
24695 CJK UNIFIED IDEOGRAPH-#24695, IRGKangXi=0702.290, RSKangXi=93.9
24696 CJK UNIFIED IDEOGRAPH-#24696, IRGKangXi=0703.010, RSKangXi=93.9
24697 CJK UNIFIED IDEOGRAPH-#24697, IRGKangXi=0703.041, RSKangXi=93.9
24698 CJK UNIFIED IDEOGRAPH-#24698, IRGKangXi=0703.041, RSKangXi=93.9
24699 CJK UNIFIED IDEOGRAPH-#24699, IRGKangXi=0703.041, RSKangXi=93.9
2469A CJK UNIFIED IDEOGRAPH-#2469A, IRGKangXi=0703.041, RSKangXi=93.9
2469B CJK UNIFIED IDEOGRAPH-#2469B, IRGKangXi=0703.041, RSKangXi=93.9
2469C CJK UNIFIED IDEOGRAPH-#2469C, IRGKangXi=0703.041, RSKangXi=77.9
2469D CJK UNIFIED IDEOGRAPH-#2469D, IRGKangXi=0703.041, RSKangXi=93.9
2469E CJK UNIFIED IDEOGRAPH-#2469E, IRGKangXi=0703.041, RSKangXi=93.9
2469F CJK UNIFIED IDEOGRAPH-#2469F, IRGKangXi=0703.041, RSKangXi=93.9
246A0 CJK UNIFIED IDEOGRAPH-#246A0, IRGKangXi=0703.041, RSKangXi=93.9
246A1 CJK UNIFIED IDEOGRAPH-#246A1, IRGKangXi=0703.041, RSKangXi=93.9
246A2 CJK UNIFIED IDEOGRAPH-#246A2, IRGKangXi=0703.041, RSKangXi=93.9
246A3 CJK UNIFIED IDEOGRAPH-#246A3, IRGKangXi=0703.041, RSKangXi=93.9
246A4 CJK UNIFIED IDEOGRAPH-#246A4, IRGKangXi=0703.041, RSKangXi=93.9
246A5 CJK UNIFIED IDEOGRAPH-#246A5, IRGKangXi=0703.041, RSKangXi=93.9
246A6 CJK UNIFIED IDEOGRAPH-#246A6, IRGKangXi=0703.041, RSKangXi=93.9
246A7 CJK UNIFIED IDEOGRAPH-#246A7, IRGKangXi=0703.041, RSKangXi=93.9
246A8 CJK UNIFIED IDEOGRAPH-#246A8, IRGKangXi=0703.041, RSKangXi=93.9
246A9 CJK UNIFIED IDEOGRAPH-#246A9, IRGKangXi=0703.050, RSKangXi=93.10
246AA CJK UNIFIED IDEOGRAPH-#246AA, IRGKangXi=0703.060, RSKangXi=93.10
246AB CJK UNIFIED IDEOGRAPH-#246AB, IRGKangXi=0703.070, RSKangXi=93.10
246AC CJK UNIFIED IDEOGRAPH-#246AC, IRGKangXi=0703.080, RSKangXi=93.10
246AD CJK UNIFIED IDEOGRAPH-#246AD, IRGKangXi=0703.100, RSKangXi=93.10
246AE CJK UNIFIED IDEOGRAPH-#246AE, IRGKangXi=0703.150, RSKangXi=93.10
246AF CJK UNIFIED IDEOGRAPH-#246AF, IRGKangXi=0703.160, RSKangXi=93.10
246B0 CJK UNIFIED IDEOGRAPH-#246B0, IRGKangXi=0703.170, RSKangXi=93.10
246B1 CJK UNIFIED IDEOGRAPH-#246B1, IRGKangXi=0703.180, RSKangXi=93.10
246B2 CJK UNIFIED IDEOGRAPH-#246B2, IRGKangXi=0703.200, RSKangXi=93.10
246B3 CJK UNIFIED IDEOGRAPH-#246B3, IRGKangXi=0703.210, RSKangXi=93.10
246B4 CJK UNIFIED IDEOGRAPH-#246B4, IRGKangXi=0703.250, RSKangXi=93.10
246B5 CJK UNIFIED IDEOGRAPH-#246B5, IRGKangXi=0703.260, RSKangXi=93.10
246B6 CJK UNIFIED IDEOGRAPH-#246B6, IRGKangXi=0703.270, RSKangXi=93.10
246B7 CJK UNIFIED IDEOGRAPH-#246B7, IRGKangXi=0703.271, RSKangXi=93.10
246B8 CJK UNIFIED IDEOGRAPH-#246B8, IRGKangXi=0703.271, RSKangXi=93.10
246B9 CJK UNIFIED IDEOGRAPH-#246B9, IRGKangXi=0703.271, RSKangXi=93.10
246BA CJK UNIFIED IDEOGRAPH-#246BA, IRGKangXi=0703.271, RSKangXi=93.10
246BB CJK UNIFIED IDEOGRAPH-#246BB, IRGKangXi=0703.271, RSKangXi=93.10
246BC CJK UNIFIED IDEOGRAPH-#246BC, IRGKangXi=0703.271, RSKangXi=93.10
246BD CJK UNIFIED IDEOGRAPH-#246BD, IRGKangXi=0703.271, RSKangXi=93.10
246BE CJK UNIFIED IDEOGRAPH-#246BE, IRGKangXi=0703.271, RSKangXi=93.10
246BF CJK UNIFIED IDEOGRAPH-#246BF, IRGKangXi=0703.271, RSKangXi=93.9
246C0 CJK UNIFIED IDEOGRAPH-#246C0, IRGKangXi=0703.271, RSKangXi=93.10
246C1 CJK UNIFIED IDEOGRAPH-#246C1, IRGKangXi=0703.271, RSKangXi=93.10
246C2 CJK UNIFIED IDEOGRAPH-#246C2, IRGKangXi=0703.271, RSKangXi=93.10
246C3 CJK UNIFIED IDEOGRAPH-#246C3, IRGKangXi=0703.271, RSKangXi=93.10
246C4 CJK UNIFIED IDEOGRAPH-#246C4, IRGKangXi=0703.271, RSKangXi=93.10
246C5 CJK UNIFIED IDEOGRAPH-#246C5, IRGKangXi=0703.271, RSKangXi=93.10
246C6 CJK UNIFIED IDEOGRAPH-#246C6, IRGKangXi=0703.271, RSKangXi=93.10
246C7 CJK UNIFIED IDEOGRAPH-#246C7, IRGKangXi=0703.271, RSKangXi=93.10
246C8 CJK UNIFIED IDEOGRAPH-#246C8, IRGKangXi=0703.271, RSKangXi=93.10
246C9 CJK UNIFIED IDEOGRAPH-#246C9, IRGKangXi=0703.271, RSKangXi=93.10
246CA CJK UNIFIED IDEOGRAPH-#246CA, IRGKangXi=0703.280, RSKangXi=93.11
246CB CJK UNIFIED IDEOGRAPH-#246CB, IRGKangXi=0703.320, RSKangXi=93.11
246CC CJK UNIFIED IDEOGRAPH-#246CC, IRGKangXi=0703.350, RSKangXi=93.11
246CD CJK UNIFIED IDEOGRAPH-#246CD, IRGKangXi=0704.010, RSKangXi=93.11
246CE CJK UNIFIED IDEOGRAPH-#246CE, IRGKangXi=0704.020, RSKangXi=93.11
246CF CJK UNIFIED IDEOGRAPH-#246CF, IRGKangXi=0704.030, RSKangXi=93.11
246D0 CJK UNIFIED IDEOGRAPH-#246D0, IRGKangXi=0704.050, RSKangXi=93.11
246D1 CJK UNIFIED IDEOGRAPH-#246D1, IRGKangXi=0704.060, RSKangXi=93.11
246D2 CJK UNIFIED IDEOGRAPH-#246D2, IRGKangXi=0704.080, RSKangXi=93.11
246D3 CJK UNIFIED IDEOGRAPH-#246D3, IRGKangXi=0704.081, RSKangXi=93.11
246D4 CJK UNIFIED IDEOGRAPH-#246D4, IRGKangXi=0704.081, RSKangXi=93.11
246D5 CJK UNIFIED IDEOGRAPH-#246D5, IRGKangXi=0704.081, RSKangXi=93.11
246D6 CJK UNIFIED IDEOGRAPH-#246D6, IRGKangXi=0704.081, RSKangXi=93.11
246D7 CJK UNIFIED IDEOGRAPH-#246D7, IRGKangXi=0704.081, RSKangXi=79.11
246D8 CJK UNIFIED IDEOGRAPH-#246D8, IRGKangXi=0704.081, RSKangXi=93.11
246D9 CJK UNIFIED IDEOGRAPH-#246D9, IRGKangXi=0704.081, RSKangXi=93.11
246DA CJK UNIFIED IDEOGRAPH-#246DA, IRGKangXi=0704.081, RSKangXi=93.11
246DB CJK UNIFIED IDEOGRAPH-#246DB, IRGKangXi=0704.081, RSKangXi=93.11
246DC CJK UNIFIED IDEOGRAPH-#246DC, IRGKangXi=0704.081, RSKangXi=93.11
246DD CJK UNIFIED IDEOGRAPH-#246DD, IRGKangXi=0704.081, RSKangXi=93.11
246DE CJK UNIFIED IDEOGRAPH-#246DE, IRGKangXi=0704.081, RSKangXi=93.11
246DF CJK UNIFIED IDEOGRAPH-#246DF, IRGKangXi=0704.081, RSKangXi=93.11
246E0 CJK UNIFIED IDEOGRAPH-#246E0, IRGKangXi=0704.081, RSKangXi=93.11
246E1 CJK UNIFIED IDEOGRAPH-#246E1, IRGKangXi=0704.090, RSKangXi=93.12
246E2 CJK UNIFIED IDEOGRAPH-#246E2, IRGKangXi=0704.100, RSKangXi=93.12
246E3 CJK UNIFIED IDEOGRAPH-#246E3, IRGKangXi=0704.120, RSKangXi=93.12
246E4 CJK UNIFIED IDEOGRAPH-#246E4, IRGKangXi=0704.130, RSKangXi=93.12
246E5 CJK UNIFIED IDEOGRAPH-#246E5, IRGKangXi=0704.150, RSKangXi=93.12
246E6 CJK UNIFIED IDEOGRAPH-#246E6, IRGKangXi=0704.160, RSKangXi=93.12
246E7 CJK UNIFIED IDEOGRAPH-#246E7, IRGKangXi=0704.190, RSKangXi=93.12
246E8 CJK UNIFIED IDEOGRAPH-#246E8, IRGKangXi=0704.211, RSKangXi=93.12
246E9 CJK UNIFIED IDEOGRAPH-#246E9, IRGKangXi=0704.211, RSKangXi=93.12
246EA CJK UNIFIED IDEOGRAPH-#246EA, IRGKangXi=0704.211, RSKangXi=93.12
246EB CJK UNIFIED IDEOGRAPH-#246EB, IRGKangXi=0704.211, RSKangXi=93.12
246EC CJK UNIFIED IDEOGRAPH-#246EC, IRGKangXi=0704.211, RSKangXi=93.12
246ED CJK UNIFIED IDEOGRAPH-#246ED, IRGKangXi=0704.211, RSKangXi=93.12
246EE CJK UNIFIED IDEOGRAPH-#246EE, IRGKangXi=0704.211, RSKangXi=93.12
246EF CJK UNIFIED IDEOGRAPH-#246EF, IRGKangXi=0704.220, RSKangXi=93.13
246F0 CJK UNIFIED IDEOGRAPH-#246F0, IRGKangXi=0704.240, RSKangXi=93.13
246F1 CJK UNIFIED IDEOGRAPH-#246F1, IRGKangXi=0704.270, RSKangXi=93.13
246F2 CJK UNIFIED IDEOGRAPH-#246F2, IRGKangXi=0704.280, RSKangXi=93.13
246F3 CJK UNIFIED IDEOGRAPH-#246F3, IRGKangXi=0704.290, RSKangXi=93.13
246F4 CJK UNIFIED IDEOGRAPH-#246F4, IRGKangXi=0704.300, RSKangXi=93.13
246F5 CJK UNIFIED IDEOGRAPH-#246F5, IRGKangXi=0704.310, RSKangXi=93.13
246F6 CJK UNIFIED IDEOGRAPH-#246F6, IRGKangXi=0704.320, RSKangXi=93.13
246F7 CJK UNIFIED IDEOGRAPH-#246F7, IRGKangXi=0704.321, RSKangXi=93.13
246F8 CJK UNIFIED IDEOGRAPH-#246F8, IRGKangXi=0704.321, RSKangXi=93.13
246F9 CJK UNIFIED IDEOGRAPH-#246F9, IRGKangXi=0704.350, RSKangXi=93.14
246FA CJK UNIFIED IDEOGRAPH-#246FA, IRGKangXi=0704.351, RSKangXi=93.14
246FB CJK UNIFIED IDEOGRAPH-#246FB, IRGKangXi=0704.360, RSKangXi=93.15
246FC CJK UNIFIED IDEOGRAPH-#246FC, IRGKangXi=0704.400, RSKangXi=93.15
246FD CJK UNIFIED IDEOGRAPH-#246FD, IRGKangXi=0705.010, RSKangXi=93.15
246FE CJK UNIFIED IDEOGRAPH-#246FE, IRGKangXi=0705.030, RSKangXi=93.15
246FF CJK UNIFIED IDEOGRAPH-#246FF, IRGKangXi=0705.050, RSKangXi=93.15
24700 CJK UNIFIED IDEOGRAPH-#24700, IRGKangXi=0705.051, RSKangXi=93.15
24701 CJK UNIFIED IDEOGRAPH-#24701, IRGKangXi=0705.051, RSKangXi=93.15
24702 CJK UNIFIED IDEOGRAPH-#24702, IRGKangXi=0705.060, RSKangXi=93.16
24703 CJK UNIFIED IDEOGRAPH-#24703, IRGKangXi=0705.070, RSKangXi=93.16
24704 CJK UNIFIED IDEOGRAPH-#24704, IRGKangXi=0705.080, RSKangXi=93.16
24705 CJK UNIFIED IDEOGRAPH-#24705, IRGKangXi=0705.110, RSKangXi=93.16
24706 CJK UNIFIED IDEOGRAPH-#24706, IRGKangXi=0705.111, RSKangXi=93.16
24707 CJK UNIFIED IDEOGRAPH-#24707, IRGKangXi=0705.130, RSKangXi=93.17
24708 CJK UNIFIED IDEOGRAPH-#24708, IRGKangXi=0705.140, RSKangXi=93.17
24709 CJK UNIFIED IDEOGRAPH-#24709, IRGKangXi=0705.150, RSKangXi=93.17
2470A CJK UNIFIED IDEOGRAPH-#2470A, IRGKangXi=0705.151, RSKangXi=93.17
2470B CJK UNIFIED IDEOGRAPH-#2470B, IRGKangXi=0705.151, RSKangXi=93.17
2470C CJK UNIFIED IDEOGRAPH-#2470C, IRGKangXi=0705.180, RSKangXi=93.18
2470D CJK UNIFIED IDEOGRAPH-#2470D, IRGKangXi=0705.190, RSKangXi=93.18
2470E CJK UNIFIED IDEOGRAPH-#2470E, IRGKangXi=0705.191, RSKangXi=93.18
2470F CJK UNIFIED IDEOGRAPH-#2470F, IRGKangXi=0705.191, RSKangXi=93.18
24710 CJK UNIFIED IDEOGRAPH-#24710, IRGKangXi=0705.191, RSKangXi=93.18
24711 CJK UNIFIED IDEOGRAPH-#24711, IRGKangXi=0705.200, RSKangXi=93.19
24712 CJK UNIFIED IDEOGRAPH-#24712, IRGKangXi=0705.210, RSKangXi=93.19
24713 CJK UNIFIED IDEOGRAPH-#24713, IRGKangXi=0705.211, RSKangXi=93.19
24714 CJK UNIFIED IDEOGRAPH-#24714, IRGKangXi=0705.230, RSKangXi=93.20
24715 CJK UNIFIED IDEOGRAPH-#24715, IRGKangXi=0705.231, RSKangXi=93.20
24716 CJK UNIFIED IDEOGRAPH-#24716, IRGKangXi=0705.240, RSKangXi=93.21
24717 CJK UNIFIED IDEOGRAPH-#24717, IRGKangXi=0705.241, RSKangXi=93.21
24718 CJK UNIFIED IDEOGRAPH-#24718, IRGKangXi=0705.241, RSKangXi=93.21
24719 CJK UNIFIED IDEOGRAPH-#24719, IRGKangXi=0705.260, RSKangXi=93.24
2471A CJK UNIFIED IDEOGRAPH-#2471A, IRGKangXi=0706.011, RSKangXi=94.1
2471B CJK UNIFIED IDEOGRAPH-#2471B, IRGKangXi=0706.050, RSKangXi=94.2
2471C CJK UNIFIED IDEOGRAPH-#2471C, IRGKangXi=0706.060, RSKangXi=94.2
2471D CJK UNIFIED IDEOGRAPH-#2471D, IRGKangXi=0706.070, RSKangXi=94.2
2471E CJK UNIFIED IDEOGRAPH-#2471E, IRGKangXi=0706.081, RSKangXi=94.2
2471F CJK UNIFIED IDEOGRAPH-#2471F, IRGKangXi=0706.081, RSKangXi=94.2
24720 CJK UNIFIED IDEOGRAPH-#24720, IRGKangXi=0706.081, RSKangXi=94.2
24721 CJK UNIFIED IDEOGRAPH-#24721, IRGKangXi=0706.090, RSKangXi=94.3
24722 CJK UNIFIED IDEOGRAPH-#24722, IRGKangXi=0706.100, RSKangXi=94.3
24723 CJK UNIFIED IDEOGRAPH-#24723, IRGKangXi=0706.110, RSKangXi=94.3
24724 CJK UNIFIED IDEOGRAPH-#24724, IRGKangXi=0706.130, RSKangXi=94.3
24725 CJK UNIFIED IDEOGRAPH-#24725, IRGKangXi=0706.171, RSKangXi=94.3
24726 CJK UNIFIED IDEOGRAPH-#24726, IRGKangXi=0706.171, RSKangXi=94.3
24727 CJK UNIFIED IDEOGRAPH-#24727, IRGKangXi=0706.171, RSKangXi=94.3
24728 CJK UNIFIED IDEOGRAPH-#24728, IRGKangXi=0706.171, RSKangXi=94.3
24729 CJK UNIFIED IDEOGRAPH-#24729, IRGKangXi=0706.171, RSKangXi=94.3
2472A CJK UNIFIED IDEOGRAPH-#2472A, IRGKangXi=0706.171, RSKangXi=94.3
2472B CJK UNIFIED IDEOGRAPH-#2472B, IRGKangXi=0706.171, RSKangXi=94.3
2472C CJK UNIFIED IDEOGRAPH-#2472C, IRGKangXi=0706.171, RSKangXi=94.3
2472D CJK UNIFIED IDEOGRAPH-#2472D, IRGKangXi=0706.171, RSKangXi=94.3
2472E CJK UNIFIED IDEOGRAPH-#2472E, IRGKangXi=0706.171, RSKangXi=94.3
2472F CJK UNIFIED IDEOGRAPH-#2472F, IRGKangXi=0706.180, RSKangXi=94.4, Def{(Cant.) to bite}
24730 CJK UNIFIED IDEOGRAPH-#24730, IRGKangXi=0706.200, RSKangXi=94.4
24731 CJK UNIFIED IDEOGRAPH-#24731, IRGKangXi=0706.220, RSKangXi=94.4
24732 CJK UNIFIED IDEOGRAPH-#24732, IRGKangXi=0706.230, RSKangXi=94.4
24733 CJK UNIFIED IDEOGRAPH-#24733, IRGKangXi=0706.250, RSKangXi=94.4
24734 CJK UNIFIED IDEOGRAPH-#24734, IRGKangXi=0706.260, RSKangXi=94.4
24735 CJK UNIFIED IDEOGRAPH-#24735, IRGKangXi=0707.010, RSKangXi=94.4
24736 CJK UNIFIED IDEOGRAPH-#24736, IRGKangXi=0707.020, RSKangXi=94.4
24737 CJK UNIFIED IDEOGRAPH-#24737, IRGKangXi=0707.030, RSKangXi=94.4
24738 CJK UNIFIED IDEOGRAPH-#24738, IRGKangXi=0707.040, RSKangXi=94.4
24739 CJK UNIFIED IDEOGRAPH-#24739, IRGKangXi=0707.060, RSKangXi=94.4
2473A CJK UNIFIED IDEOGRAPH-#2473A, IRGKangXi=0707.100, RSKangXi=94.4
2473B CJK UNIFIED IDEOGRAPH-#2473B, IRGKangXi=0707.110, RSKangXi=94.4
2473C CJK UNIFIED IDEOGRAPH-#2473C, IRGKangXi=0707.170, RSKangXi=94.4
2473D CJK UNIFIED IDEOGRAPH-#2473D, IRGKangXi=0707.180, RSKangXi=94.4
2473E CJK UNIFIED IDEOGRAPH-#2473E, IRGKangXi=0708.010, RSKangXi=94.4
2473F CJK UNIFIED IDEOGRAPH-#2473F, IRGKangXi=0708.021, RSKangXi=94.4
24740 CJK UNIFIED IDEOGRAPH-#24740, IRGKangXi=0708.021, RSKangXi=94.4
24741 CJK UNIFIED IDEOGRAPH-#24741, IRGKangXi=0708.021, RSKangXi=94.4
24742 CJK UNIFIED IDEOGRAPH-#24742, IRGKangXi=0708.021, RSKangXi=94.4
24743 CJK UNIFIED IDEOGRAPH-#24743, IRGKangXi=0708.021, RSKangXi=94.4
24744 CJK UNIFIED IDEOGRAPH-#24744, IRGKangXi=0708.021, RSKangXi=94.4
24745 CJK UNIFIED IDEOGRAPH-#24745, IRGKangXi=0708.021, RSKangXi=94.4
24746 CJK UNIFIED IDEOGRAPH-#24746, IRGKangXi=0708.021, RSKangXi=94.4
24747 CJK UNIFIED IDEOGRAPH-#24747, IRGKangXi=0708.021, RSKangXi=94.4
24748 CJK UNIFIED IDEOGRAPH-#24748, IRGKangXi=0708.021, RSKangXi=94.4
24749 CJK UNIFIED IDEOGRAPH-#24749, IRGKangXi=0708.021, RSKangXi=94.4
2474A CJK UNIFIED IDEOGRAPH-#2474A, IRGKangXi=0708.021, RSKangXi=94.4
2474B CJK UNIFIED IDEOGRAPH-#2474B, IRGKangXi=0708.021, RSKangXi=94.4
2474C CJK UNIFIED IDEOGRAPH-#2474C, IRGKangXi=0708.021, RSKangXi=94.4
2474D CJK UNIFIED IDEOGRAPH-#2474D, IRGKangXi=0708.021, RSKangXi=94.4
2474E CJK UNIFIED IDEOGRAPH-#2474E, IRGKangXi=0708.021, RSKangXi=94.4
2474F CJK UNIFIED IDEOGRAPH-#2474F, IRGKangXi=0708.030, RSKangXi=94.5
24750 CJK UNIFIED IDEOGRAPH-#24750, IRGKangXi=0708.040, RSKangXi=94.5
24751 CJK UNIFIED IDEOGRAPH-#24751, IRGKangXi=0708.050, RSKangXi=94.5
24752 CJK UNIFIED IDEOGRAPH-#24752, IRGKangXi=0708.060, RSKangXi=94.5
24753 CJK UNIFIED IDEOGRAPH-#24753, IRGKangXi=0708.070, RSKangXi=94.5
24754 CJK UNIFIED IDEOGRAPH-#24754, IRGKangXi=0708.080, RSKangXi=94.5
24755 CJK UNIFIED IDEOGRAPH-#24755, IRGKangXi=0708.110, RSKangXi=94.5
24756 CJK UNIFIED IDEOGRAPH-#24756, IRGKangXi=0708.130, RSKangXi=94.5
24757 CJK UNIFIED IDEOGRAPH-#24757, IRGKangXi=0708.140, RSKangXi=94.5
24758 CJK UNIFIED IDEOGRAPH-#24758, IRGKangXi=0708.210, RSKangXi=94.5
24759 CJK UNIFIED IDEOGRAPH-#24759, IRGKangXi=0708.220, RSKangXi=94.5
2475A CJK UNIFIED IDEOGRAPH-#2475A, IRGKangXi=0708.260, RSKangXi=94.5
2475B CJK UNIFIED IDEOGRAPH-#2475B, IRGKangXi=0708.270, RSKangXi=94.5
2475C CJK UNIFIED IDEOGRAPH-#2475C, IRGKangXi=0709.010, RSKangXi=94.5
2475D CJK UNIFIED IDEOGRAPH-#2475D, IRGKangXi=0709.040, RSKangXi=94.5
2475E CJK UNIFIED IDEOGRAPH-#2475E, IRGKangXi=0709.060, RSKangXi=94.5, Def{a lemur of the genus Cynocephalus}
2475F CJK UNIFIED IDEOGRAPH-#2475F, IRGKangXi=0709.070, RSKangXi=94.5
24760 CJK UNIFIED IDEOGRAPH-#24760, IRGKangXi=0709.170, RSKangXi=94.5
24761 CJK UNIFIED IDEOGRAPH-#24761, IRGKangXi=0709.180, RSKangXi=94.5
24762 CJK UNIFIED IDEOGRAPH-#24762, IRGKangXi=0709.181, RSKangXi=94.5
24763 CJK UNIFIED IDEOGRAPH-#24763, IRGKangXi=0709.181, RSKangXi=94.5
24764 CJK UNIFIED IDEOGRAPH-#24764, IRGKangXi=0709.181, RSKangXi=94.5
24765 CJK UNIFIED IDEOGRAPH-#24765, IRGKangXi=0709.181, RSKangXi=94.5
24766 CJK UNIFIED IDEOGRAPH-#24766, IRGKangXi=0709.181, RSKangXi=94.5
24767 CJK UNIFIED IDEOGRAPH-#24767, IRGKangXi=0709.181, RSKangXi=94.5
24768 CJK UNIFIED IDEOGRAPH-#24768, IRGKangXi=0709.181, RSKangXi=94.5
24769 CJK UNIFIED IDEOGRAPH-#24769, IRGKangXi=0709.181, RSKangXi=94.5
2476A CJK UNIFIED IDEOGRAPH-#2476A, IRGKangXi=0709.181, RSKangXi=94.5
2476B CJK UNIFIED IDEOGRAPH-#2476B, IRGKangXi=0709.181, RSKangXi=94.5
2476C CJK UNIFIED IDEOGRAPH-#2476C, IRGKangXi=0709.181, RSKangXi=94.5
2476D CJK UNIFIED IDEOGRAPH-#2476D, IRGKangXi=0709.181, RSKangXi=94.5
2476E CJK UNIFIED IDEOGRAPH-#2476E, IRGKangXi=0709.181, RSKangXi=94.4
2476F CJK UNIFIED IDEOGRAPH-#2476F, IRGKangXi=0710.040, RSKangXi=94.6
24770 CJK UNIFIED IDEOGRAPH-#24770, IRGKangXi=0710.070, RSKangXi=94.6
24771 CJK UNIFIED IDEOGRAPH-#24771, IRGKangXi=0710.090, RSKangXi=94.6
24772 CJK UNIFIED IDEOGRAPH-#24772, IRGKangXi=0710.100, RSKangXi=94.6
24773 CJK UNIFIED IDEOGRAPH-#24773, IRGKangXi=0710.110, RSKangXi=94.6
24774 CJK UNIFIED IDEOGRAPH-#24774, IRGKangXi=0710.120, RSKangXi=94.6
24775 CJK UNIFIED IDEOGRAPH-#24775, IRGKangXi=0710.130, RSKangXi=94.6
24776 CJK UNIFIED IDEOGRAPH-#24776, IRGKangXi=0710.140, RSKangXi=94.6
24777 CJK UNIFIED IDEOGRAPH-#24777, IRGKangXi=0710.150, RSKangXi=94.6
24778 CJK UNIFIED IDEOGRAPH-#24778, IRGKangXi=0710.160, RSKangXi=94.6
24779 CJK UNIFIED IDEOGRAPH-#24779, IRGKangXi=0710.190, RSKangXi=94.6
2477A CJK UNIFIED IDEOGRAPH-#2477A, IRGKangXi=0710.210, RSKangXi=94.6
2477B CJK UNIFIED IDEOGRAPH-#2477B, IRGKangXi=0710.250, RSKangXi=94.6
2477C CJK UNIFIED IDEOGRAPH-#2477C, IRGKangXi=0710.260, RSKangXi=94.6
2477D CJK UNIFIED IDEOGRAPH-#2477D, IRGKangXi=0711.010, RSKangXi=94.6
2477E CJK UNIFIED IDEOGRAPH-#2477E, IRGKangXi=0711.020, RSKangXi=94.6
2477F CJK UNIFIED IDEOGRAPH-#2477F, IRGKangXi=0711.030, RSKangXi=94.6
24780 CJK UNIFIED IDEOGRAPH-#24780, IRGKangXi=0711.070, RSKangXi=94.6
24781 CJK UNIFIED IDEOGRAPH-#24781, IRGKangXi=0711.090, RSKangXi=94.6
24782 CJK UNIFIED IDEOGRAPH-#24782, IRGKangXi=0711.100, RSKangXi=94.6
24783 CJK UNIFIED IDEOGRAPH-#24783, IRGKangXi=0711.101, RSKangXi=94.6
24784 CJK UNIFIED IDEOGRAPH-#24784, IRGKangXi=0711.101, RSKangXi=94.6
24785 CJK UNIFIED IDEOGRAPH-#24785, IRGKangXi=0711.101, RSKangXi=94.6
24786 CJK UNIFIED IDEOGRAPH-#24786, IRGKangXi=0711.101, RSKangXi=94.6
24787 CJK UNIFIED IDEOGRAPH-#24787, IRGKangXi=0711.101, RSKangXi=94.6
24788 CJK UNIFIED IDEOGRAPH-#24788, IRGKangXi=0711.101, RSKangXi=94.6
24789 CJK UNIFIED IDEOGRAPH-#24789, IRGKangXi=0711.101, RSKangXi=94.6
2478A CJK UNIFIED IDEOGRAPH-#2478A, IRGKangXi=0711.101, RSKangXi=94.6
2478B CJK UNIFIED IDEOGRAPH-#2478B, IRGKangXi=0711.101, RSKangXi=94.6
2478C CJK UNIFIED IDEOGRAPH-#2478C, IRGKangXi=0711.101, RSKangXi=94.6
2478D CJK UNIFIED IDEOGRAPH-#2478D, IRGKangXi=0711.101, RSKangXi=94.6
2478E CJK UNIFIED IDEOGRAPH-#2478E, IRGKangXi=0711.101, RSKangXi=94.6
2478F CJK UNIFIED IDEOGRAPH-#2478F, IRGKangXi=0711.101, RSKangXi=94.6
24790 CJK UNIFIED IDEOGRAPH-#24790, IRGKangXi=0711.101, RSKangXi=94.6
24791 CJK UNIFIED IDEOGRAPH-#24791, IRGKangXi=0711.101, RSKangXi=94.6
24792 CJK UNIFIED IDEOGRAPH-#24792, IRGKangXi=0711.101, RSKangXi=94.6
24793 CJK UNIFIED IDEOGRAPH-#24793, IRGKangXi=0711.101, RSKangXi=94.6
24794 CJK UNIFIED IDEOGRAPH-#24794, IRGKangXi=0711.101, RSKangXi=94.6
24795 CJK UNIFIED IDEOGRAPH-#24795, IRGKangXi=0711.101, RSKangXi=94.6
24796 CJK UNIFIED IDEOGRAPH-#24796, IRGKangXi=0711.101, RSKangXi=94.6
24797 CJK UNIFIED IDEOGRAPH-#24797, IRGKangXi=0711.101, RSKangXi=94.6
24798 CJK UNIFIED IDEOGRAPH-#24798, IRGKangXi=0711.101, RSKangXi=94.6
24799 CJK UNIFIED IDEOGRAPH-#24799, IRGKangXi=0711.110, RSKangXi=94.7
2479A CJK UNIFIED IDEOGRAPH-#2479A, IRGKangXi=0711.180, RSKangXi=94.7
2479B CJK UNIFIED IDEOGRAPH-#2479B, IRGKangXi=0711.200, RSKangXi=94.7
2479C CJK UNIFIED IDEOGRAPH-#2479C, IRGKangXi=0711.210, RSKangXi=94.7
2479D CJK UNIFIED IDEOGRAPH-#2479D, IRGKangXi=0711.230, RSKangXi=94.7
2479E CJK UNIFIED IDEOGRAPH-#2479E, IRGKangXi=0711.240, RSKangXi=94.7
2479F CJK UNIFIED IDEOGRAPH-#2479F, IRGKangXi=0711.250, RSKangXi=94.7
247A0 CJK UNIFIED IDEOGRAPH-#247A0, IRGKangXi=0711.260, RSKangXi=94.7
247A1 CJK UNIFIED IDEOGRAPH-#247A1, IRGKangXi=0711.310, RSKangXi=94.7
247A2 CJK UNIFIED IDEOGRAPH-#247A2, IRGKangXi=0712.070, RSKangXi=94.7
247A3 CJK UNIFIED IDEOGRAPH-#247A3, IRGKangXi=0712.071, RSKangXi=94.6
247A4 CJK UNIFIED IDEOGRAPH-#247A4, IRGKangXi=0712.071, RSKangXi=94.7
247A5 CJK UNIFIED IDEOGRAPH-#247A5, IRGKangXi=0712.071, RSKangXi=94.7
247A6 CJK UNIFIED IDEOGRAPH-#247A6, IRGKangXi=0712.071, RSKangXi=94.7
247A7 CJK UNIFIED IDEOGRAPH-#247A7, IRGKangXi=0712.071, RSKangXi=94.7
247A8 CJK UNIFIED IDEOGRAPH-#247A8, IRGKangXi=0712.071, RSKangXi=94.7
247A9 CJK UNIFIED IDEOGRAPH-#247A9, IRGKangXi=0712.071, RSKangXi=94.7
247AA CJK UNIFIED IDEOGRAPH-#247AA, IRGKangXi=0712.071, RSKangXi=94.7
247AB CJK UNIFIED IDEOGRAPH-#247AB, IRGKangXi=0712.071, RSKangXi=94.7
247AC CJK UNIFIED IDEOGRAPH-#247AC, IRGKangXi=0712.071, RSKangXi=94.7
247AD CJK UNIFIED IDEOGRAPH-#247AD, IRGKangXi=0712.071, RSKangXi=94.7
247AE CJK UNIFIED IDEOGRAPH-#247AE, IRGKangXi=0712.071, RSKangXi=94.7
247AF CJK UNIFIED IDEOGRAPH-#247AF, IRGKangXi=0712.071, RSKangXi=94.7
247B0 CJK UNIFIED IDEOGRAPH-#247B0, IRGKangXi=0712.071, RSKangXi=94.7
247B1 CJK UNIFIED IDEOGRAPH-#247B1, IRGKangXi=0712.071, RSKangXi=94.7
247B2 CJK UNIFIED IDEOGRAPH-#247B2, IRGKangXi=0712.071, RSKangXi=94.7
247B3 CJK UNIFIED IDEOGRAPH-#247B3, IRGKangXi=0712.071, RSKangXi=94.7
247B4 CJK UNIFIED IDEOGRAPH-#247B4, IRGKangXi=0712.071, RSKangXi=94.7
247B5 CJK UNIFIED IDEOGRAPH-#247B5, IRGKangXi=0712.071, RSKangXi=94.7
247B6 CJK UNIFIED IDEOGRAPH-#247B6, IRGKangXi=0712.071, RSKangXi=94.7
247B7 CJK UNIFIED IDEOGRAPH-#247B7, IRGKangXi=0712.071, RSKangXi=94.7
247B8 CJK UNIFIED IDEOGRAPH-#247B8, IRGKangXi=0712.071, RSKangXi=94.7
247B9 CJK UNIFIED IDEOGRAPH-#247B9, IRGKangXi=0712.071, RSKangXi=94.7
247BA CJK UNIFIED IDEOGRAPH-#247BA, IRGKangXi=0712.071, RSKangXi=94.7
247BB CJK UNIFIED IDEOGRAPH-#247BB, IRGKangXi=0712.071, RSKangXi=94.7
247BC CJK UNIFIED IDEOGRAPH-#247BC, IRGKangXi=0712.071, RSKangXi=94.7
247BD CJK UNIFIED IDEOGRAPH-#247BD, IRGKangXi=0712.071, RSKangXi=94.7
247BE CJK UNIFIED IDEOGRAPH-#247BE, IRGKangXi=0712.071, RSKangXi=94.7
247BF CJK UNIFIED IDEOGRAPH-#247BF, IRGKangXi=0712.071, RSKangXi=94.7
247C0 CJK UNIFIED IDEOGRAPH-#247C0, IRGKangXi=0712.071, RSKangXi=94.7
247C1 CJK UNIFIED IDEOGRAPH-#247C1, IRGKangXi=0712.071, RSKangXi=94.7
247C2 CJK UNIFIED IDEOGRAPH-#247C2, IRGKangXi=0712.071, RSKangXi=94.7
247C3 CJK UNIFIED IDEOGRAPH-#247C3, IRGKangXi=0712.130, RSKangXi=94.8
247C4 CJK UNIFIED IDEOGRAPH-#247C4, IRGKangXi=0712.150, RSKangXi=94.8
247C5 CJK UNIFIED IDEOGRAPH-#247C5, IRGKangXi=0712.200, RSKangXi=94.8
247C6 CJK UNIFIED IDEOGRAPH-#247C6, IRGKangXi=0713.010, RSKangXi=94.8
247C7 CJK UNIFIED IDEOGRAPH-#247C7, IRGKangXi=0713.040, RSKangXi=94.8
247C8 CJK UNIFIED IDEOGRAPH-#247C8, IRGKangXi=0713.060, RSKangXi=94.8
247C9 CJK UNIFIED IDEOGRAPH-#247C9, IRGKangXi=0713.080, RSKangXi=94.8
247CA CJK UNIFIED IDEOGRAPH-#247CA, IRGKangXi=0713.090, RSKangXi=94.8
247CB CJK UNIFIED IDEOGRAPH-#247CB, IRGKangXi=0713.120, RSKangXi=94.8
247CC CJK UNIFIED IDEOGRAPH-#247CC, IRGKangXi=0713.130, RSKangXi=94.8
247CD CJK UNIFIED IDEOGRAPH-#247CD, IRGKangXi=0713.160, RSKangXi=94.8
247CE CJK UNIFIED IDEOGRAPH-#247CE, IRGKangXi=0713.180, RSKangXi=94.8
247CF CJK UNIFIED IDEOGRAPH-#247CF, IRGKangXi=0714.030, RSKangXi=94.8
247D0 CJK UNIFIED IDEOGRAPH-#247D0, IRGKangXi=0714.040, RSKangXi=94.8
247D1 CJK UNIFIED IDEOGRAPH-#247D1, IRGKangXi=0714.050, RSKangXi=94.8
247D2 CJK UNIFIED IDEOGRAPH-#247D2, IRGKangXi=0714.051, RSKangXi=94.8
247D3 CJK UNIFIED IDEOGRAPH-#247D3, IRGKangXi=0714.051, RSKangXi=94.8
247D4 CJK UNIFIED IDEOGRAPH-#247D4, IRGKangXi=0714.051, RSKangXi=94.8
247D5 CJK UNIFIED IDEOGRAPH-#247D5, IRGKangXi=0714.051, RSKangXi=94.8
247D6 CJK UNIFIED IDEOGRAPH-#247D6, IRGKangXi=0714.051, RSKangXi=94.8
247D7 CJK UNIFIED IDEOGRAPH-#247D7, IRGKangXi=0714.051, RSKangXi=94.8
247D8 CJK UNIFIED IDEOGRAPH-#247D8, IRGKangXi=0714.051, RSKangXi=94.8
247D9 CJK UNIFIED IDEOGRAPH-#247D9, IRGKangXi=0714.051, RSKangXi=94.8
247DA CJK UNIFIED IDEOGRAPH-#247DA, IRGKangXi=0714.051, RSKangXi=94.8
247DB CJK UNIFIED IDEOGRAPH-#247DB, IRGKangXi=0714.051, RSKangXi=94.8
247DC CJK UNIFIED IDEOGRAPH-#247DC, IRGKangXi=0714.080, RSKangXi=94.9
247DD CJK UNIFIED IDEOGRAPH-#247DD, IRGKangXi=0714.110, RSKangXi=94.9
247DE CJK UNIFIED IDEOGRAPH-#247DE, IRGKangXi=0714.130, RSKangXi=94.9
247DF CJK UNIFIED IDEOGRAPH-#247DF, IRGKangXi=0714.140, RSKangXi=94.9
247E0 CJK UNIFIED IDEOGRAPH-#247E0, IRGKangXi=0714.160, RSKangXi=94.9
247E1 CJK UNIFIED IDEOGRAPH-#247E1, IRGKangXi=0714.200, RSKangXi=94.9
247E2 CJK UNIFIED IDEOGRAPH-#247E2, IRGKangXi=0714.230, RSKangXi=94.9
247E3 CJK UNIFIED IDEOGRAPH-#247E3, IRGKangXi=0714.240, RSKangXi=94.9
247E4 CJK UNIFIED IDEOGRAPH-#247E4, IRGKangXi=0714.250, RSKangXi=94.9
247E5 CJK UNIFIED IDEOGRAPH-#247E5, IRGKangXi=0715.020, RSKangXi=94.9
247E6 CJK UNIFIED IDEOGRAPH-#247E6, IRGKangXi=0715.060, RSKangXi=94.9
247E7 CJK UNIFIED IDEOGRAPH-#247E7, IRGKangXi=0715.090, RSKangXi=94.9
247E8 CJK UNIFIED IDEOGRAPH-#247E8, IRGKangXi=0715.110, RSKangXi=94.9
247E9 CJK UNIFIED IDEOGRAPH-#247E9, IRGKangXi=0715.130, RSKangXi=94.9
247EA CJK UNIFIED IDEOGRAPH-#247EA, IRGKangXi=0715.160, RSKangXi=94.9
247EB CJK UNIFIED IDEOGRAPH-#247EB, IRGKangXi=0715.180, RSKangXi=94.9
247EC CJK UNIFIED IDEOGRAPH-#247EC, IRGKangXi=0716.020, RSKangXi=94.9
247ED CJK UNIFIED IDEOGRAPH-#247ED, IRGKangXi=0716.030, RSKangXi=94.9
247EE CJK UNIFIED IDEOGRAPH-#247EE, IRGKangXi=0716.051, RSKangXi=94.9
247EF CJK UNIFIED IDEOGRAPH-#247EF, IRGKangXi=0716.051, RSKangXi=94.9
247F0 CJK UNIFIED IDEOGRAPH-#247F0, IRGKangXi=0716.051, RSKangXi=94.9
247F1 CJK UNIFIED IDEOGRAPH-#247F1, IRGKangXi=0716.051, RSKangXi=94.9
247F2 CJK UNIFIED IDEOGRAPH-#247F2, IRGKangXi=0716.051, RSKangXi=94.9
247F3 CJK UNIFIED IDEOGRAPH-#247F3, IRGKangXi=0716.051, RSKangXi=94.9
247F4 CJK UNIFIED IDEOGRAPH-#247F4, IRGKangXi=0716.051, RSKangXi=94.9
247F5 CJK UNIFIED IDEOGRAPH-#247F5, IRGKangXi=0716.051, RSKangXi=63.9
247F6 CJK UNIFIED IDEOGRAPH-#247F6, IRGKangXi=0716.051, RSKangXi=94.9
247F7 CJK UNIFIED IDEOGRAPH-#247F7, IRGKangXi=0716.051, RSKangXi=94.9
247F8 CJK UNIFIED IDEOGRAPH-#247F8, IRGKangXi=0716.051, RSKangXi=94.9
247F9 CJK UNIFIED IDEOGRAPH-#247F9, IRGKangXi=0716.051, RSKangXi=94.9
247FA CJK UNIFIED IDEOGRAPH-#247FA, IRGKangXi=0716.051, RSKangXi=94.9
247FB CJK UNIFIED IDEOGRAPH-#247FB, IRGKangXi=0716.051, RSKangXi=94.9
247FC CJK UNIFIED IDEOGRAPH-#247FC, IRGKangXi=0716.051, RSKangXi=94.9
247FD CJK UNIFIED IDEOGRAPH-#247FD, IRGKangXi=0716.051, RSKangXi=94.9
247FE CJK UNIFIED IDEOGRAPH-#247FE, IRGKangXi=0716.051, RSKangXi=94.9
247FF CJK UNIFIED IDEOGRAPH-#247FF, IRGKangXi=0716.051, RSKangXi=94.9
24800 CJK UNIFIED IDEOGRAPH-#24800, IRGKangXi=0716.051, RSKangXi=94.9
24801 CJK UNIFIED IDEOGRAPH-#24801, IRGKangXi=0716.051, RSKangXi=94.9
24802 CJK UNIFIED IDEOGRAPH-#24802, IRGKangXi=0716.051, RSKangXi=94.9
24803 CJK UNIFIED IDEOGRAPH-#24803, IRGKangXi=0716.051, RSKangXi=94.9
24804 CJK UNIFIED IDEOGRAPH-#24804, IRGKangXi=0716.051, RSKangXi=94.9
24805 CJK UNIFIED IDEOGRAPH-#24805, IRGKangXi=0716.051, RSKangXi=94.9
24806 CJK UNIFIED IDEOGRAPH-#24806, IRGKangXi=0716.051, RSKangXi=94.9
24807 CJK UNIFIED IDEOGRAPH-#24807, IRGKangXi=0716.051, RSKangXi=94.9
24808 CJK UNIFIED IDEOGRAPH-#24808, IRGKangXi=0716.051, RSKangXi=94.9
24809 CJK UNIFIED IDEOGRAPH-#24809, IRGKangXi=0716.051, RSKangXi=94.9
2480A CJK UNIFIED IDEOGRAPH-#2480A, IRGKangXi=0716.051, RSKangXi=94.9
2480B CJK UNIFIED IDEOGRAPH-#2480B, IRGKangXi=0716.051, RSKangXi=94.9
2480C CJK UNIFIED IDEOGRAPH-#2480C, IRGKangXi=0716.051, RSKangXi=94.9
2480D CJK UNIFIED IDEOGRAPH-#2480D, IRGKangXi=0716.070, RSKangXi=94.10
2480E CJK UNIFIED IDEOGRAPH-#2480E, IRGKangXi=0716.090, RSKangXi=94.10
2480F CJK UNIFIED IDEOGRAPH-#2480F, IRGKangXi=0716.100, RSKangXi=94.10
24810 CJK UNIFIED IDEOGRAPH-#24810, IRGKangXi=0716.110, RSKangXi=94.10
24811 CJK UNIFIED IDEOGRAPH-#24811, IRGKangXi=0716.120, RSKangXi=94.10, Def{sea otter}
24812 CJK UNIFIED IDEOGRAPH-#24812, IRGKangXi=0716.160, RSKangXi=94.10
24813 CJK UNIFIED IDEOGRAPH-#24813, IRGKangXi=0716.170, RSKangXi=94.10
24814 CJK UNIFIED IDEOGRAPH-#24814, IRGKangXi=0716.200, RSKangXi=94.10
24815 CJK UNIFIED IDEOGRAPH-#24815, IRGKangXi=0716.210, RSKangXi=94.10
24816 CJK UNIFIED IDEOGRAPH-#24816, IRGKangXi=0716.220, RSKangXi=94.10
24817 CJK UNIFIED IDEOGRAPH-#24817, IRGKangXi=0716.240, RSKangXi=94.10
24818 CJK UNIFIED IDEOGRAPH-#24818, IRGKangXi=0716.250, RSKangXi=94.10
24819 CJK UNIFIED IDEOGRAPH-#24819, IRGKangXi=0716.260, RSKangXi=94.10
2481A CJK UNIFIED IDEOGRAPH-#2481A, IRGKangXi=0716.270, RSKangXi=94.10
2481B CJK UNIFIED IDEOGRAPH-#2481B, IRGKangXi=0716.280, RSKangXi=94.10
2481C CJK UNIFIED IDEOGRAPH-#2481C, IRGKangXi=0716.320, RSKangXi=94.10
2481D CJK UNIFIED IDEOGRAPH-#2481D, IRGKangXi=0716.330, RSKangXi=94.10
2481E CJK UNIFIED IDEOGRAPH-#2481E, IRGKangXi=0717.010, RSKangXi=94.10
2481F CJK UNIFIED IDEOGRAPH-#2481F, IRGKangXi=0717.050, RSKangXi=94.10
24820 CJK UNIFIED IDEOGRAPH-#24820, IRGKangXi=0717.070, RSKangXi=94.10
24821 CJK UNIFIED IDEOGRAPH-#24821, IRGKangXi=0717.080, RSKangXi=94.10
24822 CJK UNIFIED IDEOGRAPH-#24822, IRGKangXi=0717.111, RSKangXi=94.10
24823 CJK UNIFIED IDEOGRAPH-#24823, IRGKangXi=0717.111, RSKangXi=94.10
24824 CJK UNIFIED IDEOGRAPH-#24824, IRGKangXi=0717.111, RSKangXi=94.10
24825 CJK UNIFIED IDEOGRAPH-#24825, IRGKangXi=0717.111, RSKangXi=94.10
24826 CJK UNIFIED IDEOGRAPH-#24826, IRGKangXi=0717.111, RSKangXi=94.10
24827 CJK UNIFIED IDEOGRAPH-#24827, IRGKangXi=0717.111, RSKangXi=94.10
24828 CJK UNIFIED IDEOGRAPH-#24828, IRGKangXi=0717.111, RSKangXi=94.10
24829 CJK UNIFIED IDEOGRAPH-#24829, IRGKangXi=0717.111, RSKangXi=94.10
2482A CJK UNIFIED IDEOGRAPH-#2482A, IRGKangXi=0717.111, RSKangXi=94.10
2482B CJK UNIFIED IDEOGRAPH-#2482B, IRGKangXi=0717.111, RSKangXi=94.10
2482C CJK UNIFIED IDEOGRAPH-#2482C, IRGKangXi=0717.111, RSKangXi=94.10
2482D CJK UNIFIED IDEOGRAPH-#2482D, IRGKangXi=0717.111, RSKangXi=94.10
2482E CJK UNIFIED IDEOGRAPH-#2482E, IRGKangXi=0717.111, RSKangXi=94.10
2482F CJK UNIFIED IDEOGRAPH-#2482F, IRGKangXi=0717.111, RSKangXi=94.10
24830 CJK UNIFIED IDEOGRAPH-#24830, IRGKangXi=0717.111, RSKangXi=94.10
24831 CJK UNIFIED IDEOGRAPH-#24831, IRGKangXi=0717.111, RSKangXi=94.10
24832 CJK UNIFIED IDEOGRAPH-#24832, IRGKangXi=0717.111, RSKangXi=94.10
24833 CJK UNIFIED IDEOGRAPH-#24833, IRGKangXi=0717.111, RSKangXi=94.10
24834 CJK UNIFIED IDEOGRAPH-#24834, IRGKangXi=0717.111, RSKangXi=94.10
24835 CJK UNIFIED IDEOGRAPH-#24835, IRGKangXi=0717.111, RSKangXi=94.10
24836 CJK UNIFIED IDEOGRAPH-#24836, IRGKangXi=0717.111, RSKangXi=94.10
24837 CJK UNIFIED IDEOGRAPH-#24837, IRGKangXi=0717.111, RSKangXi=94.10
24838 CJK UNIFIED IDEOGRAPH-#24838, IRGKangXi=0717.111, RSKangXi=94.10
24839 CJK UNIFIED IDEOGRAPH-#24839, IRGKangXi=0717.120, RSKangXi=94.11
2483A CJK UNIFIED IDEOGRAPH-#2483A, IRGKangXi=0717.130, RSKangXi=94.11
2483B CJK UNIFIED IDEOGRAPH-#2483B, IRGKangXi=0717.140, RSKangXi=94.11
2483C CJK UNIFIED IDEOGRAPH-#2483C, IRGKangXi=0717.160, RSKangXi=94.11
2483D CJK UNIFIED IDEOGRAPH-#2483D, IRGKangXi=0717.170, RSKangXi=94.11
2483E CJK UNIFIED IDEOGRAPH-#2483E, IRGKangXi=0717.200, RSKangXi=94.11
2483F CJK UNIFIED IDEOGRAPH-#2483F, IRGKangXi=0717.210, RSKangXi=94.11
24840 CJK UNIFIED IDEOGRAPH-#24840, IRGKangXi=0717.220, RSKangXi=94.11
24841 CJK UNIFIED IDEOGRAPH-#24841, IRGKangXi=0717.240, RSKangXi=94.11
24842 CJK UNIFIED IDEOGRAPH-#24842, IRGKangXi=0717.250, RSKangXi=94.11
24843 CJK UNIFIED IDEOGRAPH-#24843, IRGKangXi=0717.270, RSKangXi=94.11
24844 CJK UNIFIED IDEOGRAPH-#24844, IRGKangXi=0717.310, RSKangXi=94.11
24845 CJK UNIFIED IDEOGRAPH-#24845, IRGKangXi=0717.320, RSKangXi=94.11
24846 CJK UNIFIED IDEOGRAPH-#24846, IRGKangXi=0717.330, RSKangXi=94.11
24847 CJK UNIFIED IDEOGRAPH-#24847, IRGKangXi=0718.040, RSKangXi=94.11
24848 CJK UNIFIED IDEOGRAPH-#24848, IRGKangXi=0718.041, RSKangXi=94.11
24849 CJK UNIFIED IDEOGRAPH-#24849, IRGKangXi=0718.041, RSKangXi=94.11
2484A CJK UNIFIED IDEOGRAPH-#2484A, IRGKangXi=0718.041, RSKangXi=94.11
2484B CJK UNIFIED IDEOGRAPH-#2484B, IRGKangXi=0718.041, RSKangXi=94.11
2484C CJK UNIFIED IDEOGRAPH-#2484C, IRGKangXi=0718.041, RSKangXi=94.11
2484D CJK UNIFIED IDEOGRAPH-#2484D, IRGKangXi=0718.041, RSKangXi=94.11
2484E CJK UNIFIED IDEOGRAPH-#2484E, IRGKangXi=0718.041, RSKangXi=94.11
2484F CJK UNIFIED IDEOGRAPH-#2484F, IRGKangXi=0718.041, RSKangXi=94.11
24850 CJK UNIFIED IDEOGRAPH-#24850, IRGKangXi=0718.041, RSKangXi=94.11
24851 CJK UNIFIED IDEOGRAPH-#24851, IRGKangXi=0718.041, RSKangXi=94.11
24852 CJK UNIFIED IDEOGRAPH-#24852, IRGKangXi=0718.041, RSKangXi=94.11
24853 CJK UNIFIED IDEOGRAPH-#24853, IRGKangXi=0718.041, RSKangXi=94.11
24854 CJK UNIFIED IDEOGRAPH-#24854, IRGKangXi=0718.041, RSKangXi=94.11
24855 CJK UNIFIED IDEOGRAPH-#24855, IRGKangXi=0718.041, RSKangXi=94.11
24856 CJK UNIFIED IDEOGRAPH-#24856, IRGKangXi=0718.041, RSKangXi=94.11
24857 CJK UNIFIED IDEOGRAPH-#24857, IRGKangXi=0718.041, RSKangXi=94.11
24858 CJK UNIFIED IDEOGRAPH-#24858, IRGKangXi=0718.041, RSKangXi=94.11
24859 CJK UNIFIED IDEOGRAPH-#24859, IRGKangXi=0718.041, RSKangXi=94.11
2485A CJK UNIFIED IDEOGRAPH-#2485A, IRGKangXi=0718.041, RSKangXi=94.11
2485B CJK UNIFIED IDEOGRAPH-#2485B, IRGKangXi=0718.041, RSKangXi=94.11
2485C CJK UNIFIED IDEOGRAPH-#2485C, IRGKangXi=0718.041, RSKangXi=94.11
2485D CJK UNIFIED IDEOGRAPH-#2485D, IRGKangXi=0718.041, RSKangXi=94.11
2485E CJK UNIFIED IDEOGRAPH-#2485E, IRGKangXi=0718.041, RSKangXi=94.11
2485F CJK UNIFIED IDEOGRAPH-#2485F, IRGKangXi=0718.041, RSKangXi=94.11
24860 CJK UNIFIED IDEOGRAPH-#24860, IRGKangXi=0718.041, RSKangXi=94.11
24861 CJK UNIFIED IDEOGRAPH-#24861, IRGKangXi=0718.041, RSKangXi=94.11
24862 CJK UNIFIED IDEOGRAPH-#24862, IRGKangXi=0718.041, RSKangXi=94.11
24863 CJK UNIFIED IDEOGRAPH-#24863, IRGKangXi=0718.050, RSKangXi=94.12
24864 CJK UNIFIED IDEOGRAPH-#24864, IRGKangXi=0718.070, RSKangXi=94.12
24865 CJK UNIFIED IDEOGRAPH-#24865, IRGKangXi=0718.110, RSKangXi=94.12
24866 CJK UNIFIED IDEOGRAPH-#24866, IRGKangXi=0718.120, RSKangXi=94.12
24867 CJK UNIFIED IDEOGRAPH-#24867, IRGKangXi=0718.140, RSKangXi=94.12
24868 CJK UNIFIED IDEOGRAPH-#24868, IRGKangXi=0718.150, RSKangXi=94.12
24869 CJK UNIFIED IDEOGRAPH-#24869, IRGKangXi=0718.180, RSKangXi=94.12
2486A CJK UNIFIED IDEOGRAPH-#2486A, IRGKangXi=0718.200, RSKangXi=94.12
2486B CJK UNIFIED IDEOGRAPH-#2486B, IRGKangXi=0718.220, RSKangXi=94.12
2486C CJK UNIFIED IDEOGRAPH-#2486C, IRGKangXi=0718.250, RSKangXi=94.12
2486D CJK UNIFIED IDEOGRAPH-#2486D, IRGKangXi=0718.280, RSKangXi=94.12
2486E CJK UNIFIED IDEOGRAPH-#2486E, IRGKangXi=0719.010, RSKangXi=94.12, Def{a kind of monkey}
2486F CJK UNIFIED IDEOGRAPH-#2486F, IRGKangXi=0719.020, RSKangXi=94.12
24870 CJK UNIFIED IDEOGRAPH-#24870, IRGKangXi=0719.041, RSKangXi=94.12
24871 CJK UNIFIED IDEOGRAPH-#24871, IRGKangXi=0719.050, RSKangXi=94.12
24872 CJK UNIFIED IDEOGRAPH-#24872, IRGKangXi=0719.070, RSKangXi=94.12
24873 CJK UNIFIED IDEOGRAPH-#24873, IRGKangXi=0719.080, RSKangXi=94.12
24874 CJK UNIFIED IDEOGRAPH-#24874, IRGKangXi=0719.090, RSKangXi=94.12
24875 CJK UNIFIED IDEOGRAPH-#24875, IRGKangXi=0719.120, RSKangXi=94.12
24876 CJK UNIFIED IDEOGRAPH-#24876, IRGKangXi=0719.130, RSKangXi=94.12
24877 CJK UNIFIED IDEOGRAPH-#24877, IRGKangXi=0719.131, RSKangXi=94.12
24878 CJK UNIFIED IDEOGRAPH-#24878, IRGKangXi=0719.131, RSKangXi=94.12
24879 CJK UNIFIED IDEOGRAPH-#24879, IRGKangXi=0719.131, RSKangXi=94.12
2487A CJK UNIFIED IDEOGRAPH-#2487A, IRGKangXi=0719.131, RSKangXi=94.12
2487B CJK UNIFIED IDEOGRAPH-#2487B, IRGKangXi=0719.131, RSKangXi=94.12
2487C CJK UNIFIED IDEOGRAPH-#2487C, IRGKangXi=0719.131, RSKangXi=94.12
2487D CJK UNIFIED IDEOGRAPH-#2487D, IRGKangXi=0719.131, RSKangXi=94.12
2487E CJK UNIFIED IDEOGRAPH-#2487E, IRGKangXi=0719.131, RSKangXi=94.12
2487F CJK UNIFIED IDEOGRAPH-#2487F, IRGKangXi=0719.131, RSKangXi=94.12
24880 CJK UNIFIED IDEOGRAPH-#24880, IRGKangXi=0719.131, RSKangXi=94.12
24881 CJK UNIFIED IDEOGRAPH-#24881, IRGKangXi=0719.131, RSKangXi=94.12
24882 CJK UNIFIED IDEOGRAPH-#24882, IRGKangXi=0719.131, RSKangXi=94.12
24883 CJK UNIFIED IDEOGRAPH-#24883, IRGKangXi=0719.131, RSKangXi=94.12
24884 CJK UNIFIED IDEOGRAPH-#24884, IRGKangXi=0719.131, RSKangXi=94.12
24885 CJK UNIFIED IDEOGRAPH-#24885, IRGKangXi=0719.131, RSKangXi=94.12
24886 CJK UNIFIED IDEOGRAPH-#24886, IRGKangXi=0719.131, RSKangXi=94.12
24887 CJK UNIFIED IDEOGRAPH-#24887, IRGKangXi=0719.131, RSKangXi=94.12
24888 CJK UNIFIED IDEOGRAPH-#24888, IRGKangXi=0719.131, RSKangXi=94.12
24889 CJK UNIFIED IDEOGRAPH-#24889, IRGKangXi=0719.131, RSKangXi=94.12
2488A CJK UNIFIED IDEOGRAPH-#2488A, IRGKangXi=0719.131, RSKangXi=94.12
2488B CJK UNIFIED IDEOGRAPH-#2488B, IRGKangXi=0719.131, RSKangXi=94.12
2488C CJK UNIFIED IDEOGRAPH-#2488C, IRGKangXi=0719.140, RSKangXi=94.13
2488D CJK UNIFIED IDEOGRAPH-#2488D, IRGKangXi=0719.160, RSKangXi=94.13
2488E CJK UNIFIED IDEOGRAPH-#2488E, IRGKangXi=0719.180, RSKangXi=94.13
2488F CJK UNIFIED IDEOGRAPH-#2488F, IRGKangXi=0719.190, RSKangXi=94.13
24890 CJK UNIFIED IDEOGRAPH-#24890, IRGKangXi=0719.260, RSKangXi=94.13
24891 CJK UNIFIED IDEOGRAPH-#24891, IRGKangXi=0719.300, RSKangXi=94.13
24892 CJK UNIFIED IDEOGRAPH-#24892, IRGKangXi=0719.310, RSKangXi=94.13
24893 CJK UNIFIED IDEOGRAPH-#24893, IRGKangXi=0719.320, RSKangXi=94.13
24894 CJK UNIFIED IDEOGRAPH-#24894, IRGKangXi=0720.010, RSKangXi=94.13
24895 CJK UNIFIED IDEOGRAPH-#24895, IRGKangXi=0720.020, RSKangXi=94.13, Def{to ruin; to tire of; to explain}
24896 CJK UNIFIED IDEOGRAPH-#24896, IRGKangXi=0720.030, RSKangXi=94.13
24897 CJK UNIFIED IDEOGRAPH-#24897, IRGKangXi=0720.040, RSKangXi=94.13
24898 CJK UNIFIED IDEOGRAPH-#24898, IRGKangXi=0720.050, RSKangXi=94.13
24899 CJK UNIFIED IDEOGRAPH-#24899, IRGKangXi=0720.060, RSKangXi=94.13
2489A CJK UNIFIED IDEOGRAPH-#2489A, IRGKangXi=0720.070, RSKangXi=94.16
2489B CJK UNIFIED IDEOGRAPH-#2489B, IRGKangXi=0720.071, RSKangXi=94.13
2489C CJK UNIFIED IDEOGRAPH-#2489C, IRGKangXi=0720.071, RSKangXi=94.13
2489D CJK UNIFIED IDEOGRAPH-#2489D, IRGKangXi=0720.071, RSKangXi=94.13
2489E CJK UNIFIED IDEOGRAPH-#2489E, IRGKangXi=0720.071, RSKangXi=94.13
2489F CJK UNIFIED IDEOGRAPH-#2489F, IRGKangXi=0720.071, RSKangXi=94.13
248A0 CJK UNIFIED IDEOGRAPH-#248A0, IRGKangXi=0720.071, RSKangXi=94.13
248A1 CJK UNIFIED IDEOGRAPH-#248A1, IRGKangXi=0720.071, RSKangXi=94.13
248A2 CJK UNIFIED IDEOGRAPH-#248A2, IRGKangXi=0720.071, RSKangXi=94.13
248A3 CJK UNIFIED IDEOGRAPH-#248A3, IRGKangXi=0720.071, RSKangXi=94.13
248A4 CJK UNIFIED IDEOGRAPH-#248A4, IRGKangXi=0720.071, RSKangXi=94.13
248A5 CJK UNIFIED IDEOGRAPH-#248A5, IRGKangXi=0720.071, RSKangXi=94.13
248A6 CJK UNIFIED IDEOGRAPH-#248A6, IRGKangXi=0720.100, RSKangXi=94.14
248A7 CJK UNIFIED IDEOGRAPH-#248A7, IRGKangXi=0720.110, RSKangXi=94.14
248A8 CJK UNIFIED IDEOGRAPH-#248A8, IRGKangXi=0720.130, RSKangXi=94.14
248A9 CJK UNIFIED IDEOGRAPH-#248A9, IRGKangXi=0720.140, RSKangXi=94.14
248AA CJK UNIFIED IDEOGRAPH-#248AA, IRGKangXi=0720.200, RSKangXi=94.14, Def{to hunt}
248AB CJK UNIFIED IDEOGRAPH-#248AB, IRGKangXi=0720.211, RSKangXi=94.14
248AC CJK UNIFIED IDEOGRAPH-#248AC, IRGKangXi=0720.211, RSKangXi=94.14
248AD CJK UNIFIED IDEOGRAPH-#248AD, IRGKangXi=0720.221, RSKangXi=94.14
248AE CJK UNIFIED IDEOGRAPH-#248AE, IRGKangXi=0720.221, RSKangXi=94.14
248AF CJK UNIFIED IDEOGRAPH-#248AF, IRGKangXi=0720.221, RSKangXi=94.14
248B0 CJK UNIFIED IDEOGRAPH-#248B0, IRGKangXi=0720.221, RSKangXi=94.14
248B1 CJK UNIFIED IDEOGRAPH-#248B1, IRGKangXi=0720.221, RSKangXi=94.14
248B2 CJK UNIFIED IDEOGRAPH-#248B2, IRGKangXi=0720.221, RSKangXi=94.14
248B3 CJK UNIFIED IDEOGRAPH-#248B3, IRGKangXi=0720.221, RSKangXi=94.14
248B4 CJK UNIFIED IDEOGRAPH-#248B4, IRGKangXi=0720.230, RSKangXi=94.15
248B5 CJK UNIFIED IDEOGRAPH-#248B5, IRGKangXi=0720.240, RSKangXi=94.15
248B6 CJK UNIFIED IDEOGRAPH-#248B6, IRGKangXi=0720.250, RSKangXi=94.15
248B7 CJK UNIFIED IDEOGRAPH-#248B7, IRGKangXi=0720.260, RSKangXi=94.15
248B8 CJK UNIFIED IDEOGRAPH-#248B8, IRGKangXi=0720.280, RSKangXi=94.15
248B9 CJK UNIFIED IDEOGRAPH-#248B9, IRGKangXi=0720.300, RSKangXi=94.15
248BA CJK UNIFIED IDEOGRAPH-#248BA, IRGKangXi=0720.310, RSKangXi=94.15
248BB CJK UNIFIED IDEOGRAPH-#248BB, IRGKangXi=0721.031, RSKangXi=94.15
248BC CJK UNIFIED IDEOGRAPH-#248BC, IRGKangXi=0721.031, RSKangXi=94.15
248BD CJK UNIFIED IDEOGRAPH-#248BD, IRGKangXi=0721.031, RSKangXi=94.15
248BE CJK UNIFIED IDEOGRAPH-#248BE, IRGKangXi=0721.031, RSKangXi=94.15
248BF CJK UNIFIED IDEOGRAPH-#248BF, IRGKangXi=0721.031, RSKangXi=94.15
248C0 CJK UNIFIED IDEOGRAPH-#248C0, IRGKangXi=0721.031, RSKangXi=94.15
248C1 CJK UNIFIED IDEOGRAPH-#248C1, IRGKangXi=0721.031, RSKangXi=94.15
248C2 CJK UNIFIED IDEOGRAPH-#248C2, IRGKangXi=0721.031, RSKangXi=94.15
248C3 CJK UNIFIED IDEOGRAPH-#248C3, IRGKangXi=0721.031, RSKangXi=94.15
248C4 CJK UNIFIED IDEOGRAPH-#248C4, IRGKangXi=0721.031, RSKangXi=94.15
248C5 CJK UNIFIED IDEOGRAPH-#248C5, IRGKangXi=0721.050, RSKangXi=94.16
248C6 CJK UNIFIED IDEOGRAPH-#248C6, IRGKangXi=0721.070, RSKangXi=94.16
248C7 CJK UNIFIED IDEOGRAPH-#248C7, IRGKangXi=0721.100, RSKangXi=94.16
248C8 CJK UNIFIED IDEOGRAPH-#248C8, IRGKangXi=0721.101, RSKangXi=94.16
248C9 CJK UNIFIED IDEOGRAPH-#248C9, IRGKangXi=0721.101, RSKangXi=94.16
248CA CJK UNIFIED IDEOGRAPH-#248CA, IRGKangXi=0721.101, RSKangXi=94.16
248CB CJK UNIFIED IDEOGRAPH-#248CB, IRGKangXi=0721.101, RSKangXi=94.16
248CC CJK UNIFIED IDEOGRAPH-#248CC, IRGKangXi=0721.101, RSKangXi=94.16
248CD CJK UNIFIED IDEOGRAPH-#248CD, IRGKangXi=0721.140, RSKangXi=94.17
248CE CJK UNIFIED IDEOGRAPH-#248CE, IRGKangXi=0721.170, RSKangXi=94.17
248CF CJK UNIFIED IDEOGRAPH-#248CF, IRGKangXi=0721.171, RSKangXi=94.17
248D0 CJK UNIFIED IDEOGRAPH-#248D0, IRGKangXi=0721.171, RSKangXi=94.17
248D1 CJK UNIFIED IDEOGRAPH-#248D1, IRGKangXi=0721.180, RSKangXi=94.18
248D2 CJK UNIFIED IDEOGRAPH-#248D2, IRGKangXi=0721.190, RSKangXi=94.18
248D3 CJK UNIFIED IDEOGRAPH-#248D3, IRGKangXi=0721.200, RSKangXi=94.18
248D4 CJK UNIFIED IDEOGRAPH-#248D4, IRGKangXi=0721.220, RSKangXi=94.18
248D5 CJK UNIFIED IDEOGRAPH-#248D5, IRGKangXi=0721.231, RSKangXi=94.18
248D6 CJK UNIFIED IDEOGRAPH-#248D6, IRGKangXi=0721.231, RSKangXi=94.18
248D7 CJK UNIFIED IDEOGRAPH-#248D7, IRGKangXi=0721.231, RSKangXi=94.19
248D8 CJK UNIFIED IDEOGRAPH-#248D8, IRGKangXi=0721.231, RSKangXi=94.19
248D9 CJK UNIFIED IDEOGRAPH-#248D9, IRGKangXi=0721.231, RSKangXi=94.19
248DA CJK UNIFIED IDEOGRAPH-#248DA, IRGKangXi=0721.231, RSKangXi=94.19
248DB CJK UNIFIED IDEOGRAPH-#248DB, IRGKangXi=0722.020, RSKangXi=94.20
248DC CJK UNIFIED IDEOGRAPH-#248DC, IRGKangXi=0722.050, RSKangXi=94.20
248DD CJK UNIFIED IDEOGRAPH-#248DD, IRGKangXi=0722.051, RSKangXi=94.20
248DE CJK UNIFIED IDEOGRAPH-#248DE, IRGKangXi=0722.051, RSKangXi=94.20
248DF CJK UNIFIED IDEOGRAPH-#248DF, IRGKangXi=0722.060, RSKangXi=94.21
248E0 CJK UNIFIED IDEOGRAPH-#248E0, IRGKangXi=0722.070, RSKangXi=94.21
248E1 CJK UNIFIED IDEOGRAPH-#248E1, IRGKangXi=0722.071, RSKangXi=94.21
248E2 CJK UNIFIED IDEOGRAPH-#248E2, IRGKangXi=0722.071, RSKangXi=94.21
248E3 CJK UNIFIED IDEOGRAPH-#248E3, IRGKangXi=0722.080, RSKangXi=94.22
248E4 CJK UNIFIED IDEOGRAPH-#248E4, IRGKangXi=0722.090, RSKangXi=94.24
248E5 CJK UNIFIED IDEOGRAPH-#248E5, IRGKangXi=0725.010, RSKangXi=95.-1
248E6 CJK UNIFIED IDEOGRAPH-#248E6, IRGKangXi=0725.021, RSKangXi=95.4
248E7 CJK UNIFIED IDEOGRAPH-#248E7, IRGKangXi=0726.020, RSKangXi=95.7
248E8 CJK UNIFIED IDEOGRAPH-#248E8, IRGKangXi=0726.030, RSKangXi=95.9
248E9 CJK UNIFIED IDEOGRAPH-#248E9, IRGKangXi=0727.021, RSKangXi=96.0
248EA CJK UNIFIED IDEOGRAPH-#248EA, IRGKangXi=0727.030, RSKangXi=96.2
248EB CJK UNIFIED IDEOGRAPH-#248EB, IRGKangXi=0727.041, RSKangXi=96.2
248EC CJK UNIFIED IDEOGRAPH-#248EC, IRGKangXi=0727.101, RSKangXi=96.2
248ED CJK UNIFIED IDEOGRAPH-#248ED, IRGKangXi=0727.130, RSKangXi=96.3
248EE CJK UNIFIED IDEOGRAPH-#248EE, IRGKangXi=0727.140, RSKangXi=96.3
248EF CJK UNIFIED IDEOGRAPH-#248EF, IRGKangXi=0727.150, RSKangXi=96.3
248F0 CJK UNIFIED IDEOGRAPH-#248F0, IRGKangXi=0727.170, RSKangXi=96.3
248F1 CJK UNIFIED IDEOGRAPH-#248F1, IRGKangXi=0727.240, RSKangXi=96.3
248F2 CJK UNIFIED IDEOGRAPH-#248F2, IRGKangXi=0727.251, RSKangXi=96.3
248F3 CJK UNIFIED IDEOGRAPH-#248F3, IRGKangXi=0727.251, RSKangXi=96.3
248F4 CJK UNIFIED IDEOGRAPH-#248F4, IRGKangXi=0727.251, RSKangXi=96.3
248F5 CJK UNIFIED IDEOGRAPH-#248F5, IRGKangXi=0727.251, RSKangXi=96.3
248F6 CJK UNIFIED IDEOGRAPH-#248F6, IRGKangXi=0727.251, RSKangXi=96.3
248F7 CJK UNIFIED IDEOGRAPH-#248F7, IRGKangXi=0727.251, RSKangXi=96.3
248F8 CJK UNIFIED IDEOGRAPH-#248F8, IRGKangXi=0727.251, RSKangXi=96.3
248F9 CJK UNIFIED IDEOGRAPH-#248F9, IRGKangXi=0727.260, RSKangXi=96.4
248FA CJK UNIFIED IDEOGRAPH-#248FA, IRGKangXi=0727.270, RSKangXi=96.4
248FB CJK UNIFIED IDEOGRAPH-#248FB, IRGKangXi=0728.090, RSKangXi=96.4
248FC CJK UNIFIED IDEOGRAPH-#248FC, IRGKangXi=0728.190, RSKangXi=96.4
248FD CJK UNIFIED IDEOGRAPH-#248FD, IRGKangXi=0728.200, RSKangXi=96.4
248FE CJK UNIFIED IDEOGRAPH-#248FE, IRGKangXi=0728.211, RSKangXi=96.4
248FF CJK UNIFIED IDEOGRAPH-#248FF, IRGKangXi=0728.211, RSKangXi=96.4
24900 CJK UNIFIED IDEOGRAPH-#24900, IRGKangXi=0728.211, RSKangXi=96.4
24901 CJK UNIFIED IDEOGRAPH-#24901, IRGKangXi=0728.211, RSKangXi=96.4
24902 CJK UNIFIED IDEOGRAPH-#24902, IRGKangXi=0728.211, RSKangXi=96.4
24903 CJK UNIFIED IDEOGRAPH-#24903, IRGKangXi=0728.211, RSKangXi=96.4
24904 CJK UNIFIED IDEOGRAPH-#24904, IRGKangXi=0728.211, RSKangXi=96.4
24905 CJK UNIFIED IDEOGRAPH-#24905, IRGKangXi=0728.211, RSKangXi=96.4
24906 CJK UNIFIED IDEOGRAPH-#24906, IRGKangXi=0728.211, RSKangXi=96.4
24907 CJK UNIFIED IDEOGRAPH-#24907, IRGKangXi=0728.211, RSKangXi=96.4
24908 CJK UNIFIED IDEOGRAPH-#24908, IRGKangXi=0728.211, RSKangXi=96.4
24909 CJK UNIFIED IDEOGRAPH-#24909, IRGKangXi=0728.211, RSKangXi=96.4
2490A CJK UNIFIED IDEOGRAPH-#2490A, IRGKangXi=0728.211, RSKangXi=96.4
2490B CJK UNIFIED IDEOGRAPH-#2490B, IRGKangXi=0728.211, RSKangXi=96.4
2490C CJK UNIFIED IDEOGRAPH-#2490C, IRGKangXi=0728.211, RSKangXi=96.4
2490D CJK UNIFIED IDEOGRAPH-#2490D, IRGKangXi=0728.211, RSKangXi=96.4
2490E CJK UNIFIED IDEOGRAPH-#2490E, IRGKangXi=0728.211, RSKangXi=96.4
2490F CJK UNIFIED IDEOGRAPH-#2490F, IRGKangXi=0728.220, RSKangXi=96.5
24910 CJK UNIFIED IDEOGRAPH-#24910, IRGKangXi=0729.020, RSKangXi=96.5
24911 CJK UNIFIED IDEOGRAPH-#24911, IRGKangXi=0729.170, RSKangXi=96.5
24912 CJK UNIFIED IDEOGRAPH-#24912, IRGKangXi=0729.190, RSKangXi=96.5
24913 CJK UNIFIED IDEOGRAPH-#24913, IRGKangXi=0730.080, RSKangXi=96.5
24914 CJK UNIFIED IDEOGRAPH-#24914, IRGKangXi=0730.081, RSKangXi=96.5
24915 CJK UNIFIED IDEOGRAPH-#24915, IRGKangXi=0730.081, RSKangXi=96.5
24916 CJK UNIFIED IDEOGRAPH-#24916, IRGKangXi=0730.081, RSKangXi=96.5
24917 CJK UNIFIED IDEOGRAPH-#24917, IRGKangXi=0730.081, RSKangXi=96.5
24918 CJK UNIFIED IDEOGRAPH-#24918, IRGKangXi=0730.081, RSKangXi=96.5
24919 CJK UNIFIED IDEOGRAPH-#24919, IRGKangXi=0730.081, RSKangXi=96.5
2491A CJK UNIFIED IDEOGRAPH-#2491A, IRGKangXi=0730.081, RSKangXi=96.5
2491B CJK UNIFIED IDEOGRAPH-#2491B, IRGKangXi=0730.081, RSKangXi=96.5
2491C CJK UNIFIED IDEOGRAPH-#2491C, IRGKangXi=0730.081, RSKangXi=96.5
2491D CJK UNIFIED IDEOGRAPH-#2491D, IRGKangXi=0730.081, RSKangXi=96.5
2491E CJK UNIFIED IDEOGRAPH-#2491E, IRGKangXi=0730.081, RSKangXi=96.5
2491F CJK UNIFIED IDEOGRAPH-#2491F, IRGKangXi=0730.081, RSKangXi=96.5
24920 CJK UNIFIED IDEOGRAPH-#24920, IRGKangXi=0730.081, RSKangXi=96.5
24921 CJK UNIFIED IDEOGRAPH-#24921, IRGKangXi=0730.081, RSKangXi=96.5
24922 CJK UNIFIED IDEOGRAPH-#24922, IRGKangXi=0730.081, RSKangXi=96.5
24923 CJK UNIFIED IDEOGRAPH-#24923, IRGKangXi=0730.081, RSKangXi=96.5
24924 CJK UNIFIED IDEOGRAPH-#24924, IRGKangXi=0730.081, RSKangXi=96.5
24925 CJK UNIFIED IDEOGRAPH-#24925, IRGKangXi=0730.081, RSKangXi=96.5
24926 CJK UNIFIED IDEOGRAPH-#24926, IRGKangXi=0730.081, RSKangXi=96.5
24927 CJK UNIFIED IDEOGRAPH-#24927, IRGKangXi=0730.081, RSKangXi=96.5
24928 CJK UNIFIED IDEOGRAPH-#24928, IRGKangXi=0730.081, RSKangXi=96.5
24929 CJK UNIFIED IDEOGRAPH-#24929, IRGKangXi=0730.081, RSKangXi=96.5
2492A CJK UNIFIED IDEOGRAPH-#2492A, IRGKangXi=0730.081, RSKangXi=96.5
2492B CJK UNIFIED IDEOGRAPH-#2492B, IRGKangXi=0730.081, RSKangXi=96.5
2492C CJK UNIFIED IDEOGRAPH-#2492C, IRGKangXi=0730.081, RSKangXi=96.5
2492D CJK UNIFIED IDEOGRAPH-#2492D, IRGKangXi=0730.081, RSKangXi=96.5
2492E CJK UNIFIED IDEOGRAPH-#2492E, IRGKangXi=0730.081, RSKangXi=96.5
2492F CJK UNIFIED IDEOGRAPH-#2492F, IRGKangXi=0730.081, RSKangXi=96.5
24930 CJK UNIFIED IDEOGRAPH-#24930, IRGKangXi=0730.081, RSKangXi=96.5
24931 CJK UNIFIED IDEOGRAPH-#24931, IRGKangXi=0730.081, RSKangXi=96.5
24932 CJK UNIFIED IDEOGRAPH-#24932, IRGKangXi=0730.081, RSKangXi=96.5
24933 CJK UNIFIED IDEOGRAPH-#24933, IRGKangXi=0730.081, RSKangXi=96.5
24934 CJK UNIFIED IDEOGRAPH-#24934, IRGKangXi=0730.081, RSKangXi=96.5
24935 CJK UNIFIED IDEOGRAPH-#24935, IRGKangXi=0730.120, RSKangXi=96.6
24936 CJK UNIFIED IDEOGRAPH-#24936, IRGKangXi=0730.150, RSKangXi=96.6
24937 CJK UNIFIED IDEOGRAPH-#24937, IRGKangXi=0730.200, RSKangXi=96.6
24938 CJK UNIFIED IDEOGRAPH-#24938, IRGKangXi=0730.220, RSKangXi=96.6
24939 CJK UNIFIED IDEOGRAPH-#24939, IRGKangXi=0731.040, RSKangXi=96.6
2493A CJK UNIFIED IDEOGRAPH-#2493A, IRGKangXi=0731.100, RSKangXi=96.6
2493B CJK UNIFIED IDEOGRAPH-#2493B, IRGKangXi=0731.180, RSKangXi=96.6
2493C CJK UNIFIED IDEOGRAPH-#2493C, IRGKangXi=0732.020, RSKangXi=96.6
2493D CJK UNIFIED IDEOGRAPH-#2493D, IRGKangXi=0732.021, RSKangXi=96.6
2493E CJK UNIFIED IDEOGRAPH-#2493E, IRGKangXi=0732.021, RSKangXi=96.6
2493F CJK UNIFIED IDEOGRAPH-#2493F, IRGKangXi=0732.021, RSKangXi=96.6
24940 CJK UNIFIED IDEOGRAPH-#24940, IRGKangXi=0732.021, RSKangXi=96.6
24941 CJK UNIFIED IDEOGRAPH-#24941, IRGKangXi=0732.021, RSKangXi=96.6
24942 CJK UNIFIED IDEOGRAPH-#24942, IRGKangXi=0732.021, RSKangXi=96.6
24943 CJK UNIFIED IDEOGRAPH-#24943, IRGKangXi=0732.021, RSKangXi=96.6
24944 CJK UNIFIED IDEOGRAPH-#24944, IRGKangXi=0732.021, RSKangXi=96.6
24945 CJK UNIFIED IDEOGRAPH-#24945, IRGKangXi=0732.021, RSKangXi=96.6
24946 CJK UNIFIED IDEOGRAPH-#24946, IRGKangXi=0732.021, RSKangXi=96.6
24947 CJK UNIFIED IDEOGRAPH-#24947, IRGKangXi=0732.021, RSKangXi=96.6
24948 CJK UNIFIED IDEOGRAPH-#24948, IRGKangXi=0732.021, RSKangXi=96.6
24949 CJK UNIFIED IDEOGRAPH-#24949, IRGKangXi=0732.021, RSKangXi=96.6
2494A CJK UNIFIED IDEOGRAPH-#2494A, IRGKangXi=0732.021, RSKangXi=96.6
2494B CJK UNIFIED IDEOGRAPH-#2494B, IRGKangXi=0732.021, RSKangXi=96.6
2494C CJK UNIFIED IDEOGRAPH-#2494C, IRGKangXi=0732.021, RSKangXi=96.6
2494D CJK UNIFIED IDEOGRAPH-#2494D, IRGKangXi=0732.021, RSKangXi=96.6
2494E CJK UNIFIED IDEOGRAPH-#2494E, IRGKangXi=0732.021, RSKangXi=96.6
2494F CJK UNIFIED IDEOGRAPH-#2494F, IRGKangXi=0732.021, RSKangXi=96.6
24950 CJK UNIFIED IDEOGRAPH-#24950, IRGKangXi=0732.021, RSKangXi=96.6
24951 CJK UNIFIED IDEOGRAPH-#24951, IRGKangXi=0732.021, RSKangXi=96.6
24952 CJK UNIFIED IDEOGRAPH-#24952, IRGKangXi=0732.021, RSKangXi=96.6
24953 CJK UNIFIED IDEOGRAPH-#24953, IRGKangXi=0732.021, RSKangXi=96.6
24954 CJK UNIFIED IDEOGRAPH-#24954, IRGKangXi=0732.021, RSKangXi=96.6
24955 CJK UNIFIED IDEOGRAPH-#24955, IRGKangXi=0732.021, RSKangXi=96.6
24956 CJK UNIFIED IDEOGRAPH-#24956, IRGKangXi=0732.040, RSKangXi=96.7
24957 CJK UNIFIED IDEOGRAPH-#24957, IRGKangXi=0732.090, RSKangXi=96.7
24958 CJK UNIFIED IDEOGRAPH-#24958, IRGKangXi=0732.170, RSKangXi=96.7
24959 CJK UNIFIED IDEOGRAPH-#24959, IRGKangXi=0732.200, RSKangXi=96.7
2495A CJK UNIFIED IDEOGRAPH-#2495A, IRGKangXi=0732.230, RSKangXi=96.7
2495B CJK UNIFIED IDEOGRAPH-#2495B, IRGKangXi=0733.100, RSKangXi=96.7
2495C CJK UNIFIED IDEOGRAPH-#2495C, IRGKangXi=0733.110, RSKangXi=96.7
2495D CJK UNIFIED IDEOGRAPH-#2495D, IRGKangXi=0733.130, RSKangXi=96.7
2495E CJK UNIFIED IDEOGRAPH-#2495E, IRGKangXi=0733.140, RSKangXi=96.7
2495F CJK UNIFIED IDEOGRAPH-#2495F, IRGKangXi=0733.151, RSKangXi=96.7
24960 CJK UNIFIED IDEOGRAPH-#24960, IRGKangXi=0733.151, RSKangXi=96.7
24961 CJK UNIFIED IDEOGRAPH-#24961, IRGKangXi=0733.151, RSKangXi=96.7
24962 CJK UNIFIED IDEOGRAPH-#24962, IRGKangXi=0733.151, RSKangXi=96.7
24963 CJK UNIFIED IDEOGRAPH-#24963, IRGKangXi=0733.151, RSKangXi=96.7
24964 CJK UNIFIED IDEOGRAPH-#24964, IRGKangXi=0733.151, RSKangXi=96.7
24965 CJK UNIFIED IDEOGRAPH-#24965, IRGKangXi=0733.151, RSKangXi=96.7
24966 CJK UNIFIED IDEOGRAPH-#24966, IRGKangXi=0733.151, RSKangXi=96.7
24967 CJK UNIFIED IDEOGRAPH-#24967, IRGKangXi=0733.151, RSKangXi=96.7
24968 CJK UNIFIED IDEOGRAPH-#24968, IRGKangXi=0733.151, RSKangXi=96.7
24969 CJK UNIFIED IDEOGRAPH-#24969, IRGKangXi=0733.151, RSKangXi=96.7
2496A CJK UNIFIED IDEOGRAPH-#2496A, IRGKangXi=0733.151, RSKangXi=96.7
2496B CJK UNIFIED IDEOGRAPH-#2496B, IRGKangXi=0733.151, RSKangXi=96.7
2496C CJK UNIFIED IDEOGRAPH-#2496C, IRGKangXi=0733.151, RSKangXi=96.7
2496D CJK UNIFIED IDEOGRAPH-#2496D, IRGKangXi=0733.151, RSKangXi=96.7
2496E CJK UNIFIED IDEOGRAPH-#2496E, IRGKangXi=0733.151, RSKangXi=96.7
2496F CJK UNIFIED IDEOGRAPH-#2496F, IRGKangXi=0733.151, RSKangXi=96.7
24970 CJK UNIFIED IDEOGRAPH-#24970, IRGKangXi=0733.151, RSKangXi=96.7
24971 CJK UNIFIED IDEOGRAPH-#24971, IRGKangXi=0733.151, RSKangXi=96.7
24972 CJK UNIFIED IDEOGRAPH-#24972, IRGKangXi=0733.151, RSKangXi=96.7
24973 CJK UNIFIED IDEOGRAPH-#24973, IRGKangXi=0733.151, RSKangXi=96.7
24974 CJK UNIFIED IDEOGRAPH-#24974, IRGKangXi=0733.151, RSKangXi=96.7
24975 CJK UNIFIED IDEOGRAPH-#24975, IRGKangXi=0733.151, RSKangXi=96.7
24976 CJK UNIFIED IDEOGRAPH-#24976, IRGKangXi=0733.151, RSKangXi=96.7
24977 CJK UNIFIED IDEOGRAPH-#24977, IRGKangXi=0733.151, RSKangXi=96.7
24978 CJK UNIFIED IDEOGRAPH-#24978, IRGKangXi=0733.151, RSKangXi=96.7
24979 CJK UNIFIED IDEOGRAPH-#24979, IRGKangXi=0733.151, RSKangXi=96.7
2497A CJK UNIFIED IDEOGRAPH-#2497A, IRGKangXi=0733.151, RSKangXi=96.7
2497B CJK UNIFIED IDEOGRAPH-#2497B, IRGKangXi=0733.151, RSKangXi=96.8
2497C CJK UNIFIED IDEOGRAPH-#2497C, IRGKangXi=0733.210, RSKangXi=96.8
2497D CJK UNIFIED IDEOGRAPH-#2497D, IRGKangXi=0733.220, RSKangXi=96.8
2497E CJK UNIFIED IDEOGRAPH-#2497E, IRGKangXi=0734.010, RSKangXi=96.8
2497F CJK UNIFIED IDEOGRAPH-#2497F, IRGKangXi=0734.020, RSKangXi=96.8
24980 CJK UNIFIED IDEOGRAPH-#24980, IRGKangXi=0734.100, RSKangXi=96.8
24981 CJK UNIFIED IDEOGRAPH-#24981, IRGKangXi=0734.240, RSKangXi=96.8
24982 CJK UNIFIED IDEOGRAPH-#24982, IRGKangXi=0736.030, RSKangXi=96.8
24983 CJK UNIFIED IDEOGRAPH-#24983, IRGKangXi=0736.040, RSKangXi=96.8
24984 CJK UNIFIED IDEOGRAPH-#24984, IRGKangXi=0736.050, RSKangXi=96.8
24985 CJK UNIFIED IDEOGRAPH-#24985, IRGKangXi=0736.081, RSKangXi=96.8
24986 CJK UNIFIED IDEOGRAPH-#24986, IRGKangXi=0736.081, RSKangXi=96.8
24987 CJK UNIFIED IDEOGRAPH-#24987, IRGKangXi=0736.081, RSKangXi=96.8
24988 CJK UNIFIED IDEOGRAPH-#24988, IRGKangXi=0736.081, RSKangXi=96.8
24989 CJK UNIFIED IDEOGRAPH-#24989, IRGKangXi=0736.081, RSKangXi=96.8
2498A CJK UNIFIED IDEOGRAPH-#2498A, IRGKangXi=0736.081, RSKangXi=96.8
2498B CJK UNIFIED IDEOGRAPH-#2498B, IRGKangXi=0736.081, RSKangXi=96.8
2498C CJK UNIFIED IDEOGRAPH-#2498C, IRGKangXi=0736.081, RSKangXi=96.8
2498D CJK UNIFIED IDEOGRAPH-#2498D, IRGKangXi=0736.081, RSKangXi=96.8
2498E CJK UNIFIED IDEOGRAPH-#2498E, IRGKangXi=0736.081, RSKangXi=96.8
2498F CJK UNIFIED IDEOGRAPH-#2498F, IRGKangXi=0736.081, RSKangXi=96.8
24990 CJK UNIFIED IDEOGRAPH-#24990, IRGKangXi=0736.081, RSKangXi=96.8
24991 CJK UNIFIED IDEOGRAPH-#24991, IRGKangXi=0736.081, RSKangXi=96.8
24992 CJK UNIFIED IDEOGRAPH-#24992, IRGKangXi=0736.081, RSKangXi=96.8
24993 CJK UNIFIED IDEOGRAPH-#24993, IRGKangXi=0736.081, RSKangXi=96.8
24994 CJK UNIFIED IDEOGRAPH-#24994, IRGKangXi=0736.081, RSKangXi=96.8
24995 CJK UNIFIED IDEOGRAPH-#24995, IRGKangXi=0736.081, RSKangXi=96.8
24996 CJK UNIFIED IDEOGRAPH-#24996, IRGKangXi=0736.081, RSKangXi=96.8
24997 CJK UNIFIED IDEOGRAPH-#24997, IRGKangXi=0736.081, RSKangXi=96.8
24998 CJK UNIFIED IDEOGRAPH-#24998, IRGKangXi=0736.081, RSKangXi=96.8
24999 CJK UNIFIED IDEOGRAPH-#24999, IRGKangXi=0736.081, RSKangXi=96.8
2499A CJK UNIFIED IDEOGRAPH-#2499A, IRGKangXi=0736.081, RSKangXi=96.8
2499B CJK UNIFIED IDEOGRAPH-#2499B, IRGKangXi=0736.081, RSKangXi=96.8
2499C CJK UNIFIED IDEOGRAPH-#2499C, IRGKangXi=0736.081, RSKangXi=96.8
2499D CJK UNIFIED IDEOGRAPH-#2499D, IRGKangXi=0736.081, RSKangXi=96.8
2499E CJK UNIFIED IDEOGRAPH-#2499E, IRGKangXi=0736.081, RSKangXi=96.8
2499F CJK UNIFIED IDEOGRAPH-#2499F, IRGKangXi=0736.081, RSKangXi=96.8
249A0 CJK UNIFIED IDEOGRAPH-#249A0, IRGKangXi=0736.081, RSKangXi=96.8
249A1 CJK UNIFIED IDEOGRAPH-#249A1, IRGKangXi=0736.081, RSKangXi=96.8
249A2 CJK UNIFIED IDEOGRAPH-#249A2, IRGKangXi=0736.081, RSKangXi=96.8
249A3 CJK UNIFIED IDEOGRAPH-#249A3, IRGKangXi=0736.081, RSKangXi=96.8
249A4 CJK UNIFIED IDEOGRAPH-#249A4, IRGKangXi=0736.081, RSKangXi=96.8
249A5 CJK UNIFIED IDEOGRAPH-#249A5, IRGKangXi=0736.081, RSKangXi=96.8
249A6 CJK UNIFIED IDEOGRAPH-#249A6, IRGKangXi=0736.081, RSKangXi=96.8
249A7 CJK UNIFIED IDEOGRAPH-#249A7, IRGKangXi=0736.081, RSKangXi=96.8
249A8 CJK UNIFIED IDEOGRAPH-#249A8, IRGKangXi=0736.081, RSKangXi=96.8
249A9 CJK UNIFIED IDEOGRAPH-#249A9, IRGKangXi=0736.081, RSKangXi=96.8
249AA CJK UNIFIED IDEOGRAPH-#249AA, IRGKangXi=0736.081, RSKangXi=96.8
249AB CJK UNIFIED IDEOGRAPH-#249AB, IRGKangXi=0736.081, RSKangXi=96.8
249AC CJK UNIFIED IDEOGRAPH-#249AC, IRGKangXi=0736.081, RSKangXi=96.8
249AD CJK UNIFIED IDEOGRAPH-#249AD, IRGKangXi=0736.081, RSKangXi=96.8
249AE CJK UNIFIED IDEOGRAPH-#249AE, IRGKangXi=0736.081, RSKangXi=96.8
249AF CJK UNIFIED IDEOGRAPH-#249AF, IRGKangXi=0737.140, RSKangXi=96.9
249B0 CJK UNIFIED IDEOGRAPH-#249B0, IRGKangXi=0737.160, RSKangXi=96.9
249B1 CJK UNIFIED IDEOGRAPH-#249B1, IRGKangXi=0737.170, RSKangXi=96.9
249B2 CJK UNIFIED IDEOGRAPH-#249B2, IRGKangXi=0738.010, RSKangXi=96.9
249B3 CJK UNIFIED IDEOGRAPH-#249B3, IRGKangXi=0738.160, RSKangXi=96.9
249B4 CJK UNIFIED IDEOGRAPH-#249B4, IRGKangXi=0738.170, RSKangXi=96.9
249B5 CJK UNIFIED IDEOGRAPH-#249B5, IRGKangXi=0738.181, RSKangXi=96.9
249B6 CJK UNIFIED IDEOGRAPH-#249B6, IRGKangXi=0738.181, RSKangXi=96.9
249B7 CJK UNIFIED IDEOGRAPH-#249B7, IRGKangXi=0738.181, RSKangXi=96.9
249B8 CJK UNIFIED IDEOGRAPH-#249B8, IRGKangXi=0738.181, RSKangXi=96.9
249B9 CJK UNIFIED IDEOGRAPH-#249B9, IRGKangXi=0738.181, RSKangXi=96.9
249BA CJK UNIFIED IDEOGRAPH-#249BA, IRGKangXi=0738.181
249BB CJK UNIFIED IDEOGRAPH-#249BB, IRGKangXi=0738.181, RSKangXi=96.9
249BC CJK UNIFIED IDEOGRAPH-#249BC, IRGKangXi=0738.181, RSKangXi=96.9
249BD CJK UNIFIED IDEOGRAPH-#249BD, IRGKangXi=0738.181, RSKangXi=96.9
249BE CJK UNIFIED IDEOGRAPH-#249BE, IRGKangXi=0738.181, RSKangXi=96.9
249BF CJK UNIFIED IDEOGRAPH-#249BF, IRGKangXi=0738.181, RSKangXi=96.9
249C0 CJK UNIFIED IDEOGRAPH-#249C0, IRGKangXi=0738.181, RSKangXi=96.9
249C1 CJK UNIFIED IDEOGRAPH-#249C1, IRGKangXi=0738.181, RSKangXi=96.9
249C2 CJK UNIFIED IDEOGRAPH-#249C2, IRGKangXi=0738.181, RSKangXi=96.9
249C3 CJK UNIFIED IDEOGRAPH-#249C3, IRGKangXi=0738.181, RSKangXi=96.9
249C4 CJK UNIFIED IDEOGRAPH-#249C4, IRGKangXi=0738.181, RSKangXi=96.9
249C5 CJK UNIFIED IDEOGRAPH-#249C5, IRGKangXi=0738.181, RSKangXi=96.9
249C6 CJK UNIFIED IDEOGRAPH-#249C6, IRGKangXi=0738.181, RSKangXi=96.9
249C7 CJK UNIFIED IDEOGRAPH-#249C7, IRGKangXi=0738.181, RSKangXi=96.9
249C8 CJK UNIFIED IDEOGRAPH-#249C8, IRGKangXi=0738.181, RSKangXi=96.9
249C9 CJK UNIFIED IDEOGRAPH-#249C9, IRGKangXi=0738.181, RSKangXi=96.9
249CA CJK UNIFIED IDEOGRAPH-#249CA, IRGKangXi=0738.181, RSKangXi=96.9
249CB CJK UNIFIED IDEOGRAPH-#249CB, IRGKangXi=0738.181, RSKangXi=96.9
249CC CJK UNIFIED IDEOGRAPH-#249CC, IRGKangXi=0738.181, RSKangXi=96.9
249CD CJK UNIFIED IDEOGRAPH-#249CD, IRGKangXi=0738.181, RSKangXi=96.9
249CE CJK UNIFIED IDEOGRAPH-#249CE, IRGKangXi=0738.181, RSKangXi=96.9
249CF CJK UNIFIED IDEOGRAPH-#249CF, IRGKangXi=0738.181, RSKangXi=96.9
249D0 CJK UNIFIED IDEOGRAPH-#249D0, IRGKangXi=0738.181, RSKangXi=96.9
249D1 CJK UNIFIED IDEOGRAPH-#249D1, IRGKangXi=0738.181, RSKangXi=96.9
249D2 CJK UNIFIED IDEOGRAPH-#249D2, IRGKangXi=0738.181, RSKangXi=96.9
249D3 CJK UNIFIED IDEOGRAPH-#249D3, IRGKangXi=0738.181, RSKangXi=96.9
249D4 CJK UNIFIED IDEOGRAPH-#249D4, IRGKangXi=0738.181, RSKangXi=96.9
249D5 CJK UNIFIED IDEOGRAPH-#249D5, IRGKangXi=0738.181, RSKangXi=96.9
249D6 CJK UNIFIED IDEOGRAPH-#249D6, IRGKangXi=0738.181, RSKangXi=96.9
249D7 CJK UNIFIED IDEOGRAPH-#249D7, IRGKangXi=0738.181, RSKangXi=96.9
249D8 CJK UNIFIED IDEOGRAPH-#249D8, IRGKangXi=0738.181, RSKangXi=96.9
249D9 CJK UNIFIED IDEOGRAPH-#249D9, IRGKangXi=0738.181, RSKangXi=96.9
249DA CJK UNIFIED IDEOGRAPH-#249DA, IRGKangXi=0738.181, RSKangXi=96.9, Def{turquoise}
249DB CJK UNIFIED IDEOGRAPH-#249DB, IRGKangXi=0738.181, RSKangXi=96.9
249DC CJK UNIFIED IDEOGRAPH-#249DC, IRGKangXi=0738.181, RSKangXi=96.9
249DD CJK UNIFIED IDEOGRAPH-#249DD, IRGKangXi=0738.181, RSKangXi=96.9
249DE CJK UNIFIED IDEOGRAPH-#249DE, IRGKangXi=0738.181, RSKangXi=96.9
249DF CJK UNIFIED IDEOGRAPH-#249DF, IRGKangXi=0738.181, RSKangXi=96.9
249E0 CJK UNIFIED IDEOGRAPH-#249E0, IRGKangXi=0738.181, RSKangXi=96.9
249E1 CJK UNIFIED IDEOGRAPH-#249E1, IRGKangXi=0738.181, RSKangXi=96.9
249E2 CJK UNIFIED IDEOGRAPH-#249E2, IRGKangXi=0738.181, RSKangXi=96.9
249E3 CJK UNIFIED IDEOGRAPH-#249E3, IRGKangXi=0738.181, RSKangXi=96.9
249E4 CJK UNIFIED IDEOGRAPH-#249E4, IRGKangXi=0738.181, RSKangXi=96.9
249E5 CJK UNIFIED IDEOGRAPH-#249E5, IRGKangXi=0738.181, RSKangXi=96.9
249E6 CJK UNIFIED IDEOGRAPH-#249E6, IRGKangXi=0738.181, RSKangXi=96.9
249E7 CJK UNIFIED IDEOGRAPH-#249E7, IRGKangXi=0738.181, RSKangXi=96.9
249E8 CJK UNIFIED IDEOGRAPH-#249E8, IRGKangXi=0738.181, RSKangXi=96.9
249E9 CJK UNIFIED IDEOGRAPH-#249E9, IRGKangXi=0738.181, RSKangXi=96.9
249EA CJK UNIFIED IDEOGRAPH-#249EA, IRGKangXi=0738.210, RSKangXi=96.10
249EB CJK UNIFIED IDEOGRAPH-#249EB, IRGKangXi=0739.020, RSKangXi=96.10
249EC CJK UNIFIED IDEOGRAPH-#249EC, IRGKangXi=0739.070, RSKangXi=96.10
249ED CJK UNIFIED IDEOGRAPH-#249ED, IRGKangXi=0739.110, RSKangXi=96.10
249EE CJK UNIFIED IDEOGRAPH-#249EE, IRGKangXi=0739.170, RSKangXi=96.10
249EF CJK UNIFIED IDEOGRAPH-#249EF, IRGKangXi=0740.080, RSKangXi=96.10
249F0 CJK UNIFIED IDEOGRAPH-#249F0, IRGKangXi=0740.090, RSKangXi=96.10
249F1 CJK UNIFIED IDEOGRAPH-#249F1, IRGKangXi=0740.100, RSKangXi=96.10
249F2 CJK UNIFIED IDEOGRAPH-#249F2, IRGKangXi=0740.110, RSKangXi=96.10
249F3 CJK UNIFIED IDEOGRAPH-#249F3, IRGKangXi=0740.111, RSKangXi=96.10
249F4 CJK UNIFIED IDEOGRAPH-#249F4, IRGKangXi=0740.111, RSKangXi=96.10
249F5 CJK UNIFIED IDEOGRAPH-#249F5, IRGKangXi=0740.111, RSKangXi=96.10
249F6 CJK UNIFIED IDEOGRAPH-#249F6, IRGKangXi=0740.111, RSKangXi=96.10
249F7 CJK UNIFIED IDEOGRAPH-#249F7, IRGKangXi=0740.111, RSKangXi=96.10
249F8 CJK UNIFIED IDEOGRAPH-#249F8, IRGKangXi=0740.111, RSKangXi=96.10
249F9 CJK UNIFIED IDEOGRAPH-#249F9, IRGKangXi=0740.111, RSKangXi=96.10
249FA CJK UNIFIED IDEOGRAPH-#249FA, IRGKangXi=0740.111, RSKangXi=96.10
249FB CJK UNIFIED IDEOGRAPH-#249FB, IRGKangXi=0740.111, RSKangXi=96.10
249FC CJK UNIFIED IDEOGRAPH-#249FC, IRGKangXi=0740.111, RSKangXi=96.10
249FD CJK UNIFIED IDEOGRAPH-#249FD, IRGKangXi=0740.111, RSKangXi=96.10
249FE CJK UNIFIED IDEOGRAPH-#249FE, IRGKangXi=0740.111, RSKangXi=96.10
249FF CJK UNIFIED IDEOGRAPH-#249FF, IRGKangXi=0740.111, RSKangXi=96.10
24A00 CJK UNIFIED IDEOGRAPH-#24A00, IRGKangXi=0740.111, RSKangXi=96.10
24A01 CJK UNIFIED IDEOGRAPH-#24A01, IRGKangXi=0740.111, RSKangXi=96.10
24A02 CJK UNIFIED IDEOGRAPH-#24A02, IRGKangXi=0740.111, RSKangXi=96.10
24A03 CJK UNIFIED IDEOGRAPH-#24A03, IRGKangXi=0740.111, RSKangXi=96.10
24A04 CJK UNIFIED IDEOGRAPH-#24A04, IRGKangXi=0740.111, RSKangXi=96.10
24A05 CJK UNIFIED IDEOGRAPH-#24A05, IRGKangXi=0740.111, RSKangXi=96.10
24A06 CJK UNIFIED IDEOGRAPH-#24A06, IRGKangXi=0740.111, RSKangXi=96.10
24A07 CJK UNIFIED IDEOGRAPH-#24A07, IRGKangXi=0740.111, RSKangXi=96.10
24A08 CJK UNIFIED IDEOGRAPH-#24A08, IRGKangXi=0740.111, RSKangXi=96.10
24A09 CJK UNIFIED IDEOGRAPH-#24A09, IRGKangXi=0740.111, RSKangXi=96.10
24A0A CJK UNIFIED IDEOGRAPH-#24A0A, IRGKangXi=0740.111, RSKangXi=96.10
24A0B CJK UNIFIED IDEOGRAPH-#24A0B, IRGKangXi=0740.111, RSKangXi=96.10
24A0C CJK UNIFIED IDEOGRAPH-#24A0C, IRGKangXi=0740.111, RSKangXi=96.10
24A0D CJK UNIFIED IDEOGRAPH-#24A0D, IRGKangXi=0740.111, RSKangXi=96.10
24A0E CJK UNIFIED IDEOGRAPH-#24A0E, IRGKangXi=0740.111, RSKangXi=96.10
24A0F CJK UNIFIED IDEOGRAPH-#24A0F, IRGKangXi=0740.111, RSKangXi=96.10
24A10 CJK UNIFIED IDEOGRAPH-#24A10, IRGKangXi=0740.111, RSKangXi=96.10
24A11 CJK UNIFIED IDEOGRAPH-#24A11, IRGKangXi=0740.111, RSKangXi=96.10
24A12 CJK UNIFIED IDEOGRAPH-#24A12, IRGKangXi=0740.111, RSKangXi=96.10
24A13 CJK UNIFIED IDEOGRAPH-#24A13, IRGKangXi=0740.111, RSKangXi=96.10
24A14 CJK UNIFIED IDEOGRAPH-#24A14, IRGKangXi=0740.210, RSKangXi=96.11
24A15 CJK UNIFIED IDEOGRAPH-#24A15, IRGKangXi=0740.270, RSKangXi=96.11
24A16 CJK UNIFIED IDEOGRAPH-#24A16, IRGKangXi=0741.070, RSKangXi=96.11
24A17 CJK UNIFIED IDEOGRAPH-#24A17, IRGKangXi=0741.090, RSKangXi=96.11
24A18 CJK UNIFIED IDEOGRAPH-#24A18, IRGKangXi=0741.110, RSKangXi=96.11
24A19 CJK UNIFIED IDEOGRAPH-#24A19, IRGKangXi=0741.150, RSKangXi=96.11
24A1A CJK UNIFIED IDEOGRAPH-#24A1A, IRGKangXi=0741.160, RSKangXi=96.11
24A1B CJK UNIFIED IDEOGRAPH-#24A1B, IRGKangXi=0741.170, RSKangXi=96.11
24A1C CJK UNIFIED IDEOGRAPH-#24A1C, IRGKangXi=0741.180, RSKangXi=96.11
24A1D CJK UNIFIED IDEOGRAPH-#24A1D, IRGKangXi=0741.190, RSKangXi=96.11
24A1E CJK UNIFIED IDEOGRAPH-#24A1E, IRGKangXi=0741.221, RSKangXi=96.11
24A1F CJK UNIFIED IDEOGRAPH-#24A1F, IRGKangXi=0741.221, RSKangXi=96.11
24A20 CJK UNIFIED IDEOGRAPH-#24A20, IRGKangXi=0741.221, RSKangXi=96.11
24A21 CJK UNIFIED IDEOGRAPH-#24A21, IRGKangXi=0741.221, RSKangXi=96.11
24A22 CJK UNIFIED IDEOGRAPH-#24A22, IRGKangXi=0741.221, RSKangXi=96.11
24A23 CJK UNIFIED IDEOGRAPH-#24A23, IRGKangXi=0741.221, RSKangXi=96.11
24A24 CJK UNIFIED IDEOGRAPH-#24A24, IRGKangXi=0741.221, RSKangXi=96.11
24A25 CJK UNIFIED IDEOGRAPH-#24A25, IRGKangXi=0741.221, RSKangXi=96.11
24A26 CJK UNIFIED IDEOGRAPH-#24A26, IRGKangXi=0741.221, RSKangXi=96.11
24A27 CJK UNIFIED IDEOGRAPH-#24A27, IRGKangXi=0741.221, RSKangXi=96.11
24A28 CJK UNIFIED IDEOGRAPH-#24A28, IRGKangXi=0741.221, RSKangXi=96.11
24A29 CJK UNIFIED IDEOGRAPH-#24A29, IRGKangXi=0741.221, RSKangXi=96.11
24A2A CJK UNIFIED IDEOGRAPH-#24A2A, IRGKangXi=0741.221, RSKangXi=96.11
24A2B CJK UNIFIED IDEOGRAPH-#24A2B, IRGKangXi=0741.221, RSKangXi=96.11
24A2C CJK UNIFIED IDEOGRAPH-#24A2C, IRGKangXi=0741.221, RSKangXi=96.11
24A2D CJK UNIFIED IDEOGRAPH-#24A2D, IRGKangXi=0741.221, RSKangXi=96.11
24A2E CJK UNIFIED IDEOGRAPH-#24A2E, IRGKangXi=0741.221, RSKangXi=96.11
24A2F CJK UNIFIED IDEOGRAPH-#24A2F, IRGKangXi=0741.221, RSKangXi=96.11
24A30 CJK UNIFIED IDEOGRAPH-#24A30, IRGKangXi=0741.221, RSKangXi=96.11
24A31 CJK UNIFIED IDEOGRAPH-#24A31, IRGKangXi=0741.221, RSKangXi=96.11
24A32 CJK UNIFIED IDEOGRAPH-#24A32, IRGKangXi=0741.221, RSKangXi=96.11
24A33 CJK UNIFIED IDEOGRAPH-#24A33, IRGKangXi=0741.221, RSKangXi=96.11
24A34 CJK UNIFIED IDEOGRAPH-#24A34, IRGKangXi=0741.221, RSKangXi=96.11
24A35 CJK UNIFIED IDEOGRAPH-#24A35, IRGKangXi=0741.221, RSKangXi=96.11
24A36 CJK UNIFIED IDEOGRAPH-#24A36, IRGKangXi=0741.221, RSKangXi=96.11
24A37 CJK UNIFIED IDEOGRAPH-#24A37, IRGKangXi=0741.221, RSKangXi=96.11
24A38 CJK UNIFIED IDEOGRAPH-#24A38, IRGKangXi=0741.221, RSKangXi=96.11
24A39 CJK UNIFIED IDEOGRAPH-#24A39, IRGKangXi=0741.221, RSKangXi=96.11
24A3A CJK UNIFIED IDEOGRAPH-#24A3A, IRGKangXi=0741.221, RSKangXi=96.11
24A3B CJK UNIFIED IDEOGRAPH-#24A3B, IRGKangXi=0741.221, RSKangXi=96.11
24A3C CJK UNIFIED IDEOGRAPH-#24A3C, IRGKangXi=0741.221, RSKangXi=96.11
24A3D CJK UNIFIED IDEOGRAPH-#24A3D, IRGKangXi=0741.221, RSKangXi=96.11
24A3E CJK UNIFIED IDEOGRAPH-#24A3E, IRGKangXi=0741.221, RSKangXi=96.11
24A3F CJK UNIFIED IDEOGRAPH-#24A3F, IRGKangXi=0741.221, RSKangXi=96.11
24A40 CJK UNIFIED IDEOGRAPH-#24A40, IRGKangXi=0741.280, RSKangXi=96.12
24A41 CJK UNIFIED IDEOGRAPH-#24A41, IRGKangXi=0741.330, RSKangXi=96.11
24A42 CJK UNIFIED IDEOGRAPH-#24A42, IRGKangXi=0742.010, RSKangXi=96.12
24A43 CJK UNIFIED IDEOGRAPH-#24A43, IRGKangXi=0742.140, RSKangXi=96.12
24A44 CJK UNIFIED IDEOGRAPH-#24A44, IRGKangXi=0742.160, RSKangXi=96.12
24A45 CJK UNIFIED IDEOGRAPH-#24A45, IRGKangXi=0742.190, RSKangXi=96.12
24A46 CJK UNIFIED IDEOGRAPH-#24A46, IRGKangXi=0742.200, RSKangXi=96.12
24A47 CJK UNIFIED IDEOGRAPH-#24A47, IRGKangXi=0742.210, RSKangXi=96.12
24A48 CJK UNIFIED IDEOGRAPH-#24A48, IRGKangXi=0742.220, RSKangXi=96.12
24A49 CJK UNIFIED IDEOGRAPH-#24A49, IRGKangXi=0742.230, RSKangXi=96.12
24A4A CJK UNIFIED IDEOGRAPH-#24A4A, IRGKangXi=0742.240, RSKangXi=96.12
24A4B CJK UNIFIED IDEOGRAPH-#24A4B, IRGKangXi=0742.250, RSKangXi=96.12
24A4C CJK UNIFIED IDEOGRAPH-#24A4C, IRGKangXi=0742.251, RSKangXi=96.12
24A4D CJK UNIFIED IDEOGRAPH-#24A4D, IRGKangXi=0742.251, RSKangXi=96.12
24A4E CJK UNIFIED IDEOGRAPH-#24A4E, IRGKangXi=0742.251, RSKangXi=96.12
24A4F CJK UNIFIED IDEOGRAPH-#24A4F, IRGKangXi=0742.251, RSKangXi=96.12
24A50 CJK UNIFIED IDEOGRAPH-#24A50, IRGKangXi=0742.251, RSKangXi=96.12
24A51 CJK UNIFIED IDEOGRAPH-#24A51, IRGKangXi=0742.251, RSKangXi=96.12
24A52 CJK UNIFIED IDEOGRAPH-#24A52, IRGKangXi=0742.251, RSKangXi=96.12
24A53 CJK UNIFIED IDEOGRAPH-#24A53, IRGKangXi=0742.251, RSKangXi=96.12
24A54 CJK UNIFIED IDEOGRAPH-#24A54, IRGKangXi=0742.251, RSKangXi=96.12
24A55 CJK UNIFIED IDEOGRAPH-#24A55, IRGKangXi=0742.251, RSKangXi=96.12
24A56 CJK UNIFIED IDEOGRAPH-#24A56, IRGKangXi=0742.251, RSKangXi=96.12
24A57 CJK UNIFIED IDEOGRAPH-#24A57, IRGKangXi=0742.251, RSKangXi=96.12
24A58 CJK UNIFIED IDEOGRAPH-#24A58, IRGKangXi=0742.251, RSKangXi=96.12
24A59 CJK UNIFIED IDEOGRAPH-#24A59, IRGKangXi=0742.251, RSKangXi=96.12
24A5A CJK UNIFIED IDEOGRAPH-#24A5A, IRGKangXi=0742.251, RSKangXi=96.12
24A5B CJK UNIFIED IDEOGRAPH-#24A5B, IRGKangXi=0742.251, RSKangXi=96.12
24A5C CJK UNIFIED IDEOGRAPH-#24A5C, IRGKangXi=0742.251, RSKangXi=96.12
24A5D CJK UNIFIED IDEOGRAPH-#24A5D, IRGKangXi=0742.251, RSKangXi=96.12
24A5E CJK UNIFIED IDEOGRAPH-#24A5E, IRGKangXi=0742.251, RSKangXi=96.12
24A5F CJK UNIFIED IDEOGRAPH-#24A5F, IRGKangXi=0742.251, RSKangXi=96.12
24A60 CJK UNIFIED IDEOGRAPH-#24A60, IRGKangXi=0742.251, RSKangXi=96.12
24A61 CJK UNIFIED IDEOGRAPH-#24A61, IRGKangXi=0742.251, RSKangXi=96.12
24A62 CJK UNIFIED IDEOGRAPH-#24A62, IRGKangXi=0742.251, RSKangXi=96.12
24A63 CJK UNIFIED IDEOGRAPH-#24A63, IRGKangXi=0742.251, RSKangXi=96.12
24A64 CJK UNIFIED IDEOGRAPH-#24A64, IRGKangXi=0742.251, RSKangXi=96.12
24A65 CJK UNIFIED IDEOGRAPH-#24A65, IRGKangXi=0742.251, RSKangXi=96.12
24A66 CJK UNIFIED IDEOGRAPH-#24A66, IRGKangXi=0742.251, RSKangXi=96.12
24A67 CJK UNIFIED IDEOGRAPH-#24A67, IRGKangXi=0742.251, RSKangXi=96.12
24A68 CJK UNIFIED IDEOGRAPH-#24A68, IRGKangXi=0742.251, RSKangXi=96.12
24A69 CJK UNIFIED IDEOGRAPH-#24A69, IRGKangXi=0742.251, RSKangXi=96.12
24A6A CJK UNIFIED IDEOGRAPH-#24A6A, IRGKangXi=0742.251, RSKangXi=96.12
24A6B CJK UNIFIED IDEOGRAPH-#24A6B, IRGKangXi=0742.280, RSKangXi=96.13
24A6C CJK UNIFIED IDEOGRAPH-#24A6C, IRGKangXi=0743.020, RSKangXi=96.13
24A6D CJK UNIFIED IDEOGRAPH-#24A6D, IRGKangXi=0743.040, RSKangXi=96.13
24A6E CJK UNIFIED IDEOGRAPH-#24A6E, IRGKangXi=0743.090, RSKangXi=96.13
24A6F CJK UNIFIED IDEOGRAPH-#24A6F, IRGKangXi=0743.110, RSKangXi=96.13
24A70 CJK UNIFIED IDEOGRAPH-#24A70, IRGKangXi=0743.130, RSKangXi=96.13
24A71 CJK UNIFIED IDEOGRAPH-#24A71, IRGKangXi=0743.150, RSKangXi=96.13
24A72 CJK UNIFIED IDEOGRAPH-#24A72, IRGKangXi=0743.160, RSKangXi=96.13
24A73 CJK UNIFIED IDEOGRAPH-#24A73, IRGKangXi=0743.210, RSKangXi=96.13
24A74 CJK UNIFIED IDEOGRAPH-#24A74, IRGKangXi=0744.010, RSKangXi=96.13
24A75 CJK UNIFIED IDEOGRAPH-#24A75, IRGKangXi=0744.020, RSKangXi=96.13
24A76 CJK UNIFIED IDEOGRAPH-#24A76, IRGKangXi=0744.021, RSKangXi=96.13
24A77 CJK UNIFIED IDEOGRAPH-#24A77, IRGKangXi=0744.021, RSKangXi=96.13
24A78 CJK UNIFIED IDEOGRAPH-#24A78, IRGKangXi=0744.021, RSKangXi=96.13
24A79 CJK UNIFIED IDEOGRAPH-#24A79, IRGKangXi=0744.021, RSKangXi=96.13
24A7A CJK UNIFIED IDEOGRAPH-#24A7A, IRGKangXi=0744.021, RSKangXi=96.13
24A7B CJK UNIFIED IDEOGRAPH-#24A7B, IRGKangXi=0744.021, RSKangXi=96.13
24A7C CJK UNIFIED IDEOGRAPH-#24A7C, IRGKangXi=0744.021, RSKangXi=96.13
24A7D CJK UNIFIED IDEOGRAPH-#24A7D, IRGKangXi=0744.021, RSKangXi=96.13
24A7E CJK UNIFIED IDEOGRAPH-#24A7E, IRGKangXi=0744.021, RSKangXi=96.13
24A7F CJK UNIFIED IDEOGRAPH-#24A7F, IRGKangXi=0744.021, RSKangXi=96.13
24A80 CJK UNIFIED IDEOGRAPH-#24A80, IRGKangXi=0744.021, RSKangXi=96.13
24A81 CJK UNIFIED IDEOGRAPH-#24A81, IRGKangXi=0744.021, RSKangXi=96.13
24A82 CJK UNIFIED IDEOGRAPH-#24A82, IRGKangXi=0744.021, RSKangXi=96.13
24A83 CJK UNIFIED IDEOGRAPH-#24A83, IRGKangXi=0744.021, RSKangXi=96.13
24A84 CJK UNIFIED IDEOGRAPH-#24A84, IRGKangXi=0744.021, RSKangXi=96.13
24A85 CJK UNIFIED IDEOGRAPH-#24A85, IRGKangXi=0744.021, RSKangXi=96.13
24A86 CJK UNIFIED IDEOGRAPH-#24A86, IRGKangXi=0744.021, RSKangXi=96.13
24A87 CJK UNIFIED IDEOGRAPH-#24A87, IRGKangXi=0744.021, RSKangXi=96.13
24A88 CJK UNIFIED IDEOGRAPH-#24A88, IRGKangXi=0744.021, RSKangXi=96.13
24A89 CJK UNIFIED IDEOGRAPH-#24A89, IRGKangXi=0744.021, RSKangXi=96.13
24A8A CJK UNIFIED IDEOGRAPH-#24A8A, IRGKangXi=0744.021, RSKangXi=96.13
24A8B CJK UNIFIED IDEOGRAPH-#24A8B, IRGKangXi=0744.050, RSKangXi=96.14
24A8C CJK UNIFIED IDEOGRAPH-#24A8C, IRGKangXi=0744.080, RSKangXi=96.14
24A8D CJK UNIFIED IDEOGRAPH-#24A8D, IRGKangXi=0744.200, RSKangXi=96.14
24A8E CJK UNIFIED IDEOGRAPH-#24A8E, IRGKangXi=0744.220, RSKangXi=96.14
24A8F CJK UNIFIED IDEOGRAPH-#24A8F, IRGKangXi=0744.230, RSKangXi=96.14
24A90 CJK UNIFIED IDEOGRAPH-#24A90, IRGKangXi=0744.240, RSKangXi=96.14
24A91 CJK UNIFIED IDEOGRAPH-#24A91, IRGKangXi=0744.261, RSKangXi=96.14
24A92 CJK UNIFIED IDEOGRAPH-#24A92, IRGKangXi=0744.261, RSKangXi=96.14
24A93 CJK UNIFIED IDEOGRAPH-#24A93, IRGKangXi=0744.261, RSKangXi=96.14
24A94 CJK UNIFIED IDEOGRAPH-#24A94, IRGKangXi=0744.261, RSKangXi=96.14
24A95 CJK UNIFIED IDEOGRAPH-#24A95, IRGKangXi=0744.261, RSKangXi=96.14
24A96 CJK UNIFIED IDEOGRAPH-#24A96, IRGKangXi=0744.261, RSKangXi=96.14
24A97 CJK UNIFIED IDEOGRAPH-#24A97, IRGKangXi=0744.261, RSKangXi=96.14
24A98 CJK UNIFIED IDEOGRAPH-#24A98, IRGKangXi=0744.261, RSKangXi=96.14
24A99 CJK UNIFIED IDEOGRAPH-#24A99, IRGKangXi=0744.261, RSKangXi=96.14
24A9A CJK UNIFIED IDEOGRAPH-#24A9A, IRGKangXi=0744.261, RSKangXi=96.14
24A9B CJK UNIFIED IDEOGRAPH-#24A9B, IRGKangXi=0744.261, RSKangXi=96.14
24A9C CJK UNIFIED IDEOGRAPH-#24A9C, IRGKangXi=0744.261, RSKangXi=96.14
24A9D CJK UNIFIED IDEOGRAPH-#24A9D, IRGKangXi=0744.261, RSKangXi=96.14
24A9E CJK UNIFIED IDEOGRAPH-#24A9E, IRGKangXi=0744.261, RSKangXi=96.14
24A9F CJK UNIFIED IDEOGRAPH-#24A9F, IRGKangXi=0744.261, RSKangXi=96.14
24AA0 CJK UNIFIED IDEOGRAPH-#24AA0, IRGKangXi=0744.261, RSKangXi=96.14
24AA1 CJK UNIFIED IDEOGRAPH-#24AA1, IRGKangXi=0744.261, RSKangXi=96.14
24AA2 CJK UNIFIED IDEOGRAPH-#24AA2, IRGKangXi=0744.261, RSKangXi=96.14
24AA3 CJK UNIFIED IDEOGRAPH-#24AA3, IRGKangXi=0744.261, RSKangXi=96.14
24AA4 CJK UNIFIED IDEOGRAPH-#24AA4, IRGKangXi=0744.261, RSKangXi=96.14
24AA5 CJK UNIFIED IDEOGRAPH-#24AA5, IRGKangXi=0744.261, RSKangXi=96.14
24AA6 CJK UNIFIED IDEOGRAPH-#24AA6, IRGKangXi=0744.261, RSKangXi=96.14
24AA7 CJK UNIFIED IDEOGRAPH-#24AA7, IRGKangXi=0744.261, RSKangXi=96.14
24AA8 CJK UNIFIED IDEOGRAPH-#24AA8, IRGKangXi=0744.261, RSKangXi=96.14
24AA9 CJK UNIFIED IDEOGRAPH-#24AA9, IRGKangXi=0744.330, RSKangXi=96.15
24AAA CJK UNIFIED IDEOGRAPH-#24AAA, IRGKangXi=0744.340, RSKangXi=96.15
24AAB CJK UNIFIED IDEOGRAPH-#24AAB, IRGKangXi=0745.010, RSKangXi=96.15
24AAC CJK UNIFIED IDEOGRAPH-#24AAC, IRGKangXi=0745.020, RSKangXi=96.15
24AAD CJK UNIFIED IDEOGRAPH-#24AAD, IRGKangXi=0745.030, RSKangXi=96.15
24AAE CJK UNIFIED IDEOGRAPH-#24AAE, IRGKangXi=0745.050, RSKangXi=96.15
24AAF CJK UNIFIED IDEOGRAPH-#24AAF, IRGKangXi=0745.051, RSKangXi=96.15
24AB0 CJK UNIFIED IDEOGRAPH-#24AB0, IRGKangXi=0745.051, RSKangXi=96.15
24AB1 CJK UNIFIED IDEOGRAPH-#24AB1, IRGKangXi=0745.051, RSKangXi=96.15
24AB2 CJK UNIFIED IDEOGRAPH-#24AB2, IRGKangXi=0745.051, RSKangXi=96.15
24AB3 CJK UNIFIED IDEOGRAPH-#24AB3, IRGKangXi=0745.051, RSKangXi=96.15
24AB4 CJK UNIFIED IDEOGRAPH-#24AB4, IRGKangXi=0745.051, RSKangXi=96.14
24AB5 CJK UNIFIED IDEOGRAPH-#24AB5, IRGKangXi=0745.051, RSKangXi=96.15
24AB6 CJK UNIFIED IDEOGRAPH-#24AB6, IRGKangXi=0745.051, RSKangXi=96.15
24AB7 CJK UNIFIED IDEOGRAPH-#24AB7, IRGKangXi=0745.051, RSKangXi=96.15
24AB8 CJK UNIFIED IDEOGRAPH-#24AB8, IRGKangXi=0745.051, RSKangXi=96.15
24AB9 CJK UNIFIED IDEOGRAPH-#24AB9, IRGKangXi=0745.051, RSKangXi=96.15
24ABA CJK UNIFIED IDEOGRAPH-#24ABA, IRGKangXi=0745.051, RSKangXi=96.15
24ABB CJK UNIFIED IDEOGRAPH-#24ABB, IRGKangXi=0745.051, RSKangXi=96.15
24ABC CJK UNIFIED IDEOGRAPH-#24ABC, IRGKangXi=0745.051, RSKangXi=96.15
24ABD CJK UNIFIED IDEOGRAPH-#24ABD, IRGKangXi=0745.051, RSKangXi=96.15
24ABE CJK UNIFIED IDEOGRAPH-#24ABE, IRGKangXi=0745.060, RSKangXi=96.16
24ABF CJK UNIFIED IDEOGRAPH-#24ABF, IRGKangXi=0745.130, RSKangXi=96.16
24AC0 CJK UNIFIED IDEOGRAPH-#24AC0, IRGKangXi=0745.140, RSKangXi=96.16
24AC1 CJK UNIFIED IDEOGRAPH-#24AC1, IRGKangXi=0745.141, RSKangXi=96.16
24AC2 CJK UNIFIED IDEOGRAPH-#24AC2, IRGKangXi=0745.141, RSKangXi=96.16
24AC3 CJK UNIFIED IDEOGRAPH-#24AC3, IRGKangXi=0745.141, RSKangXi=96.16
24AC4 CJK UNIFIED IDEOGRAPH-#24AC4, IRGKangXi=0745.141, RSKangXi=96.16
24AC5 CJK UNIFIED IDEOGRAPH-#24AC5, IRGKangXi=0745.141, RSKangXi=96.16
24AC6 CJK UNIFIED IDEOGRAPH-#24AC6, IRGKangXi=0745.141, RSKangXi=96.16
24AC7 CJK UNIFIED IDEOGRAPH-#24AC7, IRGKangXi=0745.141, RSKangXi=96.16
24AC8 CJK UNIFIED IDEOGRAPH-#24AC8, IRGKangXi=0745.141, RSKangXi=96.16
24AC9 CJK UNIFIED IDEOGRAPH-#24AC9, IRGKangXi=0745.170, RSKangXi=96.17
24ACA CJK UNIFIED IDEOGRAPH-#24ACA, IRGKangXi=0745.200, RSKangXi=96.17
24ACB CJK UNIFIED IDEOGRAPH-#24ACB, IRGKangXi=0745.210, RSKangXi=96.17
24ACC CJK UNIFIED IDEOGRAPH-#24ACC, IRGKangXi=0745.220, RSKangXi=96.17
24ACD CJK UNIFIED IDEOGRAPH-#24ACD, IRGKangXi=0745.230, RSKangXi=96.17
24ACE CJK UNIFIED IDEOGRAPH-#24ACE, IRGKangXi=0745.231, RSKangXi=96.17
24ACF CJK UNIFIED IDEOGRAPH-#24ACF, IRGKangXi=0745.231, RSKangXi=96.17
24AD0 CJK UNIFIED IDEOGRAPH-#24AD0, IRGKangXi=0745.231, RSKangXi=96.17
24AD1 CJK UNIFIED IDEOGRAPH-#24AD1, IRGKangXi=0745.231, RSKangXi=96.17
24AD2 CJK UNIFIED IDEOGRAPH-#24AD2, IRGKangXi=0745.231, RSKangXi=96.17
24AD3 CJK UNIFIED IDEOGRAPH-#24AD3, IRGKangXi=0745.231, RSKangXi=96.17
24AD4 CJK UNIFIED IDEOGRAPH-#24AD4, IRGKangXi=0745.250, RSKangXi=96.18
24AD5 CJK UNIFIED IDEOGRAPH-#24AD5, IRGKangXi=0745.280, RSKangXi=96.18
24AD6 CJK UNIFIED IDEOGRAPH-#24AD6, IRGKangXi=0745.281, RSKangXi=96.18
24AD7 CJK UNIFIED IDEOGRAPH-#24AD7, IRGKangXi=0745.281, RSKangXi=96.18
24AD8 CJK UNIFIED IDEOGRAPH-#24AD8, IRGKangXi=0745.281, RSKangXi=96.18
24AD9 CJK UNIFIED IDEOGRAPH-#24AD9, IRGKangXi=0745.291, RSKangXi=96.19
24ADA CJK UNIFIED IDEOGRAPH-#24ADA, IRGKangXi=0745.291, RSKangXi=96.19
24ADB CJK UNIFIED IDEOGRAPH-#24ADB, IRGKangXi=0745.291, RSKangXi=96.19
24ADC CJK UNIFIED IDEOGRAPH-#24ADC, IRGKangXi=0745.291, RSKangXi=96.19
24ADD CJK UNIFIED IDEOGRAPH-#24ADD, IRGKangXi=0745.291, RSKangXi=96.19
24ADE CJK UNIFIED IDEOGRAPH-#24ADE, IRGKangXi=0745.291, RSKangXi=96.19
24ADF CJK UNIFIED IDEOGRAPH-#24ADF, IRGKangXi=0745.291, RSKangXi=96.19
24AE0 CJK UNIFIED IDEOGRAPH-#24AE0, IRGKangXi=0745.301, RSKangXi=96.20
24AE1 CJK UNIFIED IDEOGRAPH-#24AE1, IRGKangXi=0745.301, RSKangXi=121.18
24AE2 CJK UNIFIED IDEOGRAPH-#24AE2, IRGKangXi=0745.301, RSKangXi=96.20
24AE3 CJK UNIFIED IDEOGRAPH-#24AE3, IRGKangXi=0745.310, RSKangXi=96.21
24AE4 CJK UNIFIED IDEOGRAPH-#24AE4, IRGKangXi=0745.320, RSKangXi=96.21
24AE5 CJK UNIFIED IDEOGRAPH-#24AE5, IRGKangXi=0745.330, RSKangXi=96.21
24AE6 CJK UNIFIED IDEOGRAPH-#24AE6, IRGKangXi=0745.331, RSKangXi=96.21
24AE7 CJK UNIFIED IDEOGRAPH-#24AE7, IRGKangXi=0745.331, RSKangXi=96.21
24AE8 CJK UNIFIED IDEOGRAPH-#24AE8, IRGKangXi=0745.340, RSKangXi=96.22
24AE9 CJK UNIFIED IDEOGRAPH-#24AE9, IRGKangXi=0745.341, RSKangXi=96.24, Def{(same as U+73B2 玲) tinkling of jade pendants}
24AEA CJK UNIFIED IDEOGRAPH-#24AEA, IRGKangXi=0746.030, RSKangXi=97.3
24AEB CJK UNIFIED IDEOGRAPH-#24AEB, IRGKangXi=0746.050, RSKangXi=97.4
24AEC CJK UNIFIED IDEOGRAPH-#24AEC, IRGKangXi=0746.070, RSKangXi=97.4
24AED CJK UNIFIED IDEOGRAPH-#24AED, IRGKangXi=0746.080, RSKangXi=97.4
24AEE CJK UNIFIED IDEOGRAPH-#24AEE, IRGKangXi=0746.081, RSKangXi=97.4
24AEF CJK UNIFIED IDEOGRAPH-#24AEF, IRGKangXi=0746.081, RSKangXi=97.4
24AF0 CJK UNIFIED IDEOGRAPH-#24AF0, IRGKangXi=0746.100, RSKangXi=97.5
24AF1 CJK UNIFIED IDEOGRAPH-#24AF1, IRGKangXi=0746.110, RSKangXi=97.5
24AF2 CJK UNIFIED IDEOGRAPH-#24AF2, IRGKangXi=0746.140, RSKangXi=97.5
24AF3 CJK UNIFIED IDEOGRAPH-#24AF3, IRGKangXi=0746.160, RSKangXi=97.5
24AF4 CJK UNIFIED IDEOGRAPH-#24AF4, IRGKangXi=0746.161, RSKangXi=97.5
24AF5 CJK UNIFIED IDEOGRAPH-#24AF5, IRGKangXi=0746.190, RSKangXi=97.6
24AF6 CJK UNIFIED IDEOGRAPH-#24AF6, IRGKangXi=0746.210, RSKangXi=97.6
24AF7 CJK UNIFIED IDEOGRAPH-#24AF7, IRGKangXi=0746.220, RSKangXi=97.6
24AF8 CJK UNIFIED IDEOGRAPH-#24AF8, IRGKangXi=0746.221, RSKangXi=97.6
24AF9 CJK UNIFIED IDEOGRAPH-#24AF9, IRGKangXi=0746.221, RSKangXi=97.6
24AFA CJK UNIFIED IDEOGRAPH-#24AFA, IRGKangXi=0747.010, RSKangXi=97.7
24AFB CJK UNIFIED IDEOGRAPH-#24AFB, IRGKangXi=0747.030, RSKangXi=97.7
24AFC CJK UNIFIED IDEOGRAPH-#24AFC, IRGKangXi=0747.040, RSKangXi=97.7
24AFD CJK UNIFIED IDEOGRAPH-#24AFD, IRGKangXi=0747.041, RSKangXi=97.7
24AFE CJK UNIFIED IDEOGRAPH-#24AFE, IRGKangXi=0747.041, RSKangXi=97.7
24AFF CJK UNIFIED IDEOGRAPH-#24AFF, IRGKangXi=0747.041, RSKangXi=97.7
24B00 CJK UNIFIED IDEOGRAPH-#24B00, IRGKangXi=0747.041, RSKangXi=97.7
24B01 CJK UNIFIED IDEOGRAPH-#24B01, IRGKangXi=0747.050, RSKangXi=97.8
24B02 CJK UNIFIED IDEOGRAPH-#24B02, IRGKangXi=0747.060, RSKangXi=97.8
24B03 CJK UNIFIED IDEOGRAPH-#24B03, IRGKangXi=0747.070, RSKangXi=97.8
24B04 CJK UNIFIED IDEOGRAPH-#24B04, IRGKangXi=0747.081, RSKangXi=97.8
24B05 CJK UNIFIED IDEOGRAPH-#24B05, IRGKangXi=0747.081, RSKangXi=97.8
24B06 CJK UNIFIED IDEOGRAPH-#24B06, IRGKangXi=0747.081, RSKangXi=97.8
24B07 CJK UNIFIED IDEOGRAPH-#24B07, IRGKangXi=0747.091, RSKangXi=97.10
24B08 CJK UNIFIED IDEOGRAPH-#24B08, IRGKangXi=0747.100, RSKangXi=97.9
24B09 CJK UNIFIED IDEOGRAPH-#24B09, IRGKangXi=0747.130, RSKangXi=97.9
24B0A CJK UNIFIED IDEOGRAPH-#24B0A, IRGKangXi=0747.131, RSKangXi=97.9
24B0B CJK UNIFIED IDEOGRAPH-#24B0B, IRGKangXi=0747.131, RSKangXi=97.9
24B0C CJK UNIFIED IDEOGRAPH-#24B0C, IRGKangXi=0747.131, RSKangXi=97.9
24B0D CJK UNIFIED IDEOGRAPH-#24B0D, IRGKangXi=0747.140, RSKangXi=97.10
24B0E CJK UNIFIED IDEOGRAPH-#24B0E, IRGKangXi=0747.160, RSKangXi=97.11
24B0F CJK UNIFIED IDEOGRAPH-#24B0F, IRGKangXi=0747.170, RSKangXi=94.11
24B10 CJK UNIFIED IDEOGRAPH-#24B10, IRGKangXi=0747.190, RSKangXi=94.10
24B11 CJK UNIFIED IDEOGRAPH-#24B11, IRGKangXi=0747.191, RSKangXi=97.10
24B12 CJK UNIFIED IDEOGRAPH-#24B12, IRGKangXi=0747.191, RSKangXi=97.10
24B13 CJK UNIFIED IDEOGRAPH-#24B13, IRGKangXi=0747.191, RSKangXi=97.10
24B14 CJK UNIFIED IDEOGRAPH-#24B14, IRGKangXi=0747.191, RSKangXi=97.10
24B15 CJK UNIFIED IDEOGRAPH-#24B15, IRGKangXi=0747.191, RSKangXi=97.10
24B16 CJK UNIFIED IDEOGRAPH-#24B16, IRGKangXi=0747.220, RSKangXi=97.11
24B17 CJK UNIFIED IDEOGRAPH-#24B17, IRGKangXi=0747.230, RSKangXi=97.12
24B18 CJK UNIFIED IDEOGRAPH-#24B18, IRGKangXi=0747.250, RSKangXi=97.13
24B19 CJK UNIFIED IDEOGRAPH-#24B19, IRGKangXi=0747.251, RSKangXi=97.13
24B1A CJK UNIFIED IDEOGRAPH-#24B1A, IRGKangXi=0747.251, RSKangXi=97.13
24B1B CJK UNIFIED IDEOGRAPH-#24B1B, IRGKangXi=0747.270, RSKangXi=97.16, Def{a gourd}
24B1C CJK UNIFIED IDEOGRAPH-#24B1C, IRGKangXi=0747.280, RSKangXi=97.16
24B1D CJK UNIFIED IDEOGRAPH-#24B1D, IRGKangXi=0747.290, RSKangXi=97.16
24B1E CJK UNIFIED IDEOGRAPH-#24B1E, IRGKangXi=0747.301, RSKangXi=97.17
24B1F CJK UNIFIED IDEOGRAPH-#24B1F, IRGKangXi=0747.301, RSKangXi=97.17
24B20 CJK UNIFIED IDEOGRAPH-#24B20, IRGKangXi=0747.310, RSKangXi=97.18
24B21 CJK UNIFIED IDEOGRAPH-#24B21, IRGKangXi=0747.311, RSKangXi=97.18
24B22 CJK UNIFIED IDEOGRAPH-#24B22, IRGKangXi=0747.320, RSKangXi=97.19
24B23 CJK UNIFIED IDEOGRAPH-#24B23, IRGKangXi=0747.350, RSKangXi=97.21
24B24 CJK UNIFIED IDEOGRAPH-#24B24, IRGKangXi=0747.351, RSKangXi=97.21
24B25 CJK UNIFIED IDEOGRAPH-#24B25, IRGKangXi=0747.351, RSKangXi=97.25
24B26 CJK UNIFIED IDEOGRAPH-#24B26, IRGKangXi=0748.020, RSKangXi=98.2
24B27 CJK UNIFIED IDEOGRAPH-#24B27, IRGKangXi=0748.021, RSKangXi=98.2
24B28 CJK UNIFIED IDEOGRAPH-#24B28, IRGKangXi=0748.040, RSKangXi=98.3
24B29 CJK UNIFIED IDEOGRAPH-#24B29, IRGKangXi=0748.050, RSKangXi=98.3
24B2A CJK UNIFIED IDEOGRAPH-#24B2A, IRGKangXi=0748.070, RSKangXi=98.3
24B2B CJK UNIFIED IDEOGRAPH-#24B2B, IRGKangXi=0748.081, RSKangXi=98.3
24B2C CJK UNIFIED IDEOGRAPH-#24B2C, IRGKangXi=0748.110, RSKangXi=98.4
24B2D CJK UNIFIED IDEOGRAPH-#24B2D, IRGKangXi=0748.120, RSKangXi=98.4
24B2E CJK UNIFIED IDEOGRAPH-#24B2E, IRGKangXi=0748.140, RSKangXi=98.4
24B2F CJK UNIFIED IDEOGRAPH-#24B2F, IRGKangXi=0748.180, RSKangXi=98.4
24B30 CJK UNIFIED IDEOGRAPH-#24B30, IRGKangXi=0748.200, RSKangXi=98.4
24B31 CJK UNIFIED IDEOGRAPH-#24B31, IRGKangXi=0748.201, RSKangXi=98.4
24B32 CJK UNIFIED IDEOGRAPH-#24B32, IRGKangXi=0748.201, RSKangXi=98.4
24B33 CJK UNIFIED IDEOGRAPH-#24B33, IRGKangXi=0748.210, RSKangXi=98.5
24B34 CJK UNIFIED IDEOGRAPH-#24B34, IRGKangXi=0748.260, RSKangXi=98.5
24B35 CJK UNIFIED IDEOGRAPH-#24B35, IRGKangXi=0748.280, RSKangXi=98.5
24B36 CJK UNIFIED IDEOGRAPH-#24B36, IRGKangXi=0748.290, RSKangXi=98.5
24B37 CJK UNIFIED IDEOGRAPH-#24B37, IRGKangXi=0748.300, RSKangXi=98.5
24B38 CJK UNIFIED IDEOGRAPH-#24B38, IRGKangXi=0748.321, RSKangXi=98.5
24B39 CJK UNIFIED IDEOGRAPH-#24B39, IRGKangXi=0748.331, RSKangXi=98.5
24B3A CJK UNIFIED IDEOGRAPH-#24B3A, IRGKangXi=0748.331, RSKangXi=98.5
24B3B CJK UNIFIED IDEOGRAPH-#24B3B, IRGKangXi=0748.331, RSKangXi=98.5
24B3C CJK UNIFIED IDEOGRAPH-#24B3C, IRGKangXi=0748.331, RSKangXi=98.5
24B3D CJK UNIFIED IDEOGRAPH-#24B3D, IRGKangXi=0748.331, RSKangXi=98.5
24B3E CJK UNIFIED IDEOGRAPH-#24B3E, IRGKangXi=0749.040, RSKangXi=98.6
24B3F CJK UNIFIED IDEOGRAPH-#24B3F, IRGKangXi=0749.060, RSKangXi=98.6
24B40 CJK UNIFIED IDEOGRAPH-#24B40, IRGKangXi=0749.080, RSKangXi=98.6
24B41 CJK UNIFIED IDEOGRAPH-#24B41, IRGKangXi=0749.100, RSKangXi=98.6
24B42 CJK UNIFIED IDEOGRAPH-#24B42, IRGKangXi=0749.110, RSKangXi=98.6
24B43 CJK UNIFIED IDEOGRAPH-#24B43, IRGKangXi=0749.120, RSKangXi=98.6
24B44 CJK UNIFIED IDEOGRAPH-#24B44, IRGKangXi=0749.131, RSKangXi=98.6
24B45 CJK UNIFIED IDEOGRAPH-#24B45, IRGKangXi=0749.131, RSKangXi=98.6
24B46 CJK UNIFIED IDEOGRAPH-#24B46, IRGKangXi=0749.131, RSKangXi=98.6
24B47 CJK UNIFIED IDEOGRAPH-#24B47, IRGKangXi=0749.131, RSKangXi=98.6
24B48 CJK UNIFIED IDEOGRAPH-#24B48, IRGKangXi=0749.131, RSKangXi=98.6
24B49 CJK UNIFIED IDEOGRAPH-#24B49, IRGKangXi=0749.131, RSKangXi=98.6
24B4A CJK UNIFIED IDEOGRAPH-#24B4A, IRGKangXi=0749.131, RSKangXi=98.6
24B4B CJK UNIFIED IDEOGRAPH-#24B4B, IRGKangXi=0749.131, RSKangXi=98.6
24B4C CJK UNIFIED IDEOGRAPH-#24B4C, IRGKangXi=0749.150, RSKangXi=98.7
24B4D CJK UNIFIED IDEOGRAPH-#24B4D, IRGKangXi=0749.160, RSKangXi=98.7
24B4E CJK UNIFIED IDEOGRAPH-#24B4E, IRGKangXi=0749.180, RSKangXi=98.7
24B4F CJK UNIFIED IDEOGRAPH-#24B4F, IRGKangXi=0749.200, RSKangXi=98.7
24B50 CJK UNIFIED IDEOGRAPH-#24B50, IRGKangXi=0749.220, RSKangXi=98.7
24B51 CJK UNIFIED IDEOGRAPH-#24B51, IRGKangXi=0749.240, RSKangXi=98.7
24B52 CJK UNIFIED IDEOGRAPH-#24B52, IRGKangXi=0749.250, RSKangXi=98.7
24B53 CJK UNIFIED IDEOGRAPH-#24B53, IRGKangXi=0749.260, RSKangXi=98.7
24B54 CJK UNIFIED IDEOGRAPH-#24B54, IRGKangXi=0749.280, RSKangXi=98.7
24B55 CJK UNIFIED IDEOGRAPH-#24B55, IRGKangXi=0749.300, RSKangXi=98.7
24B56 CJK UNIFIED IDEOGRAPH-#24B56, IRGKangXi=0749.301, RSKangXi=98.7
24B57 CJK UNIFIED IDEOGRAPH-#24B57, IRGKangXi=0749.301
24B58 CJK UNIFIED IDEOGRAPH-#24B58, IRGKangXi=0749.301, RSKangXi=98.7
24B59 CJK UNIFIED IDEOGRAPH-#24B59, IRGKangXi=0749.301, RSKangXi=98.7
24B5A CJK UNIFIED IDEOGRAPH-#24B5A, IRGKangXi=0749.301, RSKangXi=98.7
24B5B CJK UNIFIED IDEOGRAPH-#24B5B, IRGKangXi=0749.340, RSKangXi=98.8
24B5C CJK UNIFIED IDEOGRAPH-#24B5C, IRGKangXi=0749.350, RSKangXi=98.8
24B5D CJK UNIFIED IDEOGRAPH-#24B5D, IRGKangXi=0749.390, RSKangXi=98.8
24B5E CJK UNIFIED IDEOGRAPH-#24B5E, IRGKangXi=0749.400, RSKangXi=98.8
24B5F CJK UNIFIED IDEOGRAPH-#24B5F, IRGKangXi=0749.410, RSKangXi=98.8
24B60 CJK UNIFIED IDEOGRAPH-#24B60, IRGKangXi=0749.430, RSKangXi=98.8
24B61 CJK UNIFIED IDEOGRAPH-#24B61, IRGKangXi=0750.010, RSKangXi=98.8
24B62 CJK UNIFIED IDEOGRAPH-#24B62, IRGKangXi=0750.040, RSKangXi=98.8
24B63 CJK UNIFIED IDEOGRAPH-#24B63, IRGKangXi=0750.070, RSKangXi=98.8
24B64 CJK UNIFIED IDEOGRAPH-#24B64, IRGKangXi=0750.071, RSKangXi=98.8
24B65 CJK UNIFIED IDEOGRAPH-#24B65, IRGKangXi=0750.071, RSKangXi=98.8
24B66 CJK UNIFIED IDEOGRAPH-#24B66, IRGKangXi=0750.071, RSKangXi=98.8
24B67 CJK UNIFIED IDEOGRAPH-#24B67, IRGKangXi=0750.090, RSKangXi=98.9
24B68 CJK UNIFIED IDEOGRAPH-#24B68, IRGKangXi=0750.120, RSKangXi=98.9
24B69 CJK UNIFIED IDEOGRAPH-#24B69, IRGKangXi=0750.130, RSKangXi=98.9
24B6A CJK UNIFIED IDEOGRAPH-#24B6A, IRGKangXi=0750.140, RSKangXi=98.9
24B6B CJK UNIFIED IDEOGRAPH-#24B6B, IRGKangXi=0750.160, RSKangXi=98.9
24B6C CJK UNIFIED IDEOGRAPH-#24B6C, IRGKangXi=0750.220, RSKangXi=98.9
24B6D CJK UNIFIED IDEOGRAPH-#24B6D, IRGKangXi=0750.231, RSKangXi=98.9
24B6E CJK UNIFIED IDEOGRAPH-#24B6E, IRGKangXi=0750.231, RSKangXi=98.9
24B6F CJK UNIFIED IDEOGRAPH-#24B6F, IRGKangXi=0750.231, RSKangXi=98.9
24B70 CJK UNIFIED IDEOGRAPH-#24B70, IRGKangXi=0750.231, RSKangXi=98.9
24B71 CJK UNIFIED IDEOGRAPH-#24B71, IRGKangXi=0750.231, RSKangXi=98.9
24B72 CJK UNIFIED IDEOGRAPH-#24B72, IRGKangXi=0750.231, RSKangXi=98.8
24B73 CJK UNIFIED IDEOGRAPH-#24B73, IRGKangXi=0750.231, RSKangXi=98.9
24B74 CJK UNIFIED IDEOGRAPH-#24B74, IRGKangXi=0750.231, RSKangXi=98.9
24B75 CJK UNIFIED IDEOGRAPH-#24B75, IRGKangXi=0750.231, RSKangXi=98.9
24B76 CJK UNIFIED IDEOGRAPH-#24B76, IRGKangXi=0750.331, RSKangXi=98.9
24B77 CJK UNIFIED IDEOGRAPH-#24B77, IRGKangXi=0750.331, RSKangXi=98.9
24B78 CJK UNIFIED IDEOGRAPH-#24B78, IRGKangXi=0750.331, RSKangXi=98.9
24B79 CJK UNIFIED IDEOGRAPH-#24B79, IRGKangXi=0751.020, RSKangXi=98.10
24B7A CJK UNIFIED IDEOGRAPH-#24B7A, IRGKangXi=0751.040, RSKangXi=98.10
24B7B CJK UNIFIED IDEOGRAPH-#24B7B, IRGKangXi=0751.060, RSKangXi=98.10
24B7C CJK UNIFIED IDEOGRAPH-#24B7C, IRGKangXi=0751.070, RSKangXi=98.10
24B7D CJK UNIFIED IDEOGRAPH-#24B7D, IRGKangXi=0751.080, RSKangXi=98.10
24B7E CJK UNIFIED IDEOGRAPH-#24B7E, IRGKangXi=0751.111, RSKangXi=98.10
24B7F CJK UNIFIED IDEOGRAPH-#24B7F, IRGKangXi=0751.111, RSKangXi=98.10
24B80 CJK UNIFIED IDEOGRAPH-#24B80, IRGKangXi=0751.111, RSKangXi=98.10
24B81 CJK UNIFIED IDEOGRAPH-#24B81, IRGKangXi=0751.111, RSKangXi=98.10
24B82 CJK UNIFIED IDEOGRAPH-#24B82, IRGKangXi=0751.111, RSKangXi=98.10
24B83 CJK UNIFIED IDEOGRAPH-#24B83, IRGKangXi=0751.111, RSKangXi=98.10
24B84 CJK UNIFIED IDEOGRAPH-#24B84, IRGKangXi=0751.111, RSKangXi=98.10
24B85 CJK UNIFIED IDEOGRAPH-#24B85, IRGKangXi=0751.120, RSKangXi=98.11
24B86 CJK UNIFIED IDEOGRAPH-#24B86, IRGKangXi=0751.130, RSKangXi=98.11
24B87 CJK UNIFIED IDEOGRAPH-#24B87, IRGKangXi=0751.140, RSKangXi=98.11
24B88 CJK UNIFIED IDEOGRAPH-#24B88, IRGKangXi=0751.150, RSKangXi=98.11
24B89 CJK UNIFIED IDEOGRAPH-#24B89, IRGKangXi=0751.170, RSKangXi=98.11
24B8A CJK UNIFIED IDEOGRAPH-#24B8A, IRGKangXi=0751.240, RSKangXi=98.11
24B8B CJK UNIFIED IDEOGRAPH-#24B8B, IRGKangXi=0752.020, RSKangXi=98.11
24B8C CJK UNIFIED IDEOGRAPH-#24B8C, IRGKangXi=0752.021, RSKangXi=98.11
24B8D CJK UNIFIED IDEOGRAPH-#24B8D, IRGKangXi=0752.021, RSKangXi=98.11
24B8E CJK UNIFIED IDEOGRAPH-#24B8E, IRGKangXi=0752.030, RSKangXi=98.12
24B8F CJK UNIFIED IDEOGRAPH-#24B8F, IRGKangXi=0752.090, RSKangXi=98.12
24B90 CJK UNIFIED IDEOGRAPH-#24B90, IRGKangXi=0752.140, RSKangXi=98.12
24B91 CJK UNIFIED IDEOGRAPH-#24B91, IRGKangXi=0752.151, RSKangXi=98.12
24B92 CJK UNIFIED IDEOGRAPH-#24B92, IRGKangXi=0752.151, RSKangXi=98.12
24B93 CJK UNIFIED IDEOGRAPH-#24B93, IRGKangXi=0752.151, RSKangXi=98.12
24B94 CJK UNIFIED IDEOGRAPH-#24B94, IRGKangXi=0752.151, RSKangXi=98.12
24B95 CJK UNIFIED IDEOGRAPH-#24B95, IRGKangXi=0752.151, RSKangXi=98.12
24B96 CJK UNIFIED IDEOGRAPH-#24B96, IRGKangXi=0752.151, RSKangXi=98.12
24B97 CJK UNIFIED IDEOGRAPH-#24B97, IRGKangXi=0752.151, RSKangXi=98.12
24B98 CJK UNIFIED IDEOGRAPH-#24B98, IRGKangXi=0752.160, RSKangXi=98.13
24B99 CJK UNIFIED IDEOGRAPH-#24B99, IRGKangXi=0752.190, RSKangXi=98.13
24B9A CJK UNIFIED IDEOGRAPH-#24B9A, IRGKangXi=0752.210, RSKangXi=98.13
24B9B CJK UNIFIED IDEOGRAPH-#24B9B, IRGKangXi=0752.220, RSKangXi=98.13
24B9C CJK UNIFIED IDEOGRAPH-#24B9C, IRGKangXi=0752.230, RSKangXi=98.13
24B9D CJK UNIFIED IDEOGRAPH-#24B9D, IRGKangXi=0752.260, RSKangXi=98.13
24B9E CJK UNIFIED IDEOGRAPH-#24B9E, IRGKangXi=0752.261, RSKangXi=98.13
24B9F CJK UNIFIED IDEOGRAPH-#24B9F, IRGKangXi=0752.261, RSKangXi=98.13
24BA0 CJK UNIFIED IDEOGRAPH-#24BA0, IRGKangXi=0752.291, RSKangXi=98.14
24BA1 CJK UNIFIED IDEOGRAPH-#24BA1, IRGKangXi=0752.291, RSKangXi=98.14
24BA2 CJK UNIFIED IDEOGRAPH-#24BA2, IRGKangXi=0753.010, RSKangXi=98.15
24BA3 CJK UNIFIED IDEOGRAPH-#24BA3, IRGKangXi=0753.011, RSKangXi=98.15
24BA4 CJK UNIFIED IDEOGRAPH-#24BA4, IRGKangXi=0753.011, RSKangXi=98.15
24BA5 CJK UNIFIED IDEOGRAPH-#24BA5, IRGKangXi=0753.011, RSKangXi=98.15
24BA6 CJK UNIFIED IDEOGRAPH-#24BA6, IRGKangXi=0753.020, RSKangXi=98.16
24BA7 CJK UNIFIED IDEOGRAPH-#24BA7, IRGKangXi=0753.030, RSKangXi=98.16
24BA8 CJK UNIFIED IDEOGRAPH-#24BA8, IRGKangXi=0753.050, RSKangXi=98.16, Def{to grind; a hull; a mill}
24BA9 CJK UNIFIED IDEOGRAPH-#24BA9, IRGKangXi=0753.060, RSKangXi=98.16
24BAA CJK UNIFIED IDEOGRAPH-#24BAA, IRGKangXi=0753.070, RSKangXi=98.16
24BAB CJK UNIFIED IDEOGRAPH-#24BAB, IRGKangXi=0753.071, RSKangXi=98.16
24BAC CJK UNIFIED IDEOGRAPH-#24BAC, IRGKangXi=0753.071, RSKangXi=98.16
24BAD CJK UNIFIED IDEOGRAPH-#24BAD, IRGKangXi=0753.090, RSKangXi=98.17, Def{a jug for boiling congee}
24BAE CJK UNIFIED IDEOGRAPH-#24BAE, IRGKangXi=0753.100, RSKangXi=98.17
24BAF CJK UNIFIED IDEOGRAPH-#24BAF, IRGKangXi=0753.101, RSKangXi=98.17
24BB0 CJK UNIFIED IDEOGRAPH-#24BB0, IRGKangXi=0753.110, RSKangXi=98.18
24BB1 CJK UNIFIED IDEOGRAPH-#24BB1, IRGKangXi=0753.120, RSKangXi=98.18
24BB2 CJK UNIFIED IDEOGRAPH-#24BB2, IRGKangXi=0753.130, RSKangXi=98.18
24BB3 CJK UNIFIED IDEOGRAPH-#24BB3, IRGKangXi=0753.140, RSKangXi=98.18
24BB4 CJK UNIFIED IDEOGRAPH-#24BB4, IRGKangXi=0753.141, RSKangXi=98.18
24BB5 CJK UNIFIED IDEOGRAPH-#24BB5, IRGKangXi=0753.141, RSKangXi=98.18
24BB6 CJK UNIFIED IDEOGRAPH-#24BB6, IRGKangXi=0753.151, RSKangXi=98.19
24BB7 CJK UNIFIED IDEOGRAPH-#24BB7, IRGKangXi=0753.160, RSKangXi=98.20
24BB8 CJK UNIFIED IDEOGRAPH-#24BB8, IRGKangXi=0753.170, RSKangXi=98.22
24BB9 CJK UNIFIED IDEOGRAPH-#24BB9, IRGKangXi=0753.180, RSKangXi=98.24
24BBA CJK UNIFIED IDEOGRAPH-#24BBA, IRGKangXi=0754.010, RSKangXi=99.0
24BBB CJK UNIFIED IDEOGRAPH-#24BBB, IRGKangXi=0754.020, RSKangXi=99.3
24BBC CJK UNIFIED IDEOGRAPH-#24BBC, IRGKangXi=0754.030, RSKangXi=99.3
24BBD CJK UNIFIED IDEOGRAPH-#24BBD, IRGKangXi=0754.040, RSKangXi=99.3
24BBE CJK UNIFIED IDEOGRAPH-#24BBE, IRGKangXi=0754.041, RSKangXi=99.3
24BBF CJK UNIFIED IDEOGRAPH-#24BBF, IRGKangXi=0754.041, RSKangXi=99.3
24BC0 CJK UNIFIED IDEOGRAPH-#24BC0, IRGKangXi=0754.041, RSKangXi=99.3
24BC1 CJK UNIFIED IDEOGRAPH-#24BC1, IRGKangXi=0754.050, RSKangXi=99.4
24BC2 CJK UNIFIED IDEOGRAPH-#24BC2, IRGKangXi=0754.090, RSKangXi=99.4
24BC3 CJK UNIFIED IDEOGRAPH-#24BC3, IRGKangXi=0754.091, RSKangXi=99.4
24BC4 CJK UNIFIED IDEOGRAPH-#24BC4, IRGKangXi=0754.091, RSKangXi=99.4
24BC5 CJK UNIFIED IDEOGRAPH-#24BC5, IRGKangXi=0754.101, RSKangXi=99.5
24BC6 CJK UNIFIED IDEOGRAPH-#24BC6, IRGKangXi=0754.131, RSKangXi=99.7
24BC7 CJK UNIFIED IDEOGRAPH-#24BC7, IRGKangXi=0754.140, RSKangXi=99.8
24BC8 CJK UNIFIED IDEOGRAPH-#24BC8, IRGKangXi=0754.180, RSKangXi=99.9
24BC9 CJK UNIFIED IDEOGRAPH-#24BC9, IRGKangXi=0754.200, RSKangXi=99.10
24BCA CJK UNIFIED IDEOGRAPH-#24BCA, IRGKangXi=0754.201, RSKangXi=99.10
24BCB CJK UNIFIED IDEOGRAPH-#24BCB, IRGKangXi=0754.210, RSKangXi=99.11
24BCC CJK UNIFIED IDEOGRAPH-#24BCC, IRGKangXi=0754.220, RSKangXi=99.11
24BCD CJK UNIFIED IDEOGRAPH-#24BCD, IRGKangXi=0754.231, RSKangXi=99.12
24BCE CJK UNIFIED IDEOGRAPH-#24BCE, IRGKangXi=0754.240, RSKangXi=99.13
24BCF CJK UNIFIED IDEOGRAPH-#24BCF, IRGKangXi=0754.241, RSKangXi=42.15
24BD0 CJK UNIFIED IDEOGRAPH-#24BD0, IRGKangXi=0754.250, RSKangXi=99.16
24BD1 CJK UNIFIED IDEOGRAPH-#24BD1, IRGKangXi=0754.251, RSKangXi=99.17
24BD2 CJK UNIFIED IDEOGRAPH-#24BD2, IRGKangXi=0754.251, RSKangXi=99.23
24BD3 CJK UNIFIED IDEOGRAPH-#24BD3, IRGKangXi=0755.010, RSKangXi=100.0
24BD4 CJK UNIFIED IDEOGRAPH-#24BD4, IRGKangXi=0755.020, RSKangXi=100.1
24BD5 CJK UNIFIED IDEOGRAPH-#24BD5, IRGKangXi=0755.030, RSKangXi=100.3
24BD6 CJK UNIFIED IDEOGRAPH-#24BD6, IRGKangXi=0755.031, RSKangXi=100.3
24BD7 CJK UNIFIED IDEOGRAPH-#24BD7, IRGKangXi=0755.031, RSKangXi=100.3
24BD8 CJK UNIFIED IDEOGRAPH-#24BD8, IRGKangXi=0755.041, RSKangXi=100.4
24BD9 CJK UNIFIED IDEOGRAPH-#24BD9, IRGKangXi=0755.041, RSKangXi=100.4
24BDA CJK UNIFIED IDEOGRAPH-#24BDA, IRGKangXi=0755.041, RSKangXi=100.4
24BDB CJK UNIFIED IDEOGRAPH-#24BDB, IRGKangXi=0755.041, RSKangXi=100.4
24BDC CJK UNIFIED IDEOGRAPH-#24BDC, IRGKangXi=0755.041, RSKangXi=100.4
24BDD CJK UNIFIED IDEOGRAPH-#24BDD, IRGKangXi=0755.041, RSKangXi=100.4
24BDE CJK UNIFIED IDEOGRAPH-#24BDE, IRGKangXi=0755.041, RSKangXi=100.4
24BDF CJK UNIFIED IDEOGRAPH-#24BDF, IRGKangXi=0755.060, RSKangXi=100.5
24BE0 CJK UNIFIED IDEOGRAPH-#24BE0, IRGKangXi=0755.070, RSKangXi=100.6
24BE1 CJK UNIFIED IDEOGRAPH-#24BE1, IRGKangXi=0755.080, RSKangXi=100.6
24BE2 CJK UNIFIED IDEOGRAPH-#24BE2, IRGKangXi=0755.100, RSKangXi=100.6
24BE3 CJK UNIFIED IDEOGRAPH-#24BE3, IRGKangXi=0755.110, RSKangXi=100.6
24BE4 CJK UNIFIED IDEOGRAPH-#24BE4, IRGKangXi=0755.111, RSKangXi=100.6
24BE5 CJK UNIFIED IDEOGRAPH-#24BE5, IRGKangXi=0755.111, RSKangXi=100.6
24BE6 CJK UNIFIED IDEOGRAPH-#24BE6, IRGKangXi=0755.130, RSKangXi=100.7
24BE7 CJK UNIFIED IDEOGRAPH-#24BE7, IRGKangXi=0755.170, RSKangXi=100.7
24BE8 CJK UNIFIED IDEOGRAPH-#24BE8, IRGKangXi=0755.171, RSKangXi=100.7
24BE9 CJK UNIFIED IDEOGRAPH-#24BE9, IRGKangXi=0755.171, RSKangXi=100.7
24BEA CJK UNIFIED IDEOGRAPH-#24BEA, IRGKangXi=0755.171, RSKangXi=100.7
24BEB CJK UNIFIED IDEOGRAPH-#24BEB, IRGKangXi=0755.171, RSKangXi=100.7
24BEC CJK UNIFIED IDEOGRAPH-#24BEC, IRGKangXi=0755.180, RSKangXi=100.8
24BED CJK UNIFIED IDEOGRAPH-#24BED, IRGKangXi=0755.181, RSKangXi=100.8
24BEE CJK UNIFIED IDEOGRAPH-#24BEE, IRGKangXi=0755.181, RSKangXi=100.8
24BEF CJK UNIFIED IDEOGRAPH-#24BEF, IRGKangXi=0755.181, RSKangXi=100.8
24BF0 CJK UNIFIED IDEOGRAPH-#24BF0, IRGKangXi=0755.181, RSKangXi=100.8
24BF1 CJK UNIFIED IDEOGRAPH-#24BF1, IRGKangXi=0755.181, RSKangXi=100.8
24BF2 CJK UNIFIED IDEOGRAPH-#24BF2, IRGKangXi=0755.190, RSKangXi=100.9
24BF3 CJK UNIFIED IDEOGRAPH-#24BF3, IRGKangXi=0755.200, RSKangXi=100.9, Def{same as 甦 U+7526 to be reborn; to resuscitate, revive}
24BF4 CJK UNIFIED IDEOGRAPH-#24BF4, IRGKangXi=0755.201, RSKangXi=100.9
24BF5 CJK UNIFIED IDEOGRAPH-#24BF5, IRGKangXi=0755.201, RSKangXi=100.10
24BF6 CJK UNIFIED IDEOGRAPH-#24BF6, IRGKangXi=0755.201, RSKangXi=100.11
24BF7 CJK UNIFIED IDEOGRAPH-#24BF7, IRGKangXi=0755.210, RSKangXi=100.12
24BF8 CJK UNIFIED IDEOGRAPH-#24BF8, IRGKangXi=0755.221, RSKangXi=100.12
24BF9 CJK UNIFIED IDEOGRAPH-#24BF9, IRGKangXi=0755.221, RSKangXi=100.12
24BFA CJK UNIFIED IDEOGRAPH-#24BFA, IRGKangXi=0755.221, RSKangXi=100.13
24BFB CJK UNIFIED IDEOGRAPH-#24BFB, IRGKangXi=0755.221, RSKangXi=100.14
24BFC CJK UNIFIED IDEOGRAPH-#24BFC, IRGKangXi=0755.221, RSKangXi=100.14
24BFD CJK UNIFIED IDEOGRAPH-#24BFD, IRGKangXi=0755.221, RSKangXi=57.16
24BFE CJK UNIFIED IDEOGRAPH-#24BFE, IRGKangXi=0755.221, RSKangXi=100.14
24BFF CJK UNIFIED IDEOGRAPH-#24BFF, IRGKangXi=0755.221, RSKangXi=100.14
24C00 CJK UNIFIED IDEOGRAPH-#24C00, IRGKangXi=0755.230, RSKangXi=100.16
24C01 CJK UNIFIED IDEOGRAPH-#24C01, IRGKangXi=0755.231, RSKangXi=100.17
24C02 CJK UNIFIED IDEOGRAPH-#24C02, IRGKangXi=0755.231, RSKangXi=100.17
24C03 CJK UNIFIED IDEOGRAPH-#24C03, IRGKangXi=0756.011, RSKangXi=101.1
24C04 CJK UNIFIED IDEOGRAPH-#24C04, IRGKangXi=0756.031, RSKangXi=101.2
24C05 CJK UNIFIED IDEOGRAPH-#24C05, IRGKangXi=0756.040, RSKangXi=101.3
24C06 CJK UNIFIED IDEOGRAPH-#24C06, IRGKangXi=0756.050, RSKangXi=101.3
24C07 CJK UNIFIED IDEOGRAPH-#24C07, IRGKangXi=0756.060, RSKangXi=101.5
24C08 CJK UNIFIED IDEOGRAPH-#24C08, IRGKangXi=0756.070, RSKangXi=101.6
24C09 CJK UNIFIED IDEOGRAPH-#24C09, IRGKangXi=0756.081, RSKangXi=101.7
24C0A CJK UNIFIED IDEOGRAPH-#24C0A, IRGKangXi=0756.081, RSKangXi=101.9
24C0B CJK UNIFIED IDEOGRAPH-#24C0B, IRGKangXi=0756.090, RSKangXi=101.10
24C0C CJK UNIFIED IDEOGRAPH-#24C0C, IRGKangXi=0756.091, RSKangXi=101.10
24C0D CJK UNIFIED IDEOGRAPH-#24C0D, IRGKangXi=0756.091, RSKangXi=101.13
24C0E CJK UNIFIED IDEOGRAPH-#24C0E, IRGKangXi=0756.100, RSKangXi=101.14
24C0F CJK UNIFIED IDEOGRAPH-#24C0F, IRGKangXi=0756.101, RSKangXi=101.17
24C10 CJK UNIFIED IDEOGRAPH-#24C10, IRGKangXi=0756.101, RSKangXi=101.20
24C11 CJK UNIFIED IDEOGRAPH-#24C11, IRGKangXi=0756.101, RSKangXi=101.18
24C12 CJK UNIFIED IDEOGRAPH-#24C12, IRGKangXi=0758.030, RSKangXi=102.0
24C13 CJK UNIFIED IDEOGRAPH-#24C13, IRGKangXi=0759.011, RSKangXi=102.1
24C14 CJK UNIFIED IDEOGRAPH-#24C14, IRGKangXi=0759.011, RSKangXi=102.1
24C15 CJK UNIFIED IDEOGRAPH-#24C15, IRGKangXi=0759.030, RSKangXi=102.2
24C16 CJK UNIFIED IDEOGRAPH-#24C16, IRGKangXi=0759.081, RSKangXi=102.2
24C17 CJK UNIFIED IDEOGRAPH-#24C17, IRGKangXi=0759.081, RSKangXi=102.2
24C18 CJK UNIFIED IDEOGRAPH-#24C18, IRGKangXi=0759.081, RSKangXi=102.2
24C19 CJK UNIFIED IDEOGRAPH-#24C19, IRGKangXi=0759.081, RSKangXi=102.2
24C1A CJK UNIFIED IDEOGRAPH-#24C1A, IRGKangXi=0759.081, RSKangXi=102.2
24C1B CJK UNIFIED IDEOGRAPH-#24C1B, IRGKangXi=0759.081, RSKangXi=102.2
24C1C CJK UNIFIED IDEOGRAPH-#24C1C, IRGKangXi=0759.081, RSKangXi=102.2
24C1D CJK UNIFIED IDEOGRAPH-#24C1D, IRGKangXi=0759.100, RSKangXi=102.3
24C1E CJK UNIFIED IDEOGRAPH-#24C1E, IRGKangXi=0759.130, RSKangXi=102.3
24C1F CJK UNIFIED IDEOGRAPH-#24C1F, IRGKangXi=0759.140, RSKangXi=102.3
24C20 CJK UNIFIED IDEOGRAPH-#24C20, IRGKangXi=0759.150, RSKangXi=102.3
24C21 CJK UNIFIED IDEOGRAPH-#24C21, IRGKangXi=0760.010, RSKangXi=102.3
24C22 CJK UNIFIED IDEOGRAPH-#24C22, IRGKangXi=0760.020, RSKangXi=102.3
24C23 CJK UNIFIED IDEOGRAPH-#24C23, IRGKangXi=0760.030, RSKangXi=102.3
24C24 CJK UNIFIED IDEOGRAPH-#24C24, IRGKangXi=0760.031, RSKangXi=102.3
24C25 CJK UNIFIED IDEOGRAPH-#24C25, IRGKangXi=0760.031, RSKangXi=102.3
24C26 CJK UNIFIED IDEOGRAPH-#24C26, IRGKangXi=0760.031, RSKangXi=102.3
24C27 CJK UNIFIED IDEOGRAPH-#24C27, IRGKangXi=0760.031, RSKangXi=102.3
24C28 CJK UNIFIED IDEOGRAPH-#24C28, IRGKangXi=0760.031, RSKangXi=102.3
24C29 CJK UNIFIED IDEOGRAPH-#24C29, IRGKangXi=0760.080, RSKangXi=102.4
24C2A CJK UNIFIED IDEOGRAPH-#24C2A, IRGKangXi=0760.090, RSKangXi=102.4
24C2B CJK UNIFIED IDEOGRAPH-#24C2B, IRGKangXi=0760.120, RSKangXi=102.4
24C2C CJK UNIFIED IDEOGRAPH-#24C2C, IRGKangXi=0760.130, RSKangXi=102.4
24C2D CJK UNIFIED IDEOGRAPH-#24C2D, IRGKangXi=0760.140, RSKangXi=102.4
24C2E CJK UNIFIED IDEOGRAPH-#24C2E, IRGKangXi=0760.150, RSKangXi=102.4
24C2F CJK UNIFIED IDEOGRAPH-#24C2F, IRGKangXi=0760.250, RSKangXi=102.4
24C30 CJK UNIFIED IDEOGRAPH-#24C30, IRGKangXi=0760.260, RSKangXi=102.4
24C31 CJK UNIFIED IDEOGRAPH-#24C31, IRGKangXi=0760.270, RSKangXi=102.4
24C32 CJK UNIFIED IDEOGRAPH-#24C32, IRGKangXi=0760.280, RSKangXi=102.4
24C33 CJK UNIFIED IDEOGRAPH-#24C33, IRGKangXi=0760.290, RSKangXi=102.4
24C34 CJK UNIFIED IDEOGRAPH-#24C34, IRGKangXi=0760.300, RSKangXi=102.4
24C35 CJK UNIFIED IDEOGRAPH-#24C35, IRGKangXi=0760.310, RSKangXi=102.4
24C36 CJK UNIFIED IDEOGRAPH-#24C36, IRGKangXi=0760.340, RSKangXi=102.4
24C37 CJK UNIFIED IDEOGRAPH-#24C37, IRGKangXi=0760.341, RSKangXi=102.4
24C38 CJK UNIFIED IDEOGRAPH-#24C38, IRGKangXi=0760.341, RSKangXi=102.4
24C39 CJK UNIFIED IDEOGRAPH-#24C39, IRGKangXi=0760.341, RSKangXi=102.4
24C3A CJK UNIFIED IDEOGRAPH-#24C3A, IRGKangXi=0760.341, RSKangXi=102.4
24C3B CJK UNIFIED IDEOGRAPH-#24C3B, IRGKangXi=0760.341, RSKangXi=102.4
24C3C CJK UNIFIED IDEOGRAPH-#24C3C, IRGKangXi=0760.341, RSKangXi=102.4
24C3D CJK UNIFIED IDEOGRAPH-#24C3D, IRGKangXi=0760.341, RSKangXi=102.4
24C3E CJK UNIFIED IDEOGRAPH-#24C3E, IRGKangXi=0760.341, RSKangXi=102.4
24C3F CJK UNIFIED IDEOGRAPH-#24C3F, IRGKangXi=0760.341, RSKangXi=102.4
24C40 CJK UNIFIED IDEOGRAPH-#24C40, IRGKangXi=0760.341, RSKangXi=102.4
24C41 CJK UNIFIED IDEOGRAPH-#24C41, IRGKangXi=0760.341, RSKangXi=102.4
24C42 CJK UNIFIED IDEOGRAPH-#24C42, IRGKangXi=0760.341, RSKangXi=102.4
24C43 CJK UNIFIED IDEOGRAPH-#24C43, IRGKangXi=0760.341, RSKangXi=102.4
24C44 CJK UNIFIED IDEOGRAPH-#24C44, IRGKangXi=0760.341, RSKangXi=102.4
24C45 CJK UNIFIED IDEOGRAPH-#24C45, IRGKangXi=0760.341, RSKangXi=102.4
24C46 CJK UNIFIED IDEOGRAPH-#24C46, IRGKangXi=0760.341, RSKangXi=102.4
24C47 CJK UNIFIED IDEOGRAPH-#24C47, IRGKangXi=0760.341, RSKangXi=102.4
24C48 CJK UNIFIED IDEOGRAPH-#24C48, IRGKangXi=0760.341, RSKangXi=102.4
24C49 CJK UNIFIED IDEOGRAPH-#24C49, IRGKangXi=0760.341, RSKangXi=102.4
24C4A CJK UNIFIED IDEOGRAPH-#24C4A, IRGKangXi=0760.341, RSKangXi=102.4
24C4B CJK UNIFIED IDEOGRAPH-#24C4B, IRGKangXi=0760.341, RSKangXi=102.4
24C4C CJK UNIFIED IDEOGRAPH-#24C4C, IRGKangXi=0760.350, RSKangXi=102.5
24C4D CJK UNIFIED IDEOGRAPH-#24C4D, IRGKangXi=0760.390, RSKangXi=102.5
24C4E CJK UNIFIED IDEOGRAPH-#24C4E, IRGKangXi=0761.010, RSKangXi=102.5
24C4F CJK UNIFIED IDEOGRAPH-#24C4F, IRGKangXi=0761.090, RSKangXi=102.5
24C50 CJK UNIFIED IDEOGRAPH-#24C50, IRGKangXi=0761.100, RSKangXi=102.5
24C51 CJK UNIFIED IDEOGRAPH-#24C51, IRGKangXi=0761.160, RSKangXi=102.5
24C52 CJK UNIFIED IDEOGRAPH-#24C52, IRGKangXi=0761.180, RSKangXi=102.5
24C53 CJK UNIFIED IDEOGRAPH-#24C53, IRGKangXi=0761.190, RSKangXi=102.5
24C54 CJK UNIFIED IDEOGRAPH-#24C54, IRGKangXi=0761.191, RSKangXi=102.5
24C55 CJK UNIFIED IDEOGRAPH-#24C55, IRGKangXi=0761.191, RSKangXi=102.5
24C56 CJK UNIFIED IDEOGRAPH-#24C56, IRGKangXi=0761.191, RSKangXi=102.5
24C57 CJK UNIFIED IDEOGRAPH-#24C57, IRGKangXi=0761.191, RSKangXi=102.5
24C58 CJK UNIFIED IDEOGRAPH-#24C58, IRGKangXi=0761.191, RSKangXi=102.5
24C59 CJK UNIFIED IDEOGRAPH-#24C59, IRGKangXi=0761.191, RSKangXi=102.5
24C5A CJK UNIFIED IDEOGRAPH-#24C5A, IRGKangXi=0761.191, RSKangXi=102.5
24C5B CJK UNIFIED IDEOGRAPH-#24C5B, IRGKangXi=0761.191, RSKangXi=102.5
24C5C CJK UNIFIED IDEOGRAPH-#24C5C, IRGKangXi=0761.191, RSKangXi=102.5
24C5D CJK UNIFIED IDEOGRAPH-#24C5D, IRGKangXi=0761.191, RSKangXi=102.5
24C5E CJK UNIFIED IDEOGRAPH-#24C5E, IRGKangXi=0761.191, RSKangXi=102.5
24C5F CJK UNIFIED IDEOGRAPH-#24C5F, IRGKangXi=0761.191, RSKangXi=102.5
24C60 CJK UNIFIED IDEOGRAPH-#24C60, IRGKangXi=0761.191, RSKangXi=102.5
24C61 CJK UNIFIED IDEOGRAPH-#24C61, IRGKangXi=0761.191, RSKangXi=5.9
24C62 CJK UNIFIED IDEOGRAPH-#24C62, IRGKangXi=0761.191, RSKangXi=102.5
24C63 CJK UNIFIED IDEOGRAPH-#24C63, IRGKangXi=0761.191, RSKangXi=102.5
24C64 CJK UNIFIED IDEOGRAPH-#24C64, IRGKangXi=0761.191, RSKangXi=102.5
24C65 CJK UNIFIED IDEOGRAPH-#24C65, IRGKangXi=0762.010, RSKangXi=102.6
24C66 CJK UNIFIED IDEOGRAPH-#24C66, IRGKangXi=0762.020, RSKangXi=102.6
24C67 CJK UNIFIED IDEOGRAPH-#24C67, IRGKangXi=0762.030, RSKangXi=102.6
24C68 CJK UNIFIED IDEOGRAPH-#24C68, IRGKangXi=0762.040, RSKangXi=102.6
24C69 CJK UNIFIED IDEOGRAPH-#24C69, IRGKangXi=0762.060, RSKangXi=102.6
24C6A CJK UNIFIED IDEOGRAPH-#24C6A, IRGKangXi=0762.100, RSKangXi=102.6
24C6B CJK UNIFIED IDEOGRAPH-#24C6B, IRGKangXi=0763.010, RSKangXi=102.6
24C6C CJK UNIFIED IDEOGRAPH-#24C6C, IRGKangXi=0763.020, RSKangXi=102.6
24C6D CJK UNIFIED IDEOGRAPH-#24C6D, IRGKangXi=0763.030, RSKangXi=102.6
24C6E CJK UNIFIED IDEOGRAPH-#24C6E, IRGKangXi=0763.031, RSKangXi=102.6
24C6F CJK UNIFIED IDEOGRAPH-#24C6F, IRGKangXi=0763.031, RSKangXi=102.6
24C70 CJK UNIFIED IDEOGRAPH-#24C70, IRGKangXi=0763.031, RSKangXi=102.6
24C71 CJK UNIFIED IDEOGRAPH-#24C71, IRGKangXi=0763.031, RSKangXi=102.6
24C72 CJK UNIFIED IDEOGRAPH-#24C72, IRGKangXi=0763.031, RSKangXi=102.6
24C73 CJK UNIFIED IDEOGRAPH-#24C73, IRGKangXi=0763.031, RSKangXi=102.6
24C74 CJK UNIFIED IDEOGRAPH-#24C74, IRGKangXi=0763.031, RSKangXi=102.6
24C75 CJK UNIFIED IDEOGRAPH-#24C75, IRGKangXi=0763.031, RSKangXi=102.6
24C76 CJK UNIFIED IDEOGRAPH-#24C76, IRGKangXi=0763.031, RSKangXi=102.6
24C77 CJK UNIFIED IDEOGRAPH-#24C77, IRGKangXi=0763.031, RSKangXi=102.6
24C78 CJK UNIFIED IDEOGRAPH-#24C78, IRGKangXi=0763.031, RSKangXi=102.6
24C79 CJK UNIFIED IDEOGRAPH-#24C79, IRGKangXi=0763.031, RSKangXi=102.6
24C7A CJK UNIFIED IDEOGRAPH-#24C7A, IRGKangXi=0763.031, RSKangXi=102.6
24C7B CJK UNIFIED IDEOGRAPH-#24C7B, IRGKangXi=0763.031, RSKangXi=102.7
24C7C CJK UNIFIED IDEOGRAPH-#24C7C, IRGKangXi=0763.150, RSKangXi=102.7
24C7D CJK UNIFIED IDEOGRAPH-#24C7D, IRGKangXi=0764.030, RSKangXi=102.7
24C7E CJK UNIFIED IDEOGRAPH-#24C7E, IRGKangXi=0764.040, RSKangXi=102.7
24C7F CJK UNIFIED IDEOGRAPH-#24C7F, IRGKangXi=0764.041, RSKangXi=102.7
24C80 CJK UNIFIED IDEOGRAPH-#24C80, IRGKangXi=0764.041, RSKangXi=102.7
24C81 CJK UNIFIED IDEOGRAPH-#24C81, IRGKangXi=0764.041, RSKangXi=102.7
24C82 CJK UNIFIED IDEOGRAPH-#24C82, IRGKangXi=0764.041, RSKangXi=102.7
24C83 CJK UNIFIED IDEOGRAPH-#24C83, IRGKangXi=0764.041, RSKangXi=102.7
24C84 CJK UNIFIED IDEOGRAPH-#24C84, IRGKangXi=0764.041, RSKangXi=102.7
24C85 CJK UNIFIED IDEOGRAPH-#24C85, IRGKangXi=0764.041, RSKangXi=102.7
24C86 CJK UNIFIED IDEOGRAPH-#24C86, IRGKangXi=0764.041, RSKangXi=102.7
24C87 CJK UNIFIED IDEOGRAPH-#24C87, IRGKangXi=0764.041, RSKangXi=102.7
24C88 CJK UNIFIED IDEOGRAPH-#24C88, IRGKangXi=0764.041, RSKangXi=102.7
24C89 CJK UNIFIED IDEOGRAPH-#24C89, IRGKangXi=0764.041, RSKangXi=102.7
24C8A CJK UNIFIED IDEOGRAPH-#24C8A, IRGKangXi=0764.041, RSKangXi=102.7
24C8B CJK UNIFIED IDEOGRAPH-#24C8B, IRGKangXi=0764.041, RSKangXi=102.7
24C8C CJK UNIFIED IDEOGRAPH-#24C8C, IRGKangXi=0764.041, RSKangXi=102.7
24C8D CJK UNIFIED IDEOGRAPH-#24C8D, IRGKangXi=0764.041, RSKangXi=102.7
24C8E CJK UNIFIED IDEOGRAPH-#24C8E, IRGKangXi=0764.041, RSKangXi=102.7
24C8F CJK UNIFIED IDEOGRAPH-#24C8F, IRGKangXi=0764.041, RSKangXi=102.7
24C90 CJK UNIFIED IDEOGRAPH-#24C90, IRGKangXi=0764.041, RSKangXi=102.7
24C91 CJK UNIFIED IDEOGRAPH-#24C91, IRGKangXi=0764.050, RSKangXi=102.8
24C92 CJK UNIFIED IDEOGRAPH-#24C92, IRGKangXi=0764.070, RSKangXi=102.8
24C93 CJK UNIFIED IDEOGRAPH-#24C93, IRGKangXi=0764.080, RSKangXi=102.8
24C94 CJK UNIFIED IDEOGRAPH-#24C94, IRGKangXi=0764.090, RSKangXi=102.8
24C95 CJK UNIFIED IDEOGRAPH-#24C95, IRGKangXi=0764.120, RSKangXi=102.8
24C96 CJK UNIFIED IDEOGRAPH-#24C96, IRGKangXi=0764.130, RSKangXi=102.8
24C97 CJK UNIFIED IDEOGRAPH-#24C97, IRGKangXi=0764.150, RSKangXi=102.8
24C98 CJK UNIFIED IDEOGRAPH-#24C98, IRGKangXi=0764.160, RSKangXi=102.8
24C99 CJK UNIFIED IDEOGRAPH-#24C99, IRGKangXi=0765.010, RSKangXi=102.8
24C9A CJK UNIFIED IDEOGRAPH-#24C9A, IRGKangXi=0765.060, RSKangXi=102.8
24C9B CJK UNIFIED IDEOGRAPH-#24C9B, IRGKangXi=0765.070, RSKangXi=102.8
24C9C CJK UNIFIED IDEOGRAPH-#24C9C, IRGKangXi=0765.080, RSKangXi=102.8
24C9D CJK UNIFIED IDEOGRAPH-#24C9D, IRGKangXi=0765.090, RSKangXi=102.8
24C9E CJK UNIFIED IDEOGRAPH-#24C9E, IRGKangXi=0765.091, RSKangXi=102.8
24C9F CJK UNIFIED IDEOGRAPH-#24C9F, IRGKangXi=0765.091, RSKangXi=102.8
24CA0 CJK UNIFIED IDEOGRAPH-#24CA0, IRGKangXi=0765.091, RSKangXi=102.8
24CA1 CJK UNIFIED IDEOGRAPH-#24CA1, IRGKangXi=0765.091, RSKangXi=102.8
24CA2 CJK UNIFIED IDEOGRAPH-#24CA2, IRGKangXi=0765.091, RSKangXi=102.8
24CA3 CJK UNIFIED IDEOGRAPH-#24CA3, IRGKangXi=0765.091, RSKangXi=102.8
24CA4 CJK UNIFIED IDEOGRAPH-#24CA4, IRGKangXi=0765.091, RSKangXi=102.8
24CA5 CJK UNIFIED IDEOGRAPH-#24CA5, IRGKangXi=0765.091, RSKangXi=102.8
24CA6 CJK UNIFIED IDEOGRAPH-#24CA6, IRGKangXi=0765.091, RSKangXi=102.8
24CA7 CJK UNIFIED IDEOGRAPH-#24CA7, IRGKangXi=0765.091, RSKangXi=102.8
24CA8 CJK UNIFIED IDEOGRAPH-#24CA8, IRGKangXi=0765.091, RSKangXi=102.8
24CA9 CJK UNIFIED IDEOGRAPH-#24CA9, IRGKangXi=0765.091, RSKangXi=102.8
24CAA CJK UNIFIED IDEOGRAPH-#24CAA, IRGKangXi=0765.091, RSKangXi=102.8
24CAB CJK UNIFIED IDEOGRAPH-#24CAB, IRGKangXi=0765.130, RSKangXi=102.9
24CAC CJK UNIFIED IDEOGRAPH-#24CAC, IRGKangXi=0765.150, RSKangXi=102.9
24CAD CJK UNIFIED IDEOGRAPH-#24CAD, IRGKangXi=0765.160, RSKangXi=102.9
24CAE CJK UNIFIED IDEOGRAPH-#24CAE, IRGKangXi=0765.170, RSKangXi=102.9
24CAF CJK UNIFIED IDEOGRAPH-#24CAF, IRGKangXi=0765.180, RSKangXi=102.9
24CB0 CJK UNIFIED IDEOGRAPH-#24CB0, IRGKangXi=0765.181, RSKangXi=102.9
24CB1 CJK UNIFIED IDEOGRAPH-#24CB1, IRGKangXi=0765.181, RSKangXi=102.9
24CB2 CJK UNIFIED IDEOGRAPH-#24CB2, IRGKangXi=0765.181, RSKangXi=102.9
24CB3 CJK UNIFIED IDEOGRAPH-#24CB3, IRGKangXi=0765.181, RSKangXi=102.9
24CB4 CJK UNIFIED IDEOGRAPH-#24CB4, IRGKangXi=0765.181, RSKangXi=102.9
24CB5 CJK UNIFIED IDEOGRAPH-#24CB5, IRGKangXi=0765.181, RSKangXi=102.9
24CB6 CJK UNIFIED IDEOGRAPH-#24CB6, IRGKangXi=0765.181, RSKangXi=102.9
24CB7 CJK UNIFIED IDEOGRAPH-#24CB7, IRGKangXi=0766.010, RSKangXi=102.10
24CB8 CJK UNIFIED IDEOGRAPH-#24CB8, IRGKangXi=0766.020, RSKangXi=102.10
24CB9 CJK UNIFIED IDEOGRAPH-#24CB9, IRGKangXi=0766.040, RSKangXi=102.10
24CBA CJK UNIFIED IDEOGRAPH-#24CBA, IRGKangXi=0766.050, RSKangXi=102.10
24CBB CJK UNIFIED IDEOGRAPH-#24CBB, IRGKangXi=0766.090, RSKangXi=102.10
24CBC CJK UNIFIED IDEOGRAPH-#24CBC, IRGKangXi=0766.091, RSKangXi=102.10
24CBD CJK UNIFIED IDEOGRAPH-#24CBD, IRGKangXi=0766.100, RSKangXi=102.10
24CBE CJK UNIFIED IDEOGRAPH-#24CBE, IRGKangXi=0766.101, RSKangXi=102.10
24CBF CJK UNIFIED IDEOGRAPH-#24CBF, IRGKangXi=0766.101, RSKangXi=102.10
24CC0 CJK UNIFIED IDEOGRAPH-#24CC0, IRGKangXi=0766.101, RSKangXi=102.10
24CC1 CJK UNIFIED IDEOGRAPH-#24CC1, IRGKangXi=0766.101, RSKangXi=102.10
24CC2 CJK UNIFIED IDEOGRAPH-#24CC2, IRGKangXi=0766.101, RSKangXi=102.10
24CC3 CJK UNIFIED IDEOGRAPH-#24CC3, IRGKangXi=0766.101, RSKangXi=102.10
24CC4 CJK UNIFIED IDEOGRAPH-#24CC4, IRGKangXi=0766.101, RSKangXi=102.10
24CC5 CJK UNIFIED IDEOGRAPH-#24CC5, IRGKangXi=0766.101, RSKangXi=102.10
24CC6 CJK UNIFIED IDEOGRAPH-#24CC6, IRGKangXi=0766.101, RSKangXi=102.10
24CC7 CJK UNIFIED IDEOGRAPH-#24CC7, IRGKangXi=0766.101, RSKangXi=102.10
24CC8 CJK UNIFIED IDEOGRAPH-#24CC8, IRGKangXi=0766.130, RSKangXi=102.11
24CC9 CJK UNIFIED IDEOGRAPH-#24CC9, IRGKangXi=0766.140, RSKangXi=102.11
24CCA CJK UNIFIED IDEOGRAPH-#24CCA, IRGKangXi=0766.160, RSKangXi=102.11
24CCB CJK UNIFIED IDEOGRAPH-#24CCB, IRGKangXi=0766.170, RSKangXi=102.11
24CCC CJK UNIFIED IDEOGRAPH-#24CCC, IRGKangXi=0766.180, RSKangXi=102.11
24CCD CJK UNIFIED IDEOGRAPH-#24CCD, IRGKangXi=0766.181, RSKangXi=102.11
24CCE CJK UNIFIED IDEOGRAPH-#24CCE, IRGKangXi=0766.181, RSKangXi=102.11
24CCF CJK UNIFIED IDEOGRAPH-#24CCF, IRGKangXi=0766.181, RSKangXi=1.15
24CD0 CJK UNIFIED IDEOGRAPH-#24CD0, IRGKangXi=0766.181, RSKangXi=102.11
24CD1 CJK UNIFIED IDEOGRAPH-#24CD1, IRGKangXi=0766.181, RSKangXi=102.11
24CD2 CJK UNIFIED IDEOGRAPH-#24CD2, IRGKangXi=0766.200, RSKangXi=102.12
24CD3 CJK UNIFIED IDEOGRAPH-#24CD3, IRGKangXi=0766.210, RSKangXi=102.12
24CD4 CJK UNIFIED IDEOGRAPH-#24CD4, IRGKangXi=0766.220, RSKangXi=102.12
24CD5 CJK UNIFIED IDEOGRAPH-#24CD5, IRGKangXi=0766.230, RSKangXi=102.12
24CD6 CJK UNIFIED IDEOGRAPH-#24CD6, IRGKangXi=0766.250, RSKangXi=102.12
24CD7 CJK UNIFIED IDEOGRAPH-#24CD7, IRGKangXi=0766.270, RSKangXi=102.12
24CD8 CJK UNIFIED IDEOGRAPH-#24CD8, IRGKangXi=0766.280, RSKangXi=102.12
24CD9 CJK UNIFIED IDEOGRAPH-#24CD9, IRGKangXi=0766.281, RSKangXi=102.12
24CDA CJK UNIFIED IDEOGRAPH-#24CDA, IRGKangXi=0766.281, RSKangXi=102.12
24CDB CJK UNIFIED IDEOGRAPH-#24CDB, IRGKangXi=0766.281, RSKangXi=165.10
24CDC CJK UNIFIED IDEOGRAPH-#24CDC, IRGKangXi=0766.281, RSKangXi=102.12
24CDD CJK UNIFIED IDEOGRAPH-#24CDD, IRGKangXi=0766.281, RSKangXi=102.12
24CDE CJK UNIFIED IDEOGRAPH-#24CDE, IRGKangXi=0766.281, RSKangXi=102.12
24CDF CJK UNIFIED IDEOGRAPH-#24CDF, IRGKangXi=0766.281, RSKangXi=102.12
24CE0 CJK UNIFIED IDEOGRAPH-#24CE0, IRGKangXi=0766.281, RSKangXi=102.12
24CE1 CJK UNIFIED IDEOGRAPH-#24CE1, IRGKangXi=0766.281, RSKangXi=102.12
24CE2 CJK UNIFIED IDEOGRAPH-#24CE2, IRGKangXi=0766.281, RSKangXi=102.12
24CE3 CJK UNIFIED IDEOGRAPH-#24CE3, IRGKangXi=0766.281, RSKangXi=102.12
24CE4 CJK UNIFIED IDEOGRAPH-#24CE4, IRGKangXi=0766.320, RSKangXi=102.13
24CE5 CJK UNIFIED IDEOGRAPH-#24CE5, IRGKangXi=0766.321, RSKangXi=102.13
24CE6 CJK UNIFIED IDEOGRAPH-#24CE6, IRGKangXi=0766.321, RSKangXi=102.13
24CE7 CJK UNIFIED IDEOGRAPH-#24CE7, IRGKangXi=0766.321, RSKangXi=102.13
24CE8 CJK UNIFIED IDEOGRAPH-#24CE8, IRGKangXi=0766.321, RSKangXi=102.13
24CE9 CJK UNIFIED IDEOGRAPH-#24CE9, IRGKangXi=0766.340, RSKangXi=102.14
24CEA CJK UNIFIED IDEOGRAPH-#24CEA, IRGKangXi=0766.360, RSKangXi=102.14
24CEB CJK UNIFIED IDEOGRAPH-#24CEB, IRGKangXi=0766.370, RSKangXi=102.14
24CEC CJK UNIFIED IDEOGRAPH-#24CEC, IRGKangXi=0766.380, RSKangXi=102.14
24CED CJK UNIFIED IDEOGRAPH-#24CED, IRGKangXi=0766.390, RSKangXi=102.14
24CEE CJK UNIFIED IDEOGRAPH-#24CEE, IRGKangXi=0767.010, RSKangXi=102.14
24CEF CJK UNIFIED IDEOGRAPH-#24CEF, IRGKangXi=0767.020, RSKangXi=102.14
24CF0 CJK UNIFIED IDEOGRAPH-#24CF0, IRGKangXi=0767.021, RSKangXi=102.14
24CF1 CJK UNIFIED IDEOGRAPH-#24CF1, IRGKangXi=0767.021, RSKangXi=102.15
24CF2 CJK UNIFIED IDEOGRAPH-#24CF2, IRGKangXi=0767.021, RSKangXi=102.14
24CF3 CJK UNIFIED IDEOGRAPH-#24CF3, IRGKangXi=0767.030, RSKangXi=102.15
24CF4 CJK UNIFIED IDEOGRAPH-#24CF4, IRGKangXi=0767.041, RSKangXi=102.15
24CF5 CJK UNIFIED IDEOGRAPH-#24CF5, IRGKangXi=0767.041, RSKangXi=102.15
24CF6 CJK UNIFIED IDEOGRAPH-#24CF6, IRGKangXi=0767.041, RSKangXi=102.15
24CF7 CJK UNIFIED IDEOGRAPH-#24CF7, IRGKangXi=0767.041, RSKangXi=102.15
24CF8 CJK UNIFIED IDEOGRAPH-#24CF8, IRGKangXi=0767.041, RSKangXi=102.15
24CF9 CJK UNIFIED IDEOGRAPH-#24CF9, IRGKangXi=0767.050, RSKangXi=102.16
24CFA CJK UNIFIED IDEOGRAPH-#24CFA, IRGKangXi=0767.051, RSKangXi=102.16
24CFB CJK UNIFIED IDEOGRAPH-#24CFB, IRGKangXi=0767.051, RSKangXi=102.16
24CFC CJK UNIFIED IDEOGRAPH-#24CFC, IRGKangXi=0767.051, RSKangXi=102.16
24CFD CJK UNIFIED IDEOGRAPH-#24CFD, IRGKangXi=0767.051, RSKangXi=102.16
24CFE CJK UNIFIED IDEOGRAPH-#24CFE, IRGKangXi=0767.051, RSKangXi=102.16
24CFF CJK UNIFIED IDEOGRAPH-#24CFF, IRGKangXi=0767.060, RSKangXi=102.17
24D00 CJK UNIFIED IDEOGRAPH-#24D00, IRGKangXi=0767.070, RSKangXi=102.17
24D01 CJK UNIFIED IDEOGRAPH-#24D01, IRGKangXi=0767.080, RSKangXi=102.17
24D02 CJK UNIFIED IDEOGRAPH-#24D02, IRGKangXi=0767.101, RSKangXi=102.18
24D03 CJK UNIFIED IDEOGRAPH-#24D03, IRGKangXi=0767.101, RSKangXi=102.18
24D04 CJK UNIFIED IDEOGRAPH-#24D04, IRGKangXi=0767.101, RSKangXi=102.18
24D05 CJK UNIFIED IDEOGRAPH-#24D05, IRGKangXi=0767.110, RSKangXi=102.19
24D06 CJK UNIFIED IDEOGRAPH-#24D06, IRGKangXi=0767.111, RSKangXi=102.20
24D07 CJK UNIFIED IDEOGRAPH-#24D07, IRGKangXi=0767.120, RSKangXi=102.21
24D08 CJK UNIFIED IDEOGRAPH-#24D08, IRGKangXi=0767.121, RSKangXi=102.21
24D09 CJK UNIFIED IDEOGRAPH-#24D09, IRGKangXi=0767.121, RSKangXi=102.21
24D0A CJK UNIFIED IDEOGRAPH-#24D0A, IRGKangXi=0767.121, RSKangXi=102.21
24D0B CJK UNIFIED IDEOGRAPH-#24D0B, IRGKangXi=0767.130, RSKangXi=102.21
24D0C CJK UNIFIED IDEOGRAPH-#24D0C, IRGKangXi=0767.131, RSKangXi=102.22
24D0D CJK UNIFIED IDEOGRAPH-#24D0D, IRGKangXi=0767.131, RSKangXi=102.22
24D0E CJK UNIFIED IDEOGRAPH-#24D0E, IRGKangXi=0767.131, RSKangXi=102.23
24D0F CJK UNIFIED IDEOGRAPH-#24D0F, IRGKangXi=0767.131, RSKangXi=102.25
24D10 CJK UNIFIED IDEOGRAPH-#24D10, IRGKangXi=0767.140, RSKangXi=102.27
24D11 CJK UNIFIED IDEOGRAPH-#24D11, IRGKangXi=0767.150, RSKangXi=102.28
24D12 CJK UNIFIED IDEOGRAPH-#24D12, IRGKangXi=0767.151, RSKangXi=102.31
24D13 CJK UNIFIED IDEOGRAPH-#24D13, IRGKangXi=0767.170, RSKangXi=103.0
24D14 CJK UNIFIED IDEOGRAPH-#24D14, IRGKangXi=0767.171, RSKangXi=103.0
24D15 CJK UNIFIED IDEOGRAPH-#24D15, IRGKangXi=0767.180, RSKangXi=103.1
24D16 CJK UNIFIED IDEOGRAPH-#24D16, IRGKangXi=0767.191, RSKangXi=103.3
24D17 CJK UNIFIED IDEOGRAPH-#24D17, IRGKangXi=0767.200, RSKangXi=103.5
24D18 CJK UNIFIED IDEOGRAPH-#24D18, IRGKangXi=0767.201, RSKangXi=103.4
24D19 CJK UNIFIED IDEOGRAPH-#24D19, IRGKangXi=0767.210, RSKangXi=103.7
24D1A CJK UNIFIED IDEOGRAPH-#24D1A, IRGKangXi=0767.231, RSKangXi=103.7
24D1B CJK UNIFIED IDEOGRAPH-#24D1B, IRGKangXi=0767.231, RSKangXi=103.7
24D1C CJK UNIFIED IDEOGRAPH-#24D1C, IRGKangXi=0768.011, RSKangXi=103.8
24D1D CJK UNIFIED IDEOGRAPH-#24D1D, IRGKangXi=0768.011, RSKangXi=103.8
24D1E CJK UNIFIED IDEOGRAPH-#24D1E, IRGKangXi=0768.050, RSKangXi=103.10
24D1F CJK UNIFIED IDEOGRAPH-#24D1F, IRGKangXi=0768.060, RSKangXi=103.11
24D20 CJK UNIFIED IDEOGRAPH-#24D20, IRGKangXi=0768.070, RSKangXi=103.11
24D21 CJK UNIFIED IDEOGRAPH-#24D21, IRGKangXi=0768.080, RSKangXi=103.11
24D22 CJK UNIFIED IDEOGRAPH-#24D22, IRGKangXi=0768.081, RSKangXi=103.11
24D23 CJK UNIFIED IDEOGRAPH-#24D23, IRGKangXi=0768.081, RSKangXi=103.13
24D24 CJK UNIFIED IDEOGRAPH-#24D24, IRGKangXi=0768.090, RSKangXi=103.17
24D25 CJK UNIFIED IDEOGRAPH-#24D25, IRGKangXi=0769.011, RSKangXi=104.1
24D26 CJK UNIFIED IDEOGRAPH-#24D26, IRGKangXi=0769.030, RSKangXi=104.2
24D27 CJK UNIFIED IDEOGRAPH-#24D27, IRGKangXi=0769.050, RSKangXi=104.2
24D28 CJK UNIFIED IDEOGRAPH-#24D28, IRGKangXi=0769.090, RSKangXi=104.2
24D29 CJK UNIFIED IDEOGRAPH-#24D29, IRGKangXi=0769.091, RSKangXi=104.2
24D2A CJK UNIFIED IDEOGRAPH-#24D2A, IRGKangXi=0769.091, RSKangXi=104.2
24D2B CJK UNIFIED IDEOGRAPH-#24D2B, IRGKangXi=0769.091, RSKangXi=104.2
24D2C CJK UNIFIED IDEOGRAPH-#24D2C, IRGKangXi=0769.091, RSKangXi=104.2
24D2D CJK UNIFIED IDEOGRAPH-#24D2D, IRGKangXi=0769.091, RSKangXi=104.2
24D2E CJK UNIFIED IDEOGRAPH-#24D2E, IRGKangXi=0769.091, RSKangXi=104.2
24D2F CJK UNIFIED IDEOGRAPH-#24D2F, IRGKangXi=0769.150, RSKangXi=104.3
24D30 CJK UNIFIED IDEOGRAPH-#24D30, IRGKangXi=0769.170, RSKangXi=104.3
24D31 CJK UNIFIED IDEOGRAPH-#24D31, IRGKangXi=0769.180, RSKangXi=104.3
24D32 CJK UNIFIED IDEOGRAPH-#24D32, IRGKangXi=0769.221, RSKangXi=104.3
24D33 CJK UNIFIED IDEOGRAPH-#24D33, IRGKangXi=0769.221, RSKangXi=104.3
24D34 CJK UNIFIED IDEOGRAPH-#24D34, IRGKangXi=0769.221, RSKangXi=104.3
24D35 CJK UNIFIED IDEOGRAPH-#24D35, IRGKangXi=0769.221, RSKangXi=104.3
24D36 CJK UNIFIED IDEOGRAPH-#24D36, IRGKangXi=0769.221, RSKangXi=104.3
24D37 CJK UNIFIED IDEOGRAPH-#24D37, IRGKangXi=0769.230, RSKangXi=104.4
24D38 CJK UNIFIED IDEOGRAPH-#24D38, IRGKangXi=0769.260, RSKangXi=104.4
24D39 CJK UNIFIED IDEOGRAPH-#24D39, IRGKangXi=0769.270, RSKangXi=104.4
24D3A CJK UNIFIED IDEOGRAPH-#24D3A, IRGKangXi=0769.280, RSKangXi=104.4
24D3B CJK UNIFIED IDEOGRAPH-#24D3B, IRGKangXi=0770.020, RSKangXi=104.4
24D3C CJK UNIFIED IDEOGRAPH-#24D3C, IRGKangXi=0770.030, RSKangXi=104.4
24D3D CJK UNIFIED IDEOGRAPH-#24D3D, IRGKangXi=0770.050, RSKangXi=104.4
24D3E CJK UNIFIED IDEOGRAPH-#24D3E, IRGKangXi=0770.070, RSKangXi=104.4
24D3F CJK UNIFIED IDEOGRAPH-#24D3F, IRGKangXi=0770.090, RSKangXi=104.4
24D40 CJK UNIFIED IDEOGRAPH-#24D40, IRGKangXi=0770.100, RSKangXi=104.4
24D41 CJK UNIFIED IDEOGRAPH-#24D41, IRGKangXi=0770.130, RSKangXi=104.4
24D42 CJK UNIFIED IDEOGRAPH-#24D42, IRGKangXi=0770.160, RSKangXi=104.4
24D43 CJK UNIFIED IDEOGRAPH-#24D43, IRGKangXi=0770.190, RSKangXi=104.4
24D44 CJK UNIFIED IDEOGRAPH-#24D44, IRGKangXi=0770.191, RSKangXi=104.4
24D45 CJK UNIFIED IDEOGRAPH-#24D45, IRGKangXi=0770.191, RSKangXi=104.4
24D46 CJK UNIFIED IDEOGRAPH-#24D46, IRGKangXi=0770.191, RSKangXi=104.4
24D47 CJK UNIFIED IDEOGRAPH-#24D47, IRGKangXi=0770.191, RSKangXi=104.4
24D48 CJK UNIFIED IDEOGRAPH-#24D48, IRGKangXi=0770.191, RSKangXi=104.4
24D49 CJK UNIFIED IDEOGRAPH-#24D49, IRGKangXi=0770.191, RSKangXi=104.4
24D4A CJK UNIFIED IDEOGRAPH-#24D4A, IRGKangXi=0770.191, RSKangXi=104.4
24D4B CJK UNIFIED IDEOGRAPH-#24D4B, IRGKangXi=0770.191, RSKangXi=104.4
24D4C CJK UNIFIED IDEOGRAPH-#24D4C, IRGKangXi=0770.191, RSKangXi=104.4
24D4D CJK UNIFIED IDEOGRAPH-#24D4D, IRGKangXi=0770.191, RSKangXi=104.4
24D4E CJK UNIFIED IDEOGRAPH-#24D4E, IRGKangXi=0770.191, RSKangXi=104.4
24D4F CJK UNIFIED IDEOGRAPH-#24D4F, IRGKangXi=0770.191, RSKangXi=104.4
24D50 CJK UNIFIED IDEOGRAPH-#24D50, IRGKangXi=0770.191, RSKangXi=104.4
24D51 CJK UNIFIED IDEOGRAPH-#24D51, IRGKangXi=0770.191, RSKangXi=104.4
24D52 CJK UNIFIED IDEOGRAPH-#24D52, IRGKangXi=0770.191, RSKangXi=104.4
24D53 CJK UNIFIED IDEOGRAPH-#24D53, IRGKangXi=0770.191, RSKangXi=104.4
24D54 CJK UNIFIED IDEOGRAPH-#24D54, IRGKangXi=0770.191, RSKangXi=104.4
24D55 CJK UNIFIED IDEOGRAPH-#24D55, IRGKangXi=0770.191, RSKangXi=104.4
24D56 CJK UNIFIED IDEOGRAPH-#24D56, IRGKangXi=0770.191, RSKangXi=104.4
24D57 CJK UNIFIED IDEOGRAPH-#24D57, IRGKangXi=0771.020, RSKangXi=104.5
24D58 CJK UNIFIED IDEOGRAPH-#24D58, IRGKangXi=0771.080, RSKangXi=104.5
24D59 CJK UNIFIED IDEOGRAPH-#24D59, IRGKangXi=0771.090, RSKangXi=104.5
24D5A CJK UNIFIED IDEOGRAPH-#24D5A, IRGKangXi=0771.100, RSKangXi=104.5, Def{humpback}
24D5B CJK UNIFIED IDEOGRAPH-#24D5B, IRGKangXi=0771.180, RSKangXi=104.5
24D5C CJK UNIFIED IDEOGRAPH-#24D5C, IRGKangXi=0771.190, RSKangXi=104.5
24D5D CJK UNIFIED IDEOGRAPH-#24D5D, IRGKangXi=0771.210, RSKangXi=104.5
24D5E CJK UNIFIED IDEOGRAPH-#24D5E, IRGKangXi=0771.290, RSKangXi=104.5
24D5F CJK UNIFIED IDEOGRAPH-#24D5F, IRGKangXi=0771.300, RSKangXi=104.5
24D60 CJK UNIFIED IDEOGRAPH-#24D60, IRGKangXi=0771.330, RSKangXi=104.5
24D61 CJK UNIFIED IDEOGRAPH-#24D61, IRGKangXi=0772.020, RSKangXi=104.5
24D62 CJK UNIFIED IDEOGRAPH-#24D62, IRGKangXi=0772.040, RSKangXi=104.5
24D63 CJK UNIFIED IDEOGRAPH-#24D63, IRGKangXi=0772.070, RSKangXi=104.5
24D64 CJK UNIFIED IDEOGRAPH-#24D64, IRGKangXi=0772.090, RSKangXi=104.5
24D65 CJK UNIFIED IDEOGRAPH-#24D65, IRGKangXi=0772.100, RSKangXi=104.5
24D66 CJK UNIFIED IDEOGRAPH-#24D66, IRGKangXi=0772.110, RSKangXi=104.5
24D67 CJK UNIFIED IDEOGRAPH-#24D67, IRGKangXi=0772.111, RSKangXi=104.5
24D68 CJK UNIFIED IDEOGRAPH-#24D68, IRGKangXi=0772.111, RSKangXi=104.5
24D69 CJK UNIFIED IDEOGRAPH-#24D69, IRGKangXi=0772.111, RSKangXi=104.5
24D6A CJK UNIFIED IDEOGRAPH-#24D6A, IRGKangXi=0772.111, RSKangXi=104.5
24D6B CJK UNIFIED IDEOGRAPH-#24D6B, IRGKangXi=0772.111, RSKangXi=104.5
24D6C CJK UNIFIED IDEOGRAPH-#24D6C, IRGKangXi=0772.111, RSKangXi=104.5
24D6D CJK UNIFIED IDEOGRAPH-#24D6D, IRGKangXi=0772.111, RSKangXi=104.5
24D6E CJK UNIFIED IDEOGRAPH-#24D6E, IRGKangXi=0772.111, RSKangXi=104.5
24D6F CJK UNIFIED IDEOGRAPH-#24D6F, IRGKangXi=0772.111, RSKangXi=104.5
24D70 CJK UNIFIED IDEOGRAPH-#24D70, IRGKangXi=0772.111, RSKangXi=104.5
24D71 CJK UNIFIED IDEOGRAPH-#24D71, IRGKangXi=0772.111, RSKangXi=104.5
24D72 CJK UNIFIED IDEOGRAPH-#24D72, IRGKangXi=0772.111, RSKangXi=104.5
24D73 CJK UNIFIED IDEOGRAPH-#24D73, IRGKangXi=0772.111, RSKangXi=104.5
24D74 CJK UNIFIED IDEOGRAPH-#24D74, IRGKangXi=0772.111, RSKangXi=104.5
24D75 CJK UNIFIED IDEOGRAPH-#24D75, IRGKangXi=0772.111, RSKangXi=104.5
24D76 CJK UNIFIED IDEOGRAPH-#24D76, IRGKangXi=0772.111, RSKangXi=104.5
24D77 CJK UNIFIED IDEOGRAPH-#24D77, IRGKangXi=0772.170, RSKangXi=104.6
24D78 CJK UNIFIED IDEOGRAPH-#24D78, IRGKangXi=0772.180, RSKangXi=104.6
24D79 CJK UNIFIED IDEOGRAPH-#24D79, IRGKangXi=0772.200, RSKangXi=104.6
24D7A CJK UNIFIED IDEOGRAPH-#24D7A, IRGKangXi=0772.210, RSKangXi=104.6
24D7B CJK UNIFIED IDEOGRAPH-#24D7B, IRGKangXi=0772.240, RSKangXi=104.6
24D7C CJK UNIFIED IDEOGRAPH-#24D7C, IRGKangXi=0772.270, RSKangXi=104.6
24D7D CJK UNIFIED IDEOGRAPH-#24D7D, IRGKangXi=0773.010, RSKangXi=104.6
24D7E CJK UNIFIED IDEOGRAPH-#24D7E, IRGKangXi=0773.030, RSKangXi=104.6
24D7F CJK UNIFIED IDEOGRAPH-#24D7F, IRGKangXi=0773.070, RSKangXi=104.6
24D80 CJK UNIFIED IDEOGRAPH-#24D80, IRGKangXi=0773.090, RSKangXi=104.6
24D81 CJK UNIFIED IDEOGRAPH-#24D81, IRGKangXi=0773.110, RSKangXi=104.6
24D82 CJK UNIFIED IDEOGRAPH-#24D82, IRGKangXi=0773.121, RSKangXi=104.6
24D83 CJK UNIFIED IDEOGRAPH-#24D83, IRGKangXi=0773.121, RSKangXi=104.6
24D84 CJK UNIFIED IDEOGRAPH-#24D84, IRGKangXi=0773.121, RSKangXi=104.6
24D85 CJK UNIFIED IDEOGRAPH-#24D85, IRGKangXi=0773.130, RSKangXi=104.6
24D86 CJK UNIFIED IDEOGRAPH-#24D86, IRGKangXi=0773.150, RSKangXi=104.6
24D87 CJK UNIFIED IDEOGRAPH-#24D87, IRGKangXi=0773.151, RSKangXi=104.6
24D88 CJK UNIFIED IDEOGRAPH-#24D88, IRGKangXi=0773.151, RSKangXi=104.6
24D89 CJK UNIFIED IDEOGRAPH-#24D89, IRGKangXi=0773.151, RSKangXi=104.6
24D8A CJK UNIFIED IDEOGRAPH-#24D8A, IRGKangXi=0773.151, RSKangXi=104.6
24D8B CJK UNIFIED IDEOGRAPH-#24D8B, IRGKangXi=0773.151, RSKangXi=104.6
24D8C CJK UNIFIED IDEOGRAPH-#24D8C, IRGKangXi=0773.151, RSKangXi=104.6
24D8D CJK UNIFIED IDEOGRAPH-#24D8D, IRGKangXi=0773.151, RSKangXi=104.6
24D8E CJK UNIFIED IDEOGRAPH-#24D8E, IRGKangXi=0773.151, RSKangXi=104.6
24D8F CJK UNIFIED IDEOGRAPH-#24D8F, IRGKangXi=0773.151, RSKangXi=104.6
24D90 CJK UNIFIED IDEOGRAPH-#24D90, IRGKangXi=0773.151, RSKangXi=104.6
24D91 CJK UNIFIED IDEOGRAPH-#24D91, IRGKangXi=0773.151, RSKangXi=104.6
24D92 CJK UNIFIED IDEOGRAPH-#24D92, IRGKangXi=0773.151, RSKangXi=104.6
24D93 CJK UNIFIED IDEOGRAPH-#24D93, IRGKangXi=0773.151, RSKangXi=104.6
24D94 CJK UNIFIED IDEOGRAPH-#24D94, IRGKangXi=0773.151, RSKangXi=104.6
24D95 CJK UNIFIED IDEOGRAPH-#24D95, IRGKangXi=0773.240, RSKangXi=104.7
24D96 CJK UNIFIED IDEOGRAPH-#24D96, IRGKangXi=0773.260, RSKangXi=104.7
24D97 CJK UNIFIED IDEOGRAPH-#24D97, IRGKangXi=0773.270, RSKangXi=104.7
24D98 CJK UNIFIED IDEOGRAPH-#24D98, IRGKangXi=0773.300, RSKangXi=104.7
24D99 CJK UNIFIED IDEOGRAPH-#24D99, IRGKangXi=0773.320, RSKangXi=104.7
24D9A CJK UNIFIED IDEOGRAPH-#24D9A, IRGKangXi=0773.340, RSKangXi=104.7
24D9B CJK UNIFIED IDEOGRAPH-#24D9B, IRGKangXi=0773.350, RSKangXi=104.7
24D9C CJK UNIFIED IDEOGRAPH-#24D9C, IRGKangXi=0773.370, RSKangXi=104.7
24D9D CJK UNIFIED IDEOGRAPH-#24D9D, IRGKangXi=0774.030, RSKangXi=104.7
24D9E CJK UNIFIED IDEOGRAPH-#24D9E, IRGKangXi=0774.110, RSKangXi=104.7
24D9F CJK UNIFIED IDEOGRAPH-#24D9F, IRGKangXi=0774.120, RSKangXi=104.7
24DA0 CJK UNIFIED IDEOGRAPH-#24DA0, IRGKangXi=0774.150, RSKangXi=104.7
24DA1 CJK UNIFIED IDEOGRAPH-#24DA1, IRGKangXi=0774.160, RSKangXi=104.7
24DA2 CJK UNIFIED IDEOGRAPH-#24DA2, IRGKangXi=0774.210, RSKangXi=104.7
24DA3 CJK UNIFIED IDEOGRAPH-#24DA3, IRGKangXi=0774.220, RSKangXi=104.7
24DA4 CJK UNIFIED IDEOGRAPH-#24DA4, IRGKangXi=0774.240, RSKangXi=104.7
24DA5 CJK UNIFIED IDEOGRAPH-#24DA5, IRGKangXi=0774.250, RSKangXi=104.7
24DA6 CJK UNIFIED IDEOGRAPH-#24DA6, IRGKangXi=0774.251, RSKangXi=104.7
24DA7 CJK UNIFIED IDEOGRAPH-#24DA7, IRGKangXi=0774.251, RSKangXi=104.7
24DA8 CJK UNIFIED IDEOGRAPH-#24DA8, IRGKangXi=0774.251, RSKangXi=104.7
24DA9 CJK UNIFIED IDEOGRAPH-#24DA9, IRGKangXi=0774.251, RSKangXi=104.7
24DAA CJK UNIFIED IDEOGRAPH-#24DAA, IRGKangXi=0774.251, RSKangXi=104.7
24DAB CJK UNIFIED IDEOGRAPH-#24DAB, IRGKangXi=0774.251, RSKangXi=104.7
24DAC CJK UNIFIED IDEOGRAPH-#24DAC, IRGKangXi=0774.251, RSKangXi=104.7
24DAD CJK UNIFIED IDEOGRAPH-#24DAD, IRGKangXi=0774.251, RSKangXi=104.7
24DAE CJK UNIFIED IDEOGRAPH-#24DAE, IRGKangXi=0774.251, RSKangXi=104.7
24DAF CJK UNIFIED IDEOGRAPH-#24DAF, IRGKangXi=0774.251, RSKangXi=104.7
24DB0 CJK UNIFIED IDEOGRAPH-#24DB0, IRGKangXi=0774.251, RSKangXi=104.7
24DB1 CJK UNIFIED IDEOGRAPH-#24DB1, IRGKangXi=0774.251, RSKangXi=104.7
24DB2 CJK UNIFIED IDEOGRAPH-#24DB2, IRGKangXi=0774.251, RSKangXi=104.7
24DB3 CJK UNIFIED IDEOGRAPH-#24DB3, IRGKangXi=0774.251, RSKangXi=104.7
24DB4 CJK UNIFIED IDEOGRAPH-#24DB4, IRGKangXi=0774.251, RSKangXi=104.7
24DB5 CJK UNIFIED IDEOGRAPH-#24DB5, IRGKangXi=0774.251, RSKangXi=104.7
24DB6 CJK UNIFIED IDEOGRAPH-#24DB6, IRGKangXi=0774.251, RSKangXi=104.7
24DB7 CJK UNIFIED IDEOGRAPH-#24DB7, IRGKangXi=0774.251, RSKangXi=104.7
24DB8 CJK UNIFIED IDEOGRAPH-#24DB8, IRGKangXi=0774.251, RSKangXi=104.7, Def{(Cant.) a scar}
24DB9 CJK UNIFIED IDEOGRAPH-#24DB9, IRGKangXi=0774.251, RSKangXi=104.7
24DBA CJK UNIFIED IDEOGRAPH-#24DBA, IRGKangXi=0774.251, RSKangXi=104.7
24DBB CJK UNIFIED IDEOGRAPH-#24DBB, IRGKangXi=0774.251, RSKangXi=104.7
24DBC CJK UNIFIED IDEOGRAPH-#24DBC, IRGKangXi=0774.251, RSKangXi=104.7
24DBD CJK UNIFIED IDEOGRAPH-#24DBD, IRGKangXi=0774.251, RSKangXi=104.7
24DBE CJK UNIFIED IDEOGRAPH-#24DBE, IRGKangXi=0774.251, RSKangXi=104.7
24DBF CJK UNIFIED IDEOGRAPH-#24DBF, IRGKangXi=0774.251, RSKangXi=104.7
24DC0 CJK UNIFIED IDEOGRAPH-#24DC0, IRGKangXi=0774.251, RSKangXi=104.7
24DC1 CJK UNIFIED IDEOGRAPH-#24DC1, IRGKangXi=0774.251, RSKangXi=104.7
24DC2 CJK UNIFIED IDEOGRAPH-#24DC2, IRGKangXi=0774.340, RSKangXi=104.8
24DC3 CJK UNIFIED IDEOGRAPH-#24DC3, IRGKangXi=0774.370, RSKangXi=104.8
24DC4 CJK UNIFIED IDEOGRAPH-#24DC4, IRGKangXi=0775.020, RSKangXi=104.8
24DC5 CJK UNIFIED IDEOGRAPH-#24DC5, IRGKangXi=0775.030, RSKangXi=104.8
24DC6 CJK UNIFIED IDEOGRAPH-#24DC6, IRGKangXi=0775.040, RSKangXi=104.8
24DC7 CJK UNIFIED IDEOGRAPH-#24DC7, IRGKangXi=0775.060, RSKangXi=104.8, Def{(Cant.) severe pain}
24DC8 CJK UNIFIED IDEOGRAPH-#24DC8, IRGKangXi=0775.070, RSKangXi=104.8
24DC9 CJK UNIFIED IDEOGRAPH-#24DC9, IRGKangXi=0775.080, RSKangXi=104.8
24DCA CJK UNIFIED IDEOGRAPH-#24DCA, IRGKangXi=0775.090, RSKangXi=104.8
24DCB CJK UNIFIED IDEOGRAPH-#24DCB, IRGKangXi=0775.100, RSKangXi=104.8
24DCC CJK UNIFIED IDEOGRAPH-#24DCC, IRGKangXi=0775.130, RSKangXi=104.8
24DCD CJK UNIFIED IDEOGRAPH-#24DCD, IRGKangXi=0775.140, RSKangXi=104.8
24DCE CJK UNIFIED IDEOGRAPH-#24DCE, IRGKangXi=0775.160, RSKangXi=104.8
24DCF CJK UNIFIED IDEOGRAPH-#24DCF, IRGKangXi=0775.170, RSKangXi=104.8
24DD0 CJK UNIFIED IDEOGRAPH-#24DD0, IRGKangXi=0775.180, RSKangXi=104.8
24DD1 CJK UNIFIED IDEOGRAPH-#24DD1, IRGKangXi=0775.200, RSKangXi=104.8
24DD2 CJK UNIFIED IDEOGRAPH-#24DD2, IRGKangXi=0775.230, RSKangXi=104.8
24DD3 CJK UNIFIED IDEOGRAPH-#24DD3, IRGKangXi=0775.240, RSKangXi=104.8
24DD4 CJK UNIFIED IDEOGRAPH-#24DD4, IRGKangXi=0775.270, RSKangXi=104.8
24DD5 CJK UNIFIED IDEOGRAPH-#24DD5, IRGKangXi=0775.310, RSKangXi=104.8
24DD6 CJK UNIFIED IDEOGRAPH-#24DD6, IRGKangXi=0775.340, RSKangXi=104.8
24DD7 CJK UNIFIED IDEOGRAPH-#24DD7, IRGKangXi=0776.030, RSKangXi=104.8
24DD8 CJK UNIFIED IDEOGRAPH-#24DD8, IRGKangXi=0776.040, RSKangXi=104.8
24DD9 CJK UNIFIED IDEOGRAPH-#24DD9, IRGKangXi=0776.070, RSKangXi=104.8
24DDA CJK UNIFIED IDEOGRAPH-#24DDA, IRGKangXi=0776.090, RSKangXi=104.8
24DDB CJK UNIFIED IDEOGRAPH-#24DDB, IRGKangXi=0776.100, RSKangXi=104.8
24DDC CJK UNIFIED IDEOGRAPH-#24DDC, IRGKangXi=0776.110, RSKangXi=104.8
24DDD CJK UNIFIED IDEOGRAPH-#24DDD, IRGKangXi=0776.111, RSKangXi=104.8
24DDE CJK UNIFIED IDEOGRAPH-#24DDE, IRGKangXi=0776.111, RSKangXi=104.8
24DDF CJK UNIFIED IDEOGRAPH-#24DDF, IRGKangXi=0776.111, RSKangXi=104.8
24DE0 CJK UNIFIED IDEOGRAPH-#24DE0, IRGKangXi=0776.111, RSKangXi=104.8
24DE1 CJK UNIFIED IDEOGRAPH-#24DE1, IRGKangXi=0776.111, RSKangXi=104.8
24DE2 CJK UNIFIED IDEOGRAPH-#24DE2, IRGKangXi=0776.111, RSKangXi=104.8
24DE3 CJK UNIFIED IDEOGRAPH-#24DE3, IRGKangXi=0776.111, RSKangXi=104.8
24DE4 CJK UNIFIED IDEOGRAPH-#24DE4, IRGKangXi=0776.111, RSKangXi=104.8
24DE5 CJK UNIFIED IDEOGRAPH-#24DE5, IRGKangXi=0776.111, RSKangXi=104.8
24DE6 CJK UNIFIED IDEOGRAPH-#24DE6, IRGKangXi=0776.111, RSKangXi=104.8
24DE7 CJK UNIFIED IDEOGRAPH-#24DE7, IRGKangXi=0776.111, RSKangXi=104.8
24DE8 CJK UNIFIED IDEOGRAPH-#24DE8, IRGKangXi=0776.111, RSKangXi=104.8
24DE9 CJK UNIFIED IDEOGRAPH-#24DE9, IRGKangXi=0776.111, RSKangXi=104.8
24DEA CJK UNIFIED IDEOGRAPH-#24DEA, IRGKangXi=0776.111, RSKangXi=104.8, Def{(Cant.) impatient, restless}
24DEB CJK UNIFIED IDEOGRAPH-#24DEB, IRGKangXi=0776.111, RSKangXi=104.8, Def{(Cant.) a prickling pain, ache}
24DEC CJK UNIFIED IDEOGRAPH-#24DEC, IRGKangXi=0776.111, RSKangXi=104.8
24DED CJK UNIFIED IDEOGRAPH-#24DED, IRGKangXi=0776.111, RSKangXi=104.8
24DEE CJK UNIFIED IDEOGRAPH-#24DEE, IRGKangXi=0776.111, RSKangXi=104.8
24DEF CJK UNIFIED IDEOGRAPH-#24DEF, IRGKangXi=0776.111, RSKangXi=104.8
24DF0 CJK UNIFIED IDEOGRAPH-#24DF0, IRGKangXi=0776.111, RSKangXi=104.8
24DF1 CJK UNIFIED IDEOGRAPH-#24DF1, IRGKangXi=0776.111, RSKangXi=104.8
24DF2 CJK UNIFIED IDEOGRAPH-#24DF2, IRGKangXi=0776.111, RSKangXi=104.8
24DF3 CJK UNIFIED IDEOGRAPH-#24DF3, IRGKangXi=0776.111, RSKangXi=104.8
24DF4 CJK UNIFIED IDEOGRAPH-#24DF4, IRGKangXi=0776.111, RSKangXi=104.8
24DF5 CJK UNIFIED IDEOGRAPH-#24DF5, IRGKangXi=0776.111, RSKangXi=104.8
24DF6 CJK UNIFIED IDEOGRAPH-#24DF6, IRGKangXi=0776.111, RSKangXi=104.8
24DF7 CJK UNIFIED IDEOGRAPH-#24DF7, IRGKangXi=0776.111, RSKangXi=104.8
24DF8 CJK UNIFIED IDEOGRAPH-#24DF8, IRGKangXi=0776.111, RSKangXi=104.8
24DF9 CJK UNIFIED IDEOGRAPH-#24DF9, IRGKangXi=0776.111, RSKangXi=104.8
24DFA CJK UNIFIED IDEOGRAPH-#24DFA, IRGKangXi=0776.111, RSKangXi=104.8
24DFB CJK UNIFIED IDEOGRAPH-#24DFB, IRGKangXi=0776.120, RSKangXi=104.9
24DFC CJK UNIFIED IDEOGRAPH-#24DFC, IRGKangXi=0776.170, RSKangXi=104.9
24DFD CJK UNIFIED IDEOGRAPH-#24DFD, IRGKangXi=0776.190, RSKangXi=104.9
24DFE CJK UNIFIED IDEOGRAPH-#24DFE, IRGKangXi=0776.230, RSKangXi=104.9
24DFF CJK UNIFIED IDEOGRAPH-#24DFF, IRGKangXi=0776.240, RSKangXi=104.9
24E00 CJK UNIFIED IDEOGRAPH-#24E00, IRGKangXi=0776.260, RSKangXi=104.9
24E01 CJK UNIFIED IDEOGRAPH-#24E01, IRGKangXi=0776.290, RSKangXi=104.9
24E02 CJK UNIFIED IDEOGRAPH-#24E02, IRGKangXi=0776.300, RSKangXi=104.9
24E03 CJK UNIFIED IDEOGRAPH-#24E03, IRGKangXi=0776.310, RSKangXi=104.9
24E04 CJK UNIFIED IDEOGRAPH-#24E04, IRGKangXi=0776.320, RSKangXi=104.9
24E05 CJK UNIFIED IDEOGRAPH-#24E05, IRGKangXi=0776.350, RSKangXi=104.9
24E06 CJK UNIFIED IDEOGRAPH-#24E06, IRGKangXi=0776.360, RSKangXi=104.9
24E07 CJK UNIFIED IDEOGRAPH-#24E07, IRGKangXi=0776.370, RSKangXi=104.9
24E08 CJK UNIFIED IDEOGRAPH-#24E08, IRGKangXi=0776.400, RSKangXi=104.9
24E09 CJK UNIFIED IDEOGRAPH-#24E09, IRGKangXi=0776.410, RSKangXi=104.9
24E0A CJK UNIFIED IDEOGRAPH-#24E0A, IRGKangXi=0776.420, RSKangXi=104.9
24E0B CJK UNIFIED IDEOGRAPH-#24E0B, IRGKangXi=0776.430, RSKangXi=104.9
24E0C CJK UNIFIED IDEOGRAPH-#24E0C, IRGKangXi=0777.010, RSKangXi=104.9
24E0D CJK UNIFIED IDEOGRAPH-#24E0D, IRGKangXi=0777.030, RSKangXi=104.9
24E0E CJK UNIFIED IDEOGRAPH-#24E0E, IRGKangXi=0777.040, RSKangXi=104.9
24E0F CJK UNIFIED IDEOGRAPH-#24E0F, IRGKangXi=0777.060, RSKangXi=104.9
24E10 CJK UNIFIED IDEOGRAPH-#24E10, IRGKangXi=0777.110, RSKangXi=104.9
24E11 CJK UNIFIED IDEOGRAPH-#24E11, IRGKangXi=0777.120, RSKangXi=104.9
24E12 CJK UNIFIED IDEOGRAPH-#24E12, IRGKangXi=0777.140, RSKangXi=104.9
24E13 CJK UNIFIED IDEOGRAPH-#24E13, IRGKangXi=0777.150, RSKangXi=104.9
24E14 CJK UNIFIED IDEOGRAPH-#24E14, IRGKangXi=0777.160, RSKangXi=104.9
24E15 CJK UNIFIED IDEOGRAPH-#24E15, IRGKangXi=0777.170, RSKangXi=104.9
24E16 CJK UNIFIED IDEOGRAPH-#24E16, IRGKangXi=0777.180, RSKangXi=104.9
24E17 CJK UNIFIED IDEOGRAPH-#24E17, IRGKangXi=0777.190, RSKangXi=104.9
24E18 CJK UNIFIED IDEOGRAPH-#24E18, IRGKangXi=0777.200, RSKangXi=104.9
24E19 CJK UNIFIED IDEOGRAPH-#24E19, IRGKangXi=0777.210, RSKangXi=104.9
24E1A CJK UNIFIED IDEOGRAPH-#24E1A, IRGKangXi=0777.211, RSKangXi=104.9
24E1B CJK UNIFIED IDEOGRAPH-#24E1B, IRGKangXi=0777.211, RSKangXi=104.9
24E1C CJK UNIFIED IDEOGRAPH-#24E1C, IRGKangXi=0777.211, RSKangXi=104.9
24E1D CJK UNIFIED IDEOGRAPH-#24E1D, IRGKangXi=0777.211, RSKangXi=104.9
24E1E CJK UNIFIED IDEOGRAPH-#24E1E, IRGKangXi=0777.211, RSKangXi=104.9
24E1F CJK UNIFIED IDEOGRAPH-#24E1F, IRGKangXi=0777.211, RSKangXi=104.9
24E20 CJK UNIFIED IDEOGRAPH-#24E20, IRGKangXi=0777.211, RSKangXi=104.9
24E21 CJK UNIFIED IDEOGRAPH-#24E21, IRGKangXi=0777.211, RSKangXi=104.9
24E22 CJK UNIFIED IDEOGRAPH-#24E22, IRGKangXi=0777.211, RSKangXi=104.9
24E23 CJK UNIFIED IDEOGRAPH-#24E23, IRGKangXi=0777.211, RSKangXi=104.9
24E24 CJK UNIFIED IDEOGRAPH-#24E24, IRGKangXi=0777.211, RSKangXi=104.9
24E25 CJK UNIFIED IDEOGRAPH-#24E25, IRGKangXi=0777.211, RSKangXi=104.9
24E26 CJK UNIFIED IDEOGRAPH-#24E26, IRGKangXi=0777.211, RSKangXi=104.9
24E27 CJK UNIFIED IDEOGRAPH-#24E27, IRGKangXi=0777.211, RSKangXi=104.9
24E28 CJK UNIFIED IDEOGRAPH-#24E28, IRGKangXi=0777.211, RSKangXi=104.9
24E29 CJK UNIFIED IDEOGRAPH-#24E29, IRGKangXi=0777.211, RSKangXi=104.9
24E2A CJK UNIFIED IDEOGRAPH-#24E2A, IRGKangXi=0777.230, RSKangXi=104.10
24E2B CJK UNIFIED IDEOGRAPH-#24E2B, IRGKangXi=0777.240, RSKangXi=104.10
24E2C CJK UNIFIED IDEOGRAPH-#24E2C, IRGKangXi=0777.270, RSKangXi=104.10
24E2D CJK UNIFIED IDEOGRAPH-#24E2D, IRGKangXi=0777.300, RSKangXi=104.10
24E2E CJK UNIFIED IDEOGRAPH-#24E2E, IRGKangXi=0777.320, RSKangXi=104.10
24E2F CJK UNIFIED IDEOGRAPH-#24E2F, IRGKangXi=0777.340, RSKangXi=104.10
24E30 CJK UNIFIED IDEOGRAPH-#24E30, IRGKangXi=0777.360, RSKangXi=104.10
24E31 CJK UNIFIED IDEOGRAPH-#24E31, IRGKangXi=0778.050, RSKangXi=104.10
24E32 CJK UNIFIED IDEOGRAPH-#24E32, IRGKangXi=0778.060, RSKangXi=104.10
24E33 CJK UNIFIED IDEOGRAPH-#24E33, IRGKangXi=0778.070, RSKangXi=104.10
24E34 CJK UNIFIED IDEOGRAPH-#24E34, IRGKangXi=0778.080, RSKangXi=104.10
24E35 CJK UNIFIED IDEOGRAPH-#24E35, IRGKangXi=0778.110, RSKangXi=104.10
24E36 CJK UNIFIED IDEOGRAPH-#24E36, IRGKangXi=0778.120, RSKangXi=104.10
24E37 CJK UNIFIED IDEOGRAPH-#24E37, IRGKangXi=0778.160, RSKangXi=104.10
24E38 CJK UNIFIED IDEOGRAPH-#24E38, IRGKangXi=0778.200, RSKangXi=104.10
24E39 CJK UNIFIED IDEOGRAPH-#24E39, IRGKangXi=0778.230, RSKangXi=104.10
24E3A CJK UNIFIED IDEOGRAPH-#24E3A, IRGKangXi=0778.240, RSKangXi=104.10
24E3B CJK UNIFIED IDEOGRAPH-#24E3B, IRGKangXi=0778.280, RSKangXi=104.10, Def{(Cant.) a scar, scab; and, with}
24E3C CJK UNIFIED IDEOGRAPH-#24E3C, IRGKangXi=0778.290, RSKangXi=104.10
24E3D CJK UNIFIED IDEOGRAPH-#24E3D, IRGKangXi=0779.020, RSKangXi=104.10
24E3E CJK UNIFIED IDEOGRAPH-#24E3E, IRGKangXi=0779.030, RSKangXi=104.10
24E3F CJK UNIFIED IDEOGRAPH-#24E3F, IRGKangXi=0779.040, RSKangXi=104.10
24E40 CJK UNIFIED IDEOGRAPH-#24E40, IRGKangXi=0779.041, RSKangXi=104.10
24E41 CJK UNIFIED IDEOGRAPH-#24E41, IRGKangXi=0779.041, RSKangXi=104.10
24E42 CJK UNIFIED IDEOGRAPH-#24E42, IRGKangXi=0779.041, RSKangXi=104.10
24E43 CJK UNIFIED IDEOGRAPH-#24E43, IRGKangXi=0779.041, RSKangXi=104.10
24E44 CJK UNIFIED IDEOGRAPH-#24E44, IRGKangXi=0779.041, RSKangXi=104.10
24E45 CJK UNIFIED IDEOGRAPH-#24E45, IRGKangXi=0779.041, RSKangXi=104.10
24E46 CJK UNIFIED IDEOGRAPH-#24E46, IRGKangXi=0779.041, RSKangXi=104.10
24E47 CJK UNIFIED IDEOGRAPH-#24E47, IRGKangXi=0779.041, RSKangXi=104.10
24E48 CJK UNIFIED IDEOGRAPH-#24E48, IRGKangXi=0779.041, RSKangXi=104.10
24E49 CJK UNIFIED IDEOGRAPH-#24E49, IRGKangXi=0779.041, RSKangXi=104.10
24E4A CJK UNIFIED IDEOGRAPH-#24E4A, IRGKangXi=0779.041, RSKangXi=104.10
24E4B CJK UNIFIED IDEOGRAPH-#24E4B, IRGKangXi=0779.041, RSKangXi=104.10
24E4C CJK UNIFIED IDEOGRAPH-#24E4C, IRGKangXi=0779.041, RSKangXi=104.10
24E4D CJK UNIFIED IDEOGRAPH-#24E4D, IRGKangXi=0779.041, RSKangXi=104.10
24E4E CJK UNIFIED IDEOGRAPH-#24E4E, IRGKangXi=0779.041, RSKangXi=104.10
24E4F CJK UNIFIED IDEOGRAPH-#24E4F, IRGKangXi=0779.041, RSKangXi=104.10
24E50 CJK UNIFIED IDEOGRAPH-#24E50, IRGKangXi=0779.041, RSKangXi=104.10, Def{(Cant.) a knot}
24E51 CJK UNIFIED IDEOGRAPH-#24E51, IRGKangXi=0779.041, RSKangXi=104.10
24E52 CJK UNIFIED IDEOGRAPH-#24E52, IRGKangXi=0779.041, RSKangXi=104.10
24E53 CJK UNIFIED IDEOGRAPH-#24E53, IRGKangXi=0779.041, RSKangXi=104.10
24E54 CJK UNIFIED IDEOGRAPH-#24E54, IRGKangXi=0779.041, RSKangXi=104.10
24E55 CJK UNIFIED IDEOGRAPH-#24E55, IRGKangXi=0779.041, RSKangXi=104.10
24E56 CJK UNIFIED IDEOGRAPH-#24E56, IRGKangXi=0779.041, RSKangXi=104.10
24E57 CJK UNIFIED IDEOGRAPH-#24E57, IRGKangXi=0779.041, RSKangXi=104.10
24E58 CJK UNIFIED IDEOGRAPH-#24E58, IRGKangXi=0779.041, RSKangXi=104.10
24E59 CJK UNIFIED IDEOGRAPH-#24E59, IRGKangXi=0779.041, RSKangXi=104.10
24E5A CJK UNIFIED IDEOGRAPH-#24E5A, IRGKangXi=0779.041, RSKangXi=104.10
24E5B CJK UNIFIED IDEOGRAPH-#24E5B, IRGKangXi=0779.041, RSKangXi=104.10
24E5C CJK UNIFIED IDEOGRAPH-#24E5C, IRGKangXi=0779.041, RSKangXi=104.10
24E5D CJK UNIFIED IDEOGRAPH-#24E5D, IRGKangXi=0779.050, RSKangXi=104.11
24E5E CJK UNIFIED IDEOGRAPH-#24E5E, IRGKangXi=0779.130, RSKangXi=104.11
24E5F CJK UNIFIED IDEOGRAPH-#24E5F, IRGKangXi=0779.140, RSKangXi=104.11
24E60 CJK UNIFIED IDEOGRAPH-#24E60, IRGKangXi=0779.200, RSKangXi=104.11
24E61 CJK UNIFIED IDEOGRAPH-#24E61, IRGKangXi=0779.220, RSKangXi=104.11
24E62 CJK UNIFIED IDEOGRAPH-#24E62, IRGKangXi=0779.240, RSKangXi=104.11
24E63 CJK UNIFIED IDEOGRAPH-#24E63, IRGKangXi=0779.250, RSKangXi=104.11
24E64 CJK UNIFIED IDEOGRAPH-#24E64, IRGKangXi=0779.290, RSKangXi=104.11
24E65 CJK UNIFIED IDEOGRAPH-#24E65, IRGKangXi=0779.360, RSKangXi=104.11
24E66 CJK UNIFIED IDEOGRAPH-#24E66, IRGKangXi=0780.020, RSKangXi=104.11
24E67 CJK UNIFIED IDEOGRAPH-#24E67, IRGKangXi=0780.030, RSKangXi=104.11
24E68 CJK UNIFIED IDEOGRAPH-#24E68, IRGKangXi=0780.040, RSKangXi=104.11
24E69 CJK UNIFIED IDEOGRAPH-#24E69, IRGKangXi=0780.060, RSKangXi=104.11
24E6A CJK UNIFIED IDEOGRAPH-#24E6A, IRGKangXi=0780.070, RSKangXi=104.11
24E6B CJK UNIFIED IDEOGRAPH-#24E6B, IRGKangXi=0780.080, RSKangXi=104.11
24E6C CJK UNIFIED IDEOGRAPH-#24E6C, IRGKangXi=0780.090, RSKangXi=104.11
24E6D CJK UNIFIED IDEOGRAPH-#24E6D, IRGKangXi=0780.091, RSKangXi=104.11
24E6E CJK UNIFIED IDEOGRAPH-#24E6E, IRGKangXi=0780.091, RSKangXi=104.11
24E6F CJK UNIFIED IDEOGRAPH-#24E6F, IRGKangXi=0780.091, RSKangXi=104.11
24E70 CJK UNIFIED IDEOGRAPH-#24E70, IRGKangXi=0780.091, RSKangXi=104.11
24E71 CJK UNIFIED IDEOGRAPH-#24E71, IRGKangXi=0780.091, RSKangXi=104.11
24E72 CJK UNIFIED IDEOGRAPH-#24E72, IRGKangXi=0780.091, RSKangXi=104.11
24E73 CJK UNIFIED IDEOGRAPH-#24E73, IRGKangXi=0780.091, RSKangXi=104.11
24E74 CJK UNIFIED IDEOGRAPH-#24E74, IRGKangXi=0780.091, RSKangXi=104.11
24E75 CJK UNIFIED IDEOGRAPH-#24E75, IRGKangXi=0780.091, RSKangXi=104.11
24E76 CJK UNIFIED IDEOGRAPH-#24E76, IRGKangXi=0780.091, RSKangXi=104.11
24E77 CJK UNIFIED IDEOGRAPH-#24E77, IRGKangXi=0780.091, RSKangXi=104.11
24E78 CJK UNIFIED IDEOGRAPH-#24E78, IRGKangXi=0780.091, RSKangXi=104.11
24E79 CJK UNIFIED IDEOGRAPH-#24E79, IRGKangXi=0780.091, RSKangXi=104.11
24E7A CJK UNIFIED IDEOGRAPH-#24E7A, IRGKangXi=0780.091, RSKangXi=104.11
24E7B CJK UNIFIED IDEOGRAPH-#24E7B, IRGKangXi=0780.091, RSKangXi=104.11
24E7C CJK UNIFIED IDEOGRAPH-#24E7C, IRGKangXi=0780.091, RSKangXi=104.11
24E7D CJK UNIFIED IDEOGRAPH-#24E7D, IRGKangXi=0780.091, RSKangXi=104.11
24E7E CJK UNIFIED IDEOGRAPH-#24E7E, IRGKangXi=0780.091, RSKangXi=104.11
24E7F CJK UNIFIED IDEOGRAPH-#24E7F, IRGKangXi=0780.091, RSKangXi=104.11
24E80 CJK UNIFIED IDEOGRAPH-#24E80, IRGKangXi=0780.091, RSKangXi=104.11
24E81 CJK UNIFIED IDEOGRAPH-#24E81, IRGKangXi=0780.091, RSKangXi=104.11
24E82 CJK UNIFIED IDEOGRAPH-#24E82, IRGKangXi=0780.091, RSKangXi=104.11
24E83 CJK UNIFIED IDEOGRAPH-#24E83, IRGKangXi=0780.100, RSKangXi=104.12
24E84 CJK UNIFIED IDEOGRAPH-#24E84, IRGKangXi=0780.110, RSKangXi=104.12
24E85 CJK UNIFIED IDEOGRAPH-#24E85, IRGKangXi=0780.140, RSKangXi=104.12
24E86 CJK UNIFIED IDEOGRAPH-#24E86, IRGKangXi=0780.150, RSKangXi=104.12
24E87 CJK UNIFIED IDEOGRAPH-#24E87, IRGKangXi=0780.160, RSKangXi=104.12
24E88 CJK UNIFIED IDEOGRAPH-#24E88, IRGKangXi=0780.170, RSKangXi=104.12
24E89 CJK UNIFIED IDEOGRAPH-#24E89, IRGKangXi=0780.200, RSKangXi=104.12
24E8A CJK UNIFIED IDEOGRAPH-#24E8A, IRGKangXi=0780.220, RSKangXi=104.12
24E8B CJK UNIFIED IDEOGRAPH-#24E8B, IRGKangXi=0780.230, RSKangXi=104.12
24E8C CJK UNIFIED IDEOGRAPH-#24E8C, IRGKangXi=0780.240, RSKangXi=104.12
24E8D CJK UNIFIED IDEOGRAPH-#24E8D, IRGKangXi=0780.270, RSKangXi=104.12
24E8E CJK UNIFIED IDEOGRAPH-#24E8E, IRGKangXi=0780.280, RSKangXi=104.12
24E8F CJK UNIFIED IDEOGRAPH-#24E8F, IRGKangXi=0780.290, RSKangXi=104.12
24E90 CJK UNIFIED IDEOGRAPH-#24E90, IRGKangXi=0780.330, RSKangXi=104.12
24E91 CJK UNIFIED IDEOGRAPH-#24E91, IRGKangXi=0780.340, RSKangXi=104.12
24E92 CJK UNIFIED IDEOGRAPH-#24E92, IRGKangXi=0780.350, RSKangXi=104.12
24E93 CJK UNIFIED IDEOGRAPH-#24E93, IRGKangXi=0780.360, RSKangXi=104.12, Def{suppurating ulcer; to restrain}
24E94 CJK UNIFIED IDEOGRAPH-#24E94, IRGKangXi=0780.370, RSKangXi=104.12
24E95 CJK UNIFIED IDEOGRAPH-#24E95, IRGKangXi=0780.390, RSKangXi=104.12
24E96 CJK UNIFIED IDEOGRAPH-#24E96, IRGKangXi=0781.030, RSKangXi=104.12
24E97 CJK UNIFIED IDEOGRAPH-#24E97, IRGKangXi=0781.040, RSKangXi=104.12
24E98 CJK UNIFIED IDEOGRAPH-#24E98, IRGKangXi=0781.050, RSKangXi=104.12
24E99 CJK UNIFIED IDEOGRAPH-#24E99, IRGKangXi=0781.060, RSKangXi=104.12
24E9A CJK UNIFIED IDEOGRAPH-#24E9A, IRGKangXi=0781.070, RSKangXi=104.12
24E9B CJK UNIFIED IDEOGRAPH-#24E9B, IRGKangXi=0781.080, RSKangXi=104.12
24E9C CJK UNIFIED IDEOGRAPH-#24E9C, IRGKangXi=0781.090, RSKangXi=104.12
24E9D CJK UNIFIED IDEOGRAPH-#24E9D, IRGKangXi=0781.100, RSKangXi=104.12
24E9E CJK UNIFIED IDEOGRAPH-#24E9E, IRGKangXi=0781.101, RSKangXi=104.11
24E9F CJK UNIFIED IDEOGRAPH-#24E9F, IRGKangXi=0781.101, RSKangXi=104.12
24EA0 CJK UNIFIED IDEOGRAPH-#24EA0, IRGKangXi=0781.101, RSKangXi=104.12
24EA1 CJK UNIFIED IDEOGRAPH-#24EA1, IRGKangXi=0781.101, RSKangXi=104.12
24EA2 CJK UNIFIED IDEOGRAPH-#24EA2, IRGKangXi=0781.101, RSKangXi=104.12
24EA3 CJK UNIFIED IDEOGRAPH-#24EA3, IRGKangXi=0781.101, RSKangXi=104.12
24EA4 CJK UNIFIED IDEOGRAPH-#24EA4, IRGKangXi=0781.101, RSKangXi=104.12
24EA5 CJK UNIFIED IDEOGRAPH-#24EA5, IRGKangXi=0781.101, RSKangXi=104.12
24EA6 CJK UNIFIED IDEOGRAPH-#24EA6, IRGKangXi=0781.101, RSKangXi=104.12
24EA7 CJK UNIFIED IDEOGRAPH-#24EA7, IRGKangXi=0781.101, RSKangXi=104.12, Def{(Cant.) annoyed}
24EA8 CJK UNIFIED IDEOGRAPH-#24EA8, IRGKangXi=0781.101, RSKangXi=104.12
24EA9 CJK UNIFIED IDEOGRAPH-#24EA9, IRGKangXi=0781.101, RSKangXi=104.12
24EAA CJK UNIFIED IDEOGRAPH-#24EAA, IRGKangXi=0781.101, RSKangXi=104.12
24EAB CJK UNIFIED IDEOGRAPH-#24EAB, IRGKangXi=0781.101, RSKangXi=104.12
24EAC CJK UNIFIED IDEOGRAPH-#24EAC, IRGKangXi=0781.101, RSKangXi=104.12
24EAD CJK UNIFIED IDEOGRAPH-#24EAD, IRGKangXi=0781.101, RSKangXi=104.12
24EAE CJK UNIFIED IDEOGRAPH-#24EAE, IRGKangXi=0781.101, RSKangXi=104.12
24EAF CJK UNIFIED IDEOGRAPH-#24EAF, IRGKangXi=0781.101, RSKangXi=104.12
24EB0 CJK UNIFIED IDEOGRAPH-#24EB0, IRGKangXi=0781.101, RSKangXi=104.12
24EB1 CJK UNIFIED IDEOGRAPH-#24EB1, IRGKangXi=0781.101, RSKangXi=104.12
24EB2 CJK UNIFIED IDEOGRAPH-#24EB2, IRGKangXi=0781.101, RSKangXi=104.12
24EB3 CJK UNIFIED IDEOGRAPH-#24EB3, IRGKangXi=0781.101, RSKangXi=104.12
24EB4 CJK UNIFIED IDEOGRAPH-#24EB4, IRGKangXi=0781.101, RSKangXi=104.12
24EB5 CJK UNIFIED IDEOGRAPH-#24EB5, IRGKangXi=0781.101, RSKangXi=104.12
24EB6 CJK UNIFIED IDEOGRAPH-#24EB6, IRGKangXi=0781.101, RSKangXi=104.12
24EB7 CJK UNIFIED IDEOGRAPH-#24EB7, IRGKangXi=0781.101, RSKangXi=104.12
24EB8 CJK UNIFIED IDEOGRAPH-#24EB8, IRGKangXi=0781.101, RSKangXi=104.12
24EB9 CJK UNIFIED IDEOGRAPH-#24EB9, IRGKangXi=0781.101, RSKangXi=104.12
24EBA CJK UNIFIED IDEOGRAPH-#24EBA, IRGKangXi=0781.120, RSKangXi=104.13
24EBB CJK UNIFIED IDEOGRAPH-#24EBB, IRGKangXi=0781.150, RSKangXi=104.13
24EBC CJK UNIFIED IDEOGRAPH-#24EBC, IRGKangXi=0781.170, RSKangXi=104.13
24EBD CJK UNIFIED IDEOGRAPH-#24EBD, IRGKangXi=0781.220, RSKangXi=104.13
24EBE CJK UNIFIED IDEOGRAPH-#24EBE, IRGKangXi=0781.230, RSKangXi=104.13
24EBF CJK UNIFIED IDEOGRAPH-#24EBF, IRGKangXi=0781.260, RSKangXi=104.13
24EC0 CJK UNIFIED IDEOGRAPH-#24EC0, IRGKangXi=0781.290, RSKangXi=104.13
24EC1 CJK UNIFIED IDEOGRAPH-#24EC1, IRGKangXi=0781.300, RSKangXi=104.13
24EC2 CJK UNIFIED IDEOGRAPH-#24EC2, IRGKangXi=0781.310, RSKangXi=104.13
24EC3 CJK UNIFIED IDEOGRAPH-#24EC3, IRGKangXi=0781.330, RSKangXi=104.13
24EC4 CJK UNIFIED IDEOGRAPH-#24EC4, IRGKangXi=0781.340, RSKangXi=104.13
24EC5 CJK UNIFIED IDEOGRAPH-#24EC5, IRGKangXi=0781.380, RSKangXi=104.13
24EC6 CJK UNIFIED IDEOGRAPH-#24EC6, IRGKangXi=0781.390, RSKangXi=104.13
24EC7 CJK UNIFIED IDEOGRAPH-#24EC7, IRGKangXi=0781.400, RSKangXi=104.13
24EC8 CJK UNIFIED IDEOGRAPH-#24EC8, IRGKangXi=0782.010, RSKangXi=104.13
24EC9 CJK UNIFIED IDEOGRAPH-#24EC9, IRGKangXi=0782.020, RSKangXi=104.13
24ECA CJK UNIFIED IDEOGRAPH-#24ECA, IRGKangXi=0782.021, RSKangXi=104.13
24ECB CJK UNIFIED IDEOGRAPH-#24ECB, IRGKangXi=0782.021, RSKangXi=104.13
24ECC CJK UNIFIED IDEOGRAPH-#24ECC, IRGKangXi=0782.021, RSKangXi=104.13
24ECD CJK UNIFIED IDEOGRAPH-#24ECD, IRGKangXi=0782.021, RSKangXi=104.13
24ECE CJK UNIFIED IDEOGRAPH-#24ECE, IRGKangXi=0782.021, RSKangXi=104.13
24ECF CJK UNIFIED IDEOGRAPH-#24ECF, IRGKangXi=0782.021, RSKangXi=104.13
24ED0 CJK UNIFIED IDEOGRAPH-#24ED0, IRGKangXi=0782.021, RSKangXi=104.13
24ED1 CJK UNIFIED IDEOGRAPH-#24ED1, IRGKangXi=0782.021, RSKangXi=104.13
24ED2 CJK UNIFIED IDEOGRAPH-#24ED2, IRGKangXi=0782.021, RSKangXi=104.13
24ED3 CJK UNIFIED IDEOGRAPH-#24ED3, IRGKangXi=0782.021, RSKangXi=104.13
24ED4 CJK UNIFIED IDEOGRAPH-#24ED4, IRGKangXi=0782.021, RSKangXi=104.13
24ED5 CJK UNIFIED IDEOGRAPH-#24ED5, IRGKangXi=0782.030, RSKangXi=104.14
24ED6 CJK UNIFIED IDEOGRAPH-#24ED6, IRGKangXi=0782.040, RSKangXi=104.14
24ED7 CJK UNIFIED IDEOGRAPH-#24ED7, IRGKangXi=0782.050, RSKangXi=104.14
24ED8 CJK UNIFIED IDEOGRAPH-#24ED8, IRGKangXi=0782.060, RSKangXi=104.14
24ED9 CJK UNIFIED IDEOGRAPH-#24ED9, IRGKangXi=0782.070, RSKangXi=104.14
24EDA CJK UNIFIED IDEOGRAPH-#24EDA, IRGKangXi=0782.090, RSKangXi=104.14
24EDB CJK UNIFIED IDEOGRAPH-#24EDB, IRGKangXi=0782.130, RSKangXi=104.14
24EDC CJK UNIFIED IDEOGRAPH-#24EDC, IRGKangXi=0782.170, RSKangXi=104.14
24EDD CJK UNIFIED IDEOGRAPH-#24EDD, IRGKangXi=0782.190, RSKangXi=104.14
24EDE CJK UNIFIED IDEOGRAPH-#24EDE, IRGKangXi=0782.200, RSKangXi=104.14
24EDF CJK UNIFIED IDEOGRAPH-#24EDF, IRGKangXi=0782.201, RSKangXi=104.14
24EE0 CJK UNIFIED IDEOGRAPH-#24EE0, IRGKangXi=0782.201, RSKangXi=104.14
24EE1 CJK UNIFIED IDEOGRAPH-#24EE1, IRGKangXi=0782.201, RSKangXi=104.14
24EE2 CJK UNIFIED IDEOGRAPH-#24EE2, IRGKangXi=0782.201, RSKangXi=104.14
24EE3 CJK UNIFIED IDEOGRAPH-#24EE3, IRGKangXi=0782.201, RSKangXi=104.14
24EE4 CJK UNIFIED IDEOGRAPH-#24EE4, IRGKangXi=0782.201, RSKangXi=104.14
24EE5 CJK UNIFIED IDEOGRAPH-#24EE5, IRGKangXi=0782.201, RSKangXi=104.14
24EE6 CJK UNIFIED IDEOGRAPH-#24EE6, IRGKangXi=0782.201, RSKangXi=104.14
24EE7 CJK UNIFIED IDEOGRAPH-#24EE7, IRGKangXi=0782.201, RSKangXi=104.14
24EE8 CJK UNIFIED IDEOGRAPH-#24EE8, IRGKangXi=0782.201, RSKangXi=104.14
24EE9 CJK UNIFIED IDEOGRAPH-#24EE9, IRGKangXi=0782.201, RSKangXi=104.14
24EEA CJK UNIFIED IDEOGRAPH-#24EEA, IRGKangXi=0782.201, RSKangXi=104.14
24EEB CJK UNIFIED IDEOGRAPH-#24EEB, IRGKangXi=0782.201, RSKangXi=104.14
24EEC CJK UNIFIED IDEOGRAPH-#24EEC, IRGKangXi=0782.201, RSKangXi=104.14
24EED CJK UNIFIED IDEOGRAPH-#24EED, IRGKangXi=0782.201, RSKangXi=104.14
24EEE CJK UNIFIED IDEOGRAPH-#24EEE, IRGKangXi=0782.201, RSKangXi=104.14
24EEF CJK UNIFIED IDEOGRAPH-#24EEF, IRGKangXi=0782.201, RSKangXi=104.14
24EF0 CJK UNIFIED IDEOGRAPH-#24EF0, IRGKangXi=0782.220, RSKangXi=104.15
24EF1 CJK UNIFIED IDEOGRAPH-#24EF1, IRGKangXi=0782.230, RSKangXi=104.15
24EF2 CJK UNIFIED IDEOGRAPH-#24EF2, IRGKangXi=0782.240, RSKangXi=104.15
24EF3 CJK UNIFIED IDEOGRAPH-#24EF3, IRGKangXi=0782.250, RSKangXi=104.15
24EF4 CJK UNIFIED IDEOGRAPH-#24EF4, IRGKangXi=0782.260, RSKangXi=104.15
24EF5 CJK UNIFIED IDEOGRAPH-#24EF5, IRGKangXi=0782.270, RSKangXi=104.15
24EF6 CJK UNIFIED IDEOGRAPH-#24EF6, IRGKangXi=0782.290, RSKangXi=104.15
24EF7 CJK UNIFIED IDEOGRAPH-#24EF7, IRGKangXi=0782.300, RSKangXi=104.15
24EF8 CJK UNIFIED IDEOGRAPH-#24EF8, IRGKangXi=0782.310, RSKangXi=104.15
24EF9 CJK UNIFIED IDEOGRAPH-#24EF9, IRGKangXi=0782.311, RSKangXi=104.15
24EFA CJK UNIFIED IDEOGRAPH-#24EFA, IRGKangXi=0782.311, RSKangXi=104.15
24EFB CJK UNIFIED IDEOGRAPH-#24EFB, IRGKangXi=0782.311, RSKangXi=104.15
24EFC CJK UNIFIED IDEOGRAPH-#24EFC, IRGKangXi=0782.311, RSKangXi=104.15
24EFD CJK UNIFIED IDEOGRAPH-#24EFD, IRGKangXi=0782.311, RSKangXi=104.15
24EFE CJK UNIFIED IDEOGRAPH-#24EFE, IRGKangXi=0782.311, RSKangXi=104.15
24EFF CJK UNIFIED IDEOGRAPH-#24EFF, IRGKangXi=0782.311, RSKangXi=104.15
24F00 CJK UNIFIED IDEOGRAPH-#24F00, IRGKangXi=0782.350, RSKangXi=104.16
24F01 CJK UNIFIED IDEOGRAPH-#24F01, IRGKangXi=0782.380, RSKangXi=104.16
24F02 CJK UNIFIED IDEOGRAPH-#24F02, IRGKangXi=0782.390, RSKangXi=104.16
24F03 CJK UNIFIED IDEOGRAPH-#24F03, IRGKangXi=0782.400, RSKangXi=104.16
24F04 CJK UNIFIED IDEOGRAPH-#24F04, IRGKangXi=0782.420, RSKangXi=104.16
24F05 CJK UNIFIED IDEOGRAPH-#24F05, IRGKangXi=0782.430, RSKangXi=104.16
24F06 CJK UNIFIED IDEOGRAPH-#24F06, IRGKangXi=0783.010, RSKangXi=104.16
24F07 CJK UNIFIED IDEOGRAPH-#24F07, IRGKangXi=0783.011, RSKangXi=104.16
24F08 CJK UNIFIED IDEOGRAPH-#24F08, IRGKangXi=0783.011, RSKangXi=104.16
24F09 CJK UNIFIED IDEOGRAPH-#24F09, IRGKangXi=0783.011, RSKangXi=104.16
24F0A CJK UNIFIED IDEOGRAPH-#24F0A, IRGKangXi=0783.011, RSKangXi=104.16
24F0B CJK UNIFIED IDEOGRAPH-#24F0B, IRGKangXi=0783.020, RSKangXi=104.17
24F0C CJK UNIFIED IDEOGRAPH-#24F0C, IRGKangXi=0783.070, RSKangXi=104.17
24F0D CJK UNIFIED IDEOGRAPH-#24F0D, IRGKangXi=0783.080, RSKangXi=104.17
24F0E CJK UNIFIED IDEOGRAPH-#24F0E, IRGKangXi=0783.081, RSKangXi=104.17
24F0F CJK UNIFIED IDEOGRAPH-#24F0F, IRGKangXi=0783.081, RSKangXi=104.17
24F10 CJK UNIFIED IDEOGRAPH-#24F10, IRGKangXi=0783.100, RSKangXi=104.18
24F11 CJK UNIFIED IDEOGRAPH-#24F11, IRGKangXi=0783.120, RSKangXi=104.18
24F12 CJK UNIFIED IDEOGRAPH-#24F12, IRGKangXi=0783.140, RSKangXi=104.18
24F13 CJK UNIFIED IDEOGRAPH-#24F13, IRGKangXi=0783.141, RSKangXi=104.18
24F14 CJK UNIFIED IDEOGRAPH-#24F14, IRGKangXi=0783.141, RSKangXi=104.18
24F15 CJK UNIFIED IDEOGRAPH-#24F15, IRGKangXi=0783.141, RSKangXi=104.18
24F16 CJK UNIFIED IDEOGRAPH-#24F16, IRGKangXi=0783.141, RSKangXi=104.18
24F17 CJK UNIFIED IDEOGRAPH-#24F17, IRGKangXi=0783.141, RSKangXi=104.18
24F18 CJK UNIFIED IDEOGRAPH-#24F18, IRGKangXi=0783.180, RSKangXi=104.19
24F19 CJK UNIFIED IDEOGRAPH-#24F19, IRGKangXi=0783.200, RSKangXi=104.19
24F1A CJK UNIFIED IDEOGRAPH-#24F1A, IRGKangXi=0783.210, RSKangXi=104.19
24F1B CJK UNIFIED IDEOGRAPH-#24F1B, IRGKangXi=0783.211, RSKangXi=104.19
24F1C CJK UNIFIED IDEOGRAPH-#24F1C, IRGKangXi=0783.220, RSKangXi=104.20
24F1D CJK UNIFIED IDEOGRAPH-#24F1D, IRGKangXi=0783.221, RSKangXi=104.20
24F1E CJK UNIFIED IDEOGRAPH-#24F1E, IRGKangXi=0783.221, RSKangXi=104.20
24F1F CJK UNIFIED IDEOGRAPH-#24F1F, IRGKangXi=0783.230, RSKangXi=104.21
24F20 CJK UNIFIED IDEOGRAPH-#24F20, IRGKangXi=0783.240, RSKangXi=104.21
24F21 CJK UNIFIED IDEOGRAPH-#24F21, IRGKangXi=0783.241, RSKangXi=104.21
24F22 CJK UNIFIED IDEOGRAPH-#24F22, IRGKangXi=0783.250, RSKangXi=104.22
24F23 CJK UNIFIED IDEOGRAPH-#24F23, IRGKangXi=0783.270, RSKangXi=104.23
24F24 CJK UNIFIED IDEOGRAPH-#24F24, IRGKangXi=0783.280, RSKangXi=104.24
24F25 CJK UNIFIED IDEOGRAPH-#24F25, IRGKangXi=0783.310, RSKangXi=105.2
24F26 CJK UNIFIED IDEOGRAPH-#24F26, IRGKangXi=0783.311, RSKangXi=105.2
24F27 CJK UNIFIED IDEOGRAPH-#24F27, IRGKangXi=0784.020, RSKangXi=105.4
24F28 CJK UNIFIED IDEOGRAPH-#24F28, IRGKangXi=0784.021, RSKangXi=105.4
24F29 CJK UNIFIED IDEOGRAPH-#24F29, IRGKangXi=0784.030, RSKangXi=105.5
24F2A CJK UNIFIED IDEOGRAPH-#24F2A, IRGKangXi=0784.040, RSKangXi=105.5
24F2B CJK UNIFIED IDEOGRAPH-#24F2B, IRGKangXi=0784.041, RSKangXi=105.5
24F2C CJK UNIFIED IDEOGRAPH-#24F2C, IRGKangXi=0784.050, RSKangXi=105.6
24F2D CJK UNIFIED IDEOGRAPH-#24F2D, IRGKangXi=0784.051, RSKangXi=105.6
24F2E CJK UNIFIED IDEOGRAPH-#24F2E, IRGKangXi=0784.051, RSKangXi=105.6
24F2F CJK UNIFIED IDEOGRAPH-#24F2F, IRGKangXi=0784.060, RSKangXi=105.7
24F30 CJK UNIFIED IDEOGRAPH-#24F30, IRGKangXi=0784.110, RSKangXi=105.7
24F31 CJK UNIFIED IDEOGRAPH-#24F31, IRGKangXi=0784.120, RSKangXi=105.7
24F32 CJK UNIFIED IDEOGRAPH-#24F32, IRGKangXi=0784.121, RSKangXi=105.7
24F33 CJK UNIFIED IDEOGRAPH-#24F33, IRGKangXi=0784.121, RSKangXi=105.8
24F34 CJK UNIFIED IDEOGRAPH-#24F34, IRGKangXi=0784.121, RSKangXi=105.8
24F35 CJK UNIFIED IDEOGRAPH-#24F35, IRGKangXi=0784.121, RSKangXi=105.8
24F36 CJK UNIFIED IDEOGRAPH-#24F36, IRGKangXi=0784.121, RSKangXi=105.9
24F37 CJK UNIFIED IDEOGRAPH-#24F37, IRGKangXi=0784.130, RSKangXi=105.10
24F38 CJK UNIFIED IDEOGRAPH-#24F38, IRGKangXi=0784.131, RSKangXi=105.10
24F39 CJK UNIFIED IDEOGRAPH-#24F39, IRGKangXi=0784.140, RSKangXi=105.11
24F3A CJK UNIFIED IDEOGRAPH-#24F3A, IRGKangXi=0784.150, RSKangXi=105.11
24F3B CJK UNIFIED IDEOGRAPH-#24F3B, IRGKangXi=0784.151, RSKangXi=105.15
24F3C CJK UNIFIED IDEOGRAPH-#24F3C, IRGKangXi=0784.151, RSKangXi=105.11
24F3D CJK UNIFIED IDEOGRAPH-#24F3D, IRGKangXi=0785.060, RSKangXi=106.1
24F3E CJK UNIFIED IDEOGRAPH-#24F3E, IRGKangXi=0785.071, RSKangXi=106.1
24F3F CJK UNIFIED IDEOGRAPH-#24F3F, IRGKangXi=0786.051, RSKangXi=106.2
24F40 CJK UNIFIED IDEOGRAPH-#24F40, IRGKangXi=0786.051, RSKangXi=106.2
24F41 CJK UNIFIED IDEOGRAPH-#24F41, IRGKangXi=0786.051, RSKangXi=106.2
24F42 CJK UNIFIED IDEOGRAPH-#24F42, IRGKangXi=0786.060, RSKangXi=106.3
24F43 CJK UNIFIED IDEOGRAPH-#24F43, IRGKangXi=0786.080, RSKangXi=106.3
24F44 CJK UNIFIED IDEOGRAPH-#24F44, IRGKangXi=0786.081, RSKangXi=106.3
24F45 CJK UNIFIED IDEOGRAPH-#24F45, IRGKangXi=0786.081, RSKangXi=106.3
24F46 CJK UNIFIED IDEOGRAPH-#24F46, IRGKangXi=0786.081, RSKangXi=106.3
24F47 CJK UNIFIED IDEOGRAPH-#24F47, IRGKangXi=0786.081, RSKangXi=106.3
24F48 CJK UNIFIED IDEOGRAPH-#24F48, IRGKangXi=0786.090, RSKangXi=106.4
24F49 CJK UNIFIED IDEOGRAPH-#24F49, IRGKangXi=0786.100, RSKangXi=106.4
24F4A CJK UNIFIED IDEOGRAPH-#24F4A, IRGKangXi=0786.130, RSKangXi=106.4
24F4B CJK UNIFIED IDEOGRAPH-#24F4B, IRGKangXi=0787.010, RSKangXi=106.4
24F4C CJK UNIFIED IDEOGRAPH-#24F4C, IRGKangXi=0787.030, RSKangXi=106.4
24F4D CJK UNIFIED IDEOGRAPH-#24F4D, IRGKangXi=0787.050, RSKangXi=106.4
24F4E CJK UNIFIED IDEOGRAPH-#24F4E, IRGKangXi=0787.060, RSKangXi=106.4
24F4F CJK UNIFIED IDEOGRAPH-#24F4F, IRGKangXi=0787.061, RSKangXi=106.4
24F50 CJK UNIFIED IDEOGRAPH-#24F50, IRGKangXi=0787.061, RSKangXi=106.4
24F51 CJK UNIFIED IDEOGRAPH-#24F51, IRGKangXi=0787.061, RSKangXi=106.4
24F52 CJK UNIFIED IDEOGRAPH-#24F52, IRGKangXi=0787.061, RSKangXi=106.4
24F53 CJK UNIFIED IDEOGRAPH-#24F53, IRGKangXi=0787.061, RSKangXi=106.4
24F54 CJK UNIFIED IDEOGRAPH-#24F54, IRGKangXi=0787.061, RSKangXi=106.4
24F55 CJK UNIFIED IDEOGRAPH-#24F55, IRGKangXi=0787.061, RSKangXi=106.4
24F56 CJK UNIFIED IDEOGRAPH-#24F56, IRGKangXi=0787.061, RSKangXi=106.4
24F57 CJK UNIFIED IDEOGRAPH-#24F57, IRGKangXi=0787.061, RSKangXi=106.4
24F58 CJK UNIFIED IDEOGRAPH-#24F58, IRGKangXi=0788.020, RSKangXi=106.5
24F59 CJK UNIFIED IDEOGRAPH-#24F59, IRGKangXi=0788.030, RSKangXi=106.5
24F5A CJK UNIFIED IDEOGRAPH-#24F5A, IRGKangXi=0788.040, RSKangXi=106.5
24F5B CJK UNIFIED IDEOGRAPH-#24F5B, IRGKangXi=0788.060, RSKangXi=106.5
24F5C CJK UNIFIED IDEOGRAPH-#24F5C, IRGKangXi=0788.061, RSKangXi=106.5
24F5D CJK UNIFIED IDEOGRAPH-#24F5D, IRGKangXi=0788.061, RSKangXi=106.5
24F5E CJK UNIFIED IDEOGRAPH-#24F5E, IRGKangXi=0788.061, RSKangXi=106.5
24F5F CJK UNIFIED IDEOGRAPH-#24F5F, IRGKangXi=0788.061, RSKangXi=106.5
24F60 CJK UNIFIED IDEOGRAPH-#24F60, IRGKangXi=0788.061, RSKangXi=106.5
24F61 CJK UNIFIED IDEOGRAPH-#24F61, IRGKangXi=0788.061, RSKangXi=106.5
24F62 CJK UNIFIED IDEOGRAPH-#24F62, IRGKangXi=0788.061, RSKangXi=106.5
24F63 CJK UNIFIED IDEOGRAPH-#24F63, IRGKangXi=0788.061, RSKangXi=106.5
24F64 CJK UNIFIED IDEOGRAPH-#24F64, IRGKangXi=0788.061, RSKangXi=106.5
24F65 CJK UNIFIED IDEOGRAPH-#24F65, IRGKangXi=0788.070, RSKangXi=106.6
24F66 CJK UNIFIED IDEOGRAPH-#24F66, IRGKangXi=0788.100, RSKangXi=106.6
24F67 CJK UNIFIED IDEOGRAPH-#24F67, IRGKangXi=0788.120, RSKangXi=106.6
24F68 CJK UNIFIED IDEOGRAPH-#24F68, IRGKangXi=0788.121, RSKangXi=106.6
24F69 CJK UNIFIED IDEOGRAPH-#24F69, IRGKangXi=0788.121, RSKangXi=106.6
24F6A CJK UNIFIED IDEOGRAPH-#24F6A, IRGKangXi=0788.121, RSKangXi=106.6
24F6B CJK UNIFIED IDEOGRAPH-#24F6B, IRGKangXi=0788.121, RSKangXi=106.6
24F6C CJK UNIFIED IDEOGRAPH-#24F6C, IRGKangXi=0788.160, RSKangXi=106.7
24F6D CJK UNIFIED IDEOGRAPH-#24F6D, IRGKangXi=0788.181, RSKangXi=106.7
24F6E CJK UNIFIED IDEOGRAPH-#24F6E, IRGKangXi=0788.181, RSKangXi=106.7
24F6F CJK UNIFIED IDEOGRAPH-#24F6F, IRGKangXi=0788.181, RSKangXi=106.7
24F70 CJK UNIFIED IDEOGRAPH-#24F70, IRGKangXi=0788.181, RSKangXi=106.7
24F71 CJK UNIFIED IDEOGRAPH-#24F71, IRGKangXi=0788.181, RSKangXi=106.7
24F72 CJK UNIFIED IDEOGRAPH-#24F72, IRGKangXi=0788.181, RSKangXi=106.7
24F73 CJK UNIFIED IDEOGRAPH-#24F73, IRGKangXi=0788.181, RSKangXi=106.7
24F74 CJK UNIFIED IDEOGRAPH-#24F74, IRGKangXi=0788.181, RSKangXi=106.7
24F75 CJK UNIFIED IDEOGRAPH-#24F75, IRGKangXi=0788.181, RSKangXi=106.7
24F76 CJK UNIFIED IDEOGRAPH-#24F76, IRGKangXi=0788.181, RSKangXi=106.7
24F77 CJK UNIFIED IDEOGRAPH-#24F77, IRGKangXi=0788.181, RSKangXi=106.7
24F78 CJK UNIFIED IDEOGRAPH-#24F78, IRGKangXi=0788.181, RSKangXi=106.7
24F79 CJK UNIFIED IDEOGRAPH-#24F79, IRGKangXi=0788.190, RSKangXi=106.8
24F7A CJK UNIFIED IDEOGRAPH-#24F7A, IRGKangXi=0788.210, RSKangXi=106.8
24F7B CJK UNIFIED IDEOGRAPH-#24F7B, IRGKangXi=0788.230, RSKangXi=106.8
24F7C CJK UNIFIED IDEOGRAPH-#24F7C, IRGKangXi=0788.240, RSKangXi=106.8
24F7D CJK UNIFIED IDEOGRAPH-#24F7D, IRGKangXi=0788.270, RSKangXi=106.8
24F7E CJK UNIFIED IDEOGRAPH-#24F7E, IRGKangXi=0788.280, RSKangXi=106.8
24F7F CJK UNIFIED IDEOGRAPH-#24F7F, IRGKangXi=0788.290, RSKangXi=106.8
24F80 CJK UNIFIED IDEOGRAPH-#24F80, IRGKangXi=0788.291, RSKangXi=106.8
24F81 CJK UNIFIED IDEOGRAPH-#24F81, IRGKangXi=0788.291, RSKangXi=106.8
24F82 CJK UNIFIED IDEOGRAPH-#24F82, IRGKangXi=0788.291, RSKangXi=106.8
24F83 CJK UNIFIED IDEOGRAPH-#24F83, IRGKangXi=0788.291, RSKangXi=106.8
24F84 CJK UNIFIED IDEOGRAPH-#24F84, IRGKangXi=0788.291, RSKangXi=106.8
24F85 CJK UNIFIED IDEOGRAPH-#24F85, IRGKangXi=0788.291, RSKangXi=106.8
24F86 CJK UNIFIED IDEOGRAPH-#24F86, IRGKangXi=0788.291, RSKangXi=106.8
24F87 CJK UNIFIED IDEOGRAPH-#24F87, IRGKangXi=0788.291, RSKangXi=106.8
24F88 CJK UNIFIED IDEOGRAPH-#24F88, IRGKangXi=0788.310, RSKangXi=106.9
24F89 CJK UNIFIED IDEOGRAPH-#24F89, IRGKangXi=0788.320, RSKangXi=106.9
24F8A CJK UNIFIED IDEOGRAPH-#24F8A, IRGKangXi=0788.330, RSKangXi=106.9
24F8B CJK UNIFIED IDEOGRAPH-#24F8B, IRGKangXi=0788.341, RSKangXi=106.9
24F8C CJK UNIFIED IDEOGRAPH-#24F8C, IRGKangXi=0788.341, RSKangXi=106.9
24F8D CJK UNIFIED IDEOGRAPH-#24F8D, IRGKangXi=0788.341, RSKangXi=106.9
24F8E CJK UNIFIED IDEOGRAPH-#24F8E, IRGKangXi=0788.341, RSKangXi=106.9
24F8F CJK UNIFIED IDEOGRAPH-#24F8F, IRGKangXi=0788.341, RSKangXi=106.9
24F90 CJK UNIFIED IDEOGRAPH-#24F90, IRGKangXi=0788.341, RSKangXi=106.9
24F91 CJK UNIFIED IDEOGRAPH-#24F91, IRGKangXi=0788.341, RSKangXi=106.9
24F92 CJK UNIFIED IDEOGRAPH-#24F92, IRGKangXi=0788.341, RSKangXi=106.9
24F93 CJK UNIFIED IDEOGRAPH-#24F93, IRGKangXi=0788.341, RSKangXi=106.9
24F94 CJK UNIFIED IDEOGRAPH-#24F94, IRGKangXi=0788.341, RSKangXi=106.10
24F95 CJK UNIFIED IDEOGRAPH-#24F95, IRGKangXi=0789.030, RSKangXi=106.10
24F96 CJK UNIFIED IDEOGRAPH-#24F96, IRGKangXi=0789.061, RSKangXi=106.10
24F97 CJK UNIFIED IDEOGRAPH-#24F97, IRGKangXi=0789.061, RSKangXi=106.10
24F98 CJK UNIFIED IDEOGRAPH-#24F98, IRGKangXi=0789.061, RSKangXi=106.10
24F99 CJK UNIFIED IDEOGRAPH-#24F99, IRGKangXi=0789.061, RSKangXi=106.10
24F9A CJK UNIFIED IDEOGRAPH-#24F9A, IRGKangXi=0789.061, RSKangXi=106.10
24F9B CJK UNIFIED IDEOGRAPH-#24F9B, IRGKangXi=0789.080, RSKangXi=106.11
24F9C CJK UNIFIED IDEOGRAPH-#24F9C, IRGKangXi=0789.090, RSKangXi=106.11
24F9D CJK UNIFIED IDEOGRAPH-#24F9D, IRGKangXi=0789.110, RSKangXi=106.11
24F9E CJK UNIFIED IDEOGRAPH-#24F9E, IRGKangXi=0789.120, RSKangXi=106.11
24F9F CJK UNIFIED IDEOGRAPH-#24F9F, IRGKangXi=0789.131, RSKangXi=106.11
24FA0 CJK UNIFIED IDEOGRAPH-#24FA0, IRGKangXi=0789.140, RSKangXi=106.12
24FA1 CJK UNIFIED IDEOGRAPH-#24FA1, IRGKangXi=0789.170, RSKangXi=106.12
24FA2 CJK UNIFIED IDEOGRAPH-#24FA2, IRGKangXi=0789.190, RSKangXi=106.12
24FA3 CJK UNIFIED IDEOGRAPH-#24FA3, IRGKangXi=0789.200, RSKangXi=106.12
24FA4 CJK UNIFIED IDEOGRAPH-#24FA4, IRGKangXi=0789.220, RSKangXi=106.12
24FA5 CJK UNIFIED IDEOGRAPH-#24FA5, IRGKangXi=0789.230, RSKangXi=106.12
24FA6 CJK UNIFIED IDEOGRAPH-#24FA6, IRGKangXi=0789.231, RSKangXi=106.12
24FA7 CJK UNIFIED IDEOGRAPH-#24FA7, IRGKangXi=0789.240, RSKangXi=106.13
24FA8 CJK UNIFIED IDEOGRAPH-#24FA8, IRGKangXi=0789.270, RSKangXi=106.13
24FA9 CJK UNIFIED IDEOGRAPH-#24FA9, IRGKangXi=0789.281, RSKangXi=106.13
24FAA CJK UNIFIED IDEOGRAPH-#24FAA, IRGKangXi=0789.281, RSKangXi=106.13
24FAB CJK UNIFIED IDEOGRAPH-#24FAB, IRGKangXi=0789.300, RSKangXi=106.14
24FAC CJK UNIFIED IDEOGRAPH-#24FAC, IRGKangXi=0789.310, RSKangXi=106.14
24FAD CJK UNIFIED IDEOGRAPH-#24FAD, IRGKangXi=0789.330, RSKangXi=106.14
24FAE CJK UNIFIED IDEOGRAPH-#24FAE, IRGKangXi=0789.340, RSKangXi=106.14
24FAF CJK UNIFIED IDEOGRAPH-#24FAF, IRGKangXi=0789.341, RSKangXi=106.14
24FB0 CJK UNIFIED IDEOGRAPH-#24FB0, IRGKangXi=0789.341, RSKangXi=106.14
24FB1 CJK UNIFIED IDEOGRAPH-#24FB1, IRGKangXi=0789.341, RSKangXi=106.14
24FB2 CJK UNIFIED IDEOGRAPH-#24FB2, IRGKangXi=0789.341, RSKangXi=106.14
24FB3 CJK UNIFIED IDEOGRAPH-#24FB3, IRGKangXi=0789.341, RSKangXi=106.14
24FB4 CJK UNIFIED IDEOGRAPH-#24FB4, IRGKangXi=0789.350, RSKangXi=106.15
24FB5 CJK UNIFIED IDEOGRAPH-#24FB5, IRGKangXi=0790.021, RSKangXi=106.15
24FB6 CJK UNIFIED IDEOGRAPH-#24FB6, IRGKangXi=0790.021, RSKangXi=106.15
24FB7 CJK UNIFIED IDEOGRAPH-#24FB7, IRGKangXi=0790.021, RSKangXi=106.15
24FB8 CJK UNIFIED IDEOGRAPH-#24FB8, IRGKangXi=0790.030, RSKangXi=106.16
24FB9 CJK UNIFIED IDEOGRAPH-#24FB9, IRGKangXi=0790.051, RSKangXi=106.16
24FBA CJK UNIFIED IDEOGRAPH-#24FBA, IRGKangXi=0790.051, RSKangXi=106.16
24FBB CJK UNIFIED IDEOGRAPH-#24FBB, IRGKangXi=0790.060, RSKangXi=106.17
24FBC CJK UNIFIED IDEOGRAPH-#24FBC, IRGKangXi=0790.061, RSKangXi=106.17
24FBD CJK UNIFIED IDEOGRAPH-#24FBD, IRGKangXi=0790.061, RSKangXi=106.17
24FBE CJK UNIFIED IDEOGRAPH-#24FBE, IRGKangXi=0790.080, RSKangXi=106.18
24FBF CJK UNIFIED IDEOGRAPH-#24FBF, IRGKangXi=0790.081, RSKangXi=106.18
24FC0 CJK UNIFIED IDEOGRAPH-#24FC0, IRGKangXi=0790.090, RSKangXi=106.19
24FC1 CJK UNIFIED IDEOGRAPH-#24FC1, IRGKangXi=0790.091, RSKangXi=106.19
24FC2 CJK UNIFIED IDEOGRAPH-#24FC2, IRGKangXi=0790.091, RSKangXi=106.19, Def{(Cant.) unattractive, pale}
24FC3 CJK UNIFIED IDEOGRAPH-#24FC3, IRGKangXi=0790.091, RSKangXi=106.19
24FC4 CJK UNIFIED IDEOGRAPH-#24FC4, IRGKangXi=0790.101, RSKangXi=106.20
24FC5 CJK UNIFIED IDEOGRAPH-#24FC5, IRGKangXi=0790.110, RSKangXi=106.24
24FC6 CJK UNIFIED IDEOGRAPH-#24FC6, IRGKangXi=0790.150, RSKangXi=107.2
24FC7 CJK UNIFIED IDEOGRAPH-#24FC7, IRGKangXi=0790.160, RSKangXi=107.2
24FC8 CJK UNIFIED IDEOGRAPH-#24FC8, IRGKangXi=0790.190, RSKangXi=107.3
24FC9 CJK UNIFIED IDEOGRAPH-#24FC9, IRGKangXi=0790.200, RSKangXi=107.3
24FCA CJK UNIFIED IDEOGRAPH-#24FCA, IRGKangXi=0790.210, RSKangXi=107.3
24FCB CJK UNIFIED IDEOGRAPH-#24FCB, IRGKangXi=0790.220, RSKangXi=107.3
24FCC CJK UNIFIED IDEOGRAPH-#24FCC, IRGKangXi=0790.221, RSKangXi=107.3
24FCD CJK UNIFIED IDEOGRAPH-#24FCD, IRGKangXi=0790.221, RSKangXi=107.3
24FCE CJK UNIFIED IDEOGRAPH-#24FCE, IRGKangXi=0790.240, RSKangXi=107.4, Def{to split}
24FCF CJK UNIFIED IDEOGRAPH-#24FCF, IRGKangXi=0790.260, RSKangXi=107.4
24FD0 CJK UNIFIED IDEOGRAPH-#24FD0, IRGKangXi=0790.280, RSKangXi=107.4
24FD1 CJK UNIFIED IDEOGRAPH-#24FD1, IRGKangXi=0790.290, RSKangXi=107.4
24FD2 CJK UNIFIED IDEOGRAPH-#24FD2, IRGKangXi=0790.300, RSKangXi=107.4
24FD3 CJK UNIFIED IDEOGRAPH-#24FD3, IRGKangXi=0790.301, RSKangXi=107.4
24FD4 CJK UNIFIED IDEOGRAPH-#24FD4, IRGKangXi=0790.301, RSKangXi=107.4
24FD5 CJK UNIFIED IDEOGRAPH-#24FD5, IRGKangXi=0791.020, RSKangXi=107.5
24FD6 CJK UNIFIED IDEOGRAPH-#24FD6, IRGKangXi=0791.040, RSKangXi=107.5
24FD7 CJK UNIFIED IDEOGRAPH-#24FD7, IRGKangXi=0791.050, RSKangXi=107.5
24FD8 CJK UNIFIED IDEOGRAPH-#24FD8, IRGKangXi=0791.060, RSKangXi=107.5
24FD9 CJK UNIFIED IDEOGRAPH-#24FD9, IRGKangXi=0791.080, RSKangXi=107.5
24FDA CJK UNIFIED IDEOGRAPH-#24FDA, IRGKangXi=0791.090, RSKangXi=107.5
24FDB CJK UNIFIED IDEOGRAPH-#24FDB, IRGKangXi=0791.100, RSKangXi=107.5
24FDC CJK UNIFIED IDEOGRAPH-#24FDC, IRGKangXi=0791.101, RSKangXi=107.5
24FDD CJK UNIFIED IDEOGRAPH-#24FDD, IRGKangXi=0791.101, RSKangXi=107.5
24FDE CJK UNIFIED IDEOGRAPH-#24FDE, IRGKangXi=0791.101, RSKangXi=107.5
24FDF CJK UNIFIED IDEOGRAPH-#24FDF, IRGKangXi=0791.120, RSKangXi=107.6
24FE0 CJK UNIFIED IDEOGRAPH-#24FE0, IRGKangXi=0791.130, RSKangXi=107.6
24FE1 CJK UNIFIED IDEOGRAPH-#24FE1, IRGKangXi=0791.140, RSKangXi=107.6
24FE2 CJK UNIFIED IDEOGRAPH-#24FE2, IRGKangXi=0791.151, RSKangXi=107.6
24FE3 CJK UNIFIED IDEOGRAPH-#24FE3, IRGKangXi=0791.151, RSKangXi=107.6
24FE4 CJK UNIFIED IDEOGRAPH-#24FE4, IRGKangXi=0791.151, RSKangXi=107.6
24FE5 CJK UNIFIED IDEOGRAPH-#24FE5, IRGKangXi=0791.151, RSKangXi=107.6
24FE6 CJK UNIFIED IDEOGRAPH-#24FE6, IRGKangXi=0791.151, RSKangXi=107.6
24FE7 CJK UNIFIED IDEOGRAPH-#24FE7, IRGKangXi=0791.160, RSKangXi=107.7
24FE8 CJK UNIFIED IDEOGRAPH-#24FE8, IRGKangXi=0791.190, RSKangXi=107.7
24FE9 CJK UNIFIED IDEOGRAPH-#24FE9, IRGKangXi=0791.200, RSKangXi=107.7
24FEA CJK UNIFIED IDEOGRAPH-#24FEA, IRGKangXi=0791.210, RSKangXi=107.7, Def{(Cant.) wrinkled, crumpled}
24FEB CJK UNIFIED IDEOGRAPH-#24FEB, IRGKangXi=0791.230, RSKangXi=107.7
24FEC CJK UNIFIED IDEOGRAPH-#24FEC, IRGKangXi=0791.231, RSKangXi=107.7
24FED CJK UNIFIED IDEOGRAPH-#24FED, IRGKangXi=0791.231, RSKangXi=107.7
24FEE CJK UNIFIED IDEOGRAPH-#24FEE, IRGKangXi=0791.231, RSKangXi=107.7
24FEF CJK UNIFIED IDEOGRAPH-#24FEF, IRGKangXi=0791.231, RSKangXi=107.8
24FF0 CJK UNIFIED IDEOGRAPH-#24FF0, IRGKangXi=0791.231, RSKangXi=107.7
24FF1 CJK UNIFIED IDEOGRAPH-#24FF1, IRGKangXi=0791.231, RSKangXi=107.7
24FF2 CJK UNIFIED IDEOGRAPH-#24FF2, IRGKangXi=0791.231, RSKangXi=107.7
24FF3 CJK UNIFIED IDEOGRAPH-#24FF3, IRGKangXi=0791.250, RSKangXi=107.8
24FF4 CJK UNIFIED IDEOGRAPH-#24FF4, IRGKangXi=0791.260, RSKangXi=107.8
24FF5 CJK UNIFIED IDEOGRAPH-#24FF5, IRGKangXi=0791.270, RSKangXi=107.8
24FF6 CJK UNIFIED IDEOGRAPH-#24FF6, IRGKangXi=0791.280, RSKangXi=107.8
24FF7 CJK UNIFIED IDEOGRAPH-#24FF7, IRGKangXi=0791.290, RSKangXi=107.8
24FF8 CJK UNIFIED IDEOGRAPH-#24FF8, IRGKangXi=0791.301, RSKangXi=107.8
24FF9 CJK UNIFIED IDEOGRAPH-#24FF9, IRGKangXi=0791.301, RSKangXi=107.8
24FFA CJK UNIFIED IDEOGRAPH-#24FFA, IRGKangXi=0791.301, RSKangXi=107.8
24FFB CJK UNIFIED IDEOGRAPH-#24FFB, IRGKangXi=0791.301, RSKangXi=107.8
24FFC CJK UNIFIED IDEOGRAPH-#24FFC, IRGKangXi=0791.301, RSKangXi=107.8
24FFD CJK UNIFIED IDEOGRAPH-#24FFD, IRGKangXi=0791.301, RSKangXi=107.8
24FFE CJK UNIFIED IDEOGRAPH-#24FFE, IRGKangXi=0791.301, RSKangXi=107.8
24FFF CJK UNIFIED IDEOGRAPH-#24FFF, IRGKangXi=0791.301, RSKangXi=107.8
25000 CJK UNIFIED IDEOGRAPH-#25000, IRGKangXi=0791.340, RSKangXi=107.9
25001 CJK UNIFIED IDEOGRAPH-#25001, IRGKangXi=0791.350, RSKangXi=107.9
25002 CJK UNIFIED IDEOGRAPH-#25002, IRGKangXi=0791.380, RSKangXi=107.9
25003 CJK UNIFIED IDEOGRAPH-#25003, IRGKangXi=0791.390, RSKangXi=107.9
25004 CJK UNIFIED IDEOGRAPH-#25004, IRGKangXi=0791.400, RSKangXi=107.9
25005 CJK UNIFIED IDEOGRAPH-#25005, IRGKangXi=0791.411, RSKangXi=107.9
25006 CJK UNIFIED IDEOGRAPH-#25006, IRGKangXi=0791.411, RSKangXi=107.9
25007 CJK UNIFIED IDEOGRAPH-#25007, IRGKangXi=0791.411, RSKangXi=107.9
25008 CJK UNIFIED IDEOGRAPH-#25008, IRGKangXi=0791.411, RSKangXi=107.9
25009 CJK UNIFIED IDEOGRAPH-#25009, IRGKangXi=0791.411, RSKangXi=107.9
2500A CJK UNIFIED IDEOGRAPH-#2500A, IRGKangXi=0791.411, RSKangXi=107.9
2500B CJK UNIFIED IDEOGRAPH-#2500B, IRGKangXi=0791.411, RSKangXi=107.9
2500C CJK UNIFIED IDEOGRAPH-#2500C, IRGKangXi=0791.411, RSKangXi=107.9
2500D CJK UNIFIED IDEOGRAPH-#2500D, IRGKangXi=0791.420, RSKangXi=107.10
2500E CJK UNIFIED IDEOGRAPH-#2500E, IRGKangXi=0791.430, RSKangXi=107.10
2500F CJK UNIFIED IDEOGRAPH-#2500F, IRGKangXi=0792.010, RSKangXi=107.10
25010 CJK UNIFIED IDEOGRAPH-#25010, IRGKangXi=0792.020, RSKangXi=107.10
25011 CJK UNIFIED IDEOGRAPH-#25011, IRGKangXi=0792.021, RSKangXi=107.10
25012 CJK UNIFIED IDEOGRAPH-#25012, IRGKangXi=0792.021, RSKangXi=107.10
25013 CJK UNIFIED IDEOGRAPH-#25013, IRGKangXi=0792.021, RSKangXi=107.10
25014 CJK UNIFIED IDEOGRAPH-#25014, IRGKangXi=0792.040, RSKangXi=107.11
25015 CJK UNIFIED IDEOGRAPH-#25015, IRGKangXi=0792.050, RSKangXi=107.11
25016 CJK UNIFIED IDEOGRAPH-#25016, IRGKangXi=0792.060, RSKangXi=107.11
25017 CJK UNIFIED IDEOGRAPH-#25017, IRGKangXi=0792.080, RSKangXi=107.11
25018 CJK UNIFIED IDEOGRAPH-#25018, IRGKangXi=0792.090, RSKangXi=107.11
25019 CJK UNIFIED IDEOGRAPH-#25019, IRGKangXi=0792.100, RSKangXi=107.11
2501A CJK UNIFIED IDEOGRAPH-#2501A, IRGKangXi=0792.101, RSKangXi=107.11
2501B CJK UNIFIED IDEOGRAPH-#2501B, IRGKangXi=0792.101, RSKangXi=107.11
2501C CJK UNIFIED IDEOGRAPH-#2501C, IRGKangXi=0792.101, RSKangXi=107.11
2501D CJK UNIFIED IDEOGRAPH-#2501D, IRGKangXi=0792.101, RSKangXi=107.11
2501E CJK UNIFIED IDEOGRAPH-#2501E, IRGKangXi=0792.101, RSKangXi=107.11
2501F CJK UNIFIED IDEOGRAPH-#2501F, IRGKangXi=0792.110, RSKangXi=107.12
25020 CJK UNIFIED IDEOGRAPH-#25020, IRGKangXi=0792.111, RSKangXi=107.12
25021 CJK UNIFIED IDEOGRAPH-#25021, IRGKangXi=0792.111, RSKangXi=107.12
25022 CJK UNIFIED IDEOGRAPH-#25022, IRGKangXi=0792.120, RSKangXi=107.13
25023 CJK UNIFIED IDEOGRAPH-#25023, IRGKangXi=0792.130, RSKangXi=107.13
25024 CJK UNIFIED IDEOGRAPH-#25024, IRGKangXi=0792.140, RSKangXi=107.13
25025 CJK UNIFIED IDEOGRAPH-#25025, IRGKangXi=0792.160, RSKangXi=107.13
25026 CJK UNIFIED IDEOGRAPH-#25026, IRGKangXi=0792.180, RSKangXi=107.13
25027 CJK UNIFIED IDEOGRAPH-#25027, IRGKangXi=0792.190, RSKangXi=107.13
25028 CJK UNIFIED IDEOGRAPH-#25028, IRGKangXi=0792.191, RSKangXi=107.13
25029 CJK UNIFIED IDEOGRAPH-#25029, IRGKangXi=0792.191, RSKangXi=107.13
2502A CJK UNIFIED IDEOGRAPH-#2502A, IRGKangXi=0792.191, RSKangXi=107.13
2502B CJK UNIFIED IDEOGRAPH-#2502B, IRGKangXi=0792.200, RSKangXi=107.14
2502C CJK UNIFIED IDEOGRAPH-#2502C, IRGKangXi=0792.210, RSKangXi=107.14, Def{(Cant.) a scar}
2502D CJK UNIFIED IDEOGRAPH-#2502D, IRGKangXi=0792.220, RSKangXi=107.14
2502E CJK UNIFIED IDEOGRAPH-#2502E, IRGKangXi=0792.221, RSKangXi=107.14
2502F CJK UNIFIED IDEOGRAPH-#2502F, IRGKangXi=0792.250, RSKangXi=107.15
25030 CJK UNIFIED IDEOGRAPH-#25030, IRGKangXi=0792.260, RSKangXi=107.15
25031 CJK UNIFIED IDEOGRAPH-#25031, IRGKangXi=0792.270, RSKangXi=107.15
25032 CJK UNIFIED IDEOGRAPH-#25032, IRGKangXi=0792.271, RSKangXi=107.15
25033 CJK UNIFIED IDEOGRAPH-#25033, IRGKangXi=0792.271, RSKangXi=107.15
25034 CJK UNIFIED IDEOGRAPH-#25034, IRGKangXi=0792.280, RSKangXi=107.16
25035 CJK UNIFIED IDEOGRAPH-#25035, IRGKangXi=0792.290, RSKangXi=107.16
25036 CJK UNIFIED IDEOGRAPH-#25036, IRGKangXi=0792.300, RSKangXi=107.17
25037 CJK UNIFIED IDEOGRAPH-#25037, IRGKangXi=0792.301, RSKangXi=107.17
25038 CJK UNIFIED IDEOGRAPH-#25038, IRGKangXi=0792.301, RSKangXi=107.17
25039 CJK UNIFIED IDEOGRAPH-#25039, IRGKangXi=0792.310, RSKangXi=107.19
2503A CJK UNIFIED IDEOGRAPH-#2503A, IRGKangXi=0792.320, RSKangXi=107.19
2503B CJK UNIFIED IDEOGRAPH-#2503B, IRGKangXi=0792.321, RSKangXi=207.12
2503C CJK UNIFIED IDEOGRAPH-#2503C, IRGKangXi=0792.321, RSKangXi=207.13
2503D CJK UNIFIED IDEOGRAPH-#2503D, IRGKangXi=0792.321, RSKangXi=207.16
2503E CJK UNIFIED IDEOGRAPH-#2503E, IRGKangXi=0792.321, RSKangXi=207.20
2503F CJK UNIFIED IDEOGRAPH-#2503F, IRGKangXi=0792.340, RSKangXi=108.2
25040 CJK UNIFIED IDEOGRAPH-#25040, IRGKangXi=0792.351, RSKangXi=108.2
25041 CJK UNIFIED IDEOGRAPH-#25041, IRGKangXi=0792.360, RSKangXi=108.3
25042 CJK UNIFIED IDEOGRAPH-#25042, IRGKangXi=0792.370, RSKangXi=108.3
25043 CJK UNIFIED IDEOGRAPH-#25043, IRGKangXi=0792.380, RSKangXi=108.3
25044 CJK UNIFIED IDEOGRAPH-#25044, IRGKangXi=0792.410, RSKangXi=108.3
25045 CJK UNIFIED IDEOGRAPH-#25045, IRGKangXi=0792.420, RSKangXi=108.3
25046 CJK UNIFIED IDEOGRAPH-#25046, IRGKangXi=0792.430, RSKangXi=108.4
25047 CJK UNIFIED IDEOGRAPH-#25047, IRGKangXi=0793.080, RSKangXi=108.4
25048 CJK UNIFIED IDEOGRAPH-#25048, IRGKangXi=0793.090, RSKangXi=108.4
25049 CJK UNIFIED IDEOGRAPH-#25049, IRGKangXi=0793.100, RSKangXi=108.4
2504A CJK UNIFIED IDEOGRAPH-#2504A, IRGKangXi=0793.101, RSKangXi=108.4
2504B CJK UNIFIED IDEOGRAPH-#2504B, IRGKangXi=0793.101, RSKangXi=108.4
2504C CJK UNIFIED IDEOGRAPH-#2504C, IRGKangXi=0793.101, RSKangXi=108.4
2504D CJK UNIFIED IDEOGRAPH-#2504D, IRGKangXi=0793.101, RSKangXi=108.4
2504E CJK UNIFIED IDEOGRAPH-#2504E, IRGKangXi=0793.120, RSKangXi=108.5
2504F CJK UNIFIED IDEOGRAPH-#2504F, IRGKangXi=0793.130, RSKangXi=108.5
25050 CJK UNIFIED IDEOGRAPH-#25050, IRGKangXi=0793.140, RSKangXi=108.5
25051 CJK UNIFIED IDEOGRAPH-#25051, IRGKangXi=0793.150, RSKangXi=108.5
25052 CJK UNIFIED IDEOGRAPH-#25052, IRGKangXi=0793.170, RSKangXi=108.5, Def{(Cant.) warped}
25053 CJK UNIFIED IDEOGRAPH-#25053, IRGKangXi=0793.210, RSKangXi=108.5
25054 CJK UNIFIED IDEOGRAPH-#25054, IRGKangXi=0793.240, RSKangXi=108.5
25055 CJK UNIFIED IDEOGRAPH-#25055, IRGKangXi=0793.250, RSKangXi=108.5, Def{compassionate; to feed a prisoner}
25056 CJK UNIFIED IDEOGRAPH-#25056, IRGKangXi=0794.040, RSKangXi=108.5
25057 CJK UNIFIED IDEOGRAPH-#25057, IRGKangXi=0794.041, RSKangXi=108.5
25058 CJK UNIFIED IDEOGRAPH-#25058, IRGKangXi=0794.041, RSKangXi=108.5
25059 CJK UNIFIED IDEOGRAPH-#25059, IRGKangXi=0794.041, RSKangXi=108.5
2505A CJK UNIFIED IDEOGRAPH-#2505A, IRGKangXi=0794.041, RSKangXi=108.5
2505B CJK UNIFIED IDEOGRAPH-#2505B, IRGKangXi=0794.041, RSKangXi=108.5
2505C CJK UNIFIED IDEOGRAPH-#2505C, IRGKangXi=0794.041, RSKangXi=108.5
2505D CJK UNIFIED IDEOGRAPH-#2505D, IRGKangXi=0794.041, RSKangXi=108.5
2505E CJK UNIFIED IDEOGRAPH-#2505E, IRGKangXi=0794.050, RSKangXi=108.6
2505F CJK UNIFIED IDEOGRAPH-#2505F, IRGKangXi=0794.080, RSKangXi=108.6
25060 CJK UNIFIED IDEOGRAPH-#25060, IRGKangXi=0794.120, RSKangXi=108.6
25061 CJK UNIFIED IDEOGRAPH-#25061, IRGKangXi=0794.160, RSKangXi=108.6
25062 CJK UNIFIED IDEOGRAPH-#25062, IRGKangXi=0794.161, RSKangXi=108.6
25063 CJK UNIFIED IDEOGRAPH-#25063, IRGKangXi=0794.161, RSKangXi=108.6
25064 CJK UNIFIED IDEOGRAPH-#25064, IRGKangXi=0794.161, RSKangXi=108.6
25065 CJK UNIFIED IDEOGRAPH-#25065, IRGKangXi=0794.161, RSKangXi=108.6
25066 CJK UNIFIED IDEOGRAPH-#25066, IRGKangXi=0794.161, RSKangXi=108.6
25067 CJK UNIFIED IDEOGRAPH-#25067, IRGKangXi=0794.161, RSKangXi=108.6
25068 CJK UNIFIED IDEOGRAPH-#25068, IRGKangXi=0794.161, RSKangXi=108.6
25069 CJK UNIFIED IDEOGRAPH-#25069, IRGKangXi=0794.161, RSKangXi=108.6
2506A CJK UNIFIED IDEOGRAPH-#2506A, IRGKangXi=0794.161, RSKangXi=108.6
2506B CJK UNIFIED IDEOGRAPH-#2506B, IRGKangXi=0794.161, RSKangXi=108.5
2506C CJK UNIFIED IDEOGRAPH-#2506C, IRGKangXi=0794.180, RSKangXi=108.7
2506D CJK UNIFIED IDEOGRAPH-#2506D, IRGKangXi=0795.010, RSKangXi=108.7
2506E CJK UNIFIED IDEOGRAPH-#2506E, IRGKangXi=0795.030, RSKangXi=108.7
2506F CJK UNIFIED IDEOGRAPH-#2506F, IRGKangXi=0795.040, RSKangXi=108.7
25070 CJK UNIFIED IDEOGRAPH-#25070, IRGKangXi=0795.050, RSKangXi=108.7
25071 CJK UNIFIED IDEOGRAPH-#25071, IRGKangXi=0795.060, RSKangXi=108.7
25072 CJK UNIFIED IDEOGRAPH-#25072, IRGKangXi=0795.070, RSKangXi=108.7
25073 CJK UNIFIED IDEOGRAPH-#25073, IRGKangXi=0795.071, RSKangXi=108.7
25074 CJK UNIFIED IDEOGRAPH-#25074, IRGKangXi=0795.071, RSKangXi=108.7
25075 CJK UNIFIED IDEOGRAPH-#25075, IRGKangXi=0795.071, RSKangXi=108.7
25076 CJK UNIFIED IDEOGRAPH-#25076, IRGKangXi=0795.071, RSKangXi=108.7
25077 CJK UNIFIED IDEOGRAPH-#25077, IRGKangXi=0795.100, RSKangXi=108.8
25078 CJK UNIFIED IDEOGRAPH-#25078, IRGKangXi=0795.110, RSKangXi=108.8
25079 CJK UNIFIED IDEOGRAPH-#25079, IRGKangXi=0795.140, RSKangXi=108.8
2507A CJK UNIFIED IDEOGRAPH-#2507A, IRGKangXi=0795.150, RSKangXi=108.8
2507B CJK UNIFIED IDEOGRAPH-#2507B, IRGKangXi=0795.190, RSKangXi=108.8
2507C CJK UNIFIED IDEOGRAPH-#2507C, IRGKangXi=0795.200, RSKangXi=108.8
2507D CJK UNIFIED IDEOGRAPH-#2507D, IRGKangXi=0795.201, RSKangXi=108.8
2507E CJK UNIFIED IDEOGRAPH-#2507E, IRGKangXi=0795.201, RSKangXi=108.8
2507F CJK UNIFIED IDEOGRAPH-#2507F, IRGKangXi=0795.201, RSKangXi=108.8
25080 CJK UNIFIED IDEOGRAPH-#25080, IRGKangXi=0795.201, RSKangXi=108.8
25081 CJK UNIFIED IDEOGRAPH-#25081, IRGKangXi=0795.201, RSKangXi=108.8, Def{salt}
25082 CJK UNIFIED IDEOGRAPH-#25082, IRGKangXi=0795.201, RSKangXi=108.8
25083 CJK UNIFIED IDEOGRAPH-#25083, IRGKangXi=0796.060, RSKangXi=108.9
25084 CJK UNIFIED IDEOGRAPH-#25084, IRGKangXi=0796.061, RSKangXi=108.9
25085 CJK UNIFIED IDEOGRAPH-#25085, IRGKangXi=0796.061, RSKangXi=108.9
25086 CJK UNIFIED IDEOGRAPH-#25086, IRGKangXi=0796.061, RSKangXi=108.9
25087 CJK UNIFIED IDEOGRAPH-#25087, IRGKangXi=0796.070, RSKangXi=108.10
25088 CJK UNIFIED IDEOGRAPH-#25088, IRGKangXi=0796.080, RSKangXi=108.10
25089 CJK UNIFIED IDEOGRAPH-#25089, IRGKangXi=0796.101, RSKangXi=108.10
2508A CJK UNIFIED IDEOGRAPH-#2508A, IRGKangXi=0796.101, RSKangXi=108.10
2508B CJK UNIFIED IDEOGRAPH-#2508B, IRGKangXi=0796.101, RSKangXi=108.10
2508C CJK UNIFIED IDEOGRAPH-#2508C, IRGKangXi=0796.101, RSKangXi=108.10
2508D CJK UNIFIED IDEOGRAPH-#2508D, IRGKangXi=0796.101, RSKangXi=108.10
2508E CJK UNIFIED IDEOGRAPH-#2508E, IRGKangXi=0796.101, RSKangXi=108.10
2508F CJK UNIFIED IDEOGRAPH-#2508F, IRGKangXi=0796.101, RSKangXi=108.10
25090 CJK UNIFIED IDEOGRAPH-#25090, IRGKangXi=0796.101, RSKangXi=108.10
25091 CJK UNIFIED IDEOGRAPH-#25091, IRGKangXi=0796.101, RSKangXi=108.10
25092 CJK UNIFIED IDEOGRAPH-#25092, IRGKangXi=0796.101, RSKangXi=108.10
25093 CJK UNIFIED IDEOGRAPH-#25093, IRGKangXi=0796.140, RSKangXi=108.11
25094 CJK UNIFIED IDEOGRAPH-#25094, IRGKangXi=0797.010, RSKangXi=108.11
25095 CJK UNIFIED IDEOGRAPH-#25095, IRGKangXi=0797.020, RSKangXi=108.11
25096 CJK UNIFIED IDEOGRAPH-#25096, IRGKangXi=0797.030, RSKangXi=108.11
25097 CJK UNIFIED IDEOGRAPH-#25097, IRGKangXi=0797.040, RSKangXi=108.11
25098 CJK UNIFIED IDEOGRAPH-#25098, IRGKangXi=0797.050, RSKangXi=108.11
25099 CJK UNIFIED IDEOGRAPH-#25099, IRGKangXi=0797.070, RSKangXi=108.11
2509A CJK UNIFIED IDEOGRAPH-#2509A, IRGKangXi=0797.071, RSKangXi=108.11
2509B CJK UNIFIED IDEOGRAPH-#2509B, IRGKangXi=0797.071, RSKangXi=108.11
2509C CJK UNIFIED IDEOGRAPH-#2509C, IRGKangXi=0797.071, RSKangXi=108.11
2509D CJK UNIFIED IDEOGRAPH-#2509D, IRGKangXi=0797.071, RSKangXi=108.11
2509E CJK UNIFIED IDEOGRAPH-#2509E, IRGKangXi=0797.071, RSKangXi=108.11
2509F CJK UNIFIED IDEOGRAPH-#2509F, IRGKangXi=0797.071, RSKangXi=108.11
250A0 CJK UNIFIED IDEOGRAPH-#250A0, IRGKangXi=0797.071, RSKangXi=108.11
250A1 CJK UNIFIED IDEOGRAPH-#250A1, IRGKangXi=0797.071, RSKangXi=108.11
250A2 CJK UNIFIED IDEOGRAPH-#250A2, IRGKangXi=0797.071, RSKangXi=108.11
250A3 CJK UNIFIED IDEOGRAPH-#250A3, IRGKangXi=0797.071, RSKangXi=108.11
250A4 CJK UNIFIED IDEOGRAPH-#250A4, IRGKangXi=0797.090, RSKangXi=108.11
250A5 CJK UNIFIED IDEOGRAPH-#250A5, IRGKangXi=0797.100, RSKangXi=108.12
250A6 CJK UNIFIED IDEOGRAPH-#250A6, IRGKangXi=0797.120, RSKangXi=108.12
250A7 CJK UNIFIED IDEOGRAPH-#250A7, IRGKangXi=0797.140, RSKangXi=108.12
250A8 CJK UNIFIED IDEOGRAPH-#250A8, IRGKangXi=0798.010, RSKangXi=108.12
250A9 CJK UNIFIED IDEOGRAPH-#250A9, IRGKangXi=0798.020, RSKangXi=108.12
250AA CJK UNIFIED IDEOGRAPH-#250AA, IRGKangXi=0798.030, RSKangXi=108.12
250AB CJK UNIFIED IDEOGRAPH-#250AB, IRGKangXi=0798.031, RSKangXi=108.12
250AC CJK UNIFIED IDEOGRAPH-#250AC, IRGKangXi=0798.031, RSKangXi=108.12
250AD CJK UNIFIED IDEOGRAPH-#250AD, IRGKangXi=0798.031, RSKangXi=108.12
250AE CJK UNIFIED IDEOGRAPH-#250AE, IRGKangXi=0798.031, RSKangXi=108.12
250AF CJK UNIFIED IDEOGRAPH-#250AF, IRGKangXi=0798.031, RSKangXi=108.12
250B0 CJK UNIFIED IDEOGRAPH-#250B0, IRGKangXi=0798.031, RSKangXi=108.12
250B1 CJK UNIFIED IDEOGRAPH-#250B1, IRGKangXi=0798.031, RSKangXi=108.12
250B2 CJK UNIFIED IDEOGRAPH-#250B2, IRGKangXi=0798.031, RSKangXi=108.12
250B3 CJK UNIFIED IDEOGRAPH-#250B3, IRGKangXi=0798.031, RSKangXi=15.15
250B4 CJK UNIFIED IDEOGRAPH-#250B4, IRGKangXi=0798.031, RSKangXi=108.12
250B5 CJK UNIFIED IDEOGRAPH-#250B5, IRGKangXi=0798.031, RSKangXi=108.12
250B6 CJK UNIFIED IDEOGRAPH-#250B6, IRGKangXi=0798.031, RSKangXi=108.12
250B7 CJK UNIFIED IDEOGRAPH-#250B7, IRGKangXi=0798.031, RSKangXi=108.12
250B8 CJK UNIFIED IDEOGRAPH-#250B8, IRGKangXi=0798.040, RSKangXi=108.13
250B9 CJK UNIFIED IDEOGRAPH-#250B9, IRGKangXi=0798.060, RSKangXi=108.13
250BA CJK UNIFIED IDEOGRAPH-#250BA, IRGKangXi=0798.080, RSKangXi=108.13
250BB CJK UNIFIED IDEOGRAPH-#250BB, IRGKangXi=0798.090, RSKangXi=108.14
250BC CJK UNIFIED IDEOGRAPH-#250BC, IRGKangXi=0798.091, RSKangXi=108.13
250BD CJK UNIFIED IDEOGRAPH-#250BD, IRGKangXi=0798.091, RSKangXi=108.13
250BE CJK UNIFIED IDEOGRAPH-#250BE, IRGKangXi=0798.091, RSKangXi=108.13
250BF CJK UNIFIED IDEOGRAPH-#250BF, IRGKangXi=0798.091, RSKangXi=108.13
250C0 CJK UNIFIED IDEOGRAPH-#250C0, IRGKangXi=0798.091, RSKangXi=108.13
250C1 CJK UNIFIED IDEOGRAPH-#250C1, IRGKangXi=0798.110, RSKangXi=108.14
250C2 CJK UNIFIED IDEOGRAPH-#250C2, IRGKangXi=0798.120, RSKangXi=108.14
250C3 CJK UNIFIED IDEOGRAPH-#250C3, IRGKangXi=0798.130, RSKangXi=108.14
250C4 CJK UNIFIED IDEOGRAPH-#250C4, IRGKangXi=0798.131, RSKangXi=108.14
250C5 CJK UNIFIED IDEOGRAPH-#250C5, IRGKangXi=0798.131, RSKangXi=108.14
250C6 CJK UNIFIED IDEOGRAPH-#250C6, IRGKangXi=0798.131, RSKangXi=108.14
250C7 CJK UNIFIED IDEOGRAPH-#250C7, IRGKangXi=0798.140, RSKangXi=108.15
250C8 CJK UNIFIED IDEOGRAPH-#250C8, IRGKangXi=0798.150, RSKangXi=108.15
250C9 CJK UNIFIED IDEOGRAPH-#250C9, IRGKangXi=0798.170, RSKangXi=108.15
250CA CJK UNIFIED IDEOGRAPH-#250CA, IRGKangXi=0798.171, RSKangXi=108.15
250CB CJK UNIFIED IDEOGRAPH-#250CB, IRGKangXi=0798.171, RSKangXi=108.15
250CC CJK UNIFIED IDEOGRAPH-#250CC, IRGKangXi=0798.171, RSKangXi=108.15
250CD CJK UNIFIED IDEOGRAPH-#250CD, IRGKangXi=0798.171, RSKangXi=108.15
250CE CJK UNIFIED IDEOGRAPH-#250CE, IRGKangXi=0798.171, RSKangXi=108.15
250CF CJK UNIFIED IDEOGRAPH-#250CF, IRGKangXi=0798.171, RSKangXi=108.15
250D0 CJK UNIFIED IDEOGRAPH-#250D0, IRGKangXi=0798.171, RSKangXi=108.15
250D1 CJK UNIFIED IDEOGRAPH-#250D1, IRGKangXi=0798.171, RSKangXi=108.15
250D2 CJK UNIFIED IDEOGRAPH-#250D2, IRGKangXi=0798.171, RSKangXi=108.16
250D3 CJK UNIFIED IDEOGRAPH-#250D3, IRGKangXi=0798.180, RSKangXi=108.17
250D4 CJK UNIFIED IDEOGRAPH-#250D4, IRGKangXi=0798.190, RSKangXi=108.17
250D5 CJK UNIFIED IDEOGRAPH-#250D5, IRGKangXi=0798.200, RSKangXi=108.17
250D6 CJK UNIFIED IDEOGRAPH-#250D6, IRGKangXi=0798.210, RSKangXi=108.17
250D7 CJK UNIFIED IDEOGRAPH-#250D7, IRGKangXi=0798.211, RSKangXi=108.17
250D8 CJK UNIFIED IDEOGRAPH-#250D8, IRGKangXi=0798.220, RSKangXi=108.18
250D9 CJK UNIFIED IDEOGRAPH-#250D9, IRGKangXi=0798.221, RSKangXi=108.18
250DA CJK UNIFIED IDEOGRAPH-#250DA, IRGKangXi=0798.221, RSKangXi=108.19
250DB CJK UNIFIED IDEOGRAPH-#250DB, IRGKangXi=0798.221, RSKangXi=108.19
250DC CJK UNIFIED IDEOGRAPH-#250DC, IRGKangXi=0798.221, RSKangXi=108.19
250DD CJK UNIFIED IDEOGRAPH-#250DD, IRGKangXi=0798.221, RSKangXi=108.19
250DE CJK UNIFIED IDEOGRAPH-#250DE, IRGKangXi=0798.221, RSKangXi=108.18
250DF CJK UNIFIED IDEOGRAPH-#250DF, IRGKangXi=0798.221, RSKangXi=108.20
250E0 CJK UNIFIED IDEOGRAPH-#250E0, IRGKangXi=0798.221, RSKangXi=108.20
250E1 CJK UNIFIED IDEOGRAPH-#250E1, IRGKangXi=0798.230, RSKangXi=108.21
250E2 CJK UNIFIED IDEOGRAPH-#250E2, IRGKangXi=0798.241, RSKangXi=108.25
250E3 CJK UNIFIED IDEOGRAPH-#250E3, IRGKangXi=0798.241, RSKangXi=108.28
250E4 CJK UNIFIED IDEOGRAPH-#250E4, IRGKangXi=0799.010, RSKangXi=109.1
250E5 CJK UNIFIED IDEOGRAPH-#250E5, IRGKangXi=0799.011, RSKangXi=109.1
250E6 CJK UNIFIED IDEOGRAPH-#250E6, IRGKangXi=0799.020, RSKangXi=109.2
250E7 CJK UNIFIED IDEOGRAPH-#250E7, IRGKangXi=0799.030, RSKangXi=109.2
250E8 CJK UNIFIED IDEOGRAPH-#250E8, IRGKangXi=0799.050, RSKangXi=109.2
250E9 CJK UNIFIED IDEOGRAPH-#250E9, IRGKangXi=0799.080, RSKangXi=109.2
250EA CJK UNIFIED IDEOGRAPH-#250EA, IRGKangXi=0799.090, RSKangXi=109.2
250EB CJK UNIFIED IDEOGRAPH-#250EB, IRGKangXi=0799.100, RSKangXi=109.2
250EC CJK UNIFIED IDEOGRAPH-#250EC, IRGKangXi=0799.101, RSKangXi=109.2
250ED CJK UNIFIED IDEOGRAPH-#250ED, IRGKangXi=0799.101, RSKangXi=109.2
250EE CJK UNIFIED IDEOGRAPH-#250EE, IRGKangXi=0799.101, RSKangXi=109.2
250EF CJK UNIFIED IDEOGRAPH-#250EF, IRGKangXi=0799.101, RSKangXi=109.2
250F0 CJK UNIFIED IDEOGRAPH-#250F0, IRGKangXi=0799.101, RSKangXi=109.2
250F1 CJK UNIFIED IDEOGRAPH-#250F1, IRGKangXi=0799.101, RSKangXi=109.2
250F2 CJK UNIFIED IDEOGRAPH-#250F2, IRGKangXi=0799.150, RSKangXi=109.3
250F3 CJK UNIFIED IDEOGRAPH-#250F3, IRGKangXi=0799.180, RSKangXi=109.3
250F4 CJK UNIFIED IDEOGRAPH-#250F4, IRGKangXi=0799.190, RSKangXi=109.3
250F5 CJK UNIFIED IDEOGRAPH-#250F5, IRGKangXi=0799.200, RSKangXi=109.3
250F6 CJK UNIFIED IDEOGRAPH-#250F6, IRGKangXi=0799.210, RSKangXi=109.3
250F7 CJK UNIFIED IDEOGRAPH-#250F7, IRGKangXi=0799.220, RSKangXi=109.3
250F8 CJK UNIFIED IDEOGRAPH-#250F8, IRGKangXi=0800.030, RSKangXi=109.3
250F9 CJK UNIFIED IDEOGRAPH-#250F9, IRGKangXi=0800.040, RSKangXi=109.3
250FA CJK UNIFIED IDEOGRAPH-#250FA, IRGKangXi=0800.080, RSKangXi=109.3
250FB CJK UNIFIED IDEOGRAPH-#250FB, IRGKangXi=0800.100, RSKangXi=109.3
250FC CJK UNIFIED IDEOGRAPH-#250FC, IRGKangXi=0800.110, RSKangXi=109.3
250FD CJK UNIFIED IDEOGRAPH-#250FD, IRGKangXi=0800.120, RSKangXi=109.3
250FE CJK UNIFIED IDEOGRAPH-#250FE, IRGKangXi=0800.121, RSKangXi=109.3
250FF CJK UNIFIED IDEOGRAPH-#250FF, IRGKangXi=0800.121, RSKangXi=109.3
25100 CJK UNIFIED IDEOGRAPH-#25100, IRGKangXi=0800.121, RSKangXi=109.3
25101 CJK UNIFIED IDEOGRAPH-#25101, IRGKangXi=0800.121, RSKangXi=109.3
25102 CJK UNIFIED IDEOGRAPH-#25102, IRGKangXi=0800.121, RSKangXi=109.3
25103 CJK UNIFIED IDEOGRAPH-#25103, IRGKangXi=0800.150, RSKangXi=109.4
25104 CJK UNIFIED IDEOGRAPH-#25104, IRGKangXi=0800.160, RSKangXi=109.4
25105 CJK UNIFIED IDEOGRAPH-#25105, IRGKangXi=0800.170, RSKangXi=109.4
25106 CJK UNIFIED IDEOGRAPH-#25106, IRGKangXi=0801.020, RSKangXi=109.4
25107 CJK UNIFIED IDEOGRAPH-#25107, IRGKangXi=0801.040, RSKangXi=109.4
25108 CJK UNIFIED IDEOGRAPH-#25108, IRGKangXi=0801.050, RSKangXi=109.4
25109 CJK UNIFIED IDEOGRAPH-#25109, IRGKangXi=0801.080, RSKangXi=109.4
2510A CJK UNIFIED IDEOGRAPH-#2510A, IRGKangXi=0801.090, RSKangXi=109.4
2510B CJK UNIFIED IDEOGRAPH-#2510B, IRGKangXi=0801.110, RSKangXi=109.4
2510C CJK UNIFIED IDEOGRAPH-#2510C, IRGKangXi=0801.130, RSKangXi=109.4
2510D CJK UNIFIED IDEOGRAPH-#2510D, IRGKangXi=0801.160, RSKangXi=109.4
2510E CJK UNIFIED IDEOGRAPH-#2510E, IRGKangXi=0801.200, RSKangXi=109.4, Def{(Cant.) to pull, lift up}
2510F CJK UNIFIED IDEOGRAPH-#2510F, IRGKangXi=0801.210, RSKangXi=109.4
25110 CJK UNIFIED IDEOGRAPH-#25110, IRGKangXi=0802.010, RSKangXi=109.4
25111 CJK UNIFIED IDEOGRAPH-#25111, IRGKangXi=0802.020, RSKangXi=109.4
25112 CJK UNIFIED IDEOGRAPH-#25112, IRGKangXi=0802.030, RSKangXi=109.4
25113 CJK UNIFIED IDEOGRAPH-#25113, IRGKangXi=0802.080, RSKangXi=109.4
25114 CJK UNIFIED IDEOGRAPH-#25114, IRGKangXi=0802.150, RSKangXi=109.4
25115 CJK UNIFIED IDEOGRAPH-#25115, IRGKangXi=0802.160, RSKangXi=109.4
25116 CJK UNIFIED IDEOGRAPH-#25116, IRGKangXi=0803.030, RSKangXi=109.4
25117 CJK UNIFIED IDEOGRAPH-#25117, IRGKangXi=0803.080, RSKangXi=109.4
25118 CJK UNIFIED IDEOGRAPH-#25118, IRGKangXi=0803.090, RSKangXi=109.4
25119 CJK UNIFIED IDEOGRAPH-#25119, IRGKangXi=0803.100, RSKangXi=109.4
2511A CJK UNIFIED IDEOGRAPH-#2511A, IRGKangXi=0803.110, RSKangXi=109.4
2511B CJK UNIFIED IDEOGRAPH-#2511B, IRGKangXi=0803.120, RSKangXi=109.4
2511C CJK UNIFIED IDEOGRAPH-#2511C, IRGKangXi=0803.130, RSKangXi=109.4
2511D CJK UNIFIED IDEOGRAPH-#2511D, IRGKangXi=0803.140, RSKangXi=109.4
2511E CJK UNIFIED IDEOGRAPH-#2511E, IRGKangXi=0803.150, RSKangXi=109.4
2511F CJK UNIFIED IDEOGRAPH-#2511F, IRGKangXi=0803.151, RSKangXi=109.4
25120 CJK UNIFIED IDEOGRAPH-#25120, IRGKangXi=0803.151, RSKangXi=109.4
25121 CJK UNIFIED IDEOGRAPH-#25121, IRGKangXi=0803.151, RSKangXi=109.4
25122 CJK UNIFIED IDEOGRAPH-#25122, IRGKangXi=0803.151, RSKangXi=109.4
25123 CJK UNIFIED IDEOGRAPH-#25123, IRGKangXi=0803.151, RSKangXi=109.4
25124 CJK UNIFIED IDEOGRAPH-#25124, IRGKangXi=0803.151, RSKangXi=109.4
25125 CJK UNIFIED IDEOGRAPH-#25125, IRGKangXi=0803.151, RSKangXi=109.4
25126 CJK UNIFIED IDEOGRAPH-#25126, IRGKangXi=0803.151, RSKangXi=109.4
25127 CJK UNIFIED IDEOGRAPH-#25127, IRGKangXi=0803.151, RSKangXi=109.4
25128 CJK UNIFIED IDEOGRAPH-#25128, IRGKangXi=0803.151, RSKangXi=109.4
25129 CJK UNIFIED IDEOGRAPH-#25129, IRGKangXi=0803.151, RSKangXi=109.4
2512A CJK UNIFIED IDEOGRAPH-#2512A, IRGKangXi=0803.151, RSKangXi=109.4
2512B CJK UNIFIED IDEOGRAPH-#2512B, IRGKangXi=0803.151, RSKangXi=109.4, Def{(Cant.) to stare, peep at}
2512C CJK UNIFIED IDEOGRAPH-#2512C, IRGKangXi=0803.151, RSKangXi=109.4
2512D CJK UNIFIED IDEOGRAPH-#2512D, IRGKangXi=0803.151, RSKangXi=109.4
2512E CJK UNIFIED IDEOGRAPH-#2512E, IRGKangXi=0803.151, RSKangXi=109.4
2512F CJK UNIFIED IDEOGRAPH-#2512F, IRGKangXi=0803.151, RSKangXi=109.4
25130 CJK UNIFIED IDEOGRAPH-#25130, IRGKangXi=0803.151, RSKangXi=109.4
25131 CJK UNIFIED IDEOGRAPH-#25131, IRGKangXi=0803.160, RSKangXi=109.5
25132 CJK UNIFIED IDEOGRAPH-#25132, IRGKangXi=0803.210, RSKangXi=109.5
25133 CJK UNIFIED IDEOGRAPH-#25133, IRGKangXi=0804.040, RSKangXi=109.5
25134 CJK UNIFIED IDEOGRAPH-#25134, IRGKangXi=0804.090, RSKangXi=109.5, Def{looking about eagerly}
25135 CJK UNIFIED IDEOGRAPH-#25135, IRGKangXi=0804.120, RSKangXi=109.5
25136 CJK UNIFIED IDEOGRAPH-#25136, IRGKangXi=0804.160, RSKangXi=109.5
25137 CJK UNIFIED IDEOGRAPH-#25137, IRGKangXi=0805.020, RSKangXi=109.5
25138 CJK UNIFIED IDEOGRAPH-#25138, IRGKangXi=0805.030, RSKangXi=109.5
25139 CJK UNIFIED IDEOGRAPH-#25139, IRGKangXi=0805.070, RSKangXi=109.5
2513A CJK UNIFIED IDEOGRAPH-#2513A, IRGKangXi=0805.120, RSKangXi=109.5
2513B CJK UNIFIED IDEOGRAPH-#2513B, IRGKangXi=0805.140, RSKangXi=109.5
2513C CJK UNIFIED IDEOGRAPH-#2513C, IRGKangXi=0805.150, RSKangXi=109.5
2513D CJK UNIFIED IDEOGRAPH-#2513D, IRGKangXi=0806.010, RSKangXi=109.5
2513E CJK UNIFIED IDEOGRAPH-#2513E, IRGKangXi=0806.030, RSKangXi=109.5
2513F CJK UNIFIED IDEOGRAPH-#2513F, IRGKangXi=0806.040, RSKangXi=109.5
25140 CJK UNIFIED IDEOGRAPH-#25140, IRGKangXi=0806.050, RSKangXi=109.5
25141 CJK UNIFIED IDEOGRAPH-#25141, IRGKangXi=0806.060, RSKangXi=109.5
25142 CJK UNIFIED IDEOGRAPH-#25142, IRGKangXi=0806.070, RSKangXi=109.5
25143 CJK UNIFIED IDEOGRAPH-#25143, IRGKangXi=0806.071, RSKangXi=109.5
25144 CJK UNIFIED IDEOGRAPH-#25144, IRGKangXi=0806.080, RSKangXi=109.5
25145 CJK UNIFIED IDEOGRAPH-#25145, IRGKangXi=0806.081, RSKangXi=109.5
25146 CJK UNIFIED IDEOGRAPH-#25146, IRGKangXi=0806.081, RSKangXi=109.5
25147 CJK UNIFIED IDEOGRAPH-#25147, IRGKangXi=0806.081, RSKangXi=109.5
25148 CJK UNIFIED IDEOGRAPH-#25148, IRGKangXi=0806.081, RSKangXi=109.5, Def{(Cant.) to look, scan}
25149 CJK UNIFIED IDEOGRAPH-#25149, IRGKangXi=0806.081, RSKangXi=109.5
2514A CJK UNIFIED IDEOGRAPH-#2514A, IRGKangXi=0806.081, RSKangXi=109.5
2514B CJK UNIFIED IDEOGRAPH-#2514B, IRGKangXi=0806.081, RSKangXi=109.5
2514C CJK UNIFIED IDEOGRAPH-#2514C, IRGKangXi=0806.081, RSKangXi=109.5
2514D CJK UNIFIED IDEOGRAPH-#2514D, IRGKangXi=0806.081, RSKangXi=109.5
2514E CJK UNIFIED IDEOGRAPH-#2514E, IRGKangXi=0806.081, RSKangXi=109.5
2514F CJK UNIFIED IDEOGRAPH-#2514F, IRGKangXi=0806.081, RSKangXi=109.5
25150 CJK UNIFIED IDEOGRAPH-#25150, IRGKangXi=0806.081, RSKangXi=109.5
25151 CJK UNIFIED IDEOGRAPH-#25151, IRGKangXi=0806.081, RSKangXi=109.5
25152 CJK UNIFIED IDEOGRAPH-#25152, IRGKangXi=0806.081, RSKangXi=109.5
25153 CJK UNIFIED IDEOGRAPH-#25153, IRGKangXi=0806.081, RSKangXi=109.5
25154 CJK UNIFIED IDEOGRAPH-#25154, IRGKangXi=0806.081, RSKangXi=109.5
25155 CJK UNIFIED IDEOGRAPH-#25155, IRGKangXi=0806.081, RSKangXi=109.5
25156 CJK UNIFIED IDEOGRAPH-#25156, IRGKangXi=0806.081, RSKangXi=109.5
25157 CJK UNIFIED IDEOGRAPH-#25157, IRGKangXi=0806.081, RSKangXi=109.5
25158 CJK UNIFIED IDEOGRAPH-#25158, IRGKangXi=0806.081, RSKangXi=109.5
25159 CJK UNIFIED IDEOGRAPH-#25159, IRGKangXi=0806.081, RSKangXi=109.5
2515A CJK UNIFIED IDEOGRAPH-#2515A, IRGKangXi=0806.110, RSKangXi=109.6
2515B CJK UNIFIED IDEOGRAPH-#2515B, IRGKangXi=0806.120, RSKangXi=109.6
2515C CJK UNIFIED IDEOGRAPH-#2515C, IRGKangXi=0806.130, RSKangXi=109.6
2515D CJK UNIFIED IDEOGRAPH-#2515D, IRGKangXi=0806.180, RSKangXi=109.6
2515E CJK UNIFIED IDEOGRAPH-#2515E, IRGKangXi=0806.190, RSKangXi=109.6
2515F CJK UNIFIED IDEOGRAPH-#2515F, IRGKangXi=0806.220, RSKangXi=109.6
25160 CJK UNIFIED IDEOGRAPH-#25160, IRGKangXi=0806.230, RSKangXi=109.6, Def{(Cant.) to fix one's eyes on, gaze at}
25161 CJK UNIFIED IDEOGRAPH-#25161, IRGKangXi=0806.250, RSKangXi=109.6
25162 CJK UNIFIED IDEOGRAPH-#25162, IRGKangXi=0806.260, RSKangXi=109.6
25163 CJK UNIFIED IDEOGRAPH-#25163, IRGKangXi=0806.300, RSKangXi=109.6
25164 CJK UNIFIED IDEOGRAPH-#25164, IRGKangXi=0806.330, RSKangXi=109.6
25165 CJK UNIFIED IDEOGRAPH-#25165, IRGKangXi=0806.340, RSKangXi=109.6
25166 CJK UNIFIED IDEOGRAPH-#25166, IRGKangXi=0806.370, RSKangXi=109.6
25167 CJK UNIFIED IDEOGRAPH-#25167, IRGKangXi=0806.380, RSKangXi=109.6
25168 CJK UNIFIED IDEOGRAPH-#25168, IRGKangXi=0806.390, RSKangXi=109.6
25169 CJK UNIFIED IDEOGRAPH-#25169, IRGKangXi=0807.020, RSKangXi=109.6
2516A CJK UNIFIED IDEOGRAPH-#2516A, IRGKangXi=0807.090, RSKangXi=109.6
2516B CJK UNIFIED IDEOGRAPH-#2516B, IRGKangXi=0808.010, RSKangXi=109.6
2516C CJK UNIFIED IDEOGRAPH-#2516C, IRGKangXi=0808.020, RSKangXi=109.6
2516D CJK UNIFIED IDEOGRAPH-#2516D, IRGKangXi=0808.030, RSKangXi=109.6
2516E CJK UNIFIED IDEOGRAPH-#2516E, IRGKangXi=0808.050, RSKangXi=109.6
2516F CJK UNIFIED IDEOGRAPH-#2516F, IRGKangXi=0808.051, RSKangXi=109.6
25170 CJK UNIFIED IDEOGRAPH-#25170, IRGKangXi=0808.051, RSKangXi=109.6
25171 CJK UNIFIED IDEOGRAPH-#25171, IRGKangXi=0808.051, RSKangXi=109.6
25172 CJK UNIFIED IDEOGRAPH-#25172, IRGKangXi=0808.051, RSKangXi=109.6
25173 CJK UNIFIED IDEOGRAPH-#25173, IRGKangXi=0808.051, RSKangXi=109.6
25174 CJK UNIFIED IDEOGRAPH-#25174, IRGKangXi=0808.051, RSKangXi=109.6
25175 CJK UNIFIED IDEOGRAPH-#25175, IRGKangXi=0808.051, RSKangXi=109.6
25176 CJK UNIFIED IDEOGRAPH-#25176, IRGKangXi=0808.051, RSKangXi=109.6
25177 CJK UNIFIED IDEOGRAPH-#25177, IRGKangXi=0808.051, RSKangXi=109.6
25178 CJK UNIFIED IDEOGRAPH-#25178, IRGKangXi=0808.051, RSKangXi=109.6
25179 CJK UNIFIED IDEOGRAPH-#25179, IRGKangXi=0808.051, RSKangXi=109.6
2517A CJK UNIFIED IDEOGRAPH-#2517A, IRGKangXi=0808.051, RSKangXi=109.6
2517B CJK UNIFIED IDEOGRAPH-#2517B, IRGKangXi=0808.051, RSKangXi=109.6
2517C CJK UNIFIED IDEOGRAPH-#2517C, IRGKangXi=0808.051, RSKangXi=109.6
2517D CJK UNIFIED IDEOGRAPH-#2517D, IRGKangXi=0808.051, RSKangXi=109.6
2517E CJK UNIFIED IDEOGRAPH-#2517E, IRGKangXi=0808.051, RSKangXi=109.6, Def{(Cant.) to peek or peep at}
2517F CJK UNIFIED IDEOGRAPH-#2517F, IRGKangXi=0808.051, RSKangXi=109.6
25180 CJK UNIFIED IDEOGRAPH-#25180, IRGKangXi=0808.051, RSKangXi=109.6
25181 CJK UNIFIED IDEOGRAPH-#25181, IRGKangXi=0808.051, RSKangXi=109.6
25182 CJK UNIFIED IDEOGRAPH-#25182, IRGKangXi=0808.051, RSKangXi=109.6
25183 CJK UNIFIED IDEOGRAPH-#25183, IRGKangXi=0808.051, RSKangXi=109.6
25184 CJK UNIFIED IDEOGRAPH-#25184, IRGKangXi=0808.051, RSKangXi=109.6
25185 CJK UNIFIED IDEOGRAPH-#25185, IRGKangXi=0808.051, RSKangXi=109.6
25186 CJK UNIFIED IDEOGRAPH-#25186, IRGKangXi=0808.051, RSKangXi=109.6
25187 CJK UNIFIED IDEOGRAPH-#25187, IRGKangXi=0808.051, RSKangXi=109.6
25188 CJK UNIFIED IDEOGRAPH-#25188, IRGKangXi=0808.051, RSKangXi=109.6
25189 CJK UNIFIED IDEOGRAPH-#25189, IRGKangXi=0808.051, RSKangXi=109.6
2518A CJK UNIFIED IDEOGRAPH-#2518A, IRGKangXi=0808.051, RSKangXi=109.7
2518B CJK UNIFIED IDEOGRAPH-#2518B, IRGKangXi=0808.090, RSKangXi=109.7
2518C CJK UNIFIED IDEOGRAPH-#2518C, IRGKangXi=0808.100, RSKangXi=109.7
2518D CJK UNIFIED IDEOGRAPH-#2518D, IRGKangXi=0808.120, RSKangXi=109.7
2518E CJK UNIFIED IDEOGRAPH-#2518E, IRGKangXi=0808.130, RSKangXi=109.7
2518F CJK UNIFIED IDEOGRAPH-#2518F, IRGKangXi=0808.190, RSKangXi=109.7
25190 CJK UNIFIED IDEOGRAPH-#25190, IRGKangXi=0808.200, RSKangXi=109.7
25191 CJK UNIFIED IDEOGRAPH-#25191, IRGKangXi=0808.210, RSKangXi=109.7
25192 CJK UNIFIED IDEOGRAPH-#25192, IRGKangXi=0808.220, RSKangXi=109.7
25193 CJK UNIFIED IDEOGRAPH-#25193, IRGKangXi=0808.270, RSKangXi=109.7
25194 CJK UNIFIED IDEOGRAPH-#25194, IRGKangXi=0808.290, RSKangXi=109.7
25195 CJK UNIFIED IDEOGRAPH-#25195, IRGKangXi=0808.300, RSKangXi=109.7
25196 CJK UNIFIED IDEOGRAPH-#25196, IRGKangXi=0808.310, RSKangXi=109.7
25197 CJK UNIFIED IDEOGRAPH-#25197, IRGKangXi=0808.360, RSKangXi=109.7
25198 CJK UNIFIED IDEOGRAPH-#25198, IRGKangXi=0808.370, RSKangXi=109.7
25199 CJK UNIFIED IDEOGRAPH-#25199, IRGKangXi=0808.380, RSKangXi=109.7
2519A CJK UNIFIED IDEOGRAPH-#2519A, IRGKangXi=0808.390, RSKangXi=109.7
2519B CJK UNIFIED IDEOGRAPH-#2519B, IRGKangXi=0808.420, RSKangXi=109.7
2519C CJK UNIFIED IDEOGRAPH-#2519C, IRGKangXi=0808.430, RSKangXi=109.7
2519D CJK UNIFIED IDEOGRAPH-#2519D, IRGKangXi=0809.010, RSKangXi=109.7
2519E CJK UNIFIED IDEOGRAPH-#2519E, IRGKangXi=0809.040, RSKangXi=109.7
2519F CJK UNIFIED IDEOGRAPH-#2519F, IRGKangXi=0809.050, RSKangXi=109.7
251A0 CJK UNIFIED IDEOGRAPH-#251A0, IRGKangXi=0809.070, RSKangXi=109.7
251A1 CJK UNIFIED IDEOGRAPH-#251A1, IRGKangXi=0809.150, RSKangXi=109.7
251A2 CJK UNIFIED IDEOGRAPH-#251A2, IRGKangXi=0809.160, RSKangXi=109.7
251A3 CJK UNIFIED IDEOGRAPH-#251A3, IRGKangXi=0809.170, RSKangXi=109.7
251A4 CJK UNIFIED IDEOGRAPH-#251A4, IRGKangXi=0809.190, RSKangXi=109.7
251A5 CJK UNIFIED IDEOGRAPH-#251A5, IRGKangXi=0809.200, RSKangXi=109.7
251A6 CJK UNIFIED IDEOGRAPH-#251A6, IRGKangXi=0809.210, RSKangXi=109.7
251A7 CJK UNIFIED IDEOGRAPH-#251A7, IRGKangXi=0809.211, RSKangXi=109.7
251A8 CJK UNIFIED IDEOGRAPH-#251A8, IRGKangXi=0809.211, RSKangXi=109.7
251A9 CJK UNIFIED IDEOGRAPH-#251A9, IRGKangXi=0809.211, RSKangXi=109.7
251AA CJK UNIFIED IDEOGRAPH-#251AA, IRGKangXi=0809.211, RSKangXi=109.7
251AB CJK UNIFIED IDEOGRAPH-#251AB, IRGKangXi=0809.211, RSKangXi=109.7
251AC CJK UNIFIED IDEOGRAPH-#251AC, IRGKangXi=0809.211, RSKangXi=109.7
251AD CJK UNIFIED IDEOGRAPH-#251AD, IRGKangXi=0809.211, RSKangXi=109.7
251AE CJK UNIFIED IDEOGRAPH-#251AE, IRGKangXi=0809.211, RSKangXi=109.7
251AF CJK UNIFIED IDEOGRAPH-#251AF, IRGKangXi=0809.211, RSKangXi=109.7
251B0 CJK UNIFIED IDEOGRAPH-#251B0, IRGKangXi=0809.211, RSKangXi=109.7
251B1 CJK UNIFIED IDEOGRAPH-#251B1, IRGKangXi=0809.211, RSKangXi=109.7
251B2 CJK UNIFIED IDEOGRAPH-#251B2, IRGKangXi=0809.211, RSKangXi=109.7
251B3 CJK UNIFIED IDEOGRAPH-#251B3, IRGKangXi=0809.211, RSKangXi=109.7
251B4 CJK UNIFIED IDEOGRAPH-#251B4, IRGKangXi=0809.211, RSKangXi=109.7
251B5 CJK UNIFIED IDEOGRAPH-#251B5, IRGKangXi=0809.211, RSKangXi=109.7
251B6 CJK UNIFIED IDEOGRAPH-#251B6, IRGKangXi=0809.211, RSKangXi=109.7
251B7 CJK UNIFIED IDEOGRAPH-#251B7, IRGKangXi=0809.211, RSKangXi=109.7
251B8 CJK UNIFIED IDEOGRAPH-#251B8, IRGKangXi=0809.211, RSKangXi=109.7
251B9 CJK UNIFIED IDEOGRAPH-#251B9, IRGKangXi=0809.211, RSKangXi=109.7
251BA CJK UNIFIED IDEOGRAPH-#251BA, IRGKangXi=0809.211, RSKangXi=109.7
251BB CJK UNIFIED IDEOGRAPH-#251BB, IRGKangXi=0809.211, RSKangXi=109.7
251BC CJK UNIFIED IDEOGRAPH-#251BC, IRGKangXi=0809.211, RSKangXi=109.7
251BD CJK UNIFIED IDEOGRAPH-#251BD, IRGKangXi=0809.211, RSKangXi=109.7
251BE CJK UNIFIED IDEOGRAPH-#251BE, IRGKangXi=0809.211, RSKangXi=109.7
251BF CJK UNIFIED IDEOGRAPH-#251BF, IRGKangXi=0809.211, RSKangXi=109.7
251C0 CJK UNIFIED IDEOGRAPH-#251C0, IRGKangXi=0809.211, RSKangXi=109.7
251C1 CJK UNIFIED IDEOGRAPH-#251C1, IRGKangXi=0809.211, RSKangXi=109.7
251C2 CJK UNIFIED IDEOGRAPH-#251C2, IRGKangXi=0809.211, RSKangXi=109.7
251C3 CJK UNIFIED IDEOGRAPH-#251C3, IRGKangXi=0809.211, RSKangXi=109.7
251C4 CJK UNIFIED IDEOGRAPH-#251C4, IRGKangXi=0809.211, RSKangXi=109.7
251C5 CJK UNIFIED IDEOGRAPH-#251C5, IRGKangXi=0809.211, RSKangXi=109.8
251C6 CJK UNIFIED IDEOGRAPH-#251C6, IRGKangXi=0809.211, RSKangXi=109.7
251C7 CJK UNIFIED IDEOGRAPH-#251C7, IRGKangXi=0809.211, RSKangXi=109.7
251C8 CJK UNIFIED IDEOGRAPH-#251C8, IRGKangXi=0809.211, RSKangXi=109.7
251C9 CJK UNIFIED IDEOGRAPH-#251C9, IRGKangXi=0809.250, RSKangXi=109.8
251CA CJK UNIFIED IDEOGRAPH-#251CA, IRGKangXi=0809.270, RSKangXi=109.8
251CB CJK UNIFIED IDEOGRAPH-#251CB, IRGKangXi=0809.310, RSKangXi=109.8
251CC CJK UNIFIED IDEOGRAPH-#251CC, IRGKangXi=0809.320, RSKangXi=109.8
251CD CJK UNIFIED IDEOGRAPH-#251CD, IRGKangXi=0809.330, RSKangXi=109.8
251CE CJK UNIFIED IDEOGRAPH-#251CE, IRGKangXi=0809.340, RSKangXi=109.8
251CF CJK UNIFIED IDEOGRAPH-#251CF, IRGKangXi=0810.010, RSKangXi=109.8
251D0 CJK UNIFIED IDEOGRAPH-#251D0, IRGKangXi=0810.020, RSKangXi=109.8
251D1 CJK UNIFIED IDEOGRAPH-#251D1, IRGKangXi=0810.030, RSKangXi=109.8
251D2 CJK UNIFIED IDEOGRAPH-#251D2, IRGKangXi=0810.080, RSKangXi=109.8
251D3 CJK UNIFIED IDEOGRAPH-#251D3, IRGKangXi=0810.090, RSKangXi=109.8
251D4 CJK UNIFIED IDEOGRAPH-#251D4, IRGKangXi=0810.160, RSKangXi=109.8
251D5 CJK UNIFIED IDEOGRAPH-#251D5, IRGKangXi=0810.240, RSKangXi=109.8
251D6 CJK UNIFIED IDEOGRAPH-#251D6, IRGKangXi=0810.260, RSKangXi=109.8
251D7 CJK UNIFIED IDEOGRAPH-#251D7, IRGKangXi=0810.270, RSKangXi=109.8
251D8 CJK UNIFIED IDEOGRAPH-#251D8, IRGKangXi=0810.280, RSKangXi=109.8
251D9 CJK UNIFIED IDEOGRAPH-#251D9, IRGKangXi=0810.290, RSKangXi=109.8
251DA CJK UNIFIED IDEOGRAPH-#251DA, IRGKangXi=0810.300, RSKangXi=109.8
251DB CJK UNIFIED IDEOGRAPH-#251DB, IRGKangXi=0811.060, RSKangXi=109.8
251DC CJK UNIFIED IDEOGRAPH-#251DC, IRGKangXi=0811.070, RSKangXi=109.8
251DD CJK UNIFIED IDEOGRAPH-#251DD, IRGKangXi=0811.140, RSKangXi=109.8
251DE CJK UNIFIED IDEOGRAPH-#251DE, IRGKangXi=0811.160, RSKangXi=109.8
251DF CJK UNIFIED IDEOGRAPH-#251DF, IRGKangXi=0811.170, RSKangXi=109.8
251E0 CJK UNIFIED IDEOGRAPH-#251E0, IRGKangXi=0811.180, RSKangXi=109.8
251E1 CJK UNIFIED IDEOGRAPH-#251E1, IRGKangXi=0811.190, RSKangXi=109.8
251E2 CJK UNIFIED IDEOGRAPH-#251E2, IRGKangXi=0811.191, RSKangXi=109.8
251E3 CJK UNIFIED IDEOGRAPH-#251E3, IRGKangXi=0811.191, RSKangXi=109.8, Def{(Cant.) to glance}
251E4 CJK UNIFIED IDEOGRAPH-#251E4, IRGKangXi=0811.191, RSKangXi=109.8
251E5 CJK UNIFIED IDEOGRAPH-#251E5, IRGKangXi=0811.191, RSKangXi=109.8
251E6 CJK UNIFIED IDEOGRAPH-#251E6, IRGKangXi=0811.191, RSKangXi=109.8
251E7 CJK UNIFIED IDEOGRAPH-#251E7, IRGKangXi=0811.191, RSKangXi=109.8
251E8 CJK UNIFIED IDEOGRAPH-#251E8, IRGKangXi=0811.191, RSKangXi=109.8
251E9 CJK UNIFIED IDEOGRAPH-#251E9, IRGKangXi=0811.191, RSKangXi=109.8
251EA CJK UNIFIED IDEOGRAPH-#251EA, IRGKangXi=0811.191, RSKangXi=109.8
251EB CJK UNIFIED IDEOGRAPH-#251EB, IRGKangXi=0811.191, RSKangXi=109.7
251EC CJK UNIFIED IDEOGRAPH-#251EC, IRGKangXi=0811.191, RSKangXi=109.8
251ED CJK UNIFIED IDEOGRAPH-#251ED, IRGKangXi=0811.191, RSKangXi=109.8
251EE CJK UNIFIED IDEOGRAPH-#251EE, IRGKangXi=0811.191, RSKangXi=109.8
251EF CJK UNIFIED IDEOGRAPH-#251EF, IRGKangXi=0811.191, RSKangXi=109.8
251F0 CJK UNIFIED IDEOGRAPH-#251F0, IRGKangXi=0811.191, RSKangXi=109.8
251F1 CJK UNIFIED IDEOGRAPH-#251F1, IRGKangXi=0811.191, RSKangXi=109.8
251F2 CJK UNIFIED IDEOGRAPH-#251F2, IRGKangXi=0811.191, RSKangXi=109.8
251F3 CJK UNIFIED IDEOGRAPH-#251F3, IRGKangXi=0811.191, RSKangXi=109.8
251F4 CJK UNIFIED IDEOGRAPH-#251F4, IRGKangXi=0811.191, RSKangXi=69.9
251F5 CJK UNIFIED IDEOGRAPH-#251F5, IRGKangXi=0811.191, RSKangXi=109.8
251F6 CJK UNIFIED IDEOGRAPH-#251F6, IRGKangXi=0811.191, RSKangXi=109.8
251F7 CJK UNIFIED IDEOGRAPH-#251F7, IRGKangXi=0811.191, RSKangXi=109.8
251F8 CJK UNIFIED IDEOGRAPH-#251F8, IRGKangXi=0811.191, RSKangXi=109.8
251F9 CJK UNIFIED IDEOGRAPH-#251F9, IRGKangXi=0811.191, RSKangXi=109.8
251FA CJK UNIFIED IDEOGRAPH-#251FA, IRGKangXi=0811.191, RSKangXi=109.8
251FB CJK UNIFIED IDEOGRAPH-#251FB, IRGKangXi=0811.191, RSKangXi=109.8
251FC CJK UNIFIED IDEOGRAPH-#251FC, IRGKangXi=0811.191, RSKangXi=109.8
251FD CJK UNIFIED IDEOGRAPH-#251FD, IRGKangXi=0811.191, RSKangXi=109.8
251FE CJK UNIFIED IDEOGRAPH-#251FE, IRGKangXi=0811.191, RSKangXi=109.8
251FF CJK UNIFIED IDEOGRAPH-#251FF, IRGKangXi=0811.191, RSKangXi=109.8
25200 CJK UNIFIED IDEOGRAPH-#25200, IRGKangXi=0811.191, RSKangXi=109.8
25201 CJK UNIFIED IDEOGRAPH-#25201, IRGKangXi=0811.191, RSKangXi=109.8
25202 CJK UNIFIED IDEOGRAPH-#25202, IRGKangXi=0811.200, RSKangXi=109.9
25203 CJK UNIFIED IDEOGRAPH-#25203, IRGKangXi=0811.220, RSKangXi=109.9
25204 CJK UNIFIED IDEOGRAPH-#25204, IRGKangXi=0812.050, RSKangXi=109.9
25205 CJK UNIFIED IDEOGRAPH-#25205, IRGKangXi=0812.070, RSKangXi=109.9
25206 CJK UNIFIED IDEOGRAPH-#25206, IRGKangXi=0812.090, RSKangXi=109.9
25207 CJK UNIFIED IDEOGRAPH-#25207, IRGKangXi=0812.100, RSKangXi=109.9
25208 CJK UNIFIED IDEOGRAPH-#25208, IRGKangXi=0812.110, RSKangXi=109.9
25209 CJK UNIFIED IDEOGRAPH-#25209, IRGKangXi=0812.140, RSKangXi=109.9
2520A CJK UNIFIED IDEOGRAPH-#2520A, IRGKangXi=0812.160, RSKangXi=109.9
2520B CJK UNIFIED IDEOGRAPH-#2520B, IRGKangXi=0812.170, RSKangXi=109.9
2520C CJK UNIFIED IDEOGRAPH-#2520C, IRGKangXi=0812.180, RSKangXi=109.9
2520D CJK UNIFIED IDEOGRAPH-#2520D, IRGKangXi=0812.200, RSKangXi=109.9
2520E CJK UNIFIED IDEOGRAPH-#2520E, IRGKangXi=0812.230, RSKangXi=109.9
2520F CJK UNIFIED IDEOGRAPH-#2520F, IRGKangXi=0812.330, RSKangXi=109.9
25210 CJK UNIFIED IDEOGRAPH-#25210, IRGKangXi=0812.340, RSKangXi=109.9
25211 CJK UNIFIED IDEOGRAPH-#25211, IRGKangXi=0812.360, RSKangXi=109.9
25212 CJK UNIFIED IDEOGRAPH-#25212, IRGKangXi=0812.370, RSKangXi=109.9
25213 CJK UNIFIED IDEOGRAPH-#25213, IRGKangXi=0812.390, RSKangXi=109.9
25214 CJK UNIFIED IDEOGRAPH-#25214, IRGKangXi=0813.020, RSKangXi=109.9
25215 CJK UNIFIED IDEOGRAPH-#25215, IRGKangXi=0813.050, RSKangXi=109.9
25216 CJK UNIFIED IDEOGRAPH-#25216, IRGKangXi=0813.060, RSKangXi=109.9
25217 CJK UNIFIED IDEOGRAPH-#25217, IRGKangXi=0813.070, RSKangXi=109.9
25218 CJK UNIFIED IDEOGRAPH-#25218, IRGKangXi=0813.080, RSKangXi=109.9
25219 CJK UNIFIED IDEOGRAPH-#25219, IRGKangXi=0813.100, RSKangXi=109.9
2521A CJK UNIFIED IDEOGRAPH-#2521A, IRGKangXi=0813.130, RSKangXi=109.9
2521B CJK UNIFIED IDEOGRAPH-#2521B, IRGKangXi=0813.150, RSKangXi=109.9
2521C CJK UNIFIED IDEOGRAPH-#2521C, IRGKangXi=0813.160, RSKangXi=109.9
2521D CJK UNIFIED IDEOGRAPH-#2521D, IRGKangXi=0813.161, RSKangXi=109.9
2521E CJK UNIFIED IDEOGRAPH-#2521E, IRGKangXi=0813.161, RSKangXi=109.9
2521F CJK UNIFIED IDEOGRAPH-#2521F, IRGKangXi=0813.161, RSKangXi=109.9, Def{blind; no pupil in the eye}
25220 CJK UNIFIED IDEOGRAPH-#25220, IRGKangXi=0813.161, RSKangXi=109.9
25221 CJK UNIFIED IDEOGRAPH-#25221, IRGKangXi=0813.161, RSKangXi=109.9
25222 CJK UNIFIED IDEOGRAPH-#25222, IRGKangXi=0813.161, RSKangXi=109.9
25223 CJK UNIFIED IDEOGRAPH-#25223, IRGKangXi=0813.161, RSKangXi=109.9
25224 CJK UNIFIED IDEOGRAPH-#25224, IRGKangXi=0813.161, RSKangXi=109.9
25225 CJK UNIFIED IDEOGRAPH-#25225, IRGKangXi=0813.161, RSKangXi=109.9
25226 CJK UNIFIED IDEOGRAPH-#25226, IRGKangXi=0813.161, RSKangXi=109.9
25227 CJK UNIFIED IDEOGRAPH-#25227, IRGKangXi=0813.161, RSKangXi=109.9
25228 CJK UNIFIED IDEOGRAPH-#25228, IRGKangXi=0813.161, RSKangXi=109.9
25229 CJK UNIFIED IDEOGRAPH-#25229, IRGKangXi=0813.161, RSKangXi=109.9
2522A CJK UNIFIED IDEOGRAPH-#2522A, IRGKangXi=0813.161, RSKangXi=109.9
2522B CJK UNIFIED IDEOGRAPH-#2522B, IRGKangXi=0813.161, RSKangXi=109.9
2522C CJK UNIFIED IDEOGRAPH-#2522C, IRGKangXi=0813.161, RSKangXi=109.9
2522D CJK UNIFIED IDEOGRAPH-#2522D, IRGKangXi=0813.161, RSKangXi=109.9
2522E CJK UNIFIED IDEOGRAPH-#2522E, IRGKangXi=0813.161, RSKangXi=109.9
2522F CJK UNIFIED IDEOGRAPH-#2522F, IRGKangXi=0813.161, RSKangXi=109.9
25230 CJK UNIFIED IDEOGRAPH-#25230, IRGKangXi=0813.161, RSKangXi=109.9
25231 CJK UNIFIED IDEOGRAPH-#25231, IRGKangXi=0813.161, RSKangXi=109.9
25232 CJK UNIFIED IDEOGRAPH-#25232, IRGKangXi=0813.161, RSKangXi=109.9, Def{(Cant.) to keep a close eye on, to control}
25233 CJK UNIFIED IDEOGRAPH-#25233, IRGKangXi=0813.161, RSKangXi=109.9
25234 CJK UNIFIED IDEOGRAPH-#25234, IRGKangXi=0813.161, RSKangXi=109.9
25235 CJK UNIFIED IDEOGRAPH-#25235, IRGKangXi=0813.161, RSKangXi=109.9
25236 CJK UNIFIED IDEOGRAPH-#25236, IRGKangXi=0813.161, RSKangXi=109.9, Def{(Cant.) sound asleep}
25237 CJK UNIFIED IDEOGRAPH-#25237, IRGKangXi=0813.161, RSKangXi=109.9
25238 CJK UNIFIED IDEOGRAPH-#25238, IRGKangXi=0813.161, RSKangXi=109.9
25239 CJK UNIFIED IDEOGRAPH-#25239, IRGKangXi=0813.161, RSKangXi=109.9
2523A CJK UNIFIED IDEOGRAPH-#2523A, IRGKangXi=0813.161, RSKangXi=109.9
2523B CJK UNIFIED IDEOGRAPH-#2523B, IRGKangXi=0813.161, RSKangXi=109.9
2523C CJK UNIFIED IDEOGRAPH-#2523C, IRGKangXi=0813.180, RSKangXi=109.10
2523D CJK UNIFIED IDEOGRAPH-#2523D, IRGKangXi=0814.020, RSKangXi=109.10
2523E CJK UNIFIED IDEOGRAPH-#2523E, IRGKangXi=0814.040, RSKangXi=109.10
2523F CJK UNIFIED IDEOGRAPH-#2523F, IRGKangXi=0814.070, RSKangXi=109.10
25240 CJK UNIFIED IDEOGRAPH-#25240, IRGKangXi=0814.090, RSKangXi=109.10
25241 CJK UNIFIED IDEOGRAPH-#25241, IRGKangXi=0814.100, RSKangXi=109.10
25242 CJK UNIFIED IDEOGRAPH-#25242, IRGKangXi=0814.110, RSKangXi=109.10
25243 CJK UNIFIED IDEOGRAPH-#25243, IRGKangXi=0814.120, RSKangXi=109.10
25244 CJK UNIFIED IDEOGRAPH-#25244, IRGKangXi=0814.130, RSKangXi=109.10
25245 CJK UNIFIED IDEOGRAPH-#25245, IRGKangXi=0814.140, RSKangXi=109.10
25246 CJK UNIFIED IDEOGRAPH-#25246, IRGKangXi=0814.150, RSKangXi=109.10
25247 CJK UNIFIED IDEOGRAPH-#25247, IRGKangXi=0814.160, RSKangXi=109.10
25248 CJK UNIFIED IDEOGRAPH-#25248, IRGKangXi=0814.170, RSKangXi=109.10
25249 CJK UNIFIED IDEOGRAPH-#25249, IRGKangXi=0814.200, RSKangXi=109.10
2524A CJK UNIFIED IDEOGRAPH-#2524A, IRGKangXi=0814.210, RSKangXi=109.10
2524B CJK UNIFIED IDEOGRAPH-#2524B, IRGKangXi=0814.220, RSKangXi=109.10
2524C CJK UNIFIED IDEOGRAPH-#2524C, IRGKangXi=0814.250, RSKangXi=109.10
2524D CJK UNIFIED IDEOGRAPH-#2524D, IRGKangXi=0814.260, RSKangXi=109.10
2524E CJK UNIFIED IDEOGRAPH-#2524E, IRGKangXi=0814.270, RSKangXi=109.10
2524F CJK UNIFIED IDEOGRAPH-#2524F, IRGKangXi=0814.280, RSKangXi=109.10
25250 CJK UNIFIED IDEOGRAPH-#25250, IRGKangXi=0814.300, RSKangXi=109.10
25251 CJK UNIFIED IDEOGRAPH-#25251, IRGKangXi=0814.310, RSKangXi=109.10
25252 CJK UNIFIED IDEOGRAPH-#25252, IRGKangXi=0814.320, RSKangXi=109.10
25253 CJK UNIFIED IDEOGRAPH-#25253, IRGKangXi=0814.340, RSKangXi=109.10
25254 CJK UNIFIED IDEOGRAPH-#25254, IRGKangXi=0815.010, RSKangXi=109.10
25255 CJK UNIFIED IDEOGRAPH-#25255, IRGKangXi=0815.020, RSKangXi=109.10
25256 CJK UNIFIED IDEOGRAPH-#25256, IRGKangXi=0815.030, RSKangXi=109.10
25257 CJK UNIFIED IDEOGRAPH-#25257, IRGKangXi=0815.040, RSKangXi=109.10
25258 CJK UNIFIED IDEOGRAPH-#25258, IRGKangXi=0815.050, RSKangXi=109.10
25259 CJK UNIFIED IDEOGRAPH-#25259, IRGKangXi=0815.060, RSKangXi=109.10
2525A CJK UNIFIED IDEOGRAPH-#2525A, IRGKangXi=0815.100, RSKangXi=109.10
2525B CJK UNIFIED IDEOGRAPH-#2525B, IRGKangXi=0815.120, RSKangXi=109.10
2525C CJK UNIFIED IDEOGRAPH-#2525C, IRGKangXi=0815.140, RSKangXi=109.10
2525D CJK UNIFIED IDEOGRAPH-#2525D, IRGKangXi=0815.150, RSKangXi=109.10
2525E CJK UNIFIED IDEOGRAPH-#2525E, IRGKangXi=0815.170, RSKangXi=109.10
2525F CJK UNIFIED IDEOGRAPH-#2525F, IRGKangXi=0815.180, RSKangXi=109.10
25260 CJK UNIFIED IDEOGRAPH-#25260, IRGKangXi=0815.181, RSKangXi=109.10
25261 CJK UNIFIED IDEOGRAPH-#25261, IRGKangXi=0815.181, RSKangXi=109.10
25262 CJK UNIFIED IDEOGRAPH-#25262, IRGKangXi=0815.181, RSKangXi=109.10
25263 CJK UNIFIED IDEOGRAPH-#25263, IRGKangXi=0815.181, RSKangXi=109.10
25264 CJK UNIFIED IDEOGRAPH-#25264, IRGKangXi=0815.181, RSKangXi=109.10
25265 CJK UNIFIED IDEOGRAPH-#25265, IRGKangXi=0815.181, RSKangXi=109.10
25266 CJK UNIFIED IDEOGRAPH-#25266, IRGKangXi=0815.181, RSKangXi=109.10
25267 CJK UNIFIED IDEOGRAPH-#25267, IRGKangXi=0815.181, RSKangXi=109.10
25268 CJK UNIFIED IDEOGRAPH-#25268, IRGKangXi=0815.181, RSKangXi=109.10
25269 CJK UNIFIED IDEOGRAPH-#25269, IRGKangXi=0815.181, RSKangXi=109.10
2526A CJK UNIFIED IDEOGRAPH-#2526A, IRGKangXi=0815.181, RSKangXi=109.10
2526B CJK UNIFIED IDEOGRAPH-#2526B, IRGKangXi=0815.181, RSKangXi=109.10
2526C CJK UNIFIED IDEOGRAPH-#2526C, IRGKangXi=0815.181, RSKangXi=109.10
2526D CJK UNIFIED IDEOGRAPH-#2526D, IRGKangXi=0815.181, RSKangXi=109.10
2526E CJK UNIFIED IDEOGRAPH-#2526E, IRGKangXi=0815.181, RSKangXi=109.10
2526F CJK UNIFIED IDEOGRAPH-#2526F, IRGKangXi=0815.181, RSKangXi=109.10
25270 CJK UNIFIED IDEOGRAPH-#25270, IRGKangXi=0815.181, RSKangXi=109.10
25271 CJK UNIFIED IDEOGRAPH-#25271, IRGKangXi=0815.181, RSKangXi=109.10
25272 CJK UNIFIED IDEOGRAPH-#25272, IRGKangXi=0815.181, RSKangXi=109.10
25273 CJK UNIFIED IDEOGRAPH-#25273, IRGKangXi=0815.181, RSKangXi=109.10
25274 CJK UNIFIED IDEOGRAPH-#25274, IRGKangXi=0815.220, RSKangXi=109.11
25275 CJK UNIFIED IDEOGRAPH-#25275, IRGKangXi=0815.230, RSKangXi=109.11, Def{blurred eyes}
25276 CJK UNIFIED IDEOGRAPH-#25276, IRGKangXi=0815.250, RSKangXi=109.11
25277 CJK UNIFIED IDEOGRAPH-#25277, IRGKangXi=0815.260, RSKangXi=109.11
25278 CJK UNIFIED IDEOGRAPH-#25278, IRGKangXi=0815.270, RSKangXi=109.11
25279 CJK UNIFIED IDEOGRAPH-#25279, IRGKangXi=0815.280, RSKangXi=109.11
2527A CJK UNIFIED IDEOGRAPH-#2527A, IRGKangXi=0815.290, RSKangXi=109.11
2527B CJK UNIFIED IDEOGRAPH-#2527B, IRGKangXi=0815.300, RSKangXi=109.11
2527C CJK UNIFIED IDEOGRAPH-#2527C, IRGKangXi=0815.310, RSKangXi=109.11
2527D CJK UNIFIED IDEOGRAPH-#2527D, IRGKangXi=0815.330, RSKangXi=109.11
2527E CJK UNIFIED IDEOGRAPH-#2527E, IRGKangXi=0815.370, RSKangXi=109.11
2527F CJK UNIFIED IDEOGRAPH-#2527F, IRGKangXi=0815.380, RSKangXi=109.11
25280 CJK UNIFIED IDEOGRAPH-#25280, IRGKangXi=0816.030, RSKangXi=109.11
25281 CJK UNIFIED IDEOGRAPH-#25281, IRGKangXi=0816.040, RSKangXi=109.11
25282 CJK UNIFIED IDEOGRAPH-#25282, IRGKangXi=0816.070, RSKangXi=109.11
25283 CJK UNIFIED IDEOGRAPH-#25283, IRGKangXi=0816.130, RSKangXi=109.11
25284 CJK UNIFIED IDEOGRAPH-#25284, IRGKangXi=0816.150, RSKangXi=109.11
25285 CJK UNIFIED IDEOGRAPH-#25285, IRGKangXi=0816.160, RSKangXi=109.11
25286 CJK UNIFIED IDEOGRAPH-#25286, IRGKangXi=0816.170, RSKangXi=109.11
25287 CJK UNIFIED IDEOGRAPH-#25287, IRGKangXi=0816.180, RSKangXi=109.10
25288 CJK UNIFIED IDEOGRAPH-#25288, IRGKangXi=0816.190, RSKangXi=109.11
25289 CJK UNIFIED IDEOGRAPH-#25289, IRGKangXi=0816.200, RSKangXi=109.11
2528A CJK UNIFIED IDEOGRAPH-#2528A, IRGKangXi=0816.210, RSKangXi=109.11
2528B CJK UNIFIED IDEOGRAPH-#2528B, IRGKangXi=0816.211, RSKangXi=109.11
2528C CJK UNIFIED IDEOGRAPH-#2528C, IRGKangXi=0816.211, RSKangXi=109.11, Def{(Cant.) wrinkled, folded, creased, crumpled}
2528D CJK UNIFIED IDEOGRAPH-#2528D, IRGKangXi=0816.211, RSKangXi=109.11
2528E CJK UNIFIED IDEOGRAPH-#2528E, IRGKangXi=0816.211, RSKangXi=109.11
2528F CJK UNIFIED IDEOGRAPH-#2528F, IRGKangXi=0816.211, RSKangXi=109.11
25290 CJK UNIFIED IDEOGRAPH-#25290, IRGKangXi=0816.211, RSKangXi=109.11
25291 CJK UNIFIED IDEOGRAPH-#25291, IRGKangXi=0816.211, RSKangXi=109.11
25292 CJK UNIFIED IDEOGRAPH-#25292, IRGKangXi=0816.211, RSKangXi=109.11
25293 CJK UNIFIED IDEOGRAPH-#25293, IRGKangXi=0816.211, RSKangXi=109.11
25294 CJK UNIFIED IDEOGRAPH-#25294, IRGKangXi=0816.211, RSKangXi=109.11
25295 CJK UNIFIED IDEOGRAPH-#25295, IRGKangXi=0816.211, RSKangXi=109.11
25296 CJK UNIFIED IDEOGRAPH-#25296, IRGKangXi=0816.211, RSKangXi=109.11
25297 CJK UNIFIED IDEOGRAPH-#25297, IRGKangXi=0816.211, RSKangXi=109.11
25298 CJK UNIFIED IDEOGRAPH-#25298, IRGKangXi=0816.211, RSKangXi=109.11
25299 CJK UNIFIED IDEOGRAPH-#25299, IRGKangXi=0816.211, RSKangXi=109.11, Def{(Cant.) to peep at, look at secretly}
2529A CJK UNIFIED IDEOGRAPH-#2529A, IRGKangXi=0816.211, RSKangXi=109.11
2529B CJK UNIFIED IDEOGRAPH-#2529B, IRGKangXi=0816.211, RSKangXi=109.11
2529C CJK UNIFIED IDEOGRAPH-#2529C, IRGKangXi=0816.211, RSKangXi=109.11
2529D CJK UNIFIED IDEOGRAPH-#2529D, IRGKangXi=0816.211, RSKangXi=109.11
2529E CJK UNIFIED IDEOGRAPH-#2529E, IRGKangXi=0816.211, RSKangXi=109.11
2529F CJK UNIFIED IDEOGRAPH-#2529F, IRGKangXi=0816.211, RSKangXi=109.11
252A0 CJK UNIFIED IDEOGRAPH-#252A0, IRGKangXi=0816.211, RSKangXi=109.11
252A1 CJK UNIFIED IDEOGRAPH-#252A1, IRGKangXi=0816.211, RSKangXi=109.11
252A2 CJK UNIFIED IDEOGRAPH-#252A2, IRGKangXi=0816.211, RSKangXi=109.11
252A3 CJK UNIFIED IDEOGRAPH-#252A3, IRGKangXi=0816.211, RSKangXi=109.11
252A4 CJK UNIFIED IDEOGRAPH-#252A4, IRGKangXi=0816.211, RSKangXi=109.11
252A5 CJK UNIFIED IDEOGRAPH-#252A5, IRGKangXi=0816.211, RSKangXi=109.11
252A6 CJK UNIFIED IDEOGRAPH-#252A6, IRGKangXi=0816.211, RSKangXi=109.11
252A7 CJK UNIFIED IDEOGRAPH-#252A7, IRGKangXi=0816.211, RSKangXi=109.11
252A8 CJK UNIFIED IDEOGRAPH-#252A8, IRGKangXi=0816.211, RSKangXi=109.11
252A9 CJK UNIFIED IDEOGRAPH-#252A9, IRGKangXi=0816.211, RSKangXi=109.11
252AA CJK UNIFIED IDEOGRAPH-#252AA, IRGKangXi=0816.220, RSKangXi=109.12
252AB CJK UNIFIED IDEOGRAPH-#252AB, IRGKangXi=0816.230, RSKangXi=109.12
252AC CJK UNIFIED IDEOGRAPH-#252AC, IRGKangXi=0816.240, RSKangXi=109.12
252AD CJK UNIFIED IDEOGRAPH-#252AD, IRGKangXi=0817.030, RSKangXi=109.12
252AE CJK UNIFIED IDEOGRAPH-#252AE, IRGKangXi=0817.050, RSKangXi=109.12
252AF CJK UNIFIED IDEOGRAPH-#252AF, IRGKangXi=0817.060, RSKangXi=109.12
252B0 CJK UNIFIED IDEOGRAPH-#252B0, IRGKangXi=0817.110, RSKangXi=109.12
252B1 CJK UNIFIED IDEOGRAPH-#252B1, IRGKangXi=0817.120, RSKangXi=109.12
252B2 CJK UNIFIED IDEOGRAPH-#252B2, IRGKangXi=0817.140, RSKangXi=109.12
252B3 CJK UNIFIED IDEOGRAPH-#252B3, IRGKangXi=0817.190, RSKangXi=109.12
252B4 CJK UNIFIED IDEOGRAPH-#252B4, IRGKangXi=0817.210, RSKangXi=109.12
252B5 CJK UNIFIED IDEOGRAPH-#252B5, IRGKangXi=0817.240, RSKangXi=109.12
252B6 CJK UNIFIED IDEOGRAPH-#252B6, IRGKangXi=0817.270, RSKangXi=109.12
252B7 CJK UNIFIED IDEOGRAPH-#252B7, IRGKangXi=0817.290, RSKangXi=109.12
252B8 CJK UNIFIED IDEOGRAPH-#252B8, IRGKangXi=0817.300, RSKangXi=109.12
252B9 CJK UNIFIED IDEOGRAPH-#252B9, IRGKangXi=0817.320, RSKangXi=109.12
252BA CJK UNIFIED IDEOGRAPH-#252BA, IRGKangXi=0817.330, RSKangXi=109.12
252BB CJK UNIFIED IDEOGRAPH-#252BB, IRGKangXi=0818.050, RSKangXi=109.12
252BC CJK UNIFIED IDEOGRAPH-#252BC, IRGKangXi=0818.080, RSKangXi=109.12
252BD CJK UNIFIED IDEOGRAPH-#252BD, IRGKangXi=0818.110, RSKangXi=109.12
252BE CJK UNIFIED IDEOGRAPH-#252BE, IRGKangXi=0818.130, RSKangXi=109.12
252BF CJK UNIFIED IDEOGRAPH-#252BF, IRGKangXi=0818.140, RSKangXi=109.12
252C0 CJK UNIFIED IDEOGRAPH-#252C0, IRGKangXi=0818.150, RSKangXi=109.12
252C1 CJK UNIFIED IDEOGRAPH-#252C1, IRGKangXi=0818.160, RSKangXi=109.12
252C2 CJK UNIFIED IDEOGRAPH-#252C2, IRGKangXi=0818.170, RSKangXi=109.12
252C3 CJK UNIFIED IDEOGRAPH-#252C3, IRGKangXi=0818.180, RSKangXi=109.12
252C4 CJK UNIFIED IDEOGRAPH-#252C4, IRGKangXi=0818.190, RSKangXi=109.12
252C5 CJK UNIFIED IDEOGRAPH-#252C5, IRGKangXi=0818.191, RSKangXi=109.12
252C6 CJK UNIFIED IDEOGRAPH-#252C6, IRGKangXi=0818.191, RSKangXi=109.12
252C7 CJK UNIFIED IDEOGRAPH-#252C7, IRGKangXi=0818.191, RSKangXi=109.12, Def{(Cant.) to open the eyes wide}
252C8 CJK UNIFIED IDEOGRAPH-#252C8, IRGKangXi=0818.191, RSKangXi=109.12
252C9 CJK UNIFIED IDEOGRAPH-#252C9, IRGKangXi=0818.191, RSKangXi=109.12
252CA CJK UNIFIED IDEOGRAPH-#252CA, IRGKangXi=0818.191, RSKangXi=109.12
252CB CJK UNIFIED IDEOGRAPH-#252CB, IRGKangXi=0818.191, RSKangXi=109.12
252CC CJK UNIFIED IDEOGRAPH-#252CC, IRGKangXi=0818.191, RSKangXi=109.12, Def{to glance at, catch sight of}
252CD CJK UNIFIED IDEOGRAPH-#252CD, IRGKangXi=0818.191, RSKangXi=109.12
252CE CJK UNIFIED IDEOGRAPH-#252CE, IRGKangXi=0818.191, RSKangXi=109.12
252CF CJK UNIFIED IDEOGRAPH-#252CF, IRGKangXi=0818.191, RSKangXi=109.12
252D0 CJK UNIFIED IDEOGRAPH-#252D0, IRGKangXi=0818.191, RSKangXi=109.12
252D1 CJK UNIFIED IDEOGRAPH-#252D1, IRGKangXi=0818.191, RSKangXi=109.12
252D2 CJK UNIFIED IDEOGRAPH-#252D2, IRGKangXi=0818.191, RSKangXi=109.12
252D3 CJK UNIFIED IDEOGRAPH-#252D3, IRGKangXi=0818.191, RSKangXi=109.12
252D4 CJK UNIFIED IDEOGRAPH-#252D4, IRGKangXi=0818.191, RSKangXi=109.12
252D5 CJK UNIFIED IDEOGRAPH-#252D5, IRGKangXi=0818.191, RSKangXi=109.12
252D6 CJK UNIFIED IDEOGRAPH-#252D6, IRGKangXi=0818.191, RSKangXi=109.11
252D7 CJK UNIFIED IDEOGRAPH-#252D7, IRGKangXi=0818.191, RSKangXi=109.12
252D8 CJK UNIFIED IDEOGRAPH-#252D8, IRGKangXi=0818.191, RSKangXi=109.13, Def{(Cant.) to swep the eyes over something}
252D9 CJK UNIFIED IDEOGRAPH-#252D9, IRGKangXi=0818.220, RSKangXi=109.13
252DA CJK UNIFIED IDEOGRAPH-#252DA, IRGKangXi=0818.230, RSKangXi=109.13
252DB CJK UNIFIED IDEOGRAPH-#252DB, IRGKangXi=0818.260, RSKangXi=109.13
252DC CJK UNIFIED IDEOGRAPH-#252DC, IRGKangXi=0818.270, RSKangXi=109.13
252DD CJK UNIFIED IDEOGRAPH-#252DD, IRGKangXi=0818.300, RSKangXi=109.13
252DE CJK UNIFIED IDEOGRAPH-#252DE, IRGKangXi=0818.340, RSKangXi=109.13
252DF CJK UNIFIED IDEOGRAPH-#252DF, IRGKangXi=0819.010, RSKangXi=109.13, Def{to wink}
252E0 CJK UNIFIED IDEOGRAPH-#252E0, IRGKangXi=0819.060, RSKangXi=109.13
252E1 CJK UNIFIED IDEOGRAPH-#252E1, IRGKangXi=0819.070, RSKangXi=109.13
252E2 CJK UNIFIED IDEOGRAPH-#252E2, IRGKangXi=0819.080, RSKangXi=109.13
252E3 CJK UNIFIED IDEOGRAPH-#252E3, IRGKangXi=0819.090, RSKangXi=109.13
252E4 CJK UNIFIED IDEOGRAPH-#252E4, IRGKangXi=0819.110, RSKangXi=109.13
252E5 CJK UNIFIED IDEOGRAPH-#252E5, IRGKangXi=0819.120, RSKangXi=109.13
252E6 CJK UNIFIED IDEOGRAPH-#252E6, IRGKangXi=0819.130, RSKangXi=109.13
252E7 CJK UNIFIED IDEOGRAPH-#252E7, IRGKangXi=0819.131, RSKangXi=109.13
252E8 CJK UNIFIED IDEOGRAPH-#252E8, IRGKangXi=0819.131, RSKangXi=109.13
252E9 CJK UNIFIED IDEOGRAPH-#252E9, IRGKangXi=0819.131, RSKangXi=109.13
252EA CJK UNIFIED IDEOGRAPH-#252EA, IRGKangXi=0819.131, RSKangXi=109.13
252EB CJK UNIFIED IDEOGRAPH-#252EB, IRGKangXi=0819.131, RSKangXi=109.13
252EC CJK UNIFIED IDEOGRAPH-#252EC, IRGKangXi=0819.131, RSKangXi=109.13
252ED CJK UNIFIED IDEOGRAPH-#252ED, IRGKangXi=0819.131, RSKangXi=109.13
252EE CJK UNIFIED IDEOGRAPH-#252EE, IRGKangXi=0819.131, RSKangXi=109.13
252EF CJK UNIFIED IDEOGRAPH-#252EF, IRGKangXi=0819.131, RSKangXi=109.13
252F0 CJK UNIFIED IDEOGRAPH-#252F0, IRGKangXi=0819.131, RSKangXi=109.13
252F1 CJK UNIFIED IDEOGRAPH-#252F1, IRGKangXi=0819.131, RSKangXi=109.13
252F2 CJK UNIFIED IDEOGRAPH-#252F2, IRGKangXi=0819.131, RSKangXi=109.13
252F3 CJK UNIFIED IDEOGRAPH-#252F3, IRGKangXi=0819.131, RSKangXi=109.13
252F4 CJK UNIFIED IDEOGRAPH-#252F4, IRGKangXi=0819.131, RSKangXi=109.13
252F5 CJK UNIFIED IDEOGRAPH-#252F5, IRGKangXi=0819.131, RSKangXi=109.13
252F6 CJK UNIFIED IDEOGRAPH-#252F6, IRGKangXi=0819.131, RSKangXi=109.13
252F7 CJK UNIFIED IDEOGRAPH-#252F7, IRGKangXi=0819.131, RSKangXi=109.13
252F8 CJK UNIFIED IDEOGRAPH-#252F8, IRGKangXi=0819.131, RSKangXi=109.13
252F9 CJK UNIFIED IDEOGRAPH-#252F9, IRGKangXi=0819.131, RSKangXi=109.13
252FA CJK UNIFIED IDEOGRAPH-#252FA, IRGKangXi=0819.131, RSKangXi=109.13
252FB CJK UNIFIED IDEOGRAPH-#252FB, IRGKangXi=0819.131, RSKangXi=109.13
252FC CJK UNIFIED IDEOGRAPH-#252FC, IRGKangXi=0819.131, RSKangXi=109.13
252FD CJK UNIFIED IDEOGRAPH-#252FD, IRGKangXi=0819.131, RSKangXi=109.13
252FE CJK UNIFIED IDEOGRAPH-#252FE, IRGKangXi=0819.131, RSKangXi=109.13
252FF CJK UNIFIED IDEOGRAPH-#252FF, IRGKangXi=0819.140, RSKangXi=109.14
25300 CJK UNIFIED IDEOGRAPH-#25300, IRGKangXi=0819.150, RSKangXi=109.14
25301 CJK UNIFIED IDEOGRAPH-#25301, IRGKangXi=0819.160, RSKangXi=109.14
25302 CJK UNIFIED IDEOGRAPH-#25302, IRGKangXi=0819.170, RSKangXi=109.14
25303 CJK UNIFIED IDEOGRAPH-#25303, IRGKangXi=0819.180, RSKangXi=109.14
25304 CJK UNIFIED IDEOGRAPH-#25304, IRGKangXi=0819.190, RSKangXi=109.14
25305 CJK UNIFIED IDEOGRAPH-#25305, IRGKangXi=0819.200, RSKangXi=109.14
25306 CJK UNIFIED IDEOGRAPH-#25306, IRGKangXi=0819.210, RSKangXi=109.14
25307 CJK UNIFIED IDEOGRAPH-#25307, IRGKangXi=0819.220, RSKangXi=109.14
25308 CJK UNIFIED IDEOGRAPH-#25308, IRGKangXi=0819.240, RSKangXi=109.14
25309 CJK UNIFIED IDEOGRAPH-#25309, IRGKangXi=0819.250, RSKangXi=109.14
2530A CJK UNIFIED IDEOGRAPH-#2530A, IRGKangXi=0820.010, RSKangXi=109.14
2530B CJK UNIFIED IDEOGRAPH-#2530B, IRGKangXi=0820.020, RSKangXi=109.14
2530C CJK UNIFIED IDEOGRAPH-#2530C, IRGKangXi=0820.060, RSKangXi=109.14
2530D CJK UNIFIED IDEOGRAPH-#2530D, IRGKangXi=0820.070, RSKangXi=109.14
2530E CJK UNIFIED IDEOGRAPH-#2530E, IRGKangXi=0820.080, RSKangXi=109.14
2530F CJK UNIFIED IDEOGRAPH-#2530F, IRGKangXi=0820.090, RSKangXi=109.14
25310 CJK UNIFIED IDEOGRAPH-#25310, IRGKangXi=0820.100, RSKangXi=109.14
25311 CJK UNIFIED IDEOGRAPH-#25311, IRGKangXi=0820.101, RSKangXi=109.14
25312 CJK UNIFIED IDEOGRAPH-#25312, IRGKangXi=0820.101, RSKangXi=109.14
25313 CJK UNIFIED IDEOGRAPH-#25313, IRGKangXi=0820.101, RSKangXi=109.14
25314 CJK UNIFIED IDEOGRAPH-#25314, IRGKangXi=0820.101, RSKangXi=109.14
25315 CJK UNIFIED IDEOGRAPH-#25315, IRGKangXi=0820.101, RSKangXi=177.10
25316 CJK UNIFIED IDEOGRAPH-#25316, IRGKangXi=0820.101, RSKangXi=109.14
25317 CJK UNIFIED IDEOGRAPH-#25317, IRGKangXi=0820.101, RSKangXi=109.14
25318 CJK UNIFIED IDEOGRAPH-#25318, IRGKangXi=0820.101, RSKangXi=109.14
25319 CJK UNIFIED IDEOGRAPH-#25319, IRGKangXi=0820.101, RSKangXi=109.14
2531A CJK UNIFIED IDEOGRAPH-#2531A, IRGKangXi=0820.150, RSKangXi=109.15
2531B CJK UNIFIED IDEOGRAPH-#2531B, IRGKangXi=0820.160, RSKangXi=109.15, Def{(Cant.) to gaze greedily at}
2531C CJK UNIFIED IDEOGRAPH-#2531C, IRGKangXi=0820.180, RSKangXi=109.15
2531D CJK UNIFIED IDEOGRAPH-#2531D, IRGKangXi=0820.210, RSKangXi=109.15
2531E CJK UNIFIED IDEOGRAPH-#2531E, IRGKangXi=0820.220, RSKangXi=109.15
2531F CJK UNIFIED IDEOGRAPH-#2531F, IRGKangXi=0820.230, RSKangXi=109.15
25320 CJK UNIFIED IDEOGRAPH-#25320, IRGKangXi=0820.231, RSKangXi=109.15
25321 CJK UNIFIED IDEOGRAPH-#25321, IRGKangXi=0820.231, RSKangXi=109.15
25322 CJK UNIFIED IDEOGRAPH-#25322, IRGKangXi=0820.231, RSKangXi=109.15
25323 CJK UNIFIED IDEOGRAPH-#25323, IRGKangXi=0820.231, RSKangXi=109.15
25324 CJK UNIFIED IDEOGRAPH-#25324, IRGKangXi=0820.231, RSKangXi=109.15
25325 CJK UNIFIED IDEOGRAPH-#25325, IRGKangXi=0820.231, RSKangXi=109.15
25326 CJK UNIFIED IDEOGRAPH-#25326, IRGKangXi=0820.231, RSKangXi=109.15
25327 CJK UNIFIED IDEOGRAPH-#25327, IRGKangXi=0820.231, RSKangXi=109.15
25328 CJK UNIFIED IDEOGRAPH-#25328, IRGKangXi=0820.231, RSKangXi=109.15
25329 CJK UNIFIED IDEOGRAPH-#25329, IRGKangXi=0820.231, RSKangXi=109.15
2532A CJK UNIFIED IDEOGRAPH-#2532A, IRGKangXi=0820.231, RSKangXi=109.15
2532B CJK UNIFIED IDEOGRAPH-#2532B, IRGKangXi=0820.231, RSKangXi=109.15
2532C CJK UNIFIED IDEOGRAPH-#2532C, IRGKangXi=0820.231, RSKangXi=109.15
2532D CJK UNIFIED IDEOGRAPH-#2532D, IRGKangXi=0820.240, RSKangXi=109.16
2532E CJK UNIFIED IDEOGRAPH-#2532E, IRGKangXi=0820.250, RSKangXi=109.16
2532F CJK UNIFIED IDEOGRAPH-#2532F, IRGKangXi=0820.260, RSKangXi=109.16
25330 CJK UNIFIED IDEOGRAPH-#25330, IRGKangXi=0820.280, RSKangXi=109.16
25331 CJK UNIFIED IDEOGRAPH-#25331, IRGKangXi=0820.320, RSKangXi=109.16
25332 CJK UNIFIED IDEOGRAPH-#25332, IRGKangXi=0820.330, RSKangXi=109.16
25333 CJK UNIFIED IDEOGRAPH-#25333, IRGKangXi=0820.341, RSKangXi=109.16
25334 CJK UNIFIED IDEOGRAPH-#25334, IRGKangXi=0820.341, RSKangXi=109.16
25335 CJK UNIFIED IDEOGRAPH-#25335, IRGKangXi=0820.341, RSKangXi=109.16
25336 CJK UNIFIED IDEOGRAPH-#25336, IRGKangXi=0820.341, RSKangXi=109.16
25337 CJK UNIFIED IDEOGRAPH-#25337, IRGKangXi=0820.341, RSKangXi=109.16
25338 CJK UNIFIED IDEOGRAPH-#25338, IRGKangXi=0820.341, RSKangXi=109.16
25339 CJK UNIFIED IDEOGRAPH-#25339, IRGKangXi=0820.341, RSKangXi=109.16
2533A CJK UNIFIED IDEOGRAPH-#2533A, IRGKangXi=0820.360, RSKangXi=109.17
2533B CJK UNIFIED IDEOGRAPH-#2533B, IRGKangXi=0820.370, RSKangXi=109.17
2533C CJK UNIFIED IDEOGRAPH-#2533C, IRGKangXi=0820.380, RSKangXi=109.17
2533D CJK UNIFIED IDEOGRAPH-#2533D, IRGKangXi=0820.390, RSKangXi=109.17
2533E CJK UNIFIED IDEOGRAPH-#2533E, IRGKangXi=0820.400, RSKangXi=109.17
2533F CJK UNIFIED IDEOGRAPH-#2533F, IRGKangXi=0820.410, RSKangXi=109.17
25340 CJK UNIFIED IDEOGRAPH-#25340, IRGKangXi=0820.420, RSKangXi=109.17
25341 CJK UNIFIED IDEOGRAPH-#25341, IRGKangXi=0820.430, RSKangXi=109.17
25342 CJK UNIFIED IDEOGRAPH-#25342, IRGKangXi=0820.440, RSKangXi=109.16
25343 CJK UNIFIED IDEOGRAPH-#25343, IRGKangXi=0820.450, RSKangXi=109.17
25344 CJK UNIFIED IDEOGRAPH-#25344, IRGKangXi=0820.451, RSKangXi=147.15
25345 CJK UNIFIED IDEOGRAPH-#25345, IRGKangXi=0820.451, RSKangXi=109.17
25346 CJK UNIFIED IDEOGRAPH-#25346, IRGKangXi=0820.451, RSKangXi=109.17
25347 CJK UNIFIED IDEOGRAPH-#25347, IRGKangXi=0820.451, RSKangXi=109.17
25348 CJK UNIFIED IDEOGRAPH-#25348, IRGKangXi=0821.020, RSKangXi=109.18
25349 CJK UNIFIED IDEOGRAPH-#25349, IRGKangXi=0821.030, RSKangXi=109.18
2534A CJK UNIFIED IDEOGRAPH-#2534A, IRGKangXi=0821.050, RSKangXi=109.18
2534B CJK UNIFIED IDEOGRAPH-#2534B, IRGKangXi=0821.060, RSKangXi=109.18
2534C CJK UNIFIED IDEOGRAPH-#2534C, IRGKangXi=0821.080, RSKangXi=109.18
2534D CJK UNIFIED IDEOGRAPH-#2534D, IRGKangXi=0821.081, RSKangXi=109.18
2534E CJK UNIFIED IDEOGRAPH-#2534E, IRGKangXi=0821.081, RSKangXi=109.18
2534F CJK UNIFIED IDEOGRAPH-#2534F, IRGKangXi=0821.090, RSKangXi=109.19
25350 CJK UNIFIED IDEOGRAPH-#25350, IRGKangXi=0821.121, RSKangXi=109.19
25351 CJK UNIFIED IDEOGRAPH-#25351, IRGKangXi=0821.121, RSKangXi=109.19
25352 CJK UNIFIED IDEOGRAPH-#25352, IRGKangXi=0821.121, RSKangXi=109.19
25353 CJK UNIFIED IDEOGRAPH-#25353, IRGKangXi=0821.150, RSKangXi=109.20
25354 CJK UNIFIED IDEOGRAPH-#25354, IRGKangXi=0821.180, RSKangXi=109.21
25355 CJK UNIFIED IDEOGRAPH-#25355, IRGKangXi=0821.190, RSKangXi=109.21
25356 CJK UNIFIED IDEOGRAPH-#25356, IRGKangXi=0821.191, RSKangXi=109.21
25357 CJK UNIFIED IDEOGRAPH-#25357, IRGKangXi=0821.191, RSKangXi=109.21
25358 CJK UNIFIED IDEOGRAPH-#25358, IRGKangXi=0821.191, RSKangXi=109.21
25359 CJK UNIFIED IDEOGRAPH-#25359, IRGKangXi=0821.191, RSKangXi=109.22
2535A CJK UNIFIED IDEOGRAPH-#2535A, IRGKangXi=0821.200, RSKangXi=109.22
2535B CJK UNIFIED IDEOGRAPH-#2535B, IRGKangXi=0821.201, RSKangXi=109.23
2535C CJK UNIFIED IDEOGRAPH-#2535C, IRGKangXi=0821.201, RSKangXi=109.24
2535D CJK UNIFIED IDEOGRAPH-#2535D, IRGKangXi=0821.261, RSKangXi=110.1
2535E CJK UNIFIED IDEOGRAPH-#2535E, IRGKangXi=0822.010, RSKangXi=110.3
2535F CJK UNIFIED IDEOGRAPH-#2535F, IRGKangXi=0822.030, RSKangXi=110.4
25360 CJK UNIFIED IDEOGRAPH-#25360, IRGKangXi=0822.050, RSKangXi=110.4
25361 CJK UNIFIED IDEOGRAPH-#25361, IRGKangXi=0822.060, RSKangXi=110.5
25362 CJK UNIFIED IDEOGRAPH-#25362, IRGKangXi=0822.070, RSKangXi=110.5
25363 CJK UNIFIED IDEOGRAPH-#25363, IRGKangXi=0822.080, RSKangXi=110.5
25364 CJK UNIFIED IDEOGRAPH-#25364, IRGKangXi=0822.090, RSKangXi=110.5
25365 CJK UNIFIED IDEOGRAPH-#25365, IRGKangXi=0822.100, RSKangXi=110.5
25366 CJK UNIFIED IDEOGRAPH-#25366, IRGKangXi=0822.101, RSKangXi=110.5
25367 CJK UNIFIED IDEOGRAPH-#25367, IRGKangXi=0822.110, RSKangXi=110.6
25368 CJK UNIFIED IDEOGRAPH-#25368, IRGKangXi=0822.120, RSKangXi=110.6
25369 CJK UNIFIED IDEOGRAPH-#25369, IRGKangXi=0822.131, RSKangXi=110.6
2536A CJK UNIFIED IDEOGRAPH-#2536A, IRGKangXi=0822.150, RSKangXi=110.7
2536B CJK UNIFIED IDEOGRAPH-#2536B, IRGKangXi=0822.160, RSKangXi=110.7
2536C CJK UNIFIED IDEOGRAPH-#2536C, IRGKangXi=0822.170, RSKangXi=110.7
2536D CJK UNIFIED IDEOGRAPH-#2536D, IRGKangXi=0822.190, RSKangXi=110.7
2536E CJK UNIFIED IDEOGRAPH-#2536E, IRGKangXi=0822.200, RSKangXi=110.7
2536F CJK UNIFIED IDEOGRAPH-#2536F, IRGKangXi=0822.210, RSKangXi=110.7
25370 CJK UNIFIED IDEOGRAPH-#25370, IRGKangXi=0822.220, RSKangXi=110.7
25371 CJK UNIFIED IDEOGRAPH-#25371, IRGKangXi=0822.230, RSKangXi=110.7
25372 CJK UNIFIED IDEOGRAPH-#25372, IRGKangXi=0822.240, RSKangXi=110.8
25373 CJK UNIFIED IDEOGRAPH-#25373, IRGKangXi=0822.250, RSKangXi=110.8
25374 CJK UNIFIED IDEOGRAPH-#25374, IRGKangXi=0822.261, RSKangXi=110.8
25375 CJK UNIFIED IDEOGRAPH-#25375, IRGKangXi=0822.261, RSKangXi=110.8
25376 CJK UNIFIED IDEOGRAPH-#25376, IRGKangXi=0822.280, RSKangXi=110.9
25377 CJK UNIFIED IDEOGRAPH-#25377, IRGKangXi=0822.290, RSKangXi=110.9
25378 CJK UNIFIED IDEOGRAPH-#25378, IRGKangXi=0822.300, RSKangXi=110.9
25379 CJK UNIFIED IDEOGRAPH-#25379, IRGKangXi=0822.310, RSKangXi=110.9
2537A CJK UNIFIED IDEOGRAPH-#2537A, IRGKangXi=0823.010, RSKangXi=110.9
2537B CJK UNIFIED IDEOGRAPH-#2537B, IRGKangXi=0823.020, RSKangXi=110.9
2537C CJK UNIFIED IDEOGRAPH-#2537C, IRGKangXi=0823.030, RSKangXi=110.9
2537D CJK UNIFIED IDEOGRAPH-#2537D, IRGKangXi=0823.040, RSKangXi=110.9
2537E CJK UNIFIED IDEOGRAPH-#2537E, IRGKangXi=0823.050, RSKangXi=110.9
2537F CJK UNIFIED IDEOGRAPH-#2537F, IRGKangXi=0823.060, RSKangXi=110.9
25380 CJK UNIFIED IDEOGRAPH-#25380, IRGKangXi=0823.061, RSKangXi=110.9
25381 CJK UNIFIED IDEOGRAPH-#25381, IRGKangXi=0823.061, RSKangXi=110.9
25382 CJK UNIFIED IDEOGRAPH-#25382, IRGKangXi=0823.070, RSKangXi=110.10
25383 CJK UNIFIED IDEOGRAPH-#25383, IRGKangXi=0823.080, RSKangXi=110.10
25384 CJK UNIFIED IDEOGRAPH-#25384, IRGKangXi=0823.090, RSKangXi=110.10
25385 CJK UNIFIED IDEOGRAPH-#25385, IRGKangXi=0823.100, RSKangXi=110.10
25386 CJK UNIFIED IDEOGRAPH-#25386, IRGKangXi=0823.110, RSKangXi=110.10
25387 CJK UNIFIED IDEOGRAPH-#25387, IRGKangXi=0823.120, RSKangXi=110.10
25388 CJK UNIFIED IDEOGRAPH-#25388, IRGKangXi=0823.121, RSKangXi=110.10
25389 CJK UNIFIED IDEOGRAPH-#25389, IRGKangXi=0823.121, RSKangXi=110.10
2538A CJK UNIFIED IDEOGRAPH-#2538A, IRGKangXi=0823.130, RSKangXi=110.11
2538B CJK UNIFIED IDEOGRAPH-#2538B, IRGKangXi=0823.140, RSKangXi=110.11
2538C CJK UNIFIED IDEOGRAPH-#2538C, IRGKangXi=0823.150, RSKangXi=110.11
2538D CJK UNIFIED IDEOGRAPH-#2538D, IRGKangXi=0823.160, RSKangXi=110.11
2538E CJK UNIFIED IDEOGRAPH-#2538E, IRGKangXi=0823.180, RSKangXi=110.13
2538F CJK UNIFIED IDEOGRAPH-#2538F, IRGKangXi=0823.200, RSKangXi=110.12
25390 CJK UNIFIED IDEOGRAPH-#25390, IRGKangXi=0823.210, RSKangXi=110.12
25391 CJK UNIFIED IDEOGRAPH-#25391, IRGKangXi=0823.211, RSKangXi=110.12
25392 CJK UNIFIED IDEOGRAPH-#25392, IRGKangXi=0823.211, RSKangXi=110.12
25393 CJK UNIFIED IDEOGRAPH-#25393, IRGKangXi=0823.220, RSKangXi=110.13
25394 CJK UNIFIED IDEOGRAPH-#25394, IRGKangXi=0823.230, RSKangXi=110.13
25395 CJK UNIFIED IDEOGRAPH-#25395, IRGKangXi=0823.231, RSKangXi=110.13
25396 CJK UNIFIED IDEOGRAPH-#25396, IRGKangXi=0823.240, RSKangXi=110.14
25397 CJK UNIFIED IDEOGRAPH-#25397, IRGKangXi=0823.250, RSKangXi=110.14
25398 CJK UNIFIED IDEOGRAPH-#25398, IRGKangXi=0823.260, RSKangXi=110.14
25399 CJK UNIFIED IDEOGRAPH-#25399, IRGKangXi=0823.270, RSKangXi=110.14
2539A CJK UNIFIED IDEOGRAPH-#2539A, IRGKangXi=0823.280, RSKangXi=110.14
2539B CJK UNIFIED IDEOGRAPH-#2539B, IRGKangXi=0823.281, RSKangXi=110.14
2539C CJK UNIFIED IDEOGRAPH-#2539C, IRGKangXi=0823.281, RSKangXi=110.14
2539D CJK UNIFIED IDEOGRAPH-#2539D, IRGKangXi=0823.291, RSKangXi=110.16
2539E CJK UNIFIED IDEOGRAPH-#2539E, IRGKangXi=0823.291, RSKangXi=110.15
2539F CJK UNIFIED IDEOGRAPH-#2539F, IRGKangXi=0823.291, RSKangXi=110.15
253A0 CJK UNIFIED IDEOGRAPH-#253A0, IRGKangXi=0823.291, RSKangXi=110.15
253A1 CJK UNIFIED IDEOGRAPH-#253A1, IRGKangXi=0823.300, RSKangXi=110.18
253A2 CJK UNIFIED IDEOGRAPH-#253A2, IRGKangXi=0823.301, RSKangXi=110.18
253A3 CJK UNIFIED IDEOGRAPH-#253A3, IRGKangXi=0823.301, RSKangXi=110.18
253A4 CJK UNIFIED IDEOGRAPH-#253A4, IRGKangXi=0823.321, RSKangXi=110.30
253A5 CJK UNIFIED IDEOGRAPH-#253A5, IRGKangXi=0823.330, RSKangXi=110.31
253A6 CJK UNIFIED IDEOGRAPH-#253A6, IRGKangXi=0823.390, RSKangXi=111.2
253A7 CJK UNIFIED IDEOGRAPH-#253A7, IRGKangXi=0823.391, RSKangXi=111.2
253A8 CJK UNIFIED IDEOGRAPH-#253A8, IRGKangXi=0824.031, RSKangXi=111.3
253A9 CJK UNIFIED IDEOGRAPH-#253A9, IRGKangXi=0824.040, RSKangXi=111.4
253AA CJK UNIFIED IDEOGRAPH-#253AA, IRGKangXi=0824.070, RSKangXi=111.4
253AB CJK UNIFIED IDEOGRAPH-#253AB, IRGKangXi=0824.090, RSKangXi=111.4
253AC CJK UNIFIED IDEOGRAPH-#253AC, IRGKangXi=0824.091, RSKangXi=111.4
253AD CJK UNIFIED IDEOGRAPH-#253AD, IRGKangXi=0824.091, RSKangXi=111.4
253AE CJK UNIFIED IDEOGRAPH-#253AE, IRGKangXi=0824.091, RSKangXi=111.4
253AF CJK UNIFIED IDEOGRAPH-#253AF, IRGKangXi=0824.091, RSKangXi=111.4
253B0 CJK UNIFIED IDEOGRAPH-#253B0, IRGKangXi=0824.100, RSKangXi=111.5
253B1 CJK UNIFIED IDEOGRAPH-#253B1, IRGKangXi=0824.130, RSKangXi=111.5
253B2 CJK UNIFIED IDEOGRAPH-#253B2, IRGKangXi=0824.160, RSKangXi=111.5
253B3 CJK UNIFIED IDEOGRAPH-#253B3, IRGKangXi=0824.161, RSKangXi=111.5
253B4 CJK UNIFIED IDEOGRAPH-#253B4, IRGKangXi=0824.161, RSKangXi=111.5
253B5 CJK UNIFIED IDEOGRAPH-#253B5, IRGKangXi=0824.161, RSKangXi=111.5
253B6 CJK UNIFIED IDEOGRAPH-#253B6, IRGKangXi=0824.161, RSKangXi=111.5
253B7 CJK UNIFIED IDEOGRAPH-#253B7, IRGKangXi=0824.161, RSKangXi=111.5
253B8 CJK UNIFIED IDEOGRAPH-#253B8, IRGKangXi=0824.161, RSKangXi=111.5
253B9 CJK UNIFIED IDEOGRAPH-#253B9, IRGKangXi=0824.170, RSKangXi=111.6
253BA CJK UNIFIED IDEOGRAPH-#253BA, IRGKangXi=0824.180, RSKangXi=111.6
253BB CJK UNIFIED IDEOGRAPH-#253BB, IRGKangXi=0824.200, RSKangXi=111.6
253BC CJK UNIFIED IDEOGRAPH-#253BC, IRGKangXi=0824.210, RSKangXi=111.6
253BD CJK UNIFIED IDEOGRAPH-#253BD, IRGKangXi=0824.220, RSKangXi=111.6
253BE CJK UNIFIED IDEOGRAPH-#253BE, IRGKangXi=0824.230, RSKangXi=111.6
253BF CJK UNIFIED IDEOGRAPH-#253BF, IRGKangXi=0824.250, RSKangXi=111.6
253C0 CJK UNIFIED IDEOGRAPH-#253C0, IRGKangXi=0824.260, RSKangXi=111.6
253C1 CJK UNIFIED IDEOGRAPH-#253C1, IRGKangXi=0824.270, RSKangXi=111.6
253C2 CJK UNIFIED IDEOGRAPH-#253C2, IRGKangXi=0824.280, RSKangXi=111.6
253C3 CJK UNIFIED IDEOGRAPH-#253C3, IRGKangXi=0824.281
253C4 CJK UNIFIED IDEOGRAPH-#253C4, IRGKangXi=0824.281, RSKangXi=111.6
253C5 CJK UNIFIED IDEOGRAPH-#253C5, IRGKangXi=0824.281, RSKangXi=111.6
253C6 CJK UNIFIED IDEOGRAPH-#253C6, IRGKangXi=0824.281, RSKangXi=111.6
253C7 CJK UNIFIED IDEOGRAPH-#253C7, IRGKangXi=0824.281, RSKangXi=111.6
253C8 CJK UNIFIED IDEOGRAPH-#253C8, IRGKangXi=0824.281, RSKangXi=111.6
253C9 CJK UNIFIED IDEOGRAPH-#253C9, IRGKangXi=0824.281, RSKangXi=111.6
253CA CJK UNIFIED IDEOGRAPH-#253CA, IRGKangXi=0824.281, RSKangXi=111.6
253CB CJK UNIFIED IDEOGRAPH-#253CB, IRGKangXi=0824.281, RSKangXi=111.6
253CC CJK UNIFIED IDEOGRAPH-#253CC, IRGKangXi=0824.281, RSKangXi=111.6
253CD CJK UNIFIED IDEOGRAPH-#253CD, IRGKangXi=0824.281, RSKangXi=111.6
253CE CJK UNIFIED IDEOGRAPH-#253CE, IRGKangXi=0824.310, RSKangXi=111.7
253CF CJK UNIFIED IDEOGRAPH-#253CF, IRGKangXi=0824.320, RSKangXi=111.7
253D0 CJK UNIFIED IDEOGRAPH-#253D0, IRGKangXi=0825.011, RSKangXi=111.7
253D1 CJK UNIFIED IDEOGRAPH-#253D1, IRGKangXi=0825.011, RSKangXi=111.7
253D2 CJK UNIFIED IDEOGRAPH-#253D2, IRGKangXi=0825.011, RSKangXi=111.7
253D3 CJK UNIFIED IDEOGRAPH-#253D3, IRGKangXi=0825.011, RSKangXi=111.7
253D4 CJK UNIFIED IDEOGRAPH-#253D4, IRGKangXi=0825.011, RSKangXi=111.7
253D5 CJK UNIFIED IDEOGRAPH-#253D5, IRGKangXi=0825.011, RSKangXi=111.7
253D6 CJK UNIFIED IDEOGRAPH-#253D6, IRGKangXi=0825.011, RSKangXi=111.7
253D7 CJK UNIFIED IDEOGRAPH-#253D7, IRGKangXi=0825.011, RSKangXi=111.7
253D8 CJK UNIFIED IDEOGRAPH-#253D8, IRGKangXi=0825.020, RSKangXi=111.8
253D9 CJK UNIFIED IDEOGRAPH-#253D9, IRGKangXi=0825.030, RSKangXi=111.8
253DA CJK UNIFIED IDEOGRAPH-#253DA, IRGKangXi=0825.050, RSKangXi=111.8
253DB CJK UNIFIED IDEOGRAPH-#253DB, IRGKangXi=0825.060, RSKangXi=111.8
253DC CJK UNIFIED IDEOGRAPH-#253DC, IRGKangXi=0825.070, RSKangXi=111.8
253DD CJK UNIFIED IDEOGRAPH-#253DD, IRGKangXi=0825.080, RSKangXi=111.8
253DE CJK UNIFIED IDEOGRAPH-#253DE, IRGKangXi=0825.090, RSKangXi=111.8
253DF CJK UNIFIED IDEOGRAPH-#253DF, IRGKangXi=0825.100, RSKangXi=111.8
253E0 CJK UNIFIED IDEOGRAPH-#253E0, IRGKangXi=0825.120, RSKangXi=111.8
253E1 CJK UNIFIED IDEOGRAPH-#253E1, IRGKangXi=0825.121, RSKangXi=111.8
253E2 CJK UNIFIED IDEOGRAPH-#253E2, IRGKangXi=0825.121, RSKangXi=111.8
253E3 CJK UNIFIED IDEOGRAPH-#253E3, IRGKangXi=0825.121, RSKangXi=111.8
253E4 CJK UNIFIED IDEOGRAPH-#253E4, IRGKangXi=0825.121, RSKangXi=111.8
253E5 CJK UNIFIED IDEOGRAPH-#253E5, IRGKangXi=0825.121, RSKangXi=111.8
253E6 CJK UNIFIED IDEOGRAPH-#253E6, IRGKangXi=0825.121, RSKangXi=111.8
253E7 CJK UNIFIED IDEOGRAPH-#253E7, IRGKangXi=0825.121, RSKangXi=111.8
253E8 CJK UNIFIED IDEOGRAPH-#253E8, IRGKangXi=0825.121, RSKangXi=111.8
253E9 CJK UNIFIED IDEOGRAPH-#253E9, IRGKangXi=0825.121, RSKangXi=111.8
253EA CJK UNIFIED IDEOGRAPH-#253EA, IRGKangXi=0825.130, RSKangXi=111.9
253EB CJK UNIFIED IDEOGRAPH-#253EB, IRGKangXi=0825.150, RSKangXi=111.9
253EC CJK UNIFIED IDEOGRAPH-#253EC, IRGKangXi=0825.160, RSKangXi=111.9
253ED CJK UNIFIED IDEOGRAPH-#253ED, IRGKangXi=0825.161, RSKangXi=111.9
253EE CJK UNIFIED IDEOGRAPH-#253EE, IRGKangXi=0825.161, RSKangXi=111.9
253EF CJK UNIFIED IDEOGRAPH-#253EF, IRGKangXi=0825.161, RSKangXi=111.9
253F0 CJK UNIFIED IDEOGRAPH-#253F0, IRGKangXi=0825.161, RSKangXi=111.9
253F1 CJK UNIFIED IDEOGRAPH-#253F1, IRGKangXi=0825.161, RSKangXi=111.9
253F2 CJK UNIFIED IDEOGRAPH-#253F2, IRGKangXi=0825.170, RSKangXi=111.10
253F3 CJK UNIFIED IDEOGRAPH-#253F3, IRGKangXi=0825.180, RSKangXi=111.10
253F4 CJK UNIFIED IDEOGRAPH-#253F4, IRGKangXi=0825.190, RSKangXi=111.10
253F5 CJK UNIFIED IDEOGRAPH-#253F5, IRGKangXi=0825.200, RSKangXi=111.10
253F6 CJK UNIFIED IDEOGRAPH-#253F6, IRGKangXi=0825.201, RSKangXi=111.10
253F7 CJK UNIFIED IDEOGRAPH-#253F7, IRGKangXi=0825.201, RSKangXi=111.10
253F8 CJK UNIFIED IDEOGRAPH-#253F8, IRGKangXi=0825.201, RSKangXi=111.10
253F9 CJK UNIFIED IDEOGRAPH-#253F9, IRGKangXi=0825.201, RSKangXi=111.10
253FA CJK UNIFIED IDEOGRAPH-#253FA, IRGKangXi=0825.201, RSKangXi=111.10
253FB CJK UNIFIED IDEOGRAPH-#253FB, IRGKangXi=0825.210, RSKangXi=111.11
253FC CJK UNIFIED IDEOGRAPH-#253FC, IRGKangXi=0825.220, RSKangXi=111.11
253FD CJK UNIFIED IDEOGRAPH-#253FD, IRGKangXi=0825.221, RSKangXi=111.11
253FE CJK UNIFIED IDEOGRAPH-#253FE, IRGKangXi=0825.221, RSKangXi=111.11
253FF CJK UNIFIED IDEOGRAPH-#253FF, IRGKangXi=0825.221, RSKangXi=111.11
25400 CJK UNIFIED IDEOGRAPH-#25400, IRGKangXi=0825.230, RSKangXi=111.12
25401 CJK UNIFIED IDEOGRAPH-#25401, IRGKangXi=0825.250, RSKangXi=111.12
25402 CJK UNIFIED IDEOGRAPH-#25402, IRGKangXi=0825.261, RSKangXi=111.12
25403 CJK UNIFIED IDEOGRAPH-#25403, IRGKangXi=0825.261, RSKangXi=111.12
25404 CJK UNIFIED IDEOGRAPH-#25404, IRGKangXi=0825.261, RSKangXi=111.12
25405 CJK UNIFIED IDEOGRAPH-#25405, IRGKangXi=0825.261, RSKangXi=111.12
25406 CJK UNIFIED IDEOGRAPH-#25406, IRGKangXi=0825.261, RSKangXi=111.12
25407 CJK UNIFIED IDEOGRAPH-#25407, IRGKangXi=0825.261, RSKangXi=111.13
25408 CJK UNIFIED IDEOGRAPH-#25408, IRGKangXi=0825.261, RSKangXi=111.13
25409 CJK UNIFIED IDEOGRAPH-#25409, IRGKangXi=0825.261, RSKangXi=111.13
2540A CJK UNIFIED IDEOGRAPH-#2540A, IRGKangXi=0825.261, RSKangXi=111.13
2540B CJK UNIFIED IDEOGRAPH-#2540B, IRGKangXi=0825.261, RSKangXi=111.13
2540C CJK UNIFIED IDEOGRAPH-#2540C, IRGKangXi=0825.271, RSKangXi=111.14
2540D CJK UNIFIED IDEOGRAPH-#2540D, IRGKangXi=0825.271, RSKangXi=111.14
2540E CJK UNIFIED IDEOGRAPH-#2540E, IRGKangXi=0825.271, RSKangXi=111.14
2540F CJK UNIFIED IDEOGRAPH-#2540F, IRGKangXi=0825.271, RSKangXi=111.14
25410 CJK UNIFIED IDEOGRAPH-#25410, IRGKangXi=0825.271, RSKangXi=111.18
25411 CJK UNIFIED IDEOGRAPH-#25411, IRGKangXi=0825.290, RSKangXi=111.17
25412 CJK UNIFIED IDEOGRAPH-#25412, IRGKangXi=0825.291, RSKangXi=111.17
25413 CJK UNIFIED IDEOGRAPH-#25413, IRGKangXi=0825.300, RSKangXi=111.18
25414 CJK UNIFIED IDEOGRAPH-#25414, IRGKangXi=0825.301, RSKangXi=111.18
25415 CJK UNIFIED IDEOGRAPH-#25415, IRGKangXi=0827.030, RSKangXi=112.1
25416 CJK UNIFIED IDEOGRAPH-#25416, IRGKangXi=0827.031, RSKangXi=112.1
25417 CJK UNIFIED IDEOGRAPH-#25417, IRGKangXi=0827.050, RSKangXi=112.2
25418 CJK UNIFIED IDEOGRAPH-#25418, IRGKangXi=0827.060, RSKangXi=112.2, Def{a stone, rock}
25419 CJK UNIFIED IDEOGRAPH-#25419, IRGKangXi=0827.070, RSKangXi=112.2
2541A CJK UNIFIED IDEOGRAPH-#2541A, IRGKangXi=0827.090, RSKangXi=112.2
2541B CJK UNIFIED IDEOGRAPH-#2541B, IRGKangXi=0827.101, RSKangXi=112.2
2541C CJK UNIFIED IDEOGRAPH-#2541C, IRGKangXi=0827.101, RSKangXi=112.2
2541D CJK UNIFIED IDEOGRAPH-#2541D, IRGKangXi=0827.120, RSKangXi=112.3
2541E CJK UNIFIED IDEOGRAPH-#2541E, IRGKangXi=0827.150, RSKangXi=112.3, Def{a crude saltpeter}
2541F CJK UNIFIED IDEOGRAPH-#2541F, IRGKangXi=0827.170, RSKangXi=112.3
25420 CJK UNIFIED IDEOGRAPH-#25420, IRGKangXi=0827.191, RSKangXi=112.3
25421 CJK UNIFIED IDEOGRAPH-#25421, IRGKangXi=0827.191, RSKangXi=112.3
25422 CJK UNIFIED IDEOGRAPH-#25422, IRGKangXi=0827.191, RSKangXi=112.3
25423 CJK UNIFIED IDEOGRAPH-#25423, IRGKangXi=0827.191, RSKangXi=112.3
25424 CJK UNIFIED IDEOGRAPH-#25424, IRGKangXi=0827.191, RSKangXi=112.3
25425 CJK UNIFIED IDEOGRAPH-#25425, IRGKangXi=0827.191, RSKangXi=112.3
25426 CJK UNIFIED IDEOGRAPH-#25426, IRGKangXi=0827.191, RSKangXi=112.3
25427 CJK UNIFIED IDEOGRAPH-#25427, IRGKangXi=0827.191, RSKangXi=112.3
25428 CJK UNIFIED IDEOGRAPH-#25428, IRGKangXi=0827.191, RSKangXi=112.3
25429 CJK UNIFIED IDEOGRAPH-#25429, IRGKangXi=0828.030, RSKangXi=112.4
2542A CJK UNIFIED IDEOGRAPH-#2542A, IRGKangXi=0828.050, RSKangXi=112.4
2542B CJK UNIFIED IDEOGRAPH-#2542B, IRGKangXi=0828.090, RSKangXi=112.4
2542C CJK UNIFIED IDEOGRAPH-#2542C, IRGKangXi=0828.230, RSKangXi=112.4
2542D CJK UNIFIED IDEOGRAPH-#2542D, IRGKangXi=0828.241, RSKangXi=112.4
2542E CJK UNIFIED IDEOGRAPH-#2542E, IRGKangXi=0828.241, RSKangXi=112.4
2542F CJK UNIFIED IDEOGRAPH-#2542F, IRGKangXi=0828.241, RSKangXi=112.4
25430 CJK UNIFIED IDEOGRAPH-#25430, IRGKangXi=0828.241, RSKangXi=112.4
25431 CJK UNIFIED IDEOGRAPH-#25431, IRGKangXi=0828.241, RSKangXi=112.4
25432 CJK UNIFIED IDEOGRAPH-#25432, IRGKangXi=0828.241, RSKangXi=112.4
25433 CJK UNIFIED IDEOGRAPH-#25433, IRGKangXi=0828.241, RSKangXi=112.4
25434 CJK UNIFIED IDEOGRAPH-#25434, IRGKangXi=0828.241, RSKangXi=112.4
25435 CJK UNIFIED IDEOGRAPH-#25435, IRGKangXi=0828.241, RSKangXi=112.4
25436 CJK UNIFIED IDEOGRAPH-#25436, IRGKangXi=0828.241, RSKangXi=112.4
25437 CJK UNIFIED IDEOGRAPH-#25437, IRGKangXi=0828.241, RSKangXi=112.4
25438 CJK UNIFIED IDEOGRAPH-#25438, IRGKangXi=0828.241, RSKangXi=112.4
25439 CJK UNIFIED IDEOGRAPH-#25439, IRGKangXi=0828.241, RSKangXi=112.4
2543A CJK UNIFIED IDEOGRAPH-#2543A, IRGKangXi=0828.241, RSKangXi=112.4
2543B CJK UNIFIED IDEOGRAPH-#2543B, IRGKangXi=0828.241, RSKangXi=112.4
2543C CJK UNIFIED IDEOGRAPH-#2543C, IRGKangXi=0828.241, RSKangXi=112.4
2543D CJK UNIFIED IDEOGRAPH-#2543D, IRGKangXi=0828.241, RSKangXi=112.4
2543E CJK UNIFIED IDEOGRAPH-#2543E, IRGKangXi=0828.241, RSKangXi=112.4
2543F CJK UNIFIED IDEOGRAPH-#2543F, IRGKangXi=0828.241, RSKangXi=112.4
25440 CJK UNIFIED IDEOGRAPH-#25440, IRGKangXi=0828.241, RSKangXi=112.4
25441 CJK UNIFIED IDEOGRAPH-#25441, IRGKangXi=0828.241, RSKangXi=112.4
25442 CJK UNIFIED IDEOGRAPH-#25442, IRGKangXi=0828.241, RSKangXi=112.4
25443 CJK UNIFIED IDEOGRAPH-#25443, IRGKangXi=0828.241, RSKangXi=112.4
25444 CJK UNIFIED IDEOGRAPH-#25444, IRGKangXi=0828.241, RSKangXi=112.4
25445 CJK UNIFIED IDEOGRAPH-#25445, IRGKangXi=0828.241, RSKangXi=112.4
25446 CJK UNIFIED IDEOGRAPH-#25446, IRGKangXi=0828.300, RSKangXi=112.5
25447 CJK UNIFIED IDEOGRAPH-#25447, IRGKangXi=0828.330, RSKangXi=112.5
25448 CJK UNIFIED IDEOGRAPH-#25448, IRGKangXi=0828.390, RSKangXi=112.5
25449 CJK UNIFIED IDEOGRAPH-#25449, IRGKangXi=0829.020, RSKangXi=112.5
2544A CJK UNIFIED IDEOGRAPH-#2544A, IRGKangXi=0829.050, RSKangXi=112.5
2544B CJK UNIFIED IDEOGRAPH-#2544B, IRGKangXi=0829.090, RSKangXi=112.5
2544C CJK UNIFIED IDEOGRAPH-#2544C, IRGKangXi=0829.150, RSKangXi=112.5
2544D CJK UNIFIED IDEOGRAPH-#2544D, IRGKangXi=0829.170, RSKangXi=112.5
2544E CJK UNIFIED IDEOGRAPH-#2544E, IRGKangXi=0829.200, RSKangXi=112.5
2544F CJK UNIFIED IDEOGRAPH-#2544F, IRGKangXi=0829.210, RSKangXi=112.5
25450 CJK UNIFIED IDEOGRAPH-#25450, IRGKangXi=0829.230, RSKangXi=112.5
25451 CJK UNIFIED IDEOGRAPH-#25451, IRGKangXi=0829.250, RSKangXi=112.5
25452 CJK UNIFIED IDEOGRAPH-#25452, IRGKangXi=0829.300, RSKangXi=112.5
25453 CJK UNIFIED IDEOGRAPH-#25453, IRGKangXi=0829.310, RSKangXi=112.5
25454 CJK UNIFIED IDEOGRAPH-#25454, IRGKangXi=0829.330, RSKangXi=112.5
25455 CJK UNIFIED IDEOGRAPH-#25455, IRGKangXi=0829.331, RSKangXi=112.5
25456 CJK UNIFIED IDEOGRAPH-#25456, IRGKangXi=0829.331, RSKangXi=112.5
25457 CJK UNIFIED IDEOGRAPH-#25457, IRGKangXi=0829.331, RSKangXi=112.5
25458 CJK UNIFIED IDEOGRAPH-#25458, IRGKangXi=0829.331, RSKangXi=112.5
25459 CJK UNIFIED IDEOGRAPH-#25459, IRGKangXi=0829.331, RSKangXi=112.5
2545A CJK UNIFIED IDEOGRAPH-#2545A, IRGKangXi=0829.331, RSKangXi=112.5
2545B CJK UNIFIED IDEOGRAPH-#2545B, IRGKangXi=0829.331, RSKangXi=112.5
2545C CJK UNIFIED IDEOGRAPH-#2545C, IRGKangXi=0829.331, RSKangXi=112.5
2545D CJK UNIFIED IDEOGRAPH-#2545D, IRGKangXi=0829.331, RSKangXi=112.5
2545E CJK UNIFIED IDEOGRAPH-#2545E, IRGKangXi=0829.331, RSKangXi=112.5
2545F CJK UNIFIED IDEOGRAPH-#2545F, IRGKangXi=0829.331, RSKangXi=112.5
25460 CJK UNIFIED IDEOGRAPH-#25460, IRGKangXi=0829.331, RSKangXi=112.5
25461 CJK UNIFIED IDEOGRAPH-#25461, IRGKangXi=0829.331, RSKangXi=112.5
25462 CJK UNIFIED IDEOGRAPH-#25462, IRGKangXi=0829.331, RSKangXi=112.5, Def{boron (obsolete; see U+787C 硼)}
25463 CJK UNIFIED IDEOGRAPH-#25463, IRGKangXi=0829.331, RSKangXi=112.5
25464 CJK UNIFIED IDEOGRAPH-#25464, IRGKangXi=0829.331, RSKangXi=112.5
25465 CJK UNIFIED IDEOGRAPH-#25465, IRGKangXi=0829.331, RSKangXi=112.5
25466 CJK UNIFIED IDEOGRAPH-#25466, IRGKangXi=0829.331, RSKangXi=112.5
25467 CJK UNIFIED IDEOGRAPH-#25467, IRGKangXi=0829.331, RSKangXi=112.5
25468 CJK UNIFIED IDEOGRAPH-#25468, IRGKangXi=0829.331, RSKangXi=112.5
25469 CJK UNIFIED IDEOGRAPH-#25469, IRGKangXi=0829.331, RSKangXi=112.5
2546A CJK UNIFIED IDEOGRAPH-#2546A, IRGKangXi=0829.331, RSKangXi=112.5, Def{impure ammonium chloride}
2546B CJK UNIFIED IDEOGRAPH-#2546B, IRGKangXi=0829.331, RSKangXi=112.5
2546C CJK UNIFIED IDEOGRAPH-#2546C, IRGKangXi=0829.331, RSKangXi=112.5
2546D CJK UNIFIED IDEOGRAPH-#2546D, IRGKangXi=0829.331, RSKangXi=112.5
2546E CJK UNIFIED IDEOGRAPH-#2546E, IRGKangXi=0829.331, RSKangXi=112.5
2546F CJK UNIFIED IDEOGRAPH-#2546F, IRGKangXi=0829.331, RSKangXi=112.5
25470 CJK UNIFIED IDEOGRAPH-#25470, IRGKangXi=0829.331, RSKangXi=112.5
25471 CJK UNIFIED IDEOGRAPH-#25471, IRGKangXi=0829.331, RSKangXi=112.5
25472 CJK UNIFIED IDEOGRAPH-#25472, IRGKangXi=0829.331, RSKangXi=112.5
25473 CJK UNIFIED IDEOGRAPH-#25473, IRGKangXi=0829.340, RSKangXi=112.6
25474 CJK UNIFIED IDEOGRAPH-#25474, IRGKangXi=0829.370, RSKangXi=112.6
25475 CJK UNIFIED IDEOGRAPH-#25475, IRGKangXi=0829.410, RSKangXi=112.6
25476 CJK UNIFIED IDEOGRAPH-#25476, IRGKangXi=0829.420, RSKangXi=112.6
25477 CJK UNIFIED IDEOGRAPH-#25477, IRGKangXi=0829.430, RSKangXi=112.6
25478 CJK UNIFIED IDEOGRAPH-#25478, IRGKangXi=0829.440, RSKangXi=112.6
25479 CJK UNIFIED IDEOGRAPH-#25479, IRGKangXi=0829.470, RSKangXi=112.6
2547A CJK UNIFIED IDEOGRAPH-#2547A, IRGKangXi=0829.480, RSKangXi=112.6
2547B CJK UNIFIED IDEOGRAPH-#2547B, IRGKangXi=0829.500, RSKangXi=112.6
2547C CJK UNIFIED IDEOGRAPH-#2547C, IRGKangXi=0829.520, RSKangXi=112.6
2547D CJK UNIFIED IDEOGRAPH-#2547D, IRGKangXi=0829.530, RSKangXi=112.6
2547E CJK UNIFIED IDEOGRAPH-#2547E, IRGKangXi=0829.580, RSKangXi=112.6
2547F CJK UNIFIED IDEOGRAPH-#2547F, IRGKangXi=0830.030, RSKangXi=112.6
25480 CJK UNIFIED IDEOGRAPH-#25480, IRGKangXi=0830.100, RSKangXi=112.6
25481 CJK UNIFIED IDEOGRAPH-#25481, IRGKangXi=0830.110, RSKangXi=112.6
25482 CJK UNIFIED IDEOGRAPH-#25482, IRGKangXi=0830.120, RSKangXi=112.6
25483 CJK UNIFIED IDEOGRAPH-#25483, IRGKangXi=0830.121, RSKangXi=112.6
25484 CJK UNIFIED IDEOGRAPH-#25484, IRGKangXi=0830.121, RSKangXi=112.6
25485 CJK UNIFIED IDEOGRAPH-#25485, IRGKangXi=0830.121, RSKangXi=112.6
25486 CJK UNIFIED IDEOGRAPH-#25486, IRGKangXi=0830.121, RSKangXi=112.6
25487 CJK UNIFIED IDEOGRAPH-#25487, IRGKangXi=0830.121, RSKangXi=112.6
25488 CJK UNIFIED IDEOGRAPH-#25488, IRGKangXi=0830.121, RSKangXi=112.6
25489 CJK UNIFIED IDEOGRAPH-#25489, IRGKangXi=0830.121, RSKangXi=112.6
2548A CJK UNIFIED IDEOGRAPH-#2548A, IRGKangXi=0830.121, RSKangXi=112.6
2548B CJK UNIFIED IDEOGRAPH-#2548B, IRGKangXi=0830.121, RSKangXi=112.6
2548C CJK UNIFIED IDEOGRAPH-#2548C, IRGKangXi=0830.121, RSKangXi=112.6
2548D CJK UNIFIED IDEOGRAPH-#2548D, IRGKangXi=0830.121, RSKangXi=112.6
2548E CJK UNIFIED IDEOGRAPH-#2548E, IRGKangXi=0830.131, RSKangXi=112.6
2548F CJK UNIFIED IDEOGRAPH-#2548F, IRGKangXi=0830.131, RSKangXi=112.6
25490 CJK UNIFIED IDEOGRAPH-#25490, IRGKangXi=0830.131, RSKangXi=112.6
25491 CJK UNIFIED IDEOGRAPH-#25491, IRGKangXi=0830.131, RSKangXi=112.6
25492 CJK UNIFIED IDEOGRAPH-#25492, IRGKangXi=0830.131, RSKangXi=112.6
25493 CJK UNIFIED IDEOGRAPH-#25493, IRGKangXi=0830.131, RSKangXi=112.6
25494 CJK UNIFIED IDEOGRAPH-#25494, IRGKangXi=0830.131, RSKangXi=112.6
25495 CJK UNIFIED IDEOGRAPH-#25495, IRGKangXi=0830.131, RSKangXi=112.6
25496 CJK UNIFIED IDEOGRAPH-#25496, IRGKangXi=0830.131, RSKangXi=112.6
25497 CJK UNIFIED IDEOGRAPH-#25497, IRGKangXi=0830.131, RSKangXi=112.6
25498 CJK UNIFIED IDEOGRAPH-#25498, IRGKangXi=0830.131, RSKangXi=112.6
25499 CJK UNIFIED IDEOGRAPH-#25499, IRGKangXi=0830.131, RSKangXi=112.6
2549A CJK UNIFIED IDEOGRAPH-#2549A, IRGKangXi=0830.131, RSKangXi=112.6
2549B CJK UNIFIED IDEOGRAPH-#2549B, IRGKangXi=0830.131, RSKangXi=112.6
2549C CJK UNIFIED IDEOGRAPH-#2549C, IRGKangXi=0830.131, RSKangXi=112.6
2549D CJK UNIFIED IDEOGRAPH-#2549D, IRGKangXi=0830.131, RSKangXi=112.6
2549E CJK UNIFIED IDEOGRAPH-#2549E, IRGKangXi=0830.131, RSKangXi=112.6
2549F CJK UNIFIED IDEOGRAPH-#2549F, IRGKangXi=0830.131, RSKangXi=112.6
254A0 CJK UNIFIED IDEOGRAPH-#254A0, IRGKangXi=0830.131, RSKangXi=112.6
254A1 CJK UNIFIED IDEOGRAPH-#254A1, IRGKangXi=0830.131, RSKangXi=112.6
254A2 CJK UNIFIED IDEOGRAPH-#254A2, IRGKangXi=0830.131, RSKangXi=112.6
254A3 CJK UNIFIED IDEOGRAPH-#254A3, IRGKangXi=0830.131, RSKangXi=112.6
254A4 CJK UNIFIED IDEOGRAPH-#254A4, IRGKangXi=0830.131, RSKangXi=112.6
254A5 CJK UNIFIED IDEOGRAPH-#254A5, IRGKangXi=0830.131, RSKangXi=112.6
254A6 CJK UNIFIED IDEOGRAPH-#254A6, IRGKangXi=0830.131, RSKangXi=112.6
254A7 CJK UNIFIED IDEOGRAPH-#254A7, IRGKangXi=0830.131, RSKangXi=112.6
254A8 CJK UNIFIED IDEOGRAPH-#254A8, IRGKangXi=0830.131, RSKangXi=112.6
254A9 CJK UNIFIED IDEOGRAPH-#254A9, IRGKangXi=0830.131, RSKangXi=112.6
254AA CJK UNIFIED IDEOGRAPH-#254AA, IRGKangXi=0830.160, RSKangXi=112.7
254AB CJK UNIFIED IDEOGRAPH-#254AB, IRGKangXi=0830.180, RSKangXi=112.7
254AC CJK UNIFIED IDEOGRAPH-#254AC, IRGKangXi=0830.230, RSKangXi=112.7
254AD CJK UNIFIED IDEOGRAPH-#254AD, IRGKangXi=0830.270, RSKangXi=112.7
254AE CJK UNIFIED IDEOGRAPH-#254AE, IRGKangXi=0830.290, RSKangXi=112.7
254AF CJK UNIFIED IDEOGRAPH-#254AF, IRGKangXi=0830.310, RSKangXi=112.7
254B0 CJK UNIFIED IDEOGRAPH-#254B0, IRGKangXi=0830.320, RSKangXi=112.7
254B1 CJK UNIFIED IDEOGRAPH-#254B1, IRGKangXi=0830.360, RSKangXi=112.7
254B2 CJK UNIFIED IDEOGRAPH-#254B2, IRGKangXi=0830.370, RSKangXi=112.7
254B3 CJK UNIFIED IDEOGRAPH-#254B3, IRGKangXi=0830.390, RSKangXi=112.7
254B4 CJK UNIFIED IDEOGRAPH-#254B4, IRGKangXi=0831.060, RSKangXi=112.7
254B5 CJK UNIFIED IDEOGRAPH-#254B5, IRGKangXi=0831.110, RSKangXi=112.7
254B6 CJK UNIFIED IDEOGRAPH-#254B6, IRGKangXi=0831.130, RSKangXi=112.7
254B7 CJK UNIFIED IDEOGRAPH-#254B7, IRGKangXi=0831.131, RSKangXi=112.7
254B8 CJK UNIFIED IDEOGRAPH-#254B8, IRGKangXi=0831.131, RSKangXi=112.7
254B9 CJK UNIFIED IDEOGRAPH-#254B9, IRGKangXi=0831.131, RSKangXi=112.7
254BA CJK UNIFIED IDEOGRAPH-#254BA, IRGKangXi=0831.131, RSKangXi=112.7
254BB CJK UNIFIED IDEOGRAPH-#254BB, IRGKangXi=0831.131, RSKangXi=112.7
254BC CJK UNIFIED IDEOGRAPH-#254BC, IRGKangXi=0831.131, RSKangXi=112.7
254BD CJK UNIFIED IDEOGRAPH-#254BD, IRGKangXi=0831.131, RSKangXi=112.7
254BE CJK UNIFIED IDEOGRAPH-#254BE, IRGKangXi=0831.131, RSKangXi=112.7
254BF CJK UNIFIED IDEOGRAPH-#254BF, IRGKangXi=0831.131, RSKangXi=112.7
254C0 CJK UNIFIED IDEOGRAPH-#254C0, IRGKangXi=0831.131, RSKangXi=112.7
254C1 CJK UNIFIED IDEOGRAPH-#254C1, IRGKangXi=0831.131, RSKangXi=112.7
254C2 CJK UNIFIED IDEOGRAPH-#254C2, IRGKangXi=0831.131, RSKangXi=112.7
254C3 CJK UNIFIED IDEOGRAPH-#254C3, IRGKangXi=0831.131, RSKangXi=112.7
254C4 CJK UNIFIED IDEOGRAPH-#254C4, IRGKangXi=0831.131, RSKangXi=112.7
254C5 CJK UNIFIED IDEOGRAPH-#254C5, IRGKangXi=0831.131, RSKangXi=112.7
254C6 CJK UNIFIED IDEOGRAPH-#254C6, IRGKangXi=0831.131, RSKangXi=112.7
254C7 CJK UNIFIED IDEOGRAPH-#254C7, IRGKangXi=0831.131, RSKangXi=112.7
254C8 CJK UNIFIED IDEOGRAPH-#254C8, IRGKangXi=0831.131, RSKangXi=112.7
254C9 CJK UNIFIED IDEOGRAPH-#254C9, IRGKangXi=0831.131, RSKangXi=112.7
254CA CJK UNIFIED IDEOGRAPH-#254CA, IRGKangXi=0831.131, RSKangXi=112.8
254CB CJK UNIFIED IDEOGRAPH-#254CB, IRGKangXi=0831.150, RSKangXi=112.8
254CC CJK UNIFIED IDEOGRAPH-#254CC, IRGKangXi=0831.220, RSKangXi=112.8
254CD CJK UNIFIED IDEOGRAPH-#254CD, IRGKangXi=0831.330, RSKangXi=112.8
254CE CJK UNIFIED IDEOGRAPH-#254CE, IRGKangXi=0831.400, RSKangXi=112.8
254CF CJK UNIFIED IDEOGRAPH-#254CF, IRGKangXi=0831.430, RSKangXi=112.8
254D0 CJK UNIFIED IDEOGRAPH-#254D0, IRGKangXi=0831.450, RSKangXi=112.8
254D1 CJK UNIFIED IDEOGRAPH-#254D1, IRGKangXi=0831.460, RSKangXi=112.8
254D2 CJK UNIFIED IDEOGRAPH-#254D2, IRGKangXi=0832.070, RSKangXi=112.8
254D3 CJK UNIFIED IDEOGRAPH-#254D3, IRGKangXi=0832.110, RSKangXi=112.8
254D4 CJK UNIFIED IDEOGRAPH-#254D4, IRGKangXi=0832.140, RSKangXi=112.8
254D5 CJK UNIFIED IDEOGRAPH-#254D5, IRGKangXi=0832.190, RSKangXi=112.8
254D6 CJK UNIFIED IDEOGRAPH-#254D6, IRGKangXi=0832.200, RSKangXi=112.8
254D7 CJK UNIFIED IDEOGRAPH-#254D7, IRGKangXi=0832.210, RSKangXi=112.8
254D8 CJK UNIFIED IDEOGRAPH-#254D8, IRGKangXi=0832.211, RSKangXi=112.8
254D9 CJK UNIFIED IDEOGRAPH-#254D9, IRGKangXi=0832.211, RSKangXi=112.8
254DA CJK UNIFIED IDEOGRAPH-#254DA, IRGKangXi=0832.211, RSKangXi=112.8
254DB CJK UNIFIED IDEOGRAPH-#254DB, IRGKangXi=0832.211, RSKangXi=112.8
254DC CJK UNIFIED IDEOGRAPH-#254DC, IRGKangXi=0832.211, RSKangXi=112.8
254DD CJK UNIFIED IDEOGRAPH-#254DD, IRGKangXi=0832.211, RSKangXi=112.8
254DE CJK UNIFIED IDEOGRAPH-#254DE, IRGKangXi=0832.211, RSKangXi=112.8
254DF CJK UNIFIED IDEOGRAPH-#254DF, IRGKangXi=0832.211, RSKangXi=112.8
254E0 CJK UNIFIED IDEOGRAPH-#254E0, IRGKangXi=0832.211, RSKangXi=112.8
254E1 CJK UNIFIED IDEOGRAPH-#254E1, IRGKangXi=0832.211, RSKangXi=112.8
254E2 CJK UNIFIED IDEOGRAPH-#254E2, IRGKangXi=0832.211, RSKangXi=112.8
254E3 CJK UNIFIED IDEOGRAPH-#254E3, IRGKangXi=0832.211, RSKangXi=112.8
254E4 CJK UNIFIED IDEOGRAPH-#254E4, IRGKangXi=0832.211, RSKangXi=112.8
254E5 CJK UNIFIED IDEOGRAPH-#254E5, IRGKangXi=0832.211, RSKangXi=112.8
254E6 CJK UNIFIED IDEOGRAPH-#254E6, IRGKangXi=0832.211, RSKangXi=112.8
254E7 CJK UNIFIED IDEOGRAPH-#254E7, IRGKangXi=0832.211, RSKangXi=112.8
254E8 CJK UNIFIED IDEOGRAPH-#254E8, IRGKangXi=0832.211, RSKangXi=112.8
254E9 CJK UNIFIED IDEOGRAPH-#254E9, IRGKangXi=0832.211, RSKangXi=112.8
254EA CJK UNIFIED IDEOGRAPH-#254EA, IRGKangXi=0832.211, RSKangXi=112.8
254EB CJK UNIFIED IDEOGRAPH-#254EB, IRGKangXi=0832.211, RSKangXi=112.8
254EC CJK UNIFIED IDEOGRAPH-#254EC, IRGKangXi=0832.211, RSKangXi=112.8
254ED CJK UNIFIED IDEOGRAPH-#254ED, IRGKangXi=0832.211, RSKangXi=112.8
254EE CJK UNIFIED IDEOGRAPH-#254EE, IRGKangXi=0832.211, RSKangXi=112.8
254EF CJK UNIFIED IDEOGRAPH-#254EF, IRGKangXi=0832.211, RSKangXi=112.8
254F0 CJK UNIFIED IDEOGRAPH-#254F0, IRGKangXi=0832.211, RSKangXi=112.8
254F1 CJK UNIFIED IDEOGRAPH-#254F1, IRGKangXi=0832.211, RSKangXi=112.8
254F2 CJK UNIFIED IDEOGRAPH-#254F2, IRGKangXi=0832.211, RSKangXi=112.8
254F3 CJK UNIFIED IDEOGRAPH-#254F3, IRGKangXi=0832.211, RSKangXi=112.8
254F4 CJK UNIFIED IDEOGRAPH-#254F4, IRGKangXi=0832.211, RSKangXi=112.8
254F5 CJK UNIFIED IDEOGRAPH-#254F5, IRGKangXi=0832.211, RSKangXi=112.8
254F6 CJK UNIFIED IDEOGRAPH-#254F6, IRGKangXi=0832.211, RSKangXi=112.8
254F7 CJK UNIFIED IDEOGRAPH-#254F7, IRGKangXi=0832.211, RSKangXi=112.8
254F8 CJK UNIFIED IDEOGRAPH-#254F8, IRGKangXi=0832.211, RSKangXi=112.8
254F9 CJK UNIFIED IDEOGRAPH-#254F9, IRGKangXi=0832.211, RSKangXi=112.8
254FA CJK UNIFIED IDEOGRAPH-#254FA, IRGKangXi=0832.220, RSKangXi=112.9
254FB CJK UNIFIED IDEOGRAPH-#254FB, IRGKangXi=0832.270, RSKangXi=112.9
254FC CJK UNIFIED IDEOGRAPH-#254FC, IRGKangXi=0832.290, RSKangXi=112.9
254FD CJK UNIFIED IDEOGRAPH-#254FD, IRGKangXi=0832.310, RSKangXi=112.9
254FE CJK UNIFIED IDEOGRAPH-#254FE, IRGKangXi=0832.320, RSKangXi=112.9
254FF CJK UNIFIED IDEOGRAPH-#254FF, IRGKangXi=0832.360, RSKangXi=112.9, Def{stone roller, weight}
25500 CJK UNIFIED IDEOGRAPH-#25500, IRGKangXi=0833.020, RSKangXi=112.9, Def{roar, crash}
25501 CJK UNIFIED IDEOGRAPH-#25501, IRGKangXi=0833.040, RSKangXi=112.9
25502 CJK UNIFIED IDEOGRAPH-#25502, IRGKangXi=0833.070, RSKangXi=112.9
25503 CJK UNIFIED IDEOGRAPH-#25503, IRGKangXi=0833.080, RSKangXi=112.9
25504 CJK UNIFIED IDEOGRAPH-#25504, IRGKangXi=0833.120, RSKangXi=112.9
25505 CJK UNIFIED IDEOGRAPH-#25505, IRGKangXi=0833.190, RSKangXi=112.9
25506 CJK UNIFIED IDEOGRAPH-#25506, IRGKangXi=0833.240, RSKangXi=112.9
25507 CJK UNIFIED IDEOGRAPH-#25507, IRGKangXi=0833.260, RSKangXi=112.9
25508 CJK UNIFIED IDEOGRAPH-#25508, IRGKangXi=0833.270, RSKangXi=112.9
25509 CJK UNIFIED IDEOGRAPH-#25509, IRGKangXi=0833.280, RSKangXi=112.9
2550A CJK UNIFIED IDEOGRAPH-#2550A, IRGKangXi=0833.290, RSKangXi=112.9
2550B CJK UNIFIED IDEOGRAPH-#2550B, IRGKangXi=0833.291, RSKangXi=112.9
2550C CJK UNIFIED IDEOGRAPH-#2550C, IRGKangXi=0833.291, RSKangXi=112.9
2550D CJK UNIFIED IDEOGRAPH-#2550D, IRGKangXi=0833.291, RSKangXi=112.9
2550E CJK UNIFIED IDEOGRAPH-#2550E, IRGKangXi=0833.291, RSKangXi=112.9
2550F CJK UNIFIED IDEOGRAPH-#2550F, IRGKangXi=0833.291, RSKangXi=112.9
25510 CJK UNIFIED IDEOGRAPH-#25510, IRGKangXi=0833.291, RSKangXi=112.9
25511 CJK UNIFIED IDEOGRAPH-#25511, IRGKangXi=0833.291, RSKangXi=112.9
25512 CJK UNIFIED IDEOGRAPH-#25512, IRGKangXi=0833.291, RSKangXi=112.9
25513 CJK UNIFIED IDEOGRAPH-#25513, IRGKangXi=0833.291, RSKangXi=112.9
25514 CJK UNIFIED IDEOGRAPH-#25514, IRGKangXi=0833.291, RSKangXi=112.9
25515 CJK UNIFIED IDEOGRAPH-#25515, IRGKangXi=0833.291, RSKangXi=112.9
25516 CJK UNIFIED IDEOGRAPH-#25516, IRGKangXi=0833.291, RSKangXi=112.9
25517 CJK UNIFIED IDEOGRAPH-#25517, IRGKangXi=0833.291, RSKangXi=112.9
25518 CJK UNIFIED IDEOGRAPH-#25518, IRGKangXi=0833.291, RSKangXi=112.9
25519 CJK UNIFIED IDEOGRAPH-#25519, IRGKangXi=0833.291, RSKangXi=112.9
2551A CJK UNIFIED IDEOGRAPH-#2551A, IRGKangXi=0833.291, RSKangXi=112.9
2551B CJK UNIFIED IDEOGRAPH-#2551B, IRGKangXi=0833.291, RSKangXi=112.9
2551C CJK UNIFIED IDEOGRAPH-#2551C, IRGKangXi=0833.291, RSKangXi=112.9
2551D CJK UNIFIED IDEOGRAPH-#2551D, IRGKangXi=0833.291, RSKangXi=112.9
2551E CJK UNIFIED IDEOGRAPH-#2551E, IRGKangXi=0833.291, RSKangXi=112.9
2551F CJK UNIFIED IDEOGRAPH-#2551F, IRGKangXi=0833.291, RSKangXi=112.9
25520 CJK UNIFIED IDEOGRAPH-#25520, IRGKangXi=0833.291, RSKangXi=112.9
25521 CJK UNIFIED IDEOGRAPH-#25521, IRGKangXi=0833.291, RSKangXi=112.9
25522 CJK UNIFIED IDEOGRAPH-#25522, IRGKangXi=0833.291, RSKangXi=112.9
25523 CJK UNIFIED IDEOGRAPH-#25523, IRGKangXi=0833.291, RSKangXi=112.9
25524 CJK UNIFIED IDEOGRAPH-#25524, IRGKangXi=0833.291, RSKangXi=112.9
25525 CJK UNIFIED IDEOGRAPH-#25525, IRGKangXi=0833.291, RSKangXi=112.9
25526 CJK UNIFIED IDEOGRAPH-#25526, IRGKangXi=0833.291, RSKangXi=112.9
25527 CJK UNIFIED IDEOGRAPH-#25527, IRGKangXi=0833.291, RSKangXi=112.9
25528 CJK UNIFIED IDEOGRAPH-#25528, IRGKangXi=0833.291, RSKangXi=112.9
25529 CJK UNIFIED IDEOGRAPH-#25529, IRGKangXi=0833.291, RSKangXi=112.9
2552A CJK UNIFIED IDEOGRAPH-#2552A, IRGKangXi=0833.291, RSKangXi=112.9
2552B CJK UNIFIED IDEOGRAPH-#2552B, IRGKangXi=0833.291, RSKangXi=112.9
2552C CJK UNIFIED IDEOGRAPH-#2552C, IRGKangXi=0833.291, RSKangXi=112.9
2552D CJK UNIFIED IDEOGRAPH-#2552D, IRGKangXi=0833.300, RSKangXi=112.10
2552E CJK UNIFIED IDEOGRAPH-#2552E, IRGKangXi=0834.040, RSKangXi=112.10
2552F CJK UNIFIED IDEOGRAPH-#2552F, IRGKangXi=0834.050, RSKangXi=112.10
25530 CJK UNIFIED IDEOGRAPH-#25530, IRGKangXi=0834.070, RSKangXi=112.10
25531 CJK UNIFIED IDEOGRAPH-#25531, IRGKangXi=0834.110, RSKangXi=112.10, Def{(Cant.) to slip}
25532 CJK UNIFIED IDEOGRAPH-#25532, IRGKangXi=0834.190, RSKangXi=112.10
25533 CJK UNIFIED IDEOGRAPH-#25533, IRGKangXi=0835.030, RSKangXi=112.10
25534 CJK UNIFIED IDEOGRAPH-#25534, IRGKangXi=0835.061, RSKangXi=112.10
25535 CJK UNIFIED IDEOGRAPH-#25535, IRGKangXi=0835.061, RSKangXi=112.10, Def{variant of 磁 U+78C1, magnetic; magnetism; procelain}
25536 CJK UNIFIED IDEOGRAPH-#25536, IRGKangXi=0835.061, RSKangXi=112.10
25537 CJK UNIFIED IDEOGRAPH-#25537, IRGKangXi=0835.061, RSKangXi=112.10
25538 CJK UNIFIED IDEOGRAPH-#25538, IRGKangXi=0835.061, RSKangXi=112.10
25539 CJK UNIFIED IDEOGRAPH-#25539, IRGKangXi=0835.061, RSKangXi=112.10
2553A CJK UNIFIED IDEOGRAPH-#2553A, IRGKangXi=0835.061, RSKangXi=112.10
2553B CJK UNIFIED IDEOGRAPH-#2553B, IRGKangXi=0835.061, RSKangXi=112.10
2553C CJK UNIFIED IDEOGRAPH-#2553C, IRGKangXi=0835.061, RSKangXi=112.10
2553D CJK UNIFIED IDEOGRAPH-#2553D, IRGKangXi=0835.061, RSKangXi=112.10
2553E CJK UNIFIED IDEOGRAPH-#2553E, IRGKangXi=0835.061, RSKangXi=112.10
2553F CJK UNIFIED IDEOGRAPH-#2553F, IRGKangXi=0835.061, RSKangXi=112.10, Def{(Cant.) classifier for cannons, large guns, etc.}
25540 CJK UNIFIED IDEOGRAPH-#25540, IRGKangXi=0835.061, RSKangXi=112.10
25541 CJK UNIFIED IDEOGRAPH-#25541, IRGKangXi=0835.061, RSKangXi=112.10
25542 CJK UNIFIED IDEOGRAPH-#25542, IRGKangXi=0835.061, RSKangXi=112.10
25543 CJK UNIFIED IDEOGRAPH-#25543, IRGKangXi=0835.061, RSKangXi=112.10
25544 CJK UNIFIED IDEOGRAPH-#25544, IRGKangXi=0835.061, RSKangXi=112.10
25545 CJK UNIFIED IDEOGRAPH-#25545, IRGKangXi=0835.061, RSKangXi=112.10
25546 CJK UNIFIED IDEOGRAPH-#25546, IRGKangXi=0835.061, RSKangXi=112.10
25547 CJK UNIFIED IDEOGRAPH-#25547, IRGKangXi=0835.061, RSKangXi=112.10
25548 CJK UNIFIED IDEOGRAPH-#25548, IRGKangXi=0835.061, RSKangXi=112.10
25549 CJK UNIFIED IDEOGRAPH-#25549, IRGKangXi=0835.061, RSKangXi=112.10
2554A CJK UNIFIED IDEOGRAPH-#2554A, IRGKangXi=0835.061, RSKangXi=112.10
2554B CJK UNIFIED IDEOGRAPH-#2554B, IRGKangXi=0835.061, RSKangXi=112.10
2554C CJK UNIFIED IDEOGRAPH-#2554C, IRGKangXi=0835.090, RSKangXi=112.11
2554D CJK UNIFIED IDEOGRAPH-#2554D, IRGKangXi=0835.110, RSKangXi=112.11
2554E CJK UNIFIED IDEOGRAPH-#2554E, IRGKangXi=0835.170, RSKangXi=112.11
2554F CJK UNIFIED IDEOGRAPH-#2554F, IRGKangXi=0835.190, RSKangXi=112.11
25550 CJK UNIFIED IDEOGRAPH-#25550, IRGKangXi=0835.210, RSKangXi=112.11
25551 CJK UNIFIED IDEOGRAPH-#25551, IRGKangXi=0835.220, RSKangXi=112.11
25552 CJK UNIFIED IDEOGRAPH-#25552, IRGKangXi=0835.230, RSKangXi=112.11
25553 CJK UNIFIED IDEOGRAPH-#25553, IRGKangXi=0835.240, RSKangXi=112.11
25554 CJK UNIFIED IDEOGRAPH-#25554, IRGKangXi=0835.290, RSKangXi=112.11
25555 CJK UNIFIED IDEOGRAPH-#25555, IRGKangXi=0835.300, RSKangXi=112.11
25556 CJK UNIFIED IDEOGRAPH-#25556, IRGKangXi=0835.340, RSKangXi=112.11
25557 CJK UNIFIED IDEOGRAPH-#25557, IRGKangXi=0835.350, RSKangXi=112.11
25558 CJK UNIFIED IDEOGRAPH-#25558, IRGKangXi=0835.410, RSKangXi=112.11
25559 CJK UNIFIED IDEOGRAPH-#25559, IRGKangXi=0836.080, RSKangXi=112.11
2555A CJK UNIFIED IDEOGRAPH-#2555A, IRGKangXi=0836.090, RSKangXi=112.11
2555B CJK UNIFIED IDEOGRAPH-#2555B, IRGKangXi=0836.091, RSKangXi=112.11
2555C CJK UNIFIED IDEOGRAPH-#2555C, IRGKangXi=0836.091, RSKangXi=112.11
2555D CJK UNIFIED IDEOGRAPH-#2555D, IRGKangXi=0836.091, RSKangXi=112.11
2555E CJK UNIFIED IDEOGRAPH-#2555E, IRGKangXi=0836.091, RSKangXi=112.11
2555F CJK UNIFIED IDEOGRAPH-#2555F, IRGKangXi=0836.091, RSKangXi=112.11
25560 CJK UNIFIED IDEOGRAPH-#25560, IRGKangXi=0836.091, RSKangXi=112.11
25561 CJK UNIFIED IDEOGRAPH-#25561, IRGKangXi=0836.091, RSKangXi=112.11
25562 CJK UNIFIED IDEOGRAPH-#25562, IRGKangXi=0836.091, RSKangXi=112.11
25563 CJK UNIFIED IDEOGRAPH-#25563, IRGKangXi=0836.091, RSKangXi=112.11
25564 CJK UNIFIED IDEOGRAPH-#25564, IRGKangXi=0836.091, RSKangXi=112.11
25565 CJK UNIFIED IDEOGRAPH-#25565, IRGKangXi=0836.091, RSKangXi=112.11
25566 CJK UNIFIED IDEOGRAPH-#25566, IRGKangXi=0836.091, RSKangXi=112.11
25567 CJK UNIFIED IDEOGRAPH-#25567, IRGKangXi=0836.091, RSKangXi=112.11
25568 CJK UNIFIED IDEOGRAPH-#25568, IRGKangXi=0836.091, RSKangXi=112.11
25569 CJK UNIFIED IDEOGRAPH-#25569, IRGKangXi=0836.091, RSKangXi=112.11
2556A CJK UNIFIED IDEOGRAPH-#2556A, IRGKangXi=0836.091, RSKangXi=112.11
2556B CJK UNIFIED IDEOGRAPH-#2556B, IRGKangXi=0836.091, RSKangXi=112.11
2556C CJK UNIFIED IDEOGRAPH-#2556C, IRGKangXi=0836.091, RSKangXi=112.11
2556D CJK UNIFIED IDEOGRAPH-#2556D, IRGKangXi=0836.091, RSKangXi=112.11
2556E CJK UNIFIED IDEOGRAPH-#2556E, IRGKangXi=0836.091, RSKangXi=112.11
2556F CJK UNIFIED IDEOGRAPH-#2556F, IRGKangXi=0836.091, RSKangXi=112.11
25570 CJK UNIFIED IDEOGRAPH-#25570, IRGKangXi=0836.100, RSKangXi=112.12
25571 CJK UNIFIED IDEOGRAPH-#25571, IRGKangXi=0836.120, RSKangXi=112.12
25572 CJK UNIFIED IDEOGRAPH-#25572, IRGKangXi=0836.150, RSKangXi=112.12
25573 CJK UNIFIED IDEOGRAPH-#25573, IRGKangXi=0836.160, RSKangXi=112.12
25574 CJK UNIFIED IDEOGRAPH-#25574, IRGKangXi=0836.200, RSKangXi=112.12
25575 CJK UNIFIED IDEOGRAPH-#25575, IRGKangXi=0836.210, RSKangXi=112.12
25576 CJK UNIFIED IDEOGRAPH-#25576, IRGKangXi=0836.220, RSKangXi=112.12
25577 CJK UNIFIED IDEOGRAPH-#25577, IRGKangXi=0836.310, RSKangXi=112.12
25578 CJK UNIFIED IDEOGRAPH-#25578, IRGKangXi=0836.330, RSKangXi=112.12
25579 CJK UNIFIED IDEOGRAPH-#25579, IRGKangXi=0836.340, RSKangXi=112.12
2557A CJK UNIFIED IDEOGRAPH-#2557A, IRGKangXi=0836.400, RSKangXi=112.12
2557B CJK UNIFIED IDEOGRAPH-#2557B, IRGKangXi=0837.040, RSKangXi=112.12
2557C CJK UNIFIED IDEOGRAPH-#2557C, IRGKangXi=0837.060, RSKangXi=112.12
2557D CJK UNIFIED IDEOGRAPH-#2557D, IRGKangXi=0837.070, RSKangXi=112.12
2557E CJK UNIFIED IDEOGRAPH-#2557E, IRGKangXi=0837.080, RSKangXi=112.12
2557F CJK UNIFIED IDEOGRAPH-#2557F, IRGKangXi=0837.090, RSKangXi=112.12
25580 CJK UNIFIED IDEOGRAPH-#25580, IRGKangXi=0837.091, RSKangXi=112.12
25581 CJK UNIFIED IDEOGRAPH-#25581, IRGKangXi=0837.091, RSKangXi=112.12
25582 CJK UNIFIED IDEOGRAPH-#25582, IRGKangXi=0837.091, RSKangXi=112.12
25583 CJK UNIFIED IDEOGRAPH-#25583, IRGKangXi=0837.091, RSKangXi=112.12
25584 CJK UNIFIED IDEOGRAPH-#25584, IRGKangXi=0837.091, RSKangXi=112.12
25585 CJK UNIFIED IDEOGRAPH-#25585, IRGKangXi=0837.091, RSKangXi=112.12
25586 CJK UNIFIED IDEOGRAPH-#25586, IRGKangXi=0837.091, RSKangXi=112.12
25587 CJK UNIFIED IDEOGRAPH-#25587, IRGKangXi=0837.091, RSKangXi=112.12
25588 CJK UNIFIED IDEOGRAPH-#25588, IRGKangXi=0837.091, RSKangXi=112.12
25589 CJK UNIFIED IDEOGRAPH-#25589, IRGKangXi=0837.091, RSKangXi=112.12
2558A CJK UNIFIED IDEOGRAPH-#2558A, IRGKangXi=0837.091, RSKangXi=112.12
2558B CJK UNIFIED IDEOGRAPH-#2558B, IRGKangXi=0837.091, RSKangXi=112.12
2558C CJK UNIFIED IDEOGRAPH-#2558C, IRGKangXi=0837.091, RSKangXi=112.12
2558D CJK UNIFIED IDEOGRAPH-#2558D, IRGKangXi=0837.091, RSKangXi=112.12
2558E CJK UNIFIED IDEOGRAPH-#2558E, IRGKangXi=0837.091, RSKangXi=112.12
2558F CJK UNIFIED IDEOGRAPH-#2558F, IRGKangXi=0837.091, RSKangXi=112.12
25590 CJK UNIFIED IDEOGRAPH-#25590, IRGKangXi=0837.091, RSKangXi=112.12
25591 CJK UNIFIED IDEOGRAPH-#25591, IRGKangXi=0837.091, RSKangXi=112.12
25592 CJK UNIFIED IDEOGRAPH-#25592, IRGKangXi=0837.091, RSKangXi=112.12
25593 CJK UNIFIED IDEOGRAPH-#25593, IRGKangXi=0837.091, RSKangXi=112.12
25594 CJK UNIFIED IDEOGRAPH-#25594, IRGKangXi=0837.091, RSKangXi=112.12
25595 CJK UNIFIED IDEOGRAPH-#25595, IRGKangXi=0837.091, RSKangXi=112.12
25596 CJK UNIFIED IDEOGRAPH-#25596, IRGKangXi=0837.091, RSKangXi=112.12
25597 CJK UNIFIED IDEOGRAPH-#25597, IRGKangXi=0837.170, RSKangXi=112.13
25598 CJK UNIFIED IDEOGRAPH-#25598, IRGKangXi=0837.180, RSKangXi=112.13
25599 CJK UNIFIED IDEOGRAPH-#25599, IRGKangXi=0837.190, RSKangXi=112.13
2559A CJK UNIFIED IDEOGRAPH-#2559A, IRGKangXi=0837.210, RSKangXi=112.13
2559B CJK UNIFIED IDEOGRAPH-#2559B, IRGKangXi=0837.230, RSKangXi=112.13
2559C CJK UNIFIED IDEOGRAPH-#2559C, IRGKangXi=0837.240, RSKangXi=112.13
2559D CJK UNIFIED IDEOGRAPH-#2559D, IRGKangXi=0837.260, RSKangXi=112.13
2559E CJK UNIFIED IDEOGRAPH-#2559E, IRGKangXi=0837.280, RSKangXi=112.13
2559F CJK UNIFIED IDEOGRAPH-#2559F, IRGKangXi=0837.310, RSKangXi=112.13
255A0 CJK UNIFIED IDEOGRAPH-#255A0, IRGKangXi=0837.360, RSKangXi=112.13
255A1 CJK UNIFIED IDEOGRAPH-#255A1, IRGKangXi=0837.400, RSKangXi=112.13
255A2 CJK UNIFIED IDEOGRAPH-#255A2, IRGKangXi=0837.401, RSKangXi=112.13
255A3 CJK UNIFIED IDEOGRAPH-#255A3, IRGKangXi=0837.401, RSKangXi=112.13
255A4 CJK UNIFIED IDEOGRAPH-#255A4, IRGKangXi=0837.401, RSKangXi=112.13
255A5 CJK UNIFIED IDEOGRAPH-#255A5, IRGKangXi=0837.401, RSKangXi=112.13
255A6 CJK UNIFIED IDEOGRAPH-#255A6, IRGKangXi=0837.401, RSKangXi=112.13
255A7 CJK UNIFIED IDEOGRAPH-#255A7, IRGKangXi=0837.411, RSKangXi=112.13
255A8 CJK UNIFIED IDEOGRAPH-#255A8, IRGKangXi=0837.411, RSKangXi=112.13
255A9 CJK UNIFIED IDEOGRAPH-#255A9, IRGKangXi=0837.411, RSKangXi=112.13
255AA CJK UNIFIED IDEOGRAPH-#255AA, IRGKangXi=0837.430, RSKangXi=112.14
255AB CJK UNIFIED IDEOGRAPH-#255AB, IRGKangXi=0837.450, RSKangXi=112.14
255AC CJK UNIFIED IDEOGRAPH-#255AC, IRGKangXi=0838.030, RSKangXi=112.14
255AD CJK UNIFIED IDEOGRAPH-#255AD, IRGKangXi=0838.051, RSKangXi=112.14
255AE CJK UNIFIED IDEOGRAPH-#255AE, IRGKangXi=0838.051, RSKangXi=112.14
255AF CJK UNIFIED IDEOGRAPH-#255AF, IRGKangXi=0838.051, RSKangXi=112.14
255B0 CJK UNIFIED IDEOGRAPH-#255B0, IRGKangXi=0838.051, RSKangXi=112.14
255B1 CJK UNIFIED IDEOGRAPH-#255B1, IRGKangXi=0838.051, RSKangXi=112.14
255B2 CJK UNIFIED IDEOGRAPH-#255B2, IRGKangXi=0838.051, RSKangXi=112.14
255B3 CJK UNIFIED IDEOGRAPH-#255B3, IRGKangXi=0838.051, RSKangXi=112.14
255B4 CJK UNIFIED IDEOGRAPH-#255B4, IRGKangXi=0838.051, RSKangXi=112.14
255B5 CJK UNIFIED IDEOGRAPH-#255B5, IRGKangXi=0838.051, RSKangXi=112.14
255B6 CJK UNIFIED IDEOGRAPH-#255B6, IRGKangXi=0838.051, RSKangXi=112.14
255B7 CJK UNIFIED IDEOGRAPH-#255B7, IRGKangXi=0838.051, RSKangXi=112.14
255B8 CJK UNIFIED IDEOGRAPH-#255B8, IRGKangXi=0838.051, RSKangXi=112.14
255B9 CJK UNIFIED IDEOGRAPH-#255B9, IRGKangXi=0838.051, RSKangXi=112.14
255BA CJK UNIFIED IDEOGRAPH-#255BA, IRGKangXi=0838.051, RSKangXi=112.14
255BB CJK UNIFIED IDEOGRAPH-#255BB, IRGKangXi=0838.090, RSKangXi=112.15
255BC CJK UNIFIED IDEOGRAPH-#255BC, IRGKangXi=0838.100, RSKangXi=112.15
255BD CJK UNIFIED IDEOGRAPH-#255BD, IRGKangXi=0838.120, RSKangXi=112.15
255BE CJK UNIFIED IDEOGRAPH-#255BE, IRGKangXi=0838.130, RSKangXi=112.15
255BF CJK UNIFIED IDEOGRAPH-#255BF, IRGKangXi=0838.140, RSKangXi=112.15
255C0 CJK UNIFIED IDEOGRAPH-#255C0, IRGKangXi=0838.180, RSKangXi=112.15
255C1 CJK UNIFIED IDEOGRAPH-#255C1, IRGKangXi=0838.190, RSKangXi=112.15
255C2 CJK UNIFIED IDEOGRAPH-#255C2, IRGKangXi=0838.260, RSKangXi=112.15
255C3 CJK UNIFIED IDEOGRAPH-#255C3, IRGKangXi=0838.261, RSKangXi=112.15
255C4 CJK UNIFIED IDEOGRAPH-#255C4, IRGKangXi=0838.261, RSKangXi=112.15
255C5 CJK UNIFIED IDEOGRAPH-#255C5, IRGKangXi=0838.261, RSKangXi=112.15
255C6 CJK UNIFIED IDEOGRAPH-#255C6, IRGKangXi=0838.261, RSKangXi=112.15
255C7 CJK UNIFIED IDEOGRAPH-#255C7, IRGKangXi=0838.261, RSKangXi=112.15
255C8 CJK UNIFIED IDEOGRAPH-#255C8, IRGKangXi=0838.261, RSKangXi=112.15
255C9 CJK UNIFIED IDEOGRAPH-#255C9, IRGKangXi=0838.261, RSKangXi=112.15
255CA CJK UNIFIED IDEOGRAPH-#255CA, IRGKangXi=0838.261, RSKangXi=112.15
255CB CJK UNIFIED IDEOGRAPH-#255CB, IRGKangXi=0838.261, RSKangXi=112.15
255CC CJK UNIFIED IDEOGRAPH-#255CC, IRGKangXi=0838.261, RSKangXi=112.15
255CD CJK UNIFIED IDEOGRAPH-#255CD, IRGKangXi=0838.261, RSKangXi=112.15
255CE CJK UNIFIED IDEOGRAPH-#255CE, IRGKangXi=0838.261, RSKangXi=112.15
255CF CJK UNIFIED IDEOGRAPH-#255CF, IRGKangXi=0838.261, RSKangXi=115.15
255D0 CJK UNIFIED IDEOGRAPH-#255D0, IRGKangXi=0838.261, RSKangXi=112.15
255D1 CJK UNIFIED IDEOGRAPH-#255D1, IRGKangXi=0838.261, RSKangXi=112.15
255D2 CJK UNIFIED IDEOGRAPH-#255D2, IRGKangXi=0838.280, RSKangXi=112.16
255D3 CJK UNIFIED IDEOGRAPH-#255D3, IRGKangXi=0838.300, RSKangXi=112.16
255D4 CJK UNIFIED IDEOGRAPH-#255D4, IRGKangXi=0838.381, RSKangXi=112.16
255D5 CJK UNIFIED IDEOGRAPH-#255D5, IRGKangXi=0838.381, RSKangXi=112.16
255D6 CJK UNIFIED IDEOGRAPH-#255D6, IRGKangXi=0838.381, RSKangXi=112.16
255D7 CJK UNIFIED IDEOGRAPH-#255D7, IRGKangXi=0838.381, RSKangXi=112.16
255D8 CJK UNIFIED IDEOGRAPH-#255D8, IRGKangXi=0838.381, RSKangXi=112.16
255D9 CJK UNIFIED IDEOGRAPH-#255D9, IRGKangXi=0838.381, RSKangXi=112.16
255DA CJK UNIFIED IDEOGRAPH-#255DA, IRGKangXi=0838.381, RSKangXi=112.16
255DB CJK UNIFIED IDEOGRAPH-#255DB, IRGKangXi=0838.381, RSKangXi=112.16
255DC CJK UNIFIED IDEOGRAPH-#255DC, IRGKangXi=0838.381, RSKangXi=112.16
255DD CJK UNIFIED IDEOGRAPH-#255DD, IRGKangXi=0839.010, RSKangXi=112.17
255DE CJK UNIFIED IDEOGRAPH-#255DE, IRGKangXi=0839.030, RSKangXi=112.17
255DF CJK UNIFIED IDEOGRAPH-#255DF, IRGKangXi=0839.040, RSKangXi=112.17
255E0 CJK UNIFIED IDEOGRAPH-#255E0, IRGKangXi=0839.051, RSKangXi=112.17
255E1 CJK UNIFIED IDEOGRAPH-#255E1, IRGKangXi=0839.051, RSKangXi=112.17
255E2 CJK UNIFIED IDEOGRAPH-#255E2, IRGKangXi=0839.051, RSKangXi=112.17
255E3 CJK UNIFIED IDEOGRAPH-#255E3, IRGKangXi=0839.051, RSKangXi=112.17
255E4 CJK UNIFIED IDEOGRAPH-#255E4, IRGKangXi=0839.051, RSKangXi=112.17
255E5 CJK UNIFIED IDEOGRAPH-#255E5, IRGKangXi=0839.051, RSKangXi=112.17
255E6 CJK UNIFIED IDEOGRAPH-#255E6, IRGKangXi=0839.051, RSKangXi=112.17
255E7 CJK UNIFIED IDEOGRAPH-#255E7, IRGKangXi=0839.051, RSKangXi=112.17
255E8 CJK UNIFIED IDEOGRAPH-#255E8, IRGKangXi=0839.051, RSKangXi=112.17
255E9 CJK UNIFIED IDEOGRAPH-#255E9, IRGKangXi=0839.051, RSKangXi=112.17
255EA CJK UNIFIED IDEOGRAPH-#255EA, IRGKangXi=0839.051, RSKangXi=112.17
255EB CJK UNIFIED IDEOGRAPH-#255EB, IRGKangXi=0839.060, RSKangXi=112.18
255EC CJK UNIFIED IDEOGRAPH-#255EC, IRGKangXi=0839.070, RSKangXi=112.15
255ED CJK UNIFIED IDEOGRAPH-#255ED, IRGKangXi=0839.080, RSKangXi=112.18
255EE CJK UNIFIED IDEOGRAPH-#255EE, IRGKangXi=0839.090, RSKangXi=112.18
255EF CJK UNIFIED IDEOGRAPH-#255EF, IRGKangXi=0839.091, RSKangXi=112.18
255F0 CJK UNIFIED IDEOGRAPH-#255F0, IRGKangXi=0839.091, RSKangXi=112.18
255F1 CJK UNIFIED IDEOGRAPH-#255F1, IRGKangXi=0839.091, RSKangXi=112.18
255F2 CJK UNIFIED IDEOGRAPH-#255F2, IRGKangXi=0839.091, RSKangXi=112.18
255F3 CJK UNIFIED IDEOGRAPH-#255F3, IRGKangXi=0839.091, RSKangXi=112.18
255F4 CJK UNIFIED IDEOGRAPH-#255F4, IRGKangXi=0839.100, RSKangXi=112.19
255F5 CJK UNIFIED IDEOGRAPH-#255F5, IRGKangXi=0839.130, RSKangXi=112.19
255F6 CJK UNIFIED IDEOGRAPH-#255F6, IRGKangXi=0839.131, RSKangXi=186.15
255F7 CJK UNIFIED IDEOGRAPH-#255F7, IRGKangXi=0839.131, RSKangXi=112.19
255F8 CJK UNIFIED IDEOGRAPH-#255F8, IRGKangXi=0839.131, RSKangXi=112.19
255F9 CJK UNIFIED IDEOGRAPH-#255F9, IRGKangXi=0839.141, RSKangXi=112.20
255FA CJK UNIFIED IDEOGRAPH-#255FA, IRGKangXi=0839.160, RSKangXi=112.21
255FB CJK UNIFIED IDEOGRAPH-#255FB, IRGKangXi=0839.161, RSKangXi=112.21
255FC CJK UNIFIED IDEOGRAPH-#255FC, IRGKangXi=0839.161, RSKangXi=112.21
255FD CJK UNIFIED IDEOGRAPH-#255FD, IRGKangXi=0839.161, RSKangXi=112.21
255FE CJK UNIFIED IDEOGRAPH-#255FE, IRGKangXi=0839.170, RSKangXi=112.22
255FF CJK UNIFIED IDEOGRAPH-#255FF, IRGKangXi=0839.180, RSKangXi=112.22
25600 CJK UNIFIED IDEOGRAPH-#25600, IRGKangXi=0839.181, RSKangXi=112.22
25601 CJK UNIFIED IDEOGRAPH-#25601, IRGKangXi=0839.181, RSKangXi=112.23
25602 CJK UNIFIED IDEOGRAPH-#25602, IRGKangXi=0839.181, RSKangXi=112.23
25603 CJK UNIFIED IDEOGRAPH-#25603, IRGKangXi=0839.181, RSKangXi=112.24
25604 CJK UNIFIED IDEOGRAPH-#25604, IRGKangXi=0839.190, RSKangXi=112.29
25605 CJK UNIFIED IDEOGRAPH-#25605, IRGKangXi=0839.230, RSKangXi=113.0
25606 CJK UNIFIED IDEOGRAPH-#25606, IRGKangXi=0839.231, RSKangXi=113.1
25607 CJK UNIFIED IDEOGRAPH-#25607, IRGKangXi=0839.240, RSKangXi=113.2
25608 CJK UNIFIED IDEOGRAPH-#25608, IRGKangXi=0839.251, RSKangXi=113.2
25609 CJK UNIFIED IDEOGRAPH-#25609, IRGKangXi=0839.251, RSKangXi=113.2
2560A CJK UNIFIED IDEOGRAPH-#2560A, IRGKangXi=0839.251, RSKangXi=113.2
2560B CJK UNIFIED IDEOGRAPH-#2560B, IRGKangXi=0839.251, RSKangXi=113.2
2560C CJK UNIFIED IDEOGRAPH-#2560C, IRGKangXi=0839.251, RSKangXi=113.2
2560D CJK UNIFIED IDEOGRAPH-#2560D, IRGKangXi=0840.031, RSKangXi=113.3
2560E CJK UNIFIED IDEOGRAPH-#2560E, IRGKangXi=0840.031, RSKangXi=113.3
2560F CJK UNIFIED IDEOGRAPH-#2560F, IRGKangXi=0840.031, RSKangXi=113.3
25610 CJK UNIFIED IDEOGRAPH-#25610, IRGKangXi=0840.031, RSKangXi=113.3
25611 CJK UNIFIED IDEOGRAPH-#25611, IRGKangXi=0840.031, RSKangXi=113.3
25612 CJK UNIFIED IDEOGRAPH-#25612, IRGKangXi=0840.031, RSKangXi=113.3
25613 CJK UNIFIED IDEOGRAPH-#25613, IRGKangXi=0840.031, RSKangXi=113.3
25614 CJK UNIFIED IDEOGRAPH-#25614, IRGKangXi=0840.031, RSKangXi=113.3
25615 CJK UNIFIED IDEOGRAPH-#25615, IRGKangXi=0840.130, RSKangXi=113.4
25616 CJK UNIFIED IDEOGRAPH-#25616, IRGKangXi=0841.030, RSKangXi=113.4
25617 CJK UNIFIED IDEOGRAPH-#25617, IRGKangXi=0841.031, RSKangXi=113.4
25618 CJK UNIFIED IDEOGRAPH-#25618, IRGKangXi=0841.031, RSKangXi=113.4
25619 CJK UNIFIED IDEOGRAPH-#25619, IRGKangXi=0841.031, RSKangXi=113.4
2561A CJK UNIFIED IDEOGRAPH-#2561A, IRGKangXi=0841.031, RSKangXi=113.4
2561B CJK UNIFIED IDEOGRAPH-#2561B, IRGKangXi=0841.031, RSKangXi=113.4
2561C CJK UNIFIED IDEOGRAPH-#2561C, IRGKangXi=0841.031, RSKangXi=113.4
2561D CJK UNIFIED IDEOGRAPH-#2561D, IRGKangXi=0841.031, RSKangXi=113.4
2561E CJK UNIFIED IDEOGRAPH-#2561E, IRGKangXi=0841.031, RSKangXi=113.4
2561F CJK UNIFIED IDEOGRAPH-#2561F, IRGKangXi=0841.031, RSKangXi=113.4
25620 CJK UNIFIED IDEOGRAPH-#25620, IRGKangXi=0841.031, RSKangXi=113.4
25621 CJK UNIFIED IDEOGRAPH-#25621, IRGKangXi=0841.031, RSKangXi=113.4
25622 CJK UNIFIED IDEOGRAPH-#25622, IRGKangXi=0841.031, RSKangXi=113.4
25623 CJK UNIFIED IDEOGRAPH-#25623, IRGKangXi=0841.031, RSKangXi=113.4
25624 CJK UNIFIED IDEOGRAPH-#25624, IRGKangXi=0841.031, RSKangXi=113.4
25625 CJK UNIFIED IDEOGRAPH-#25625, IRGKangXi=0841.031, RSKangXi=113.4
25626 CJK UNIFIED IDEOGRAPH-#25626, IRGKangXi=0841.031, RSKangXi=113.4
25627 CJK UNIFIED IDEOGRAPH-#25627, IRGKangXi=0841.031, RSKangXi=113.4
25628 CJK UNIFIED IDEOGRAPH-#25628, IRGKangXi=0841.031, RSKangXi=113.4
25629 CJK UNIFIED IDEOGRAPH-#25629, IRGKangXi=0841.031, RSKangXi=113.4
2562A CJK UNIFIED IDEOGRAPH-#2562A, IRGKangXi=0841.031, RSKangXi=113.4
2562B CJK UNIFIED IDEOGRAPH-#2562B, IRGKangXi=0841.100, RSKangXi=113.5
2562C CJK UNIFIED IDEOGRAPH-#2562C, IRGKangXi=0841.130, RSKangXi=113.5
2562D CJK UNIFIED IDEOGRAPH-#2562D, IRGKangXi=0841.140, RSKangXi=113.5
2562E CJK UNIFIED IDEOGRAPH-#2562E, IRGKangXi=0841.150, RSKangXi=113.5
2562F CJK UNIFIED IDEOGRAPH-#2562F, IRGKangXi=0841.230, RSKangXi=113.5
25630 CJK UNIFIED IDEOGRAPH-#25630, IRGKangXi=0842.090, RSKangXi=113.5
25631 CJK UNIFIED IDEOGRAPH-#25631, IRGKangXi=0842.110, RSKangXi=113.5
25632 CJK UNIFIED IDEOGRAPH-#25632, IRGKangXi=0842.120, RSKangXi=113.5
25633 CJK UNIFIED IDEOGRAPH-#25633, IRGKangXi=0842.121, RSKangXi=113.5
25634 CJK UNIFIED IDEOGRAPH-#25634, IRGKangXi=0842.121, RSKangXi=113.5
25635 CJK UNIFIED IDEOGRAPH-#25635, IRGKangXi=0842.121, RSKangXi=113.5
25636 CJK UNIFIED IDEOGRAPH-#25636, IRGKangXi=0842.121, RSKangXi=113.5
25637 CJK UNIFIED IDEOGRAPH-#25637, IRGKangXi=0842.121, RSKangXi=113.5
25638 CJK UNIFIED IDEOGRAPH-#25638, IRGKangXi=0842.121, RSKangXi=113.5
25639 CJK UNIFIED IDEOGRAPH-#25639, IRGKangXi=0842.121, RSKangXi=113.5
2563A CJK UNIFIED IDEOGRAPH-#2563A, IRGKangXi=0842.121, RSKangXi=113.5
2563B CJK UNIFIED IDEOGRAPH-#2563B, IRGKangXi=0842.121, RSKangXi=113.5
2563C CJK UNIFIED IDEOGRAPH-#2563C, IRGKangXi=0842.121, RSKangXi=113.5
2563D CJK UNIFIED IDEOGRAPH-#2563D, IRGKangXi=0842.121, RSKangXi=113.5
2563E CJK UNIFIED IDEOGRAPH-#2563E, IRGKangXi=0842.121, RSKangXi=113.5
2563F CJK UNIFIED IDEOGRAPH-#2563F, IRGKangXi=0842.121, RSKangXi=113.5
25640 CJK UNIFIED IDEOGRAPH-#25640, IRGKangXi=0842.121, RSKangXi=113.5
25641 CJK UNIFIED IDEOGRAPH-#25641, IRGKangXi=0842.121, RSKangXi=113.5
25642 CJK UNIFIED IDEOGRAPH-#25642, IRGKangXi=0842.121, RSKangXi=113.5
25643 CJK UNIFIED IDEOGRAPH-#25643, IRGKangXi=0842.121, RSKangXi=113.5
25644 CJK UNIFIED IDEOGRAPH-#25644, IRGKangXi=0842.121, RSKangXi=113.5
25645 CJK UNIFIED IDEOGRAPH-#25645, IRGKangXi=0842.121, RSKangXi=113.5
25646 CJK UNIFIED IDEOGRAPH-#25646, IRGKangXi=0842.121, RSKangXi=113.5
25647 CJK UNIFIED IDEOGRAPH-#25647, IRGKangXi=0842.121, RSKangXi=113.5
25648 CJK UNIFIED IDEOGRAPH-#25648, IRGKangXi=0842.121, RSKangXi=113.5
25649 CJK UNIFIED IDEOGRAPH-#25649, IRGKangXi=0842.121, RSKangXi=113.5
2564A CJK UNIFIED IDEOGRAPH-#2564A, IRGKangXi=0842.121, RSKangXi=113.5
2564B CJK UNIFIED IDEOGRAPH-#2564B, IRGKangXi=0842.121, RSKangXi=113.5
2564C CJK UNIFIED IDEOGRAPH-#2564C, IRGKangXi=0842.121, RSKangXi=113.5
2564D CJK UNIFIED IDEOGRAPH-#2564D, IRGKangXi=0842.121, RSKangXi=113.5
2564E CJK UNIFIED IDEOGRAPH-#2564E, IRGKangXi=0842.140, RSKangXi=113.6
2564F CJK UNIFIED IDEOGRAPH-#2564F, IRGKangXi=0843.080, RSKangXi=113.6
25650 CJK UNIFIED IDEOGRAPH-#25650, IRGKangXi=0843.081, RSKangXi=113.6
25651 CJK UNIFIED IDEOGRAPH-#25651, IRGKangXi=0843.081, RSKangXi=113.6
25652 CJK UNIFIED IDEOGRAPH-#25652, IRGKangXi=0843.081, RSKangXi=113.6
25653 CJK UNIFIED IDEOGRAPH-#25653, IRGKangXi=0843.081, RSKangXi=113.6
25654 CJK UNIFIED IDEOGRAPH-#25654, IRGKangXi=0843.081, RSKangXi=113.6
25655 CJK UNIFIED IDEOGRAPH-#25655, IRGKangXi=0843.081, RSKangXi=113.6
25656 CJK UNIFIED IDEOGRAPH-#25656, IRGKangXi=0843.081, RSKangXi=113.6
25657 CJK UNIFIED IDEOGRAPH-#25657, IRGKangXi=0843.081, RSKangXi=113.6
25658 CJK UNIFIED IDEOGRAPH-#25658, IRGKangXi=0843.081, RSKangXi=113.6
25659 CJK UNIFIED IDEOGRAPH-#25659, IRGKangXi=0843.081, RSKangXi=113.6
2565A CJK UNIFIED IDEOGRAPH-#2565A, IRGKangXi=0843.081, RSKangXi=113.6
2565B CJK UNIFIED IDEOGRAPH-#2565B, IRGKangXi=0843.081, RSKangXi=113.6
2565C CJK UNIFIED IDEOGRAPH-#2565C, IRGKangXi=0843.081, RSKangXi=113.6
2565D CJK UNIFIED IDEOGRAPH-#2565D, IRGKangXi=0843.081, RSKangXi=113.6
2565E CJK UNIFIED IDEOGRAPH-#2565E, IRGKangXi=0843.081, RSKangXi=113.6
2565F CJK UNIFIED IDEOGRAPH-#2565F, IRGKangXi=0843.081, RSKangXi=113.6
25660 CJK UNIFIED IDEOGRAPH-#25660, IRGKangXi=0843.081, RSKangXi=113.6
25661 CJK UNIFIED IDEOGRAPH-#25661, IRGKangXi=0843.081, RSKangXi=113.6
25662 CJK UNIFIED IDEOGRAPH-#25662, IRGKangXi=0843.081, RSKangXi=113.6
25663 CJK UNIFIED IDEOGRAPH-#25663, IRGKangXi=0843.081, RSKangXi=113.6
25664 CJK UNIFIED IDEOGRAPH-#25664, IRGKangXi=0843.081, RSKangXi=113.6
25665 CJK UNIFIED IDEOGRAPH-#25665, IRGKangXi=0843.081, RSKangXi=113.6
25666 CJK UNIFIED IDEOGRAPH-#25666, IRGKangXi=0843.081, RSKangXi=113.6
25667 CJK UNIFIED IDEOGRAPH-#25667, IRGKangXi=0843.081, RSKangXi=113.6
25668 CJK UNIFIED IDEOGRAPH-#25668, IRGKangXi=0843.081, RSKangXi=113.6
25669 CJK UNIFIED IDEOGRAPH-#25669, IRGKangXi=0843.081, RSKangXi=113.6
2566A CJK UNIFIED IDEOGRAPH-#2566A, IRGKangXi=0843.081, RSKangXi=113.6
2566B CJK UNIFIED IDEOGRAPH-#2566B, IRGKangXi=0843.090, RSKangXi=113.7
2566C CJK UNIFIED IDEOGRAPH-#2566C, IRGKangXi=0843.110, RSKangXi=113.7
2566D CJK UNIFIED IDEOGRAPH-#2566D, IRGKangXi=0843.170, RSKangXi=113.7
2566E CJK UNIFIED IDEOGRAPH-#2566E, IRGKangXi=0843.180, RSKangXi=113.7
2566F CJK UNIFIED IDEOGRAPH-#2566F, IRGKangXi=0843.220, RSKangXi=113.7
25670 CJK UNIFIED IDEOGRAPH-#25670, IRGKangXi=0843.230, RSKangXi=113.7
25671 CJK UNIFIED IDEOGRAPH-#25671, IRGKangXi=0843.240, RSKangXi=113.7
25672 CJK UNIFIED IDEOGRAPH-#25672, IRGKangXi=0843.250, RSKangXi=113.7
25673 CJK UNIFIED IDEOGRAPH-#25673, IRGKangXi=0843.260, RSKangXi=113.7
25674 CJK UNIFIED IDEOGRAPH-#25674, IRGKangXi=0843.261, RSKangXi=113.7
25675 CJK UNIFIED IDEOGRAPH-#25675, IRGKangXi=0843.261, RSKangXi=113.7
25676 CJK UNIFIED IDEOGRAPH-#25676, IRGKangXi=0843.261, RSKangXi=113.7
25677 CJK UNIFIED IDEOGRAPH-#25677, IRGKangXi=0843.261, RSKangXi=113.7
25678 CJK UNIFIED IDEOGRAPH-#25678, IRGKangXi=0843.261, RSKangXi=113.7
25679 CJK UNIFIED IDEOGRAPH-#25679, IRGKangXi=0843.261, RSKangXi=113.7
2567A CJK UNIFIED IDEOGRAPH-#2567A, IRGKangXi=0843.261, RSKangXi=113.7
2567B CJK UNIFIED IDEOGRAPH-#2567B, IRGKangXi=0843.261, RSKangXi=113.7
2567C CJK UNIFIED IDEOGRAPH-#2567C, IRGKangXi=0843.261, RSKangXi=113.7
2567D CJK UNIFIED IDEOGRAPH-#2567D, IRGKangXi=0843.261, RSKangXi=113.7
2567E CJK UNIFIED IDEOGRAPH-#2567E, IRGKangXi=0843.261, RSKangXi=113.7
2567F CJK UNIFIED IDEOGRAPH-#2567F, IRGKangXi=0843.261, RSKangXi=113.7
25680 CJK UNIFIED IDEOGRAPH-#25680, IRGKangXi=0843.261, RSKangXi=113.7
25681 CJK UNIFIED IDEOGRAPH-#25681, IRGKangXi=0843.261, RSKangXi=113.7
25682 CJK UNIFIED IDEOGRAPH-#25682, IRGKangXi=0843.261, RSKangXi=113.7
25683 CJK UNIFIED IDEOGRAPH-#25683, IRGKangXi=0843.261, RSKangXi=113.7
25684 CJK UNIFIED IDEOGRAPH-#25684, IRGKangXi=0843.261, RSKangXi=113.7
25685 CJK UNIFIED IDEOGRAPH-#25685, IRGKangXi=0843.261, RSKangXi=113.7
25686 CJK UNIFIED IDEOGRAPH-#25686, IRGKangXi=0843.261, RSKangXi=113.7
25687 CJK UNIFIED IDEOGRAPH-#25687, IRGKangXi=0843.261, RSKangXi=113.7
25688 CJK UNIFIED IDEOGRAPH-#25688, IRGKangXi=0843.280, RSKangXi=113.8
25689 CJK UNIFIED IDEOGRAPH-#25689, IRGKangXi=0844.030, RSKangXi=113.8
2568A CJK UNIFIED IDEOGRAPH-#2568A, IRGKangXi=0844.130, RSKangXi=113.8
2568B CJK UNIFIED IDEOGRAPH-#2568B, IRGKangXi=0844.150, RSKangXi=113.8
2568C CJK UNIFIED IDEOGRAPH-#2568C, IRGKangXi=0844.160, RSKangXi=113.8
2568D CJK UNIFIED IDEOGRAPH-#2568D, IRGKangXi=0844.170, RSKangXi=113.8
2568E CJK UNIFIED IDEOGRAPH-#2568E, IRGKangXi=0844.171, RSKangXi=113.8
2568F CJK UNIFIED IDEOGRAPH-#2568F, IRGKangXi=0844.171, RSKangXi=113.8
25690 CJK UNIFIED IDEOGRAPH-#25690, IRGKangXi=0844.171, RSKangXi=113.8
25691 CJK UNIFIED IDEOGRAPH-#25691, IRGKangXi=0844.171, RSKangXi=113.8
25692 CJK UNIFIED IDEOGRAPH-#25692, IRGKangXi=0844.171, RSKangXi=113.8
25693 CJK UNIFIED IDEOGRAPH-#25693, IRGKangXi=0844.171, RSKangXi=113.8
25694 CJK UNIFIED IDEOGRAPH-#25694, IRGKangXi=0844.171, RSKangXi=113.8
25695 CJK UNIFIED IDEOGRAPH-#25695, IRGKangXi=0844.171, RSKangXi=113.8
25696 CJK UNIFIED IDEOGRAPH-#25696, IRGKangXi=0844.171, RSKangXi=113.8
25697 CJK UNIFIED IDEOGRAPH-#25697, IRGKangXi=0844.171, RSKangXi=113.8
25698 CJK UNIFIED IDEOGRAPH-#25698, IRGKangXi=0844.171, RSKangXi=113.8
25699 CJK UNIFIED IDEOGRAPH-#25699, IRGKangXi=0844.171, RSKangXi=113.8
2569A CJK UNIFIED IDEOGRAPH-#2569A, IRGKangXi=0844.171, RSKangXi=113.8
2569B CJK UNIFIED IDEOGRAPH-#2569B, IRGKangXi=0844.171, RSKangXi=113.8
2569C CJK UNIFIED IDEOGRAPH-#2569C, IRGKangXi=0844.171, RSKangXi=113.8
2569D CJK UNIFIED IDEOGRAPH-#2569D, IRGKangXi=0844.171, RSKangXi=113.8
2569E CJK UNIFIED IDEOGRAPH-#2569E, IRGKangXi=0844.171, RSKangXi=113.8
2569F CJK UNIFIED IDEOGRAPH-#2569F, IRGKangXi=0844.171, RSKangXi=113.8
256A0 CJK UNIFIED IDEOGRAPH-#256A0, IRGKangXi=0844.171, RSKangXi=113.8
256A1 CJK UNIFIED IDEOGRAPH-#256A1, IRGKangXi=0844.171, RSKangXi=113.8
256A2 CJK UNIFIED IDEOGRAPH-#256A2, IRGKangXi=0844.171, RSKangXi=113.8
256A3 CJK UNIFIED IDEOGRAPH-#256A3, IRGKangXi=0844.171, RSKangXi=113.8
256A4 CJK UNIFIED IDEOGRAPH-#256A4, IRGKangXi=0844.171, RSKangXi=113.8
256A5 CJK UNIFIED IDEOGRAPH-#256A5, IRGKangXi=0844.171, RSKangXi=113.8
256A6 CJK UNIFIED IDEOGRAPH-#256A6, IRGKangXi=0844.220, RSKangXi=113.9
256A7 CJK UNIFIED IDEOGRAPH-#256A7, IRGKangXi=0844.270, RSKangXi=113.9
256A8 CJK UNIFIED IDEOGRAPH-#256A8, IRGKangXi=0844.280, RSKangXi=113.9
256A9 CJK UNIFIED IDEOGRAPH-#256A9, IRGKangXi=0845.090, RSKangXi=113.9
256AA CJK UNIFIED IDEOGRAPH-#256AA, IRGKangXi=0845.140, RSKangXi=113.9
256AB CJK UNIFIED IDEOGRAPH-#256AB, IRGKangXi=0845.160, RSKangXi=113.9
256AC CJK UNIFIED IDEOGRAPH-#256AC, IRGKangXi=0845.161, RSKangXi=113.9
256AD CJK UNIFIED IDEOGRAPH-#256AD, IRGKangXi=0845.161, RSKangXi=113.9
256AE CJK UNIFIED IDEOGRAPH-#256AE, IRGKangXi=0845.161, RSKangXi=113.9
256AF CJK UNIFIED IDEOGRAPH-#256AF, IRGKangXi=0845.161, RSKangXi=113.9
256B0 CJK UNIFIED IDEOGRAPH-#256B0, IRGKangXi=0845.161, RSKangXi=113.9
256B1 CJK UNIFIED IDEOGRAPH-#256B1, IRGKangXi=0845.161, RSKangXi=113.9
256B2 CJK UNIFIED IDEOGRAPH-#256B2, IRGKangXi=0845.161, RSKangXi=113.9
256B3 CJK UNIFIED IDEOGRAPH-#256B3, IRGKangXi=0845.161, RSKangXi=113.9
256B4 CJK UNIFIED IDEOGRAPH-#256B4, IRGKangXi=0845.161, RSKangXi=113.9
256B5 CJK UNIFIED IDEOGRAPH-#256B5, IRGKangXi=0845.161, RSKangXi=113.9
256B6 CJK UNIFIED IDEOGRAPH-#256B6, IRGKangXi=0845.161, RSKangXi=113.9
256B7 CJK UNIFIED IDEOGRAPH-#256B7, IRGKangXi=0845.161, RSKangXi=113.9
256B8 CJK UNIFIED IDEOGRAPH-#256B8, IRGKangXi=0845.161, RSKangXi=113.9
256B9 CJK UNIFIED IDEOGRAPH-#256B9, IRGKangXi=0845.161, RSKangXi=113.9
256BA CJK UNIFIED IDEOGRAPH-#256BA, IRGKangXi=0845.161, RSKangXi=113.9
256BB CJK UNIFIED IDEOGRAPH-#256BB, IRGKangXi=0845.161, RSKangXi=113.9
256BC CJK UNIFIED IDEOGRAPH-#256BC, IRGKangXi=0845.161, RSKangXi=113.9
256BD CJK UNIFIED IDEOGRAPH-#256BD, IRGKangXi=0845.161, RSKangXi=113.9
256BE CJK UNIFIED IDEOGRAPH-#256BE, IRGKangXi=0845.161, RSKangXi=113.9
256BF CJK UNIFIED IDEOGRAPH-#256BF, IRGKangXi=0845.161, RSKangXi=113.9
256C0 CJK UNIFIED IDEOGRAPH-#256C0, IRGKangXi=0845.161, RSKangXi=113.9
256C1 CJK UNIFIED IDEOGRAPH-#256C1, IRGKangXi=0845.161, RSKangXi=113.9
256C2 CJK UNIFIED IDEOGRAPH-#256C2, IRGKangXi=0845.161, RSKangXi=113.9
256C3 CJK UNIFIED IDEOGRAPH-#256C3, IRGKangXi=0845.161, RSKangXi=113.9
256C4 CJK UNIFIED IDEOGRAPH-#256C4, IRGKangXi=0845.161, RSKangXi=113.9
256C5 CJK UNIFIED IDEOGRAPH-#256C5, IRGKangXi=0845.200, RSKangXi=113.10
256C6 CJK UNIFIED IDEOGRAPH-#256C6, IRGKangXi=0846.040, RSKangXi=113.10
256C7 CJK UNIFIED IDEOGRAPH-#256C7, IRGKangXi=0846.080, RSKangXi=113.10
256C8 CJK UNIFIED IDEOGRAPH-#256C8, IRGKangXi=0846.090, RSKangXi=113.10
256C9 CJK UNIFIED IDEOGRAPH-#256C9, IRGKangXi=0846.091, RSKangXi=113.10
256CA CJK UNIFIED IDEOGRAPH-#256CA, IRGKangXi=0846.091, RSKangXi=113.10
256CB CJK UNIFIED IDEOGRAPH-#256CB, IRGKangXi=0846.091, RSKangXi=113.10
256CC CJK UNIFIED IDEOGRAPH-#256CC, IRGKangXi=0846.091, RSKangXi=113.10
256CD CJK UNIFIED IDEOGRAPH-#256CD, IRGKangXi=0846.091, RSKangXi=113.10
256CE CJK UNIFIED IDEOGRAPH-#256CE, IRGKangXi=0846.091, RSKangXi=113.10
256CF CJK UNIFIED IDEOGRAPH-#256CF, IRGKangXi=0846.091, RSKangXi=113.10
256D0 CJK UNIFIED IDEOGRAPH-#256D0, IRGKangXi=0846.091, RSKangXi=113.10
256D1 CJK UNIFIED IDEOGRAPH-#256D1, IRGKangXi=0846.091, RSKangXi=113.10
256D2 CJK UNIFIED IDEOGRAPH-#256D2, IRGKangXi=0846.091, RSKangXi=113.10
256D3 CJK UNIFIED IDEOGRAPH-#256D3, IRGKangXi=0846.091, RSKangXi=113.10
256D4 CJK UNIFIED IDEOGRAPH-#256D4, IRGKangXi=0846.091, RSKangXi=113.10
256D5 CJK UNIFIED IDEOGRAPH-#256D5, IRGKangXi=0846.091, RSKangXi=113.10
256D6 CJK UNIFIED IDEOGRAPH-#256D6, IRGKangXi=0846.091, RSKangXi=113.10
256D7 CJK UNIFIED IDEOGRAPH-#256D7, IRGKangXi=0846.091, RSKangXi=113.10
256D8 CJK UNIFIED IDEOGRAPH-#256D8, IRGKangXi=0846.100, RSKangXi=113.11
256D9 CJK UNIFIED IDEOGRAPH-#256D9, IRGKangXi=0846.110, RSKangXi=113.11
256DA CJK UNIFIED IDEOGRAPH-#256DA, IRGKangXi=0846.140, RSKangXi=113.11
256DB CJK UNIFIED IDEOGRAPH-#256DB, IRGKangXi=0846.160, RSKangXi=113.11
256DC CJK UNIFIED IDEOGRAPH-#256DC, IRGKangXi=0846.190, RSKangXi=113.11
256DD CJK UNIFIED IDEOGRAPH-#256DD, IRGKangXi=0846.200, RSKangXi=113.11
256DE CJK UNIFIED IDEOGRAPH-#256DE, IRGKangXi=0846.210, RSKangXi=113.11
256DF CJK UNIFIED IDEOGRAPH-#256DF, IRGKangXi=0846.240, RSKangXi=113.11
256E0 CJK UNIFIED IDEOGRAPH-#256E0, IRGKangXi=0846.250, RSKangXi=113.11
256E1 CJK UNIFIED IDEOGRAPH-#256E1, IRGKangXi=0846.260, RSKangXi=113.11
256E2 CJK UNIFIED IDEOGRAPH-#256E2, IRGKangXi=0846.261, RSKangXi=113.11
256E3 CJK UNIFIED IDEOGRAPH-#256E3, IRGKangXi=0846.261, RSKangXi=113.11
256E4 CJK UNIFIED IDEOGRAPH-#256E4, IRGKangXi=0846.261, RSKangXi=113.11
256E5 CJK UNIFIED IDEOGRAPH-#256E5, IRGKangXi=0846.261, RSKangXi=113.11
256E6 CJK UNIFIED IDEOGRAPH-#256E6, IRGKangXi=0846.261, RSKangXi=113.11
256E7 CJK UNIFIED IDEOGRAPH-#256E7, IRGKangXi=0846.261, RSKangXi=113.11
256E8 CJK UNIFIED IDEOGRAPH-#256E8, IRGKangXi=0846.261, RSKangXi=113.11
256E9 CJK UNIFIED IDEOGRAPH-#256E9, IRGKangXi=0846.261, RSKangXi=113.11
256EA CJK UNIFIED IDEOGRAPH-#256EA, IRGKangXi=0846.261, RSKangXi=113.11
256EB CJK UNIFIED IDEOGRAPH-#256EB, IRGKangXi=0846.261, RSKangXi=113.11
256EC CJK UNIFIED IDEOGRAPH-#256EC, IRGKangXi=0846.261, RSKangXi=113.11
256ED CJK UNIFIED IDEOGRAPH-#256ED, IRGKangXi=0846.261, RSKangXi=113.11
256EE CJK UNIFIED IDEOGRAPH-#256EE, IRGKangXi=0846.270, RSKangXi=113.12
256EF CJK UNIFIED IDEOGRAPH-#256EF, IRGKangXi=0846.280, RSKangXi=113.12
256F0 CJK UNIFIED IDEOGRAPH-#256F0, IRGKangXi=0846.310, RSKangXi=113.12
256F1 CJK UNIFIED IDEOGRAPH-#256F1, IRGKangXi=0846.320, RSKangXi=113.12
256F2 CJK UNIFIED IDEOGRAPH-#256F2, IRGKangXi=0846.350, RSKangXi=113.12
256F3 CJK UNIFIED IDEOGRAPH-#256F3, IRGKangXi=0847.010, RSKangXi=113.12
256F4 CJK UNIFIED IDEOGRAPH-#256F4, IRGKangXi=0847.020, RSKangXi=113.12
256F5 CJK UNIFIED IDEOGRAPH-#256F5, IRGKangXi=0847.021, RSKangXi=113.12
256F6 CJK UNIFIED IDEOGRAPH-#256F6, IRGKangXi=0847.021, RSKangXi=113.12
256F7 CJK UNIFIED IDEOGRAPH-#256F7, IRGKangXi=0847.021, RSKangXi=113.12
256F8 CJK UNIFIED IDEOGRAPH-#256F8, IRGKangXi=0847.021, RSKangXi=113.12
256F9 CJK UNIFIED IDEOGRAPH-#256F9, IRGKangXi=0847.021, RSKangXi=113.12
256FA CJK UNIFIED IDEOGRAPH-#256FA, IRGKangXi=0847.021, RSKangXi=113.12
256FB CJK UNIFIED IDEOGRAPH-#256FB, IRGKangXi=0847.021, RSKangXi=113.12
256FC CJK UNIFIED IDEOGRAPH-#256FC, IRGKangXi=0847.021, RSKangXi=113.12
256FD CJK UNIFIED IDEOGRAPH-#256FD, IRGKangXi=0847.021, RSKangXi=113.12
256FE CJK UNIFIED IDEOGRAPH-#256FE, IRGKangXi=0847.021, RSKangXi=113.12
256FF CJK UNIFIED IDEOGRAPH-#256FF, IRGKangXi=0847.021, RSKangXi=113.12
25700 CJK UNIFIED IDEOGRAPH-#25700, IRGKangXi=0847.021, RSKangXi=113.12
25701 CJK UNIFIED IDEOGRAPH-#25701, IRGKangXi=0847.021, RSKangXi=113.12
25702 CJK UNIFIED IDEOGRAPH-#25702, IRGKangXi=0847.021, RSKangXi=113.12
25703 CJK UNIFIED IDEOGRAPH-#25703, IRGKangXi=0847.030, RSKangXi=113.13
25704 CJK UNIFIED IDEOGRAPH-#25704, IRGKangXi=0847.130, RSKangXi=113.13
25705 CJK UNIFIED IDEOGRAPH-#25705, IRGKangXi=0847.140, RSKangXi=113.13
25706 CJK UNIFIED IDEOGRAPH-#25706, IRGKangXi=0847.141, RSKangXi=113.13
25707 CJK UNIFIED IDEOGRAPH-#25707, IRGKangXi=0847.141, RSKangXi=113.13
25708 CJK UNIFIED IDEOGRAPH-#25708, IRGKangXi=0847.141, RSKangXi=113.13
25709 CJK UNIFIED IDEOGRAPH-#25709, IRGKangXi=0847.141, RSKangXi=113.13
2570A CJK UNIFIED IDEOGRAPH-#2570A, IRGKangXi=0847.141, RSKangXi=113.13
2570B CJK UNIFIED IDEOGRAPH-#2570B, IRGKangXi=0847.141, RSKangXi=113.13
2570C CJK UNIFIED IDEOGRAPH-#2570C, IRGKangXi=0847.141, RSKangXi=113.13, Def{a coat, jacket, robe}
2570D CJK UNIFIED IDEOGRAPH-#2570D, IRGKangXi=0847.141, RSKangXi=113.13
2570E CJK UNIFIED IDEOGRAPH-#2570E, IRGKangXi=0847.141, RSKangXi=113.13
2570F CJK UNIFIED IDEOGRAPH-#2570F, IRGKangXi=0847.141, RSKangXi=113.13
25710 CJK UNIFIED IDEOGRAPH-#25710, IRGKangXi=0847.141, RSKangXi=113.13
25711 CJK UNIFIED IDEOGRAPH-#25711, IRGKangXi=0847.141, RSKangXi=113.13
25712 CJK UNIFIED IDEOGRAPH-#25712, IRGKangXi=0847.190, RSKangXi=113.14, Def{to pray to the gods}
25713 CJK UNIFIED IDEOGRAPH-#25713, IRGKangXi=0847.200, RSKangXi=113.14
25714 CJK UNIFIED IDEOGRAPH-#25714, IRGKangXi=0847.210, RSKangXi=113.14
25715 CJK UNIFIED IDEOGRAPH-#25715, IRGKangXi=0847.221, RSKangXi=113.14
25716 CJK UNIFIED IDEOGRAPH-#25716, IRGKangXi=0847.221, RSKangXi=113.14
25717 CJK UNIFIED IDEOGRAPH-#25717, IRGKangXi=0847.221, RSKangXi=113.14
25718 CJK UNIFIED IDEOGRAPH-#25718, IRGKangXi=0847.221, RSKangXi=113.14
25719 CJK UNIFIED IDEOGRAPH-#25719, IRGKangXi=0847.221, RSKangXi=113.14
2571A CJK UNIFIED IDEOGRAPH-#2571A, IRGKangXi=0847.240, RSKangXi=113.15
2571B CJK UNIFIED IDEOGRAPH-#2571B, IRGKangXi=0847.250, RSKangXi=113.15
2571C CJK UNIFIED IDEOGRAPH-#2571C, IRGKangXi=0847.251, RSKangXi=113.15
2571D CJK UNIFIED IDEOGRAPH-#2571D, IRGKangXi=0847.251, RSKangXi=113.15
2571E CJK UNIFIED IDEOGRAPH-#2571E, IRGKangXi=0847.251, RSKangXi=113.15
2571F CJK UNIFIED IDEOGRAPH-#2571F, IRGKangXi=0847.251, RSKangXi=113.15
25720 CJK UNIFIED IDEOGRAPH-#25720, IRGKangXi=0847.260, RSKangXi=113.16
25721 CJK UNIFIED IDEOGRAPH-#25721, IRGKangXi=0847.271, RSKangXi=113.16
25722 CJK UNIFIED IDEOGRAPH-#25722, IRGKangXi=0847.271, RSKangXi=113.16
25723 CJK UNIFIED IDEOGRAPH-#25723, IRGKangXi=0847.271, RSKangXi=113.16
25724 CJK UNIFIED IDEOGRAPH-#25724, IRGKangXi=0847.271, RSKangXi=113.16
25725 CJK UNIFIED IDEOGRAPH-#25725, IRGKangXi=0847.271, RSKangXi=113.17, Def{the duration of a dynasty or reign}
25726 CJK UNIFIED IDEOGRAPH-#25726, IRGKangXi=0847.280, RSKangXi=113.17
25727 CJK UNIFIED IDEOGRAPH-#25727, IRGKangXi=0847.300, RSKangXi=113.17
25728 CJK UNIFIED IDEOGRAPH-#25728, IRGKangXi=0847.311, RSKangXi=113.17
25729 CJK UNIFIED IDEOGRAPH-#25729, IRGKangXi=0847.311, RSKangXi=113.17
2572A CJK UNIFIED IDEOGRAPH-#2572A, IRGKangXi=0847.321, RSKangXi=113.18
2572B CJK UNIFIED IDEOGRAPH-#2572B, IRGKangXi=0847.321, RSKangXi=113.18
2572C CJK UNIFIED IDEOGRAPH-#2572C, IRGKangXi=0847.321, RSKangXi=113.18
2572D CJK UNIFIED IDEOGRAPH-#2572D, IRGKangXi=0847.321, RSKangXi=113.18
2572E CJK UNIFIED IDEOGRAPH-#2572E, IRGKangXi=0847.321, RSKangXi=113.18
2572F CJK UNIFIED IDEOGRAPH-#2572F, IRGKangXi=0847.321, RSKangXi=113.18
25730 CJK UNIFIED IDEOGRAPH-#25730, IRGKangXi=0847.350, RSKangXi=113.19
25731 CJK UNIFIED IDEOGRAPH-#25731, IRGKangXi=0847.360, RSKangXi=113.19
25732 CJK UNIFIED IDEOGRAPH-#25732, IRGKangXi=0847.370, RSKangXi=113.19
25733 CJK UNIFIED IDEOGRAPH-#25733, IRGKangXi=0847.371, RSKangXi=113.19
25734 CJK UNIFIED IDEOGRAPH-#25734, IRGKangXi=0847.380, RSKangXi=113.20
25735 CJK UNIFIED IDEOGRAPH-#25735, IRGKangXi=0847.381, RSKangXi=113.20
25736 CJK UNIFIED IDEOGRAPH-#25736, IRGKangXi=0847.381, RSKangXi=113.21
25737 CJK UNIFIED IDEOGRAPH-#25737, IRGKangXi=0847.390, RSKangXi=113.21
25738 CJK UNIFIED IDEOGRAPH-#25738, IRGKangXi=0847.391, RSKangXi=113.21
25739 CJK UNIFIED IDEOGRAPH-#25739, IRGKangXi=0847.400, RSKangXi=113.22
2573A CJK UNIFIED IDEOGRAPH-#2573A, IRGKangXi=0847.401, RSKangXi=113.22
2573B CJK UNIFIED IDEOGRAPH-#2573B, IRGKangXi=0848.011, RSKangXi=114.1
2573C CJK UNIFIED IDEOGRAPH-#2573C, IRGKangXi=0848.060, RSKangXi=114.4
2573D CJK UNIFIED IDEOGRAPH-#2573D, IRGKangXi=0848.090, RSKangXi=114.6
2573E CJK UNIFIED IDEOGRAPH-#2573E, IRGKangXi=0848.091, RSKangXi=114.7
2573F CJK UNIFIED IDEOGRAPH-#2573F, IRGKangXi=0848.100, RSKangXi=114.8
25740 CJK UNIFIED IDEOGRAPH-#25740, IRGKangXi=0848.111, RSKangXi=5.11
25741 CJK UNIFIED IDEOGRAPH-#25741, IRGKangXi=0848.120, RSKangXi=114.8
25742 CJK UNIFIED IDEOGRAPH-#25742, IRGKangXi=0848.141, RSKangXi=114.8
25743 CJK UNIFIED IDEOGRAPH-#25743, IRGKangXi=0848.150, RSKangXi=114.9
25744 CJK UNIFIED IDEOGRAPH-#25744, IRGKangXi=0848.151, RSKangXi=114.10
25745 CJK UNIFIED IDEOGRAPH-#25745, IRGKangXi=0848.151, RSKangXi=114.11
25746 CJK UNIFIED IDEOGRAPH-#25746, IRGKangXi=0848.151, RSKangXi=114.11
25747 CJK UNIFIED IDEOGRAPH-#25747, IRGKangXi=0848.151, RSKangXi=114.11
25748 CJK UNIFIED IDEOGRAPH-#25748, IRGKangXi=0848.160, RSKangXi=114.13
25749 CJK UNIFIED IDEOGRAPH-#25749, IRGKangXi=0848.161, RSKangXi=114.13
2574A CJK UNIFIED IDEOGRAPH-#2574A, IRGKangXi=0848.161, RSKangXi=114.17
2574B CJK UNIFIED IDEOGRAPH-#2574B, IRGKangXi=0848.170, RSKangXi=114.20
2574C CJK UNIFIED IDEOGRAPH-#2574C, IRGKangXi=0848.190, RSKangXi=115.0
2574D CJK UNIFIED IDEOGRAPH-#2574D, IRGKangXi=0849.010, RSKangXi=115.1
2574E CJK UNIFIED IDEOGRAPH-#2574E, IRGKangXi=0849.011, RSKangXi=115.1
2574F CJK UNIFIED IDEOGRAPH-#2574F, IRGKangXi=0849.011, RSKangXi=115.1
25750 CJK UNIFIED IDEOGRAPH-#25750, IRGKangXi=0849.040, RSKangXi=115.2
25751 CJK UNIFIED IDEOGRAPH-#25751, IRGKangXi=0849.081, RSKangXi=115.2
25752 CJK UNIFIED IDEOGRAPH-#25752, IRGKangXi=0849.081, RSKangXi=115.2
25753 CJK UNIFIED IDEOGRAPH-#25753, IRGKangXi=0849.081, RSKangXi=115.2
25754 CJK UNIFIED IDEOGRAPH-#25754, IRGKangXi=0849.100, RSKangXi=115.3
25755 CJK UNIFIED IDEOGRAPH-#25755, IRGKangXi=0849.120, RSKangXi=115.3
25756 CJK UNIFIED IDEOGRAPH-#25756, IRGKangXi=0849.190, RSKangXi=115.3
25757 CJK UNIFIED IDEOGRAPH-#25757, IRGKangXi=0849.200, RSKangXi=115.3
25758 CJK UNIFIED IDEOGRAPH-#25758, IRGKangXi=0850.020, RSKangXi=115.3
25759 CJK UNIFIED IDEOGRAPH-#25759, IRGKangXi=0850.031, RSKangXi=115.3
2575A CJK UNIFIED IDEOGRAPH-#2575A, IRGKangXi=0850.031, RSKangXi=115.3
2575B CJK UNIFIED IDEOGRAPH-#2575B, IRGKangXi=0850.031, RSKangXi=115.3
2575C CJK UNIFIED IDEOGRAPH-#2575C, IRGKangXi=0850.031, RSKangXi=115.3
2575D CJK UNIFIED IDEOGRAPH-#2575D, IRGKangXi=0850.031, RSKangXi=115.3
2575E CJK UNIFIED IDEOGRAPH-#2575E, IRGKangXi=0850.031, RSKangXi=115.3
2575F CJK UNIFIED IDEOGRAPH-#2575F, IRGKangXi=0850.031, RSKangXi=115.3
25760 CJK UNIFIED IDEOGRAPH-#25760, IRGKangXi=0850.031, RSKangXi=115.3
25761 CJK UNIFIED IDEOGRAPH-#25761, IRGKangXi=0850.031, RSKangXi=115.3
25762 CJK UNIFIED IDEOGRAPH-#25762, IRGKangXi=0850.031, RSKangXi=115.3, Def{to take advantage of; sharp (of weapons); profitable; profit}
25763 CJK UNIFIED IDEOGRAPH-#25763, IRGKangXi=0850.040, RSKangXi=115.4
25764 CJK UNIFIED IDEOGRAPH-#25764, IRGKangXi=0850.150, RSKangXi=115.4
25765 CJK UNIFIED IDEOGRAPH-#25765, IRGKangXi=0850.170, RSKangXi=115.4
25766 CJK UNIFIED IDEOGRAPH-#25766, IRGKangXi=0850.180, RSKangXi=115.4
25767 CJK UNIFIED IDEOGRAPH-#25767, IRGKangXi=0850.210, RSKangXi=115.4
25768 CJK UNIFIED IDEOGRAPH-#25768, IRGKangXi=0850.270, RSKangXi=115.4
25769 CJK UNIFIED IDEOGRAPH-#25769, IRGKangXi=0851.010, RSKangXi=115.4
2576A CJK UNIFIED IDEOGRAPH-#2576A, IRGKangXi=0851.030, RSKangXi=115.4
2576B CJK UNIFIED IDEOGRAPH-#2576B, IRGKangXi=0851.050, RSKangXi=115.4
2576C CJK UNIFIED IDEOGRAPH-#2576C, IRGKangXi=0851.060, RSKangXi=115.4
2576D CJK UNIFIED IDEOGRAPH-#2576D, IRGKangXi=0851.070, RSKangXi=115.4
2576E CJK UNIFIED IDEOGRAPH-#2576E, IRGKangXi=0851.080, RSKangXi=115.4
2576F CJK UNIFIED IDEOGRAPH-#2576F, IRGKangXi=0851.090, RSKangXi=115.4
25770 CJK UNIFIED IDEOGRAPH-#25770, IRGKangXi=0851.091, RSKangXi=115.4
25771 CJK UNIFIED IDEOGRAPH-#25771, IRGKangXi=0851.091, RSKangXi=115.4
25772 CJK UNIFIED IDEOGRAPH-#25772, IRGKangXi=0851.091, RSKangXi=115.4
25773 CJK UNIFIED IDEOGRAPH-#25773, IRGKangXi=0851.091, RSKangXi=115.4
25774 CJK UNIFIED IDEOGRAPH-#25774, IRGKangXi=0851.091, RSKangXi=115.4
25775 CJK UNIFIED IDEOGRAPH-#25775, IRGKangXi=0851.091, RSKangXi=115.4
25776 CJK UNIFIED IDEOGRAPH-#25776, IRGKangXi=0851.091, RSKangXi=115.4
25777 CJK UNIFIED IDEOGRAPH-#25777, IRGKangXi=0851.091, RSKangXi=115.4
25778 CJK UNIFIED IDEOGRAPH-#25778, IRGKangXi=0851.091, RSKangXi=115.4
25779 CJK UNIFIED IDEOGRAPH-#25779, IRGKangXi=0851.091, RSKangXi=115.4
2577A CJK UNIFIED IDEOGRAPH-#2577A, IRGKangXi=0851.091, RSKangXi=115.4
2577B CJK UNIFIED IDEOGRAPH-#2577B, IRGKangXi=0851.091, RSKangXi=115.4
2577C CJK UNIFIED IDEOGRAPH-#2577C, IRGKangXi=0851.091, RSKangXi=115.4
2577D CJK UNIFIED IDEOGRAPH-#2577D, IRGKangXi=0851.091, RSKangXi=115.4
2577E CJK UNIFIED IDEOGRAPH-#2577E, IRGKangXi=0851.100, RSKangXi=115.5
2577F CJK UNIFIED IDEOGRAPH-#2577F, IRGKangXi=0851.110, RSKangXi=115.5
25780 CJK UNIFIED IDEOGRAPH-#25780, IRGKangXi=0851.140, RSKangXi=115.5
25781 CJK UNIFIED IDEOGRAPH-#25781, IRGKangXi=0851.200, RSKangXi=115.5
25782 CJK UNIFIED IDEOGRAPH-#25782, IRGKangXi=0851.210, RSKangXi=115.5
25783 CJK UNIFIED IDEOGRAPH-#25783, IRGKangXi=0852.070, RSKangXi=115.5
25784 CJK UNIFIED IDEOGRAPH-#25784, IRGKangXi=0852.080, RSKangXi=115.5
25785 CJK UNIFIED IDEOGRAPH-#25785, IRGKangXi=0852.090, RSKangXi=115.5
25786 CJK UNIFIED IDEOGRAPH-#25786, IRGKangXi=0852.100, RSKangXi=115.5
25787 CJK UNIFIED IDEOGRAPH-#25787, IRGKangXi=0852.101, RSKangXi=115.5
25788 CJK UNIFIED IDEOGRAPH-#25788, IRGKangXi=0852.101, RSKangXi=115.5
25789 CJK UNIFIED IDEOGRAPH-#25789, IRGKangXi=0852.101, RSKangXi=115.5
2578A CJK UNIFIED IDEOGRAPH-#2578A, IRGKangXi=0852.101, RSKangXi=115.5
2578B CJK UNIFIED IDEOGRAPH-#2578B, IRGKangXi=0852.101, RSKangXi=115.5
2578C CJK UNIFIED IDEOGRAPH-#2578C, IRGKangXi=0852.101, RSKangXi=115.5
2578D CJK UNIFIED IDEOGRAPH-#2578D, IRGKangXi=0852.101, RSKangXi=115.5
2578E CJK UNIFIED IDEOGRAPH-#2578E, IRGKangXi=0852.101, RSKangXi=115.5
2578F CJK UNIFIED IDEOGRAPH-#2578F, IRGKangXi=0852.101, RSKangXi=115.5
25790 CJK UNIFIED IDEOGRAPH-#25790, IRGKangXi=0852.101, RSKangXi=115.5
25791 CJK UNIFIED IDEOGRAPH-#25791, IRGKangXi=0852.101, RSKangXi=115.5
25792 CJK UNIFIED IDEOGRAPH-#25792, IRGKangXi=0852.101, RSKangXi=115.5
25793 CJK UNIFIED IDEOGRAPH-#25793, IRGKangXi=0852.101, RSKangXi=115.5
25794 CJK UNIFIED IDEOGRAPH-#25794, IRGKangXi=0852.101, RSKangXi=115.5
25795 CJK UNIFIED IDEOGRAPH-#25795, IRGKangXi=0852.101, RSKangXi=115.5
25796 CJK UNIFIED IDEOGRAPH-#25796, IRGKangXi=0852.101, RSKangXi=115.5
25797 CJK UNIFIED IDEOGRAPH-#25797, IRGKangXi=0852.101, RSKangXi=115.5
25798 CJK UNIFIED IDEOGRAPH-#25798, IRGKangXi=0852.120, RSKangXi=115.5
25799 CJK UNIFIED IDEOGRAPH-#25799, IRGKangXi=0852.220, RSKangXi=115.6
2579A CJK UNIFIED IDEOGRAPH-#2579A, IRGKangXi=0852.230, RSKangXi=115.6
2579B CJK UNIFIED IDEOGRAPH-#2579B, IRGKangXi=0852.250, RSKangXi=115.6, Def{a stack, pile}
2579C CJK UNIFIED IDEOGRAPH-#2579C, IRGKangXi=0852.260, RSKangXi=115.6
2579D CJK UNIFIED IDEOGRAPH-#2579D, IRGKangXi=0853.050, RSKangXi=115.6
2579E CJK UNIFIED IDEOGRAPH-#2579E, IRGKangXi=0853.070, RSKangXi=115.6
2579F CJK UNIFIED IDEOGRAPH-#2579F, IRGKangXi=0853.081, RSKangXi=115.6
257A0 CJK UNIFIED IDEOGRAPH-#257A0, IRGKangXi=0853.081, RSKangXi=115.6
257A1 CJK UNIFIED IDEOGRAPH-#257A1, IRGKangXi=0853.081, RSKangXi=115.6
257A2 CJK UNIFIED IDEOGRAPH-#257A2, IRGKangXi=0853.081, RSKangXi=115.6
257A3 CJK UNIFIED IDEOGRAPH-#257A3, IRGKangXi=0853.081, RSKangXi=115.6
257A4 CJK UNIFIED IDEOGRAPH-#257A4, IRGKangXi=0853.081, RSKangXi=115.6
257A5 CJK UNIFIED IDEOGRAPH-#257A5, IRGKangXi=0853.081, RSKangXi=115.6
257A6 CJK UNIFIED IDEOGRAPH-#257A6, IRGKangXi=0853.081, RSKangXi=115.6
257A7 CJK UNIFIED IDEOGRAPH-#257A7, IRGKangXi=0853.081, RSKangXi=115.6
257A8 CJK UNIFIED IDEOGRAPH-#257A8, IRGKangXi=0853.081, RSKangXi=115.6
257A9 CJK UNIFIED IDEOGRAPH-#257A9, IRGKangXi=0853.081, RSKangXi=115.6
257AA CJK UNIFIED IDEOGRAPH-#257AA, IRGKangXi=0853.081, RSKangXi=115.6
257AB CJK UNIFIED IDEOGRAPH-#257AB, IRGKangXi=0853.081, RSKangXi=115.6
257AC CJK UNIFIED IDEOGRAPH-#257AC, IRGKangXi=0853.081, RSKangXi=115.6
257AD CJK UNIFIED IDEOGRAPH-#257AD, IRGKangXi=0853.081, RSKangXi=115.6
257AE CJK UNIFIED IDEOGRAPH-#257AE, IRGKangXi=0853.081, RSKangXi=115.6
257AF CJK UNIFIED IDEOGRAPH-#257AF, IRGKangXi=0853.081, RSKangXi=115.6
257B0 CJK UNIFIED IDEOGRAPH-#257B0, IRGKangXi=0853.081, RSKangXi=115.6
257B1 CJK UNIFIED IDEOGRAPH-#257B1, IRGKangXi=0853.081, RSKangXi=115.6
257B2 CJK UNIFIED IDEOGRAPH-#257B2, IRGKangXi=0853.110, RSKangXi=115.7
257B3 CJK UNIFIED IDEOGRAPH-#257B3, IRGKangXi=0853.150, RSKangXi=115.7
257B4 CJK UNIFIED IDEOGRAPH-#257B4, IRGKangXi=0853.160, RSKangXi=115.7
257B5 CJK UNIFIED IDEOGRAPH-#257B5, IRGKangXi=0854.070, RSKangXi=115.7
257B6 CJK UNIFIED IDEOGRAPH-#257B6, IRGKangXi=0854.090, RSKangXi=115.7
257B7 CJK UNIFIED IDEOGRAPH-#257B7, IRGKangXi=0854.130, RSKangXi=115.7
257B8 CJK UNIFIED IDEOGRAPH-#257B8, IRGKangXi=0854.140, RSKangXi=115.7
257B9 CJK UNIFIED IDEOGRAPH-#257B9, IRGKangXi=0854.150, RSKangXi=115.7
257BA CJK UNIFIED IDEOGRAPH-#257BA, IRGKangXi=0854.170, RSKangXi=115.7
257BB CJK UNIFIED IDEOGRAPH-#257BB, IRGKangXi=0854.180, RSKangXi=115.7
257BC CJK UNIFIED IDEOGRAPH-#257BC, IRGKangXi=0854.200, RSKangXi=115.7
257BD CJK UNIFIED IDEOGRAPH-#257BD, IRGKangXi=0854.201, RSKangXi=115.7
257BE CJK UNIFIED IDEOGRAPH-#257BE, IRGKangXi=0854.201, RSKangXi=115.7
257BF CJK UNIFIED IDEOGRAPH-#257BF, IRGKangXi=0854.201, RSKangXi=115.7
257C0 CJK UNIFIED IDEOGRAPH-#257C0, IRGKangXi=0854.201, RSKangXi=115.7
257C1 CJK UNIFIED IDEOGRAPH-#257C1, IRGKangXi=0854.201, RSKangXi=115.7
257C2 CJK UNIFIED IDEOGRAPH-#257C2, IRGKangXi=0854.201, RSKangXi=115.7
257C3 CJK UNIFIED IDEOGRAPH-#257C3, IRGKangXi=0854.201, RSKangXi=115.7
257C4 CJK UNIFIED IDEOGRAPH-#257C4, IRGKangXi=0854.201, RSKangXi=115.7
257C5 CJK UNIFIED IDEOGRAPH-#257C5, IRGKangXi=0854.201, RSKangXi=115.6
257C6 CJK UNIFIED IDEOGRAPH-#257C6, IRGKangXi=0854.201, RSKangXi=115.7
257C7 CJK UNIFIED IDEOGRAPH-#257C7, IRGKangXi=0854.201, RSKangXi=115.7
257C8 CJK UNIFIED IDEOGRAPH-#257C8, IRGKangXi=0854.201, RSKangXi=115.7
257C9 CJK UNIFIED IDEOGRAPH-#257C9, IRGKangXi=0854.201, RSKangXi=115.7
257CA CJK UNIFIED IDEOGRAPH-#257CA, IRGKangXi=0854.201, RSKangXi=115.7
257CB CJK UNIFIED IDEOGRAPH-#257CB, IRGKangXi=0854.201, RSKangXi=115.7
257CC CJK UNIFIED IDEOGRAPH-#257CC, IRGKangXi=0854.201, RSKangXi=115.7
257CD CJK UNIFIED IDEOGRAPH-#257CD, IRGKangXi=0854.220, RSKangXi=115.8
257CE CJK UNIFIED IDEOGRAPH-#257CE, IRGKangXi=0854.230, RSKangXi=115.8
257CF CJK UNIFIED IDEOGRAPH-#257CF, IRGKangXi=0854.250, RSKangXi=115.8
257D0 CJK UNIFIED IDEOGRAPH-#257D0, IRGKangXi=0854.260, RSKangXi=115.8
257D1 CJK UNIFIED IDEOGRAPH-#257D1, IRGKangXi=0855.030, RSKangXi=115.8
257D2 CJK UNIFIED IDEOGRAPH-#257D2, IRGKangXi=0855.040, RSKangXi=115.8
257D3 CJK UNIFIED IDEOGRAPH-#257D3, IRGKangXi=0855.050, RSKangXi=115.8
257D4 CJK UNIFIED IDEOGRAPH-#257D4, IRGKangXi=0855.170, RSKangXi=115.8
257D5 CJK UNIFIED IDEOGRAPH-#257D5, IRGKangXi=0855.180, RSKangXi=115.8
257D6 CJK UNIFIED IDEOGRAPH-#257D6, IRGKangXi=0855.220, RSKangXi=115.8
257D7 CJK UNIFIED IDEOGRAPH-#257D7, IRGKangXi=0855.230, RSKangXi=115.8
257D8 CJK UNIFIED IDEOGRAPH-#257D8, IRGKangXi=0855.250, RSKangXi=115.8
257D9 CJK UNIFIED IDEOGRAPH-#257D9, IRGKangXi=0855.270, RSKangXi=115.8
257DA CJK UNIFIED IDEOGRAPH-#257DA, IRGKangXi=0855.280, RSKangXi=115.8
257DB CJK UNIFIED IDEOGRAPH-#257DB, IRGKangXi=0855.290, RSKangXi=115.8
257DC CJK UNIFIED IDEOGRAPH-#257DC, IRGKangXi=0855.300, RSKangXi=115.8
257DD CJK UNIFIED IDEOGRAPH-#257DD, IRGKangXi=0855.310, RSKangXi=115.8
257DE CJK UNIFIED IDEOGRAPH-#257DE, IRGKangXi=0855.311, RSKangXi=115.8
257DF CJK UNIFIED IDEOGRAPH-#257DF, IRGKangXi=0855.311, RSKangXi=115.8
257E0 CJK UNIFIED IDEOGRAPH-#257E0, IRGKangXi=0855.311, RSKangXi=115.8
257E1 CJK UNIFIED IDEOGRAPH-#257E1, IRGKangXi=0855.311, RSKangXi=115.8
257E2 CJK UNIFIED IDEOGRAPH-#257E2, IRGKangXi=0855.311, RSKangXi=115.8
257E3 CJK UNIFIED IDEOGRAPH-#257E3, IRGKangXi=0855.311, RSKangXi=115.8
257E4 CJK UNIFIED IDEOGRAPH-#257E4, IRGKangXi=0855.311, RSKangXi=115.8
257E5 CJK UNIFIED IDEOGRAPH-#257E5, IRGKangXi=0855.311, RSKangXi=115.8
257E6 CJK UNIFIED IDEOGRAPH-#257E6, IRGKangXi=0855.311, RSKangXi=115.8
257E7 CJK UNIFIED IDEOGRAPH-#257E7, IRGKangXi=0855.311, RSKangXi=115.8
257E8 CJK UNIFIED IDEOGRAPH-#257E8, IRGKangXi=0855.311, RSKangXi=115.8
257E9 CJK UNIFIED IDEOGRAPH-#257E9, IRGKangXi=0855.311, RSKangXi=115.8
257EA CJK UNIFIED IDEOGRAPH-#257EA, IRGKangXi=0855.311, RSKangXi=115.8
257EB CJK UNIFIED IDEOGRAPH-#257EB, IRGKangXi=0855.311, RSKangXi=115.8
257EC CJK UNIFIED IDEOGRAPH-#257EC, IRGKangXi=0855.311, RSKangXi=115.8
257ED CJK UNIFIED IDEOGRAPH-#257ED, IRGKangXi=0855.311, RSKangXi=115.8
257EE CJK UNIFIED IDEOGRAPH-#257EE, IRGKangXi=0855.311, RSKangXi=115.8
257EF CJK UNIFIED IDEOGRAPH-#257EF, IRGKangXi=0855.311, RSKangXi=115.8
257F0 CJK UNIFIED IDEOGRAPH-#257F0, IRGKangXi=0855.311, RSKangXi=115.8
257F1 CJK UNIFIED IDEOGRAPH-#257F1, IRGKangXi=0855.311, RSKangXi=115.8
257F2 CJK UNIFIED IDEOGRAPH-#257F2, IRGKangXi=0855.311, RSKangXi=115.8
257F3 CJK UNIFIED IDEOGRAPH-#257F3, IRGKangXi=0855.311, RSKangXi=115.8
257F4 CJK UNIFIED IDEOGRAPH-#257F4, IRGKangXi=0855.311, RSKangXi=115.8
257F5 CJK UNIFIED IDEOGRAPH-#257F5, IRGKangXi=0855.311, RSKangXi=115.8
257F6 CJK UNIFIED IDEOGRAPH-#257F6, IRGKangXi=0855.311, RSKangXi=115.8
257F7 CJK UNIFIED IDEOGRAPH-#257F7, IRGKangXi=0855.311, RSKangXi=115.8
257F8 CJK UNIFIED IDEOGRAPH-#257F8, IRGKangXi=0855.311, RSKangXi=115.8
257F9 CJK UNIFIED IDEOGRAPH-#257F9, IRGKangXi=0855.311, RSKangXi=115.8
257FA CJK UNIFIED IDEOGRAPH-#257FA, IRGKangXi=0855.311, RSKangXi=115.8
257FB CJK UNIFIED IDEOGRAPH-#257FB, IRGKangXi=0855.311, RSKangXi=115.8
257FC CJK UNIFIED IDEOGRAPH-#257FC, IRGKangXi=0855.311, RSKangXi=115.8
257FD CJK UNIFIED IDEOGRAPH-#257FD, IRGKangXi=0855.320, RSKangXi=115.9
257FE CJK UNIFIED IDEOGRAPH-#257FE, IRGKangXi=0855.350, RSKangXi=115.9
257FF CJK UNIFIED IDEOGRAPH-#257FF, IRGKangXi=0855.370, RSKangXi=115.9
25800 CJK UNIFIED IDEOGRAPH-#25800, IRGKangXi=0856.010, RSKangXi=115.9
25801 CJK UNIFIED IDEOGRAPH-#25801, IRGKangXi=0856.020, RSKangXi=115.9
25802 CJK UNIFIED IDEOGRAPH-#25802, IRGKangXi=0856.030, RSKangXi=115.9
25803 CJK UNIFIED IDEOGRAPH-#25803, IRGKangXi=0856.050, RSKangXi=115.9
25804 CJK UNIFIED IDEOGRAPH-#25804, IRGKangXi=0856.110, RSKangXi=115.9
25805 CJK UNIFIED IDEOGRAPH-#25805, IRGKangXi=0856.120, RSKangXi=115.9
25806 CJK UNIFIED IDEOGRAPH-#25806, IRGKangXi=0856.130, RSKangXi=115.9
25807 CJK UNIFIED IDEOGRAPH-#25807, IRGKangXi=0856.190, RSKangXi=115.9
25808 CJK UNIFIED IDEOGRAPH-#25808, IRGKangXi=0856.220, RSKangXi=115.9
25809 CJK UNIFIED IDEOGRAPH-#25809, IRGKangXi=0856.250, RSKangXi=115.9
2580A CJK UNIFIED IDEOGRAPH-#2580A, IRGKangXi=0856.270, RSKangXi=115.9
2580B CJK UNIFIED IDEOGRAPH-#2580B, IRGKangXi=0856.280, RSKangXi=115.9
2580C CJK UNIFIED IDEOGRAPH-#2580C, IRGKangXi=0856.290, RSKangXi=115.9
2580D CJK UNIFIED IDEOGRAPH-#2580D, IRGKangXi=0856.310, RSKangXi=115.9
2580E CJK UNIFIED IDEOGRAPH-#2580E, IRGKangXi=0856.320, RSKangXi=115.9
2580F CJK UNIFIED IDEOGRAPH-#2580F, IRGKangXi=0856.321, RSKangXi=115.9
25810 CJK UNIFIED IDEOGRAPH-#25810, IRGKangXi=0856.321, RSKangXi=115.9
25811 CJK UNIFIED IDEOGRAPH-#25811, IRGKangXi=0856.321, RSKangXi=115.9
25812 CJK UNIFIED IDEOGRAPH-#25812, IRGKangXi=0856.321, RSKangXi=115.9
25813 CJK UNIFIED IDEOGRAPH-#25813, IRGKangXi=0856.321, RSKangXi=115.9
25814 CJK UNIFIED IDEOGRAPH-#25814, IRGKangXi=0856.321, RSKangXi=115.9
25815 CJK UNIFIED IDEOGRAPH-#25815, IRGKangXi=0856.321, RSKangXi=115.9
25816 CJK UNIFIED IDEOGRAPH-#25816, IRGKangXi=0856.321, RSKangXi=115.9
25817 CJK UNIFIED IDEOGRAPH-#25817, IRGKangXi=0856.321, RSKangXi=115.9
25818 CJK UNIFIED IDEOGRAPH-#25818, IRGKangXi=0856.321, RSKangXi=115.9
25819 CJK UNIFIED IDEOGRAPH-#25819, IRGKangXi=0856.321, RSKangXi=115.9
2581A CJK UNIFIED IDEOGRAPH-#2581A, IRGKangXi=0856.321, RSKangXi=115.9
2581B CJK UNIFIED IDEOGRAPH-#2581B, IRGKangXi=0856.321, RSKangXi=115.9
2581C CJK UNIFIED IDEOGRAPH-#2581C, IRGKangXi=0856.321, RSKangXi=115.9
2581D CJK UNIFIED IDEOGRAPH-#2581D, IRGKangXi=0856.321, RSKangXi=115.9
2581E CJK UNIFIED IDEOGRAPH-#2581E, IRGKangXi=0856.321, RSKangXi=115.9
2581F CJK UNIFIED IDEOGRAPH-#2581F, IRGKangXi=0856.321, RSKangXi=115.9
25820 CJK UNIFIED IDEOGRAPH-#25820, IRGKangXi=0856.321, RSKangXi=115.9
25821 CJK UNIFIED IDEOGRAPH-#25821, IRGKangXi=0856.321, RSKangXi=115.9
25822 CJK UNIFIED IDEOGRAPH-#25822, IRGKangXi=0856.321, RSKangXi=115.9
25823 CJK UNIFIED IDEOGRAPH-#25823, IRGKangXi=0856.321, RSKangXi=115.9
25824 CJK UNIFIED IDEOGRAPH-#25824, IRGKangXi=0856.321, RSKangXi=115.9
25825 CJK UNIFIED IDEOGRAPH-#25825, IRGKangXi=0856.321, RSKangXi=115.9
25826 CJK UNIFIED IDEOGRAPH-#25826, IRGKangXi=0856.321, RSKangXi=115.9
25827 CJK UNIFIED IDEOGRAPH-#25827, IRGKangXi=0856.321, RSKangXi=115.9
25828 CJK UNIFIED IDEOGRAPH-#25828, IRGKangXi=0856.321, RSKangXi=115.9
25829 CJK UNIFIED IDEOGRAPH-#25829, IRGKangXi=0856.321, RSKangXi=115.9
2582A CJK UNIFIED IDEOGRAPH-#2582A, IRGKangXi=0856.321, RSKangXi=115.9
2582B CJK UNIFIED IDEOGRAPH-#2582B, IRGKangXi=0856.321, RSKangXi=115.9
2582C CJK UNIFIED IDEOGRAPH-#2582C, IRGKangXi=0856.321, RSKangXi=115.9
2582D CJK UNIFIED IDEOGRAPH-#2582D, IRGKangXi=0856.321, RSKangXi=115.9
2582E CJK UNIFIED IDEOGRAPH-#2582E, IRGKangXi=0856.321, RSKangXi=115.9
2582F CJK UNIFIED IDEOGRAPH-#2582F, IRGKangXi=0856.321, RSKangXi=115.9
25830 CJK UNIFIED IDEOGRAPH-#25830, IRGKangXi=0856.321, RSKangXi=115.9
25831 CJK UNIFIED IDEOGRAPH-#25831, IRGKangXi=0857.020, RSKangXi=115.10
25832 CJK UNIFIED IDEOGRAPH-#25832, IRGKangXi=0857.040, RSKangXi=115.10
25833 CJK UNIFIED IDEOGRAPH-#25833, IRGKangXi=0857.060, RSKangXi=115.10
25834 CJK UNIFIED IDEOGRAPH-#25834, IRGKangXi=0857.090, RSKangXi=115.10
25835 CJK UNIFIED IDEOGRAPH-#25835, IRGKangXi=0857.130, RSKangXi=115.10
25836 CJK UNIFIED IDEOGRAPH-#25836, IRGKangXi=0857.140, RSKangXi=115.10
25837 CJK UNIFIED IDEOGRAPH-#25837, IRGKangXi=0857.150, RSKangXi=115.10
25838 CJK UNIFIED IDEOGRAPH-#25838, IRGKangXi=0857.220, RSKangXi=115.10
25839 CJK UNIFIED IDEOGRAPH-#25839, IRGKangXi=0857.230, RSKangXi=115.10
2583A CJK UNIFIED IDEOGRAPH-#2583A, IRGKangXi=0857.280, RSKangXi=115.10
2583B CJK UNIFIED IDEOGRAPH-#2583B, IRGKangXi=0858.010, RSKangXi=115.10
2583C CJK UNIFIED IDEOGRAPH-#2583C, IRGKangXi=0858.060, RSKangXi=115.10
2583D CJK UNIFIED IDEOGRAPH-#2583D, IRGKangXi=0858.080, RSKangXi=115.10
2583E CJK UNIFIED IDEOGRAPH-#2583E, IRGKangXi=0858.090, RSKangXi=115.10
2583F CJK UNIFIED IDEOGRAPH-#2583F, IRGKangXi=0858.110, RSKangXi=115.10
25840 CJK UNIFIED IDEOGRAPH-#25840, IRGKangXi=0858.120, RSKangXi=115.10
25841 CJK UNIFIED IDEOGRAPH-#25841, IRGKangXi=0858.130, RSKangXi=115.10
25842 CJK UNIFIED IDEOGRAPH-#25842, IRGKangXi=0858.131, RSKangXi=115.10
25843 CJK UNIFIED IDEOGRAPH-#25843, IRGKangXi=0858.131, RSKangXi=115.10
25844 CJK UNIFIED IDEOGRAPH-#25844, IRGKangXi=0858.131, RSKangXi=115.10
25845 CJK UNIFIED IDEOGRAPH-#25845, IRGKangXi=0858.131, RSKangXi=115.10
25846 CJK UNIFIED IDEOGRAPH-#25846, IRGKangXi=0858.131, RSKangXi=115.10
25847 CJK UNIFIED IDEOGRAPH-#25847, IRGKangXi=0858.131, RSKangXi=115.10
25848 CJK UNIFIED IDEOGRAPH-#25848, IRGKangXi=0858.131, RSKangXi=115.10
25849 CJK UNIFIED IDEOGRAPH-#25849, IRGKangXi=0858.131, RSKangXi=115.10
2584A CJK UNIFIED IDEOGRAPH-#2584A, IRGKangXi=0858.131, RSKangXi=115.10
2584B CJK UNIFIED IDEOGRAPH-#2584B, IRGKangXi=0858.131, RSKangXi=115.10
2584C CJK UNIFIED IDEOGRAPH-#2584C, IRGKangXi=0858.131, RSKangXi=115.10
2584D CJK UNIFIED IDEOGRAPH-#2584D, IRGKangXi=0858.131, RSKangXi=115.10
2584E CJK UNIFIED IDEOGRAPH-#2584E, IRGKangXi=0858.131, RSKangXi=115.10
2584F CJK UNIFIED IDEOGRAPH-#2584F, IRGKangXi=0858.131, RSKangXi=115.10
25850 CJK UNIFIED IDEOGRAPH-#25850, IRGKangXi=0858.131, RSKangXi=115.10
25851 CJK UNIFIED IDEOGRAPH-#25851, IRGKangXi=0858.131, RSKangXi=115.10
25852 CJK UNIFIED IDEOGRAPH-#25852, IRGKangXi=0858.131, RSKangXi=115.10
25853 CJK UNIFIED IDEOGRAPH-#25853, IRGKangXi=0858.131, RSKangXi=115.10
25854 CJK UNIFIED IDEOGRAPH-#25854, IRGKangXi=0858.131, RSKangXi=115.10
25855 CJK UNIFIED IDEOGRAPH-#25855, IRGKangXi=0858.131, RSKangXi=115.10
25856 CJK UNIFIED IDEOGRAPH-#25856, IRGKangXi=0858.131, RSKangXi=115.10
25857 CJK UNIFIED IDEOGRAPH-#25857, IRGKangXi=0858.131, RSKangXi=115.10
25858 CJK UNIFIED IDEOGRAPH-#25858, IRGKangXi=0858.131, RSKangXi=115.10
25859 CJK UNIFIED IDEOGRAPH-#25859, IRGKangXi=0858.131, RSKangXi=115.10
2585A CJK UNIFIED IDEOGRAPH-#2585A, IRGKangXi=0858.131, RSKangXi=115.10
2585B CJK UNIFIED IDEOGRAPH-#2585B, IRGKangXi=0858.131, RSKangXi=115.10
2585C CJK UNIFIED IDEOGRAPH-#2585C, IRGKangXi=0858.140, RSKangXi=115.11
2585D CJK UNIFIED IDEOGRAPH-#2585D, IRGKangXi=0858.160, RSKangXi=115.11
2585E CJK UNIFIED IDEOGRAPH-#2585E, IRGKangXi=0858.170, RSKangXi=115.11
2585F CJK UNIFIED IDEOGRAPH-#2585F, IRGKangXi=0858.190, RSKangXi=115.11
25860 CJK UNIFIED IDEOGRAPH-#25860, IRGKangXi=0858.200, RSKangXi=115.11
25861 CJK UNIFIED IDEOGRAPH-#25861, IRGKangXi=0858.210, RSKangXi=115.11
25862 CJK UNIFIED IDEOGRAPH-#25862, IRGKangXi=0858.220, RSKangXi=115.11
25863 CJK UNIFIED IDEOGRAPH-#25863, IRGKangXi=0858.230, RSKangXi=115.11
25864 CJK UNIFIED IDEOGRAPH-#25864, IRGKangXi=0858.240, RSKangXi=115.11, Def{to shrink}
25865 CJK UNIFIED IDEOGRAPH-#25865, IRGKangXi=0859.010, RSKangXi=115.11
25866 CJK UNIFIED IDEOGRAPH-#25866, IRGKangXi=0859.090, RSKangXi=115.11
25867 CJK UNIFIED IDEOGRAPH-#25867, IRGKangXi=0859.100, RSKangXi=115.11
25868 CJK UNIFIED IDEOGRAPH-#25868, IRGKangXi=0859.110, RSKangXi=115.11
25869 CJK UNIFIED IDEOGRAPH-#25869, IRGKangXi=0859.120, RSKangXi=115.11
2586A CJK UNIFIED IDEOGRAPH-#2586A, IRGKangXi=0859.150, RSKangXi=115.11
2586B CJK UNIFIED IDEOGRAPH-#2586B, IRGKangXi=0859.160, RSKangXi=115.11
2586C CJK UNIFIED IDEOGRAPH-#2586C, IRGKangXi=0859.270, RSKangXi=115.11
2586D CJK UNIFIED IDEOGRAPH-#2586D, IRGKangXi=0860.010, RSKangXi=115.11
2586E CJK UNIFIED IDEOGRAPH-#2586E, IRGKangXi=0860.020, RSKangXi=115.11
2586F CJK UNIFIED IDEOGRAPH-#2586F, IRGKangXi=0860.030, RSKangXi=115.11
25870 CJK UNIFIED IDEOGRAPH-#25870, IRGKangXi=0860.040, RSKangXi=115.11
25871 CJK UNIFIED IDEOGRAPH-#25871, IRGKangXi=0860.041, RSKangXi=115.11
25872 CJK UNIFIED IDEOGRAPH-#25872, IRGKangXi=0860.041, RSKangXi=115.11
25873 CJK UNIFIED IDEOGRAPH-#25873, IRGKangXi=0860.041, RSKangXi=115.11
25874 CJK UNIFIED IDEOGRAPH-#25874, IRGKangXi=0860.041, RSKangXi=115.11, Def{surname}
25875 CJK UNIFIED IDEOGRAPH-#25875, IRGKangXi=0860.041, RSKangXi=115.11
25876 CJK UNIFIED IDEOGRAPH-#25876, IRGKangXi=0860.041, RSKangXi=115.11
25877 CJK UNIFIED IDEOGRAPH-#25877, IRGKangXi=0860.041, RSKangXi=115.11
25878 CJK UNIFIED IDEOGRAPH-#25878, IRGKangXi=0860.041, RSKangXi=115.11
25879 CJK UNIFIED IDEOGRAPH-#25879, IRGKangXi=0860.041, RSKangXi=115.11
2587A CJK UNIFIED IDEOGRAPH-#2587A, IRGKangXi=0860.041, RSKangXi=115.11
2587B CJK UNIFIED IDEOGRAPH-#2587B, IRGKangXi=0860.041, RSKangXi=115.11
2587C CJK UNIFIED IDEOGRAPH-#2587C, IRGKangXi=0860.041, RSKangXi=115.11
2587D CJK UNIFIED IDEOGRAPH-#2587D, IRGKangXi=0860.041, RSKangXi=115.11
2587E CJK UNIFIED IDEOGRAPH-#2587E, IRGKangXi=0860.041, RSKangXi=115.11
2587F CJK UNIFIED IDEOGRAPH-#2587F, IRGKangXi=0860.041, RSKangXi=115.11
25880 CJK UNIFIED IDEOGRAPH-#25880, IRGKangXi=0860.041, RSKangXi=115.11
25881 CJK UNIFIED IDEOGRAPH-#25881, IRGKangXi=0860.041, RSKangXi=115.11
25882 CJK UNIFIED IDEOGRAPH-#25882, IRGKangXi=0860.041, RSKangXi=115.11
25883 CJK UNIFIED IDEOGRAPH-#25883, IRGKangXi=0860.041, RSKangXi=115.11
25884 CJK UNIFIED IDEOGRAPH-#25884, IRGKangXi=0860.041, RSKangXi=115.11
25885 CJK UNIFIED IDEOGRAPH-#25885, IRGKangXi=0860.041, RSKangXi=115.11
25886 CJK UNIFIED IDEOGRAPH-#25886, IRGKangXi=0860.041, RSKangXi=115.11
25887 CJK UNIFIED IDEOGRAPH-#25887, IRGKangXi=0860.041, RSKangXi=115.11
25888 CJK UNIFIED IDEOGRAPH-#25888, IRGKangXi=0860.041, RSKangXi=115.11
25889 CJK UNIFIED IDEOGRAPH-#25889, IRGKangXi=0860.051, RSKangXi=115.11
2588A CJK UNIFIED IDEOGRAPH-#2588A, IRGKangXi=0860.060, RSKangXi=115.12
2588B CJK UNIFIED IDEOGRAPH-#2588B, IRGKangXi=0860.080, RSKangXi=115.12
2588C CJK UNIFIED IDEOGRAPH-#2588C, IRGKangXi=0860.090, RSKangXi=115.12
2588D CJK UNIFIED IDEOGRAPH-#2588D, IRGKangXi=0860.110, RSKangXi=115.12
2588E CJK UNIFIED IDEOGRAPH-#2588E, IRGKangXi=0860.140, RSKangXi=115.12
2588F CJK UNIFIED IDEOGRAPH-#2588F, IRGKangXi=0860.160, RSKangXi=115.12
25890 CJK UNIFIED IDEOGRAPH-#25890, IRGKangXi=0860.170, RSKangXi=115.12
25891 CJK UNIFIED IDEOGRAPH-#25891, IRGKangXi=0860.210, RSKangXi=115.12
25892 CJK UNIFIED IDEOGRAPH-#25892, IRGKangXi=0860.220, RSKangXi=115.12
25893 CJK UNIFIED IDEOGRAPH-#25893, IRGKangXi=0860.260, RSKangXi=115.12
25894 CJK UNIFIED IDEOGRAPH-#25894, IRGKangXi=0860.280, RSKangXi=115.12
25895 CJK UNIFIED IDEOGRAPH-#25895, IRGKangXi=0860.300, RSKangXi=115.12
25896 CJK UNIFIED IDEOGRAPH-#25896, IRGKangXi=0860.310, RSKangXi=115.12
25897 CJK UNIFIED IDEOGRAPH-#25897, IRGKangXi=0860.311, RSKangXi=115.12
25898 CJK UNIFIED IDEOGRAPH-#25898, IRGKangXi=0860.311, RSKangXi=115.12
25899 CJK UNIFIED IDEOGRAPH-#25899, IRGKangXi=0860.311, RSKangXi=115.12
2589A CJK UNIFIED IDEOGRAPH-#2589A, IRGKangXi=0860.311, RSKangXi=115.12
2589B CJK UNIFIED IDEOGRAPH-#2589B, IRGKangXi=0860.311, RSKangXi=115.12
2589C CJK UNIFIED IDEOGRAPH-#2589C, IRGKangXi=0860.311, RSKangXi=115.12
2589D CJK UNIFIED IDEOGRAPH-#2589D, IRGKangXi=0860.311, RSKangXi=115.12
2589E CJK UNIFIED IDEOGRAPH-#2589E, IRGKangXi=0860.311, RSKangXi=115.12
2589F CJK UNIFIED IDEOGRAPH-#2589F, IRGKangXi=0860.311, RSKangXi=115.12
258A0 CJK UNIFIED IDEOGRAPH-#258A0, IRGKangXi=0860.311, RSKangXi=115.12
258A1 CJK UNIFIED IDEOGRAPH-#258A1, IRGKangXi=0860.311, RSKangXi=115.12
258A2 CJK UNIFIED IDEOGRAPH-#258A2, IRGKangXi=0860.311, RSKangXi=115.12
258A3 CJK UNIFIED IDEOGRAPH-#258A3, IRGKangXi=0860.311, RSKangXi=115.12
258A4 CJK UNIFIED IDEOGRAPH-#258A4, IRGKangXi=0860.311, RSKangXi=115.12
258A5 CJK UNIFIED IDEOGRAPH-#258A5, IRGKangXi=0860.311, RSKangXi=115.12
258A6 CJK UNIFIED IDEOGRAPH-#258A6, IRGKangXi=0860.311, RSKangXi=115.12
258A7 CJK UNIFIED IDEOGRAPH-#258A7, IRGKangXi=0860.311, RSKangXi=115.12
258A8 CJK UNIFIED IDEOGRAPH-#258A8, IRGKangXi=0860.311, RSKangXi=115.12
258A9 CJK UNIFIED IDEOGRAPH-#258A9, IRGKangXi=0860.311, RSKangXi=115.12
258AA CJK UNIFIED IDEOGRAPH-#258AA, IRGKangXi=0860.311, RSKangXi=115.12
258AB CJK UNIFIED IDEOGRAPH-#258AB, IRGKangXi=0860.311, RSKangXi=115.12
258AC CJK UNIFIED IDEOGRAPH-#258AC, IRGKangXi=0860.311, RSKangXi=115.12
258AD CJK UNIFIED IDEOGRAPH-#258AD, IRGKangXi=0860.311, RSKangXi=115.12
258AE CJK UNIFIED IDEOGRAPH-#258AE, IRGKangXi=0860.311, RSKangXi=115.12
258AF CJK UNIFIED IDEOGRAPH-#258AF, IRGKangXi=0860.311, RSKangXi=115.12
258B0 CJK UNIFIED IDEOGRAPH-#258B0, IRGKangXi=0860.311, RSKangXi=115.12
258B1 CJK UNIFIED IDEOGRAPH-#258B1, IRGKangXi=0860.311, RSKangXi=115.12
258B2 CJK UNIFIED IDEOGRAPH-#258B2, IRGKangXi=0860.311, RSKangXi=115.12
258B3 CJK UNIFIED IDEOGRAPH-#258B3, IRGKangXi=0860.311, RSKangXi=115.12
258B4 CJK UNIFIED IDEOGRAPH-#258B4, IRGKangXi=0860.330, RSKangXi=115.13
258B5 CJK UNIFIED IDEOGRAPH-#258B5, IRGKangXi=0860.340, RSKangXi=115.13
258B6 CJK UNIFIED IDEOGRAPH-#258B6, IRGKangXi=0860.360, RSKangXi=115.13
258B7 CJK UNIFIED IDEOGRAPH-#258B7, IRGKangXi=0860.370, RSKangXi=115.13
258B8 CJK UNIFIED IDEOGRAPH-#258B8, IRGKangXi=0860.380, RSKangXi=115.13
258B9 CJK UNIFIED IDEOGRAPH-#258B9, IRGKangXi=0860.390, RSKangXi=115.13
258BA CJK UNIFIED IDEOGRAPH-#258BA, IRGKangXi=0860.400, RSKangXi=115.13
258BB CJK UNIFIED IDEOGRAPH-#258BB, IRGKangXi=0861.010, RSKangXi=115.13
258BC CJK UNIFIED IDEOGRAPH-#258BC, IRGKangXi=0861.040, RSKangXi=115.13
258BD CJK UNIFIED IDEOGRAPH-#258BD, IRGKangXi=0861.050, RSKangXi=115.13
258BE CJK UNIFIED IDEOGRAPH-#258BE, IRGKangXi=0861.051, RSKangXi=115.13
258BF CJK UNIFIED IDEOGRAPH-#258BF, IRGKangXi=0861.051, RSKangXi=115.13
258C0 CJK UNIFIED IDEOGRAPH-#258C0, IRGKangXi=0861.051, RSKangXi=115.13
258C1 CJK UNIFIED IDEOGRAPH-#258C1, IRGKangXi=0861.051, RSKangXi=115.13
258C2 CJK UNIFIED IDEOGRAPH-#258C2, IRGKangXi=0861.051, RSKangXi=115.13
258C3 CJK UNIFIED IDEOGRAPH-#258C3, IRGKangXi=0861.051, RSKangXi=115.13
258C4 CJK UNIFIED IDEOGRAPH-#258C4, IRGKangXi=0861.051, RSKangXi=115.13
258C5 CJK UNIFIED IDEOGRAPH-#258C5, IRGKangXi=0861.051, RSKangXi=115.13
258C6 CJK UNIFIED IDEOGRAPH-#258C6, IRGKangXi=0861.051, RSKangXi=115.13
258C7 CJK UNIFIED IDEOGRAPH-#258C7, IRGKangXi=0861.051, RSKangXi=115.13
258C8 CJK UNIFIED IDEOGRAPH-#258C8, IRGKangXi=0861.051, RSKangXi=115.13
258C9 CJK UNIFIED IDEOGRAPH-#258C9, IRGKangXi=0861.051, RSKangXi=115.13
258CA CJK UNIFIED IDEOGRAPH-#258CA, IRGKangXi=0861.051, RSKangXi=115.14
258CB CJK UNIFIED IDEOGRAPH-#258CB, IRGKangXi=0861.051, RSKangXi=115.13
258CC CJK UNIFIED IDEOGRAPH-#258CC, IRGKangXi=0861.051, RSKangXi=115.13
258CD CJK UNIFIED IDEOGRAPH-#258CD, IRGKangXi=0861.051, RSKangXi=115.13
258CE CJK UNIFIED IDEOGRAPH-#258CE, IRGKangXi=0861.051, RSKangXi=115.13
258CF CJK UNIFIED IDEOGRAPH-#258CF, IRGKangXi=0861.051, RSKangXi=115.13
258D0 CJK UNIFIED IDEOGRAPH-#258D0, IRGKangXi=0861.051, RSKangXi=115.13
258D1 CJK UNIFIED IDEOGRAPH-#258D1, IRGKangXi=0861.051, RSKangXi=115.13
258D2 CJK UNIFIED IDEOGRAPH-#258D2, IRGKangXi=0861.051, RSKangXi=115.13
258D3 CJK UNIFIED IDEOGRAPH-#258D3, IRGKangXi=0861.051, RSKangXi=115.13
258D4 CJK UNIFIED IDEOGRAPH-#258D4, IRGKangXi=0861.051, RSKangXi=115.13
258D5 CJK UNIFIED IDEOGRAPH-#258D5, IRGKangXi=0861.051, RSKangXi=115.14
258D6 CJK UNIFIED IDEOGRAPH-#258D6, IRGKangXi=0861.060, RSKangXi=115.14
258D7 CJK UNIFIED IDEOGRAPH-#258D7, IRGKangXi=0861.100, RSKangXi=115.14
258D8 CJK UNIFIED IDEOGRAPH-#258D8, IRGKangXi=0861.110, RSKangXi=115.14
258D9 CJK UNIFIED IDEOGRAPH-#258D9, IRGKangXi=0861.170, RSKangXi=115.14
258DA CJK UNIFIED IDEOGRAPH-#258DA, IRGKangXi=0861.180, RSKangXi=115.14
258DB CJK UNIFIED IDEOGRAPH-#258DB, IRGKangXi=0861.190, RSKangXi=115.14
258DC CJK UNIFIED IDEOGRAPH-#258DC, IRGKangXi=0861.200, RSKangXi=115.14
258DD CJK UNIFIED IDEOGRAPH-#258DD, IRGKangXi=0861.210, RSKangXi=115.14
258DE CJK UNIFIED IDEOGRAPH-#258DE, IRGKangXi=0861.220, RSKangXi=115.14
258DF CJK UNIFIED IDEOGRAPH-#258DF, IRGKangXi=0861.230, RSKangXi=115.14
258E0 CJK UNIFIED IDEOGRAPH-#258E0, IRGKangXi=0861.240, RSKangXi=115.14
258E1 CJK UNIFIED IDEOGRAPH-#258E1, IRGKangXi=0861.241, RSKangXi=115.14
258E2 CJK UNIFIED IDEOGRAPH-#258E2, IRGKangXi=0861.241, RSKangXi=115.15
258E3 CJK UNIFIED IDEOGRAPH-#258E3, IRGKangXi=0861.241, RSKangXi=115.14
258E4 CJK UNIFIED IDEOGRAPH-#258E4, IRGKangXi=0861.241, RSKangXi=115.14
258E5 CJK UNIFIED IDEOGRAPH-#258E5, IRGKangXi=0861.241, RSKangXi=115.14
258E6 CJK UNIFIED IDEOGRAPH-#258E6, IRGKangXi=0861.241, RSKangXi=115.14
258E7 CJK UNIFIED IDEOGRAPH-#258E7, IRGKangXi=0861.241, RSKangXi=115.14
258E8 CJK UNIFIED IDEOGRAPH-#258E8, IRGKangXi=0861.241, RSKangXi=115.15
258E9 CJK UNIFIED IDEOGRAPH-#258E9, IRGKangXi=0861.250, RSKangXi=115.15
258EA CJK UNIFIED IDEOGRAPH-#258EA, IRGKangXi=0861.260, RSKangXi=115.15
258EB CJK UNIFIED IDEOGRAPH-#258EB, IRGKangXi=0861.290, RSKangXi=115.15
258EC CJK UNIFIED IDEOGRAPH-#258EC, IRGKangXi=0861.310, RSKangXi=115.15
258ED CJK UNIFIED IDEOGRAPH-#258ED, IRGKangXi=0861.320, RSKangXi=115.15
258EE CJK UNIFIED IDEOGRAPH-#258EE, IRGKangXi=0861.330, RSKangXi=115.15
258EF CJK UNIFIED IDEOGRAPH-#258EF, IRGKangXi=0861.350, RSKangXi=115.15
258F0 CJK UNIFIED IDEOGRAPH-#258F0, IRGKangXi=0861.360, RSKangXi=115.15
258F1 CJK UNIFIED IDEOGRAPH-#258F1, IRGKangXi=0861.380, RSKangXi=115.15
258F2 CJK UNIFIED IDEOGRAPH-#258F2, IRGKangXi=0861.390, RSKangXi=115.15
258F3 CJK UNIFIED IDEOGRAPH-#258F3, IRGKangXi=0861.391, RSKangXi=115.15
258F4 CJK UNIFIED IDEOGRAPH-#258F4, IRGKangXi=0861.391, RSKangXi=115.15
258F5 CJK UNIFIED IDEOGRAPH-#258F5, IRGKangXi=0861.391, RSKangXi=115.15
258F6 CJK UNIFIED IDEOGRAPH-#258F6, IRGKangXi=0861.391, RSKangXi=115.15
258F7 CJK UNIFIED IDEOGRAPH-#258F7, IRGKangXi=0861.391, RSKangXi=166.13
258F8 CJK UNIFIED IDEOGRAPH-#258F8, IRGKangXi=0861.391, RSKangXi=115.15
258F9 CJK UNIFIED IDEOGRAPH-#258F9, IRGKangXi=0861.391, RSKangXi=115.15
258FA CJK UNIFIED IDEOGRAPH-#258FA, IRGKangXi=0861.391, RSKangXi=115.15
258FB CJK UNIFIED IDEOGRAPH-#258FB, IRGKangXi=0861.391, RSKangXi=115.15
258FC CJK UNIFIED IDEOGRAPH-#258FC, IRGKangXi=0861.391, RSKangXi=115.15
258FD CJK UNIFIED IDEOGRAPH-#258FD, IRGKangXi=0861.391, RSKangXi=115.15
258FE CJK UNIFIED IDEOGRAPH-#258FE, IRGKangXi=0861.391, RSKangXi=115.15
258FF CJK UNIFIED IDEOGRAPH-#258FF, IRGKangXi=0861.391, RSKangXi=115.15
25900 CJK UNIFIED IDEOGRAPH-#25900, IRGKangXi=0861.400, RSKangXi=115.16
25901 CJK UNIFIED IDEOGRAPH-#25901, IRGKangXi=0861.410, RSKangXi=115.16
25902 CJK UNIFIED IDEOGRAPH-#25902, IRGKangXi=0861.430, RSKangXi=115.16
25903 CJK UNIFIED IDEOGRAPH-#25903, IRGKangXi=0861.440, RSKangXi=115.16
25904 CJK UNIFIED IDEOGRAPH-#25904, IRGKangXi=0861.441, RSKangXi=115.16
25905 CJK UNIFIED IDEOGRAPH-#25905, IRGKangXi=0861.441, RSKangXi=115.16
25906 CJK UNIFIED IDEOGRAPH-#25906, IRGKangXi=0862.010, RSKangXi=115.17
25907 CJK UNIFIED IDEOGRAPH-#25907, IRGKangXi=0862.030, RSKangXi=115.17
25908 CJK UNIFIED IDEOGRAPH-#25908, IRGKangXi=0862.031, RSKangXi=115.17
25909 CJK UNIFIED IDEOGRAPH-#25909, IRGKangXi=0862.031, RSKangXi=115.17
2590A CJK UNIFIED IDEOGRAPH-#2590A, IRGKangXi=0862.040, RSKangXi=115.18
2590B CJK UNIFIED IDEOGRAPH-#2590B, IRGKangXi=0862.050, RSKangXi=115.18
2590C CJK UNIFIED IDEOGRAPH-#2590C, IRGKangXi=0862.080, RSKangXi=115.18
2590D CJK UNIFIED IDEOGRAPH-#2590D, IRGKangXi=0862.090, RSKangXi=115.18
2590E CJK UNIFIED IDEOGRAPH-#2590E, IRGKangXi=0862.100, RSKangXi=115.18
2590F CJK UNIFIED IDEOGRAPH-#2590F, IRGKangXi=0862.101, RSKangXi=115.18
25910 CJK UNIFIED IDEOGRAPH-#25910, IRGKangXi=0862.101, RSKangXi=115.18
25911 CJK UNIFIED IDEOGRAPH-#25911, IRGKangXi=0862.101, RSKangXi=115.18
25912 CJK UNIFIED IDEOGRAPH-#25912, IRGKangXi=0862.101, RSKangXi=115.18
25913 CJK UNIFIED IDEOGRAPH-#25913, IRGKangXi=0862.121, RSKangXi=115.19
25914 CJK UNIFIED IDEOGRAPH-#25914, IRGKangXi=0862.121, RSKangXi=75.20
25915 CJK UNIFIED IDEOGRAPH-#25915, IRGKangXi=0862.121, RSKangXi=115.19
25916 CJK UNIFIED IDEOGRAPH-#25916, IRGKangXi=0862.121, RSKangXi=115.19
25917 CJK UNIFIED IDEOGRAPH-#25917, IRGKangXi=0862.130, RSKangXi=115.20
25918 CJK UNIFIED IDEOGRAPH-#25918, IRGKangXi=0862.140, RSKangXi=115.20
25919 CJK UNIFIED IDEOGRAPH-#25919, IRGKangXi=0862.141, RSKangXi=115.20
2591A CJK UNIFIED IDEOGRAPH-#2591A, IRGKangXi=0862.141, RSKangXi=115.20
2591B CJK UNIFIED IDEOGRAPH-#2591B, IRGKangXi=0862.150, RSKangXi=115.21
2591C CJK UNIFIED IDEOGRAPH-#2591C, IRGKangXi=0862.160, RSKangXi=115.21
2591D CJK UNIFIED IDEOGRAPH-#2591D, IRGKangXi=0862.161, RSKangXi=115.21
2591E CJK UNIFIED IDEOGRAPH-#2591E, IRGKangXi=0862.170, RSKangXi=115.24
2591F CJK UNIFIED IDEOGRAPH-#2591F, IRGKangXi=0862.180, RSKangXi=115.24
25920 CJK UNIFIED IDEOGRAPH-#25920, IRGKangXi=0862.191, RSKangXi=115.27
25921 CJK UNIFIED IDEOGRAPH-#25921, IRGKangXi=0862.191, RSKangXi=115.30
25922 CJK UNIFIED IDEOGRAPH-#25922, IRGKangXi=0862.210, RSKangXi=116.0
25923 CJK UNIFIED IDEOGRAPH-#25923, IRGKangXi=0862.260, RSKangXi=116.2
25924 CJK UNIFIED IDEOGRAPH-#25924, IRGKangXi=0862.270, RSKangXi=116.2
25925 CJK UNIFIED IDEOGRAPH-#25925, IRGKangXi=0862.271, RSKangXi=116.2
25926 CJK UNIFIED IDEOGRAPH-#25926, IRGKangXi=0862.271, RSKangXi=116.2
25927 CJK UNIFIED IDEOGRAPH-#25927, IRGKangXi=0863.020, RSKangXi=116.3
25928 CJK UNIFIED IDEOGRAPH-#25928, IRGKangXi=0863.040, RSKangXi=116.3
25929 CJK UNIFIED IDEOGRAPH-#25929, IRGKangXi=0863.050, RSKangXi=116.3
2592A CJK UNIFIED IDEOGRAPH-#2592A, IRGKangXi=0863.060, RSKangXi=116.3
2592B CJK UNIFIED IDEOGRAPH-#2592B, IRGKangXi=0863.070, RSKangXi=116.3
2592C CJK UNIFIED IDEOGRAPH-#2592C, IRGKangXi=0863.080, RSKangXi=116.3
2592D CJK UNIFIED IDEOGRAPH-#2592D, IRGKangXi=0863.090, RSKangXi=116.3
2592E CJK UNIFIED IDEOGRAPH-#2592E, IRGKangXi=0863.100, RSKangXi=116.3
2592F CJK UNIFIED IDEOGRAPH-#2592F, IRGKangXi=0863.101, RSKangXi=116.3
25930 CJK UNIFIED IDEOGRAPH-#25930, IRGKangXi=0863.101, RSKangXi=116.3
25931 CJK UNIFIED IDEOGRAPH-#25931, IRGKangXi=0863.101, RSKangXi=116.3
25932 CJK UNIFIED IDEOGRAPH-#25932, IRGKangXi=0863.101, RSKangXi=116.3
25933 CJK UNIFIED IDEOGRAPH-#25933, IRGKangXi=0863.101, RSKangXi=116.3
25934 CJK UNIFIED IDEOGRAPH-#25934, IRGKangXi=0863.140, RSKangXi=116.4
25935 CJK UNIFIED IDEOGRAPH-#25935, IRGKangXi=0864.020, RSKangXi=116.4
25936 CJK UNIFIED IDEOGRAPH-#25936, IRGKangXi=0864.030, RSKangXi=116.4
25937 CJK UNIFIED IDEOGRAPH-#25937, IRGKangXi=0864.040, RSKangXi=116.4
25938 CJK UNIFIED IDEOGRAPH-#25938, IRGKangXi=0864.050, RSKangXi=116.4
25939 CJK UNIFIED IDEOGRAPH-#25939, IRGKangXi=0864.060, RSKangXi=116.4
2593A CJK UNIFIED IDEOGRAPH-#2593A, IRGKangXi=0864.070, RSKangXi=116.4
2593B CJK UNIFIED IDEOGRAPH-#2593B, IRGKangXi=0864.080, RSKangXi=116.4
2593C CJK UNIFIED IDEOGRAPH-#2593C, IRGKangXi=0864.090, RSKangXi=116.4
2593D CJK UNIFIED IDEOGRAPH-#2593D, IRGKangXi=0864.100, RSKangXi=116.4
2593E CJK UNIFIED IDEOGRAPH-#2593E, IRGKangXi=0864.110, RSKangXi=116.4
2593F CJK UNIFIED IDEOGRAPH-#2593F, IRGKangXi=0864.120, RSKangXi=116.4
25940 CJK UNIFIED IDEOGRAPH-#25940, IRGKangXi=0864.121, RSKangXi=116.4
25941 CJK UNIFIED IDEOGRAPH-#25941, IRGKangXi=0864.121, RSKangXi=116.4
25942 CJK UNIFIED IDEOGRAPH-#25942, IRGKangXi=0864.121, RSKangXi=116.4
25943 CJK UNIFIED IDEOGRAPH-#25943, IRGKangXi=0864.121, RSKangXi=116.4
25944 CJK UNIFIED IDEOGRAPH-#25944, IRGKangXi=0864.121, RSKangXi=116.4
25945 CJK UNIFIED IDEOGRAPH-#25945, IRGKangXi=0864.121, RSKangXi=116.4, Def{(Cant.) a hole, hollow; cavity}
25946 CJK UNIFIED IDEOGRAPH-#25946, IRGKangXi=0864.121, RSKangXi=116.4
25947 CJK UNIFIED IDEOGRAPH-#25947, IRGKangXi=0864.150, RSKangXi=116.5
25948 CJK UNIFIED IDEOGRAPH-#25948, IRGKangXi=0864.160, RSKangXi=116.5
25949 CJK UNIFIED IDEOGRAPH-#25949, IRGKangXi=0864.210, RSKangXi=116.5
2594A CJK UNIFIED IDEOGRAPH-#2594A, IRGKangXi=0864.240, RSKangXi=116.5
2594B CJK UNIFIED IDEOGRAPH-#2594B, IRGKangXi=0864.250, RSKangXi=116.5
2594C CJK UNIFIED IDEOGRAPH-#2594C, IRGKangXi=0864.270, RSKangXi=116.5
2594D CJK UNIFIED IDEOGRAPH-#2594D, IRGKangXi=0864.300, RSKangXi=116.5
2594E CJK UNIFIED IDEOGRAPH-#2594E, IRGKangXi=0864.310, RSKangXi=116.5
2594F CJK UNIFIED IDEOGRAPH-#2594F, IRGKangXi=0864.320, RSKangXi=116.5
25950 CJK UNIFIED IDEOGRAPH-#25950, IRGKangXi=0864.330, RSKangXi=116.5
25951 CJK UNIFIED IDEOGRAPH-#25951, IRGKangXi=0864.340, RSKangXi=116.5
25952 CJK UNIFIED IDEOGRAPH-#25952, IRGKangXi=0864.350, RSKangXi=116.5
25953 CJK UNIFIED IDEOGRAPH-#25953, IRGKangXi=0864.360, RSKangXi=116.5
25954 CJK UNIFIED IDEOGRAPH-#25954, IRGKangXi=0864.370, RSKangXi=116.5
25955 CJK UNIFIED IDEOGRAPH-#25955, IRGKangXi=0864.381, RSKangXi=116.5
25956 CJK UNIFIED IDEOGRAPH-#25956, IRGKangXi=0864.381, RSKangXi=116.5
25957 CJK UNIFIED IDEOGRAPH-#25957, IRGKangXi=0864.381, RSKangXi=116.5
25958 CJK UNIFIED IDEOGRAPH-#25958, IRGKangXi=0864.381, RSKangXi=116.5
25959 CJK UNIFIED IDEOGRAPH-#25959, IRGKangXi=0864.381, RSKangXi=116.5
2595A CJK UNIFIED IDEOGRAPH-#2595A, IRGKangXi=0864.381, RSKangXi=116.5
2595B CJK UNIFIED IDEOGRAPH-#2595B, IRGKangXi=0864.381, RSKangXi=116.5
2595C CJK UNIFIED IDEOGRAPH-#2595C, IRGKangXi=0864.381, RSKangXi=116.5
2595D CJK UNIFIED IDEOGRAPH-#2595D, IRGKangXi=0864.381, RSKangXi=116.5
2595E CJK UNIFIED IDEOGRAPH-#2595E, IRGKangXi=0864.381, RSKangXi=116.5
2595F CJK UNIFIED IDEOGRAPH-#2595F, IRGKangXi=0864.381, RSKangXi=116.5
25960 CJK UNIFIED IDEOGRAPH-#25960, IRGKangXi=0865.010, RSKangXi=116.6
25961 CJK UNIFIED IDEOGRAPH-#25961, IRGKangXi=0865.030, RSKangXi=116.6
25962 CJK UNIFIED IDEOGRAPH-#25962, IRGKangXi=0865.150, RSKangXi=116.6
25963 CJK UNIFIED IDEOGRAPH-#25963, IRGKangXi=0865.160, RSKangXi=116.6
25964 CJK UNIFIED IDEOGRAPH-#25964, IRGKangXi=0865.180, RSKangXi=116.6
25965 CJK UNIFIED IDEOGRAPH-#25965, IRGKangXi=0865.190, RSKangXi=116.6
25966 CJK UNIFIED IDEOGRAPH-#25966, IRGKangXi=0865.200, RSKangXi=116.6
25967 CJK UNIFIED IDEOGRAPH-#25967, IRGKangXi=0865.210, RSKangXi=116.6
25968 CJK UNIFIED IDEOGRAPH-#25968, IRGKangXi=0865.220, RSKangXi=116.6
25969 CJK UNIFIED IDEOGRAPH-#25969, IRGKangXi=0865.230, RSKangXi=116.6
2596A CJK UNIFIED IDEOGRAPH-#2596A, IRGKangXi=0865.231, RSKangXi=116.6
2596B CJK UNIFIED IDEOGRAPH-#2596B, IRGKangXi=0865.231, RSKangXi=116.6
2596C CJK UNIFIED IDEOGRAPH-#2596C, IRGKangXi=0865.231, RSKangXi=116.6
2596D CJK UNIFIED IDEOGRAPH-#2596D, IRGKangXi=0865.231, RSKangXi=116.6
2596E CJK UNIFIED IDEOGRAPH-#2596E, IRGKangXi=0865.231, RSKangXi=116.6
2596F CJK UNIFIED IDEOGRAPH-#2596F, IRGKangXi=0865.231, RSKangXi=116.6
25970 CJK UNIFIED IDEOGRAPH-#25970, IRGKangXi=0865.231, RSKangXi=116.6
25971 CJK UNIFIED IDEOGRAPH-#25971, IRGKangXi=0865.231, RSKangXi=116.6
25972 CJK UNIFIED IDEOGRAPH-#25972, IRGKangXi=0865.231, RSKangXi=116.6
25973 CJK UNIFIED IDEOGRAPH-#25973, IRGKangXi=0865.231, RSKangXi=116.6
25974 CJK UNIFIED IDEOGRAPH-#25974, IRGKangXi=0865.231, RSKangXi=116.6
25975 CJK UNIFIED IDEOGRAPH-#25975, IRGKangXi=0865.231, RSKangXi=116.6
25976 CJK UNIFIED IDEOGRAPH-#25976, IRGKangXi=0865.240, RSKangXi=116.7
25977 CJK UNIFIED IDEOGRAPH-#25977, IRGKangXi=0865.250, RSKangXi=116.7
25978 CJK UNIFIED IDEOGRAPH-#25978, IRGKangXi=0865.270, RSKangXi=116.7
25979 CJK UNIFIED IDEOGRAPH-#25979, IRGKangXi=0865.290, RSKangXi=116.7
2597A CJK UNIFIED IDEOGRAPH-#2597A, IRGKangXi=0865.300, RSKangXi=116.7
2597B CJK UNIFIED IDEOGRAPH-#2597B, IRGKangXi=0865.340, RSKangXi=116.7
2597C CJK UNIFIED IDEOGRAPH-#2597C, IRGKangXi=0866.020, RSKangXi=116.7
2597D CJK UNIFIED IDEOGRAPH-#2597D, IRGKangXi=0866.040, RSKangXi=116.7
2597E CJK UNIFIED IDEOGRAPH-#2597E, IRGKangXi=0866.050, RSKangXi=116.7
2597F CJK UNIFIED IDEOGRAPH-#2597F, IRGKangXi=0866.060, RSKangXi=116.7
25980 CJK UNIFIED IDEOGRAPH-#25980, IRGKangXi=0866.070, RSKangXi=116.7
25981 CJK UNIFIED IDEOGRAPH-#25981, IRGKangXi=0866.080, RSKangXi=116.7
25982 CJK UNIFIED IDEOGRAPH-#25982, IRGKangXi=0866.090, RSKangXi=116.7
25983 CJK UNIFIED IDEOGRAPH-#25983, IRGKangXi=0866.100, RSKangXi=116.7
25984 CJK UNIFIED IDEOGRAPH-#25984, IRGKangXi=0866.110, RSKangXi=116.7
25985 CJK UNIFIED IDEOGRAPH-#25985, IRGKangXi=0866.120, RSKangXi=116.7
25986 CJK UNIFIED IDEOGRAPH-#25986, IRGKangXi=0866.130, RSKangXi=116.7
25987 CJK UNIFIED IDEOGRAPH-#25987, IRGKangXi=0866.140, RSKangXi=116.7
25988 CJK UNIFIED IDEOGRAPH-#25988, IRGKangXi=0866.150, RSKangXi=116.7
25989 CJK UNIFIED IDEOGRAPH-#25989, IRGKangXi=0866.160, RSKangXi=116.7
2598A CJK UNIFIED IDEOGRAPH-#2598A, IRGKangXi=0866.180, RSKangXi=116.7
2598B CJK UNIFIED IDEOGRAPH-#2598B, IRGKangXi=0866.190, RSKangXi=116.7
2598C CJK UNIFIED IDEOGRAPH-#2598C, IRGKangXi=0866.200, RSKangXi=116.7
2598D CJK UNIFIED IDEOGRAPH-#2598D, IRGKangXi=0866.210, RSKangXi=116.7
2598E CJK UNIFIED IDEOGRAPH-#2598E, IRGKangXi=0866.240, RSKangXi=116.7
2598F CJK UNIFIED IDEOGRAPH-#2598F, IRGKangXi=0866.250, RSKangXi=116.7
25990 CJK UNIFIED IDEOGRAPH-#25990, IRGKangXi=0866.270, RSKangXi=116.7
25991 CJK UNIFIED IDEOGRAPH-#25991, IRGKangXi=0866.280, RSKangXi=116.7
25992 CJK UNIFIED IDEOGRAPH-#25992, IRGKangXi=0866.281, RSKangXi=116.7
25993 CJK UNIFIED IDEOGRAPH-#25993, IRGKangXi=0866.281, RSKangXi=116.7
25994 CJK UNIFIED IDEOGRAPH-#25994, IRGKangXi=0866.281, RSKangXi=116.7
25995 CJK UNIFIED IDEOGRAPH-#25995, IRGKangXi=0866.281, RSKangXi=116.7
25996 CJK UNIFIED IDEOGRAPH-#25996, IRGKangXi=0866.281, RSKangXi=116.7
25997 CJK UNIFIED IDEOGRAPH-#25997, IRGKangXi=0866.281, RSKangXi=116.7
25998 CJK UNIFIED IDEOGRAPH-#25998, IRGKangXi=0866.281, RSKangXi=116.7
25999 CJK UNIFIED IDEOGRAPH-#25999, IRGKangXi=0866.281, RSKangXi=116.7
2599A CJK UNIFIED IDEOGRAPH-#2599A, IRGKangXi=0866.281, RSKangXi=116.7
2599B CJK UNIFIED IDEOGRAPH-#2599B, IRGKangXi=0866.290, RSKangXi=116.8
2599C CJK UNIFIED IDEOGRAPH-#2599C, IRGKangXi=0866.300, RSKangXi=116.8
2599D CJK UNIFIED IDEOGRAPH-#2599D, IRGKangXi=0866.310, RSKangXi=116.8
2599E CJK UNIFIED IDEOGRAPH-#2599E, IRGKangXi=0866.350, RSKangXi=116.8
2599F CJK UNIFIED IDEOGRAPH-#2599F, IRGKangXi=0866.380, RSKangXi=116.8
259A0 CJK UNIFIED IDEOGRAPH-#259A0, IRGKangXi=0866.410, RSKangXi=116.8
259A1 CJK UNIFIED IDEOGRAPH-#259A1, IRGKangXi=0866.430, RSKangXi=116.8
259A2 CJK UNIFIED IDEOGRAPH-#259A2, IRGKangXi=0866.450, RSKangXi=116.8
259A3 CJK UNIFIED IDEOGRAPH-#259A3, IRGKangXi=0866.460, RSKangXi=116.8
259A4 CJK UNIFIED IDEOGRAPH-#259A4, IRGKangXi=0866.470, RSKangXi=116.8
259A5 CJK UNIFIED IDEOGRAPH-#259A5, IRGKangXi=0866.480, RSKangXi=116.8
259A6 CJK UNIFIED IDEOGRAPH-#259A6, IRGKangXi=0866.510, RSKangXi=116.8
259A7 CJK UNIFIED IDEOGRAPH-#259A7, IRGKangXi=0866.520, RSKangXi=116.8
259A8 CJK UNIFIED IDEOGRAPH-#259A8, IRGKangXi=0866.530, RSKangXi=116.8
259A9 CJK UNIFIED IDEOGRAPH-#259A9, IRGKangXi=0866.540, RSKangXi=116.8
259AA CJK UNIFIED IDEOGRAPH-#259AA, IRGKangXi=0866.550, RSKangXi=116.8
259AB CJK UNIFIED IDEOGRAPH-#259AB, IRGKangXi=0866.551, RSKangXi=116.8
259AC CJK UNIFIED IDEOGRAPH-#259AC, IRGKangXi=0866.551, RSKangXi=116.8
259AD CJK UNIFIED IDEOGRAPH-#259AD, IRGKangXi=0866.551, RSKangXi=116.8
259AE CJK UNIFIED IDEOGRAPH-#259AE, IRGKangXi=0866.551, RSKangXi=116.8
259AF CJK UNIFIED IDEOGRAPH-#259AF, IRGKangXi=0866.551, RSKangXi=116.8
259B0 CJK UNIFIED IDEOGRAPH-#259B0, IRGKangXi=0866.551, RSKangXi=116.8
259B1 CJK UNIFIED IDEOGRAPH-#259B1, IRGKangXi=0866.551, RSKangXi=116.8
259B2 CJK UNIFIED IDEOGRAPH-#259B2, IRGKangXi=0866.551, RSKangXi=116.8
259B3 CJK UNIFIED IDEOGRAPH-#259B3, IRGKangXi=0866.551, RSKangXi=116.8
259B4 CJK UNIFIED IDEOGRAPH-#259B4, IRGKangXi=0866.551, RSKangXi=116.8
259B5 CJK UNIFIED IDEOGRAPH-#259B5, IRGKangXi=0866.551, RSKangXi=116.8
259B6 CJK UNIFIED IDEOGRAPH-#259B6, IRGKangXi=0866.551, RSKangXi=116.8
259B7 CJK UNIFIED IDEOGRAPH-#259B7, IRGKangXi=0866.551, RSKangXi=116.8
259B8 CJK UNIFIED IDEOGRAPH-#259B8, IRGKangXi=0866.580, RSKangXi=116.9
259B9 CJK UNIFIED IDEOGRAPH-#259B9, IRGKangXi=0867.020, RSKangXi=116.9
259BA CJK UNIFIED IDEOGRAPH-#259BA, IRGKangXi=0867.030, RSKangXi=116.9
259BB CJK UNIFIED IDEOGRAPH-#259BB, IRGKangXi=0867.040, RSKangXi=116.9
259BC CJK UNIFIED IDEOGRAPH-#259BC, IRGKangXi=0867.050, RSKangXi=116.9
259BD CJK UNIFIED IDEOGRAPH-#259BD, IRGKangXi=0867.060, RSKangXi=116.9
259BE CJK UNIFIED IDEOGRAPH-#259BE, IRGKangXi=0867.070, RSKangXi=116.9
259BF CJK UNIFIED IDEOGRAPH-#259BF, IRGKangXi=0867.080, RSKangXi=116.9
259C0 CJK UNIFIED IDEOGRAPH-#259C0, IRGKangXi=0867.090, RSKangXi=116.9
259C1 CJK UNIFIED IDEOGRAPH-#259C1, IRGKangXi=0867.091, RSKangXi=116.9
259C2 CJK UNIFIED IDEOGRAPH-#259C2, IRGKangXi=0867.091, RSKangXi=116.9
259C3 CJK UNIFIED IDEOGRAPH-#259C3, IRGKangXi=0867.091, RSKangXi=116.9
259C4 CJK UNIFIED IDEOGRAPH-#259C4, IRGKangXi=0867.091, RSKangXi=116.9
259C5 CJK UNIFIED IDEOGRAPH-#259C5, IRGKangXi=0867.091, RSKangXi=116.9
259C6 CJK UNIFIED IDEOGRAPH-#259C6, IRGKangXi=0867.091, RSKangXi=116.9
259C7 CJK UNIFIED IDEOGRAPH-#259C7, IRGKangXi=0867.091, RSKangXi=116.9
259C8 CJK UNIFIED IDEOGRAPH-#259C8, IRGKangXi=0867.091, RSKangXi=116.9
259C9 CJK UNIFIED IDEOGRAPH-#259C9, IRGKangXi=0867.091, RSKangXi=116.9
259CA CJK UNIFIED IDEOGRAPH-#259CA, IRGKangXi=0867.091, RSKangXi=116.9
259CB CJK UNIFIED IDEOGRAPH-#259CB, IRGKangXi=0867.091, RSKangXi=116.9
259CC CJK UNIFIED IDEOGRAPH-#259CC, IRGKangXi=0867.091, RSKangXi=116.9
259CD CJK UNIFIED IDEOGRAPH-#259CD, IRGKangXi=0867.091, RSKangXi=116.9
259CE CJK UNIFIED IDEOGRAPH-#259CE, IRGKangXi=0867.091, RSKangXi=116.9
259CF CJK UNIFIED IDEOGRAPH-#259CF, IRGKangXi=0867.091, RSKangXi=116.9
259D0 CJK UNIFIED IDEOGRAPH-#259D0, IRGKangXi=0867.130, RSKangXi=116.10
259D1 CJK UNIFIED IDEOGRAPH-#259D1, IRGKangXi=0867.150, RSKangXi=116.10
259D2 CJK UNIFIED IDEOGRAPH-#259D2, IRGKangXi=0867.160, RSKangXi=116.10
259D3 CJK UNIFIED IDEOGRAPH-#259D3, IRGKangXi=0867.190, RSKangXi=116.10
259D4 CJK UNIFIED IDEOGRAPH-#259D4, IRGKangXi=0867.200, RSKangXi=116.10
259D5 CJK UNIFIED IDEOGRAPH-#259D5, IRGKangXi=0867.210, RSKangXi=116.10
259D6 CJK UNIFIED IDEOGRAPH-#259D6, IRGKangXi=0867.220, RSKangXi=116.10
259D7 CJK UNIFIED IDEOGRAPH-#259D7, IRGKangXi=0867.230, RSKangXi=116.10
259D8 CJK UNIFIED IDEOGRAPH-#259D8, IRGKangXi=0867.240, RSKangXi=116.10
259D9 CJK UNIFIED IDEOGRAPH-#259D9, IRGKangXi=0867.250, RSKangXi=116.10
259DA CJK UNIFIED IDEOGRAPH-#259DA, IRGKangXi=0867.270, RSKangXi=116.10
259DB CJK UNIFIED IDEOGRAPH-#259DB, IRGKangXi=0867.290, RSKangXi=116.10
259DC CJK UNIFIED IDEOGRAPH-#259DC, IRGKangXi=0867.300, RSKangXi=116.10
259DD CJK UNIFIED IDEOGRAPH-#259DD, IRGKangXi=0867.310, RSKangXi=116.10
259DE CJK UNIFIED IDEOGRAPH-#259DE, IRGKangXi=0867.320, RSKangXi=116.10
259DF CJK UNIFIED IDEOGRAPH-#259DF, IRGKangXi=0867.330, RSKangXi=116.10
259E0 CJK UNIFIED IDEOGRAPH-#259E0, IRGKangXi=0867.340, RSKangXi=116.10
259E1 CJK UNIFIED IDEOGRAPH-#259E1, IRGKangXi=0867.351, RSKangXi=116.10
259E2 CJK UNIFIED IDEOGRAPH-#259E2, IRGKangXi=0867.351, RSKangXi=128.9
259E3 CJK UNIFIED IDEOGRAPH-#259E3, IRGKangXi=0867.351, RSKangXi=116.10
259E4 CJK UNIFIED IDEOGRAPH-#259E4, IRGKangXi=0867.351, RSKangXi=116.10
259E5 CJK UNIFIED IDEOGRAPH-#259E5, IRGKangXi=0867.351, RSKangXi=116.10
259E6 CJK UNIFIED IDEOGRAPH-#259E6, IRGKangXi=0867.351, RSKangXi=116.10
259E7 CJK UNIFIED IDEOGRAPH-#259E7, IRGKangXi=0867.351, RSKangXi=116.10
259E8 CJK UNIFIED IDEOGRAPH-#259E8, IRGKangXi=0867.351, RSKangXi=116.10
259E9 CJK UNIFIED IDEOGRAPH-#259E9, IRGKangXi=0867.351, RSKangXi=116.10
259EA CJK UNIFIED IDEOGRAPH-#259EA, IRGKangXi=0867.351, RSKangXi=116.10
259EB CJK UNIFIED IDEOGRAPH-#259EB, IRGKangXi=0867.351, RSKangXi=116.10
259EC CJK UNIFIED IDEOGRAPH-#259EC, IRGKangXi=0867.360, RSKangXi=116.11
259ED CJK UNIFIED IDEOGRAPH-#259ED, IRGKangXi=0867.370, RSKangXi=116.11
259EE CJK UNIFIED IDEOGRAPH-#259EE, IRGKangXi=0867.410, RSKangXi=116.11
259EF CJK UNIFIED IDEOGRAPH-#259EF, IRGKangXi=0867.420, RSKangXi=116.11
259F0 CJK UNIFIED IDEOGRAPH-#259F0, IRGKangXi=0867.430, RSKangXi=116.11
259F1 CJK UNIFIED IDEOGRAPH-#259F1, IRGKangXi=0868.020, RSKangXi=116.11
259F2 CJK UNIFIED IDEOGRAPH-#259F2, IRGKangXi=0868.060, RSKangXi=116.11
259F3 CJK UNIFIED IDEOGRAPH-#259F3, IRGKangXi=0868.080, RSKangXi=116.11
259F4 CJK UNIFIED IDEOGRAPH-#259F4, IRGKangXi=0868.090, RSKangXi=116.11
259F5 CJK UNIFIED IDEOGRAPH-#259F5, IRGKangXi=0868.100, RSKangXi=116.11
259F6 CJK UNIFIED IDEOGRAPH-#259F6, IRGKangXi=0868.130, RSKangXi=116.11
259F7 CJK UNIFIED IDEOGRAPH-#259F7, IRGKangXi=0868.140, RSKangXi=116.11
259F8 CJK UNIFIED IDEOGRAPH-#259F8, IRGKangXi=0868.150, RSKangXi=116.11
259F9 CJK UNIFIED IDEOGRAPH-#259F9, IRGKangXi=0868.160, RSKangXi=116.11, Def{(Cant.) puddle}
259FA CJK UNIFIED IDEOGRAPH-#259FA, IRGKangXi=0868.180, RSKangXi=116.11
259FB CJK UNIFIED IDEOGRAPH-#259FB, IRGKangXi=0868.190, RSKangXi=116.11
259FC CJK UNIFIED IDEOGRAPH-#259FC, IRGKangXi=0868.200, RSKangXi=116.12
259FD CJK UNIFIED IDEOGRAPH-#259FD, IRGKangXi=0868.210, RSKangXi=116.11
259FE CJK UNIFIED IDEOGRAPH-#259FE, IRGKangXi=0868.211, RSKangXi=116.11
259FF CJK UNIFIED IDEOGRAPH-#259FF, IRGKangXi=0868.211, RSKangXi=116.11
25A00 CJK UNIFIED IDEOGRAPH-#25A00, IRGKangXi=0868.211, RSKangXi=116.11
25A01 CJK UNIFIED IDEOGRAPH-#25A01, IRGKangXi=0868.211, RSKangXi=116.11
25A02 CJK UNIFIED IDEOGRAPH-#25A02, IRGKangXi=0868.211, RSKangXi=116.11
25A03 CJK UNIFIED IDEOGRAPH-#25A03, IRGKangXi=0868.211, RSKangXi=116.11
25A04 CJK UNIFIED IDEOGRAPH-#25A04, IRGKangXi=0868.211, RSKangXi=116.11
25A05 CJK UNIFIED IDEOGRAPH-#25A05, IRGKangXi=0868.211, RSKangXi=116.11
25A06 CJK UNIFIED IDEOGRAPH-#25A06, IRGKangXi=0868.211, RSKangXi=116.11
25A07 CJK UNIFIED IDEOGRAPH-#25A07, IRGKangXi=0868.211, RSKangXi=116.11
25A08 CJK UNIFIED IDEOGRAPH-#25A08, IRGKangXi=0868.211, RSKangXi=116.11
25A09 CJK UNIFIED IDEOGRAPH-#25A09, IRGKangXi=0868.211, RSKangXi=116.11
25A0A CJK UNIFIED IDEOGRAPH-#25A0A, IRGKangXi=0868.211, RSKangXi=116.11
25A0B CJK UNIFIED IDEOGRAPH-#25A0B, IRGKangXi=0868.211, RSKangXi=116.11
25A0C CJK UNIFIED IDEOGRAPH-#25A0C, IRGKangXi=0868.220, RSKangXi=116.12
25A0D CJK UNIFIED IDEOGRAPH-#25A0D, IRGKangXi=0868.230, RSKangXi=116.12
25A0E CJK UNIFIED IDEOGRAPH-#25A0E, IRGKangXi=0868.270, RSKangXi=116.12
25A0F CJK UNIFIED IDEOGRAPH-#25A0F, IRGKangXi=0868.350, RSKangXi=116.12
25A10 CJK UNIFIED IDEOGRAPH-#25A10, IRGKangXi=0868.360, RSKangXi=116.12
25A11 CJK UNIFIED IDEOGRAPH-#25A11, IRGKangXi=0868.380, RSKangXi=116.12
25A12 CJK UNIFIED IDEOGRAPH-#25A12, IRGKangXi=0868.400, RSKangXi=116.12
25A13 CJK UNIFIED IDEOGRAPH-#25A13, IRGKangXi=0868.410, RSKangXi=116.12
25A14 CJK UNIFIED IDEOGRAPH-#25A14, IRGKangXi=0868.420, RSKangXi=116.12
25A15 CJK UNIFIED IDEOGRAPH-#25A15, IRGKangXi=0868.430, RSKangXi=116.12
25A16 CJK UNIFIED IDEOGRAPH-#25A16, IRGKangXi=0868.440, RSKangXi=116.12
25A17 CJK UNIFIED IDEOGRAPH-#25A17, IRGKangXi=0868.460, RSKangXi=116.12
25A18 CJK UNIFIED IDEOGRAPH-#25A18, IRGKangXi=0868.470, RSKangXi=116.12
25A19 CJK UNIFIED IDEOGRAPH-#25A19, IRGKangXi=0868.471, RSKangXi=116.12
25A1A CJK UNIFIED IDEOGRAPH-#25A1A, IRGKangXi=0868.471, RSKangXi=116.12
25A1B CJK UNIFIED IDEOGRAPH-#25A1B, IRGKangXi=0868.471, RSKangXi=116.12
25A1C CJK UNIFIED IDEOGRAPH-#25A1C, IRGKangXi=0868.471, RSKangXi=116.12
25A1D CJK UNIFIED IDEOGRAPH-#25A1D, IRGKangXi=0868.471, RSKangXi=116.12
25A1E CJK UNIFIED IDEOGRAPH-#25A1E, IRGKangXi=0868.471, RSKangXi=116.12
25A1F CJK UNIFIED IDEOGRAPH-#25A1F, IRGKangXi=0868.471, RSKangXi=116.12
25A20 CJK UNIFIED IDEOGRAPH-#25A20, IRGKangXi=0869.050, RSKangXi=116.13
25A21 CJK UNIFIED IDEOGRAPH-#25A21, IRGKangXi=0869.060, RSKangXi=116.13
25A22 CJK UNIFIED IDEOGRAPH-#25A22, IRGKangXi=0869.070, RSKangXi=116.13
25A23 CJK UNIFIED IDEOGRAPH-#25A23, IRGKangXi=0869.071, RSKangXi=116.13
25A24 CJK UNIFIED IDEOGRAPH-#25A24, IRGKangXi=0869.071, RSKangXi=116.13
25A25 CJK UNIFIED IDEOGRAPH-#25A25, IRGKangXi=0869.071, RSKangXi=116.13
25A26 CJK UNIFIED IDEOGRAPH-#25A26, IRGKangXi=0869.071, RSKangXi=116.13
25A27 CJK UNIFIED IDEOGRAPH-#25A27, IRGKangXi=0869.071, RSKangXi=116.13
25A28 CJK UNIFIED IDEOGRAPH-#25A28, IRGKangXi=0869.071, RSKangXi=116.13
25A29 CJK UNIFIED IDEOGRAPH-#25A29, IRGKangXi=0869.071, RSKangXi=116.12
25A2A CJK UNIFIED IDEOGRAPH-#25A2A, IRGKangXi=0869.110, RSKangXi=116.14
25A2B CJK UNIFIED IDEOGRAPH-#25A2B, IRGKangXi=0869.120, RSKangXi=116.14
25A2C CJK UNIFIED IDEOGRAPH-#25A2C, IRGKangXi=0869.130, RSKangXi=116.14
25A2D CJK UNIFIED IDEOGRAPH-#25A2D, IRGKangXi=0869.140, RSKangXi=116.14
25A2E CJK UNIFIED IDEOGRAPH-#25A2E, IRGKangXi=0869.150, RSKangXi=116.14
25A2F CJK UNIFIED IDEOGRAPH-#25A2F, IRGKangXi=0869.151, RSKangXi=116.14
25A30 CJK UNIFIED IDEOGRAPH-#25A30, IRGKangXi=0869.160, RSKangXi=116.15
25A31 CJK UNIFIED IDEOGRAPH-#25A31, IRGKangXi=0869.170, RSKangXi=116.15
25A32 CJK UNIFIED IDEOGRAPH-#25A32, IRGKangXi=0869.190, RSKangXi=116.14
25A33 CJK UNIFIED IDEOGRAPH-#25A33, IRGKangXi=0869.210, RSKangXi=116.15
25A34 CJK UNIFIED IDEOGRAPH-#25A34, IRGKangXi=0869.220, RSKangXi=116.15
25A35 CJK UNIFIED IDEOGRAPH-#25A35, IRGKangXi=0869.230, RSKangXi=116.16
25A36 CJK UNIFIED IDEOGRAPH-#25A36, IRGKangXi=0869.240, RSKangXi=116.15
25A37 CJK UNIFIED IDEOGRAPH-#25A37, IRGKangXi=0869.250, RSKangXi=116.15
25A38 CJK UNIFIED IDEOGRAPH-#25A38, IRGKangXi=0869.251, RSKangXi=116.15
25A39 CJK UNIFIED IDEOGRAPH-#25A39, IRGKangXi=0869.251, RSKangXi=116.15
25A3A CJK UNIFIED IDEOGRAPH-#25A3A, IRGKangXi=0869.251, RSKangXi=116.15
25A3B CJK UNIFIED IDEOGRAPH-#25A3B, IRGKangXi=0869.270, RSKangXi=116.16
25A3C CJK UNIFIED IDEOGRAPH-#25A3C, IRGKangXi=0870.010, RSKangXi=116.16
25A3D CJK UNIFIED IDEOGRAPH-#25A3D, IRGKangXi=0870.020, RSKangXi=116.16
25A3E CJK UNIFIED IDEOGRAPH-#25A3E, IRGKangXi=0870.030, RSKangXi=116.16
25A3F CJK UNIFIED IDEOGRAPH-#25A3F, IRGKangXi=0870.040, RSKangXi=116.16
25A40 CJK UNIFIED IDEOGRAPH-#25A40, IRGKangXi=0870.050, RSKangXi=116.16
25A41 CJK UNIFIED IDEOGRAPH-#25A41, IRGKangXi=0870.060, RSKangXi=116.16
25A42 CJK UNIFIED IDEOGRAPH-#25A42, IRGKangXi=0870.070, RSKangXi=116.16
25A43 CJK UNIFIED IDEOGRAPH-#25A43, IRGKangXi=0870.071, RSKangXi=116.16
25A44 CJK UNIFIED IDEOGRAPH-#25A44, IRGKangXi=0870.071, RSKangXi=116.16
25A45 CJK UNIFIED IDEOGRAPH-#25A45, IRGKangXi=0870.071, RSKangXi=116.16
25A46 CJK UNIFIED IDEOGRAPH-#25A46, IRGKangXi=0870.071, RSKangXi=116.16
25A47 CJK UNIFIED IDEOGRAPH-#25A47, IRGKangXi=0870.071, RSKangXi=116.16
25A48 CJK UNIFIED IDEOGRAPH-#25A48, IRGKangXi=0870.071, RSKangXi=116.16
25A49 CJK UNIFIED IDEOGRAPH-#25A49, IRGKangXi=0870.101, RSKangXi=116.17
25A4A CJK UNIFIED IDEOGRAPH-#25A4A, IRGKangXi=0870.110, RSKangXi=116.18
25A4B CJK UNIFIED IDEOGRAPH-#25A4B, IRGKangXi=0870.111, RSKangXi=116.18
25A4C CJK UNIFIED IDEOGRAPH-#25A4C, IRGKangXi=0870.120, RSKangXi=116.19
25A4D CJK UNIFIED IDEOGRAPH-#25A4D, IRGKangXi=0870.121, RSKangXi=116.19
25A4E CJK UNIFIED IDEOGRAPH-#25A4E, IRGKangXi=0870.130, RSKangXi=116.20
25A4F CJK UNIFIED IDEOGRAPH-#25A4F, IRGKangXi=0870.131, RSKangXi=116.19
25A50 CJK UNIFIED IDEOGRAPH-#25A50, IRGKangXi=0870.131, RSKangXi=116.19
25A51 CJK UNIFIED IDEOGRAPH-#25A51, IRGKangXi=0870.131, RSKangXi=116.19
25A52 CJK UNIFIED IDEOGRAPH-#25A52, IRGKangXi=0870.140, RSKangXi=116.20
25A53 CJK UNIFIED IDEOGRAPH-#25A53, IRGKangXi=0870.150, RSKangXi=116.21
25A54 CJK UNIFIED IDEOGRAPH-#25A54, IRGKangXi=0870.160, RSKangXi=116.24
25A55 CJK UNIFIED IDEOGRAPH-#25A55, IRGKangXi=0870.200, RSKangXi=117.2
25A56 CJK UNIFIED IDEOGRAPH-#25A56, IRGKangXi=0870.201, RSKangXi=117.2
25A57 CJK UNIFIED IDEOGRAPH-#25A57, IRGKangXi=0870.230, RSKangXi=117.3
25A58 CJK UNIFIED IDEOGRAPH-#25A58, IRGKangXi=0870.231, RSKangXi=117.3
25A59 CJK UNIFIED IDEOGRAPH-#25A59, IRGKangXi=0870.260, RSKangXi=117.4
25A5A CJK UNIFIED IDEOGRAPH-#25A5A, IRGKangXi=0870.271, RSKangXi=117.4
25A5B CJK UNIFIED IDEOGRAPH-#25A5B, IRGKangXi=0870.271, RSKangXi=117.4
25A5C CJK UNIFIED IDEOGRAPH-#25A5C, IRGKangXi=0870.271, RSKangXi=117.4
25A5D CJK UNIFIED IDEOGRAPH-#25A5D, IRGKangXi=0870.271, RSKangXi=117.4
25A5E CJK UNIFIED IDEOGRAPH-#25A5E, IRGKangXi=0870.271, RSKangXi=117.4
25A5F CJK UNIFIED IDEOGRAPH-#25A5F, IRGKangXi=0870.271, RSKangXi=117.4
25A60 CJK UNIFIED IDEOGRAPH-#25A60, IRGKangXi=0870.300, RSKangXi=117.5
25A61 CJK UNIFIED IDEOGRAPH-#25A61, IRGKangXi=0870.340, RSKangXi=117.5
25A62 CJK UNIFIED IDEOGRAPH-#25A62, IRGKangXi=0870.360, RSKangXi=117.5
25A63 CJK UNIFIED IDEOGRAPH-#25A63, IRGKangXi=0870.370, RSKangXi=117.5
25A64 CJK UNIFIED IDEOGRAPH-#25A64, IRGKangXi=0871.010, RSKangXi=117.5
25A65 CJK UNIFIED IDEOGRAPH-#25A65, IRGKangXi=0871.020, RSKangXi=117.5
25A66 CJK UNIFIED IDEOGRAPH-#25A66, IRGKangXi=0871.030, RSKangXi=117.5
25A67 CJK UNIFIED IDEOGRAPH-#25A67, IRGKangXi=0871.031, RSKangXi=117.5
25A68 CJK UNIFIED IDEOGRAPH-#25A68, IRGKangXi=0871.031, RSKangXi=117.5
25A69 CJK UNIFIED IDEOGRAPH-#25A69, IRGKangXi=0871.031, RSKangXi=117.5
25A6A CJK UNIFIED IDEOGRAPH-#25A6A, IRGKangXi=0871.031, RSKangXi=117.5
25A6B CJK UNIFIED IDEOGRAPH-#25A6B, IRGKangXi=0871.031, RSKangXi=117.5
25A6C CJK UNIFIED IDEOGRAPH-#25A6C, IRGKangXi=0871.031, RSKangXi=117.5
25A6D CJK UNIFIED IDEOGRAPH-#25A6D, IRGKangXi=0871.031, RSKangXi=117.5
25A6E CJK UNIFIED IDEOGRAPH-#25A6E, IRGKangXi=0871.031, RSKangXi=117.5
25A6F CJK UNIFIED IDEOGRAPH-#25A6F, IRGKangXi=0871.031, RSKangXi=117.5
25A70 CJK UNIFIED IDEOGRAPH-#25A70, IRGKangXi=0871.031, RSKangXi=117.5
25A71 CJK UNIFIED IDEOGRAPH-#25A71, IRGKangXi=0871.050, RSKangXi=117.6
25A72 CJK UNIFIED IDEOGRAPH-#25A72, IRGKangXi=0871.070, RSKangXi=117.6, Def{a god; to raise}
25A73 CJK UNIFIED IDEOGRAPH-#25A73, IRGKangXi=0871.090, RSKangXi=117.6
25A74 CJK UNIFIED IDEOGRAPH-#25A74, IRGKangXi=0871.100, RSKangXi=117.6
25A75 CJK UNIFIED IDEOGRAPH-#25A75, IRGKangXi=0871.110, RSKangXi=117.6
25A76 CJK UNIFIED IDEOGRAPH-#25A76, IRGKangXi=0871.120, RSKangXi=117.6
25A77 CJK UNIFIED IDEOGRAPH-#25A77, IRGKangXi=0871.121, RSKangXi=117.6
25A78 CJK UNIFIED IDEOGRAPH-#25A78, IRGKangXi=0871.121, RSKangXi=117.6
25A79 CJK UNIFIED IDEOGRAPH-#25A79, IRGKangXi=0871.121, RSKangXi=117.6
25A7A CJK UNIFIED IDEOGRAPH-#25A7A, IRGKangXi=0871.121, RSKangXi=117.6
25A7B CJK UNIFIED IDEOGRAPH-#25A7B, IRGKangXi=0871.121, RSKangXi=117.6
25A7C CJK UNIFIED IDEOGRAPH-#25A7C, IRGKangXi=0871.121, RSKangXi=117.6
25A7D CJK UNIFIED IDEOGRAPH-#25A7D, IRGKangXi=0871.121, RSKangXi=117.6
25A7E CJK UNIFIED IDEOGRAPH-#25A7E, IRGKangXi=0871.130, RSKangXi=117.7
25A7F CJK UNIFIED IDEOGRAPH-#25A7F, IRGKangXi=0871.140, RSKangXi=117.7
25A80 CJK UNIFIED IDEOGRAPH-#25A80, IRGKangXi=0871.160, RSKangXi=117.7
25A81 CJK UNIFIED IDEOGRAPH-#25A81, IRGKangXi=0872.040, RSKangXi=117.7
25A82 CJK UNIFIED IDEOGRAPH-#25A82, IRGKangXi=0872.060, RSKangXi=117.7
25A83 CJK UNIFIED IDEOGRAPH-#25A83, IRGKangXi=0872.070, RSKangXi=117.7
25A84 CJK UNIFIED IDEOGRAPH-#25A84, IRGKangXi=0872.090, RSKangXi=117.7
25A85 CJK UNIFIED IDEOGRAPH-#25A85, IRGKangXi=0872.091, RSKangXi=117.7
25A86 CJK UNIFIED IDEOGRAPH-#25A86, IRGKangXi=0872.091, RSKangXi=117.7
25A87 CJK UNIFIED IDEOGRAPH-#25A87, IRGKangXi=0872.091, RSKangXi=117.7
25A88 CJK UNIFIED IDEOGRAPH-#25A88, IRGKangXi=0872.091, RSKangXi=117.7
25A89 CJK UNIFIED IDEOGRAPH-#25A89, IRGKangXi=0872.091, RSKangXi=117.7
25A8A CJK UNIFIED IDEOGRAPH-#25A8A, IRGKangXi=0872.110, RSKangXi=117.8
25A8B CJK UNIFIED IDEOGRAPH-#25A8B, IRGKangXi=0872.120, RSKangXi=117.8
25A8C CJK UNIFIED IDEOGRAPH-#25A8C, IRGKangXi=0872.150, RSKangXi=117.8
25A8D CJK UNIFIED IDEOGRAPH-#25A8D, IRGKangXi=0872.200, RSKangXi=117.8
25A8E CJK UNIFIED IDEOGRAPH-#25A8E, IRGKangXi=0872.220, RSKangXi=117.8
25A8F CJK UNIFIED IDEOGRAPH-#25A8F, IRGKangXi=0872.230, RSKangXi=117.8
25A90 CJK UNIFIED IDEOGRAPH-#25A90, IRGKangXi=0872.240, RSKangXi=117.8
25A91 CJK UNIFIED IDEOGRAPH-#25A91, IRGKangXi=0872.250, RSKangXi=117.8
25A92 CJK UNIFIED IDEOGRAPH-#25A92, IRGKangXi=0872.251, RSKangXi=117.8
25A93 CJK UNIFIED IDEOGRAPH-#25A93, IRGKangXi=0872.251, RSKangXi=117.8
25A94 CJK UNIFIED IDEOGRAPH-#25A94, IRGKangXi=0872.251, RSKangXi=117.8
25A95 CJK UNIFIED IDEOGRAPH-#25A95, IRGKangXi=0872.251, RSKangXi=117.8
25A96 CJK UNIFIED IDEOGRAPH-#25A96, IRGKangXi=0872.251, RSKangXi=117.8
25A97 CJK UNIFIED IDEOGRAPH-#25A97, IRGKangXi=0872.251, RSKangXi=117.8
25A98 CJK UNIFIED IDEOGRAPH-#25A98, IRGKangXi=0872.270, RSKangXi=117.9
25A99 CJK UNIFIED IDEOGRAPH-#25A99, IRGKangXi=0872.280, RSKangXi=117.9
25A9A CJK UNIFIED IDEOGRAPH-#25A9A, IRGKangXi=0872.310, RSKangXi=117.9
25A9B CJK UNIFIED IDEOGRAPH-#25A9B, IRGKangXi=0873.010, RSKangXi=117.9
25A9C CJK UNIFIED IDEOGRAPH-#25A9C, IRGKangXi=0873.011, RSKangXi=117.9
25A9D CJK UNIFIED IDEOGRAPH-#25A9D, IRGKangXi=0873.011, RSKangXi=117.9
25A9E CJK UNIFIED IDEOGRAPH-#25A9E, IRGKangXi=0873.011, RSKangXi=117.9
25A9F CJK UNIFIED IDEOGRAPH-#25A9F, IRGKangXi=0873.011, RSKangXi=117.9
25AA0 CJK UNIFIED IDEOGRAPH-#25AA0, IRGKangXi=0873.011, RSKangXi=117.9
25AA1 CJK UNIFIED IDEOGRAPH-#25AA1, IRGKangXi=0873.011, RSKangXi=117.9
25AA2 CJK UNIFIED IDEOGRAPH-#25AA2, IRGKangXi=0873.011, RSKangXi=117.9
25AA3 CJK UNIFIED IDEOGRAPH-#25AA3, IRGKangXi=0873.011, RSKangXi=117.9
25AA4 CJK UNIFIED IDEOGRAPH-#25AA4, IRGKangXi=0873.011, RSKangXi=117.9
25AA5 CJK UNIFIED IDEOGRAPH-#25AA5, IRGKangXi=0873.020, RSKangXi=117.10
25AA6 CJK UNIFIED IDEOGRAPH-#25AA6, IRGKangXi=0873.030, RSKangXi=117.10
25AA7 CJK UNIFIED IDEOGRAPH-#25AA7, IRGKangXi=0873.040, RSKangXi=117.10
25AA8 CJK UNIFIED IDEOGRAPH-#25AA8, IRGKangXi=0873.041, RSKangXi=117.10
25AA9 CJK UNIFIED IDEOGRAPH-#25AA9, IRGKangXi=0873.041, RSKangXi=117.10
25AAA CJK UNIFIED IDEOGRAPH-#25AAA, IRGKangXi=0873.041, RSKangXi=117.10
25AAB CJK UNIFIED IDEOGRAPH-#25AAB, IRGKangXi=0873.041, RSKangXi=117.10
25AAC CJK UNIFIED IDEOGRAPH-#25AAC, IRGKangXi=0873.041, RSKangXi=117.10
25AAD CJK UNIFIED IDEOGRAPH-#25AAD, IRGKangXi=0873.071, RSKangXi=117.11
25AAE CJK UNIFIED IDEOGRAPH-#25AAE, IRGKangXi=0873.071, RSKangXi=117.11
25AAF CJK UNIFIED IDEOGRAPH-#25AAF, IRGKangXi=0873.100, RSKangXi=117.12
25AB0 CJK UNIFIED IDEOGRAPH-#25AB0, IRGKangXi=0873.130, RSKangXi=117.11
25AB1 CJK UNIFIED IDEOGRAPH-#25AB1, IRGKangXi=0873.140, RSKangXi=117.11
25AB2 CJK UNIFIED IDEOGRAPH-#25AB2, IRGKangXi=0873.141, RSKangXi=117.12
25AB3 CJK UNIFIED IDEOGRAPH-#25AB3, IRGKangXi=0873.141, RSKangXi=117.12
25AB4 CJK UNIFIED IDEOGRAPH-#25AB4, IRGKangXi=0873.141, RSKangXi=117.12
25AB5 CJK UNIFIED IDEOGRAPH-#25AB5, IRGKangXi=0873.141, RSKangXi=117.12
25AB6 CJK UNIFIED IDEOGRAPH-#25AB6, IRGKangXi=0873.141, RSKangXi=117.12
25AB7 CJK UNIFIED IDEOGRAPH-#25AB7, IRGKangXi=0873.141, RSKangXi=117.12
25AB8 CJK UNIFIED IDEOGRAPH-#25AB8, IRGKangXi=0873.141, RSKangXi=117.12
25AB9 CJK UNIFIED IDEOGRAPH-#25AB9, IRGKangXi=0873.141, RSKangXi=117.12
25ABA CJK UNIFIED IDEOGRAPH-#25ABA, IRGKangXi=0873.160, RSKangXi=117.14
25ABB CJK UNIFIED IDEOGRAPH-#25ABB, IRGKangXi=0873.180, RSKangXi=117.12
25ABC CJK UNIFIED IDEOGRAPH-#25ABC, IRGKangXi=0873.190, RSKangXi=117.13
25ABD CJK UNIFIED IDEOGRAPH-#25ABD, IRGKangXi=0873.200, RSKangXi=117.13
25ABE CJK UNIFIED IDEOGRAPH-#25ABE, IRGKangXi=0873.201, RSKangXi=117.13
25ABF CJK UNIFIED IDEOGRAPH-#25ABF, IRGKangXi=0873.201, RSKangXi=117.13
25AC0 CJK UNIFIED IDEOGRAPH-#25AC0, IRGKangXi=0873.201, RSKangXi=117.13
25AC1 CJK UNIFIED IDEOGRAPH-#25AC1, IRGKangXi=0873.201, RSKangXi=117.13
25AC2 CJK UNIFIED IDEOGRAPH-#25AC2, IRGKangXi=0873.201, RSKangXi=72.14
25AC3 CJK UNIFIED IDEOGRAPH-#25AC3, IRGKangXi=0873.201, RSKangXi=117.13
25AC4 CJK UNIFIED IDEOGRAPH-#25AC4, IRGKangXi=0873.201, RSKangXi=117.13
25AC5 CJK UNIFIED IDEOGRAPH-#25AC5, IRGKangXi=0873.240, RSKangXi=117.14
25AC6 CJK UNIFIED IDEOGRAPH-#25AC6, IRGKangXi=0873.241, RSKangXi=117.14
25AC7 CJK UNIFIED IDEOGRAPH-#25AC7, IRGKangXi=0873.241, RSKangXi=117.14
25AC8 CJK UNIFIED IDEOGRAPH-#25AC8, IRGKangXi=0873.250, RSKangXi=117.15
25AC9 CJK UNIFIED IDEOGRAPH-#25AC9, IRGKangXi=0873.260, RSKangXi=117.15
25ACA CJK UNIFIED IDEOGRAPH-#25ACA, IRGKangXi=0873.261, RSKangXi=117.15
25ACB CJK UNIFIED IDEOGRAPH-#25ACB, IRGKangXi=0873.261, RSKangXi=117.15
25ACC CJK UNIFIED IDEOGRAPH-#25ACC, IRGKangXi=0873.261, RSKangXi=117.15
25ACD CJK UNIFIED IDEOGRAPH-#25ACD, IRGKangXi=0873.261, RSKangXi=117.15
25ACE CJK UNIFIED IDEOGRAPH-#25ACE, IRGKangXi=0873.270, RSKangXi=117.16
25ACF CJK UNIFIED IDEOGRAPH-#25ACF, IRGKangXi=0873.271, RSKangXi=117.16
25AD0 CJK UNIFIED IDEOGRAPH-#25AD0, IRGKangXi=0873.280, RSKangXi=117.17
25AD1 CJK UNIFIED IDEOGRAPH-#25AD1, IRGKangXi=0873.291, RSKangXi=117.17
25AD2 CJK UNIFIED IDEOGRAPH-#25AD2, IRGKangXi=0873.291, RSKangXi=117.20
25AD3 CJK UNIFIED IDEOGRAPH-#25AD3, IRGKangXi=0873.291, RSKangXi=117.18
25AD4 CJK UNIFIED IDEOGRAPH-#25AD4, IRGKangXi=0873.291, RSKangXi=117.19
25AD5 CJK UNIFIED IDEOGRAPH-#25AD5, IRGKangXi=0873.291, RSKangXi=117.20
25AD6 CJK UNIFIED IDEOGRAPH-#25AD6, IRGKangXi=0873.291, RSKangXi=117.20
25AD7 CJK UNIFIED IDEOGRAPH-#25AD7, IRGKangXi=0877.011, RSKangXi=118.0
25AD8 CJK UNIFIED IDEOGRAPH-#25AD8, IRGKangXi=0877.011, RSKangXi=118.1
25AD9 CJK UNIFIED IDEOGRAPH-#25AD9, IRGKangXi=0877.030, RSKangXi=118.2
25ADA CJK UNIFIED IDEOGRAPH-#25ADA, IRGKangXi=0877.050, RSKangXi=118.2
25ADB CJK UNIFIED IDEOGRAPH-#25ADB, IRGKangXi=0877.060, RSKangXi=118.2
25ADC CJK UNIFIED IDEOGRAPH-#25ADC, IRGKangXi=0877.070, RSKangXi=118.2
25ADD CJK UNIFIED IDEOGRAPH-#25ADD, IRGKangXi=0877.090, RSKangXi=118.3
25ADE CJK UNIFIED IDEOGRAPH-#25ADE, IRGKangXi=0877.100, RSKangXi=118.3
25ADF CJK UNIFIED IDEOGRAPH-#25ADF, IRGKangXi=0878.010, RSKangXi=118.3
25AE0 CJK UNIFIED IDEOGRAPH-#25AE0, IRGKangXi=0878.050, RSKangXi=118.3
25AE1 CJK UNIFIED IDEOGRAPH-#25AE1, IRGKangXi=0878.060, RSKangXi=118.3
25AE2 CJK UNIFIED IDEOGRAPH-#25AE2, IRGKangXi=0878.080, RSKangXi=118.3
25AE3 CJK UNIFIED IDEOGRAPH-#25AE3, IRGKangXi=0878.081, RSKangXi=118.3
25AE4 CJK UNIFIED IDEOGRAPH-#25AE4, IRGKangXi=0878.081, RSKangXi=118.3
25AE5 CJK UNIFIED IDEOGRAPH-#25AE5, IRGKangXi=0878.081, RSKangXi=118.3
25AE6 CJK UNIFIED IDEOGRAPH-#25AE6, IRGKangXi=0878.081, RSKangXi=118.3
25AE7 CJK UNIFIED IDEOGRAPH-#25AE7, IRGKangXi=0878.081, RSKangXi=118.3
25AE8 CJK UNIFIED IDEOGRAPH-#25AE8, IRGKangXi=0878.081, RSKangXi=118.3
25AE9 CJK UNIFIED IDEOGRAPH-#25AE9, IRGKangXi=0878.081, RSKangXi=118.3
25AEA CJK UNIFIED IDEOGRAPH-#25AEA, IRGKangXi=0878.081, RSKangXi=118.3
25AEB CJK UNIFIED IDEOGRAPH-#25AEB, IRGKangXi=0878.081, RSKangXi=118.3
25AEC CJK UNIFIED IDEOGRAPH-#25AEC, IRGKangXi=0878.081, RSKangXi=118.3
25AED CJK UNIFIED IDEOGRAPH-#25AED, IRGKangXi=0878.081, RSKangXi=118.3
25AEE CJK UNIFIED IDEOGRAPH-#25AEE, IRGKangXi=0878.081, RSKangXi=118.3
25AEF CJK UNIFIED IDEOGRAPH-#25AEF, IRGKangXi=0878.120, RSKangXi=118.4
25AF0 CJK UNIFIED IDEOGRAPH-#25AF0, IRGKangXi=0878.190, RSKangXi=118.4
25AF1 CJK UNIFIED IDEOGRAPH-#25AF1, IRGKangXi=0878.220, RSKangXi=118.4, Def{to hoard}
25AF2 CJK UNIFIED IDEOGRAPH-#25AF2, IRGKangXi=0878.240, RSKangXi=118.4
25AF3 CJK UNIFIED IDEOGRAPH-#25AF3, IRGKangXi=0878.250, RSKangXi=118.4
25AF4 CJK UNIFIED IDEOGRAPH-#25AF4, IRGKangXi=0878.280, RSKangXi=118.4
25AF5 CJK UNIFIED IDEOGRAPH-#25AF5, IRGKangXi=0879.020, RSKangXi=118.4
25AF6 CJK UNIFIED IDEOGRAPH-#25AF6, IRGKangXi=0879.090, RSKangXi=118.4
25AF7 CJK UNIFIED IDEOGRAPH-#25AF7, IRGKangXi=0879.100, RSKangXi=118.4
25AF8 CJK UNIFIED IDEOGRAPH-#25AF8, IRGKangXi=0879.130, RSKangXi=118.4
25AF9 CJK UNIFIED IDEOGRAPH-#25AF9, IRGKangXi=0879.150, RSKangXi=118.4
25AFA CJK UNIFIED IDEOGRAPH-#25AFA, IRGKangXi=0879.160, RSKangXi=118.4
25AFB CJK UNIFIED IDEOGRAPH-#25AFB, IRGKangXi=0879.170, RSKangXi=118.4
25AFC CJK UNIFIED IDEOGRAPH-#25AFC, IRGKangXi=0879.180, RSKangXi=118.4
25AFD CJK UNIFIED IDEOGRAPH-#25AFD, IRGKangXi=0879.190, RSKangXi=118.4
25AFE CJK UNIFIED IDEOGRAPH-#25AFE, IRGKangXi=0879.191, RSKangXi=118.4
25AFF CJK UNIFIED IDEOGRAPH-#25AFF, IRGKangXi=0879.191, RSKangXi=118.4
25B00 CJK UNIFIED IDEOGRAPH-#25B00, IRGKangXi=0879.191, RSKangXi=118.4
25B01 CJK UNIFIED IDEOGRAPH-#25B01, IRGKangXi=0879.191, RSKangXi=118.4
25B02 CJK UNIFIED IDEOGRAPH-#25B02, IRGKangXi=0879.191, RSKangXi=118.4
25B03 CJK UNIFIED IDEOGRAPH-#25B03, IRGKangXi=0879.191, RSKangXi=118.4
25B04 CJK UNIFIED IDEOGRAPH-#25B04, IRGKangXi=0879.191, RSKangXi=118.4
25B05 CJK UNIFIED IDEOGRAPH-#25B05, IRGKangXi=0879.191, RSKangXi=118.4
25B06 CJK UNIFIED IDEOGRAPH-#25B06, IRGKangXi=0879.191, RSKangXi=118.4
25B07 CJK UNIFIED IDEOGRAPH-#25B07, IRGKangXi=0879.191, RSKangXi=118.4
25B08 CJK UNIFIED IDEOGRAPH-#25B08, IRGKangXi=0879.191, RSKangXi=118.4
25B09 CJK UNIFIED IDEOGRAPH-#25B09, IRGKangXi=0879.191, RSKangXi=118.4
25B0A CJK UNIFIED IDEOGRAPH-#25B0A, IRGKangXi=0879.191, RSKangXi=118.4
25B0B CJK UNIFIED IDEOGRAPH-#25B0B, IRGKangXi=0879.191, RSKangXi=118.4
25B0C CJK UNIFIED IDEOGRAPH-#25B0C, IRGKangXi=0879.200, RSKangXi=118.5
25B0D CJK UNIFIED IDEOGRAPH-#25B0D, IRGKangXi=0879.230, RSKangXi=118.5
25B0E CJK UNIFIED IDEOGRAPH-#25B0E, IRGKangXi=0879.240, RSKangXi=118.5
25B0F CJK UNIFIED IDEOGRAPH-#25B0F, IRGKangXi=0879.300, RSKangXi=118.5
25B10 CJK UNIFIED IDEOGRAPH-#25B10, IRGKangXi=0879.320, RSKangXi=118.5
25B11 CJK UNIFIED IDEOGRAPH-#25B11, IRGKangXi=0880.010, RSKangXi=118.5
25B12 CJK UNIFIED IDEOGRAPH-#25B12, IRGKangXi=0880.050, RSKangXi=118.5
25B13 CJK UNIFIED IDEOGRAPH-#25B13, IRGKangXi=0880.120, RSKangXi=118.5
25B14 CJK UNIFIED IDEOGRAPH-#25B14, IRGKangXi=0880.150, RSKangXi=118.5
25B15 CJK UNIFIED IDEOGRAPH-#25B15, IRGKangXi=0880.190, RSKangXi=118.5
25B16 CJK UNIFIED IDEOGRAPH-#25B16, IRGKangXi=0880.200, RSKangXi=118.5
25B17 CJK UNIFIED IDEOGRAPH-#25B17, IRGKangXi=0881.140, RSKangXi=118.5
25B18 CJK UNIFIED IDEOGRAPH-#25B18, IRGKangXi=0881.160, RSKangXi=118.5
25B19 CJK UNIFIED IDEOGRAPH-#25B19, IRGKangXi=0881.170, RSKangXi=118.5
25B1A CJK UNIFIED IDEOGRAPH-#25B1A, IRGKangXi=0881.190, RSKangXi=118.5
25B1B CJK UNIFIED IDEOGRAPH-#25B1B, IRGKangXi=0881.200, RSKangXi=118.5
25B1C CJK UNIFIED IDEOGRAPH-#25B1C, IRGKangXi=0881.230, RSKangXi=118.5
25B1D CJK UNIFIED IDEOGRAPH-#25B1D, IRGKangXi=0881.240, RSKangXi=118.5
25B1E CJK UNIFIED IDEOGRAPH-#25B1E, IRGKangXi=0881.250, RSKangXi=118.5
25B1F CJK UNIFIED IDEOGRAPH-#25B1F, IRGKangXi=0881.251, RSKangXi=118.5
25B20 CJK UNIFIED IDEOGRAPH-#25B20, IRGKangXi=0881.251, RSKangXi=118.5
25B21 CJK UNIFIED IDEOGRAPH-#25B21, IRGKangXi=0881.251, RSKangXi=118.5
25B22 CJK UNIFIED IDEOGRAPH-#25B22, IRGKangXi=0881.251, RSKangXi=118.5
25B23 CJK UNIFIED IDEOGRAPH-#25B23, IRGKangXi=0881.251, RSKangXi=118.5
25B24 CJK UNIFIED IDEOGRAPH-#25B24, IRGKangXi=0881.251, RSKangXi=118.5
25B25 CJK UNIFIED IDEOGRAPH-#25B25, IRGKangXi=0881.251, RSKangXi=118.5
25B26 CJK UNIFIED IDEOGRAPH-#25B26, IRGKangXi=0881.251, RSKangXi=118.5
25B27 CJK UNIFIED IDEOGRAPH-#25B27, IRGKangXi=0881.251, RSKangXi=118.5
25B28 CJK UNIFIED IDEOGRAPH-#25B28, IRGKangXi=0881.251, RSKangXi=118.5
25B29 CJK UNIFIED IDEOGRAPH-#25B29, IRGKangXi=0881.251, RSKangXi=118.5
25B2A CJK UNIFIED IDEOGRAPH-#25B2A, IRGKangXi=0882.080, RSKangXi=118.6
25B2B CJK UNIFIED IDEOGRAPH-#25B2B, IRGKangXi=0882.090, RSKangXi=118.6
25B2C CJK UNIFIED IDEOGRAPH-#25B2C, IRGKangXi=0882.120, RSKangXi=118.6
25B2D CJK UNIFIED IDEOGRAPH-#25B2D, IRGKangXi=0882.160, RSKangXi=118.6
25B2E CJK UNIFIED IDEOGRAPH-#25B2E, IRGKangXi=0882.230, RSKangXi=118.6
25B2F CJK UNIFIED IDEOGRAPH-#25B2F, IRGKangXi=0883.010, RSKangXi=118.6, Def{a basket}
25B30 CJK UNIFIED IDEOGRAPH-#25B30, IRGKangXi=0883.060, RSKangXi=118.6
25B31 CJK UNIFIED IDEOGRAPH-#25B31, IRGKangXi=0883.100, RSKangXi=118.6
25B32 CJK UNIFIED IDEOGRAPH-#25B32, IRGKangXi=0883.160, RSKangXi=118.6
25B33 CJK UNIFIED IDEOGRAPH-#25B33, IRGKangXi=0884.010, RSKangXi=118.6
25B34 CJK UNIFIED IDEOGRAPH-#25B34, IRGKangXi=0884.030, RSKangXi=118.6
25B35 CJK UNIFIED IDEOGRAPH-#25B35, IRGKangXi=0884.040, RSKangXi=118.6
25B36 CJK UNIFIED IDEOGRAPH-#25B36, IRGKangXi=0884.070, RSKangXi=118.6
25B37 CJK UNIFIED IDEOGRAPH-#25B37, IRGKangXi=0884.080, RSKangXi=118.6
25B38 CJK UNIFIED IDEOGRAPH-#25B38, IRGKangXi=0884.090, RSKangXi=118.6
25B39 CJK UNIFIED IDEOGRAPH-#25B39, IRGKangXi=0884.100, RSKangXi=118.6
25B3A CJK UNIFIED IDEOGRAPH-#25B3A, IRGKangXi=0884.130, RSKangXi=118.6
25B3B CJK UNIFIED IDEOGRAPH-#25B3B, IRGKangXi=0884.140, RSKangXi=118.6
25B3C CJK UNIFIED IDEOGRAPH-#25B3C, IRGKangXi=0884.160, RSKangXi=118.6
25B3D CJK UNIFIED IDEOGRAPH-#25B3D, IRGKangXi=0884.170, RSKangXi=118.6
25B3E CJK UNIFIED IDEOGRAPH-#25B3E, IRGKangXi=0884.180, RSKangXi=118.6
25B3F CJK UNIFIED IDEOGRAPH-#25B3F, IRGKangXi=0884.181, RSKangXi=118.5
25B40 CJK UNIFIED IDEOGRAPH-#25B40, IRGKangXi=0884.181, RSKangXi=118.6
25B41 CJK UNIFIED IDEOGRAPH-#25B41, IRGKangXi=0884.181, RSKangXi=118.6
25B42 CJK UNIFIED IDEOGRAPH-#25B42, IRGKangXi=0884.181, RSKangXi=118.6
25B43 CJK UNIFIED IDEOGRAPH-#25B43, IRGKangXi=0884.181, RSKangXi=118.6
25B44 CJK UNIFIED IDEOGRAPH-#25B44, IRGKangXi=0884.181, RSKangXi=118.6
25B45 CJK UNIFIED IDEOGRAPH-#25B45, IRGKangXi=0884.181, RSKangXi=118.6
25B46 CJK UNIFIED IDEOGRAPH-#25B46, IRGKangXi=0884.181, RSKangXi=118.6
25B47 CJK UNIFIED IDEOGRAPH-#25B47, IRGKangXi=0884.181, RSKangXi=118.6
25B48 CJK UNIFIED IDEOGRAPH-#25B48, IRGKangXi=0884.181, RSKangXi=118.6
25B49 CJK UNIFIED IDEOGRAPH-#25B49, IRGKangXi=0884.181, RSKangXi=118.6
25B4A CJK UNIFIED IDEOGRAPH-#25B4A, IRGKangXi=0884.181, RSKangXi=118.6
25B4B CJK UNIFIED IDEOGRAPH-#25B4B, IRGKangXi=0884.181, RSKangXi=118.6
25B4C CJK UNIFIED IDEOGRAPH-#25B4C, IRGKangXi=0884.181, RSKangXi=118.6
25B4D CJK UNIFIED IDEOGRAPH-#25B4D, IRGKangXi=0884.181, RSKangXi=118.6
25B4E CJK UNIFIED IDEOGRAPH-#25B4E, IRGKangXi=0884.181, RSKangXi=118.6
25B4F CJK UNIFIED IDEOGRAPH-#25B4F, IRGKangXi=0884.181, RSKangXi=118.6
25B50 CJK UNIFIED IDEOGRAPH-#25B50, IRGKangXi=0884.230, RSKangXi=118.7
25B51 CJK UNIFIED IDEOGRAPH-#25B51, IRGKangXi=0884.240, RSKangXi=118.7
25B52 CJK UNIFIED IDEOGRAPH-#25B52, IRGKangXi=0884.250, RSKangXi=118.7
25B53 CJK UNIFIED IDEOGRAPH-#25B53, IRGKangXi=0884.300, RSKangXi=118.7
25B54 CJK UNIFIED IDEOGRAPH-#25B54, IRGKangXi=0884.320, RSKangXi=118.7
25B55 CJK UNIFIED IDEOGRAPH-#25B55, IRGKangXi=0884.340, RSKangXi=118.7
25B56 CJK UNIFIED IDEOGRAPH-#25B56, IRGKangXi=0884.350, RSKangXi=118.7
25B57 CJK UNIFIED IDEOGRAPH-#25B57, IRGKangXi=0884.360, RSKangXi=118.7
25B58 CJK UNIFIED IDEOGRAPH-#25B58, IRGKangXi=0885.010, RSKangXi=118.7
25B59 CJK UNIFIED IDEOGRAPH-#25B59, IRGKangXi=0885.030, RSKangXi=118.7
25B5A CJK UNIFIED IDEOGRAPH-#25B5A, IRGKangXi=0885.050, RSKangXi=118.7
25B5B CJK UNIFIED IDEOGRAPH-#25B5B, IRGKangXi=0885.110, RSKangXi=118.7
25B5C CJK UNIFIED IDEOGRAPH-#25B5C, IRGKangXi=0885.160, RSKangXi=118.7
25B5D CJK UNIFIED IDEOGRAPH-#25B5D, IRGKangXi=0885.190, RSKangXi=118.7
25B5E CJK UNIFIED IDEOGRAPH-#25B5E, IRGKangXi=0885.210, RSKangXi=118.7
25B5F CJK UNIFIED IDEOGRAPH-#25B5F, IRGKangXi=0885.250, RSKangXi=118.7
25B60 CJK UNIFIED IDEOGRAPH-#25B60, IRGKangXi=0885.260, RSKangXi=118.7
25B61 CJK UNIFIED IDEOGRAPH-#25B61, IRGKangXi=0886.070, RSKangXi=118.7
25B62 CJK UNIFIED IDEOGRAPH-#25B62, IRGKangXi=0886.080, RSKangXi=118.7
25B63 CJK UNIFIED IDEOGRAPH-#25B63, IRGKangXi=0886.090, RSKangXi=118.7
25B64 CJK UNIFIED IDEOGRAPH-#25B64, IRGKangXi=0886.100, RSKangXi=118.7
25B65 CJK UNIFIED IDEOGRAPH-#25B65, IRGKangXi=0886.110, RSKangXi=118.7
25B66 CJK UNIFIED IDEOGRAPH-#25B66, IRGKangXi=0886.120, RSKangXi=118.7
25B67 CJK UNIFIED IDEOGRAPH-#25B67, IRGKangXi=0886.130, RSKangXi=118.7
25B68 CJK UNIFIED IDEOGRAPH-#25B68, IRGKangXi=0886.140, RSKangXi=118.7
25B69 CJK UNIFIED IDEOGRAPH-#25B69, IRGKangXi=0886.150, RSKangXi=118.7
25B6A CJK UNIFIED IDEOGRAPH-#25B6A, IRGKangXi=0886.160, RSKangXi=118.7
25B6B CJK UNIFIED IDEOGRAPH-#25B6B, IRGKangXi=0886.170, RSKangXi=118.7
25B6C CJK UNIFIED IDEOGRAPH-#25B6C, IRGKangXi=0886.180, RSKangXi=118.7
25B6D CJK UNIFIED IDEOGRAPH-#25B6D, IRGKangXi=0886.190, RSKangXi=118.7
25B6E CJK UNIFIED IDEOGRAPH-#25B6E, IRGKangXi=0886.200, RSKangXi=118.7
25B6F CJK UNIFIED IDEOGRAPH-#25B6F, IRGKangXi=0886.210, RSKangXi=118.7
25B70 CJK UNIFIED IDEOGRAPH-#25B70, IRGKangXi=0886.220, RSKangXi=118.7
25B71 CJK UNIFIED IDEOGRAPH-#25B71, IRGKangXi=0886.230, RSKangXi=118.7
25B72 CJK UNIFIED IDEOGRAPH-#25B72, IRGKangXi=0886.231, RSKangXi=118.7
25B73 CJK UNIFIED IDEOGRAPH-#25B73, IRGKangXi=0886.231, RSKangXi=118.7
25B74 CJK UNIFIED IDEOGRAPH-#25B74, IRGKangXi=0886.231, RSKangXi=118.7
25B75 CJK UNIFIED IDEOGRAPH-#25B75, IRGKangXi=0886.231, RSKangXi=118.7
25B76 CJK UNIFIED IDEOGRAPH-#25B76, IRGKangXi=0886.231, RSKangXi=118.7
25B77 CJK UNIFIED IDEOGRAPH-#25B77, IRGKangXi=0886.231, RSKangXi=118.7
25B78 CJK UNIFIED IDEOGRAPH-#25B78, IRGKangXi=0886.231, RSKangXi=118.7
25B79 CJK UNIFIED IDEOGRAPH-#25B79, IRGKangXi=0886.231, RSKangXi=118.7
25B7A CJK UNIFIED IDEOGRAPH-#25B7A, IRGKangXi=0886.231, RSKangXi=118.7
25B7B CJK UNIFIED IDEOGRAPH-#25B7B, IRGKangXi=0886.231, RSKangXi=118.7
25B7C CJK UNIFIED IDEOGRAPH-#25B7C, IRGKangXi=0886.231, RSKangXi=118.7
25B7D CJK UNIFIED IDEOGRAPH-#25B7D, IRGKangXi=0886.231, RSKangXi=118.7
25B7E CJK UNIFIED IDEOGRAPH-#25B7E, IRGKangXi=0886.231, RSKangXi=118.7
25B7F CJK UNIFIED IDEOGRAPH-#25B7F, IRGKangXi=0886.231, RSKangXi=118.7
25B80 CJK UNIFIED IDEOGRAPH-#25B80, IRGKangXi=0886.231, RSKangXi=118.7
25B81 CJK UNIFIED IDEOGRAPH-#25B81, IRGKangXi=0886.231, RSKangXi=118.7
25B82 CJK UNIFIED IDEOGRAPH-#25B82, IRGKangXi=0886.231, RSKangXi=118.7
25B83 CJK UNIFIED IDEOGRAPH-#25B83, IRGKangXi=0886.231, RSKangXi=118.7
25B84 CJK UNIFIED IDEOGRAPH-#25B84, IRGKangXi=0886.231, RSKangXi=118.7
25B85 CJK UNIFIED IDEOGRAPH-#25B85, IRGKangXi=0886.231, RSKangXi=118.7
25B86 CJK UNIFIED IDEOGRAPH-#25B86, IRGKangXi=0886.231, RSKangXi=118.7
25B87 CJK UNIFIED IDEOGRAPH-#25B87, IRGKangXi=0886.231, RSKangXi=118.7
25B88 CJK UNIFIED IDEOGRAPH-#25B88, IRGKangXi=0886.231, RSKangXi=118.7
25B89 CJK UNIFIED IDEOGRAPH-#25B89, IRGKangXi=0886.231, RSKangXi=118.7
25B8A CJK UNIFIED IDEOGRAPH-#25B8A, IRGKangXi=0886.231, RSKangXi=118.7
25B8B CJK UNIFIED IDEOGRAPH-#25B8B, IRGKangXi=0886.231, RSKangXi=118.7
25B8C CJK UNIFIED IDEOGRAPH-#25B8C, IRGKangXi=0886.231, RSKangXi=118.7
25B8D CJK UNIFIED IDEOGRAPH-#25B8D, IRGKangXi=0886.280, RSKangXi=118.8
25B8E CJK UNIFIED IDEOGRAPH-#25B8E, IRGKangXi=0886.300, RSKangXi=118.8
25B8F CJK UNIFIED IDEOGRAPH-#25B8F, IRGKangXi=0886.330, RSKangXi=118.8
25B90 CJK UNIFIED IDEOGRAPH-#25B90, IRGKangXi=0886.350, RSKangXi=118.8
25B91 CJK UNIFIED IDEOGRAPH-#25B91, IRGKangXi=0887.060, RSKangXi=118.8
25B92 CJK UNIFIED IDEOGRAPH-#25B92, IRGKangXi=0887.080, RSKangXi=118.8
25B93 CJK UNIFIED IDEOGRAPH-#25B93, IRGKangXi=0887.090, RSKangXi=118.8
25B94 CJK UNIFIED IDEOGRAPH-#25B94, IRGKangXi=0887.160, RSKangXi=118.8
25B95 CJK UNIFIED IDEOGRAPH-#25B95, IRGKangXi=0887.200, RSKangXi=118.8
25B96 CJK UNIFIED IDEOGRAPH-#25B96, IRGKangXi=0887.230, RSKangXi=118.8
25B97 CJK UNIFIED IDEOGRAPH-#25B97, IRGKangXi=0888.010, RSKangXi=118.8
25B98 CJK UNIFIED IDEOGRAPH-#25B98, IRGKangXi=0888.120, RSKangXi=118.8
25B99 CJK UNIFIED IDEOGRAPH-#25B99, IRGKangXi=0888.130, RSKangXi=118.8
25B9A CJK UNIFIED IDEOGRAPH-#25B9A, IRGKangXi=0888.140, RSKangXi=118.8
25B9B CJK UNIFIED IDEOGRAPH-#25B9B, IRGKangXi=0889.030, RSKangXi=118.8
25B9C CJK UNIFIED IDEOGRAPH-#25B9C, IRGKangXi=0889.040, RSKangXi=118.8
25B9D CJK UNIFIED IDEOGRAPH-#25B9D, IRGKangXi=0889.070, RSKangXi=118.8
25B9E CJK UNIFIED IDEOGRAPH-#25B9E, IRGKangXi=0889.100, RSKangXi=118.8
25B9F CJK UNIFIED IDEOGRAPH-#25B9F, IRGKangXi=0889.110, RSKangXi=118.8
25BA0 CJK UNIFIED IDEOGRAPH-#25BA0, IRGKangXi=0889.140, RSKangXi=118.8
25BA1 CJK UNIFIED IDEOGRAPH-#25BA1, IRGKangXi=0889.160, RSKangXi=118.8
25BA2 CJK UNIFIED IDEOGRAPH-#25BA2, IRGKangXi=0889.170, RSKangXi=118.8
25BA3 CJK UNIFIED IDEOGRAPH-#25BA3, IRGKangXi=0889.180, RSKangXi=118.8
25BA4 CJK UNIFIED IDEOGRAPH-#25BA4, IRGKangXi=0889.190, RSKangXi=118.8
25BA5 CJK UNIFIED IDEOGRAPH-#25BA5, IRGKangXi=0889.210, RSKangXi=118.8
25BA6 CJK UNIFIED IDEOGRAPH-#25BA6, IRGKangXi=0889.220, RSKangXi=118.8
25BA7 CJK UNIFIED IDEOGRAPH-#25BA7, IRGKangXi=0889.230, RSKangXi=118.8
25BA8 CJK UNIFIED IDEOGRAPH-#25BA8, IRGKangXi=0889.240, RSKangXi=118.8
25BA9 CJK UNIFIED IDEOGRAPH-#25BA9, IRGKangXi=0889.250, RSKangXi=118.8
25BAA CJK UNIFIED IDEOGRAPH-#25BAA, IRGKangXi=0889.260, RSKangXi=118.8
25BAB CJK UNIFIED IDEOGRAPH-#25BAB, IRGKangXi=0889.280, RSKangXi=118.8
25BAC CJK UNIFIED IDEOGRAPH-#25BAC, IRGKangXi=0889.290, RSKangXi=118.8
25BAD CJK UNIFIED IDEOGRAPH-#25BAD, IRGKangXi=0889.300, RSKangXi=118.8
25BAE CJK UNIFIED IDEOGRAPH-#25BAE, IRGKangXi=0889.310, RSKangXi=118.8
25BAF CJK UNIFIED IDEOGRAPH-#25BAF, IRGKangXi=0889.320, RSKangXi=118.8
25BB0 CJK UNIFIED IDEOGRAPH-#25BB0, IRGKangXi=0889.321, RSKangXi=118.8
25BB1 CJK UNIFIED IDEOGRAPH-#25BB1, IRGKangXi=0889.321, RSKangXi=118.8
25BB2 CJK UNIFIED IDEOGRAPH-#25BB2, IRGKangXi=0889.321, RSKangXi=118.8
25BB3 CJK UNIFIED IDEOGRAPH-#25BB3, IRGKangXi=0889.321, RSKangXi=118.8
25BB4 CJK UNIFIED IDEOGRAPH-#25BB4, IRGKangXi=0889.321, RSKangXi=118.8
25BB5 CJK UNIFIED IDEOGRAPH-#25BB5, IRGKangXi=0889.321, RSKangXi=118.8
25BB6 CJK UNIFIED IDEOGRAPH-#25BB6, IRGKangXi=0889.321, RSKangXi=118.8
25BB7 CJK UNIFIED IDEOGRAPH-#25BB7, IRGKangXi=0889.321, RSKangXi=118.8
25BB8 CJK UNIFIED IDEOGRAPH-#25BB8, IRGKangXi=0889.321, RSKangXi=118.8
25BB9 CJK UNIFIED IDEOGRAPH-#25BB9, IRGKangXi=0889.321, RSKangXi=118.8
25BBA CJK UNIFIED IDEOGRAPH-#25BBA, IRGKangXi=0889.321, RSKangXi=118.8
25BBB CJK UNIFIED IDEOGRAPH-#25BBB, IRGKangXi=0889.321, RSKangXi=118.8
25BBC CJK UNIFIED IDEOGRAPH-#25BBC, IRGKangXi=0889.321, RSKangXi=118.8
25BBD CJK UNIFIED IDEOGRAPH-#25BBD, IRGKangXi=0889.321, RSKangXi=118.8
25BBE CJK UNIFIED IDEOGRAPH-#25BBE, IRGKangXi=0889.321, RSKangXi=118.5
25BBF CJK UNIFIED IDEOGRAPH-#25BBF, IRGKangXi=0889.321, RSKangXi=118.8
25BC0 CJK UNIFIED IDEOGRAPH-#25BC0, IRGKangXi=0889.321, RSKangXi=118.8
25BC1 CJK UNIFIED IDEOGRAPH-#25BC1, IRGKangXi=0889.321, RSKangXi=118.8
25BC2 CJK UNIFIED IDEOGRAPH-#25BC2, IRGKangXi=0889.321, RSKangXi=118.8
25BC3 CJK UNIFIED IDEOGRAPH-#25BC3, IRGKangXi=0889.321, RSKangXi=118.8
25BC4 CJK UNIFIED IDEOGRAPH-#25BC4, IRGKangXi=0889.321, RSKangXi=118.8
25BC5 CJK UNIFIED IDEOGRAPH-#25BC5, IRGKangXi=0889.321, RSKangXi=118.8
25BC6 CJK UNIFIED IDEOGRAPH-#25BC6, IRGKangXi=0889.321, RSKangXi=118.8
25BC7 CJK UNIFIED IDEOGRAPH-#25BC7, IRGKangXi=0889.321, RSKangXi=118.8
25BC8 CJK UNIFIED IDEOGRAPH-#25BC8, IRGKangXi=0889.321, RSKangXi=118.8
25BC9 CJK UNIFIED IDEOGRAPH-#25BC9, IRGKangXi=0889.321, RSKangXi=118.8
25BCA CJK UNIFIED IDEOGRAPH-#25BCA, IRGKangXi=0889.321, RSKangXi=118.8
25BCB CJK UNIFIED IDEOGRAPH-#25BCB, IRGKangXi=0889.321, RSKangXi=118.8
25BCC CJK UNIFIED IDEOGRAPH-#25BCC, IRGKangXi=0889.321, RSKangXi=118.8
25BCD CJK UNIFIED IDEOGRAPH-#25BCD, IRGKangXi=0889.321, RSKangXi=118.8
25BCE CJK UNIFIED IDEOGRAPH-#25BCE, IRGKangXi=0889.321, RSKangXi=118.8
25BCF CJK UNIFIED IDEOGRAPH-#25BCF, IRGKangXi=0889.321, RSKangXi=118.8
25BD0 CJK UNIFIED IDEOGRAPH-#25BD0, IRGKangXi=0889.321, RSKangXi=118.8
25BD1 CJK UNIFIED IDEOGRAPH-#25BD1, IRGKangXi=0890.010, RSKangXi=118.9
25BD2 CJK UNIFIED IDEOGRAPH-#25BD2, IRGKangXi=0890.030, RSKangXi=118.9
25BD3 CJK UNIFIED IDEOGRAPH-#25BD3, IRGKangXi=0890.040, RSKangXi=118.9
25BD4 CJK UNIFIED IDEOGRAPH-#25BD4, IRGKangXi=0890.050, RSKangXi=118.9
25BD5 CJK UNIFIED IDEOGRAPH-#25BD5, IRGKangXi=0890.080, RSKangXi=118.9
25BD6 CJK UNIFIED IDEOGRAPH-#25BD6, IRGKangXi=0890.110, RSKangXi=118.9
25BD7 CJK UNIFIED IDEOGRAPH-#25BD7, IRGKangXi=0890.120, RSKangXi=118.9
25BD8 CJK UNIFIED IDEOGRAPH-#25BD8, IRGKangXi=0890.170, RSKangXi=118.9
25BD9 CJK UNIFIED IDEOGRAPH-#25BD9, IRGKangXi=0890.180, RSKangXi=118.9
25BDA CJK UNIFIED IDEOGRAPH-#25BDA, IRGKangXi=0891.010, RSKangXi=118.9
25BDB CJK UNIFIED IDEOGRAPH-#25BDB, IRGKangXi=0891.020, RSKangXi=118.9
25BDC CJK UNIFIED IDEOGRAPH-#25BDC, IRGKangXi=0891.100, RSKangXi=118.9
25BDD CJK UNIFIED IDEOGRAPH-#25BDD, IRGKangXi=0891.130, RSKangXi=118.9
25BDE CJK UNIFIED IDEOGRAPH-#25BDE, IRGKangXi=0891.140, RSKangXi=118.9
25BDF CJK UNIFIED IDEOGRAPH-#25BDF, IRGKangXi=0891.150, RSKangXi=118.9
25BE0 CJK UNIFIED IDEOGRAPH-#25BE0, IRGKangXi=0891.160, RSKangXi=118.9
25BE1 CJK UNIFIED IDEOGRAPH-#25BE1, IRGKangXi=0891.170, RSKangXi=118.9
25BE2 CJK UNIFIED IDEOGRAPH-#25BE2, IRGKangXi=0891.180, RSKangXi=118.9
25BE3 CJK UNIFIED IDEOGRAPH-#25BE3, IRGKangXi=0891.190, RSKangXi=118.9
25BE4 CJK UNIFIED IDEOGRAPH-#25BE4, IRGKangXi=0891.210, RSKangXi=118.9
25BE5 CJK UNIFIED IDEOGRAPH-#25BE5, IRGKangXi=0891.230, RSKangXi=118.9
25BE6 CJK UNIFIED IDEOGRAPH-#25BE6, IRGKangXi=0892.030, RSKangXi=118.9
25BE7 CJK UNIFIED IDEOGRAPH-#25BE7, IRGKangXi=0892.040, RSKangXi=118.9
25BE8 CJK UNIFIED IDEOGRAPH-#25BE8, IRGKangXi=0892.050, RSKangXi=118.9
25BE9 CJK UNIFIED IDEOGRAPH-#25BE9, IRGKangXi=0892.160, RSKangXi=118.9
25BEA CJK UNIFIED IDEOGRAPH-#25BEA, IRGKangXi=0892.170, RSKangXi=118.9
25BEB CJK UNIFIED IDEOGRAPH-#25BEB, IRGKangXi=0892.190, RSKangXi=118.9
25BEC CJK UNIFIED IDEOGRAPH-#25BEC, IRGKangXi=0892.210, RSKangXi=118.9
25BED CJK UNIFIED IDEOGRAPH-#25BED, IRGKangXi=0892.250, RSKangXi=118.9
25BEE CJK UNIFIED IDEOGRAPH-#25BEE, IRGKangXi=0892.260, RSKangXi=118.9
25BEF CJK UNIFIED IDEOGRAPH-#25BEF, IRGKangXi=0892.270, RSKangXi=118.9
25BF0 CJK UNIFIED IDEOGRAPH-#25BF0, IRGKangXi=0893.050, RSKangXi=118.9
25BF1 CJK UNIFIED IDEOGRAPH-#25BF1, IRGKangXi=0893.060, RSKangXi=118.9
25BF2 CJK UNIFIED IDEOGRAPH-#25BF2, IRGKangXi=0893.090, RSKangXi=118.9
25BF3 CJK UNIFIED IDEOGRAPH-#25BF3, IRGKangXi=0893.100, RSKangXi=118.9
25BF4 CJK UNIFIED IDEOGRAPH-#25BF4, IRGKangXi=0893.110, RSKangXi=118.9
25BF5 CJK UNIFIED IDEOGRAPH-#25BF5, IRGKangXi=0893.120, RSKangXi=118.9
25BF6 CJK UNIFIED IDEOGRAPH-#25BF6, IRGKangXi=0893.140, RSKangXi=118.9
25BF7 CJK UNIFIED IDEOGRAPH-#25BF7, IRGKangXi=0893.150, RSKangXi=118.9
25BF8 CJK UNIFIED IDEOGRAPH-#25BF8, IRGKangXi=0893.160, RSKangXi=118.9
25BF9 CJK UNIFIED IDEOGRAPH-#25BF9, IRGKangXi=0893.180, RSKangXi=118.9
25BFA CJK UNIFIED IDEOGRAPH-#25BFA, IRGKangXi=0893.210, RSKangXi=118.9
25BFB CJK UNIFIED IDEOGRAPH-#25BFB, IRGKangXi=0893.230, RSKangXi=118.9
25BFC CJK UNIFIED IDEOGRAPH-#25BFC, IRGKangXi=0893.240, RSKangXi=118.9
25BFD CJK UNIFIED IDEOGRAPH-#25BFD, IRGKangXi=0893.250, RSKangXi=118.9
25BFE CJK UNIFIED IDEOGRAPH-#25BFE, IRGKangXi=0893.270, RSKangXi=118.9
25BFF CJK UNIFIED IDEOGRAPH-#25BFF, IRGKangXi=0893.280, RSKangXi=118.9
25C00 CJK UNIFIED IDEOGRAPH-#25C00, IRGKangXi=0893.291, RSKangXi=118.9
25C01 CJK UNIFIED IDEOGRAPH-#25C01, IRGKangXi=0893.291, RSKangXi=118.9
25C02 CJK UNIFIED IDEOGRAPH-#25C02, IRGKangXi=0893.291, RSKangXi=118.9
25C03 CJK UNIFIED IDEOGRAPH-#25C03, IRGKangXi=0893.291, RSKangXi=118.9
25C04 CJK UNIFIED IDEOGRAPH-#25C04, IRGKangXi=0893.291, RSKangXi=118.9
25C05 CJK UNIFIED IDEOGRAPH-#25C05, IRGKangXi=0893.291, RSKangXi=118.9
25C06 CJK UNIFIED IDEOGRAPH-#25C06, IRGKangXi=0893.291, RSKangXi=118.9
25C07 CJK UNIFIED IDEOGRAPH-#25C07, IRGKangXi=0893.291, RSKangXi=118.9
25C08 CJK UNIFIED IDEOGRAPH-#25C08, IRGKangXi=0893.291, RSKangXi=118.9
25C09 CJK UNIFIED IDEOGRAPH-#25C09, IRGKangXi=0893.291, RSKangXi=118.9
25C0A CJK UNIFIED IDEOGRAPH-#25C0A, IRGKangXi=0893.291, RSKangXi=118.9
25C0B CJK UNIFIED IDEOGRAPH-#25C0B, IRGKangXi=0893.291, RSKangXi=118.9
25C0C CJK UNIFIED IDEOGRAPH-#25C0C, IRGKangXi=0893.291, RSKangXi=118.9
25C0D CJK UNIFIED IDEOGRAPH-#25C0D, IRGKangXi=0893.291, RSKangXi=118.9
25C0E CJK UNIFIED IDEOGRAPH-#25C0E, IRGKangXi=0893.291, RSKangXi=118.9
25C0F CJK UNIFIED IDEOGRAPH-#25C0F, IRGKangXi=0893.291, RSKangXi=118.9
25C10 CJK UNIFIED IDEOGRAPH-#25C10, IRGKangXi=0893.291, RSKangXi=118.9
25C11 CJK UNIFIED IDEOGRAPH-#25C11, IRGKangXi=0893.291, RSKangXi=118.9
25C12 CJK UNIFIED IDEOGRAPH-#25C12, IRGKangXi=0893.291, RSKangXi=118.9
25C13 CJK UNIFIED IDEOGRAPH-#25C13, IRGKangXi=0893.291, RSKangXi=118.9
25C14 CJK UNIFIED IDEOGRAPH-#25C14, IRGKangXi=0893.291, RSKangXi=118.9
25C15 CJK UNIFIED IDEOGRAPH-#25C15, IRGKangXi=0893.291, RSKangXi=118.9
25C16 CJK UNIFIED IDEOGRAPH-#25C16, IRGKangXi=0893.291, RSKangXi=118.9
25C17 CJK UNIFIED IDEOGRAPH-#25C17, IRGKangXi=0893.291, RSKangXi=118.9
25C18 CJK UNIFIED IDEOGRAPH-#25C18, IRGKangXi=0893.310, RSKangXi=118.10
25C19 CJK UNIFIED IDEOGRAPH-#25C19, IRGKangXi=0893.330, RSKangXi=118.10
25C1A CJK UNIFIED IDEOGRAPH-#25C1A, IRGKangXi=0893.340, RSKangXi=118.10
25C1B CJK UNIFIED IDEOGRAPH-#25C1B, IRGKangXi=0893.350, RSKangXi=118.10
25C1C CJK UNIFIED IDEOGRAPH-#25C1C, IRGKangXi=0893.360, RSKangXi=118.10
25C1D CJK UNIFIED IDEOGRAPH-#25C1D, IRGKangXi=0893.380, RSKangXi=118.10
25C1E CJK UNIFIED IDEOGRAPH-#25C1E, IRGKangXi=0893.410, RSKangXi=118.10
25C1F CJK UNIFIED IDEOGRAPH-#25C1F, IRGKangXi=0893.420, RSKangXi=118.10
25C20 CJK UNIFIED IDEOGRAPH-#25C20, IRGKangXi=0893.430, RSKangXi=118.10
25C21 CJK UNIFIED IDEOGRAPH-#25C21, IRGKangXi=0894.010, RSKangXi=118.10
25C22 CJK UNIFIED IDEOGRAPH-#25C22, IRGKangXi=0894.020, RSKangXi=118.10
25C23 CJK UNIFIED IDEOGRAPH-#25C23, IRGKangXi=0894.070, RSKangXi=118.10
25C24 CJK UNIFIED IDEOGRAPH-#25C24, IRGKangXi=0894.090, RSKangXi=118.10
25C25 CJK UNIFIED IDEOGRAPH-#25C25, IRGKangXi=0894.120, RSKangXi=118.10
25C26 CJK UNIFIED IDEOGRAPH-#25C26, IRGKangXi=0894.140, RSKangXi=118.10
25C27 CJK UNIFIED IDEOGRAPH-#25C27, IRGKangXi=0894.170, RSKangXi=118.10
25C28 CJK UNIFIED IDEOGRAPH-#25C28, IRGKangXi=0894.220, RSKangXi=118.10
25C29 CJK UNIFIED IDEOGRAPH-#25C29, IRGKangXi=0894.230, RSKangXi=118.10
25C2A CJK UNIFIED IDEOGRAPH-#25C2A, IRGKangXi=0894.250, RSKangXi=118.10
25C2B CJK UNIFIED IDEOGRAPH-#25C2B, IRGKangXi=0894.260, RSKangXi=118.10
25C2C CJK UNIFIED IDEOGRAPH-#25C2C, IRGKangXi=0894.270, RSKangXi=118.10
25C2D CJK UNIFIED IDEOGRAPH-#25C2D, IRGKangXi=0894.310, RSKangXi=118.10
25C2E CJK UNIFIED IDEOGRAPH-#25C2E, IRGKangXi=0894.320, RSKangXi=118.10
25C2F CJK UNIFIED IDEOGRAPH-#25C2F, IRGKangXi=0894.330, RSKangXi=118.10
25C30 CJK UNIFIED IDEOGRAPH-#25C30, IRGKangXi=0894.350, RSKangXi=118.10
25C31 CJK UNIFIED IDEOGRAPH-#25C31, IRGKangXi=0894.360, RSKangXi=118.10
25C32 CJK UNIFIED IDEOGRAPH-#25C32, IRGKangXi=0895.030, RSKangXi=118.10
25C33 CJK UNIFIED IDEOGRAPH-#25C33, IRGKangXi=0895.090, RSKangXi=118.10
25C34 CJK UNIFIED IDEOGRAPH-#25C34, IRGKangXi=0895.100, RSKangXi=118.10
25C35 CJK UNIFIED IDEOGRAPH-#25C35, IRGKangXi=0895.120, RSKangXi=118.10
25C36 CJK UNIFIED IDEOGRAPH-#25C36, IRGKangXi=0895.130, RSKangXi=118.10
25C37 CJK UNIFIED IDEOGRAPH-#25C37, IRGKangXi=0895.140, RSKangXi=118.10
25C38 CJK UNIFIED IDEOGRAPH-#25C38, IRGKangXi=0895.150, RSKangXi=118.10
25C39 CJK UNIFIED IDEOGRAPH-#25C39, IRGKangXi=0895.160, RSKangXi=118.10
25C3A CJK UNIFIED IDEOGRAPH-#25C3A, IRGKangXi=0895.170, RSKangXi=118.10
25C3B CJK UNIFIED IDEOGRAPH-#25C3B, IRGKangXi=0895.210, RSKangXi=118.10
25C3C CJK UNIFIED IDEOGRAPH-#25C3C, IRGKangXi=0895.220, RSKangXi=118.10
25C3D CJK UNIFIED IDEOGRAPH-#25C3D, IRGKangXi=0895.230, RSKangXi=118.10
25C3E CJK UNIFIED IDEOGRAPH-#25C3E, IRGKangXi=0895.240, RSKangXi=118.10
25C3F CJK UNIFIED IDEOGRAPH-#25C3F, IRGKangXi=0895.250, RSKangXi=118.10
25C40 CJK UNIFIED IDEOGRAPH-#25C40, IRGKangXi=0895.260, RSKangXi=118.10
25C41 CJK UNIFIED IDEOGRAPH-#25C41, IRGKangXi=0895.270, RSKangXi=118.10
25C42 CJK UNIFIED IDEOGRAPH-#25C42, IRGKangXi=0895.280, RSKangXi=118.10
25C43 CJK UNIFIED IDEOGRAPH-#25C43, IRGKangXi=0895.300, RSKangXi=118.10
25C44 CJK UNIFIED IDEOGRAPH-#25C44, IRGKangXi=0895.310, RSKangXi=118.10
25C45 CJK UNIFIED IDEOGRAPH-#25C45, IRGKangXi=0895.320, RSKangXi=118.10
25C46 CJK UNIFIED IDEOGRAPH-#25C46, IRGKangXi=0895.330, RSKangXi=118.10
25C47 CJK UNIFIED IDEOGRAPH-#25C47, IRGKangXi=0895.340, RSKangXi=118.10
25C48 CJK UNIFIED IDEOGRAPH-#25C48, IRGKangXi=0895.341, RSKangXi=118.10
25C49 CJK UNIFIED IDEOGRAPH-#25C49, IRGKangXi=0895.341, RSKangXi=118.10
25C4A CJK UNIFIED IDEOGRAPH-#25C4A, IRGKangXi=0895.341, RSKangXi=118.10
25C4B CJK UNIFIED IDEOGRAPH-#25C4B, IRGKangXi=0895.341, RSKangXi=118.10
25C4C CJK UNIFIED IDEOGRAPH-#25C4C, IRGKangXi=0895.341, RSKangXi=118.10
25C4D CJK UNIFIED IDEOGRAPH-#25C4D, IRGKangXi=0895.341, RSKangXi=118.10
25C4E CJK UNIFIED IDEOGRAPH-#25C4E, IRGKangXi=0895.341, RSKangXi=118.10
25C4F CJK UNIFIED IDEOGRAPH-#25C4F, IRGKangXi=0895.341, RSKangXi=118.10
25C50 CJK UNIFIED IDEOGRAPH-#25C50, IRGKangXi=0895.341, RSKangXi=118.10
25C51 CJK UNIFIED IDEOGRAPH-#25C51, IRGKangXi=0895.341, RSKangXi=118.10
25C52 CJK UNIFIED IDEOGRAPH-#25C52, IRGKangXi=0895.341, RSKangXi=118.10
25C53 CJK UNIFIED IDEOGRAPH-#25C53, IRGKangXi=0895.341, RSKangXi=118.10
25C54 CJK UNIFIED IDEOGRAPH-#25C54, IRGKangXi=0895.341, RSKangXi=118.10
25C55 CJK UNIFIED IDEOGRAPH-#25C55, IRGKangXi=0895.341, RSKangXi=118.10
25C56 CJK UNIFIED IDEOGRAPH-#25C56, IRGKangXi=0895.341, RSKangXi=118.10
25C57 CJK UNIFIED IDEOGRAPH-#25C57, IRGKangXi=0895.341, RSKangXi=118.10
25C58 CJK UNIFIED IDEOGRAPH-#25C58, IRGKangXi=0895.341, RSKangXi=118.10
25C59 CJK UNIFIED IDEOGRAPH-#25C59, IRGKangXi=0895.341, RSKangXi=118.10
25C5A CJK UNIFIED IDEOGRAPH-#25C5A, IRGKangXi=0895.341, RSKangXi=118.10
25C5B CJK UNIFIED IDEOGRAPH-#25C5B, IRGKangXi=0895.341, RSKangXi=118.10
25C5C CJK UNIFIED IDEOGRAPH-#25C5C, IRGKangXi=0895.341, RSKangXi=118.10
25C5D CJK UNIFIED IDEOGRAPH-#25C5D, IRGKangXi=0895.341, RSKangXi=118.10
25C5E CJK UNIFIED IDEOGRAPH-#25C5E, IRGKangXi=0895.341, RSKangXi=118.10
25C5F CJK UNIFIED IDEOGRAPH-#25C5F, IRGKangXi=0895.341, RSKangXi=118.10
25C60 CJK UNIFIED IDEOGRAPH-#25C60, IRGKangXi=0895.341, RSKangXi=118.10
25C61 CJK UNIFIED IDEOGRAPH-#25C61, IRGKangXi=0895.341, RSKangXi=118.10
25C62 CJK UNIFIED IDEOGRAPH-#25C62, IRGKangXi=0895.341, RSKangXi=118.10
25C63 CJK UNIFIED IDEOGRAPH-#25C63, IRGKangXi=0895.341, RSKangXi=118.10
25C64 CJK UNIFIED IDEOGRAPH-#25C64, IRGKangXi=0895.341, RSKangXi=118.10
25C65 CJK UNIFIED IDEOGRAPH-#25C65, IRGKangXi=0895.341, RSKangXi=118.10
25C66 CJK UNIFIED IDEOGRAPH-#25C66, IRGKangXi=0895.341, RSKangXi=118.10
25C67 CJK UNIFIED IDEOGRAPH-#25C67, IRGKangXi=0895.341, RSKangXi=118.10
25C68 CJK UNIFIED IDEOGRAPH-#25C68, IRGKangXi=0895.341, RSKangXi=118.10
25C69 CJK UNIFIED IDEOGRAPH-#25C69, IRGKangXi=0895.341, RSKangXi=118.10
25C6A CJK UNIFIED IDEOGRAPH-#25C6A, IRGKangXi=0895.341, RSKangXi=118.10
25C6B CJK UNIFIED IDEOGRAPH-#25C6B, IRGKangXi=0895.341, RSKangXi=118.10
25C6C CJK UNIFIED IDEOGRAPH-#25C6C, IRGKangXi=0895.341, RSKangXi=118.10
25C6D CJK UNIFIED IDEOGRAPH-#25C6D, IRGKangXi=0895.341, RSKangXi=118.10
25C6E CJK UNIFIED IDEOGRAPH-#25C6E, IRGKangXi=0895.341, RSKangXi=118.10
25C6F CJK UNIFIED IDEOGRAPH-#25C6F, IRGKangXi=0895.341, RSKangXi=118.10
25C70 CJK UNIFIED IDEOGRAPH-#25C70, IRGKangXi=0895.341, RSKangXi=118.10
25C71 CJK UNIFIED IDEOGRAPH-#25C71, IRGKangXi=0895.341, RSKangXi=118.10
25C72 CJK UNIFIED IDEOGRAPH-#25C72, IRGKangXi=0895.341, RSKangXi=118.10
25C73 CJK UNIFIED IDEOGRAPH-#25C73, IRGKangXi=0895.341, RSKangXi=118.10
25C74 CJK UNIFIED IDEOGRAPH-#25C74, IRGKangXi=0895.341, RSKangXi=118.10
25C75 CJK UNIFIED IDEOGRAPH-#25C75, IRGKangXi=0895.410, RSKangXi=118.11
25C76 CJK UNIFIED IDEOGRAPH-#25C76, IRGKangXi=0896.030, RSKangXi=118.11
25C77 CJK UNIFIED IDEOGRAPH-#25C77, IRGKangXi=0896.040, RSKangXi=118.11
25C78 CJK UNIFIED IDEOGRAPH-#25C78, IRGKangXi=0896.050, RSKangXi=118.11
25C79 CJK UNIFIED IDEOGRAPH-#25C79, IRGKangXi=0896.060, RSKangXi=118.11
25C7A CJK UNIFIED IDEOGRAPH-#25C7A, IRGKangXi=0896.090, RSKangXi=118.11
25C7B CJK UNIFIED IDEOGRAPH-#25C7B, IRGKangXi=0896.100, RSKangXi=118.11
25C7C CJK UNIFIED IDEOGRAPH-#25C7C, IRGKangXi=0896.150, RSKangXi=118.11
25C7D CJK UNIFIED IDEOGRAPH-#25C7D, IRGKangXi=0897.010, RSKangXi=118.11
25C7E CJK UNIFIED IDEOGRAPH-#25C7E, IRGKangXi=0897.040, RSKangXi=118.11
25C7F CJK UNIFIED IDEOGRAPH-#25C7F, IRGKangXi=0897.060, RSKangXi=118.11
25C80 CJK UNIFIED IDEOGRAPH-#25C80, IRGKangXi=0897.080, RSKangXi=118.11
25C81 CJK UNIFIED IDEOGRAPH-#25C81, IRGKangXi=0897.110, RSKangXi=118.11
25C82 CJK UNIFIED IDEOGRAPH-#25C82, IRGKangXi=0897.120, RSKangXi=118.11
25C83 CJK UNIFIED IDEOGRAPH-#25C83, IRGKangXi=0897.150, RSKangXi=118.11
25C84 CJK UNIFIED IDEOGRAPH-#25C84, IRGKangXi=0897.180, RSKangXi=118.11
25C85 CJK UNIFIED IDEOGRAPH-#25C85, IRGKangXi=0897.190, RSKangXi=118.11
25C86 CJK UNIFIED IDEOGRAPH-#25C86, IRGKangXi=0897.200, RSKangXi=118.11
25C87 CJK UNIFIED IDEOGRAPH-#25C87, IRGKangXi=0897.210, RSKangXi=118.11
25C88 CJK UNIFIED IDEOGRAPH-#25C88, IRGKangXi=0897.220, RSKangXi=118.11
25C89 CJK UNIFIED IDEOGRAPH-#25C89, IRGKangXi=0897.250, RSKangXi=118.11
25C8A CJK UNIFIED IDEOGRAPH-#25C8A, IRGKangXi=0897.300, RSKangXi=118.11
25C8B CJK UNIFIED IDEOGRAPH-#25C8B, IRGKangXi=0897.310, RSKangXi=118.11
25C8C CJK UNIFIED IDEOGRAPH-#25C8C, IRGKangXi=0897.320, RSKangXi=118.11
25C8D CJK UNIFIED IDEOGRAPH-#25C8D, IRGKangXi=0897.340, RSKangXi=118.11
25C8E CJK UNIFIED IDEOGRAPH-#25C8E, IRGKangXi=0898.020, RSKangXi=118.11
25C8F CJK UNIFIED IDEOGRAPH-#25C8F, IRGKangXi=0898.030, RSKangXi=118.11
25C90 CJK UNIFIED IDEOGRAPH-#25C90, IRGKangXi=0898.050, RSKangXi=118.11
25C91 CJK UNIFIED IDEOGRAPH-#25C91, IRGKangXi=0898.060, RSKangXi=118.11
25C92 CJK UNIFIED IDEOGRAPH-#25C92, IRGKangXi=0898.070, RSKangXi=118.11
25C93 CJK UNIFIED IDEOGRAPH-#25C93, IRGKangXi=0898.090, RSKangXi=118.11
25C94 CJK UNIFIED IDEOGRAPH-#25C94, IRGKangXi=0898.100, RSKangXi=118.11
25C95 CJK UNIFIED IDEOGRAPH-#25C95, IRGKangXi=0898.110, RSKangXi=118.11
25C96 CJK UNIFIED IDEOGRAPH-#25C96, IRGKangXi=0898.120, RSKangXi=118.11
25C97 CJK UNIFIED IDEOGRAPH-#25C97, IRGKangXi=0898.130, RSKangXi=118.11
25C98 CJK UNIFIED IDEOGRAPH-#25C98, IRGKangXi=0898.140, RSKangXi=118.11
25C99 CJK UNIFIED IDEOGRAPH-#25C99, IRGKangXi=0898.150, RSKangXi=118.11
25C9A CJK UNIFIED IDEOGRAPH-#25C9A, IRGKangXi=0898.160, RSKangXi=118.11
25C9B CJK UNIFIED IDEOGRAPH-#25C9B, IRGKangXi=0898.170, RSKangXi=118.11
25C9C CJK UNIFIED IDEOGRAPH-#25C9C, IRGKangXi=0898.180, RSKangXi=118.11
25C9D CJK UNIFIED IDEOGRAPH-#25C9D, IRGKangXi=0898.190, RSKangXi=118.11
25C9E CJK UNIFIED IDEOGRAPH-#25C9E, IRGKangXi=0898.200, RSKangXi=118.11
25C9F CJK UNIFIED IDEOGRAPH-#25C9F, IRGKangXi=0898.210, RSKangXi=118.11
25CA0 CJK UNIFIED IDEOGRAPH-#25CA0, IRGKangXi=0898.220, RSKangXi=118.11
25CA1 CJK UNIFIED IDEOGRAPH-#25CA1, IRGKangXi=0898.230, RSKangXi=118.11
25CA2 CJK UNIFIED IDEOGRAPH-#25CA2, IRGKangXi=0898.250, RSKangXi=118.11
25CA3 CJK UNIFIED IDEOGRAPH-#25CA3, IRGKangXi=0898.260, RSKangXi=118.11
25CA4 CJK UNIFIED IDEOGRAPH-#25CA4, IRGKangXi=0898.270, RSKangXi=118.11
25CA5 CJK UNIFIED IDEOGRAPH-#25CA5, IRGKangXi=0898.290, RSKangXi=118.11
25CA6 CJK UNIFIED IDEOGRAPH-#25CA6, IRGKangXi=0898.300, RSKangXi=118.11
25CA7 CJK UNIFIED IDEOGRAPH-#25CA7, IRGKangXi=0898.310, RSKangXi=118.11
25CA8 CJK UNIFIED IDEOGRAPH-#25CA8, IRGKangXi=0898.320, RSKangXi=118.11
25CA9 CJK UNIFIED IDEOGRAPH-#25CA9, IRGKangXi=0898.330, RSKangXi=118.11
25CAA CJK UNIFIED IDEOGRAPH-#25CAA, IRGKangXi=0898.340, RSKangXi=118.11
25CAB CJK UNIFIED IDEOGRAPH-#25CAB, IRGKangXi=0898.360, RSKangXi=118.11
25CAC CJK UNIFIED IDEOGRAPH-#25CAC, IRGKangXi=0898.370, RSKangXi=118.11
25CAD CJK UNIFIED IDEOGRAPH-#25CAD, IRGKangXi=0898.371, RSKangXi=118.11
25CAE CJK UNIFIED IDEOGRAPH-#25CAE, IRGKangXi=0898.371, RSKangXi=118.11
25CAF CJK UNIFIED IDEOGRAPH-#25CAF, IRGKangXi=0898.371, RSKangXi=118.11
25CB0 CJK UNIFIED IDEOGRAPH-#25CB0, IRGKangXi=0898.371, RSKangXi=118.11
25CB1 CJK UNIFIED IDEOGRAPH-#25CB1, IRGKangXi=0898.371, RSKangXi=118.11
25CB2 CJK UNIFIED IDEOGRAPH-#25CB2, IRGKangXi=0898.371, RSKangXi=118.11
25CB3 CJK UNIFIED IDEOGRAPH-#25CB3, IRGKangXi=0898.371, RSKangXi=118.11
25CB4 CJK UNIFIED IDEOGRAPH-#25CB4, IRGKangXi=0898.371, RSKangXi=118.11
25CB5 CJK UNIFIED IDEOGRAPH-#25CB5, IRGKangXi=0898.371, RSKangXi=118.11
25CB6 CJK UNIFIED IDEOGRAPH-#25CB6, IRGKangXi=0898.371, RSKangXi=118.11
25CB7 CJK UNIFIED IDEOGRAPH-#25CB7, IRGKangXi=0898.371, RSKangXi=118.11
25CB8 CJK UNIFIED IDEOGRAPH-#25CB8, IRGKangXi=0898.371, RSKangXi=118.11
25CB9 CJK UNIFIED IDEOGRAPH-#25CB9, IRGKangXi=0898.371, RSKangXi=118.11
25CBA CJK UNIFIED IDEOGRAPH-#25CBA, IRGKangXi=0898.371, RSKangXi=118.11
25CBB CJK UNIFIED IDEOGRAPH-#25CBB, IRGKangXi=0898.371, RSKangXi=118.11
25CBC CJK UNIFIED IDEOGRAPH-#25CBC, IRGKangXi=0898.371, RSKangXi=118.11
25CBD CJK UNIFIED IDEOGRAPH-#25CBD, IRGKangXi=0898.371, RSKangXi=118.11
25CBE CJK UNIFIED IDEOGRAPH-#25CBE, IRGKangXi=0898.371, RSKangXi=118.11
25CBF CJK UNIFIED IDEOGRAPH-#25CBF, IRGKangXi=0898.371, RSKangXi=118.11
25CC0 CJK UNIFIED IDEOGRAPH-#25CC0, IRGKangXi=0898.371, RSKangXi=118.11
25CC1 CJK UNIFIED IDEOGRAPH-#25CC1, IRGKangXi=0898.371, RSKangXi=118.12
25CC2 CJK UNIFIED IDEOGRAPH-#25CC2, IRGKangXi=0898.371, RSKangXi=118.11
25CC3 CJK UNIFIED IDEOGRAPH-#25CC3, IRGKangXi=0898.371, RSKangXi=118.11
25CC4 CJK UNIFIED IDEOGRAPH-#25CC4, IRGKangXi=0898.371, RSKangXi=118.11
25CC5 CJK UNIFIED IDEOGRAPH-#25CC5, IRGKangXi=0898.371, RSKangXi=118.11
25CC6 CJK UNIFIED IDEOGRAPH-#25CC6, IRGKangXi=0898.430, RSKangXi=118.12
25CC7 CJK UNIFIED IDEOGRAPH-#25CC7, IRGKangXi=0898.460, RSKangXi=118.12
25CC8 CJK UNIFIED IDEOGRAPH-#25CC8, IRGKangXi=0898.480, RSKangXi=118.12
25CC9 CJK UNIFIED IDEOGRAPH-#25CC9, IRGKangXi=0898.490, RSKangXi=118.12
25CCA CJK UNIFIED IDEOGRAPH-#25CCA, IRGKangXi=0898.500, RSKangXi=118.12
25CCB CJK UNIFIED IDEOGRAPH-#25CCB, IRGKangXi=0898.510, RSKangXi=118.12
25CCC CJK UNIFIED IDEOGRAPH-#25CCC, IRGKangXi=0899.040, RSKangXi=118.12
25CCD CJK UNIFIED IDEOGRAPH-#25CCD, IRGKangXi=0899.050, RSKangXi=118.12
25CCE CJK UNIFIED IDEOGRAPH-#25CCE, IRGKangXi=0899.060, RSKangXi=118.12
25CCF CJK UNIFIED IDEOGRAPH-#25CCF, IRGKangXi=0899.080, RSKangXi=118.12
25CD0 CJK UNIFIED IDEOGRAPH-#25CD0, IRGKangXi=0899.120, RSKangXi=118.12
25CD1 CJK UNIFIED IDEOGRAPH-#25CD1, IRGKangXi=0899.140, RSKangXi=118.12
25CD2 CJK UNIFIED IDEOGRAPH-#25CD2, IRGKangXi=0899.170, RSKangXi=118.12
25CD3 CJK UNIFIED IDEOGRAPH-#25CD3, IRGKangXi=0899.240, RSKangXi=118.12
25CD4 CJK UNIFIED IDEOGRAPH-#25CD4, IRGKangXi=0900.010, RSKangXi=118.12
25CD5 CJK UNIFIED IDEOGRAPH-#25CD5, IRGKangXi=0900.040, RSKangXi=118.12
25CD6 CJK UNIFIED IDEOGRAPH-#25CD6, IRGKangXi=0900.050, RSKangXi=118.12
25CD7 CJK UNIFIED IDEOGRAPH-#25CD7, IRGKangXi=0900.060, RSKangXi=118.12
25CD8 CJK UNIFIED IDEOGRAPH-#25CD8, IRGKangXi=0900.070, RSKangXi=118.12
25CD9 CJK UNIFIED IDEOGRAPH-#25CD9, IRGKangXi=0900.080, RSKangXi=118.12
25CDA CJK UNIFIED IDEOGRAPH-#25CDA, IRGKangXi=0900.100, RSKangXi=118.12
25CDB CJK UNIFIED IDEOGRAPH-#25CDB, IRGKangXi=0900.120, RSKangXi=118.12
25CDC CJK UNIFIED IDEOGRAPH-#25CDC, IRGKangXi=0900.140, RSKangXi=118.12
25CDD CJK UNIFIED IDEOGRAPH-#25CDD, IRGKangXi=0900.150, RSKangXi=118.12
25CDE CJK UNIFIED IDEOGRAPH-#25CDE, IRGKangXi=0900.160, RSKangXi=118.12
25CDF CJK UNIFIED IDEOGRAPH-#25CDF, IRGKangXi=0900.180, RSKangXi=118.12
25CE0 CJK UNIFIED IDEOGRAPH-#25CE0, IRGKangXi=0900.190, RSKangXi=118.12
25CE1 CJK UNIFIED IDEOGRAPH-#25CE1, IRGKangXi=0900.200, RSKangXi=118.12
25CE2 CJK UNIFIED IDEOGRAPH-#25CE2, IRGKangXi=0900.210, RSKangXi=118.12
25CE3 CJK UNIFIED IDEOGRAPH-#25CE3, IRGKangXi=0900.220, RSKangXi=118.12
25CE4 CJK UNIFIED IDEOGRAPH-#25CE4, IRGKangXi=0900.310, RSKangXi=118.12
25CE5 CJK UNIFIED IDEOGRAPH-#25CE5, IRGKangXi=0901.010, RSKangXi=118.12
25CE6 CJK UNIFIED IDEOGRAPH-#25CE6, IRGKangXi=0901.040, RSKangXi=118.12
25CE7 CJK UNIFIED IDEOGRAPH-#25CE7, IRGKangXi=0901.060, RSKangXi=118.12
25CE8 CJK UNIFIED IDEOGRAPH-#25CE8, IRGKangXi=0901.070, RSKangXi=118.12
25CE9 CJK UNIFIED IDEOGRAPH-#25CE9, IRGKangXi=0901.090, RSKangXi=118.12
25CEA CJK UNIFIED IDEOGRAPH-#25CEA, IRGKangXi=0901.100, RSKangXi=118.12
25CEB CJK UNIFIED IDEOGRAPH-#25CEB, IRGKangXi=0901.110, RSKangXi=118.12
25CEC CJK UNIFIED IDEOGRAPH-#25CEC, IRGKangXi=0901.120, RSKangXi=118.12
25CED CJK UNIFIED IDEOGRAPH-#25CED, IRGKangXi=0901.130, RSKangXi=118.12
25CEE CJK UNIFIED IDEOGRAPH-#25CEE, IRGKangXi=0901.140, RSKangXi=118.12
25CEF CJK UNIFIED IDEOGRAPH-#25CEF, IRGKangXi=0901.150, RSKangXi=118.12
25CF0 CJK UNIFIED IDEOGRAPH-#25CF0, IRGKangXi=0901.170, RSKangXi=118.12
25CF1 CJK UNIFIED IDEOGRAPH-#25CF1, IRGKangXi=0901.180, RSKangXi=118.12
25CF2 CJK UNIFIED IDEOGRAPH-#25CF2, IRGKangXi=0901.190, RSKangXi=118.12
25CF3 CJK UNIFIED IDEOGRAPH-#25CF3, IRGKangXi=0901.200, RSKangXi=118.12
25CF4 CJK UNIFIED IDEOGRAPH-#25CF4, IRGKangXi=0901.210, RSKangXi=118.12
25CF5 CJK UNIFIED IDEOGRAPH-#25CF5, IRGKangXi=0901.220, RSKangXi=118.12
25CF6 CJK UNIFIED IDEOGRAPH-#25CF6, IRGKangXi=0901.230, RSKangXi=118.12
25CF7 CJK UNIFIED IDEOGRAPH-#25CF7, IRGKangXi=0901.240, RSKangXi=118.12
25CF8 CJK UNIFIED IDEOGRAPH-#25CF8, IRGKangXi=0901.260, RSKangXi=118.12
25CF9 CJK UNIFIED IDEOGRAPH-#25CF9, IRGKangXi=0901.270, RSKangXi=118.12
25CFA CJK UNIFIED IDEOGRAPH-#25CFA, IRGKangXi=0901.280, RSKangXi=118.12
25CFB CJK UNIFIED IDEOGRAPH-#25CFB, IRGKangXi=0901.281, RSKangXi=118.12
25CFC CJK UNIFIED IDEOGRAPH-#25CFC, IRGKangXi=0901.281, RSKangXi=118.12
25CFD CJK UNIFIED IDEOGRAPH-#25CFD, IRGKangXi=0901.281, RSKangXi=118.12
25CFE CJK UNIFIED IDEOGRAPH-#25CFE, IRGKangXi=0901.281, RSKangXi=118.12
25CFF CJK UNIFIED IDEOGRAPH-#25CFF, IRGKangXi=0901.281, RSKangXi=118.12
25D00 CJK UNIFIED IDEOGRAPH-#25D00, IRGKangXi=0901.281, RSKangXi=118.12
25D01 CJK UNIFIED IDEOGRAPH-#25D01, IRGKangXi=0901.281, RSKangXi=118.12
25D02 CJK UNIFIED IDEOGRAPH-#25D02, IRGKangXi=0901.281, RSKangXi=118.12
25D03 CJK UNIFIED IDEOGRAPH-#25D03, IRGKangXi=0901.281, RSKangXi=118.12
25D04 CJK UNIFIED IDEOGRAPH-#25D04, IRGKangXi=0901.281, RSKangXi=118.12
25D05 CJK UNIFIED IDEOGRAPH-#25D05, IRGKangXi=0901.281, RSKangXi=118.12
25D06 CJK UNIFIED IDEOGRAPH-#25D06, IRGKangXi=0901.281, RSKangXi=118.12
25D07 CJK UNIFIED IDEOGRAPH-#25D07, IRGKangXi=0901.281, RSKangXi=118.12
25D08 CJK UNIFIED IDEOGRAPH-#25D08, IRGKangXi=0901.281, RSKangXi=118.12
25D09 CJK UNIFIED IDEOGRAPH-#25D09, IRGKangXi=0901.281, RSKangXi=118.12
25D0A CJK UNIFIED IDEOGRAPH-#25D0A, IRGKangXi=0901.281, RSKangXi=118.12
25D0B CJK UNIFIED IDEOGRAPH-#25D0B, IRGKangXi=0901.281, RSKangXi=118.12
25D0C CJK UNIFIED IDEOGRAPH-#25D0C, IRGKangXi=0901.281, RSKangXi=118.12
25D0D CJK UNIFIED IDEOGRAPH-#25D0D, IRGKangXi=0901.281, RSKangXi=118.12
25D0E CJK UNIFIED IDEOGRAPH-#25D0E, IRGKangXi=0901.281, RSKangXi=118.11
25D0F CJK UNIFIED IDEOGRAPH-#25D0F, IRGKangXi=0901.281, RSKangXi=118.12
25D10 CJK UNIFIED IDEOGRAPH-#25D10, IRGKangXi=0901.281, RSKangXi=118.12
25D11 CJK UNIFIED IDEOGRAPH-#25D11, IRGKangXi=0901.281, RSKangXi=118.12
25D12 CJK UNIFIED IDEOGRAPH-#25D12, IRGKangXi=0901.281, RSKangXi=118.12
25D13 CJK UNIFIED IDEOGRAPH-#25D13, IRGKangXi=0901.281, RSKangXi=118.12
25D14 CJK UNIFIED IDEOGRAPH-#25D14, IRGKangXi=0901.281, RSKangXi=118.12
25D15 CJK UNIFIED IDEOGRAPH-#25D15, IRGKangXi=0901.281, RSKangXi=118.12
25D16 CJK UNIFIED IDEOGRAPH-#25D16, IRGKangXi=0901.281, RSKangXi=118.12
25D17 CJK UNIFIED IDEOGRAPH-#25D17, IRGKangXi=0901.281, RSKangXi=118.12
25D18 CJK UNIFIED IDEOGRAPH-#25D18, IRGKangXi=0901.281, RSKangXi=118.12
25D19 CJK UNIFIED IDEOGRAPH-#25D19, IRGKangXi=0901.281, RSKangXi=118.12
25D1A CJK UNIFIED IDEOGRAPH-#25D1A, IRGKangXi=0901.281, RSKangXi=118.12
25D1B CJK UNIFIED IDEOGRAPH-#25D1B, IRGKangXi=0901.281, RSKangXi=118.12
25D1C CJK UNIFIED IDEOGRAPH-#25D1C, IRGKangXi=0901.281, RSKangXi=118.12
25D1D CJK UNIFIED IDEOGRAPH-#25D1D, IRGKangXi=0901.281, RSKangXi=118.12
25D1E CJK UNIFIED IDEOGRAPH-#25D1E, IRGKangXi=0901.281, RSKangXi=118.12
25D1F CJK UNIFIED IDEOGRAPH-#25D1F, IRGKangXi=0901.281, RSKangXi=118.12
25D20 CJK UNIFIED IDEOGRAPH-#25D20, IRGKangXi=0901.281, RSKangXi=118.12
25D21 CJK UNIFIED IDEOGRAPH-#25D21, IRGKangXi=0901.300, RSKangXi=118.13
25D22 CJK UNIFIED IDEOGRAPH-#25D22, IRGKangXi=0901.340, RSKangXi=118.13
25D23 CJK UNIFIED IDEOGRAPH-#25D23, IRGKangXi=0901.360, RSKangXi=118.13
25D24 CJK UNIFIED IDEOGRAPH-#25D24, IRGKangXi=0901.380, RSKangXi=118.13
25D25 CJK UNIFIED IDEOGRAPH-#25D25, IRGKangXi=0901.390, RSKangXi=118.13
25D26 CJK UNIFIED IDEOGRAPH-#25D26, IRGKangXi=0901.420, RSKangXi=118.13
25D27 CJK UNIFIED IDEOGRAPH-#25D27, IRGKangXi=0901.430, RSKangXi=118.13
25D28 CJK UNIFIED IDEOGRAPH-#25D28, IRGKangXi=0902.030, RSKangXi=118.13
25D29 CJK UNIFIED IDEOGRAPH-#25D29, IRGKangXi=0902.060, RSKangXi=118.13
25D2A CJK UNIFIED IDEOGRAPH-#25D2A, IRGKangXi=0902.070, RSKangXi=118.13
25D2B CJK UNIFIED IDEOGRAPH-#25D2B, IRGKangXi=0902.080, RSKangXi=118.13
25D2C CJK UNIFIED IDEOGRAPH-#25D2C, IRGKangXi=0902.090, RSKangXi=118.13
25D2D CJK UNIFIED IDEOGRAPH-#25D2D, IRGKangXi=0902.100, RSKangXi=118.13
25D2E CJK UNIFIED IDEOGRAPH-#25D2E, IRGKangXi=0902.120, RSKangXi=118.13
25D2F CJK UNIFIED IDEOGRAPH-#25D2F, IRGKangXi=0902.130, RSKangXi=118.13
25D30 CJK UNIFIED IDEOGRAPH-#25D30, IRGKangXi=0902.140, RSKangXi=118.13
25D31 CJK UNIFIED IDEOGRAPH-#25D31, IRGKangXi=0902.150, RSKangXi=118.13
25D32 CJK UNIFIED IDEOGRAPH-#25D32, IRGKangXi=0902.170, RSKangXi=118.13
25D33 CJK UNIFIED IDEOGRAPH-#25D33, IRGKangXi=0902.180, RSKangXi=118.13
25D34 CJK UNIFIED IDEOGRAPH-#25D34, IRGKangXi=0902.190, RSKangXi=118.13
25D35 CJK UNIFIED IDEOGRAPH-#25D35, IRGKangXi=0902.210, RSKangXi=118.13
25D36 CJK UNIFIED IDEOGRAPH-#25D36, IRGKangXi=0902.230, RSKangXi=118.13
25D37 CJK UNIFIED IDEOGRAPH-#25D37, IRGKangXi=0902.240, RSKangXi=118.13
25D38 CJK UNIFIED IDEOGRAPH-#25D38, IRGKangXi=0902.250, RSKangXi=118.13
25D39 CJK UNIFIED IDEOGRAPH-#25D39, IRGKangXi=0902.260, RSKangXi=118.13
25D3A CJK UNIFIED IDEOGRAPH-#25D3A, IRGKangXi=0902.270, RSKangXi=118.13
25D3B CJK UNIFIED IDEOGRAPH-#25D3B, IRGKangXi=0902.280, RSKangXi=118.13
25D3C CJK UNIFIED IDEOGRAPH-#25D3C, IRGKangXi=0902.290, RSKangXi=118.13
25D3D CJK UNIFIED IDEOGRAPH-#25D3D, IRGKangXi=0902.300, RSKangXi=118.13
25D3E CJK UNIFIED IDEOGRAPH-#25D3E, IRGKangXi=0902.310, RSKangXi=118.13
25D3F CJK UNIFIED IDEOGRAPH-#25D3F, IRGKangXi=0902.320, RSKangXi=118.13
25D40 CJK UNIFIED IDEOGRAPH-#25D40, IRGKangXi=0902.321, RSKangXi=118.13
25D41 CJK UNIFIED IDEOGRAPH-#25D41, IRGKangXi=0902.321, RSKangXi=118.13
25D42 CJK UNIFIED IDEOGRAPH-#25D42, IRGKangXi=0902.321, RSKangXi=118.13
25D43 CJK UNIFIED IDEOGRAPH-#25D43, IRGKangXi=0902.321, RSKangXi=118.13
25D44 CJK UNIFIED IDEOGRAPH-#25D44, IRGKangXi=0902.321, RSKangXi=118.13
25D45 CJK UNIFIED IDEOGRAPH-#25D45, IRGKangXi=0902.321, RSKangXi=118.13
25D46 CJK UNIFIED IDEOGRAPH-#25D46, IRGKangXi=0902.321, RSKangXi=118.13
25D47 CJK UNIFIED IDEOGRAPH-#25D47, IRGKangXi=0902.321, RSKangXi=118.13
25D48 CJK UNIFIED IDEOGRAPH-#25D48, IRGKangXi=0902.321, RSKangXi=118.13
25D49 CJK UNIFIED IDEOGRAPH-#25D49, IRGKangXi=0902.321, RSKangXi=118.13
25D4A CJK UNIFIED IDEOGRAPH-#25D4A, IRGKangXi=0902.321, RSKangXi=118.13
25D4B CJK UNIFIED IDEOGRAPH-#25D4B, IRGKangXi=0902.321, RSKangXi=118.13
25D4C CJK UNIFIED IDEOGRAPH-#25D4C, IRGKangXi=0902.321, RSKangXi=118.13
25D4D CJK UNIFIED IDEOGRAPH-#25D4D, IRGKangXi=0902.321, RSKangXi=118.13
25D4E CJK UNIFIED IDEOGRAPH-#25D4E, IRGKangXi=0902.321, RSKangXi=118.13
25D4F CJK UNIFIED IDEOGRAPH-#25D4F, IRGKangXi=0902.321, RSKangXi=118.13
25D50 CJK UNIFIED IDEOGRAPH-#25D50, IRGKangXi=0902.321, RSKangXi=118.13
25D51 CJK UNIFIED IDEOGRAPH-#25D51, IRGKangXi=0902.321, RSKangXi=118.13
25D52 CJK UNIFIED IDEOGRAPH-#25D52, IRGKangXi=0902.321, RSKangXi=118.13
25D53 CJK UNIFIED IDEOGRAPH-#25D53, IRGKangXi=0902.321, RSKangXi=118.13
25D54 CJK UNIFIED IDEOGRAPH-#25D54, IRGKangXi=0902.321, RSKangXi=118.13
25D55 CJK UNIFIED IDEOGRAPH-#25D55, IRGKangXi=0902.321, RSKangXi=118.13
25D56 CJK UNIFIED IDEOGRAPH-#25D56, IRGKangXi=0902.321, RSKangXi=118.13
25D57 CJK UNIFIED IDEOGRAPH-#25D57, IRGKangXi=0902.321, RSKangXi=118.13
25D58 CJK UNIFIED IDEOGRAPH-#25D58, IRGKangXi=0902.321, RSKangXi=118.13
25D59 CJK UNIFIED IDEOGRAPH-#25D59, IRGKangXi=0902.321, RSKangXi=118.13
25D5A CJK UNIFIED IDEOGRAPH-#25D5A, IRGKangXi=0902.321, RSKangXi=118.13, Def{thorns, brambles}
25D5B CJK UNIFIED IDEOGRAPH-#25D5B, IRGKangXi=0902.321, RSKangXi=118.13
25D5C CJK UNIFIED IDEOGRAPH-#25D5C, IRGKangXi=0902.350, RSKangXi=118.14
25D5D CJK UNIFIED IDEOGRAPH-#25D5D, IRGKangXi=0902.360, RSKangXi=118.14
25D5E CJK UNIFIED IDEOGRAPH-#25D5E, IRGKangXi=0902.380, RSKangXi=118.14
25D5F CJK UNIFIED IDEOGRAPH-#25D5F, IRGKangXi=0902.410, RSKangXi=118.14
25D60 CJK UNIFIED IDEOGRAPH-#25D60, IRGKangXi=0902.430, RSKangXi=118.14
25D61 CJK UNIFIED IDEOGRAPH-#25D61, IRGKangXi=0902.450, RSKangXi=118.14
25D62 CJK UNIFIED IDEOGRAPH-#25D62, IRGKangXi=0902.460, RSKangXi=118.14
25D63 CJK UNIFIED IDEOGRAPH-#25D63, IRGKangXi=0902.470, RSKangXi=118.14
25D64 CJK UNIFIED IDEOGRAPH-#25D64, IRGKangXi=0902.480, RSKangXi=118.14
25D65 CJK UNIFIED IDEOGRAPH-#25D65, IRGKangXi=0902.490, RSKangXi=118.14
25D66 CJK UNIFIED IDEOGRAPH-#25D66, IRGKangXi=0902.510, RSKangXi=118.14
25D67 CJK UNIFIED IDEOGRAPH-#25D67, IRGKangXi=0902.520, RSKangXi=118.14
25D68 CJK UNIFIED IDEOGRAPH-#25D68, IRGKangXi=0902.540, RSKangXi=118.14
25D69 CJK UNIFIED IDEOGRAPH-#25D69, IRGKangXi=0903.010, RSKangXi=118.14
25D6A CJK UNIFIED IDEOGRAPH-#25D6A, IRGKangXi=0903.020, RSKangXi=118.14
25D6B CJK UNIFIED IDEOGRAPH-#25D6B, IRGKangXi=0903.030, RSKangXi=118.14
25D6C CJK UNIFIED IDEOGRAPH-#25D6C, IRGKangXi=0903.070, RSKangXi=118.14
25D6D CJK UNIFIED IDEOGRAPH-#25D6D, IRGKangXi=0903.100, RSKangXi=118.14
25D6E CJK UNIFIED IDEOGRAPH-#25D6E, IRGKangXi=0903.110, RSKangXi=118.14
25D6F CJK UNIFIED IDEOGRAPH-#25D6F, IRGKangXi=0903.120, RSKangXi=118.14
25D70 CJK UNIFIED IDEOGRAPH-#25D70, IRGKangXi=0903.130, RSKangXi=118.14
25D71 CJK UNIFIED IDEOGRAPH-#25D71, IRGKangXi=0903.140, RSKangXi=118.14
25D72 CJK UNIFIED IDEOGRAPH-#25D72, IRGKangXi=0903.150, RSKangXi=118.14
25D73 CJK UNIFIED IDEOGRAPH-#25D73, IRGKangXi=0903.160, RSKangXi=118.14
25D74 CJK UNIFIED IDEOGRAPH-#25D74, IRGKangXi=0903.170, RSKangXi=118.14
25D75 CJK UNIFIED IDEOGRAPH-#25D75, IRGKangXi=0903.180, RSKangXi=118.14
25D76 CJK UNIFIED IDEOGRAPH-#25D76, IRGKangXi=0903.190, RSKangXi=118.14
25D77 CJK UNIFIED IDEOGRAPH-#25D77, IRGKangXi=0903.191, RSKangXi=118.14
25D78 CJK UNIFIED IDEOGRAPH-#25D78, IRGKangXi=0903.191, RSKangXi=118.14
25D79 CJK UNIFIED IDEOGRAPH-#25D79, IRGKangXi=0903.191, RSKangXi=118.14
25D7A CJK UNIFIED IDEOGRAPH-#25D7A, IRGKangXi=0903.191, RSKangXi=118.14
25D7B CJK UNIFIED IDEOGRAPH-#25D7B, IRGKangXi=0903.191, RSKangXi=118.14
25D7C CJK UNIFIED IDEOGRAPH-#25D7C, IRGKangXi=0903.191, RSKangXi=118.14
25D7D CJK UNIFIED IDEOGRAPH-#25D7D, IRGKangXi=0903.191, RSKangXi=118.14
25D7E CJK UNIFIED IDEOGRAPH-#25D7E, IRGKangXi=0903.191, RSKangXi=117.14
25D7F CJK UNIFIED IDEOGRAPH-#25D7F, IRGKangXi=0903.191, RSKangXi=118.14
25D80 CJK UNIFIED IDEOGRAPH-#25D80, IRGKangXi=0903.191, RSKangXi=118.14
25D81 CJK UNIFIED IDEOGRAPH-#25D81, IRGKangXi=0903.191, RSKangXi=118.14
25D82 CJK UNIFIED IDEOGRAPH-#25D82, IRGKangXi=0903.191, RSKangXi=118.14
25D83 CJK UNIFIED IDEOGRAPH-#25D83, IRGKangXi=0903.191, RSKangXi=118.14
25D84 CJK UNIFIED IDEOGRAPH-#25D84, IRGKangXi=0903.191, RSKangXi=118.14
25D85 CJK UNIFIED IDEOGRAPH-#25D85, IRGKangXi=0903.210, RSKangXi=118.15
25D86 CJK UNIFIED IDEOGRAPH-#25D86, IRGKangXi=0903.230, RSKangXi=118.15
25D87 CJK UNIFIED IDEOGRAPH-#25D87, IRGKangXi=0903.250, RSKangXi=118.15
25D88 CJK UNIFIED IDEOGRAPH-#25D88, IRGKangXi=0903.260, RSKangXi=118.15
25D89 CJK UNIFIED IDEOGRAPH-#25D89, IRGKangXi=0903.280, RSKangXi=118.15
25D8A CJK UNIFIED IDEOGRAPH-#25D8A, IRGKangXi=0903.290, RSKangXi=118.15
25D8B CJK UNIFIED IDEOGRAPH-#25D8B, IRGKangXi=0903.300, RSKangXi=118.15
25D8C CJK UNIFIED IDEOGRAPH-#25D8C, IRGKangXi=0903.310, RSKangXi=118.15
25D8D CJK UNIFIED IDEOGRAPH-#25D8D, IRGKangXi=0903.350, RSKangXi=118.15
25D8E CJK UNIFIED IDEOGRAPH-#25D8E, IRGKangXi=0904.020, RSKangXi=118.15
25D8F CJK UNIFIED IDEOGRAPH-#25D8F, IRGKangXi=0904.030, RSKangXi=118.15
25D90 CJK UNIFIED IDEOGRAPH-#25D90, IRGKangXi=0904.050, RSKangXi=118.15
25D91 CJK UNIFIED IDEOGRAPH-#25D91, IRGKangXi=0904.060, RSKangXi=118.15
25D92 CJK UNIFIED IDEOGRAPH-#25D92, IRGKangXi=0904.070, RSKangXi=118.15
25D93 CJK UNIFIED IDEOGRAPH-#25D93, IRGKangXi=0904.080, RSKangXi=118.15
25D94 CJK UNIFIED IDEOGRAPH-#25D94, IRGKangXi=0904.090, RSKangXi=118.15
25D95 CJK UNIFIED IDEOGRAPH-#25D95, IRGKangXi=0904.100, RSKangXi=118.15
25D96 CJK UNIFIED IDEOGRAPH-#25D96, IRGKangXi=0904.110, RSKangXi=118.15
25D97 CJK UNIFIED IDEOGRAPH-#25D97, IRGKangXi=0904.120, RSKangXi=118.15
25D98 CJK UNIFIED IDEOGRAPH-#25D98, IRGKangXi=0904.130, RSKangXi=118.15
25D99 CJK UNIFIED IDEOGRAPH-#25D99, IRGKangXi=0904.140, RSKangXi=118.15
25D9A CJK UNIFIED IDEOGRAPH-#25D9A, IRGKangXi=0904.150, RSKangXi=118.15
25D9B CJK UNIFIED IDEOGRAPH-#25D9B, IRGKangXi=0904.160, RSKangXi=118.15
25D9C CJK UNIFIED IDEOGRAPH-#25D9C, IRGKangXi=0904.170, RSKangXi=118.15
25D9D CJK UNIFIED IDEOGRAPH-#25D9D, IRGKangXi=0904.180, RSKangXi=118.15
25D9E CJK UNIFIED IDEOGRAPH-#25D9E, IRGKangXi=0904.190, RSKangXi=118.15
25D9F CJK UNIFIED IDEOGRAPH-#25D9F, IRGKangXi=0904.200, RSKangXi=118.15
25DA0 CJK UNIFIED IDEOGRAPH-#25DA0, IRGKangXi=0904.201, RSKangXi=118.15
25DA1 CJK UNIFIED IDEOGRAPH-#25DA1, IRGKangXi=0904.201, RSKangXi=118.15
25DA2 CJK UNIFIED IDEOGRAPH-#25DA2, IRGKangXi=0904.201, RSKangXi=118.15
25DA3 CJK UNIFIED IDEOGRAPH-#25DA3, IRGKangXi=0904.201, RSKangXi=118.15
25DA4 CJK UNIFIED IDEOGRAPH-#25DA4, IRGKangXi=0904.201, RSKangXi=118.15
25DA5 CJK UNIFIED IDEOGRAPH-#25DA5, IRGKangXi=0904.201, RSKangXi=118.15
25DA6 CJK UNIFIED IDEOGRAPH-#25DA6, IRGKangXi=0904.201, RSKangXi=118.15
25DA7 CJK UNIFIED IDEOGRAPH-#25DA7, IRGKangXi=0904.201, RSKangXi=118.15
25DA8 CJK UNIFIED IDEOGRAPH-#25DA8, IRGKangXi=0904.201, RSKangXi=118.15
25DA9 CJK UNIFIED IDEOGRAPH-#25DA9, IRGKangXi=0904.201, RSKangXi=118.15
25DAA CJK UNIFIED IDEOGRAPH-#25DAA, IRGKangXi=0904.201, RSKangXi=118.15
25DAB CJK UNIFIED IDEOGRAPH-#25DAB, IRGKangXi=0904.201, RSKangXi=118.15
25DAC CJK UNIFIED IDEOGRAPH-#25DAC, IRGKangXi=0904.201, RSKangXi=118.15
25DAD CJK UNIFIED IDEOGRAPH-#25DAD, IRGKangXi=0904.201, RSKangXi=118.15
25DAE CJK UNIFIED IDEOGRAPH-#25DAE, IRGKangXi=0904.201, RSKangXi=118.15
25DAF CJK UNIFIED IDEOGRAPH-#25DAF, IRGKangXi=0904.201, RSKangXi=118.15
25DB0 CJK UNIFIED IDEOGRAPH-#25DB0, IRGKangXi=0904.201, RSKangXi=118.15
25DB1 CJK UNIFIED IDEOGRAPH-#25DB1, IRGKangXi=0904.201, RSKangXi=118.15
25DB2 CJK UNIFIED IDEOGRAPH-#25DB2, IRGKangXi=0904.201, RSKangXi=118.15
25DB3 CJK UNIFIED IDEOGRAPH-#25DB3, IRGKangXi=0904.201, RSKangXi=118.15
25DB4 CJK UNIFIED IDEOGRAPH-#25DB4, IRGKangXi=0904.201, RSKangXi=118.15
25DB5 CJK UNIFIED IDEOGRAPH-#25DB5, IRGKangXi=0904.210, RSKangXi=118.16
25DB6 CJK UNIFIED IDEOGRAPH-#25DB6, IRGKangXi=0904.220, RSKangXi=118.16
25DB7 CJK UNIFIED IDEOGRAPH-#25DB7, IRGKangXi=0904.230, RSKangXi=118.16
25DB8 CJK UNIFIED IDEOGRAPH-#25DB8, IRGKangXi=0904.240, RSKangXi=118.16
25DB9 CJK UNIFIED IDEOGRAPH-#25DB9, IRGKangXi=0904.280, RSKangXi=118.16
25DBA CJK UNIFIED IDEOGRAPH-#25DBA, IRGKangXi=0904.300, RSKangXi=118.16
25DBB CJK UNIFIED IDEOGRAPH-#25DBB, IRGKangXi=0904.310, RSKangXi=118.16
25DBC CJK UNIFIED IDEOGRAPH-#25DBC, IRGKangXi=0904.320, RSKangXi=118.16
25DBD CJK UNIFIED IDEOGRAPH-#25DBD, IRGKangXi=0904.330, RSKangXi=118.16
25DBE CJK UNIFIED IDEOGRAPH-#25DBE, IRGKangXi=0904.360, RSKangXi=118.16
25DBF CJK UNIFIED IDEOGRAPH-#25DBF, IRGKangXi=0904.380, RSKangXi=118.16
25DC0 CJK UNIFIED IDEOGRAPH-#25DC0, IRGKangXi=0904.400, RSKangXi=118.16
25DC1 CJK UNIFIED IDEOGRAPH-#25DC1, IRGKangXi=0904.410, RSKangXi=118.16
25DC2 CJK UNIFIED IDEOGRAPH-#25DC2, IRGKangXi=0904.420, RSKangXi=118.16
25DC3 CJK UNIFIED IDEOGRAPH-#25DC3, IRGKangXi=0905.020, RSKangXi=118.16
25DC4 CJK UNIFIED IDEOGRAPH-#25DC4, IRGKangXi=0905.030, RSKangXi=118.16
25DC5 CJK UNIFIED IDEOGRAPH-#25DC5, IRGKangXi=0905.050, RSKangXi=118.16
25DC6 CJK UNIFIED IDEOGRAPH-#25DC6, IRGKangXi=0905.060, RSKangXi=118.16
25DC7 CJK UNIFIED IDEOGRAPH-#25DC7, IRGKangXi=0905.070, RSKangXi=118.16
25DC8 CJK UNIFIED IDEOGRAPH-#25DC8, IRGKangXi=0905.080, RSKangXi=118.16
25DC9 CJK UNIFIED IDEOGRAPH-#25DC9, IRGKangXi=0905.100, RSKangXi=118.16
25DCA CJK UNIFIED IDEOGRAPH-#25DCA, IRGKangXi=0905.101, RSKangXi=118.16
25DCB CJK UNIFIED IDEOGRAPH-#25DCB, IRGKangXi=0905.101, RSKangXi=118.16
25DCC CJK UNIFIED IDEOGRAPH-#25DCC, IRGKangXi=0905.101, RSKangXi=118.16
25DCD CJK UNIFIED IDEOGRAPH-#25DCD, IRGKangXi=0905.101, RSKangXi=118.16
25DCE CJK UNIFIED IDEOGRAPH-#25DCE, IRGKangXi=0905.101, RSKangXi=118.16
25DCF CJK UNIFIED IDEOGRAPH-#25DCF, IRGKangXi=0905.101, RSKangXi=118.16
25DD0 CJK UNIFIED IDEOGRAPH-#25DD0, IRGKangXi=0905.101, RSKangXi=118.16
25DD1 CJK UNIFIED IDEOGRAPH-#25DD1, IRGKangXi=0905.101, RSKangXi=118.16
25DD2 CJK UNIFIED IDEOGRAPH-#25DD2, IRGKangXi=0905.101, RSKangXi=118.16
25DD3 CJK UNIFIED IDEOGRAPH-#25DD3, IRGKangXi=0905.101, RSKangXi=118.16
25DD4 CJK UNIFIED IDEOGRAPH-#25DD4, IRGKangXi=0905.110, RSKangXi=118.17
25DD5 CJK UNIFIED IDEOGRAPH-#25DD5, IRGKangXi=0905.140, RSKangXi=118.17
25DD6 CJK UNIFIED IDEOGRAPH-#25DD6, IRGKangXi=0905.190, RSKangXi=118.17
25DD7 CJK UNIFIED IDEOGRAPH-#25DD7, IRGKangXi=0905.200, RSKangXi=118.17
25DD8 CJK UNIFIED IDEOGRAPH-#25DD8, IRGKangXi=0905.230, RSKangXi=118.17
25DD9 CJK UNIFIED IDEOGRAPH-#25DD9, IRGKangXi=0905.250, RSKangXi=118.17
25DDA CJK UNIFIED IDEOGRAPH-#25DDA, IRGKangXi=0905.260, RSKangXi=118.17
25DDB CJK UNIFIED IDEOGRAPH-#25DDB, IRGKangXi=0905.270, RSKangXi=118.17
25DDC CJK UNIFIED IDEOGRAPH-#25DDC, IRGKangXi=0905.280, RSKangXi=118.17
25DDD CJK UNIFIED IDEOGRAPH-#25DDD, IRGKangXi=0905.290, RSKangXi=118.17
25DDE CJK UNIFIED IDEOGRAPH-#25DDE, IRGKangXi=0905.300, RSKangXi=118.17
25DDF CJK UNIFIED IDEOGRAPH-#25DDF, IRGKangXi=0905.310, RSKangXi=118.17
25DE0 CJK UNIFIED IDEOGRAPH-#25DE0, IRGKangXi=0905.311, RSKangXi=118.17
25DE1 CJK UNIFIED IDEOGRAPH-#25DE1, IRGKangXi=0905.311, RSKangXi=118.17
25DE2 CJK UNIFIED IDEOGRAPH-#25DE2, IRGKangXi=0905.311, RSKangXi=118.17
25DE3 CJK UNIFIED IDEOGRAPH-#25DE3, IRGKangXi=0905.311, RSKangXi=118.17
25DE4 CJK UNIFIED IDEOGRAPH-#25DE4, IRGKangXi=0905.311, RSKangXi=118.17
25DE5 CJK UNIFIED IDEOGRAPH-#25DE5, IRGKangXi=0905.311, RSKangXi=118.17
25DE6 CJK UNIFIED IDEOGRAPH-#25DE6, IRGKangXi=0905.311, RSKangXi=118.17
25DE7 CJK UNIFIED IDEOGRAPH-#25DE7, IRGKangXi=0905.311, RSKangXi=118.17
25DE8 CJK UNIFIED IDEOGRAPH-#25DE8, IRGKangXi=0905.320, RSKangXi=118.18
25DE9 CJK UNIFIED IDEOGRAPH-#25DE9, IRGKangXi=0905.330, RSKangXi=118.18
25DEA CJK UNIFIED IDEOGRAPH-#25DEA, IRGKangXi=0905.350, RSKangXi=118.18
25DEB CJK UNIFIED IDEOGRAPH-#25DEB, IRGKangXi=0905.360, RSKangXi=118.18
25DEC CJK UNIFIED IDEOGRAPH-#25DEC, IRGKangXi=0905.380, RSKangXi=118.18
25DED CJK UNIFIED IDEOGRAPH-#25DED, IRGKangXi=0905.390, RSKangXi=118.18
25DEE CJK UNIFIED IDEOGRAPH-#25DEE, IRGKangXi=0905.400, RSKangXi=118.18
25DEF CJK UNIFIED IDEOGRAPH-#25DEF, IRGKangXi=0905.410, RSKangXi=118.18
25DF0 CJK UNIFIED IDEOGRAPH-#25DF0, IRGKangXi=0905.420, RSKangXi=118.18
25DF1 CJK UNIFIED IDEOGRAPH-#25DF1, IRGKangXi=0906.010, RSKangXi=118.18
25DF2 CJK UNIFIED IDEOGRAPH-#25DF2, IRGKangXi=0906.020, RSKangXi=118.18
25DF3 CJK UNIFIED IDEOGRAPH-#25DF3, IRGKangXi=0906.030, RSKangXi=118.18
25DF4 CJK UNIFIED IDEOGRAPH-#25DF4, IRGKangXi=0906.031, RSKangXi=118.18
25DF5 CJK UNIFIED IDEOGRAPH-#25DF5, IRGKangXi=0906.031, RSKangXi=118.18
25DF6 CJK UNIFIED IDEOGRAPH-#25DF6, IRGKangXi=0906.031, RSKangXi=118.18
25DF7 CJK UNIFIED IDEOGRAPH-#25DF7, IRGKangXi=0906.031, RSKangXi=118.18
25DF8 CJK UNIFIED IDEOGRAPH-#25DF8, IRGKangXi=0906.031, RSKangXi=118.18
25DF9 CJK UNIFIED IDEOGRAPH-#25DF9, IRGKangXi=0906.031, RSKangXi=118.18
25DFA CJK UNIFIED IDEOGRAPH-#25DFA, IRGKangXi=0906.031, RSKangXi=118.18
25DFB CJK UNIFIED IDEOGRAPH-#25DFB, IRGKangXi=0906.031, RSKangXi=118.18
25DFC CJK UNIFIED IDEOGRAPH-#25DFC, IRGKangXi=0906.080, RSKangXi=118.19
25DFD CJK UNIFIED IDEOGRAPH-#25DFD, IRGKangXi=0906.090, RSKangXi=118.19
25DFE CJK UNIFIED IDEOGRAPH-#25DFE, IRGKangXi=0906.100, RSKangXi=118.19
25DFF CJK UNIFIED IDEOGRAPH-#25DFF, IRGKangXi=0906.110, RSKangXi=118.19
25E00 CJK UNIFIED IDEOGRAPH-#25E00, IRGKangXi=0906.120, RSKangXi=119.19
25E01 CJK UNIFIED IDEOGRAPH-#25E01, IRGKangXi=0906.121, RSKangXi=118.19
25E02 CJK UNIFIED IDEOGRAPH-#25E02, IRGKangXi=0906.121, RSKangXi=118.19
25E03 CJK UNIFIED IDEOGRAPH-#25E03, IRGKangXi=0906.121, RSKangXi=118.19
25E04 CJK UNIFIED IDEOGRAPH-#25E04, IRGKangXi=0906.121, RSKangXi=118.19
25E05 CJK UNIFIED IDEOGRAPH-#25E05, IRGKangXi=0906.121, RSKangXi=118.19
25E06 CJK UNIFIED IDEOGRAPH-#25E06, IRGKangXi=0906.121, RSKangXi=118.19
25E07 CJK UNIFIED IDEOGRAPH-#25E07, IRGKangXi=0906.121, RSKangXi=118.19
25E08 CJK UNIFIED IDEOGRAPH-#25E08, IRGKangXi=0906.140, RSKangXi=118.20
25E09 CJK UNIFIED IDEOGRAPH-#25E09, IRGKangXi=0906.170, RSKangXi=118.20
25E0A CJK UNIFIED IDEOGRAPH-#25E0A, IRGKangXi=0906.180, RSKangXi=118.20
25E0B CJK UNIFIED IDEOGRAPH-#25E0B, IRGKangXi=0906.190, RSKangXi=118.20
25E0C CJK UNIFIED IDEOGRAPH-#25E0C, IRGKangXi=0906.191, RSKangXi=118.20
25E0D CJK UNIFIED IDEOGRAPH-#25E0D, IRGKangXi=0906.191, RSKangXi=118.20
25E0E CJK UNIFIED IDEOGRAPH-#25E0E, IRGKangXi=0906.191, RSKangXi=118.20
25E0F CJK UNIFIED IDEOGRAPH-#25E0F, IRGKangXi=0906.191, RSKangXi=118.20
25E10 CJK UNIFIED IDEOGRAPH-#25E10, IRGKangXi=0906.210, RSKangXi=118.21
25E11 CJK UNIFIED IDEOGRAPH-#25E11, IRGKangXi=0906.220, RSKangXi=118.21
25E12 CJK UNIFIED IDEOGRAPH-#25E12, IRGKangXi=0906.221, RSKangXi=118.21
25E13 CJK UNIFIED IDEOGRAPH-#25E13, IRGKangXi=0906.221, RSKangXi=118.21
25E14 CJK UNIFIED IDEOGRAPH-#25E14, IRGKangXi=0906.221, RSKangXi=118.21
25E15 CJK UNIFIED IDEOGRAPH-#25E15, IRGKangXi=0906.221, RSKangXi=118.21
25E16 CJK UNIFIED IDEOGRAPH-#25E16, IRGKangXi=0906.221, RSKangXi=118.21
25E17 CJK UNIFIED IDEOGRAPH-#25E17, IRGKangXi=0906.230, RSKangXi=118.22
25E18 CJK UNIFIED IDEOGRAPH-#25E18, IRGKangXi=0906.240, RSKangXi=118.23
25E19 CJK UNIFIED IDEOGRAPH-#25E19, IRGKangXi=0906.241, RSKangXi=118.23
25E1A CJK UNIFIED IDEOGRAPH-#25E1A, IRGKangXi=0906.241, RSKangXi=118.22
25E1B CJK UNIFIED IDEOGRAPH-#25E1B, IRGKangXi=0906.241, RSKangXi=118.22
25E1C CJK UNIFIED IDEOGRAPH-#25E1C, IRGKangXi=0906.241, RSKangXi=118.22
25E1D CJK UNIFIED IDEOGRAPH-#25E1D, IRGKangXi=0906.241, RSKangXi=118.22
25E1E CJK UNIFIED IDEOGRAPH-#25E1E, IRGKangXi=0906.241, RSKangXi=118.23
25E1F CJK UNIFIED IDEOGRAPH-#25E1F, IRGKangXi=0906.241, RSKangXi=118.23
25E20 CJK UNIFIED IDEOGRAPH-#25E20, IRGKangXi=0906.241, RSKangXi=118.23
25E21 CJK UNIFIED IDEOGRAPH-#25E21, IRGKangXi=0906.250, RSKangXi=118.24
25E22 CJK UNIFIED IDEOGRAPH-#25E22, IRGKangXi=0906.280, RSKangXi=118.24
25E23 CJK UNIFIED IDEOGRAPH-#25E23, IRGKangXi=0906.290, RSKangXi=118.25
25E24 CJK UNIFIED IDEOGRAPH-#25E24, IRGKangXi=0906.300, RSKangXi=118.26
25E25 CJK UNIFIED IDEOGRAPH-#25E25, IRGKangXi=0906.320, RSKangXi=119.1
25E26 CJK UNIFIED IDEOGRAPH-#25E26, IRGKangXi=0906.321, RSKangXi=119.1
25E27 CJK UNIFIED IDEOGRAPH-#25E27, IRGKangXi=0906.330, RSKangXi=119.2
25E28 CJK UNIFIED IDEOGRAPH-#25E28, IRGKangXi=0906.340, RSKangXi=119.2
25E29 CJK UNIFIED IDEOGRAPH-#25E29, IRGKangXi=0906.361, RSKangXi=119.2
25E2A CJK UNIFIED IDEOGRAPH-#25E2A, IRGKangXi=0906.361, RSKangXi=119.2
25E2B CJK UNIFIED IDEOGRAPH-#25E2B, IRGKangXi=0907.010, RSKangXi=119.3
25E2C CJK UNIFIED IDEOGRAPH-#25E2C, IRGKangXi=0907.020, RSKangXi=119.3
25E2D CJK UNIFIED IDEOGRAPH-#25E2D, IRGKangXi=0907.050, RSKangXi=119.3
25E2E CJK UNIFIED IDEOGRAPH-#25E2E, IRGKangXi=0907.051, RSKangXi=119.3
25E2F CJK UNIFIED IDEOGRAPH-#25E2F, IRGKangXi=0907.051, RSKangXi=119.3
25E30 CJK UNIFIED IDEOGRAPH-#25E30, IRGKangXi=0907.051, RSKangXi=119.3
25E31 CJK UNIFIED IDEOGRAPH-#25E31, IRGKangXi=0907.051, RSKangXi=119.3
25E32 CJK UNIFIED IDEOGRAPH-#25E32, IRGKangXi=0907.051, RSKangXi=119.3
25E33 CJK UNIFIED IDEOGRAPH-#25E33, IRGKangXi=0907.080, RSKangXi=119.4
25E34 CJK UNIFIED IDEOGRAPH-#25E34, IRGKangXi=0907.090, RSKangXi=119.4
25E35 CJK UNIFIED IDEOGRAPH-#25E35, IRGKangXi=0907.150, RSKangXi=119.4
25E36 CJK UNIFIED IDEOGRAPH-#25E36, IRGKangXi=0907.170, RSKangXi=119.4
25E37 CJK UNIFIED IDEOGRAPH-#25E37, IRGKangXi=0907.190, RSKangXi=119.4
25E38 CJK UNIFIED IDEOGRAPH-#25E38, IRGKangXi=0907.210, RSKangXi=119.4
25E39 CJK UNIFIED IDEOGRAPH-#25E39, IRGKangXi=0907.211, RSKangXi=119.4
25E3A CJK UNIFIED IDEOGRAPH-#25E3A, IRGKangXi=0907.211, RSKangXi=119.4
25E3B CJK UNIFIED IDEOGRAPH-#25E3B, IRGKangXi=0907.211, RSKangXi=119.4
25E3C CJK UNIFIED IDEOGRAPH-#25E3C, IRGKangXi=0907.211, RSKangXi=119.4
25E3D CJK UNIFIED IDEOGRAPH-#25E3D, IRGKangXi=0907.211, RSKangXi=119.4
25E3E CJK UNIFIED IDEOGRAPH-#25E3E, IRGKangXi=0907.211, RSKangXi=119.4
25E3F CJK UNIFIED IDEOGRAPH-#25E3F, IRGKangXi=0907.211, RSKangXi=119.4
25E40 CJK UNIFIED IDEOGRAPH-#25E40, IRGKangXi=0907.211, RSKangXi=119.4
25E41 CJK UNIFIED IDEOGRAPH-#25E41, IRGKangXi=0907.260, RSKangXi=119.5
25E42 CJK UNIFIED IDEOGRAPH-#25E42, IRGKangXi=0907.270, RSKangXi=119.5
25E43 CJK UNIFIED IDEOGRAPH-#25E43, IRGKangXi=0907.310, RSKangXi=119.5
25E44 CJK UNIFIED IDEOGRAPH-#25E44, IRGKangXi=0907.320, RSKangXi=119.5
25E45 CJK UNIFIED IDEOGRAPH-#25E45, IRGKangXi=0907.330, RSKangXi=119.5
25E46 CJK UNIFIED IDEOGRAPH-#25E46, IRGKangXi=0907.340, RSKangXi=119.5
25E47 CJK UNIFIED IDEOGRAPH-#25E47, IRGKangXi=0907.350, RSKangXi=119.5
25E48 CJK UNIFIED IDEOGRAPH-#25E48, IRGKangXi=0907.380, RSKangXi=119.5
25E49 CJK UNIFIED IDEOGRAPH-#25E49, IRGKangXi=0907.390, RSKangXi=119.5, Def{(Cant.) sticky}
25E4A CJK UNIFIED IDEOGRAPH-#25E4A, IRGKangXi=0908.010, RSKangXi=119.5
25E4B CJK UNIFIED IDEOGRAPH-#25E4B, IRGKangXi=0908.030, RSKangXi=119.5
25E4C CJK UNIFIED IDEOGRAPH-#25E4C, IRGKangXi=0908.060, RSKangXi=119.5
25E4D CJK UNIFIED IDEOGRAPH-#25E4D, IRGKangXi=0908.080, RSKangXi=119.5
25E4E CJK UNIFIED IDEOGRAPH-#25E4E, IRGKangXi=0908.090, RSKangXi=119.5
25E4F CJK UNIFIED IDEOGRAPH-#25E4F, IRGKangXi=0908.120, RSKangXi=119.5
25E50 CJK UNIFIED IDEOGRAPH-#25E50, IRGKangXi=0908.121, RSKangXi=119.5
25E51 CJK UNIFIED IDEOGRAPH-#25E51, IRGKangXi=0908.121, RSKangXi=119.5
25E52 CJK UNIFIED IDEOGRAPH-#25E52, IRGKangXi=0908.121, RSKangXi=119.5
25E53 CJK UNIFIED IDEOGRAPH-#25E53, IRGKangXi=0908.121, RSKangXi=119.5
25E54 CJK UNIFIED IDEOGRAPH-#25E54, IRGKangXi=0908.121, RSKangXi=119.5
25E55 CJK UNIFIED IDEOGRAPH-#25E55, IRGKangXi=0908.121, RSKangXi=119.5
25E56 CJK UNIFIED IDEOGRAPH-#25E56, IRGKangXi=0908.121, RSKangXi=119.5
25E57 CJK UNIFIED IDEOGRAPH-#25E57, IRGKangXi=0908.121, RSKangXi=119.6
25E58 CJK UNIFIED IDEOGRAPH-#25E58, IRGKangXi=0908.121, RSKangXi=119.5
25E59 CJK UNIFIED IDEOGRAPH-#25E59, IRGKangXi=0908.121, RSKangXi=119.5
25E5A CJK UNIFIED IDEOGRAPH-#25E5A, IRGKangXi=0908.230, RSKangXi=119.6
25E5B CJK UNIFIED IDEOGRAPH-#25E5B, IRGKangXi=0908.260, RSKangXi=119.6
25E5C CJK UNIFIED IDEOGRAPH-#25E5C, IRGKangXi=0908.300, RSKangXi=119.6
25E5D CJK UNIFIED IDEOGRAPH-#25E5D, IRGKangXi=0908.310, RSKangXi=119.6
25E5E CJK UNIFIED IDEOGRAPH-#25E5E, IRGKangXi=0908.350, RSKangXi=119.6
25E5F CJK UNIFIED IDEOGRAPH-#25E5F, IRGKangXi=0909.020, RSKangXi=119.6
25E60 CJK UNIFIED IDEOGRAPH-#25E60, IRGKangXi=0909.030, RSKangXi=119.6
25E61 CJK UNIFIED IDEOGRAPH-#25E61, IRGKangXi=0909.040, RSKangXi=119.6
25E62 CJK UNIFIED IDEOGRAPH-#25E62, IRGKangXi=0909.050, RSKangXi=119.6
25E63 CJK UNIFIED IDEOGRAPH-#25E63, IRGKangXi=0909.060, RSKangXi=119.6
25E64 CJK UNIFIED IDEOGRAPH-#25E64, IRGKangXi=0909.071, RSKangXi=119.6
25E65 CJK UNIFIED IDEOGRAPH-#25E65, IRGKangXi=0909.071, RSKangXi=119.6
25E66 CJK UNIFIED IDEOGRAPH-#25E66, IRGKangXi=0909.071, RSKangXi=119.6
25E67 CJK UNIFIED IDEOGRAPH-#25E67, IRGKangXi=0909.071, RSKangXi=119.6
25E68 CJK UNIFIED IDEOGRAPH-#25E68, IRGKangXi=0909.071, RSKangXi=119.6
25E69 CJK UNIFIED IDEOGRAPH-#25E69, IRGKangXi=0909.071, RSKangXi=119.6
25E6A CJK UNIFIED IDEOGRAPH-#25E6A, IRGKangXi=0909.071, RSKangXi=119.6
25E6B CJK UNIFIED IDEOGRAPH-#25E6B, IRGKangXi=0909.071, RSKangXi=119.6
25E6C CJK UNIFIED IDEOGRAPH-#25E6C, IRGKangXi=0909.071, RSKangXi=119.6
25E6D CJK UNIFIED IDEOGRAPH-#25E6D, IRGKangXi=0909.071, RSKangXi=119.6
25E6E CJK UNIFIED IDEOGRAPH-#25E6E, IRGKangXi=0909.071, RSKangXi=119.6
25E6F CJK UNIFIED IDEOGRAPH-#25E6F, IRGKangXi=0909.071, RSKangXi=119.6
25E70 CJK UNIFIED IDEOGRAPH-#25E70, IRGKangXi=0909.071, RSKangXi=119.6
25E71 CJK UNIFIED IDEOGRAPH-#25E71, IRGKangXi=0909.071, RSKangXi=119.5
25E72 CJK UNIFIED IDEOGRAPH-#25E72, IRGKangXi=0909.080, RSKangXi=119.7
25E73 CJK UNIFIED IDEOGRAPH-#25E73, IRGKangXi=0909.090, RSKangXi=119.7
25E74 CJK UNIFIED IDEOGRAPH-#25E74, IRGKangXi=0909.120, RSKangXi=119.7
25E75 CJK UNIFIED IDEOGRAPH-#25E75, IRGKangXi=0909.150, RSKangXi=119.7
25E76 CJK UNIFIED IDEOGRAPH-#25E76, IRGKangXi=0909.160, RSKangXi=119.7
25E77 CJK UNIFIED IDEOGRAPH-#25E77, IRGKangXi=0909.190, RSKangXi=119.7
25E78 CJK UNIFIED IDEOGRAPH-#25E78, IRGKangXi=0909.210, RSKangXi=119.7
25E79 CJK UNIFIED IDEOGRAPH-#25E79, IRGKangXi=0909.250, RSKangXi=119.7
25E7A CJK UNIFIED IDEOGRAPH-#25E7A, IRGKangXi=0909.260, RSKangXi=119.7
25E7B CJK UNIFIED IDEOGRAPH-#25E7B, IRGKangXi=0909.270, RSKangXi=119.7
25E7C CJK UNIFIED IDEOGRAPH-#25E7C, IRGKangXi=0909.280, RSKangXi=119.7
25E7D CJK UNIFIED IDEOGRAPH-#25E7D, IRGKangXi=0909.290, RSKangXi=119.7
25E7E CJK UNIFIED IDEOGRAPH-#25E7E, IRGKangXi=0909.300, RSKangXi=119.7
25E7F CJK UNIFIED IDEOGRAPH-#25E7F, IRGKangXi=0909.310, RSKangXi=119.7
25E80 CJK UNIFIED IDEOGRAPH-#25E80, IRGKangXi=0909.311, RSKangXi=119.7
25E81 CJK UNIFIED IDEOGRAPH-#25E81, IRGKangXi=0909.311, RSKangXi=119.7
25E82 CJK UNIFIED IDEOGRAPH-#25E82, IRGKangXi=0909.311, RSKangXi=119.7
25E83 CJK UNIFIED IDEOGRAPH-#25E83, IRGKangXi=0909.311, RSKangXi=119.7
25E84 CJK UNIFIED IDEOGRAPH-#25E84, IRGKangXi=0909.311, RSKangXi=119.7
25E85 CJK UNIFIED IDEOGRAPH-#25E85, IRGKangXi=0909.311, RSKangXi=119.7
25E86 CJK UNIFIED IDEOGRAPH-#25E86, IRGKangXi=0909.311, RSKangXi=119.7
25E87 CJK UNIFIED IDEOGRAPH-#25E87, IRGKangXi=0909.311, RSKangXi=119.7
25E88 CJK UNIFIED IDEOGRAPH-#25E88, IRGKangXi=0909.311, RSKangXi=119.7
25E89 CJK UNIFIED IDEOGRAPH-#25E89, IRGKangXi=0909.311, RSKangXi=119.7
25E8A CJK UNIFIED IDEOGRAPH-#25E8A, IRGKangXi=0909.311, RSKangXi=119.7
25E8B CJK UNIFIED IDEOGRAPH-#25E8B, IRGKangXi=0909.311, RSKangXi=119.7
25E8C CJK UNIFIED IDEOGRAPH-#25E8C, IRGKangXi=0909.311, RSKangXi=119.7
25E8D CJK UNIFIED IDEOGRAPH-#25E8D, IRGKangXi=0909.311, RSKangXi=119.7
25E8E CJK UNIFIED IDEOGRAPH-#25E8E, IRGKangXi=0909.311, RSKangXi=119.7
25E8F CJK UNIFIED IDEOGRAPH-#25E8F, IRGKangXi=0909.311, RSKangXi=119.7
25E90 CJK UNIFIED IDEOGRAPH-#25E90, IRGKangXi=0909.311, RSKangXi=119.7
25E91 CJK UNIFIED IDEOGRAPH-#25E91, IRGKangXi=0909.311, RSKangXi=119.7
25E92 CJK UNIFIED IDEOGRAPH-#25E92, IRGKangXi=0909.311, RSKangXi=119.7
25E93 CJK UNIFIED IDEOGRAPH-#25E93, IRGKangXi=0909.311, RSKangXi=119.7
25E94 CJK UNIFIED IDEOGRAPH-#25E94, IRGKangXi=0909.311, RSKangXi=119.7
25E95 CJK UNIFIED IDEOGRAPH-#25E95, IRGKangXi=0909.311, RSKangXi=119.7
25E96 CJK UNIFIED IDEOGRAPH-#25E96, IRGKangXi=0909.311, RSKangXi=119.7
25E97 CJK UNIFIED IDEOGRAPH-#25E97, IRGKangXi=0909.311, RSKangXi=119.7
25E98 CJK UNIFIED IDEOGRAPH-#25E98, IRGKangXi=0909.340, RSKangXi=119.8
25E99 CJK UNIFIED IDEOGRAPH-#25E99, IRGKangXi=0909.370, RSKangXi=119.8
25E9A CJK UNIFIED IDEOGRAPH-#25E9A, IRGKangXi=0909.380, RSKangXi=119.8
25E9B CJK UNIFIED IDEOGRAPH-#25E9B, IRGKangXi=0910.020, RSKangXi=119.8
25E9C CJK UNIFIED IDEOGRAPH-#25E9C, IRGKangXi=0910.080, RSKangXi=119.8
25E9D CJK UNIFIED IDEOGRAPH-#25E9D, IRGKangXi=0910.090, RSKangXi=119.8
25E9E CJK UNIFIED IDEOGRAPH-#25E9E, IRGKangXi=0910.130, RSKangXi=119.8
25E9F CJK UNIFIED IDEOGRAPH-#25E9F, IRGKangXi=0910.140, RSKangXi=119.8
25EA0 CJK UNIFIED IDEOGRAPH-#25EA0, IRGKangXi=0910.150, RSKangXi=119.8
25EA1 CJK UNIFIED IDEOGRAPH-#25EA1, IRGKangXi=0910.160, RSKangXi=119.8
25EA2 CJK UNIFIED IDEOGRAPH-#25EA2, IRGKangXi=0910.180, RSKangXi=119.8
25EA3 CJK UNIFIED IDEOGRAPH-#25EA3, IRGKangXi=0910.190, RSKangXi=119.8
25EA4 CJK UNIFIED IDEOGRAPH-#25EA4, IRGKangXi=0910.200, RSKangXi=119.8
25EA5 CJK UNIFIED IDEOGRAPH-#25EA5, IRGKangXi=0910.201, RSKangXi=119.8
25EA6 CJK UNIFIED IDEOGRAPH-#25EA6, IRGKangXi=0910.201, RSKangXi=119.8
25EA7 CJK UNIFIED IDEOGRAPH-#25EA7, IRGKangXi=0910.201, RSKangXi=119.8
25EA8 CJK UNIFIED IDEOGRAPH-#25EA8, IRGKangXi=0910.201, RSKangXi=119.8
25EA9 CJK UNIFIED IDEOGRAPH-#25EA9, IRGKangXi=0910.201, RSKangXi=119.8
25EAA CJK UNIFIED IDEOGRAPH-#25EAA, IRGKangXi=0910.201, RSKangXi=119.8
25EAB CJK UNIFIED IDEOGRAPH-#25EAB, IRGKangXi=0910.201, RSKangXi=119.8
25EAC CJK UNIFIED IDEOGRAPH-#25EAC, IRGKangXi=0910.201, RSKangXi=119.8
25EAD CJK UNIFIED IDEOGRAPH-#25EAD, IRGKangXi=0910.201, RSKangXi=119.8
25EAE CJK UNIFIED IDEOGRAPH-#25EAE, IRGKangXi=0910.201, RSKangXi=119.8
25EAF CJK UNIFIED IDEOGRAPH-#25EAF, IRGKangXi=0910.201, RSKangXi=119.8
25EB0 CJK UNIFIED IDEOGRAPH-#25EB0, IRGKangXi=0910.201, RSKangXi=119.8
25EB1 CJK UNIFIED IDEOGRAPH-#25EB1, IRGKangXi=0910.201, RSKangXi=119.8
25EB2 CJK UNIFIED IDEOGRAPH-#25EB2, IRGKangXi=0910.201, RSKangXi=119.8
25EB3 CJK UNIFIED IDEOGRAPH-#25EB3, IRGKangXi=0910.201, RSKangXi=119.8
25EB4 CJK UNIFIED IDEOGRAPH-#25EB4, IRGKangXi=0910.201, RSKangXi=119.8
25EB5 CJK UNIFIED IDEOGRAPH-#25EB5, IRGKangXi=0910.201, RSKangXi=119.8
25EB6 CJK UNIFIED IDEOGRAPH-#25EB6, IRGKangXi=0910.201, RSKangXi=119.8
25EB7 CJK UNIFIED IDEOGRAPH-#25EB7, IRGKangXi=0910.201, RSKangXi=119.8
25EB8 CJK UNIFIED IDEOGRAPH-#25EB8, IRGKangXi=0910.201, RSKangXi=119.8
25EB9 CJK UNIFIED IDEOGRAPH-#25EB9, IRGKangXi=0910.201, RSKangXi=119.8
25EBA CJK UNIFIED IDEOGRAPH-#25EBA, IRGKangXi=0910.201, RSKangXi=119.8
25EBB CJK UNIFIED IDEOGRAPH-#25EBB, IRGKangXi=0910.201, RSKangXi=119.8
25EBC CJK UNIFIED IDEOGRAPH-#25EBC, IRGKangXi=0910.201, RSKangXi=119.8
25EBD CJK UNIFIED IDEOGRAPH-#25EBD, IRGKangXi=0910.201, RSKangXi=119.8
25EBE CJK UNIFIED IDEOGRAPH-#25EBE, IRGKangXi=0910.201, RSKangXi=119.8
25EBF CJK UNIFIED IDEOGRAPH-#25EBF, IRGKangXi=0910.201, RSKangXi=119.8
25EC0 CJK UNIFIED IDEOGRAPH-#25EC0, IRGKangXi=0910.211, RSKangXi=119.8
25EC1 CJK UNIFIED IDEOGRAPH-#25EC1, IRGKangXi=0910.280, RSKangXi=119.9
25EC2 CJK UNIFIED IDEOGRAPH-#25EC2, IRGKangXi=0910.290, RSKangXi=119.9
25EC3 CJK UNIFIED IDEOGRAPH-#25EC3, IRGKangXi=0910.330, RSKangXi=119.9
25EC4 CJK UNIFIED IDEOGRAPH-#25EC4, IRGKangXi=0910.340, RSKangXi=119.9
25EC5 CJK UNIFIED IDEOGRAPH-#25EC5, IRGKangXi=0910.360, RSKangXi=119.9
25EC6 CJK UNIFIED IDEOGRAPH-#25EC6, IRGKangXi=0911.010, RSKangXi=119.9
25EC7 CJK UNIFIED IDEOGRAPH-#25EC7, IRGKangXi=0911.020, RSKangXi=119.9
25EC8 CJK UNIFIED IDEOGRAPH-#25EC8, IRGKangXi=0911.040, RSKangXi=119.9
25EC9 CJK UNIFIED IDEOGRAPH-#25EC9, IRGKangXi=0911.050, RSKangXi=119.9
25ECA CJK UNIFIED IDEOGRAPH-#25ECA, IRGKangXi=0911.100, RSKangXi=119.9
25ECB CJK UNIFIED IDEOGRAPH-#25ECB, IRGKangXi=0911.110, RSKangXi=119.9
25ECC CJK UNIFIED IDEOGRAPH-#25ECC, IRGKangXi=0911.120, RSKangXi=119.9
25ECD CJK UNIFIED IDEOGRAPH-#25ECD, IRGKangXi=0911.130, RSKangXi=119.9
25ECE CJK UNIFIED IDEOGRAPH-#25ECE, IRGKangXi=0911.150, RSKangXi=119.9
25ECF CJK UNIFIED IDEOGRAPH-#25ECF, IRGKangXi=0911.160, RSKangXi=119.9
25ED0 CJK UNIFIED IDEOGRAPH-#25ED0, IRGKangXi=0911.170, RSKangXi=119.9
25ED1 CJK UNIFIED IDEOGRAPH-#25ED1, IRGKangXi=0911.180, RSKangXi=119.9
25ED2 CJK UNIFIED IDEOGRAPH-#25ED2, IRGKangXi=0911.200, RSKangXi=119.9
25ED3 CJK UNIFIED IDEOGRAPH-#25ED3, IRGKangXi=0911.210, RSKangXi=119.9
25ED4 CJK UNIFIED IDEOGRAPH-#25ED4, IRGKangXi=0911.220, RSKangXi=119.9
25ED5 CJK UNIFIED IDEOGRAPH-#25ED5, IRGKangXi=0911.230, RSKangXi=119.9
25ED6 CJK UNIFIED IDEOGRAPH-#25ED6, IRGKangXi=0911.240, RSKangXi=119.9
25ED7 CJK UNIFIED IDEOGRAPH-#25ED7, IRGKangXi=0911.241, RSKangXi=119.9
25ED8 CJK UNIFIED IDEOGRAPH-#25ED8, IRGKangXi=0911.241, RSKangXi=119.9
25ED9 CJK UNIFIED IDEOGRAPH-#25ED9, IRGKangXi=0911.241, RSKangXi=119.9
25EDA CJK UNIFIED IDEOGRAPH-#25EDA, IRGKangXi=0911.241, RSKangXi=119.9
25EDB CJK UNIFIED IDEOGRAPH-#25EDB, IRGKangXi=0911.241, RSKangXi=119.9
25EDC CJK UNIFIED IDEOGRAPH-#25EDC, IRGKangXi=0911.241, RSKangXi=119.9
25EDD CJK UNIFIED IDEOGRAPH-#25EDD, IRGKangXi=0911.241, RSKangXi=119.9
25EDE CJK UNIFIED IDEOGRAPH-#25EDE, IRGKangXi=0911.241, RSKangXi=119.9
25EDF CJK UNIFIED IDEOGRAPH-#25EDF, IRGKangXi=0911.241, RSKangXi=119.9, Def{glutinous rice}
25EE0 CJK UNIFIED IDEOGRAPH-#25EE0, IRGKangXi=0911.241, RSKangXi=119.9
25EE1 CJK UNIFIED IDEOGRAPH-#25EE1, IRGKangXi=0911.241, RSKangXi=119.9
25EE2 CJK UNIFIED IDEOGRAPH-#25EE2, IRGKangXi=0911.241, RSKangXi=119.9
25EE3 CJK UNIFIED IDEOGRAPH-#25EE3, IRGKangXi=0911.241, RSKangXi=119.9
25EE4 CJK UNIFIED IDEOGRAPH-#25EE4, IRGKangXi=0911.250, RSKangXi=119.10
25EE5 CJK UNIFIED IDEOGRAPH-#25EE5, IRGKangXi=0911.260, RSKangXi=119.10
25EE6 CJK UNIFIED IDEOGRAPH-#25EE6, IRGKangXi=0911.300, RSKangXi=119.10
25EE7 CJK UNIFIED IDEOGRAPH-#25EE7, IRGKangXi=0911.320, RSKangXi=119.10
25EE8 CJK UNIFIED IDEOGRAPH-#25EE8, IRGKangXi=0911.340, RSKangXi=119.10
25EE9 CJK UNIFIED IDEOGRAPH-#25EE9, IRGKangXi=0912.010, RSKangXi=119.10
25EEA CJK UNIFIED IDEOGRAPH-#25EEA, IRGKangXi=0912.020, RSKangXi=119.10
25EEB CJK UNIFIED IDEOGRAPH-#25EEB, IRGKangXi=0912.040, RSKangXi=119.10
25EEC CJK UNIFIED IDEOGRAPH-#25EEC, IRGKangXi=0912.050, RSKangXi=119.10
25EED CJK UNIFIED IDEOGRAPH-#25EED, IRGKangXi=0912.060, RSKangXi=119.10
25EEE CJK UNIFIED IDEOGRAPH-#25EEE, IRGKangXi=0912.070, RSKangXi=119.10
25EEF CJK UNIFIED IDEOGRAPH-#25EEF, IRGKangXi=0912.080, RSKangXi=119.10
25EF0 CJK UNIFIED IDEOGRAPH-#25EF0, IRGKangXi=0912.100, RSKangXi=119.10
25EF1 CJK UNIFIED IDEOGRAPH-#25EF1, IRGKangXi=0912.101, RSKangXi=119.10
25EF2 CJK UNIFIED IDEOGRAPH-#25EF2, IRGKangXi=0912.101, RSKangXi=119.10
25EF3 CJK UNIFIED IDEOGRAPH-#25EF3, IRGKangXi=0912.101, RSKangXi=119.10
25EF4 CJK UNIFIED IDEOGRAPH-#25EF4, IRGKangXi=0912.101, RSKangXi=119.10
25EF5 CJK UNIFIED IDEOGRAPH-#25EF5, IRGKangXi=0912.101, RSKangXi=119.10
25EF6 CJK UNIFIED IDEOGRAPH-#25EF6, IRGKangXi=0912.101, RSKangXi=119.10
25EF7 CJK UNIFIED IDEOGRAPH-#25EF7, IRGKangXi=0912.101, RSKangXi=119.10
25EF8 CJK UNIFIED IDEOGRAPH-#25EF8, IRGKangXi=0912.101, RSKangXi=119.10
25EF9 CJK UNIFIED IDEOGRAPH-#25EF9, IRGKangXi=0912.101, RSKangXi=119.10
25EFA CJK UNIFIED IDEOGRAPH-#25EFA, IRGKangXi=0912.101, RSKangXi=119.10
25EFB CJK UNIFIED IDEOGRAPH-#25EFB, IRGKangXi=0912.101, RSKangXi=119.10
25EFC CJK UNIFIED IDEOGRAPH-#25EFC, IRGKangXi=0912.101, RSKangXi=119.10
25EFD CJK UNIFIED IDEOGRAPH-#25EFD, IRGKangXi=0912.101, RSKangXi=119.10
25EFE CJK UNIFIED IDEOGRAPH-#25EFE, IRGKangXi=0912.101, RSKangXi=119.10
25EFF CJK UNIFIED IDEOGRAPH-#25EFF, IRGKangXi=0912.130, RSKangXi=119.11
25F00 CJK UNIFIED IDEOGRAPH-#25F00, IRGKangXi=0912.140, RSKangXi=119.11
25F01 CJK UNIFIED IDEOGRAPH-#25F01, IRGKangXi=0912.190, RSKangXi=119.11
25F02 CJK UNIFIED IDEOGRAPH-#25F02, IRGKangXi=0912.220, RSKangXi=119.11
25F03 CJK UNIFIED IDEOGRAPH-#25F03, IRGKangXi=0912.240, RSKangXi=119.11
25F04 CJK UNIFIED IDEOGRAPH-#25F04, IRGKangXi=0912.320, RSKangXi=119.11
25F05 CJK UNIFIED IDEOGRAPH-#25F05, IRGKangXi=0912.340, RSKangXi=119.11
25F06 CJK UNIFIED IDEOGRAPH-#25F06, IRGKangXi=0912.350, RSKangXi=119.11
25F07 CJK UNIFIED IDEOGRAPH-#25F07, IRGKangXi=0912.360, RSKangXi=119.11
25F08 CJK UNIFIED IDEOGRAPH-#25F08, IRGKangXi=0912.370, RSKangXi=119.11
25F09 CJK UNIFIED IDEOGRAPH-#25F09, IRGKangXi=0912.390, RSKangXi=119.11
25F0A CJK UNIFIED IDEOGRAPH-#25F0A, IRGKangXi=0912.391, RSKangXi=119.11
25F0B CJK UNIFIED IDEOGRAPH-#25F0B, IRGKangXi=0912.391, RSKangXi=119.11
25F0C CJK UNIFIED IDEOGRAPH-#25F0C, IRGKangXi=0912.391, RSKangXi=119.11
25F0D CJK UNIFIED IDEOGRAPH-#25F0D, IRGKangXi=0912.391, RSKangXi=119.11
25F0E CJK UNIFIED IDEOGRAPH-#25F0E, IRGKangXi=0912.391, RSKangXi=119.11
25F0F CJK UNIFIED IDEOGRAPH-#25F0F, IRGKangXi=0912.391, RSKangXi=119.11
25F10 CJK UNIFIED IDEOGRAPH-#25F10, IRGKangXi=0912.391, RSKangXi=119.11
25F11 CJK UNIFIED IDEOGRAPH-#25F11, IRGKangXi=0912.391, RSKangXi=119.11
25F12 CJK UNIFIED IDEOGRAPH-#25F12, IRGKangXi=0912.391, RSKangXi=119.11
25F13 CJK UNIFIED IDEOGRAPH-#25F13, IRGKangXi=0912.391, RSKangXi=119.11
25F14 CJK UNIFIED IDEOGRAPH-#25F14, IRGKangXi=0912.391, RSKangXi=119.11
25F15 CJK UNIFIED IDEOGRAPH-#25F15, IRGKangXi=0912.391, RSKangXi=119.11
25F16 CJK UNIFIED IDEOGRAPH-#25F16, IRGKangXi=0912.391, RSKangXi=119.11
25F17 CJK UNIFIED IDEOGRAPH-#25F17, IRGKangXi=0912.400, RSKangXi=119.12
25F18 CJK UNIFIED IDEOGRAPH-#25F18, IRGKangXi=0912.430, RSKangXi=119.12
25F19 CJK UNIFIED IDEOGRAPH-#25F19, IRGKangXi=0912.440, RSKangXi=119.12
25F1A CJK UNIFIED IDEOGRAPH-#25F1A, IRGKangXi=0912.460, RSKangXi=119.12
25F1B CJK UNIFIED IDEOGRAPH-#25F1B, IRGKangXi=0913.020, RSKangXi=119.12
25F1C CJK UNIFIED IDEOGRAPH-#25F1C, IRGKangXi=0913.050, RSKangXi=119.12
25F1D CJK UNIFIED IDEOGRAPH-#25F1D, IRGKangXi=0913.100, RSKangXi=119.12
25F1E CJK UNIFIED IDEOGRAPH-#25F1E, IRGKangXi=0913.110, RSKangXi=119.12
25F1F CJK UNIFIED IDEOGRAPH-#25F1F, IRGKangXi=0913.120, RSKangXi=119.12
25F20 CJK UNIFIED IDEOGRAPH-#25F20, IRGKangXi=0913.140, RSKangXi=119.12
25F21 CJK UNIFIED IDEOGRAPH-#25F21, IRGKangXi=0913.141, RSKangXi=119.12
25F22 CJK UNIFIED IDEOGRAPH-#25F22, IRGKangXi=0913.141, RSKangXi=119.12
25F23 CJK UNIFIED IDEOGRAPH-#25F23, IRGKangXi=0913.141, RSKangXi=119.12
25F24 CJK UNIFIED IDEOGRAPH-#25F24, IRGKangXi=0913.141, RSKangXi=119.12
25F25 CJK UNIFIED IDEOGRAPH-#25F25, IRGKangXi=0913.141, RSKangXi=119.12
25F26 CJK UNIFIED IDEOGRAPH-#25F26, IRGKangXi=0913.141, RSKangXi=119.12
25F27 CJK UNIFIED IDEOGRAPH-#25F27, IRGKangXi=0913.141, RSKangXi=119.12
25F28 CJK UNIFIED IDEOGRAPH-#25F28, IRGKangXi=0913.141, RSKangXi=119.12
25F29 CJK UNIFIED IDEOGRAPH-#25F29, IRGKangXi=0913.141, RSKangXi=119.12
25F2A CJK UNIFIED IDEOGRAPH-#25F2A, IRGKangXi=0913.141, RSKangXi=119.12
25F2B CJK UNIFIED IDEOGRAPH-#25F2B, IRGKangXi=0913.141, RSKangXi=119.12
25F2C CJK UNIFIED IDEOGRAPH-#25F2C, IRGKangXi=0913.141, RSKangXi=119.12
25F2D CJK UNIFIED IDEOGRAPH-#25F2D, IRGKangXi=0913.141, RSKangXi=119.12
25F2E CJK UNIFIED IDEOGRAPH-#25F2E, IRGKangXi=0913.141, RSKangXi=119.12
25F2F CJK UNIFIED IDEOGRAPH-#25F2F, IRGKangXi=0913.141, RSKangXi=119.12
25F30 CJK UNIFIED IDEOGRAPH-#25F30, IRGKangXi=0913.141, RSKangXi=119.12
25F31 CJK UNIFIED IDEOGRAPH-#25F31, IRGKangXi=0913.141, RSKangXi=119.12
25F32 CJK UNIFIED IDEOGRAPH-#25F32, IRGKangXi=0913.141, RSKangXi=119.12
25F33 CJK UNIFIED IDEOGRAPH-#25F33, IRGKangXi=0913.141, RSKangXi=119.12
25F34 CJK UNIFIED IDEOGRAPH-#25F34, IRGKangXi=0913.141, RSKangXi=119.12
25F35 CJK UNIFIED IDEOGRAPH-#25F35, IRGKangXi=0913.141, RSKangXi=119.12
25F36 CJK UNIFIED IDEOGRAPH-#25F36, IRGKangXi=0913.150, RSKangXi=119.13
25F37 CJK UNIFIED IDEOGRAPH-#25F37, IRGKangXi=0913.160, RSKangXi=119.13
25F38 CJK UNIFIED IDEOGRAPH-#25F38, IRGKangXi=0913.220, RSKangXi=119.13
25F39 CJK UNIFIED IDEOGRAPH-#25F39, IRGKangXi=0913.230, RSKangXi=119.13
25F3A CJK UNIFIED IDEOGRAPH-#25F3A, IRGKangXi=0913.240, RSKangXi=119.13
25F3B CJK UNIFIED IDEOGRAPH-#25F3B, IRGKangXi=0913.250, RSKangXi=119.13
25F3C CJK UNIFIED IDEOGRAPH-#25F3C, IRGKangXi=0913.260, RSKangXi=119.13
25F3D CJK UNIFIED IDEOGRAPH-#25F3D, IRGKangXi=0913.270, RSKangXi=119.13
25F3E CJK UNIFIED IDEOGRAPH-#25F3E, IRGKangXi=0913.280, RSKangXi=119.13
25F3F CJK UNIFIED IDEOGRAPH-#25F3F, IRGKangXi=0913.290, RSKangXi=119.13
25F40 CJK UNIFIED IDEOGRAPH-#25F40, IRGKangXi=0913.300, RSKangXi=119.13
25F41 CJK UNIFIED IDEOGRAPH-#25F41, IRGKangXi=0913.310, RSKangXi=119.13
25F42 CJK UNIFIED IDEOGRAPH-#25F42, IRGKangXi=0913.320, RSKangXi=119.13
25F43 CJK UNIFIED IDEOGRAPH-#25F43, IRGKangXi=0913.330, RSKangXi=119.13
25F44 CJK UNIFIED IDEOGRAPH-#25F44, IRGKangXi=0913.341, RSKangXi=119.13
25F45 CJK UNIFIED IDEOGRAPH-#25F45, IRGKangXi=0913.341, RSKangXi=119.13
25F46 CJK UNIFIED IDEOGRAPH-#25F46, IRGKangXi=0913.341, RSKangXi=119.13
25F47 CJK UNIFIED IDEOGRAPH-#25F47, IRGKangXi=0913.341, RSKangXi=119.13
25F48 CJK UNIFIED IDEOGRAPH-#25F48, IRGKangXi=0913.341, RSKangXi=119.13
25F49 CJK UNIFIED IDEOGRAPH-#25F49, IRGKangXi=0913.341, RSKangXi=119.13
25F4A CJK UNIFIED IDEOGRAPH-#25F4A, IRGKangXi=0913.341, RSKangXi=119.13
25F4B CJK UNIFIED IDEOGRAPH-#25F4B, IRGKangXi=0913.341, RSKangXi=119.13
25F4C CJK UNIFIED IDEOGRAPH-#25F4C, IRGKangXi=0913.341, RSKangXi=119.13
25F4D CJK UNIFIED IDEOGRAPH-#25F4D, IRGKangXi=0913.341, RSKangXi=119.13
25F4E CJK UNIFIED IDEOGRAPH-#25F4E, IRGKangXi=0913.341, RSKangXi=119.13
25F4F CJK UNIFIED IDEOGRAPH-#25F4F, IRGKangXi=0913.360, RSKangXi=119.14
25F50 CJK UNIFIED IDEOGRAPH-#25F50, IRGKangXi=0913.400, RSKangXi=119.14
25F51 CJK UNIFIED IDEOGRAPH-#25F51, IRGKangXi=0913.420, RSKangXi=119.14
25F52 CJK UNIFIED IDEOGRAPH-#25F52, IRGKangXi=0913.430, RSKangXi=119.14
25F53 CJK UNIFIED IDEOGRAPH-#25F53, IRGKangXi=0913.431, RSKangXi=119.14
25F54 CJK UNIFIED IDEOGRAPH-#25F54, IRGKangXi=0913.431, RSKangXi=119.14
25F55 CJK UNIFIED IDEOGRAPH-#25F55, IRGKangXi=0913.431, RSKangXi=119.14
25F56 CJK UNIFIED IDEOGRAPH-#25F56, IRGKangXi=0913.431, RSKangXi=119.14
25F57 CJK UNIFIED IDEOGRAPH-#25F57, IRGKangXi=0913.440, RSKangXi=119.15
25F58 CJK UNIFIED IDEOGRAPH-#25F58, IRGKangXi=0913.480, RSKangXi=119.15, Def{broken grain}
25F59 CJK UNIFIED IDEOGRAPH-#25F59, IRGKangXi=0913.490, RSKangXi=119.15
25F5A CJK UNIFIED IDEOGRAPH-#25F5A, IRGKangXi=0913.500, RSKangXi=119.15
25F5B CJK UNIFIED IDEOGRAPH-#25F5B, IRGKangXi=0913.510, RSKangXi=119.15
25F5C CJK UNIFIED IDEOGRAPH-#25F5C, IRGKangXi=0913.511, RSKangXi=119.15
25F5D CJK UNIFIED IDEOGRAPH-#25F5D, IRGKangXi=0913.511, RSKangXi=119.15
25F5E CJK UNIFIED IDEOGRAPH-#25F5E, IRGKangXi=0913.511, RSKangXi=119.15
25F5F CJK UNIFIED IDEOGRAPH-#25F5F, IRGKangXi=0913.511, RSKangXi=119.15
25F60 CJK UNIFIED IDEOGRAPH-#25F60, IRGKangXi=0913.511, RSKangXi=119.15
25F61 CJK UNIFIED IDEOGRAPH-#25F61, IRGKangXi=0913.511, RSKangXi=119.16
25F62 CJK UNIFIED IDEOGRAPH-#25F62, IRGKangXi=0913.511, RSKangXi=119.15
25F63 CJK UNIFIED IDEOGRAPH-#25F63, IRGKangXi=0913.511, RSKangXi=119.15
25F64 CJK UNIFIED IDEOGRAPH-#25F64, IRGKangXi=0913.511, RSKangXi=119.16
25F65 CJK UNIFIED IDEOGRAPH-#25F65, IRGKangXi=0913.520, RSKangXi=119.16
25F66 CJK UNIFIED IDEOGRAPH-#25F66, IRGKangXi=0913.530, RSKangXi=119.16
25F67 CJK UNIFIED IDEOGRAPH-#25F67, IRGKangXi=0914.020, RSKangXi=119.16
25F68 CJK UNIFIED IDEOGRAPH-#25F68, IRGKangXi=0914.021, RSKangXi=119.16
25F69 CJK UNIFIED IDEOGRAPH-#25F69, IRGKangXi=0914.021, RSKangXi=119.16
25F6A CJK UNIFIED IDEOGRAPH-#25F6A, IRGKangXi=0914.021, RSKangXi=119.16
25F6B CJK UNIFIED IDEOGRAPH-#25F6B, IRGKangXi=0914.021, RSKangXi=119.16
25F6C CJK UNIFIED IDEOGRAPH-#25F6C, IRGKangXi=0914.030, RSKangXi=119.17
25F6D CJK UNIFIED IDEOGRAPH-#25F6D, IRGKangXi=0914.040, RSKangXi=119.17
25F6E CJK UNIFIED IDEOGRAPH-#25F6E, IRGKangXi=0914.080, RSKangXi=119.17
25F6F CJK UNIFIED IDEOGRAPH-#25F6F, IRGKangXi=0914.081, RSKangXi=119.17
25F70 CJK UNIFIED IDEOGRAPH-#25F70, IRGKangXi=0914.081, RSKangXi=119.17
25F71 CJK UNIFIED IDEOGRAPH-#25F71, IRGKangXi=0914.090, RSKangXi=119.18
25F72 CJK UNIFIED IDEOGRAPH-#25F72, IRGKangXi=0914.100, RSKangXi=119.18
25F73 CJK UNIFIED IDEOGRAPH-#25F73, IRGKangXi=0914.110, RSKangXi=119.18
25F74 CJK UNIFIED IDEOGRAPH-#25F74, IRGKangXi=0914.120, RSKangXi=119.18
25F75 CJK UNIFIED IDEOGRAPH-#25F75, IRGKangXi=0914.121, RSKangXi=119.18
25F76 CJK UNIFIED IDEOGRAPH-#25F76, IRGKangXi=0914.130, RSKangXi=119.19
25F77 CJK UNIFIED IDEOGRAPH-#25F77, IRGKangXi=0914.160, RSKangXi=119.19
25F78 CJK UNIFIED IDEOGRAPH-#25F78, IRGKangXi=0914.170, RSKangXi=119.19
25F79 CJK UNIFIED IDEOGRAPH-#25F79, IRGKangXi=0914.190, RSKangXi=119.19
25F7A CJK UNIFIED IDEOGRAPH-#25F7A, IRGKangXi=0914.191, RSKangXi=119.19
25F7B CJK UNIFIED IDEOGRAPH-#25F7B, IRGKangXi=0914.200, RSKangXi=119.20
25F7C CJK UNIFIED IDEOGRAPH-#25F7C, IRGKangXi=0914.210, RSKangXi=119.20
25F7D CJK UNIFIED IDEOGRAPH-#25F7D, IRGKangXi=0914.220, RSKangXi=119.20
25F7E CJK UNIFIED IDEOGRAPH-#25F7E, IRGKangXi=0914.221, RSKangXi=119.20
25F7F CJK UNIFIED IDEOGRAPH-#25F7F, IRGKangXi=0914.240, RSKangXi=119.20
25F80 CJK UNIFIED IDEOGRAPH-#25F80, IRGKangXi=0914.250, RSKangXi=119.21
25F81 CJK UNIFIED IDEOGRAPH-#25F81, IRGKangXi=0914.251, RSKangXi=119.21
25F82 CJK UNIFIED IDEOGRAPH-#25F82, IRGKangXi=0914.260, RSKangXi=119.24
25F83 CJK UNIFIED IDEOGRAPH-#25F83, IRGKangXi=0914.261, RSKangXi=119.25
25F84 CJK UNIFIED IDEOGRAPH-#25F84, IRGKangXi=0914.270, RSKangXi=119.27
25F85 CJK UNIFIED IDEOGRAPH-#25F85, IRGKangXi=0915.100, RSKangXi=120.2
25F86 CJK UNIFIED IDEOGRAPH-#25F86, IRGKangXi=0915.110, RSKangXi=120.2
25F87 CJK UNIFIED IDEOGRAPH-#25F87, IRGKangXi=0915.120, RSKangXi=120.2
25F88 CJK UNIFIED IDEOGRAPH-#25F88, IRGKangXi=0915.121, RSKangXi=120.2
25F89 CJK UNIFIED IDEOGRAPH-#25F89, IRGKangXi=0915.121, RSKangXi=120.2
25F8A CJK UNIFIED IDEOGRAPH-#25F8A, IRGKangXi=0915.121, RSKangXi=120.2
25F8B CJK UNIFIED IDEOGRAPH-#25F8B, IRGKangXi=0915.121, RSKangXi=120.2
25F8C CJK UNIFIED IDEOGRAPH-#25F8C, IRGKangXi=0915.150, RSKangXi=120.3
25F8D CJK UNIFIED IDEOGRAPH-#25F8D, IRGKangXi=0915.160, RSKangXi=120.3
25F8E CJK UNIFIED IDEOGRAPH-#25F8E, IRGKangXi=0916.060, RSKangXi=120.3
25F8F CJK UNIFIED IDEOGRAPH-#25F8F, IRGKangXi=0916.070, RSKangXi=120.3
25F90 CJK UNIFIED IDEOGRAPH-#25F90, IRGKangXi=0916.080, RSKangXi=120.3
25F91 CJK UNIFIED IDEOGRAPH-#25F91, IRGKangXi=0916.100, RSKangXi=120.3
25F92 CJK UNIFIED IDEOGRAPH-#25F92, IRGKangXi=0916.110, RSKangXi=120.3
25F93 CJK UNIFIED IDEOGRAPH-#25F93, IRGKangXi=0916.120, RSKangXi=120.3
25F94 CJK UNIFIED IDEOGRAPH-#25F94, IRGKangXi=0916.121, RSKangXi=120.3
25F95 CJK UNIFIED IDEOGRAPH-#25F95, IRGKangXi=0916.121, RSKangXi=120.3
25F96 CJK UNIFIED IDEOGRAPH-#25F96, IRGKangXi=0916.121, RSKangXi=120.3
25F97 CJK UNIFIED IDEOGRAPH-#25F97, IRGKangXi=0916.121, RSKangXi=120.3
25F98 CJK UNIFIED IDEOGRAPH-#25F98, IRGKangXi=0916.121, RSKangXi=120.3
25F99 CJK UNIFIED IDEOGRAPH-#25F99, IRGKangXi=0916.140, RSKangXi=120.4
25F9A CJK UNIFIED IDEOGRAPH-#25F9A, IRGKangXi=0916.230, RSKangXi=120.4
25F9B CJK UNIFIED IDEOGRAPH-#25F9B, IRGKangXi=0916.240, RSKangXi=120.4
25F9C CJK UNIFIED IDEOGRAPH-#25F9C, IRGKangXi=0917.010, RSKangXi=120.4
25F9D CJK UNIFIED IDEOGRAPH-#25F9D, IRGKangXi=0917.030, RSKangXi=120.4
25F9E CJK UNIFIED IDEOGRAPH-#25F9E, IRGKangXi=0917.090, RSKangXi=120.4
25F9F CJK UNIFIED IDEOGRAPH-#25F9F, IRGKangXi=0917.120, RSKangXi=120.4
25FA0 CJK UNIFIED IDEOGRAPH-#25FA0, IRGKangXi=0917.140, RSKangXi=120.4
25FA1 CJK UNIFIED IDEOGRAPH-#25FA1, IRGKangXi=0917.190, RSKangXi=120.4
25FA2 CJK UNIFIED IDEOGRAPH-#25FA2, IRGKangXi=0918.020, RSKangXi=120.4
25FA3 CJK UNIFIED IDEOGRAPH-#25FA3, IRGKangXi=0918.120, RSKangXi=120.4
25FA4 CJK UNIFIED IDEOGRAPH-#25FA4, IRGKangXi=0919.010, RSKangXi=120.4
25FA5 CJK UNIFIED IDEOGRAPH-#25FA5, IRGKangXi=0919.020, RSKangXi=120.4
25FA6 CJK UNIFIED IDEOGRAPH-#25FA6, IRGKangXi=0919.030, RSKangXi=120.4
25FA7 CJK UNIFIED IDEOGRAPH-#25FA7, IRGKangXi=0919.040, RSKangXi=120.4
25FA8 CJK UNIFIED IDEOGRAPH-#25FA8, IRGKangXi=0919.060, RSKangXi=120.4
25FA9 CJK UNIFIED IDEOGRAPH-#25FA9, IRGKangXi=0919.070, RSKangXi=120.4
25FAA CJK UNIFIED IDEOGRAPH-#25FAA, IRGKangXi=0919.080, RSKangXi=120.4
25FAB CJK UNIFIED IDEOGRAPH-#25FAB, IRGKangXi=0919.090, RSKangXi=120.4
25FAC CJK UNIFIED IDEOGRAPH-#25FAC, IRGKangXi=0919.100, RSKangXi=120.4
25FAD CJK UNIFIED IDEOGRAPH-#25FAD, IRGKangXi=0919.120, RSKangXi=120.4
25FAE CJK UNIFIED IDEOGRAPH-#25FAE, IRGKangXi=0919.130, RSKangXi=120.4
25FAF CJK UNIFIED IDEOGRAPH-#25FAF, IRGKangXi=0919.140, RSKangXi=120.4
25FB0 CJK UNIFIED IDEOGRAPH-#25FB0, IRGKangXi=0919.150, RSKangXi=120.4
25FB1 CJK UNIFIED IDEOGRAPH-#25FB1, IRGKangXi=0919.171, RSKangXi=120.4
25FB2 CJK UNIFIED IDEOGRAPH-#25FB2, IRGKangXi=0919.171, RSKangXi=120.4
25FB3 CJK UNIFIED IDEOGRAPH-#25FB3, IRGKangXi=0919.171, RSKangXi=120.4
25FB4 CJK UNIFIED IDEOGRAPH-#25FB4, IRGKangXi=0919.171, RSKangXi=120.4
25FB5 CJK UNIFIED IDEOGRAPH-#25FB5, IRGKangXi=0919.171, RSKangXi=120.4
25FB6 CJK UNIFIED IDEOGRAPH-#25FB6, IRGKangXi=0919.171, RSKangXi=120.4
25FB7 CJK UNIFIED IDEOGRAPH-#25FB7, IRGKangXi=0919.171, RSKangXi=120.4
25FB8 CJK UNIFIED IDEOGRAPH-#25FB8, IRGKangXi=0919.171, RSKangXi=120.4
25FB9 CJK UNIFIED IDEOGRAPH-#25FB9, IRGKangXi=0919.171, RSKangXi=120.4
25FBA CJK UNIFIED IDEOGRAPH-#25FBA, IRGKangXi=0919.171, RSKangXi=120.4
25FBB CJK UNIFIED IDEOGRAPH-#25FBB, IRGKangXi=0919.171, RSKangXi=120.4
25FBC CJK UNIFIED IDEOGRAPH-#25FBC, IRGKangXi=0919.171, RSKangXi=120.4
25FBD CJK UNIFIED IDEOGRAPH-#25FBD, IRGKangXi=0919.171, RSKangXi=120.4
25FBE CJK UNIFIED IDEOGRAPH-#25FBE, IRGKangXi=0919.171, RSKangXi=120.4
25FBF CJK UNIFIED IDEOGRAPH-#25FBF, IRGKangXi=0919.171, RSKangXi=120.4
25FC0 CJK UNIFIED IDEOGRAPH-#25FC0, IRGKangXi=0919.171, RSKangXi=120.4
25FC1 CJK UNIFIED IDEOGRAPH-#25FC1, IRGKangXi=0919.171, RSKangXi=120.4
25FC2 CJK UNIFIED IDEOGRAPH-#25FC2, IRGKangXi=0919.171, RSKangXi=120.4
25FC3 CJK UNIFIED IDEOGRAPH-#25FC3, IRGKangXi=0919.200, RSKangXi=120.5
25FC4 CJK UNIFIED IDEOGRAPH-#25FC4, IRGKangXi=0919.210, RSKangXi=120.5
25FC5 CJK UNIFIED IDEOGRAPH-#25FC5, IRGKangXi=0919.230, RSKangXi=120.5
25FC6 CJK UNIFIED IDEOGRAPH-#25FC6, IRGKangXi=0919.270, RSKangXi=120.5
25FC7 CJK UNIFIED IDEOGRAPH-#25FC7, IRGKangXi=0919.340, RSKangXi=120.5
25FC8 CJK UNIFIED IDEOGRAPH-#25FC8, IRGKangXi=0919.380, RSKangXi=120.5
25FC9 CJK UNIFIED IDEOGRAPH-#25FC9, IRGKangXi=0920.030, RSKangXi=120.5
25FCA CJK UNIFIED IDEOGRAPH-#25FCA, IRGKangXi=0920.060, RSKangXi=120.5
25FCB CJK UNIFIED IDEOGRAPH-#25FCB, IRGKangXi=0920.100, RSKangXi=120.5
25FCC CJK UNIFIED IDEOGRAPH-#25FCC, IRGKangXi=0921.180, RSKangXi=120.5
25FCD CJK UNIFIED IDEOGRAPH-#25FCD, IRGKangXi=0921.190, RSKangXi=120.5
25FCE CJK UNIFIED IDEOGRAPH-#25FCE, IRGKangXi=0921.200, RSKangXi=120.5
25FCF CJK UNIFIED IDEOGRAPH-#25FCF, IRGKangXi=0921.210, RSKangXi=120.5
25FD0 CJK UNIFIED IDEOGRAPH-#25FD0, IRGKangXi=0921.220, RSKangXi=120.5
25FD1 CJK UNIFIED IDEOGRAPH-#25FD1, IRGKangXi=0921.240, RSKangXi=120.5
25FD2 CJK UNIFIED IDEOGRAPH-#25FD2, IRGKangXi=0921.260, RSKangXi=120.5
25FD3 CJK UNIFIED IDEOGRAPH-#25FD3, IRGKangXi=0921.280, RSKangXi=120.5
25FD4 CJK UNIFIED IDEOGRAPH-#25FD4, IRGKangXi=0921.291, RSKangXi=120.5
25FD5 CJK UNIFIED IDEOGRAPH-#25FD5, IRGKangXi=0921.291, RSKangXi=120.5
25FD6 CJK UNIFIED IDEOGRAPH-#25FD6, IRGKangXi=0921.291, RSKangXi=120.5
25FD7 CJK UNIFIED IDEOGRAPH-#25FD7, IRGKangXi=0921.291, RSKangXi=120.5
25FD8 CJK UNIFIED IDEOGRAPH-#25FD8, IRGKangXi=0921.291, RSKangXi=120.5
25FD9 CJK UNIFIED IDEOGRAPH-#25FD9, IRGKangXi=0921.291, RSKangXi=120.5
25FDA CJK UNIFIED IDEOGRAPH-#25FDA, IRGKangXi=0921.291, RSKangXi=120.5
25FDB CJK UNIFIED IDEOGRAPH-#25FDB, IRGKangXi=0921.291, RSKangXi=120.5
25FDC CJK UNIFIED IDEOGRAPH-#25FDC, IRGKangXi=0921.291, RSKangXi=120.5
25FDD CJK UNIFIED IDEOGRAPH-#25FDD, IRGKangXi=0921.291, RSKangXi=120.5
25FDE CJK UNIFIED IDEOGRAPH-#25FDE, IRGKangXi=0921.291, RSKangXi=120.5
25FDF CJK UNIFIED IDEOGRAPH-#25FDF, IRGKangXi=0921.291, RSKangXi=120.5
25FE0 CJK UNIFIED IDEOGRAPH-#25FE0, IRGKangXi=0921.291, RSKangXi=120.5
25FE1 CJK UNIFIED IDEOGRAPH-#25FE1, IRGKangXi=0921.291, RSKangXi=120.5
25FE2 CJK UNIFIED IDEOGRAPH-#25FE2, IRGKangXi=0921.291, RSKangXi=120.5
25FE3 CJK UNIFIED IDEOGRAPH-#25FE3, IRGKangXi=0921.291, RSKangXi=120.5
25FE4 CJK UNIFIED IDEOGRAPH-#25FE4, IRGKangXi=0921.291, RSKangXi=120.5
25FE5 CJK UNIFIED IDEOGRAPH-#25FE5, IRGKangXi=0921.291, RSKangXi=120.5
25FE6 CJK UNIFIED IDEOGRAPH-#25FE6, IRGKangXi=0921.350, RSKangXi=120.6
25FE7 CJK UNIFIED IDEOGRAPH-#25FE7, IRGKangXi=0922.020, RSKangXi=120.6
25FE8 CJK UNIFIED IDEOGRAPH-#25FE8, IRGKangXi=0922.090, RSKangXi=120.6
25FE9 CJK UNIFIED IDEOGRAPH-#25FE9, IRGKangXi=0922.120, RSKangXi=120.6
25FEA CJK UNIFIED IDEOGRAPH-#25FEA, IRGKangXi=0922.170, RSKangXi=120.6
25FEB CJK UNIFIED IDEOGRAPH-#25FEB, IRGKangXi=0922.180, RSKangXi=120.6
25FEC CJK UNIFIED IDEOGRAPH-#25FEC, IRGKangXi=0922.240, RSKangXi=120.6
25FED CJK UNIFIED IDEOGRAPH-#25FED, IRGKangXi=0922.250, RSKangXi=120.6
25FEE CJK UNIFIED IDEOGRAPH-#25FEE, IRGKangXi=0923.100, RSKangXi=120.6
25FEF CJK UNIFIED IDEOGRAPH-#25FEF, IRGKangXi=0923.150, RSKangXi=120.6
25FF0 CJK UNIFIED IDEOGRAPH-#25FF0, IRGKangXi=0924.010, RSKangXi=120.6
25FF1 CJK UNIFIED IDEOGRAPH-#25FF1, IRGKangXi=0924.050, RSKangXi=120.6
25FF2 CJK UNIFIED IDEOGRAPH-#25FF2, IRGKangXi=0924.060, RSKangXi=120.6
25FF3 CJK UNIFIED IDEOGRAPH-#25FF3, IRGKangXi=0924.070, RSKangXi=120.6
25FF4 CJK UNIFIED IDEOGRAPH-#25FF4, IRGKangXi=0924.080, RSKangXi=120.6
25FF5 CJK UNIFIED IDEOGRAPH-#25FF5, IRGKangXi=0924.090, RSKangXi=120.6
25FF6 CJK UNIFIED IDEOGRAPH-#25FF6, IRGKangXi=0924.100, RSKangXi=120.6
25FF7 CJK UNIFIED IDEOGRAPH-#25FF7, IRGKangXi=0924.110, RSKangXi=120.6
25FF8 CJK UNIFIED IDEOGRAPH-#25FF8, IRGKangXi=0924.140, RSKangXi=120.6
25FF9 CJK UNIFIED IDEOGRAPH-#25FF9, IRGKangXi=0924.150, RSKangXi=120.6
25FFA CJK UNIFIED IDEOGRAPH-#25FFA, IRGKangXi=0924.160, RSKangXi=120.6
25FFB CJK UNIFIED IDEOGRAPH-#25FFB, IRGKangXi=0924.161, RSKangXi=120.6
25FFC CJK UNIFIED IDEOGRAPH-#25FFC, IRGKangXi=0924.161, RSKangXi=120.6
25FFD CJK UNIFIED IDEOGRAPH-#25FFD, IRGKangXi=0924.161, RSKangXi=120.6
25FFE CJK UNIFIED IDEOGRAPH-#25FFE, IRGKangXi=0924.161, RSKangXi=120.6
25FFF CJK UNIFIED IDEOGRAPH-#25FFF, IRGKangXi=0924.161, RSKangXi=120.6
26000 CJK UNIFIED IDEOGRAPH-#26000, IRGKangXi=0924.161, RSKangXi=120.6
26001 CJK UNIFIED IDEOGRAPH-#26001, IRGKangXi=0924.161, RSKangXi=120.6
26002 CJK UNIFIED IDEOGRAPH-#26002, IRGKangXi=0924.161, RSKangXi=120.6
26003 CJK UNIFIED IDEOGRAPH-#26003, IRGKangXi=0924.161, RSKangXi=120.6
26004 CJK UNIFIED IDEOGRAPH-#26004, IRGKangXi=0924.161, RSKangXi=120.6
26005 CJK UNIFIED IDEOGRAPH-#26005, IRGKangXi=0924.161, RSKangXi=120.6
26006 CJK UNIFIED IDEOGRAPH-#26006, IRGKangXi=0924.161, RSKangXi=120.6
26007 CJK UNIFIED IDEOGRAPH-#26007, IRGKangXi=0924.161, RSKangXi=120.6, Def{the past; a classic}
26008 CJK UNIFIED IDEOGRAPH-#26008, IRGKangXi=0924.161, RSKangXi=120.6
26009 CJK UNIFIED IDEOGRAPH-#26009, IRGKangXi=0924.161, RSKangXi=120.6
2600A CJK UNIFIED IDEOGRAPH-#2600A, IRGKangXi=0924.161, RSKangXi=120.6
2600B CJK UNIFIED IDEOGRAPH-#2600B, IRGKangXi=0924.161, RSKangXi=120.6
2600C CJK UNIFIED IDEOGRAPH-#2600C, IRGKangXi=0924.161, RSKangXi=120.6
2600D CJK UNIFIED IDEOGRAPH-#2600D, IRGKangXi=0924.161, RSKangXi=120.6
2600E CJK UNIFIED IDEOGRAPH-#2600E, IRGKangXi=0924.161, RSKangXi=120.6
2600F CJK UNIFIED IDEOGRAPH-#2600F, IRGKangXi=0924.161, RSKangXi=120.6
26010 CJK UNIFIED IDEOGRAPH-#26010, IRGKangXi=0924.161, RSKangXi=120.6
26011 CJK UNIFIED IDEOGRAPH-#26011, IRGKangXi=0924.161, RSKangXi=120.6
26012 CJK UNIFIED IDEOGRAPH-#26012, IRGKangXi=0924.180, RSKangXi=120.7
26013 CJK UNIFIED IDEOGRAPH-#26013, IRGKangXi=0924.200, RSKangXi=120.7
26014 CJK UNIFIED IDEOGRAPH-#26014, IRGKangXi=0924.270, RSKangXi=120.7
26015 CJK UNIFIED IDEOGRAPH-#26015, IRGKangXi=0924.290, RSKangXi=120.7
26016 CJK UNIFIED IDEOGRAPH-#26016, IRGKangXi=0924.300, RSKangXi=120.7
26017 CJK UNIFIED IDEOGRAPH-#26017, IRGKangXi=0924.330, RSKangXi=120.7
26018 CJK UNIFIED IDEOGRAPH-#26018, IRGKangXi=0925.080, RSKangXi=120.7
26019 CJK UNIFIED IDEOGRAPH-#26019, IRGKangXi=0925.140, RSKangXi=120.7
2601A CJK UNIFIED IDEOGRAPH-#2601A, IRGKangXi=0925.190, RSKangXi=120.7
2601B CJK UNIFIED IDEOGRAPH-#2601B, IRGKangXi=0925.210, RSKangXi=120.7
2601C CJK UNIFIED IDEOGRAPH-#2601C, IRGKangXi=0926.030, RSKangXi=120.7
2601D CJK UNIFIED IDEOGRAPH-#2601D, IRGKangXi=0926.080, RSKangXi=120.7
2601E CJK UNIFIED IDEOGRAPH-#2601E, IRGKangXi=0926.090, RSKangXi=120.7
2601F CJK UNIFIED IDEOGRAPH-#2601F, IRGKangXi=0926.100, RSKangXi=120.7
26020 CJK UNIFIED IDEOGRAPH-#26020, IRGKangXi=0926.120, RSKangXi=120.7
26021 CJK UNIFIED IDEOGRAPH-#26021, IRGKangXi=0926.140, RSKangXi=120.7
26022 CJK UNIFIED IDEOGRAPH-#26022, IRGKangXi=0926.150, RSKangXi=120.7
26023 CJK UNIFIED IDEOGRAPH-#26023, IRGKangXi=0926.160, RSKangXi=120.7
26024 CJK UNIFIED IDEOGRAPH-#26024, IRGKangXi=0926.170, RSKangXi=120.7
26025 CJK UNIFIED IDEOGRAPH-#26025, IRGKangXi=0926.180, RSKangXi=120.7
26026 CJK UNIFIED IDEOGRAPH-#26026, IRGKangXi=0926.190, RSKangXi=120.7
26027 CJK UNIFIED IDEOGRAPH-#26027, IRGKangXi=0926.200, RSKangXi=120.7
26028 CJK UNIFIED IDEOGRAPH-#26028, IRGKangXi=0926.201, RSKangXi=120.7
26029 CJK UNIFIED IDEOGRAPH-#26029, IRGKangXi=0926.201, RSKangXi=120.7
2602A CJK UNIFIED IDEOGRAPH-#2602A, IRGKangXi=0926.201, RSKangXi=120.7
2602B CJK UNIFIED IDEOGRAPH-#2602B, IRGKangXi=0926.201, RSKangXi=120.7
2602C CJK UNIFIED IDEOGRAPH-#2602C, IRGKangXi=0926.201, RSKangXi=120.7
2602D CJK UNIFIED IDEOGRAPH-#2602D, IRGKangXi=0926.201, RSKangXi=120.7
2602E CJK UNIFIED IDEOGRAPH-#2602E, IRGKangXi=0926.201, RSKangXi=120.7
2602F CJK UNIFIED IDEOGRAPH-#2602F, IRGKangXi=0926.201, RSKangXi=120.7
26030 CJK UNIFIED IDEOGRAPH-#26030, IRGKangXi=0926.201, RSKangXi=120.7
26031 CJK UNIFIED IDEOGRAPH-#26031, IRGKangXi=0926.201, RSKangXi=120.7
26032 CJK UNIFIED IDEOGRAPH-#26032, IRGKangXi=0926.201, RSKangXi=120.7
26033 CJK UNIFIED IDEOGRAPH-#26033, IRGKangXi=0926.201, RSKangXi=120.7
26034 CJK UNIFIED IDEOGRAPH-#26034, IRGKangXi=0926.201, RSKangXi=120.7
26035 CJK UNIFIED IDEOGRAPH-#26035, IRGKangXi=0926.201, RSKangXi=120.7
26036 CJK UNIFIED IDEOGRAPH-#26036, IRGKangXi=0926.201, RSKangXi=120.7
26037 CJK UNIFIED IDEOGRAPH-#26037, IRGKangXi=0926.201, RSKangXi=120.7
26038 CJK UNIFIED IDEOGRAPH-#26038, IRGKangXi=0926.201, RSKangXi=120.7
26039 CJK UNIFIED IDEOGRAPH-#26039, IRGKangXi=0926.201, RSKangXi=120.7
2603A CJK UNIFIED IDEOGRAPH-#2603A, IRGKangXi=0926.201, RSKangXi=120.7
2603B CJK UNIFIED IDEOGRAPH-#2603B, IRGKangXi=0926.201, RSKangXi=120.7
2603C CJK UNIFIED IDEOGRAPH-#2603C, IRGKangXi=0926.201, RSKangXi=120.7
2603D CJK UNIFIED IDEOGRAPH-#2603D, IRGKangXi=0926.201, RSKangXi=120.7
2603E CJK UNIFIED IDEOGRAPH-#2603E, IRGKangXi=0926.201, RSKangXi=120.7
2603F CJK UNIFIED IDEOGRAPH-#2603F, IRGKangXi=0926.201, RSKangXi=120.7
26040 CJK UNIFIED IDEOGRAPH-#26040, IRGKangXi=0926.201, RSKangXi=120.7
26041 CJK UNIFIED IDEOGRAPH-#26041, IRGKangXi=0926.201, RSKangXi=120.7
26042 CJK UNIFIED IDEOGRAPH-#26042, IRGKangXi=0926.201, RSKangXi=120.7
26043 CJK UNIFIED IDEOGRAPH-#26043, IRGKangXi=0926.201, RSKangXi=120.7
26044 CJK UNIFIED IDEOGRAPH-#26044, IRGKangXi=0926.201, RSKangXi=120.7
26045 CJK UNIFIED IDEOGRAPH-#26045, IRGKangXi=0926.201, RSKangXi=120.7
26046 CJK UNIFIED IDEOGRAPH-#26046, IRGKangXi=0926.220, RSKangXi=120.8
26047 CJK UNIFIED IDEOGRAPH-#26047, IRGKangXi=0926.300, RSKangXi=120.8
26048 CJK UNIFIED IDEOGRAPH-#26048, IRGKangXi=0926.340, RSKangXi=120.8
26049 CJK UNIFIED IDEOGRAPH-#26049, IRGKangXi=0926.350, RSKangXi=120.8
2604A CJK UNIFIED IDEOGRAPH-#2604A, IRGKangXi=0926.380, RSKangXi=120.8
2604B CJK UNIFIED IDEOGRAPH-#2604B, IRGKangXi=0926.390, RSKangXi=120.8
2604C CJK UNIFIED IDEOGRAPH-#2604C, IRGKangXi=0927.070, RSKangXi=120.8
2604D CJK UNIFIED IDEOGRAPH-#2604D, IRGKangXi=0927.130, RSKangXi=120.8
2604E CJK UNIFIED IDEOGRAPH-#2604E, IRGKangXi=0928.080, RSKangXi=120.8
2604F CJK UNIFIED IDEOGRAPH-#2604F, IRGKangXi=0928.120, RSKangXi=120.8
26050 CJK UNIFIED IDEOGRAPH-#26050, IRGKangXi=0929.110, RSKangXi=120.8
26051 CJK UNIFIED IDEOGRAPH-#26051, IRGKangXi=0929.140, RSKangXi=120.8
26052 CJK UNIFIED IDEOGRAPH-#26052, IRGKangXi=0929.150, RSKangXi=120.8
26053 CJK UNIFIED IDEOGRAPH-#26053, IRGKangXi=0929.160, RSKangXi=120.8
26054 CJK UNIFIED IDEOGRAPH-#26054, IRGKangXi=0929.170, RSKangXi=120.8
26055 CJK UNIFIED IDEOGRAPH-#26055, IRGKangXi=0929.180, RSKangXi=120.8
26056 CJK UNIFIED IDEOGRAPH-#26056, IRGKangXi=0929.200, RSKangXi=120.8
26057 CJK UNIFIED IDEOGRAPH-#26057, IRGKangXi=0929.210, RSKangXi=120.8
26058 CJK UNIFIED IDEOGRAPH-#26058, IRGKangXi=0929.220, RSKangXi=120.8
26059 CJK UNIFIED IDEOGRAPH-#26059, IRGKangXi=0929.230, RSKangXi=120.8
2605A CJK UNIFIED IDEOGRAPH-#2605A, IRGKangXi=0929.250, RSKangXi=120.8
2605B CJK UNIFIED IDEOGRAPH-#2605B, IRGKangXi=0929.260, RSKangXi=120.8
2605C CJK UNIFIED IDEOGRAPH-#2605C, IRGKangXi=0929.270, RSKangXi=120.8
2605D CJK UNIFIED IDEOGRAPH-#2605D, IRGKangXi=0929.280, RSKangXi=120.8
2605E CJK UNIFIED IDEOGRAPH-#2605E, IRGKangXi=0929.290, RSKangXi=120.8
2605F CJK UNIFIED IDEOGRAPH-#2605F, IRGKangXi=0929.290, RSKangXi=120.8
26060 CJK UNIFIED IDEOGRAPH-#26060, IRGKangXi=0929.291, RSKangXi=120.8
26061 CJK UNIFIED IDEOGRAPH-#26061, IRGKangXi=0929.291, RSKangXi=120.8
26062 CJK UNIFIED IDEOGRAPH-#26062, IRGKangXi=0929.291, RSKangXi=120.8
26063 CJK UNIFIED IDEOGRAPH-#26063, IRGKangXi=0929.291, RSKangXi=120.8
26064 CJK UNIFIED IDEOGRAPH-#26064, IRGKangXi=0929.291, RSKangXi=120.8
26065 CJK UNIFIED IDEOGRAPH-#26065, IRGKangXi=0929.291, RSKangXi=120.8
26066 CJK UNIFIED IDEOGRAPH-#26066, IRGKangXi=0929.291, RSKangXi=120.8
26067 CJK UNIFIED IDEOGRAPH-#26067, IRGKangXi=0929.291, RSKangXi=120.8
26068 CJK UNIFIED IDEOGRAPH-#26068, IRGKangXi=0929.291, RSKangXi=120.8
26069 CJK UNIFIED IDEOGRAPH-#26069, IRGKangXi=0929.291, RSKangXi=120.8
2606A CJK UNIFIED IDEOGRAPH-#2606A, IRGKangXi=0929.291, RSKangXi=120.8
2606B CJK UNIFIED IDEOGRAPH-#2606B, IRGKangXi=0929.291, RSKangXi=120.8
2606C CJK UNIFIED IDEOGRAPH-#2606C, IRGKangXi=0929.291, RSKangXi=120.8
2606D CJK UNIFIED IDEOGRAPH-#2606D, IRGKangXi=0929.291, RSKangXi=120.8
2606E CJK UNIFIED IDEOGRAPH-#2606E, IRGKangXi=0929.291, RSKangXi=120.8
2606F CJK UNIFIED IDEOGRAPH-#2606F, IRGKangXi=0929.291, RSKangXi=120.8
26070 CJK UNIFIED IDEOGRAPH-#26070, IRGKangXi=0929.291, RSKangXi=120.8
26071 CJK UNIFIED IDEOGRAPH-#26071, IRGKangXi=0929.291, RSKangXi=120.8
26072 CJK UNIFIED IDEOGRAPH-#26072, IRGKangXi=0929.291, RSKangXi=120.8
26073 CJK UNIFIED IDEOGRAPH-#26073, IRGKangXi=0929.291, RSKangXi=120.8
26074 CJK UNIFIED IDEOGRAPH-#26074, IRGKangXi=0929.291, RSKangXi=120.8
26075 CJK UNIFIED IDEOGRAPH-#26075, IRGKangXi=0929.291, RSKangXi=120.8
26076 CJK UNIFIED IDEOGRAPH-#26076, IRGKangXi=0929.291, RSKangXi=120.8
26077 CJK UNIFIED IDEOGRAPH-#26077, IRGKangXi=0929.291, RSKangXi=120.8
26078 CJK UNIFIED IDEOGRAPH-#26078, IRGKangXi=0929.291, RSKangXi=120.8
26079 CJK UNIFIED IDEOGRAPH-#26079, IRGKangXi=0929.291, RSKangXi=120.8
2607A CJK UNIFIED IDEOGRAPH-#2607A, IRGKangXi=0929.291, RSKangXi=120.8
2607B CJK UNIFIED IDEOGRAPH-#2607B, IRGKangXi=0929.291, RSKangXi=120.8
2607C CJK UNIFIED IDEOGRAPH-#2607C, IRGKangXi=0929.291, RSKangXi=120.8
2607D CJK UNIFIED IDEOGRAPH-#2607D, IRGKangXi=0929.291, RSKangXi=120.8
2607E CJK UNIFIED IDEOGRAPH-#2607E, IRGKangXi=0929.291, RSKangXi=120.8
2607F CJK UNIFIED IDEOGRAPH-#2607F, IRGKangXi=0929.291, RSKangXi=120.8
26080 CJK UNIFIED IDEOGRAPH-#26080, IRGKangXi=0929.320, RSKangXi=120.9
26081 CJK UNIFIED IDEOGRAPH-#26081, IRGKangXi=0930.120, RSKangXi=120.9
26082 CJK UNIFIED IDEOGRAPH-#26082, IRGKangXi=0931.010, RSKangXi=120.9
26083 CJK UNIFIED IDEOGRAPH-#26083, IRGKangXi=0931.110, RSKangXi=120.9
26084 CJK UNIFIED IDEOGRAPH-#26084, IRGKangXi=0931.160, RSKangXi=120.9
26085 CJK UNIFIED IDEOGRAPH-#26085, IRGKangXi=0931.170, RSKangXi=120.9
26086 CJK UNIFIED IDEOGRAPH-#26086, IRGKangXi=0931.190, RSKangXi=120.9
26087 CJK UNIFIED IDEOGRAPH-#26087, IRGKangXi=0931.200, RSKangXi=120.9
26088 CJK UNIFIED IDEOGRAPH-#26088, IRGKangXi=0931.220, RSKangXi=120.9
26089 CJK UNIFIED IDEOGRAPH-#26089, IRGKangXi=0931.230, RSKangXi=120.9
2608A CJK UNIFIED IDEOGRAPH-#2608A, IRGKangXi=0931.240, RSKangXi=120.9
2608B CJK UNIFIED IDEOGRAPH-#2608B, IRGKangXi=0931.250, RSKangXi=120.9
2608C CJK UNIFIED IDEOGRAPH-#2608C, IRGKangXi=0932.010, RSKangXi=120.9
2608D CJK UNIFIED IDEOGRAPH-#2608D, IRGKangXi=0932.050, RSKangXi=120.9
2608E CJK UNIFIED IDEOGRAPH-#2608E, IRGKangXi=0932.170, RSKangXi=120.9
2608F CJK UNIFIED IDEOGRAPH-#2608F, IRGKangXi=0932.180, RSKangXi=120.9
26090 CJK UNIFIED IDEOGRAPH-#26090, IRGKangXi=0932.190, RSKangXi=120.9
26091 CJK UNIFIED IDEOGRAPH-#26091, IRGKangXi=0932.210, RSKangXi=120.9
26092 CJK UNIFIED IDEOGRAPH-#26092, IRGKangXi=0932.220, RSKangXi=120.9
26093 CJK UNIFIED IDEOGRAPH-#26093, IRGKangXi=0932.230, RSKangXi=120.9
26094 CJK UNIFIED IDEOGRAPH-#26094, IRGKangXi=0932.250, RSKangXi=120.9
26095 CJK UNIFIED IDEOGRAPH-#26095, IRGKangXi=0932.260, RSKangXi=120.9
26096 CJK UNIFIED IDEOGRAPH-#26096, IRGKangXi=0932.270, RSKangXi=120.9
26097 CJK UNIFIED IDEOGRAPH-#26097, IRGKangXi=0932.300, RSKangXi=120.9, Def{(Cant.) to tighten}
26098 CJK UNIFIED IDEOGRAPH-#26098, IRGKangXi=0932.320, RSKangXi=120.9
26099 CJK UNIFIED IDEOGRAPH-#26099, IRGKangXi=0932.330, RSKangXi=120.9
2609A CJK UNIFIED IDEOGRAPH-#2609A, IRGKangXi=0932.340, RSKangXi=120.9
2609B CJK UNIFIED IDEOGRAPH-#2609B, IRGKangXi=0932.350, RSKangXi=120.9
2609C CJK UNIFIED IDEOGRAPH-#2609C, IRGKangXi=0933.010, RSKangXi=120.9
2609D CJK UNIFIED IDEOGRAPH-#2609D, IRGKangXi=0933.020, RSKangXi=120.9
2609E CJK UNIFIED IDEOGRAPH-#2609E, IRGKangXi=0933.030, RSKangXi=120.9
2609F CJK UNIFIED IDEOGRAPH-#2609F, IRGKangXi=0933.040, RSKangXi=120.9
260A0 CJK UNIFIED IDEOGRAPH-#260A0, IRGKangXi=0933.050, RSKangXi=120.9
260A1 CJK UNIFIED IDEOGRAPH-#260A1, IRGKangXi=0933.060, RSKangXi=120.9
260A2 CJK UNIFIED IDEOGRAPH-#260A2, IRGKangXi=0933.061, RSKangXi=120.9
260A3 CJK UNIFIED IDEOGRAPH-#260A3, IRGKangXi=0933.061, RSKangXi=120.9
260A4 CJK UNIFIED IDEOGRAPH-#260A4, IRGKangXi=0933.061, RSKangXi=120.9
260A5 CJK UNIFIED IDEOGRAPH-#260A5, IRGKangXi=0933.061, RSKangXi=120.9, Def{(Cant.) to drop down}
260A6 CJK UNIFIED IDEOGRAPH-#260A6, IRGKangXi=0933.061, RSKangXi=120.9
260A7 CJK UNIFIED IDEOGRAPH-#260A7, IRGKangXi=0933.061, RSKangXi=120.10
260A8 CJK UNIFIED IDEOGRAPH-#260A8, IRGKangXi=0933.061, RSKangXi=120.9
260A9 CJK UNIFIED IDEOGRAPH-#260A9, IRGKangXi=0933.061, RSKangXi=120.9
260AA CJK UNIFIED IDEOGRAPH-#260AA, IRGKangXi=0933.061, RSKangXi=120.9
260AB CJK UNIFIED IDEOGRAPH-#260AB, IRGKangXi=0933.061, RSKangXi=120.9
260AC CJK UNIFIED IDEOGRAPH-#260AC, IRGKangXi=0933.061, RSKangXi=120.9
260AD CJK UNIFIED IDEOGRAPH-#260AD, IRGKangXi=0933.061, RSKangXi=120.9
260AE CJK UNIFIED IDEOGRAPH-#260AE, IRGKangXi=0933.061, RSKangXi=120.9
260AF CJK UNIFIED IDEOGRAPH-#260AF, IRGKangXi=0933.061, RSKangXi=120.9
260B0 CJK UNIFIED IDEOGRAPH-#260B0, IRGKangXi=0933.061, RSKangXi=120.9
260B1 CJK UNIFIED IDEOGRAPH-#260B1, IRGKangXi=0933.061, RSKangXi=120.9
260B2 CJK UNIFIED IDEOGRAPH-#260B2, IRGKangXi=0933.061, RSKangXi=120.9
260B3 CJK UNIFIED IDEOGRAPH-#260B3, IRGKangXi=0933.061, RSKangXi=120.9
260B4 CJK UNIFIED IDEOGRAPH-#260B4, IRGKangXi=0933.061, RSKangXi=120.9
260B5 CJK UNIFIED IDEOGRAPH-#260B5, IRGKangXi=0933.061, RSKangXi=120.9
260B6 CJK UNIFIED IDEOGRAPH-#260B6, IRGKangXi=0933.061, RSKangXi=120.9
260B7 CJK UNIFIED IDEOGRAPH-#260B7, IRGKangXi=0933.061, RSKangXi=120.9
260B8 CJK UNIFIED IDEOGRAPH-#260B8, IRGKangXi=0933.061, RSKangXi=120.9
260B9 CJK UNIFIED IDEOGRAPH-#260B9, IRGKangXi=0933.061, RSKangXi=120.9
260BA CJK UNIFIED IDEOGRAPH-#260BA, IRGKangXi=0933.061, RSKangXi=120.9
260BB CJK UNIFIED IDEOGRAPH-#260BB, IRGKangXi=0933.061, RSKangXi=120.9
260BC CJK UNIFIED IDEOGRAPH-#260BC, IRGKangXi=0933.061, RSKangXi=120.9
260BD CJK UNIFIED IDEOGRAPH-#260BD, IRGKangXi=0933.061, RSKangXi=120.9
260BE CJK UNIFIED IDEOGRAPH-#260BE, IRGKangXi=0933.061, RSKangXi=120.9
260BF CJK UNIFIED IDEOGRAPH-#260BF, IRGKangXi=0933.061, RSKangXi=120.9
260C0 CJK UNIFIED IDEOGRAPH-#260C0, IRGKangXi=0933.061, RSKangXi=120.9
260C1 CJK UNIFIED IDEOGRAPH-#260C1, IRGKangXi=0933.061, RSKangXi=120.9
260C2 CJK UNIFIED IDEOGRAPH-#260C2, IRGKangXi=0933.061, RSKangXi=120.10
260C3 CJK UNIFIED IDEOGRAPH-#260C3, IRGKangXi=0933.070, RSKangXi=120.10
260C4 CJK UNIFIED IDEOGRAPH-#260C4, IRGKangXi=0933.080, RSKangXi=120.10
260C5 CJK UNIFIED IDEOGRAPH-#260C5, IRGKangXi=0933.100, RSKangXi=120.10
260C6 CJK UNIFIED IDEOGRAPH-#260C6, IRGKangXi=0933.110, RSKangXi=120.10
260C7 CJK UNIFIED IDEOGRAPH-#260C7, IRGKangXi=0933.120, RSKangXi=120.10
260C8 CJK UNIFIED IDEOGRAPH-#260C8, IRGKangXi=0933.150, RSKangXi=120.10
260C9 CJK UNIFIED IDEOGRAPH-#260C9, IRGKangXi=0933.240, RSKangXi=120.10
260CA CJK UNIFIED IDEOGRAPH-#260CA, IRGKangXi=0933.250, RSKangXi=120.10
260CB CJK UNIFIED IDEOGRAPH-#260CB, IRGKangXi=0933.290, RSKangXi=120.10
260CC CJK UNIFIED IDEOGRAPH-#260CC, IRGKangXi=0933.300, RSKangXi=120.10
260CD CJK UNIFIED IDEOGRAPH-#260CD, IRGKangXi=0933.310, RSKangXi=120.10
260CE CJK UNIFIED IDEOGRAPH-#260CE, IRGKangXi=0933.340, RSKangXi=120.10
260CF CJK UNIFIED IDEOGRAPH-#260CF, IRGKangXi=0933.360, RSKangXi=120.10
260D0 CJK UNIFIED IDEOGRAPH-#260D0, IRGKangXi=0934.020, RSKangXi=120.10
260D1 CJK UNIFIED IDEOGRAPH-#260D1, IRGKangXi=0934.030, RSKangXi=120.10
260D2 CJK UNIFIED IDEOGRAPH-#260D2, IRGKangXi=0934.040, RSKangXi=120.10
260D3 CJK UNIFIED IDEOGRAPH-#260D3, IRGKangXi=0934.050, RSKangXi=120.10
260D4 CJK UNIFIED IDEOGRAPH-#260D4, IRGKangXi=0934.060, RSKangXi=120.10
260D5 CJK UNIFIED IDEOGRAPH-#260D5, IRGKangXi=0934.080, RSKangXi=120.10
260D6 CJK UNIFIED IDEOGRAPH-#260D6, IRGKangXi=0934.110, RSKangXi=120.10
260D7 CJK UNIFIED IDEOGRAPH-#260D7, IRGKangXi=0934.130, RSKangXi=120.10
260D8 CJK UNIFIED IDEOGRAPH-#260D8, IRGKangXi=0934.150, RSKangXi=120.10
260D9 CJK UNIFIED IDEOGRAPH-#260D9, IRGKangXi=0934.170, RSKangXi=120.10
260DA CJK UNIFIED IDEOGRAPH-#260DA, IRGKangXi=0935.010, RSKangXi=120.10
260DB CJK UNIFIED IDEOGRAPH-#260DB, IRGKangXi=0935.020, RSKangXi=120.10
260DC CJK UNIFIED IDEOGRAPH-#260DC, IRGKangXi=0935.030, RSKangXi=120.10
260DD CJK UNIFIED IDEOGRAPH-#260DD, IRGKangXi=0935.040, RSKangXi=120.10
260DE CJK UNIFIED IDEOGRAPH-#260DE, IRGKangXi=0935.070, RSKangXi=120.10
260DF CJK UNIFIED IDEOGRAPH-#260DF, IRGKangXi=0935.080, RSKangXi=120.10
260E0 CJK UNIFIED IDEOGRAPH-#260E0, IRGKangXi=0935.090, RSKangXi=120.10
260E1 CJK UNIFIED IDEOGRAPH-#260E1, IRGKangXi=0935.100, RSKangXi=120.10
260E2 CJK UNIFIED IDEOGRAPH-#260E2, IRGKangXi=0935.110, RSKangXi=120.10
260E3 CJK UNIFIED IDEOGRAPH-#260E3, IRGKangXi=0935.130, RSKangXi=120.10
260E4 CJK UNIFIED IDEOGRAPH-#260E4, IRGKangXi=0935.140, RSKangXi=120.10
260E5 CJK UNIFIED IDEOGRAPH-#260E5, IRGKangXi=0935.150, RSKangXi=120.10
260E6 CJK UNIFIED IDEOGRAPH-#260E6, IRGKangXi=0935.160, RSKangXi=120.10
260E7 CJK UNIFIED IDEOGRAPH-#260E7, IRGKangXi=0935.170, RSKangXi=120.10
260E8 CJK UNIFIED IDEOGRAPH-#260E8, IRGKangXi=0935.180, RSKangXi=120.10
260E9 CJK UNIFIED IDEOGRAPH-#260E9, IRGKangXi=0935.181, RSKangXi=120.10
260EA CJK UNIFIED IDEOGRAPH-#260EA, IRGKangXi=0935.181, RSKangXi=120.10
260EB CJK UNIFIED IDEOGRAPH-#260EB, IRGKangXi=0935.181, RSKangXi=120.10
260EC CJK UNIFIED IDEOGRAPH-#260EC, IRGKangXi=0935.181, RSKangXi=120.10
260ED CJK UNIFIED IDEOGRAPH-#260ED, IRGKangXi=0935.181, RSKangXi=120.10
260EE CJK UNIFIED IDEOGRAPH-#260EE, IRGKangXi=0935.181, RSKangXi=120.10
260EF CJK UNIFIED IDEOGRAPH-#260EF, IRGKangXi=0935.181, RSKangXi=120.10
260F0 CJK UNIFIED IDEOGRAPH-#260F0, IRGKangXi=0935.181, RSKangXi=120.10
260F1 CJK UNIFIED IDEOGRAPH-#260F1, IRGKangXi=0935.181, RSKangXi=120.10
260F2 CJK UNIFIED IDEOGRAPH-#260F2, IRGKangXi=0935.181, RSKangXi=120.10
260F3 CJK UNIFIED IDEOGRAPH-#260F3, IRGKangXi=0935.181, RSKangXi=120.10
260F4 CJK UNIFIED IDEOGRAPH-#260F4, IRGKangXi=0935.181, RSKangXi=120.10
260F5 CJK UNIFIED IDEOGRAPH-#260F5, IRGKangXi=0935.181, RSKangXi=120.10
260F6 CJK UNIFIED IDEOGRAPH-#260F6, IRGKangXi=0935.181, RSKangXi=120.10
260F7 CJK UNIFIED IDEOGRAPH-#260F7, IRGKangXi=0935.181, RSKangXi=120.10
260F8 CJK UNIFIED IDEOGRAPH-#260F8, IRGKangXi=0935.181, RSKangXi=120.10
260F9 CJK UNIFIED IDEOGRAPH-#260F9, IRGKangXi=0935.181, RSKangXi=120.10
260FA CJK UNIFIED IDEOGRAPH-#260FA, IRGKangXi=0935.181, RSKangXi=120.10
260FB CJK UNIFIED IDEOGRAPH-#260FB, IRGKangXi=0935.181, RSKangXi=120.10
260FC CJK UNIFIED IDEOGRAPH-#260FC, IRGKangXi=0935.181, RSKangXi=120.10
260FD CJK UNIFIED IDEOGRAPH-#260FD, IRGKangXi=0935.181, RSKangXi=120.10
260FE CJK UNIFIED IDEOGRAPH-#260FE, IRGKangXi=0935.181, RSKangXi=120.10
260FF CJK UNIFIED IDEOGRAPH-#260FF, IRGKangXi=0935.181, RSKangXi=120.10
26100 CJK UNIFIED IDEOGRAPH-#26100, IRGKangXi=0935.181, RSKangXi=120.10
26101 CJK UNIFIED IDEOGRAPH-#26101, IRGKangXi=0935.181, RSKangXi=120.10
26102 CJK UNIFIED IDEOGRAPH-#26102, IRGKangXi=0935.181, RSKangXi=120.11, Def{girdle; zone}
26103 CJK UNIFIED IDEOGRAPH-#26103, IRGKangXi=0935.181, RSKangXi=120.10
26104 CJK UNIFIED IDEOGRAPH-#26104, IRGKangXi=0935.181, RSKangXi=120.10
26105 CJK UNIFIED IDEOGRAPH-#26105, IRGKangXi=0935.181, RSKangXi=120.10
26106 CJK UNIFIED IDEOGRAPH-#26106, IRGKangXi=0935.181, RSKangXi=120.10
26107 CJK UNIFIED IDEOGRAPH-#26107, IRGKangXi=0935.181, RSKangXi=120.10
26108 CJK UNIFIED IDEOGRAPH-#26108, IRGKangXi=0935.181, RSKangXi=120.10
26109 CJK UNIFIED IDEOGRAPH-#26109, IRGKangXi=0935.250, RSKangXi=120.11
2610A CJK UNIFIED IDEOGRAPH-#2610A, IRGKangXi=0935.330, RSKangXi=120.11
2610B CJK UNIFIED IDEOGRAPH-#2610B, IRGKangXi=0936.060, RSKangXi=120.11
2610C CJK UNIFIED IDEOGRAPH-#2610C, IRGKangXi=0936.080, RSKangXi=120.11
2610D CJK UNIFIED IDEOGRAPH-#2610D, IRGKangXi=0936.110, RSKangXi=120.11
2610E CJK UNIFIED IDEOGRAPH-#2610E, IRGKangXi=0936.120, RSKangXi=120.11
2610F CJK UNIFIED IDEOGRAPH-#2610F, IRGKangXi=0936.130, RSKangXi=120.11
26110 CJK UNIFIED IDEOGRAPH-#26110, IRGKangXi=0936.180, RSKangXi=120.11
26111 CJK UNIFIED IDEOGRAPH-#26111, IRGKangXi=0936.240, RSKangXi=120.11
26112 CJK UNIFIED IDEOGRAPH-#26112, IRGKangXi=0938.010, RSKangXi=120.11
26113 CJK UNIFIED IDEOGRAPH-#26113, IRGKangXi=0938.020, RSKangXi=120.11
26114 CJK UNIFIED IDEOGRAPH-#26114, IRGKangXi=0938.030, RSKangXi=120.11
26115 CJK UNIFIED IDEOGRAPH-#26115, IRGKangXi=0938.040, RSKangXi=120.11
26116 CJK UNIFIED IDEOGRAPH-#26116, IRGKangXi=0938.050, RSKangXi=120.11
26117 CJK UNIFIED IDEOGRAPH-#26117, IRGKangXi=0938.070, RSKangXi=120.11
26118 CJK UNIFIED IDEOGRAPH-#26118, IRGKangXi=0938.090, RSKangXi=120.11
26119 CJK UNIFIED IDEOGRAPH-#26119, IRGKangXi=0938.100, RSKangXi=120.11
2611A CJK UNIFIED IDEOGRAPH-#2611A, IRGKangXi=0938.110, RSKangXi=120.11
2611B CJK UNIFIED IDEOGRAPH-#2611B, IRGKangXi=0938.120, RSKangXi=120.11
2611C CJK UNIFIED IDEOGRAPH-#2611C, IRGKangXi=0938.130, RSKangXi=120.11
2611D CJK UNIFIED IDEOGRAPH-#2611D, IRGKangXi=0938.141, RSKangXi=120.11
2611E CJK UNIFIED IDEOGRAPH-#2611E, IRGKangXi=0938.141, RSKangXi=120.11
2611F CJK UNIFIED IDEOGRAPH-#2611F, IRGKangXi=0938.141, RSKangXi=120.11
26120 CJK UNIFIED IDEOGRAPH-#26120, IRGKangXi=0938.141, RSKangXi=120.11
26121 CJK UNIFIED IDEOGRAPH-#26121, IRGKangXi=0938.141, RSKangXi=120.11
26122 CJK UNIFIED IDEOGRAPH-#26122, IRGKangXi=0938.141, RSKangXi=120.11
26123 CJK UNIFIED IDEOGRAPH-#26123, IRGKangXi=0938.141, RSKangXi=120.11
26124 CJK UNIFIED IDEOGRAPH-#26124, IRGKangXi=0938.141, RSKangXi=120.11
26125 CJK UNIFIED IDEOGRAPH-#26125, IRGKangXi=0938.141, RSKangXi=120.11
26126 CJK UNIFIED IDEOGRAPH-#26126, IRGKangXi=0938.141, RSKangXi=120.11
26127 CJK UNIFIED IDEOGRAPH-#26127, IRGKangXi=0938.141, RSKangXi=120.11
26128 CJK UNIFIED IDEOGRAPH-#26128, IRGKangXi=0938.141, RSKangXi=120.11
26129 CJK UNIFIED IDEOGRAPH-#26129, IRGKangXi=0938.141, RSKangXi=120.11
2612A CJK UNIFIED IDEOGRAPH-#2612A, IRGKangXi=0938.141, RSKangXi=120.11
2612B CJK UNIFIED IDEOGRAPH-#2612B, IRGKangXi=0938.141, RSKangXi=120.11
2612C CJK UNIFIED IDEOGRAPH-#2612C, IRGKangXi=0938.141, RSKangXi=120.11
2612D CJK UNIFIED IDEOGRAPH-#2612D, IRGKangXi=0938.141, RSKangXi=120.11
2612E CJK UNIFIED IDEOGRAPH-#2612E, IRGKangXi=0938.141, RSKangXi=120.11
2612F CJK UNIFIED IDEOGRAPH-#2612F, IRGKangXi=0938.141, RSKangXi=120.11
26130 CJK UNIFIED IDEOGRAPH-#26130, IRGKangXi=0938.141, RSKangXi=120.11
26131 CJK UNIFIED IDEOGRAPH-#26131, IRGKangXi=0938.141, RSKangXi=120.11
26132 CJK UNIFIED IDEOGRAPH-#26132, IRGKangXi=0938.141, RSKangXi=120.11
26133 CJK UNIFIED IDEOGRAPH-#26133, IRGKangXi=0938.141, RSKangXi=120.11
26134 CJK UNIFIED IDEOGRAPH-#26134, IRGKangXi=0938.141, RSKangXi=120.11
26135 CJK UNIFIED IDEOGRAPH-#26135, IRGKangXi=0938.141, RSKangXi=120.11
26136 CJK UNIFIED IDEOGRAPH-#26136, IRGKangXi=0938.141, RSKangXi=120.11
26137 CJK UNIFIED IDEOGRAPH-#26137, IRGKangXi=0938.141, RSKangXi=120.11
26138 CJK UNIFIED IDEOGRAPH-#26138, IRGKangXi=0938.141, RSKangXi=120.11
26139 CJK UNIFIED IDEOGRAPH-#26139, IRGKangXi=0938.141, RSKangXi=120.11
2613A CJK UNIFIED IDEOGRAPH-#2613A, IRGKangXi=0938.141, RSKangXi=120.11
2613B CJK UNIFIED IDEOGRAPH-#2613B, IRGKangXi=0938.141, RSKangXi=120.11
2613C CJK UNIFIED IDEOGRAPH-#2613C, IRGKangXi=0938.160, RSKangXi=120.12
2613D CJK UNIFIED IDEOGRAPH-#2613D, IRGKangXi=0938.170, RSKangXi=120.12
2613E CJK UNIFIED IDEOGRAPH-#2613E, IRGKangXi=0938.200, RSKangXi=120.12
2613F CJK UNIFIED IDEOGRAPH-#2613F, IRGKangXi=0938.220, RSKangXi=120.12
26140 CJK UNIFIED IDEOGRAPH-#26140, IRGKangXi=0938.260, RSKangXi=120.12
26141 CJK UNIFIED IDEOGRAPH-#26141, IRGKangXi=0938.270, RSKangXi=120.12
26142 CJK UNIFIED IDEOGRAPH-#26142, IRGKangXi=0938.350, RSKangXi=120.12
26143 CJK UNIFIED IDEOGRAPH-#26143, IRGKangXi=0938.360, RSKangXi=120.12
26144 CJK UNIFIED IDEOGRAPH-#26144, IRGKangXi=0938.380, RSKangXi=120.12
26145 CJK UNIFIED IDEOGRAPH-#26145, IRGKangXi=0939.010, RSKangXi=120.12
26146 CJK UNIFIED IDEOGRAPH-#26146, IRGKangXi=0939.120, RSKangXi=120.12
26147 CJK UNIFIED IDEOGRAPH-#26147, IRGKangXi=0939.160, RSKangXi=120.12
26148 CJK UNIFIED IDEOGRAPH-#26148, IRGKangXi=0939.200, RSKangXi=120.12
26149 CJK UNIFIED IDEOGRAPH-#26149, IRGKangXi=0939.220, RSKangXi=120.12
2614A CJK UNIFIED IDEOGRAPH-#2614A, IRGKangXi=0939.240, RSKangXi=120.12
2614B CJK UNIFIED IDEOGRAPH-#2614B, IRGKangXi=0939.250, RSKangXi=120.12
2614C CJK UNIFIED IDEOGRAPH-#2614C, IRGKangXi=0939.260, RSKangXi=120.12
2614D CJK UNIFIED IDEOGRAPH-#2614D, IRGKangXi=0939.270, RSKangXi=120.12
2614E CJK UNIFIED IDEOGRAPH-#2614E, IRGKangXi=0939.280, RSKangXi=120.12
2614F CJK UNIFIED IDEOGRAPH-#2614F, IRGKangXi=0939.290, RSKangXi=120.12
26150 CJK UNIFIED IDEOGRAPH-#26150, IRGKangXi=0939.320, RSKangXi=120.12
26151 CJK UNIFIED IDEOGRAPH-#26151, IRGKangXi=0939.330, RSKangXi=120.12
26152 CJK UNIFIED IDEOGRAPH-#26152, IRGKangXi=0939.340, RSKangXi=120.12
26153 CJK UNIFIED IDEOGRAPH-#26153, IRGKangXi=0940.010, RSKangXi=120.12
26154 CJK UNIFIED IDEOGRAPH-#26154, IRGKangXi=0940.020, RSKangXi=120.12
26155 CJK UNIFIED IDEOGRAPH-#26155, IRGKangXi=0940.030, RSKangXi=120.12
26156 CJK UNIFIED IDEOGRAPH-#26156, IRGKangXi=0940.031, RSKangXi=120.12
26157 CJK UNIFIED IDEOGRAPH-#26157, IRGKangXi=0940.031, RSKangXi=120.12
26158 CJK UNIFIED IDEOGRAPH-#26158, IRGKangXi=0940.031, RSKangXi=120.12
26159 CJK UNIFIED IDEOGRAPH-#26159, IRGKangXi=0940.031, RSKangXi=120.12
2615A CJK UNIFIED IDEOGRAPH-#2615A, IRGKangXi=0940.031, RSKangXi=120.12
2615B CJK UNIFIED IDEOGRAPH-#2615B, IRGKangXi=0940.031, RSKangXi=120.12
2615C CJK UNIFIED IDEOGRAPH-#2615C, IRGKangXi=0940.031, RSKangXi=120.12
2615D CJK UNIFIED IDEOGRAPH-#2615D, IRGKangXi=0940.031, RSKangXi=120.12
2615E CJK UNIFIED IDEOGRAPH-#2615E, IRGKangXi=0940.031, RSKangXi=120.12
2615F CJK UNIFIED IDEOGRAPH-#2615F, IRGKangXi=0940.031, RSKangXi=120.12
26160 CJK UNIFIED IDEOGRAPH-#26160, IRGKangXi=0940.031, RSKangXi=120.12
26161 CJK UNIFIED IDEOGRAPH-#26161, IRGKangXi=0940.031, RSKangXi=120.12
26162 CJK UNIFIED IDEOGRAPH-#26162, IRGKangXi=0940.031, RSKangXi=120.12
26163 CJK UNIFIED IDEOGRAPH-#26163, IRGKangXi=0940.031, RSKangXi=120.12
26164 CJK UNIFIED IDEOGRAPH-#26164, IRGKangXi=0940.031, RSKangXi=120.12
26165 CJK UNIFIED IDEOGRAPH-#26165, IRGKangXi=0940.031, RSKangXi=120.12
26166 CJK UNIFIED IDEOGRAPH-#26166, IRGKangXi=0940.031, RSKangXi=120.12
26167 CJK UNIFIED IDEOGRAPH-#26167, IRGKangXi=0940.031, RSKangXi=120.12
26168 CJK UNIFIED IDEOGRAPH-#26168, IRGKangXi=0940.031, RSKangXi=120.12
26169 CJK UNIFIED IDEOGRAPH-#26169, IRGKangXi=0940.031, RSKangXi=120.12
2616A CJK UNIFIED IDEOGRAPH-#2616A, IRGKangXi=0940.031, RSKangXi=120.12
2616B CJK UNIFIED IDEOGRAPH-#2616B, IRGKangXi=0940.031, RSKangXi=120.12
2616C CJK UNIFIED IDEOGRAPH-#2616C, IRGKangXi=0940.031, RSKangXi=120.12
2616D CJK UNIFIED IDEOGRAPH-#2616D, IRGKangXi=0940.031, RSKangXi=120.12
2616E CJK UNIFIED IDEOGRAPH-#2616E, IRGKangXi=0940.031, RSKangXi=120.12
2616F CJK UNIFIED IDEOGRAPH-#2616F, IRGKangXi=0940.031, RSKangXi=120.12
26170 CJK UNIFIED IDEOGRAPH-#26170, IRGKangXi=0940.031, RSKangXi=120.12
26171 CJK UNIFIED IDEOGRAPH-#26171, IRGKangXi=0940.031, RSKangXi=120.12
26172 CJK UNIFIED IDEOGRAPH-#26172, IRGKangXi=0940.031, RSKangXi=120.12
26173 CJK UNIFIED IDEOGRAPH-#26173, IRGKangXi=0940.031, RSKangXi=120.12
26174 CJK UNIFIED IDEOGRAPH-#26174, IRGKangXi=0940.031, RSKangXi=120.12
26175 CJK UNIFIED IDEOGRAPH-#26175, IRGKangXi=0940.050, RSKangXi=120.13
26176 CJK UNIFIED IDEOGRAPH-#26176, IRGKangXi=0940.080, RSKangXi=120.13
26177 CJK UNIFIED IDEOGRAPH-#26177, IRGKangXi=0940.100, RSKangXi=120.13
26178 CJK UNIFIED IDEOGRAPH-#26178, IRGKangXi=0940.130, RSKangXi=120.13
26179 CJK UNIFIED IDEOGRAPH-#26179, IRGKangXi=0940.140, RSKangXi=120.13
2617A CJK UNIFIED IDEOGRAPH-#2617A, IRGKangXi=0940.150, RSKangXi=120.13
2617B CJK UNIFIED IDEOGRAPH-#2617B, IRGKangXi=0940.180, RSKangXi=120.13
2617C CJK UNIFIED IDEOGRAPH-#2617C, IRGKangXi=0940.190, RSKangXi=120.13
2617D CJK UNIFIED IDEOGRAPH-#2617D, IRGKangXi=0940.250, RSKangXi=120.13
2617E CJK UNIFIED IDEOGRAPH-#2617E, IRGKangXi=0940.260, RSKangXi=120.13
2617F CJK UNIFIED IDEOGRAPH-#2617F, IRGKangXi=0940.270, RSKangXi=120.13
26180 CJK UNIFIED IDEOGRAPH-#26180, IRGKangXi=0941.050, RSKangXi=120.13
26181 CJK UNIFIED IDEOGRAPH-#26181, IRGKangXi=0941.060, RSKangXi=120.13
26182 CJK UNIFIED IDEOGRAPH-#26182, IRGKangXi=0941.070, RSKangXi=120.13
26183 CJK UNIFIED IDEOGRAPH-#26183, IRGKangXi=0941.090, RSKangXi=120.13
26184 CJK UNIFIED IDEOGRAPH-#26184, IRGKangXi=0941.120, RSKangXi=120.13
26185 CJK UNIFIED IDEOGRAPH-#26185, IRGKangXi=0941.170, RSKangXi=120.13
26186 CJK UNIFIED IDEOGRAPH-#26186, IRGKangXi=0941.180, RSKangXi=120.13
26187 CJK UNIFIED IDEOGRAPH-#26187, IRGKangXi=0941.190, RSKangXi=120.13
26188 CJK UNIFIED IDEOGRAPH-#26188, IRGKangXi=0941.200, RSKangXi=120.13
26189 CJK UNIFIED IDEOGRAPH-#26189, IRGKangXi=0941.210, RSKangXi=120.13
2618A CJK UNIFIED IDEOGRAPH-#2618A, IRGKangXi=0941.230, RSKangXi=120.13
2618B CJK UNIFIED IDEOGRAPH-#2618B, IRGKangXi=0941.240, RSKangXi=120.13
2618C CJK UNIFIED IDEOGRAPH-#2618C, IRGKangXi=0941.250, RSKangXi=120.13
2618D CJK UNIFIED IDEOGRAPH-#2618D, IRGKangXi=0941.260, RSKangXi=120.13
2618E CJK UNIFIED IDEOGRAPH-#2618E, IRGKangXi=0941.270, RSKangXi=120.13
2618F CJK UNIFIED IDEOGRAPH-#2618F, IRGKangXi=0941.271, RSKangXi=120.13
26190 CJK UNIFIED IDEOGRAPH-#26190, IRGKangXi=0941.271, RSKangXi=120.13
26191 CJK UNIFIED IDEOGRAPH-#26191, IRGKangXi=0941.271, RSKangXi=120.13
26192 CJK UNIFIED IDEOGRAPH-#26192, IRGKangXi=0941.271, RSKangXi=120.13
26193 CJK UNIFIED IDEOGRAPH-#26193, IRGKangXi=0941.271, RSKangXi=120.13
26194 CJK UNIFIED IDEOGRAPH-#26194, IRGKangXi=0941.271, RSKangXi=120.13
26195 CJK UNIFIED IDEOGRAPH-#26195, IRGKangXi=0941.271, RSKangXi=120.13
26196 CJK UNIFIED IDEOGRAPH-#26196, IRGKangXi=0941.271, RSKangXi=120.13
26197 CJK UNIFIED IDEOGRAPH-#26197, IRGKangXi=0941.271, RSKangXi=120.13
26198 CJK UNIFIED IDEOGRAPH-#26198, IRGKangXi=0941.271, RSKangXi=120.13
26199 CJK UNIFIED IDEOGRAPH-#26199, IRGKangXi=0941.271, RSKangXi=120.13
2619A CJK UNIFIED IDEOGRAPH-#2619A, IRGKangXi=0941.271, RSKangXi=120.13
2619B CJK UNIFIED IDEOGRAPH-#2619B, IRGKangXi=0941.271, RSKangXi=120.13
2619C CJK UNIFIED IDEOGRAPH-#2619C, IRGKangXi=0941.290, RSKangXi=120.14
2619D CJK UNIFIED IDEOGRAPH-#2619D, IRGKangXi=0941.300, RSKangXi=120.14
2619E CJK UNIFIED IDEOGRAPH-#2619E, IRGKangXi=0941.320, RSKangXi=120.14
2619F CJK UNIFIED IDEOGRAPH-#2619F, IRGKangXi=0942.040, RSKangXi=120.14, Def{tangled}
261A0 CJK UNIFIED IDEOGRAPH-#261A0, IRGKangXi=0942.060, RSKangXi=120.14
261A1 CJK UNIFIED IDEOGRAPH-#261A1, IRGKangXi=0942.070, RSKangXi=120.14
261A2 CJK UNIFIED IDEOGRAPH-#261A2, IRGKangXi=0942.080, RSKangXi=120.14
261A3 CJK UNIFIED IDEOGRAPH-#261A3, IRGKangXi=0942.160, RSKangXi=120.14
261A4 CJK UNIFIED IDEOGRAPH-#261A4, IRGKangXi=0942.170, RSKangXi=120.15
261A5 CJK UNIFIED IDEOGRAPH-#261A5, IRGKangXi=0942.180, RSKangXi=120.13
261A6 CJK UNIFIED IDEOGRAPH-#261A6, IRGKangXi=0942.190, RSKangXi=120.14
261A7 CJK UNIFIED IDEOGRAPH-#261A7, IRGKangXi=0942.200, RSKangXi=120.14
261A8 CJK UNIFIED IDEOGRAPH-#261A8, IRGKangXi=0942.210, RSKangXi=120.15
261A9 CJK UNIFIED IDEOGRAPH-#261A9, IRGKangXi=0942.220, RSKangXi=120.14
261AA CJK UNIFIED IDEOGRAPH-#261AA, IRGKangXi=0942.230, RSKangXi=120.14
261AB CJK UNIFIED IDEOGRAPH-#261AB, IRGKangXi=0942.240, RSKangXi=120.15
261AC CJK UNIFIED IDEOGRAPH-#261AC, IRGKangXi=0942.250, RSKangXi=120.14
261AD CJK UNIFIED IDEOGRAPH-#261AD, IRGKangXi=0942.251, RSKangXi=120.14
261AE CJK UNIFIED IDEOGRAPH-#261AE, IRGKangXi=0942.251, RSKangXi=120.14
261AF CJK UNIFIED IDEOGRAPH-#261AF, IRGKangXi=0942.251, RSKangXi=120.14, Def{confused}
261B0 CJK UNIFIED IDEOGRAPH-#261B0, IRGKangXi=0942.251, RSKangXi=120.14
261B1 CJK UNIFIED IDEOGRAPH-#261B1, IRGKangXi=0942.251, RSKangXi=120.14
261B2 CJK UNIFIED IDEOGRAPH-#261B2, IRGKangXi=0942.251, RSKangXi=120.14
261B3 CJK UNIFIED IDEOGRAPH-#261B3, IRGKangXi=0942.251, RSKangXi=120.14
261B4 CJK UNIFIED IDEOGRAPH-#261B4, IRGKangXi=0942.251, RSKangXi=120.14
261B5 CJK UNIFIED IDEOGRAPH-#261B5, IRGKangXi=0942.251, RSKangXi=120.14
261B6 CJK UNIFIED IDEOGRAPH-#261B6, IRGKangXi=0942.251, RSKangXi=120.14
261B7 CJK UNIFIED IDEOGRAPH-#261B7, IRGKangXi=0942.251, RSKangXi=120.14
261B8 CJK UNIFIED IDEOGRAPH-#261B8, IRGKangXi=0942.251, RSKangXi=120.14
261B9 CJK UNIFIED IDEOGRAPH-#261B9, IRGKangXi=0942.251, RSKangXi=120.14
261BA CJK UNIFIED IDEOGRAPH-#261BA, IRGKangXi=0942.251, RSKangXi=120.14
261BB CJK UNIFIED IDEOGRAPH-#261BB, IRGKangXi=0942.270, RSKangXi=120.15
261BC CJK UNIFIED IDEOGRAPH-#261BC, IRGKangXi=0942.320, RSKangXi=120.15
261BD CJK UNIFIED IDEOGRAPH-#261BD, IRGKangXi=0942.340, RSKangXi=120.15
261BE CJK UNIFIED IDEOGRAPH-#261BE, IRGKangXi=0942.350, RSKangXi=120.15
261BF CJK UNIFIED IDEOGRAPH-#261BF, IRGKangXi=0942.380, RSKangXi=120.15
261C0 CJK UNIFIED IDEOGRAPH-#261C0, IRGKangXi=0942.390, RSKangXi=120.15
261C1 CJK UNIFIED IDEOGRAPH-#261C1, IRGKangXi=0943.010, RSKangXi=120.15
261C2 CJK UNIFIED IDEOGRAPH-#261C2, IRGKangXi=0943.040, RSKangXi=120.16
261C3 CJK UNIFIED IDEOGRAPH-#261C3, IRGKangXi=0943.050, RSKangXi=120.15
261C4 CJK UNIFIED IDEOGRAPH-#261C4, IRGKangXi=0943.060, RSKangXi=120.15
261C5 CJK UNIFIED IDEOGRAPH-#261C5, IRGKangXi=0943.070, RSKangXi=120.15
261C6 CJK UNIFIED IDEOGRAPH-#261C6, IRGKangXi=0943.071, RSKangXi=120.15
261C7 CJK UNIFIED IDEOGRAPH-#261C7, IRGKangXi=0943.071, RSKangXi=120.15
261C8 CJK UNIFIED IDEOGRAPH-#261C8, IRGKangXi=0943.071, RSKangXi=120.15
261C9 CJK UNIFIED IDEOGRAPH-#261C9, IRGKangXi=0943.071, RSKangXi=120.15
261CA CJK UNIFIED IDEOGRAPH-#261CA, IRGKangXi=0943.071, RSKangXi=120.15
261CB CJK UNIFIED IDEOGRAPH-#261CB, IRGKangXi=0943.071, RSKangXi=120.15
261CC CJK UNIFIED IDEOGRAPH-#261CC, IRGKangXi=0943.071, RSKangXi=120.15
261CD CJK UNIFIED IDEOGRAPH-#261CD, IRGKangXi=0943.071, RSKangXi=120.15
261CE CJK UNIFIED IDEOGRAPH-#261CE, IRGKangXi=0943.071, RSKangXi=120.15
261CF CJK UNIFIED IDEOGRAPH-#261CF, IRGKangXi=0943.071, RSKangXi=120.15
261D0 CJK UNIFIED IDEOGRAPH-#261D0, IRGKangXi=0943.071, RSKangXi=120.15
261D1 CJK UNIFIED IDEOGRAPH-#261D1, IRGKangXi=0943.071, RSKangXi=120.15
261D2 CJK UNIFIED IDEOGRAPH-#261D2, IRGKangXi=0943.071, RSKangXi=120.15
261D3 CJK UNIFIED IDEOGRAPH-#261D3, IRGKangXi=0943.071, RSKangXi=120.15
261D4 CJK UNIFIED IDEOGRAPH-#261D4, IRGKangXi=0943.080, RSKangXi=120.16
261D5 CJK UNIFIED IDEOGRAPH-#261D5, IRGKangXi=0943.120, RSKangXi=120.16
261D6 CJK UNIFIED IDEOGRAPH-#261D6, IRGKangXi=0943.140, RSKangXi=120.16
261D7 CJK UNIFIED IDEOGRAPH-#261D7, IRGKangXi=0943.160, RSKangXi=120.16
261D8 CJK UNIFIED IDEOGRAPH-#261D8, IRGKangXi=0943.170, RSKangXi=120.16
261D9 CJK UNIFIED IDEOGRAPH-#261D9, IRGKangXi=0943.180, RSKangXi=120.16
261DA CJK UNIFIED IDEOGRAPH-#261DA, IRGKangXi=0943.200, RSKangXi=120.16
261DB CJK UNIFIED IDEOGRAPH-#261DB, IRGKangXi=0943.210, RSKangXi=120.16
261DC CJK UNIFIED IDEOGRAPH-#261DC, IRGKangXi=0943.220, RSKangXi=120.16
261DD CJK UNIFIED IDEOGRAPH-#261DD, IRGKangXi=0943.221, RSKangXi=120.16
261DE CJK UNIFIED IDEOGRAPH-#261DE, IRGKangXi=0943.221, RSKangXi=120.16
261DF CJK UNIFIED IDEOGRAPH-#261DF, IRGKangXi=0943.221, RSKangXi=120.16
261E0 CJK UNIFIED IDEOGRAPH-#261E0, IRGKangXi=0943.221, RSKangXi=120.16
261E1 CJK UNIFIED IDEOGRAPH-#261E1, IRGKangXi=0943.221, RSKangXi=120.16
261E2 CJK UNIFIED IDEOGRAPH-#261E2, IRGKangXi=0943.221, RSKangXi=120.16
261E3 CJK UNIFIED IDEOGRAPH-#261E3, IRGKangXi=0943.221, RSKangXi=120.16
261E4 CJK UNIFIED IDEOGRAPH-#261E4, IRGKangXi=0943.221, RSKangXi=120.16
261E5 CJK UNIFIED IDEOGRAPH-#261E5, IRGKangXi=0943.221, RSKangXi=120.16
261E6 CJK UNIFIED IDEOGRAPH-#261E6, IRGKangXi=0943.221, RSKangXi=120.16
261E7 CJK UNIFIED IDEOGRAPH-#261E7, IRGKangXi=0943.230, RSKangXi=120.17
261E8 CJK UNIFIED IDEOGRAPH-#261E8, IRGKangXi=0943.250, RSKangXi=120.17
261E9 CJK UNIFIED IDEOGRAPH-#261E9, IRGKangXi=0943.260, RSKangXi=120.17
261EA CJK UNIFIED IDEOGRAPH-#261EA, IRGKangXi=0943.300, RSKangXi=120.17
261EB CJK UNIFIED IDEOGRAPH-#261EB, IRGKangXi=0943.310, RSKangXi=120.17
261EC CJK UNIFIED IDEOGRAPH-#261EC, IRGKangXi=0943.320, RSKangXi=120.17
261ED CJK UNIFIED IDEOGRAPH-#261ED, IRGKangXi=0943.331, RSKangXi=120.17
261EE CJK UNIFIED IDEOGRAPH-#261EE, IRGKangXi=0943.331, RSKangXi=120.17
261EF CJK UNIFIED IDEOGRAPH-#261EF, IRGKangXi=0943.331, RSKangXi=120.17
261F0 CJK UNIFIED IDEOGRAPH-#261F0, IRGKangXi=0944.020, RSKangXi=120.18
261F1 CJK UNIFIED IDEOGRAPH-#261F1, IRGKangXi=0944.040, RSKangXi=120.18
261F2 CJK UNIFIED IDEOGRAPH-#261F2, IRGKangXi=0944.060, RSKangXi=120.18
261F3 CJK UNIFIED IDEOGRAPH-#261F3, IRGKangXi=0944.061, RSKangXi=120.18
261F4 CJK UNIFIED IDEOGRAPH-#261F4, IRGKangXi=0944.061, RSKangXi=120.18
261F5 CJK UNIFIED IDEOGRAPH-#261F5, IRGKangXi=0944.061, RSKangXi=120.18
261F6 CJK UNIFIED IDEOGRAPH-#261F6, IRGKangXi=0944.061, RSKangXi=120.18
261F7 CJK UNIFIED IDEOGRAPH-#261F7, IRGKangXi=0944.061, RSKangXi=120.18
261F8 CJK UNIFIED IDEOGRAPH-#261F8, IRGKangXi=0944.080, RSKangXi=120.19
261F9 CJK UNIFIED IDEOGRAPH-#261F9, IRGKangXi=0944.130, RSKangXi=120.18
261FA CJK UNIFIED IDEOGRAPH-#261FA, IRGKangXi=0944.140, RSKangXi=120.19
261FB CJK UNIFIED IDEOGRAPH-#261FB, IRGKangXi=0944.160, RSKangXi=120.19
261FC CJK UNIFIED IDEOGRAPH-#261FC, IRGKangXi=0944.170, RSKangXi=120.20
261FD CJK UNIFIED IDEOGRAPH-#261FD, IRGKangXi=0944.171, RSKangXi=120.20
261FE CJK UNIFIED IDEOGRAPH-#261FE, IRGKangXi=0944.200, RSKangXi=120.21
261FF CJK UNIFIED IDEOGRAPH-#261FF, IRGKangXi=0944.211, RSKangXi=120.21
26200 CJK UNIFIED IDEOGRAPH-#26200, IRGKangXi=0944.211, RSKangXi=120.21
26201 CJK UNIFIED IDEOGRAPH-#26201, IRGKangXi=0944.211, RSKangXi=120.21
26202 CJK UNIFIED IDEOGRAPH-#26202, IRGKangXi=0944.211, RSKangXi=120.21
26203 CJK UNIFIED IDEOGRAPH-#26203, IRGKangXi=0944.220, RSKangXi=120.22
26204 CJK UNIFIED IDEOGRAPH-#26204, IRGKangXi=0944.221, RSKangXi=120.22
26205 CJK UNIFIED IDEOGRAPH-#26205, IRGKangXi=0944.230, RSKangXi=120.23
26206 CJK UNIFIED IDEOGRAPH-#26206, IRGKangXi=0944.241, RSKangXi=120.24
26207 CJK UNIFIED IDEOGRAPH-#26207, IRGKangXi=0944.250, RSKangXi=120.25
26208 CJK UNIFIED IDEOGRAPH-#26208, IRGKangXi=0944.251, RSKangXi=120.5
26209 CJK UNIFIED IDEOGRAPH-#26209, IRGKangXi=0944.251, RSKangXi=120.6
2620A CJK UNIFIED IDEOGRAPH-#2620A, IRGKangXi=0944.251, RSKangXi=120.7
2620B CJK UNIFIED IDEOGRAPH-#2620B, IRGKangXi=0944.251, RSKangXi=120.7
2620C CJK UNIFIED IDEOGRAPH-#2620C, IRGKangXi=0944.251, RSKangXi=120.7
2620D CJK UNIFIED IDEOGRAPH-#2620D, IRGKangXi=0944.251, RSKangXi=120.8
2620E CJK UNIFIED IDEOGRAPH-#2620E, IRGKangXi=0944.251, RSKangXi=120.8
2620F CJK UNIFIED IDEOGRAPH-#2620F, IRGKangXi=0944.251, RSKangXi=120.8
26210 CJK UNIFIED IDEOGRAPH-#26210, IRGKangXi=0944.251, RSKangXi=120.8
26211 CJK UNIFIED IDEOGRAPH-#26211, IRGKangXi=0944.251, RSKangXi=120.9
26212 CJK UNIFIED IDEOGRAPH-#26212, IRGKangXi=0944.251, RSKangXi=120.9
26213 CJK UNIFIED IDEOGRAPH-#26213, IRGKangXi=0944.251, RSKangXi=120.9
26214 CJK UNIFIED IDEOGRAPH-#26214, IRGKangXi=0944.251, RSKangXi=120.9
26215 CJK UNIFIED IDEOGRAPH-#26215, IRGKangXi=0944.251, RSKangXi=120.9
26216 CJK UNIFIED IDEOGRAPH-#26216, IRGKangXi=0944.251, RSKangXi=120.10
26217 CJK UNIFIED IDEOGRAPH-#26217, IRGKangXi=0944.251, RSKangXi=120.10
26218 CJK UNIFIED IDEOGRAPH-#26218, IRGKangXi=0944.251, RSKangXi=120.10
26219 CJK UNIFIED IDEOGRAPH-#26219, IRGKangXi=0944.251, RSKangXi=120.10
2621A CJK UNIFIED IDEOGRAPH-#2621A, IRGKangXi=0944.251, RSKangXi=120.11
2621B CJK UNIFIED IDEOGRAPH-#2621B, IRGKangXi=0944.251, RSKangXi=120.12
2621C CJK UNIFIED IDEOGRAPH-#2621C, IRGKangXi=0944.251, RSKangXi=120.12
2621D CJK UNIFIED IDEOGRAPH-#2621D, IRGKangXi=0944.251, RSKangXi=120.12
2621E CJK UNIFIED IDEOGRAPH-#2621E, IRGKangXi=0944.251, RSKangXi=120.13
2621F CJK UNIFIED IDEOGRAPH-#2621F, IRGKangXi=0944.251, RSKangXi=120.13
26220 CJK UNIFIED IDEOGRAPH-#26220, IRGKangXi=0944.251, RSKangXi=120.14
26221 CJK UNIFIED IDEOGRAPH-#26221, IRGKangXi=0944.251, RSKangXi=120.14
26222 CJK UNIFIED IDEOGRAPH-#26222, IRGKangXi=0944.270, RSKangXi=121.0
26223 CJK UNIFIED IDEOGRAPH-#26223, IRGKangXi=0944.300, RSKangXi=121.3
26224 CJK UNIFIED IDEOGRAPH-#26224, IRGKangXi=0944.310, RSKangXi=121.3
26225 CJK UNIFIED IDEOGRAPH-#26225, IRGKangXi=0944.311
26226 CJK UNIFIED IDEOGRAPH-#26226, IRGKangXi=0944.320, RSKangXi=121.4
26227 CJK UNIFIED IDEOGRAPH-#26227, IRGKangXi=0945.010, RSKangXi=121.4
26228 CJK UNIFIED IDEOGRAPH-#26228, IRGKangXi=0945.020, RSKangXi=121.4
26229 CJK UNIFIED IDEOGRAPH-#26229, IRGKangXi=0945.110, RSKangXi=121.5
2622A CJK UNIFIED IDEOGRAPH-#2622A, IRGKangXi=0945.120, RSKangXi=121.5
2622B CJK UNIFIED IDEOGRAPH-#2622B, IRGKangXi=0945.130, RSKangXi=121.5
2622C CJK UNIFIED IDEOGRAPH-#2622C, IRGKangXi=0945.160, RSKangXi=121.5
2622D CJK UNIFIED IDEOGRAPH-#2622D, IRGKangXi=0945.170, RSKangXi=121.5
2622E CJK UNIFIED IDEOGRAPH-#2622E, IRGKangXi=0945.171
2622F CJK UNIFIED IDEOGRAPH-#2622F, IRGKangXi=0945.190, RSKangXi=121.6
26230 CJK UNIFIED IDEOGRAPH-#26230, IRGKangXi=0945.210, RSKangXi=121.6
26231 CJK UNIFIED IDEOGRAPH-#26231, IRGKangXi=0945.220, RSKangXi=121.6
26232 CJK UNIFIED IDEOGRAPH-#26232, IRGKangXi=0945.230, RSKangXi=121.6
26233 CJK UNIFIED IDEOGRAPH-#26233, IRGKangXi=0945.251
26234 CJK UNIFIED IDEOGRAPH-#26234, IRGKangXi=0945.260, RSKangXi=121.7
26235 CJK UNIFIED IDEOGRAPH-#26235, IRGKangXi=0945.270, RSKangXi=121.7
26236 CJK UNIFIED IDEOGRAPH-#26236, IRGKangXi=0945.280, RSKangXi=121.7
26237 CJK UNIFIED IDEOGRAPH-#26237, IRGKangXi=0945.281, RSKangXi=121.7
26238 CJK UNIFIED IDEOGRAPH-#26238, IRGKangXi=0945.290, RSKangXi=121.8
26239 CJK UNIFIED IDEOGRAPH-#26239, IRGKangXi=0945.300, RSKangXi=121.8
2623A CJK UNIFIED IDEOGRAPH-#2623A, IRGKangXi=0945.310, RSKangXi=121.8
2623B CJK UNIFIED IDEOGRAPH-#2623B, IRGKangXi=0945.340, RSKangXi=121.8
2623C CJK UNIFIED IDEOGRAPH-#2623C, IRGKangXi=0945.370, RSKangXi=121.8
2623D CJK UNIFIED IDEOGRAPH-#2623D, IRGKangXi=0945.381
2623E CJK UNIFIED IDEOGRAPH-#2623E, IRGKangXi=0945.381
2623F CJK UNIFIED IDEOGRAPH-#2623F, IRGKangXi=0945.381
26240 CJK UNIFIED IDEOGRAPH-#26240, IRGKangXi=0945.381
26241 CJK UNIFIED IDEOGRAPH-#26241, IRGKangXi=0945.390, RSKangXi=121.9
26242 CJK UNIFIED IDEOGRAPH-#26242, IRGKangXi=0945.400, RSKangXi=121.9
26243 CJK UNIFIED IDEOGRAPH-#26243, IRGKangXi=0945.401
26244 CJK UNIFIED IDEOGRAPH-#26244, IRGKangXi=0945.401
26245 CJK UNIFIED IDEOGRAPH-#26245, IRGKangXi=0945.401
26246 CJK UNIFIED IDEOGRAPH-#26246, IRGKangXi=0945.401, Def{to break off; a potsherd, a flaw}
26247 CJK UNIFIED IDEOGRAPH-#26247, IRGKangXi=0945.401, RSKangXi=121.9
26248 CJK UNIFIED IDEOGRAPH-#26248, IRGKangXi=0945.410, RSKangXi=121.10
26249 CJK UNIFIED IDEOGRAPH-#26249, IRGKangXi=0945.430, RSKangXi=121.10
2624A CJK UNIFIED IDEOGRAPH-#2624A, IRGKangXi=0945.441
2624B CJK UNIFIED IDEOGRAPH-#2624B, IRGKangXi=0945.441
2624C CJK UNIFIED IDEOGRAPH-#2624C, IRGKangXi=0945.441
2624D CJK UNIFIED IDEOGRAPH-#2624D, IRGKangXi=0945.441
2624E CJK UNIFIED IDEOGRAPH-#2624E, IRGKangXi=0945.460, RSKangXi=121.10
2624F CJK UNIFIED IDEOGRAPH-#2624F, IRGKangXi=0945.480, RSKangXi=121.11
26250 CJK UNIFIED IDEOGRAPH-#26250, IRGKangXi=0945.490, RSKangXi=121.11
26251 CJK UNIFIED IDEOGRAPH-#26251, IRGKangXi=0945.491, RSKangXi=121.11
26252 CJK UNIFIED IDEOGRAPH-#26252, IRGKangXi=0945.491
26253 CJK UNIFIED IDEOGRAPH-#26253, IRGKangXi=0945.491
26254 CJK UNIFIED IDEOGRAPH-#26254, IRGKangXi=0945.491
26255 CJK UNIFIED IDEOGRAPH-#26255, IRGKangXi=0945.500, RSKangXi=121.12
26256 CJK UNIFIED IDEOGRAPH-#26256, IRGKangXi=0945.520
26257 CJK UNIFIED IDEOGRAPH-#26257, IRGKangXi=0945.521
26258 CJK UNIFIED IDEOGRAPH-#26258, IRGKangXi=0945.521, Def{(Cant.) a cooking pot, cooker}
26259 CJK UNIFIED IDEOGRAPH-#26259, IRGKangXi=0946.010, RSKangXi=121.13
2625A CJK UNIFIED IDEOGRAPH-#2625A, IRGKangXi=0946.030, RSKangXi=121.13
2625B CJK UNIFIED IDEOGRAPH-#2625B, IRGKangXi=0946.031
2625C CJK UNIFIED IDEOGRAPH-#2625C, IRGKangXi=0946.031
2625D CJK UNIFIED IDEOGRAPH-#2625D, IRGKangXi=0946.040, RSKangXi=121.14
2625E CJK UNIFIED IDEOGRAPH-#2625E, IRGKangXi=0946.050, RSKangXi=121.14
2625F CJK UNIFIED IDEOGRAPH-#2625F, IRGKangXi=0946.070, RSKangXi=121.15
26260 CJK UNIFIED IDEOGRAPH-#26260, IRGKangXi=0946.100, RSKangXi=121.15
26261 CJK UNIFIED IDEOGRAPH-#26261, IRGKangXi=0946.121
26262 CJK UNIFIED IDEOGRAPH-#26262, IRGKangXi=0946.130, RSKangXi=121.17
26263 CJK UNIFIED IDEOGRAPH-#26263, IRGKangXi=0946.150, RSKangXi=121.17
26264 CJK UNIFIED IDEOGRAPH-#26264, IRGKangXi=0946.151
26265 CJK UNIFIED IDEOGRAPH-#26265, IRGKangXi=0946.170, RSKangXi=121.18
26266 CJK UNIFIED IDEOGRAPH-#26266, IRGKangXi=0946.171
26267 CJK UNIFIED IDEOGRAPH-#26267, IRGKangXi=0946.180, RSKangXi=121.20
26268 CJK UNIFIED IDEOGRAPH-#26268, IRGKangXi=0946.181
26269 CJK UNIFIED IDEOGRAPH-#26269, IRGKangXi=0946.190, RSKangXi=121.25
2626A CJK UNIFIED IDEOGRAPH-#2626A, IRGKangXi=0946.241, RSKangXi=122.0
2626B CJK UNIFIED IDEOGRAPH-#2626B, IRGKangXi=0946.241, RSKangXi=122.0
2626C CJK UNIFIED IDEOGRAPH-#2626C, IRGKangXi=0946.250, RSKangXi=122.2
2626D CJK UNIFIED IDEOGRAPH-#2626D, IRGKangXi=0946.260, RSKangXi=122.0
2626E CJK UNIFIED IDEOGRAPH-#2626E, IRGKangXi=0946.270, RSKangXi=122.2
2626F CJK UNIFIED IDEOGRAPH-#2626F, IRGKangXi=0946.280, RSKangXi=122.1
26270 CJK UNIFIED IDEOGRAPH-#26270, IRGKangXi=0946.281, RSKangXi=122.0
26271 CJK UNIFIED IDEOGRAPH-#26271, IRGKangXi=0946.281, RSKangXi=122.2
26272 CJK UNIFIED IDEOGRAPH-#26272, IRGKangXi=0946.281, RSKangXi=122.2
26273 CJK UNIFIED IDEOGRAPH-#26273, IRGKangXi=0946.281, RSKangXi=122.2
26274 CJK UNIFIED IDEOGRAPH-#26274, IRGKangXi=0946.281, RSKangXi=122.2
26275 CJK UNIFIED IDEOGRAPH-#26275, IRGKangXi=0946.281, RSKangXi=122.2
26276 CJK UNIFIED IDEOGRAPH-#26276, IRGKangXi=0946.281, RSKangXi=122.2
26277 CJK UNIFIED IDEOGRAPH-#26277, IRGKangXi=0946.290, RSKangXi=122.3
26278 CJK UNIFIED IDEOGRAPH-#26278, IRGKangXi=0946.330, RSKangXi=122.3
26279 CJK UNIFIED IDEOGRAPH-#26279, IRGKangXi=0946.360, RSKangXi=122.3
2627A CJK UNIFIED IDEOGRAPH-#2627A, IRGKangXi=0947.010, RSKangXi=122.3
2627B CJK UNIFIED IDEOGRAPH-#2627B, IRGKangXi=0947.020, RSKangXi=122.3
2627C CJK UNIFIED IDEOGRAPH-#2627C, IRGKangXi=0947.030, RSKangXi=122.3
2627D CJK UNIFIED IDEOGRAPH-#2627D, IRGKangXi=0947.031, RSKangXi=122.3
2627E CJK UNIFIED IDEOGRAPH-#2627E, IRGKangXi=0947.031, RSKangXi=122.3
2627F CJK UNIFIED IDEOGRAPH-#2627F, IRGKangXi=0947.031, RSKangXi=122.3
26280 CJK UNIFIED IDEOGRAPH-#26280, IRGKangXi=0947.031, RSKangXi=122.3
26281 CJK UNIFIED IDEOGRAPH-#26281, IRGKangXi=0947.050, RSKangXi=122.4
26282 CJK UNIFIED IDEOGRAPH-#26282, IRGKangXi=0947.080, RSKangXi=122.4
26283 CJK UNIFIED IDEOGRAPH-#26283, IRGKangXi=0947.100, RSKangXi=122.4
26284 CJK UNIFIED IDEOGRAPH-#26284, IRGKangXi=0947.101, RSKangXi=122.4
26285 CJK UNIFIED IDEOGRAPH-#26285, IRGKangXi=0947.101, RSKangXi=122.4
26286 CJK UNIFIED IDEOGRAPH-#26286, IRGKangXi=0947.101, RSKangXi=122.4
26287 CJK UNIFIED IDEOGRAPH-#26287, IRGKangXi=0947.101, RSKangXi=122.4
26288 CJK UNIFIED IDEOGRAPH-#26288, IRGKangXi=0947.101, RSKangXi=122.4
26289 CJK UNIFIED IDEOGRAPH-#26289, IRGKangXi=0947.101, RSKangXi=122.4
2628A CJK UNIFIED IDEOGRAPH-#2628A, IRGKangXi=0947.101, RSKangXi=122.4
2628B CJK UNIFIED IDEOGRAPH-#2628B, IRGKangXi=0947.101, RSKangXi=122.4
2628C CJK UNIFIED IDEOGRAPH-#2628C, IRGKangXi=0947.101, RSKangXi=122.4
2628D CJK UNIFIED IDEOGRAPH-#2628D, IRGKangXi=0947.101, RSKangXi=122.4
2628E CJK UNIFIED IDEOGRAPH-#2628E, IRGKangXi=0947.110, RSKangXi=122.5
2628F CJK UNIFIED IDEOGRAPH-#2628F, IRGKangXi=0947.120, RSKangXi=122.5
26290 CJK UNIFIED IDEOGRAPH-#26290, IRGKangXi=0947.130, RSKangXi=122.5
26291 CJK UNIFIED IDEOGRAPH-#26291, IRGKangXi=0947.140, RSKangXi=122.5
26292 CJK UNIFIED IDEOGRAPH-#26292, IRGKangXi=0947.160, RSKangXi=122.5
26293 CJK UNIFIED IDEOGRAPH-#26293, IRGKangXi=0947.170, RSKangXi=122.5
26294 CJK UNIFIED IDEOGRAPH-#26294, IRGKangXi=0947.190, RSKangXi=122.5
26295 CJK UNIFIED IDEOGRAPH-#26295, IRGKangXi=0947.230, RSKangXi=122.5
26296 CJK UNIFIED IDEOGRAPH-#26296, IRGKangXi=0947.290, RSKangXi=122.5
26297 CJK UNIFIED IDEOGRAPH-#26297, IRGKangXi=0947.310, RSKangXi=122.5
26298 CJK UNIFIED IDEOGRAPH-#26298, IRGKangXi=0947.320, RSKangXi=122.5
26299 CJK UNIFIED IDEOGRAPH-#26299, IRGKangXi=0947.321, RSKangXi=122.5
2629A CJK UNIFIED IDEOGRAPH-#2629A, IRGKangXi=0947.321, RSKangXi=122.5
2629B CJK UNIFIED IDEOGRAPH-#2629B, IRGKangXi=0947.321, RSKangXi=122.5
2629C CJK UNIFIED IDEOGRAPH-#2629C, IRGKangXi=0947.321, RSKangXi=122.5
2629D CJK UNIFIED IDEOGRAPH-#2629D, IRGKangXi=0947.321, RSKangXi=122.5
2629E CJK UNIFIED IDEOGRAPH-#2629E, IRGKangXi=0947.321, RSKangXi=122.5
2629F CJK UNIFIED IDEOGRAPH-#2629F, IRGKangXi=0947.321, RSKangXi=122.5
262A0 CJK UNIFIED IDEOGRAPH-#262A0, IRGKangXi=0947.321, RSKangXi=122.5
262A1 CJK UNIFIED IDEOGRAPH-#262A1, IRGKangXi=0947.321, RSKangXi=122.5
262A2 CJK UNIFIED IDEOGRAPH-#262A2, IRGKangXi=0947.321, RSKangXi=122.5
262A3 CJK UNIFIED IDEOGRAPH-#262A3, IRGKangXi=0947.321, RSKangXi=122.5
262A4 CJK UNIFIED IDEOGRAPH-#262A4, IRGKangXi=0947.321, RSKangXi=46.7
262A5 CJK UNIFIED IDEOGRAPH-#262A5, IRGKangXi=0947.321, RSKangXi=122.5
262A6 CJK UNIFIED IDEOGRAPH-#262A6, IRGKangXi=0947.321, RSKangXi=122.5
262A7 CJK UNIFIED IDEOGRAPH-#262A7, IRGKangXi=0947.321, RSKangXi=122.5
262A8 CJK UNIFIED IDEOGRAPH-#262A8, IRGKangXi=0947.321, RSKangXi=122.5
262A9 CJK UNIFIED IDEOGRAPH-#262A9, IRGKangXi=0947.321, RSKangXi=122.5
262AA CJK UNIFIED IDEOGRAPH-#262AA, IRGKangXi=0947.330, RSKangXi=122.6
262AB CJK UNIFIED IDEOGRAPH-#262AB, IRGKangXi=0947.350, RSKangXi=122.6
262AC CJK UNIFIED IDEOGRAPH-#262AC, IRGKangXi=0947.360, RSKangXi=122.6
262AD CJK UNIFIED IDEOGRAPH-#262AD, IRGKangXi=0947.380, RSKangXi=122.6
262AE CJK UNIFIED IDEOGRAPH-#262AE, IRGKangXi=0947.390, RSKangXi=122.6
262AF CJK UNIFIED IDEOGRAPH-#262AF, IRGKangXi=0947.400, RSKangXi=122.6
262B0 CJK UNIFIED IDEOGRAPH-#262B0, IRGKangXi=0947.401, RSKangXi=122.6
262B1 CJK UNIFIED IDEOGRAPH-#262B1, IRGKangXi=0947.401, RSKangXi=122.6
262B2 CJK UNIFIED IDEOGRAPH-#262B2, IRGKangXi=0947.401, RSKangXi=122.6
262B3 CJK UNIFIED IDEOGRAPH-#262B3, IRGKangXi=0947.401, RSKangXi=122.5
262B4 CJK UNIFIED IDEOGRAPH-#262B4, IRGKangXi=0947.401, RSKangXi=122.6
262B5 CJK UNIFIED IDEOGRAPH-#262B5, IRGKangXi=0947.401, RSKangXi=122.6
262B6 CJK UNIFIED IDEOGRAPH-#262B6, IRGKangXi=0947.401, RSKangXi=122.6
262B7 CJK UNIFIED IDEOGRAPH-#262B7, IRGKangXi=0947.401, RSKangXi=122.6
262B8 CJK UNIFIED IDEOGRAPH-#262B8, IRGKangXi=0947.401, RSKangXi=122.6
262B9 CJK UNIFIED IDEOGRAPH-#262B9, IRGKangXi=0947.401, RSKangXi=122.6
262BA CJK UNIFIED IDEOGRAPH-#262BA, IRGKangXi=0947.401, RSKangXi=122.6
262BB CJK UNIFIED IDEOGRAPH-#262BB, IRGKangXi=0947.401, RSKangXi=122.6
262BC CJK UNIFIED IDEOGRAPH-#262BC, IRGKangXi=0947.410, RSKangXi=122.7
262BD CJK UNIFIED IDEOGRAPH-#262BD, IRGKangXi=0947.420, RSKangXi=122.7
262BE CJK UNIFIED IDEOGRAPH-#262BE, IRGKangXi=0947.440, RSKangXi=122.7
262BF CJK UNIFIED IDEOGRAPH-#262BF, IRGKangXi=0948.030, RSKangXi=122.7
262C0 CJK UNIFIED IDEOGRAPH-#262C0, IRGKangXi=0948.031, RSKangXi=122.7
262C1 CJK UNIFIED IDEOGRAPH-#262C1, IRGKangXi=0948.031, RSKangXi=122.7
262C2 CJK UNIFIED IDEOGRAPH-#262C2, IRGKangXi=0948.031, RSKangXi=122.7
262C3 CJK UNIFIED IDEOGRAPH-#262C3, IRGKangXi=0948.031, RSKangXi=122.7
262C4 CJK UNIFIED IDEOGRAPH-#262C4, IRGKangXi=0948.031, RSKangXi=122.7
262C5 CJK UNIFIED IDEOGRAPH-#262C5, IRGKangXi=0948.040, RSKangXi=122.8
262C6 CJK UNIFIED IDEOGRAPH-#262C6, IRGKangXi=0948.060, RSKangXi=122.8
262C7 CJK UNIFIED IDEOGRAPH-#262C7, IRGKangXi=0948.100, RSKangXi=122.8
262C8 CJK UNIFIED IDEOGRAPH-#262C8, IRGKangXi=0948.120, RSKangXi=122.8
262C9 CJK UNIFIED IDEOGRAPH-#262C9, IRGKangXi=0948.160, RSKangXi=122.8
262CA CJK UNIFIED IDEOGRAPH-#262CA, IRGKangXi=0948.260, RSKangXi=122.8
262CB CJK UNIFIED IDEOGRAPH-#262CB, IRGKangXi=0948.270, RSKangXi=122.8
262CC CJK UNIFIED IDEOGRAPH-#262CC, IRGKangXi=0948.280, RSKangXi=122.8
262CD CJK UNIFIED IDEOGRAPH-#262CD, IRGKangXi=0948.290, RSKangXi=122.8
262CE CJK UNIFIED IDEOGRAPH-#262CE, IRGKangXi=0948.291, RSKangXi=122.8
262CF CJK UNIFIED IDEOGRAPH-#262CF, IRGKangXi=0948.291, RSKangXi=122.8
262D0 CJK UNIFIED IDEOGRAPH-#262D0, IRGKangXi=0948.291, RSKangXi=122.8
262D1 CJK UNIFIED IDEOGRAPH-#262D1, IRGKangXi=0948.291, RSKangXi=122.7
262D2 CJK UNIFIED IDEOGRAPH-#262D2, IRGKangXi=0948.291, RSKangXi=122.8
262D3 CJK UNIFIED IDEOGRAPH-#262D3, IRGKangXi=0948.291, RSKangXi=122.8
262D4 CJK UNIFIED IDEOGRAPH-#262D4, IRGKangXi=0948.291, RSKangXi=122.8
262D5 CJK UNIFIED IDEOGRAPH-#262D5, IRGKangXi=0948.291, RSKangXi=122.8
262D6 CJK UNIFIED IDEOGRAPH-#262D6, IRGKangXi=0948.291, RSKangXi=122.8
262D7 CJK UNIFIED IDEOGRAPH-#262D7, IRGKangXi=0948.291, RSKangXi=122.8
262D8 CJK UNIFIED IDEOGRAPH-#262D8, IRGKangXi=0948.291, RSKangXi=122.8
262D9 CJK UNIFIED IDEOGRAPH-#262D9, IRGKangXi=0948.291, RSKangXi=122.8
262DA CJK UNIFIED IDEOGRAPH-#262DA, IRGKangXi=0948.291, RSKangXi=122.8
262DB CJK UNIFIED IDEOGRAPH-#262DB, IRGKangXi=0948.291, RSKangXi=122.8
262DC CJK UNIFIED IDEOGRAPH-#262DC, IRGKangXi=0948.291, RSKangXi=122.8
262DD CJK UNIFIED IDEOGRAPH-#262DD, IRGKangXi=0948.310, RSKangXi=122.9
262DE CJK UNIFIED IDEOGRAPH-#262DE, IRGKangXi=0948.320, RSKangXi=122.9
262DF CJK UNIFIED IDEOGRAPH-#262DF, IRGKangXi=0948.360, RSKangXi=122.9
262E0 CJK UNIFIED IDEOGRAPH-#262E0, IRGKangXi=0948.380, RSKangXi=122.9
262E1 CJK UNIFIED IDEOGRAPH-#262E1, IRGKangXi=0948.400, RSKangXi=122.9
262E2 CJK UNIFIED IDEOGRAPH-#262E2, IRGKangXi=0948.410, RSKangXi=122.9
262E3 CJK UNIFIED IDEOGRAPH-#262E3, IRGKangXi=0949.010, RSKangXi=122.9
262E4 CJK UNIFIED IDEOGRAPH-#262E4, IRGKangXi=0949.020, RSKangXi=122.9
262E5 CJK UNIFIED IDEOGRAPH-#262E5, IRGKangXi=0949.021, RSKangXi=122.9
262E6 CJK UNIFIED IDEOGRAPH-#262E6, IRGKangXi=0949.021, RSKangXi=122.9
262E7 CJK UNIFIED IDEOGRAPH-#262E7, IRGKangXi=0949.021, RSKangXi=122.9
262E8 CJK UNIFIED IDEOGRAPH-#262E8, IRGKangXi=0949.021, RSKangXi=122.9
262E9 CJK UNIFIED IDEOGRAPH-#262E9, IRGKangXi=0949.021, RSKangXi=122.9
262EA CJK UNIFIED IDEOGRAPH-#262EA, IRGKangXi=0949.021, RSKangXi=54.12
262EB CJK UNIFIED IDEOGRAPH-#262EB, IRGKangXi=0949.021, RSKangXi=122.9
262EC CJK UNIFIED IDEOGRAPH-#262EC, IRGKangXi=0949.021, RSKangXi=122.9
262ED CJK UNIFIED IDEOGRAPH-#262ED, IRGKangXi=0949.021, RSKangXi=122.9
262EE CJK UNIFIED IDEOGRAPH-#262EE, IRGKangXi=0949.021, RSKangXi=122.9
262EF CJK UNIFIED IDEOGRAPH-#262EF, IRGKangXi=0949.030, RSKangXi=122.10
262F0 CJK UNIFIED IDEOGRAPH-#262F0, IRGKangXi=0949.040, RSKangXi=122.10
262F1 CJK UNIFIED IDEOGRAPH-#262F1, IRGKangXi=0949.060, RSKangXi=122.10
262F2 CJK UNIFIED IDEOGRAPH-#262F2, IRGKangXi=0949.090, RSKangXi=122.10
262F3 CJK UNIFIED IDEOGRAPH-#262F3, IRGKangXi=0949.100, RSKangXi=122.10
262F4 CJK UNIFIED IDEOGRAPH-#262F4, IRGKangXi=0949.110, RSKangXi=122.10
262F5 CJK UNIFIED IDEOGRAPH-#262F5, IRGKangXi=0949.120, RSKangXi=122.10
262F6 CJK UNIFIED IDEOGRAPH-#262F6, IRGKangXi=0949.121, RSKangXi=122.10
262F7 CJK UNIFIED IDEOGRAPH-#262F7, IRGKangXi=0949.121, RSKangXi=122.10
262F8 CJK UNIFIED IDEOGRAPH-#262F8, IRGKangXi=0949.121, RSKangXi=122.10
262F9 CJK UNIFIED IDEOGRAPH-#262F9, IRGKangXi=0949.121, RSKangXi=122.10
262FA CJK UNIFIED IDEOGRAPH-#262FA, IRGKangXi=0949.121, RSKangXi=122.10
262FB CJK UNIFIED IDEOGRAPH-#262FB, IRGKangXi=0949.121, RSKangXi=122.10
262FC CJK UNIFIED IDEOGRAPH-#262FC, IRGKangXi=0949.121, RSKangXi=122.10
262FD CJK UNIFIED IDEOGRAPH-#262FD, IRGKangXi=0949.130, RSKangXi=122.11
262FE CJK UNIFIED IDEOGRAPH-#262FE, IRGKangXi=0949.140, RSKangXi=122.11
262FF CJK UNIFIED IDEOGRAPH-#262FF, IRGKangXi=0949.150, RSKangXi=122.11
26300 CJK UNIFIED IDEOGRAPH-#26300, IRGKangXi=0949.170, RSKangXi=122.11
26301 CJK UNIFIED IDEOGRAPH-#26301, IRGKangXi=0949.180, RSKangXi=122.11, Def{a net}
26302 CJK UNIFIED IDEOGRAPH-#26302, IRGKangXi=0949.210, RSKangXi=122.11
26303 CJK UNIFIED IDEOGRAPH-#26303, IRGKangXi=0949.230, RSKangXi=122.11
26304 CJK UNIFIED IDEOGRAPH-#26304, IRGKangXi=0949.250, RSKangXi=122.11
26305 CJK UNIFIED IDEOGRAPH-#26305, IRGKangXi=0949.260, RSKangXi=122.11
26306 CJK UNIFIED IDEOGRAPH-#26306, IRGKangXi=0949.270, RSKangXi=122.11
26307 CJK UNIFIED IDEOGRAPH-#26307, IRGKangXi=0949.271, RSKangXi=122.11
26308 CJK UNIFIED IDEOGRAPH-#26308, IRGKangXi=0949.271, RSKangXi=122.11
26309 CJK UNIFIED IDEOGRAPH-#26309, IRGKangXi=0949.271, RSKangXi=122.11
2630A CJK UNIFIED IDEOGRAPH-#2630A, IRGKangXi=0949.271, RSKangXi=122.11
2630B CJK UNIFIED IDEOGRAPH-#2630B, IRGKangXi=0949.271, RSKangXi=122.11
2630C CJK UNIFIED IDEOGRAPH-#2630C, IRGKangXi=0949.271, RSKangXi=122.11
2630D CJK UNIFIED IDEOGRAPH-#2630D, IRGKangXi=0949.271, RSKangXi=122.11
2630E CJK UNIFIED IDEOGRAPH-#2630E, IRGKangXi=0949.271, RSKangXi=122.11
2630F CJK UNIFIED IDEOGRAPH-#2630F, IRGKangXi=0949.271, RSKangXi=122.11
26310 CJK UNIFIED IDEOGRAPH-#26310, IRGKangXi=0949.271, RSKangXi=122.11
26311 CJK UNIFIED IDEOGRAPH-#26311, IRGKangXi=0949.271, RSKangXi=122.11
26312 CJK UNIFIED IDEOGRAPH-#26312, IRGKangXi=0949.280, RSKangXi=122.12
26313 CJK UNIFIED IDEOGRAPH-#26313, IRGKangXi=0949.310, RSKangXi=122.12
26314 CJK UNIFIED IDEOGRAPH-#26314, IRGKangXi=0949.320, RSKangXi=122.12
26315 CJK UNIFIED IDEOGRAPH-#26315, IRGKangXi=0949.340, RSKangXi=122.12
26316 CJK UNIFIED IDEOGRAPH-#26316, IRGKangXi=0949.360, RSKangXi=122.12
26317 CJK UNIFIED IDEOGRAPH-#26317, IRGKangXi=0949.370, RSKangXi=122.12
26318 CJK UNIFIED IDEOGRAPH-#26318, IRGKangXi=0949.371, RSKangXi=122.12
26319 CJK UNIFIED IDEOGRAPH-#26319, IRGKangXi=0949.371, RSKangXi=122.12
2631A CJK UNIFIED IDEOGRAPH-#2631A, IRGKangXi=0949.371, RSKangXi=122.12
2631B CJK UNIFIED IDEOGRAPH-#2631B, IRGKangXi=0949.371, RSKangXi=122.12
2631C CJK UNIFIED IDEOGRAPH-#2631C, IRGKangXi=0949.371, RSKangXi=122.12
2631D CJK UNIFIED IDEOGRAPH-#2631D, IRGKangXi=0949.371, RSKangXi=122.12
2631E CJK UNIFIED IDEOGRAPH-#2631E, IRGKangXi=0949.371, RSKangXi=122.12
2631F CJK UNIFIED IDEOGRAPH-#2631F, IRGKangXi=0949.380, RSKangXi=122.13
26320 CJK UNIFIED IDEOGRAPH-#26320, IRGKangXi=0949.390, RSKangXi=122.13
26321 CJK UNIFIED IDEOGRAPH-#26321, IRGKangXi=0949.400, RSKangXi=122.13
26322 CJK UNIFIED IDEOGRAPH-#26322, IRGKangXi=0950.020, RSKangXi=122.13
26323 CJK UNIFIED IDEOGRAPH-#26323, IRGKangXi=0950.040, RSKangXi=122.13
26324 CJK UNIFIED IDEOGRAPH-#26324, IRGKangXi=0950.050, RSKangXi=122.13
26325 CJK UNIFIED IDEOGRAPH-#26325, IRGKangXi=0950.051, RSKangXi=122.13
26326 CJK UNIFIED IDEOGRAPH-#26326, IRGKangXi=0950.051, RSKangXi=122.13
26327 CJK UNIFIED IDEOGRAPH-#26327, IRGKangXi=0950.051, RSKangXi=122.13
26328 CJK UNIFIED IDEOGRAPH-#26328, IRGKangXi=0950.051, RSKangXi=122.13
26329 CJK UNIFIED IDEOGRAPH-#26329, IRGKangXi=0950.051, RSKangXi=123.12
2632A CJK UNIFIED IDEOGRAPH-#2632A, IRGKangXi=0950.070, RSKangXi=122.14
2632B CJK UNIFIED IDEOGRAPH-#2632B, IRGKangXi=0950.110, RSKangXi=122.14
2632C CJK UNIFIED IDEOGRAPH-#2632C, IRGKangXi=0950.170, RSKangXi=122.14
2632D CJK UNIFIED IDEOGRAPH-#2632D, IRGKangXi=0950.180, RSKangXi=122.14
2632E CJK UNIFIED IDEOGRAPH-#2632E, IRGKangXi=0950.190, RSKangXi=122.14
2632F CJK UNIFIED IDEOGRAPH-#2632F, IRGKangXi=0950.191, RSKangXi=122.14
26330 CJK UNIFIED IDEOGRAPH-#26330, IRGKangXi=0950.191, RSKangXi=122.14
26331 CJK UNIFIED IDEOGRAPH-#26331, IRGKangXi=0950.191, RSKangXi=122.14
26332 CJK UNIFIED IDEOGRAPH-#26332, IRGKangXi=0950.191, RSKangXi=122.14
26333 CJK UNIFIED IDEOGRAPH-#26333, IRGKangXi=0950.191, RSKangXi=122.14
26334 CJK UNIFIED IDEOGRAPH-#26334, IRGKangXi=0950.191, RSKangXi=122.14
26335 CJK UNIFIED IDEOGRAPH-#26335, IRGKangXi=0950.200, RSKangXi=122.15
26336 CJK UNIFIED IDEOGRAPH-#26336, IRGKangXi=0950.210, RSKangXi=122.15
26337 CJK UNIFIED IDEOGRAPH-#26337, IRGKangXi=0950.220, RSKangXi=122.15
26338 CJK UNIFIED IDEOGRAPH-#26338, IRGKangXi=0950.230, RSKangXi=122.15
26339 CJK UNIFIED IDEOGRAPH-#26339, IRGKangXi=0950.231, RSKangXi=122.15
2633A CJK UNIFIED IDEOGRAPH-#2633A, IRGKangXi=0950.231, RSKangXi=122.15
2633B CJK UNIFIED IDEOGRAPH-#2633B, IRGKangXi=0950.240, RSKangXi=122.16
2633C CJK UNIFIED IDEOGRAPH-#2633C, IRGKangXi=0950.270, RSKangXi=122.16
2633D CJK UNIFIED IDEOGRAPH-#2633D, IRGKangXi=0950.271, RSKangXi=122.18
2633E CJK UNIFIED IDEOGRAPH-#2633E, IRGKangXi=0950.290, RSKangXi=122.19
2633F CJK UNIFIED IDEOGRAPH-#2633F, IRGKangXi=0950.300, RSKangXi=122.19
26340 CJK UNIFIED IDEOGRAPH-#26340, IRGKangXi=0950.310, RSKangXi=122.19
26341 CJK UNIFIED IDEOGRAPH-#26341, IRGKangXi=0950.340, RSKangXi=122.19
26342 CJK UNIFIED IDEOGRAPH-#26342, IRGKangXi=0950.351, RSKangXi=122.19
26343 CJK UNIFIED IDEOGRAPH-#26343, IRGKangXi=0950.351, RSKangXi=122.19
26344 CJK UNIFIED IDEOGRAPH-#26344, IRGKangXi=0950.351, RSKangXi=122.19
26345 CJK UNIFIED IDEOGRAPH-#26345, IRGKangXi=0950.351, RSKangXi=122.19
26346 CJK UNIFIED IDEOGRAPH-#26346, IRGKangXi=0950.351, RSKangXi=122.21
26347 CJK UNIFIED IDEOGRAPH-#26347, IRGKangXi=0950.360, RSKangXi=122.22
26348 CJK UNIFIED IDEOGRAPH-#26348, IRGKangXi=0950.370, RSKangXi=122.23
26349 CJK UNIFIED IDEOGRAPH-#26349, IRGKangXi=0950.371, RSKangXi=122.23
2634A CJK UNIFIED IDEOGRAPH-#2634A, IRGKangXi=0950.371, RSKangXi=122.23
2634B CJK UNIFIED IDEOGRAPH-#2634B, IRGKangXi=0951.010, RSKangXi=123.0
2634C CJK UNIFIED IDEOGRAPH-#2634C, IRGKangXi=0951.021, RSKangXi=123.0
2634D CJK UNIFIED IDEOGRAPH-#2634D, IRGKangXi=0951.021, RSKangXi=123.-1
2634E CJK UNIFIED IDEOGRAPH-#2634E, IRGKangXi=0951.050, RSKangXi=123.2
2634F CJK UNIFIED IDEOGRAPH-#2634F, IRGKangXi=0951.060, RSKangXi=123.2
26350 CJK UNIFIED IDEOGRAPH-#26350, IRGKangXi=0951.070, RSKangXi=123.2
26351 CJK UNIFIED IDEOGRAPH-#26351, IRGKangXi=0951.071, RSKangXi=123.3
26352 CJK UNIFIED IDEOGRAPH-#26352, IRGKangXi=0951.080, RSKangXi=123.3
26353 CJK UNIFIED IDEOGRAPH-#26353, IRGKangXi=0951.130, RSKangXi=123.3
26354 CJK UNIFIED IDEOGRAPH-#26354, IRGKangXi=0951.140, RSKangXi=123.3
26355 CJK UNIFIED IDEOGRAPH-#26355, IRGKangXi=0951.150, RSKangXi=123.3
26356 CJK UNIFIED IDEOGRAPH-#26356, IRGKangXi=0951.151, RSKangXi=123.3
26357 CJK UNIFIED IDEOGRAPH-#26357, IRGKangXi=0951.180, RSKangXi=123.4
26358 CJK UNIFIED IDEOGRAPH-#26358, IRGKangXi=0951.190, RSKangXi=123.4
26359 CJK UNIFIED IDEOGRAPH-#26359, IRGKangXi=0951.220, RSKangXi=123.4
2635A CJK UNIFIED IDEOGRAPH-#2635A, IRGKangXi=0951.240, RSKangXi=123.4
2635B CJK UNIFIED IDEOGRAPH-#2635B, IRGKangXi=0951.250, RSKangXi=123.4
2635C CJK UNIFIED IDEOGRAPH-#2635C, IRGKangXi=0951.270, RSKangXi=123.4
2635D CJK UNIFIED IDEOGRAPH-#2635D, IRGKangXi=0951.280, RSKangXi=123.4
2635E CJK UNIFIED IDEOGRAPH-#2635E, IRGKangXi=0951.290, RSKangXi=123.4
2635F CJK UNIFIED IDEOGRAPH-#2635F, IRGKangXi=0951.330, RSKangXi=123.4
26360 CJK UNIFIED IDEOGRAPH-#26360, IRGKangXi=0951.331, RSKangXi=123.4
26361 CJK UNIFIED IDEOGRAPH-#26361, IRGKangXi=0951.331, RSKangXi=123.4
26362 CJK UNIFIED IDEOGRAPH-#26362, IRGKangXi=0951.331, RSKangXi=123.4
26363 CJK UNIFIED IDEOGRAPH-#26363, IRGKangXi=0951.331, RSKangXi=123.4
26364 CJK UNIFIED IDEOGRAPH-#26364, IRGKangXi=0951.331, RSKangXi=123.4
26365 CJK UNIFIED IDEOGRAPH-#26365, IRGKangXi=0951.360, RSKangXi=123.5
26366 CJK UNIFIED IDEOGRAPH-#26366, IRGKangXi=0951.380, RSKangXi=123.5
26367 CJK UNIFIED IDEOGRAPH-#26367, IRGKangXi=0951.400, RSKangXi=123.5
26368 CJK UNIFIED IDEOGRAPH-#26368, IRGKangXi=0951.410, RSKangXi=123.5
26369 CJK UNIFIED IDEOGRAPH-#26369, IRGKangXi=0952.020, RSKangXi=123.5, Def{a ram}
2636A CJK UNIFIED IDEOGRAPH-#2636A, IRGKangXi=0952.050, RSKangXi=123.5
2636B CJK UNIFIED IDEOGRAPH-#2636B, IRGKangXi=0952.060, RSKangXi=123.5
2636C CJK UNIFIED IDEOGRAPH-#2636C, IRGKangXi=0952.070, RSKangXi=123.5
2636D CJK UNIFIED IDEOGRAPH-#2636D, IRGKangXi=0952.090, RSKangXi=123.5
2636E CJK UNIFIED IDEOGRAPH-#2636E, IRGKangXi=0952.091, RSKangXi=123.4
2636F CJK UNIFIED IDEOGRAPH-#2636F, IRGKangXi=0952.091, RSKangXi=123.5
26370 CJK UNIFIED IDEOGRAPH-#26370, IRGKangXi=0952.091, RSKangXi=123.5
26371 CJK UNIFIED IDEOGRAPH-#26371, IRGKangXi=0952.091, RSKangXi=123.5
26372 CJK UNIFIED IDEOGRAPH-#26372, IRGKangXi=0952.091, RSKangXi=123.5
26373 CJK UNIFIED IDEOGRAPH-#26373, IRGKangXi=0952.091, RSKangXi=123.5
26374 CJK UNIFIED IDEOGRAPH-#26374, IRGKangXi=0952.091, RSKangXi=123.5
26375 CJK UNIFIED IDEOGRAPH-#26375, IRGKangXi=0952.091, RSKangXi=123.5
26376 CJK UNIFIED IDEOGRAPH-#26376, IRGKangXi=0952.091, RSKangXi=123.5
26377 CJK UNIFIED IDEOGRAPH-#26377, IRGKangXi=0952.091, RSKangXi=123.5
26378 CJK UNIFIED IDEOGRAPH-#26378, IRGKangXi=0952.091, RSKangXi=123.5
26379 CJK UNIFIED IDEOGRAPH-#26379, IRGKangXi=0952.120, RSKangXi=123.6
2637A CJK UNIFIED IDEOGRAPH-#2637A, IRGKangXi=0952.140, RSKangXi=123.6
2637B CJK UNIFIED IDEOGRAPH-#2637B, IRGKangXi=0952.160, RSKangXi=123.6
2637C CJK UNIFIED IDEOGRAPH-#2637C, IRGKangXi=0952.170, RSKangXi=123.6
2637D CJK UNIFIED IDEOGRAPH-#2637D, IRGKangXi=0952.190, RSKangXi=123.6
2637E CJK UNIFIED IDEOGRAPH-#2637E, IRGKangXi=0952.200, RSKangXi=123.6
2637F CJK UNIFIED IDEOGRAPH-#2637F, IRGKangXi=0952.210, RSKangXi=123.6
26380 CJK UNIFIED IDEOGRAPH-#26380, IRGKangXi=0952.220, RSKangXi=123.6
26381 CJK UNIFIED IDEOGRAPH-#26381, IRGKangXi=0952.241, RSKangXi=123.6
26382 CJK UNIFIED IDEOGRAPH-#26382, IRGKangXi=0952.241, RSKangXi=123.6
26383 CJK UNIFIED IDEOGRAPH-#26383, IRGKangXi=0952.241, RSKangXi=123.6
26384 CJK UNIFIED IDEOGRAPH-#26384, IRGKangXi=0952.241, RSKangXi=123.6
26385 CJK UNIFIED IDEOGRAPH-#26385, IRGKangXi=0952.241, RSKangXi=28.10
26386 CJK UNIFIED IDEOGRAPH-#26386, IRGKangXi=0952.300, RSKangXi=123.7
26387 CJK UNIFIED IDEOGRAPH-#26387, IRGKangXi=0953.010, RSKangXi=123.7
26388 CJK UNIFIED IDEOGRAPH-#26388, IRGKangXi=0953.030, RSKangXi=123.7
26389 CJK UNIFIED IDEOGRAPH-#26389, IRGKangXi=0953.040, RSKangXi=123.7
2638A CJK UNIFIED IDEOGRAPH-#2638A, IRGKangXi=0953.050, RSKangXi=123.7
2638B CJK UNIFIED IDEOGRAPH-#2638B, IRGKangXi=0953.060, RSKangXi=123.7
2638C CJK UNIFIED IDEOGRAPH-#2638C, IRGKangXi=0953.070, RSKangXi=123.7
2638D CJK UNIFIED IDEOGRAPH-#2638D, IRGKangXi=0953.080, RSKangXi=123.7
2638E CJK UNIFIED IDEOGRAPH-#2638E, IRGKangXi=0953.081, RSKangXi=123.7
2638F CJK UNIFIED IDEOGRAPH-#2638F, IRGKangXi=0953.081, RSKangXi=123.7
26390 CJK UNIFIED IDEOGRAPH-#26390, IRGKangXi=0953.081, RSKangXi=123.7
26391 CJK UNIFIED IDEOGRAPH-#26391, IRGKangXi=0953.081, RSKangXi=123.7
26392 CJK UNIFIED IDEOGRAPH-#26392, IRGKangXi=0953.081, RSKangXi=123.7
26393 CJK UNIFIED IDEOGRAPH-#26393, IRGKangXi=0953.081, RSKangXi=123.7
26394 CJK UNIFIED IDEOGRAPH-#26394, IRGKangXi=0953.081, RSKangXi=123.7
26395 CJK UNIFIED IDEOGRAPH-#26395, IRGKangXi=0953.081, RSKangXi=123.7
26396 CJK UNIFIED IDEOGRAPH-#26396, IRGKangXi=0953.081, RSKangXi=123.7
26397 CJK UNIFIED IDEOGRAPH-#26397, IRGKangXi=0953.130, RSKangXi=123.8
26398 CJK UNIFIED IDEOGRAPH-#26398, IRGKangXi=0953.140, RSKangXi=123.8
26399 CJK UNIFIED IDEOGRAPH-#26399, IRGKangXi=0953.170, RSKangXi=123.8
2639A CJK UNIFIED IDEOGRAPH-#2639A, IRGKangXi=0953.180, RSKangXi=123.8
2639B CJK UNIFIED IDEOGRAPH-#2639B, IRGKangXi=0953.181, RSKangXi=123.8
2639C CJK UNIFIED IDEOGRAPH-#2639C, IRGKangXi=0953.181, RSKangXi=123.8
2639D CJK UNIFIED IDEOGRAPH-#2639D, IRGKangXi=0953.181, RSKangXi=123.8
2639E CJK UNIFIED IDEOGRAPH-#2639E, IRGKangXi=0953.181, RSKangXi=123.8
2639F CJK UNIFIED IDEOGRAPH-#2639F, IRGKangXi=0953.181, RSKangXi=123.8
263A0 CJK UNIFIED IDEOGRAPH-#263A0, IRGKangXi=0953.181, RSKangXi=123.8
263A1 CJK UNIFIED IDEOGRAPH-#263A1, IRGKangXi=0953.181, RSKangXi=123.8
263A2 CJK UNIFIED IDEOGRAPH-#263A2, IRGKangXi=0953.190, RSKangXi=123.9
263A3 CJK UNIFIED IDEOGRAPH-#263A3, IRGKangXi=0953.200, RSKangXi=123.9
263A4 CJK UNIFIED IDEOGRAPH-#263A4, IRGKangXi=0953.220, RSKangXi=123.9
263A5 CJK UNIFIED IDEOGRAPH-#263A5, IRGKangXi=0953.240, RSKangXi=123.9
263A6 CJK UNIFIED IDEOGRAPH-#263A6, IRGKangXi=0953.260, RSKangXi=123.9
263A7 CJK UNIFIED IDEOGRAPH-#263A7, IRGKangXi=0953.270, RSKangXi=123.9
263A8 CJK UNIFIED IDEOGRAPH-#263A8, IRGKangXi=0953.300, RSKangXi=123.9
263A9 CJK UNIFIED IDEOGRAPH-#263A9, IRGKangXi=0953.310, RSKangXi=123.9
263AA CJK UNIFIED IDEOGRAPH-#263AA, IRGKangXi=0953.311, RSKangXi=123.9
263AB CJK UNIFIED IDEOGRAPH-#263AB, IRGKangXi=0953.311, RSKangXi=123.9
263AC CJK UNIFIED IDEOGRAPH-#263AC, IRGKangXi=0953.311, RSKangXi=123.9
263AD CJK UNIFIED IDEOGRAPH-#263AD, IRGKangXi=0953.311, RSKangXi=123.9
263AE CJK UNIFIED IDEOGRAPH-#263AE, IRGKangXi=0953.311, RSKangXi=123.9
263AF CJK UNIFIED IDEOGRAPH-#263AF, IRGKangXi=0953.340, RSKangXi=123.10
263B0 CJK UNIFIED IDEOGRAPH-#263B0, IRGKangXi=0953.360, RSKangXi=123.10
263B1 CJK UNIFIED IDEOGRAPH-#263B1, IRGKangXi=0953.370, RSKangXi=123.10
263B2 CJK UNIFIED IDEOGRAPH-#263B2, IRGKangXi=0953.380, RSKangXi=123.10
263B3 CJK UNIFIED IDEOGRAPH-#263B3, IRGKangXi=0953.381, RSKangXi=123.10
263B4 CJK UNIFIED IDEOGRAPH-#263B4, IRGKangXi=0953.381, RSKangXi=123.10
263B5 CJK UNIFIED IDEOGRAPH-#263B5, IRGKangXi=0953.381, RSKangXi=123.10
263B6 CJK UNIFIED IDEOGRAPH-#263B6, IRGKangXi=0953.381, RSKangXi=123.10
263B7 CJK UNIFIED IDEOGRAPH-#263B7, IRGKangXi=0953.390, RSKangXi=123.11
263B8 CJK UNIFIED IDEOGRAPH-#263B8, IRGKangXi=0953.410, RSKangXi=123.11
263B9 CJK UNIFIED IDEOGRAPH-#263B9, IRGKangXi=0953.420, RSKangXi=123.11
263BA CJK UNIFIED IDEOGRAPH-#263BA, IRGKangXi=0954.020, RSKangXi=123.11
263BB CJK UNIFIED IDEOGRAPH-#263BB, IRGKangXi=0954.030, RSKangXi=123.11
263BC CJK UNIFIED IDEOGRAPH-#263BC, IRGKangXi=0954.040, RSKangXi=123.11
263BD CJK UNIFIED IDEOGRAPH-#263BD, IRGKangXi=0954.041, RSKangXi=123.11
263BE CJK UNIFIED IDEOGRAPH-#263BE, IRGKangXi=0954.041, RSKangXi=123.11
263BF CJK UNIFIED IDEOGRAPH-#263BF, IRGKangXi=0954.041, RSKangXi=123.11
263C0 CJK UNIFIED IDEOGRAPH-#263C0, IRGKangXi=0954.041, RSKangXi=123.11
263C1 CJK UNIFIED IDEOGRAPH-#263C1, IRGKangXi=0954.041, RSKangXi=123.11
263C2 CJK UNIFIED IDEOGRAPH-#263C2, IRGKangXi=0954.041, RSKangXi=123.11
263C3 CJK UNIFIED IDEOGRAPH-#263C3, IRGKangXi=0954.041, RSKangXi=123.11
263C4 CJK UNIFIED IDEOGRAPH-#263C4, IRGKangXi=0954.041, RSKangXi=123.11
263C5 CJK UNIFIED IDEOGRAPH-#263C5, IRGKangXi=0954.060, RSKangXi=123.12
263C6 CJK UNIFIED IDEOGRAPH-#263C6, IRGKangXi=0954.090, RSKangXi=123.12
263C7 CJK UNIFIED IDEOGRAPH-#263C7, IRGKangXi=0954.100, RSKangXi=123.12
263C8 CJK UNIFIED IDEOGRAPH-#263C8, IRGKangXi=0954.110, RSKangXi=123.12
263C9 CJK UNIFIED IDEOGRAPH-#263C9, IRGKangXi=0954.120, RSKangXi=123.12
263CA CJK UNIFIED IDEOGRAPH-#263CA, IRGKangXi=0954.140, RSKangXi=123.12
263CB CJK UNIFIED IDEOGRAPH-#263CB, IRGKangXi=0954.160, RSKangXi=123.12
263CC CJK UNIFIED IDEOGRAPH-#263CC, IRGKangXi=0954.170, RSKangXi=123.12
263CD CJK UNIFIED IDEOGRAPH-#263CD, IRGKangXi=0954.180, RSKangXi=123.12
263CE CJK UNIFIED IDEOGRAPH-#263CE, IRGKangXi=0954.181, RSKangXi=123.12
263CF CJK UNIFIED IDEOGRAPH-#263CF, IRGKangXi=0954.181, RSKangXi=123.12
263D0 CJK UNIFIED IDEOGRAPH-#263D0, IRGKangXi=0954.181, RSKangXi=123.12
263D1 CJK UNIFIED IDEOGRAPH-#263D1, IRGKangXi=0954.181, RSKangXi=123.12
263D2 CJK UNIFIED IDEOGRAPH-#263D2, IRGKangXi=0954.181, RSKangXi=123.12
263D3 CJK UNIFIED IDEOGRAPH-#263D3, IRGKangXi=0954.181, RSKangXi=123.12
263D4 CJK UNIFIED IDEOGRAPH-#263D4, IRGKangXi=0954.181, RSKangXi=123.12
263D5 CJK UNIFIED IDEOGRAPH-#263D5, IRGKangXi=0954.190, RSKangXi=123.13
263D6 CJK UNIFIED IDEOGRAPH-#263D6, IRGKangXi=0954.200, RSKangXi=123.13
263D7 CJK UNIFIED IDEOGRAPH-#263D7, IRGKangXi=0954.220, RSKangXi=123.13
263D8 CJK UNIFIED IDEOGRAPH-#263D8, IRGKangXi=0954.260, RSKangXi=123.13
263D9 CJK UNIFIED IDEOGRAPH-#263D9, IRGKangXi=0954.270, RSKangXi=123.13
263DA CJK UNIFIED IDEOGRAPH-#263DA, IRGKangXi=0954.271, RSKangXi=123.13
263DB CJK UNIFIED IDEOGRAPH-#263DB, IRGKangXi=0954.271, RSKangXi=123.13
263DC CJK UNIFIED IDEOGRAPH-#263DC, IRGKangXi=0954.290, RSKangXi=123.14
263DD CJK UNIFIED IDEOGRAPH-#263DD, IRGKangXi=0954.300, RSKangXi=123.14
263DE CJK UNIFIED IDEOGRAPH-#263DE, IRGKangXi=0954.301, RSKangXi=123.14
263DF CJK UNIFIED IDEOGRAPH-#263DF, IRGKangXi=0954.301, RSKangXi=123.14
263E0 CJK UNIFIED IDEOGRAPH-#263E0, IRGKangXi=0954.301, RSKangXi=123.14
263E1 CJK UNIFIED IDEOGRAPH-#263E1, IRGKangXi=0954.301, RSKangXi=123.14
263E2 CJK UNIFIED IDEOGRAPH-#263E2, IRGKangXi=0954.310, RSKangXi=123.15
263E3 CJK UNIFIED IDEOGRAPH-#263E3, IRGKangXi=0954.340, RSKangXi=123.15
263E4 CJK UNIFIED IDEOGRAPH-#263E4, IRGKangXi=0954.341, RSKangXi=123.15
263E5 CJK UNIFIED IDEOGRAPH-#263E5, IRGKangXi=0954.341, RSKangXi=123.15
263E6 CJK UNIFIED IDEOGRAPH-#263E6, IRGKangXi=0954.341, RSKangXi=123.15
263E7 CJK UNIFIED IDEOGRAPH-#263E7, IRGKangXi=0954.341, RSKangXi=123.15
263E8 CJK UNIFIED IDEOGRAPH-#263E8, IRGKangXi=0954.350, RSKangXi=123.16
263E9 CJK UNIFIED IDEOGRAPH-#263E9, IRGKangXi=0954.370, RSKangXi=123.16
263EA CJK UNIFIED IDEOGRAPH-#263EA, IRGKangXi=0954.380, RSKangXi=123.17
263EB CJK UNIFIED IDEOGRAPH-#263EB, IRGKangXi=0954.390, RSKangXi=123.17
263EC CJK UNIFIED IDEOGRAPH-#263EC, IRGKangXi=0954.391, RSKangXi=123.18
263ED CJK UNIFIED IDEOGRAPH-#263ED, IRGKangXi=0954.400, RSKangXi=123.19
263EE CJK UNIFIED IDEOGRAPH-#263EE, IRGKangXi=0954.401, RSKangXi=123.20
263EF CJK UNIFIED IDEOGRAPH-#263EF, IRGKangXi=0954.401, RSKangXi=123.21
263F0 CJK UNIFIED IDEOGRAPH-#263F0, IRGKangXi=0954.410, RSKangXi=123.24
263F1 CJK UNIFIED IDEOGRAPH-#263F1, IRGKangXi=0954.411, RSKangXi=123.24
263F2 CJK UNIFIED IDEOGRAPH-#263F2, IRGKangXi=0955.011, RSKangXi=124.0
263F3 CJK UNIFIED IDEOGRAPH-#263F3, IRGKangXi=0955.011, RSKangXi=124.1
263F4 CJK UNIFIED IDEOGRAPH-#263F4, IRGKangXi=0955.020, RSKangXi=124.3
263F5 CJK UNIFIED IDEOGRAPH-#263F5, IRGKangXi=0955.030, RSKangXi=124.3
263F6 CJK UNIFIED IDEOGRAPH-#263F6, IRGKangXi=0955.040, RSKangXi=124.3
263F7 CJK UNIFIED IDEOGRAPH-#263F7, IRGKangXi=0955.050, RSKangXi=124.3
263F8 CJK UNIFIED IDEOGRAPH-#263F8, IRGKangXi=0955.060, RSKangXi=124.3
263F9 CJK UNIFIED IDEOGRAPH-#263F9, IRGKangXi=0955.070, RSKangXi=124.3
263FA CJK UNIFIED IDEOGRAPH-#263FA, IRGKangXi=0955.080, RSKangXi=124.3
263FB CJK UNIFIED IDEOGRAPH-#263FB, IRGKangXi=0955.110, RSKangXi=124.3
263FC CJK UNIFIED IDEOGRAPH-#263FC, IRGKangXi=0955.120, RSKangXi=124.3
263FD CJK UNIFIED IDEOGRAPH-#263FD, IRGKangXi=0955.121, RSKangXi=124.3
263FE CJK UNIFIED IDEOGRAPH-#263FE, IRGKangXi=0955.121, RSKangXi=124.3
263FF CJK UNIFIED IDEOGRAPH-#263FF, IRGKangXi=0955.121, RSKangXi=124.3
26400 CJK UNIFIED IDEOGRAPH-#26400, IRGKangXi=0955.121, RSKangXi=124.3
26401 CJK UNIFIED IDEOGRAPH-#26401, IRGKangXi=0955.121, RSKangXi=124.3
26402 CJK UNIFIED IDEOGRAPH-#26402, IRGKangXi=0955.130, RSKangXi=124.4
26403 CJK UNIFIED IDEOGRAPH-#26403, IRGKangXi=0955.140, RSKangXi=124.4
26404 CJK UNIFIED IDEOGRAPH-#26404, IRGKangXi=0955.150, RSKangXi=124.4
26405 CJK UNIFIED IDEOGRAPH-#26405, IRGKangXi=0955.170, RSKangXi=124.4
26406 CJK UNIFIED IDEOGRAPH-#26406, IRGKangXi=0955.190, RSKangXi=124.4
26407 CJK UNIFIED IDEOGRAPH-#26407, IRGKangXi=0955.200, RSKangXi=124.4, Def{the sound of wings, whir}
26408 CJK UNIFIED IDEOGRAPH-#26408, IRGKangXi=0955.230, RSKangXi=124.4, Def{to fly}
26409 CJK UNIFIED IDEOGRAPH-#26409, IRGKangXi=0955.260, RSKangXi=124.4
2640A CJK UNIFIED IDEOGRAPH-#2640A, IRGKangXi=0955.290, RSKangXi=124.4
2640B CJK UNIFIED IDEOGRAPH-#2640B, IRGKangXi=0955.300, RSKangXi=124.4
2640C CJK UNIFIED IDEOGRAPH-#2640C, IRGKangXi=0955.310, RSKangXi=124.4
2640D CJK UNIFIED IDEOGRAPH-#2640D, IRGKangXi=0956.010, RSKangXi=124.4
2640E CJK UNIFIED IDEOGRAPH-#2640E, IRGKangXi=0956.020, RSKangXi=124.4
2640F CJK UNIFIED IDEOGRAPH-#2640F, IRGKangXi=0956.031, RSKangXi=124.4
26410 CJK UNIFIED IDEOGRAPH-#26410, IRGKangXi=0956.031, RSKangXi=124.4
26411 CJK UNIFIED IDEOGRAPH-#26411, IRGKangXi=0956.031, RSKangXi=124.4
26412 CJK UNIFIED IDEOGRAPH-#26412, IRGKangXi=0956.031, RSKangXi=124.4
26413 CJK UNIFIED IDEOGRAPH-#26413, IRGKangXi=0956.031, RSKangXi=124.4
26414 CJK UNIFIED IDEOGRAPH-#26414, IRGKangXi=0956.031, RSKangXi=124.4
26415 CJK UNIFIED IDEOGRAPH-#26415, IRGKangXi=0956.070, RSKangXi=124.5
26416 CJK UNIFIED IDEOGRAPH-#26416, IRGKangXi=0956.210, RSKangXi=124.5
26417 CJK UNIFIED IDEOGRAPH-#26417, IRGKangXi=0956.240, RSKangXi=124.5
26418 CJK UNIFIED IDEOGRAPH-#26418, IRGKangXi=0956.250, RSKangXi=124.5
26419 CJK UNIFIED IDEOGRAPH-#26419, IRGKangXi=0956.260, RSKangXi=124.5
2641A CJK UNIFIED IDEOGRAPH-#2641A, IRGKangXi=0956.280, RSKangXi=124.5
2641B CJK UNIFIED IDEOGRAPH-#2641B, IRGKangXi=0956.290, RSKangXi=124.5
2641C CJK UNIFIED IDEOGRAPH-#2641C, IRGKangXi=0956.300, RSKangXi=124.5
2641D CJK UNIFIED IDEOGRAPH-#2641D, IRGKangXi=0956.301, RSKangXi=124.5
2641E CJK UNIFIED IDEOGRAPH-#2641E, IRGKangXi=0956.301, RSKangXi=124.5
2641F CJK UNIFIED IDEOGRAPH-#2641F, IRGKangXi=0956.301, RSKangXi=124.5
26420 CJK UNIFIED IDEOGRAPH-#26420, IRGKangXi=0956.301, RSKangXi=124.5
26421 CJK UNIFIED IDEOGRAPH-#26421, IRGKangXi=0956.301, RSKangXi=124.5
26422 CJK UNIFIED IDEOGRAPH-#26422, IRGKangXi=0956.301, RSKangXi=124.5
26423 CJK UNIFIED IDEOGRAPH-#26423, IRGKangXi=0956.310, RSKangXi=124.6
26424 CJK UNIFIED IDEOGRAPH-#26424, IRGKangXi=0956.320, RSKangXi=124.6
26425 CJK UNIFIED IDEOGRAPH-#26425, IRGKangXi=0956.330, RSKangXi=124.6
26426 CJK UNIFIED IDEOGRAPH-#26426, IRGKangXi=0956.390, RSKangXi=124.6
26427 CJK UNIFIED IDEOGRAPH-#26427, IRGKangXi=0956.410, RSKangXi=124.6
26428 CJK UNIFIED IDEOGRAPH-#26428, IRGKangXi=0956.450, RSKangXi=124.6
26429 CJK UNIFIED IDEOGRAPH-#26429, IRGKangXi=0956.460, RSKangXi=124.6
2642A CJK UNIFIED IDEOGRAPH-#2642A, IRGKangXi=0956.470, RSKangXi=124.6
2642B CJK UNIFIED IDEOGRAPH-#2642B, IRGKangXi=0957.010, RSKangXi=124.6
2642C CJK UNIFIED IDEOGRAPH-#2642C, IRGKangXi=0957.020, RSKangXi=124.6
2642D CJK UNIFIED IDEOGRAPH-#2642D, IRGKangXi=0957.030, RSKangXi=124.6
2642E CJK UNIFIED IDEOGRAPH-#2642E, IRGKangXi=0957.040, RSKangXi=124.6
2642F CJK UNIFIED IDEOGRAPH-#2642F, IRGKangXi=0957.050, RSKangXi=124.6
26430 CJK UNIFIED IDEOGRAPH-#26430, IRGKangXi=0957.060, RSKangXi=124.6
26431 CJK UNIFIED IDEOGRAPH-#26431, IRGKangXi=0957.070, RSKangXi=124.6
26432 CJK UNIFIED IDEOGRAPH-#26432, IRGKangXi=0957.080, RSKangXi=124.6
26433 CJK UNIFIED IDEOGRAPH-#26433, IRGKangXi=0957.090, RSKangXi=124.6
26434 CJK UNIFIED IDEOGRAPH-#26434, IRGKangXi=0957.091, RSKangXi=124.6
26435 CJK UNIFIED IDEOGRAPH-#26435, IRGKangXi=0957.091, RSKangXi=124.6
26436 CJK UNIFIED IDEOGRAPH-#26436, IRGKangXi=0957.091, RSKangXi=124.6
26437 CJK UNIFIED IDEOGRAPH-#26437, IRGKangXi=0957.091, RSKangXi=124.6
26438 CJK UNIFIED IDEOGRAPH-#26438, IRGKangXi=0957.120, RSKangXi=124.7
26439 CJK UNIFIED IDEOGRAPH-#26439, IRGKangXi=0957.130, RSKangXi=124.7
2643A CJK UNIFIED IDEOGRAPH-#2643A, IRGKangXi=0957.160, RSKangXi=124.7
2643B CJK UNIFIED IDEOGRAPH-#2643B, IRGKangXi=0957.170, RSKangXi=124.7
2643C CJK UNIFIED IDEOGRAPH-#2643C, IRGKangXi=0957.180, RSKangXi=124.7
2643D CJK UNIFIED IDEOGRAPH-#2643D, IRGKangXi=0957.200, RSKangXi=124.7
2643E CJK UNIFIED IDEOGRAPH-#2643E, IRGKangXi=0957.210, RSKangXi=124.7
2643F CJK UNIFIED IDEOGRAPH-#2643F, IRGKangXi=0957.240, RSKangXi=124.7
26440 CJK UNIFIED IDEOGRAPH-#26440, IRGKangXi=0957.250, RSKangXi=124.7
26441 CJK UNIFIED IDEOGRAPH-#26441, IRGKangXi=0957.261, RSKangXi=124.7
26442 CJK UNIFIED IDEOGRAPH-#26442, IRGKangXi=0957.261, RSKangXi=124.7
26443 CJK UNIFIED IDEOGRAPH-#26443, IRGKangXi=0957.261, RSKangXi=124.7
26444 CJK UNIFIED IDEOGRAPH-#26444, IRGKangXi=0957.261, RSKangXi=124.7
26445 CJK UNIFIED IDEOGRAPH-#26445, IRGKangXi=0957.261, RSKangXi=124.8
26446 CJK UNIFIED IDEOGRAPH-#26446, IRGKangXi=0957.261, RSKangXi=124.7
26447 CJK UNIFIED IDEOGRAPH-#26447, IRGKangXi=0957.290, RSKangXi=124.8
26448 CJK UNIFIED IDEOGRAPH-#26448, IRGKangXi=0957.310, RSKangXi=124.8
26449 CJK UNIFIED IDEOGRAPH-#26449, IRGKangXi=0957.330, RSKangXi=124.8
2644A CJK UNIFIED IDEOGRAPH-#2644A, IRGKangXi=0957.340, RSKangXi=124.8
2644B CJK UNIFIED IDEOGRAPH-#2644B, IRGKangXi=0957.350, RSKangXi=124.8
2644C CJK UNIFIED IDEOGRAPH-#2644C, IRGKangXi=0957.400, RSKangXi=124.8
2644D CJK UNIFIED IDEOGRAPH-#2644D, IRGKangXi=0957.410, RSKangXi=124.8
2644E CJK UNIFIED IDEOGRAPH-#2644E, IRGKangXi=0957.420, RSKangXi=124.8
2644F CJK UNIFIED IDEOGRAPH-#2644F, IRGKangXi=0958.010, RSKangXi=124.8
26450 CJK UNIFIED IDEOGRAPH-#26450, IRGKangXi=0958.030, RSKangXi=124.8
26451 CJK UNIFIED IDEOGRAPH-#26451, IRGKangXi=0958.040, RSKangXi=124.8
26452 CJK UNIFIED IDEOGRAPH-#26452, IRGKangXi=0958.041, RSKangXi=124.8
26453 CJK UNIFIED IDEOGRAPH-#26453, IRGKangXi=0958.041, RSKangXi=124.8
26454 CJK UNIFIED IDEOGRAPH-#26454, IRGKangXi=0958.041, RSKangXi=124.8
26455 CJK UNIFIED IDEOGRAPH-#26455, IRGKangXi=0958.041, RSKangXi=124.8
26456 CJK UNIFIED IDEOGRAPH-#26456, IRGKangXi=0958.041, RSKangXi=124.8
26457 CJK UNIFIED IDEOGRAPH-#26457, IRGKangXi=0958.041, RSKangXi=124.8
26458 CJK UNIFIED IDEOGRAPH-#26458, IRGKangXi=0958.050, RSKangXi=124.9
26459 CJK UNIFIED IDEOGRAPH-#26459, IRGKangXi=0958.070, RSKangXi=124.9
2645A CJK UNIFIED IDEOGRAPH-#2645A, IRGKangXi=0958.080, RSKangXi=124.9
2645B CJK UNIFIED IDEOGRAPH-#2645B, IRGKangXi=0958.090, RSKangXi=124.9
2645C CJK UNIFIED IDEOGRAPH-#2645C, IRGKangXi=0958.100, RSKangXi=124.9
2645D CJK UNIFIED IDEOGRAPH-#2645D, IRGKangXi=0958.140, RSKangXi=124.9
2645E CJK UNIFIED IDEOGRAPH-#2645E, IRGKangXi=0958.150, RSKangXi=124.9
2645F CJK UNIFIED IDEOGRAPH-#2645F, IRGKangXi=0958.160, RSKangXi=124.9
26460 CJK UNIFIED IDEOGRAPH-#26460, IRGKangXi=0958.170, RSKangXi=124.9
26461 CJK UNIFIED IDEOGRAPH-#26461, IRGKangXi=0958.200, RSKangXi=124.9
26462 CJK UNIFIED IDEOGRAPH-#26462, IRGKangXi=0958.220, RSKangXi=124.9
26463 CJK UNIFIED IDEOGRAPH-#26463, IRGKangXi=0958.240, RSKangXi=124.9
26464 CJK UNIFIED IDEOGRAPH-#26464, IRGKangXi=0958.270, RSKangXi=124.9
26465 CJK UNIFIED IDEOGRAPH-#26465, IRGKangXi=0958.280, RSKangXi=124.9
26466 CJK UNIFIED IDEOGRAPH-#26466, IRGKangXi=0958.290, RSKangXi=124.9
26467 CJK UNIFIED IDEOGRAPH-#26467, IRGKangXi=0958.300, RSKangXi=124.9
26468 CJK UNIFIED IDEOGRAPH-#26468, IRGKangXi=0958.310, RSKangXi=124.9
26469 CJK UNIFIED IDEOGRAPH-#26469, IRGKangXi=0958.320, RSKangXi=124.9
2646A CJK UNIFIED IDEOGRAPH-#2646A, IRGKangXi=0958.330, RSKangXi=124.9
2646B CJK UNIFIED IDEOGRAPH-#2646B, IRGKangXi=0958.331, RSKangXi=124.9
2646C CJK UNIFIED IDEOGRAPH-#2646C, IRGKangXi=0958.331, RSKangXi=124.9
2646D CJK UNIFIED IDEOGRAPH-#2646D, IRGKangXi=0958.331, RSKangXi=124.9
2646E CJK UNIFIED IDEOGRAPH-#2646E, IRGKangXi=0958.331, RSKangXi=124.9
2646F CJK UNIFIED IDEOGRAPH-#2646F, IRGKangXi=0958.331, RSKangXi=124.9
26470 CJK UNIFIED IDEOGRAPH-#26470, IRGKangXi=0958.340, RSKangXi=124.10
26471 CJK UNIFIED IDEOGRAPH-#26471, IRGKangXi=0958.350, RSKangXi=124.10
26472 CJK UNIFIED IDEOGRAPH-#26472, IRGKangXi=0958.370, RSKangXi=124.10
26473 CJK UNIFIED IDEOGRAPH-#26473, IRGKangXi=0958.380, RSKangXi=124.10
26474 CJK UNIFIED IDEOGRAPH-#26474, IRGKangXi=0958.420, RSKangXi=124.10
26475 CJK UNIFIED IDEOGRAPH-#26475, IRGKangXi=0959.010, RSKangXi=124.10
26476 CJK UNIFIED IDEOGRAPH-#26476, IRGKangXi=0959.020, RSKangXi=124.10
26477 CJK UNIFIED IDEOGRAPH-#26477, IRGKangXi=0959.030, RSKangXi=124.10
26478 CJK UNIFIED IDEOGRAPH-#26478, IRGKangXi=0959.040, RSKangXi=124.10
26479 CJK UNIFIED IDEOGRAPH-#26479, IRGKangXi=0959.050, RSKangXi=124.10
2647A CJK UNIFIED IDEOGRAPH-#2647A, IRGKangXi=0959.060, RSKangXi=124.10
2647B CJK UNIFIED IDEOGRAPH-#2647B, IRGKangXi=0959.070, RSKangXi=124.9
2647C CJK UNIFIED IDEOGRAPH-#2647C, IRGKangXi=0959.080, RSKangXi=124.10
2647D CJK UNIFIED IDEOGRAPH-#2647D, IRGKangXi=0959.090, RSKangXi=124.10
2647E CJK UNIFIED IDEOGRAPH-#2647E, IRGKangXi=0959.100, RSKangXi=124.10
2647F CJK UNIFIED IDEOGRAPH-#2647F, IRGKangXi=0959.101, RSKangXi=124.10
26480 CJK UNIFIED IDEOGRAPH-#26480, IRGKangXi=0959.101, RSKangXi=124.10
26481 CJK UNIFIED IDEOGRAPH-#26481, IRGKangXi=0959.101, RSKangXi=124.10
26482 CJK UNIFIED IDEOGRAPH-#26482, IRGKangXi=0959.101, RSKangXi=124.10
26483 CJK UNIFIED IDEOGRAPH-#26483, IRGKangXi=0959.110, RSKangXi=124.11
26484 CJK UNIFIED IDEOGRAPH-#26484, IRGKangXi=0959.120, RSKangXi=124.11
26485 CJK UNIFIED IDEOGRAPH-#26485, IRGKangXi=0959.130, RSKangXi=124.11
26486 CJK UNIFIED IDEOGRAPH-#26486, IRGKangXi=0959.170, RSKangXi=124.11
26487 CJK UNIFIED IDEOGRAPH-#26487, IRGKangXi=0959.180, RSKangXi=124.11
26488 CJK UNIFIED IDEOGRAPH-#26488, IRGKangXi=0959.200, RSKangXi=124.11
26489 CJK UNIFIED IDEOGRAPH-#26489, IRGKangXi=0959.201, RSKangXi=124.11
2648A CJK UNIFIED IDEOGRAPH-#2648A, IRGKangXi=0959.201, RSKangXi=124.11
2648B CJK UNIFIED IDEOGRAPH-#2648B, IRGKangXi=0959.201, RSKangXi=124.11
2648C CJK UNIFIED IDEOGRAPH-#2648C, IRGKangXi=0959.201, RSKangXi=124.11
2648D CJK UNIFIED IDEOGRAPH-#2648D, IRGKangXi=0959.230, RSKangXi=124.12
2648E CJK UNIFIED IDEOGRAPH-#2648E, IRGKangXi=0959.240, RSKangXi=124.12
2648F CJK UNIFIED IDEOGRAPH-#2648F, IRGKangXi=0959.260, RSKangXi=124.12
26490 CJK UNIFIED IDEOGRAPH-#26490, IRGKangXi=0959.290, RSKangXi=124.12
26491 CJK UNIFIED IDEOGRAPH-#26491, IRGKangXi=0959.320, RSKangXi=124.12
26492 CJK UNIFIED IDEOGRAPH-#26492, IRGKangXi=0960.010, RSKangXi=124.12
26493 CJK UNIFIED IDEOGRAPH-#26493, IRGKangXi=0960.020, RSKangXi=124.12
26494 CJK UNIFIED IDEOGRAPH-#26494, IRGKangXi=0960.030, RSKangXi=124.12
26495 CJK UNIFIED IDEOGRAPH-#26495, IRGKangXi=0960.040, RSKangXi=124.12
26496 CJK UNIFIED IDEOGRAPH-#26496, IRGKangXi=0960.050, RSKangXi=124.12
26497 CJK UNIFIED IDEOGRAPH-#26497, IRGKangXi=0960.051, RSKangXi=124.12
26498 CJK UNIFIED IDEOGRAPH-#26498, IRGKangXi=0960.051, RSKangXi=124.12
26499 CJK UNIFIED IDEOGRAPH-#26499, IRGKangXi=0960.051, RSKangXi=124.12
2649A CJK UNIFIED IDEOGRAPH-#2649A, IRGKangXi=0960.051, RSKangXi=124.12
2649B CJK UNIFIED IDEOGRAPH-#2649B, IRGKangXi=0960.051, RSKangXi=124.12
2649C CJK UNIFIED IDEOGRAPH-#2649C, IRGKangXi=0960.060, RSKangXi=124.13
2649D CJK UNIFIED IDEOGRAPH-#2649D, IRGKangXi=0960.070, RSKangXi=124.13
2649E CJK UNIFIED IDEOGRAPH-#2649E, IRGKangXi=0960.100, RSKangXi=124.10
2649F CJK UNIFIED IDEOGRAPH-#2649F, IRGKangXi=0960.110, RSKangXi=124.12
264A0 CJK UNIFIED IDEOGRAPH-#264A0, IRGKangXi=0960.111, RSKangXi=124.13
264A1 CJK UNIFIED IDEOGRAPH-#264A1, IRGKangXi=0960.111, RSKangXi=124.13
264A2 CJK UNIFIED IDEOGRAPH-#264A2, IRGKangXi=0960.150, RSKangXi=124.14
264A3 CJK UNIFIED IDEOGRAPH-#264A3, IRGKangXi=0960.160, RSKangXi=124.14
264A4 CJK UNIFIED IDEOGRAPH-#264A4, IRGKangXi=0960.161, RSKangXi=124.14
264A5 CJK UNIFIED IDEOGRAPH-#264A5, IRGKangXi=0960.161, RSKangXi=124.14
264A6 CJK UNIFIED IDEOGRAPH-#264A6, IRGKangXi=0960.180, RSKangXi=124.15
264A7 CJK UNIFIED IDEOGRAPH-#264A7, IRGKangXi=0960.190, RSKangXi=124.16
264A8 CJK UNIFIED IDEOGRAPH-#264A8, IRGKangXi=0960.200, RSKangXi=124.15
264A9 CJK UNIFIED IDEOGRAPH-#264A9, IRGKangXi=0960.210, RSKangXi=124.15
264AA CJK UNIFIED IDEOGRAPH-#264AA, IRGKangXi=0960.220, RSKangXi=124.14
264AB CJK UNIFIED IDEOGRAPH-#264AB, IRGKangXi=0960.230, RSKangXi=124.14
264AC CJK UNIFIED IDEOGRAPH-#264AC, IRGKangXi=0960.231, RSKangXi=124.15
264AD CJK UNIFIED IDEOGRAPH-#264AD, IRGKangXi=0960.240, RSKangXi=124.16
264AE CJK UNIFIED IDEOGRAPH-#264AE, IRGKangXi=0960.241, RSKangXi=124.16
264AF CJK UNIFIED IDEOGRAPH-#264AF, IRGKangXi=0960.241, RSKangXi=124.16
264B0 CJK UNIFIED IDEOGRAPH-#264B0, IRGKangXi=0960.241, RSKangXi=124.18
264B1 CJK UNIFIED IDEOGRAPH-#264B1, IRGKangXi=0960.290, RSKangXi=125.2
264B2 CJK UNIFIED IDEOGRAPH-#264B2, IRGKangXi=0960.300, RSKangXi=125.2
264B3 CJK UNIFIED IDEOGRAPH-#264B3, IRGKangXi=0960.301, RSKangXi=125.3
264B4 CJK UNIFIED IDEOGRAPH-#264B4, IRGKangXi=0960.301, RSKangXi=125.3
264B5 CJK UNIFIED IDEOGRAPH-#264B5, IRGKangXi=0960.301, RSKangXi=125.3
264B6 CJK UNIFIED IDEOGRAPH-#264B6, IRGKangXi=0960.310, RSKangXi=125.4
264B7 CJK UNIFIED IDEOGRAPH-#264B7, IRGKangXi=0961.030, RSKangXi=125.4, Def{senility}
264B8 CJK UNIFIED IDEOGRAPH-#264B8, IRGKangXi=0961.040, RSKangXi=125.4
264B9 CJK UNIFIED IDEOGRAPH-#264B9, IRGKangXi=0961.041, RSKangXi=125.4
264BA CJK UNIFIED IDEOGRAPH-#264BA, IRGKangXi=0961.050, RSKangXi=125.5
264BB CJK UNIFIED IDEOGRAPH-#264BB, IRGKangXi=0961.060, RSKangXi=125.5
264BC CJK UNIFIED IDEOGRAPH-#264BC, IRGKangXi=0961.081, RSKangXi=125.5
264BD CJK UNIFIED IDEOGRAPH-#264BD, IRGKangXi=0961.081, RSKangXi=125.5
264BE CJK UNIFIED IDEOGRAPH-#264BE, IRGKangXi=0961.081, RSKangXi=125.5
264BF CJK UNIFIED IDEOGRAPH-#264BF, IRGKangXi=0961.081, RSKangXi=125.5
264C0 CJK UNIFIED IDEOGRAPH-#264C0, IRGKangXi=0961.130, RSKangXi=125.6
264C1 CJK UNIFIED IDEOGRAPH-#264C1, IRGKangXi=0961.131, RSKangXi=125.8
264C2 CJK UNIFIED IDEOGRAPH-#264C2, IRGKangXi=0961.140, RSKangXi=125.9
264C3 CJK UNIFIED IDEOGRAPH-#264C3, IRGKangXi=0961.150, RSKangXi=125.12
264C4 CJK UNIFIED IDEOGRAPH-#264C4, IRGKangXi=0961.160, RSKangXi=125.10
264C5 CJK UNIFIED IDEOGRAPH-#264C5, IRGKangXi=0961.161, RSKangXi=125.10
264C6 CJK UNIFIED IDEOGRAPH-#264C6, IRGKangXi=0961.161, RSKangXi=125.11
264C7 CJK UNIFIED IDEOGRAPH-#264C7, IRGKangXi=0961.171, RSKangXi=125.11
264C8 CJK UNIFIED IDEOGRAPH-#264C8, IRGKangXi=0961.171, RSKangXi=125.12
264C9 CJK UNIFIED IDEOGRAPH-#264C9, IRGKangXi=0961.171, RSKangXi=125.12
264CA CJK UNIFIED IDEOGRAPH-#264CA, IRGKangXi=0961.171, RSKangXi=125.13
264CB CJK UNIFIED IDEOGRAPH-#264CB, IRGKangXi=0961.171, RSKangXi=125.18
264CC CJK UNIFIED IDEOGRAPH-#264CC, IRGKangXi=0961.171, RSKangXi=125.18
264CD CJK UNIFIED IDEOGRAPH-#264CD, IRGKangXi=0961.171, RSKangXi=125.21
264CE CJK UNIFIED IDEOGRAPH-#264CE, IRGKangXi=0961.190, RSKangXi=126.2
264CF CJK UNIFIED IDEOGRAPH-#264CF, IRGKangXi=0961.200, RSKangXi=126.2
264D0 CJK UNIFIED IDEOGRAPH-#264D0, IRGKangXi=0961.210, RSKangXi=126.-1
264D1 CJK UNIFIED IDEOGRAPH-#264D1, IRGKangXi=0961.211, RSKangXi=126.2
264D2 CJK UNIFIED IDEOGRAPH-#264D2, IRGKangXi=0962.050, RSKangXi=126.4
264D3 CJK UNIFIED IDEOGRAPH-#264D3, IRGKangXi=0962.060, RSKangXi=126.5
264D4 CJK UNIFIED IDEOGRAPH-#264D4, IRGKangXi=0962.070, RSKangXi=126.6
264D5 CJK UNIFIED IDEOGRAPH-#264D5, IRGKangXi=0962.071, RSKangXi=126.6
264D6 CJK UNIFIED IDEOGRAPH-#264D6, IRGKangXi=0962.080, RSKangXi=126.7
264D7 CJK UNIFIED IDEOGRAPH-#264D7, IRGKangXi=0962.090, RSKangXi=126.8
264D8 CJK UNIFIED IDEOGRAPH-#264D8, IRGKangXi=0962.100, RSKangXi=126.9
264D9 CJK UNIFIED IDEOGRAPH-#264D9, IRGKangXi=0962.110, RSKangXi=126.9
264DA CJK UNIFIED IDEOGRAPH-#264DA, IRGKangXi=0962.120, RSKangXi=126.9
264DB CJK UNIFIED IDEOGRAPH-#264DB, IRGKangXi=0962.121, RSKangXi=126.9
264DC CJK UNIFIED IDEOGRAPH-#264DC, IRGKangXi=0962.121, RSKangXi=126.9
264DD CJK UNIFIED IDEOGRAPH-#264DD, IRGKangXi=0962.130, RSKangXi=126.10
264DE CJK UNIFIED IDEOGRAPH-#264DE, IRGKangXi=0962.140, RSKangXi=126.10
264DF CJK UNIFIED IDEOGRAPH-#264DF, IRGKangXi=0962.150, RSKangXi=126.11
264E0 CJK UNIFIED IDEOGRAPH-#264E0, IRGKangXi=0962.151, RSKangXi=126.11
264E1 CJK UNIFIED IDEOGRAPH-#264E1, IRGKangXi=0962.151, RSKangXi=126.11
264E2 CJK UNIFIED IDEOGRAPH-#264E2, IRGKangXi=0962.151, RSKangXi=126.16
264E3 CJK UNIFIED IDEOGRAPH-#264E3, IRGKangXi=0962.151, RSKangXi=126.18
264E4 CJK UNIFIED IDEOGRAPH-#264E4, IRGKangXi=0962.170, RSKangXi=127.0
264E5 CJK UNIFIED IDEOGRAPH-#264E5, IRGKangXi=0962.190, RSKangXi=127.2
264E6 CJK UNIFIED IDEOGRAPH-#264E6, IRGKangXi=0962.191, RSKangXi=127.2
264E7 CJK UNIFIED IDEOGRAPH-#264E7, IRGKangXi=0962.191, RSKangXi=127.2
264E8 CJK UNIFIED IDEOGRAPH-#264E8, IRGKangXi=0962.210, RSKangXi=127.3
264E9 CJK UNIFIED IDEOGRAPH-#264E9, IRGKangXi=0962.221, RSKangXi=127.3
264EA CJK UNIFIED IDEOGRAPH-#264EA, IRGKangXi=0962.221, RSKangXi=127.3
264EB CJK UNIFIED IDEOGRAPH-#264EB, IRGKangXi=0963.031, RSKangXi=127.4
264EC CJK UNIFIED IDEOGRAPH-#264EC, IRGKangXi=0963.040, RSKangXi=127.5
264ED CJK UNIFIED IDEOGRAPH-#264ED, IRGKangXi=0963.111, RSKangXi=127.5
264EE CJK UNIFIED IDEOGRAPH-#264EE, IRGKangXi=0963.111, RSKangXi=127.5
264EF CJK UNIFIED IDEOGRAPH-#264EF, IRGKangXi=0963.120, RSKangXi=127.6
264F0 CJK UNIFIED IDEOGRAPH-#264F0, IRGKangXi=0963.140, RSKangXi=127.6
264F1 CJK UNIFIED IDEOGRAPH-#264F1, IRGKangXi=0963.150, RSKangXi=127.6
264F2 CJK UNIFIED IDEOGRAPH-#264F2, IRGKangXi=0963.151, RSKangXi=127.6
264F3 CJK UNIFIED IDEOGRAPH-#264F3, IRGKangXi=0963.151, RSKangXi=127.6
264F4 CJK UNIFIED IDEOGRAPH-#264F4, IRGKangXi=0963.180, RSKangXi=127.7
264F5 CJK UNIFIED IDEOGRAPH-#264F5, IRGKangXi=0963.190, RSKangXi=127.7
264F6 CJK UNIFIED IDEOGRAPH-#264F6, IRGKangXi=0963.191, RSKangXi=127.7
264F7 CJK UNIFIED IDEOGRAPH-#264F7, IRGKangXi=0963.200, RSKangXi=127.8
264F8 CJK UNIFIED IDEOGRAPH-#264F8, IRGKangXi=0963.210, RSKangXi=127.8
264F9 CJK UNIFIED IDEOGRAPH-#264F9, IRGKangXi=0963.230, RSKangXi=127.8
264FA CJK UNIFIED IDEOGRAPH-#264FA, IRGKangXi=0963.250, RSKangXi=127.8
264FB CJK UNIFIED IDEOGRAPH-#264FB, IRGKangXi=0963.260, RSKangXi=127.8
264FC CJK UNIFIED IDEOGRAPH-#264FC, IRGKangXi=0963.290, RSKangXi=127.8
264FD CJK UNIFIED IDEOGRAPH-#264FD, IRGKangXi=0963.310, RSKangXi=127.8
264FE CJK UNIFIED IDEOGRAPH-#264FE, IRGKangXi=0963.320, RSKangXi=127.8
264FF CJK UNIFIED IDEOGRAPH-#264FF, IRGKangXi=0963.341, RSKangXi=127.8
26500 CJK UNIFIED IDEOGRAPH-#26500, IRGKangXi=0963.341, RSKangXi=127.8
26501 CJK UNIFIED IDEOGRAPH-#26501, IRGKangXi=0963.341, RSKangXi=127.8
26502 CJK UNIFIED IDEOGRAPH-#26502, IRGKangXi=0964.020, RSKangXi=127.9
26503 CJK UNIFIED IDEOGRAPH-#26503, IRGKangXi=0964.030, RSKangXi=127.9
26504 CJK UNIFIED IDEOGRAPH-#26504, IRGKangXi=0964.040, RSKangXi=127.9
26505 CJK UNIFIED IDEOGRAPH-#26505, IRGKangXi=0964.050, RSKangXi=127.9
26506 CJK UNIFIED IDEOGRAPH-#26506, IRGKangXi=0964.070, RSKangXi=127.9
26507 CJK UNIFIED IDEOGRAPH-#26507, IRGKangXi=0964.071, RSKangXi=127.9
26508 CJK UNIFIED IDEOGRAPH-#26508, IRGKangXi=0964.071, RSKangXi=127.9
26509 CJK UNIFIED IDEOGRAPH-#26509, IRGKangXi=0964.071, RSKangXi=127.9
2650A CJK UNIFIED IDEOGRAPH-#2650A, IRGKangXi=0964.071, RSKangXi=127.9
2650B CJK UNIFIED IDEOGRAPH-#2650B, IRGKangXi=0964.080, RSKangXi=127.10
2650C CJK UNIFIED IDEOGRAPH-#2650C, IRGKangXi=0964.090, RSKangXi=127.10
2650D CJK UNIFIED IDEOGRAPH-#2650D, IRGKangXi=0964.100, RSKangXi=127.10
2650E CJK UNIFIED IDEOGRAPH-#2650E, IRGKangXi=0964.110, RSKangXi=127.10
2650F CJK UNIFIED IDEOGRAPH-#2650F, IRGKangXi=0964.120, RSKangXi=127.10
26510 CJK UNIFIED IDEOGRAPH-#26510, IRGKangXi=0964.150, RSKangXi=127.10
26511 CJK UNIFIED IDEOGRAPH-#26511, IRGKangXi=0964.160, RSKangXi=127.10
26512 CJK UNIFIED IDEOGRAPH-#26512, IRGKangXi=0964.161, RSKangXi=127.10
26513 CJK UNIFIED IDEOGRAPH-#26513, IRGKangXi=0964.170, RSKangXi=127.11
26514 CJK UNIFIED IDEOGRAPH-#26514, IRGKangXi=0964.210, RSKangXi=127.11
26515 CJK UNIFIED IDEOGRAPH-#26515, IRGKangXi=0964.240, RSKangXi=127.11
26516 CJK UNIFIED IDEOGRAPH-#26516, IRGKangXi=0964.241, RSKangXi=127.11
26517 CJK UNIFIED IDEOGRAPH-#26517, IRGKangXi=0964.241, RSKangXi=127.11
26518 CJK UNIFIED IDEOGRAPH-#26518, IRGKangXi=0964.241, RSKangXi=127.11
26519 CJK UNIFIED IDEOGRAPH-#26519, IRGKangXi=0964.241, RSKangXi=127.11
2651A CJK UNIFIED IDEOGRAPH-#2651A, IRGKangXi=0964.241, RSKangXi=127.11
2651B CJK UNIFIED IDEOGRAPH-#2651B, IRGKangXi=0964.250, RSKangXi=127.12
2651C CJK UNIFIED IDEOGRAPH-#2651C, IRGKangXi=0964.270, RSKangXi=127.12
2651D CJK UNIFIED IDEOGRAPH-#2651D, IRGKangXi=0964.300, RSKangXi=127.12
2651E CJK UNIFIED IDEOGRAPH-#2651E, IRGKangXi=0964.310, RSKangXi=127.12
2651F CJK UNIFIED IDEOGRAPH-#2651F, IRGKangXi=0964.320, RSKangXi=127.13
26520 CJK UNIFIED IDEOGRAPH-#26520, IRGKangXi=0964.330, RSKangXi=127.12
26521 CJK UNIFIED IDEOGRAPH-#26521, IRGKangXi=0964.331, RSKangXi=127.12
26522 CJK UNIFIED IDEOGRAPH-#26522, IRGKangXi=0964.331, RSKangXi=127.12
26523 CJK UNIFIED IDEOGRAPH-#26523, IRGKangXi=0964.331, RSKangXi=127.12
26524 CJK UNIFIED IDEOGRAPH-#26524, IRGKangXi=0964.331, RSKangXi=127.12
26525 CJK UNIFIED IDEOGRAPH-#26525, IRGKangXi=0964.340, RSKangXi=127.13
26526 CJK UNIFIED IDEOGRAPH-#26526, IRGKangXi=0964.350, RSKangXi=127.13
26527 CJK UNIFIED IDEOGRAPH-#26527, IRGKangXi=0964.351, RSKangXi=127.13
26528 CJK UNIFIED IDEOGRAPH-#26528, IRGKangXi=0964.351, RSKangXi=127.13
26529 CJK UNIFIED IDEOGRAPH-#26529, IRGKangXi=0964.370, RSKangXi=127.15
2652A CJK UNIFIED IDEOGRAPH-#2652A, IRGKangXi=0965.010, RSKangXi=127.15
2652B CJK UNIFIED IDEOGRAPH-#2652B, IRGKangXi=0965.020, RSKangXi=127.18
2652C CJK UNIFIED IDEOGRAPH-#2652C, IRGKangXi=0965.030, RSKangXi=127.18
2652D CJK UNIFIED IDEOGRAPH-#2652D, IRGKangXi=0965.040, RSKangXi=127.19
2652E CJK UNIFIED IDEOGRAPH-#2652E, IRGKangXi=0965.070, RSKangXi=128.1
2652F CJK UNIFIED IDEOGRAPH-#2652F, IRGKangXi=0965.080, RSKangXi=128.2
26530 CJK UNIFIED IDEOGRAPH-#26530, IRGKangXi=0965.090, RSKangXi=128.2
26531 CJK UNIFIED IDEOGRAPH-#26531, IRGKangXi=0965.100, RSKangXi=128.2
26532 CJK UNIFIED IDEOGRAPH-#26532, IRGKangXi=0965.111, RSKangXi=128.2
26533 CJK UNIFIED IDEOGRAPH-#26533, IRGKangXi=0965.111, RSKangXi=128.2
26534 CJK UNIFIED IDEOGRAPH-#26534, IRGKangXi=0965.111, RSKangXi=128.2
26535 CJK UNIFIED IDEOGRAPH-#26535, IRGKangXi=0965.111, RSKangXi=128.2
26536 CJK UNIFIED IDEOGRAPH-#26536, IRGKangXi=0965.111, RSKangXi=128.2
26537 CJK UNIFIED IDEOGRAPH-#26537, IRGKangXi=0965.130, RSKangXi=128.3
26538 CJK UNIFIED IDEOGRAPH-#26538, IRGKangXi=0965.140, RSKangXi=128.3
26539 CJK UNIFIED IDEOGRAPH-#26539, IRGKangXi=0965.160, RSKangXi=128.3
2653A CJK UNIFIED IDEOGRAPH-#2653A, IRGKangXi=0965.161, RSKangXi=128.3
2653B CJK UNIFIED IDEOGRAPH-#2653B, IRGKangXi=0965.161, RSKangXi=128.3
2653C CJK UNIFIED IDEOGRAPH-#2653C, IRGKangXi=0966.020, RSKangXi=128.4
2653D CJK UNIFIED IDEOGRAPH-#2653D, IRGKangXi=0966.070, RSKangXi=128.4
2653E CJK UNIFIED IDEOGRAPH-#2653E, IRGKangXi=0966.090, RSKangXi=128.4
2653F CJK UNIFIED IDEOGRAPH-#2653F, IRGKangXi=0966.100, RSKangXi=128.4
26540 CJK UNIFIED IDEOGRAPH-#26540, IRGKangXi=0966.160, RSKangXi=128.4
26541 CJK UNIFIED IDEOGRAPH-#26541, IRGKangXi=0966.170, RSKangXi=128.4
26542 CJK UNIFIED IDEOGRAPH-#26542, IRGKangXi=0966.171, RSKangXi=128.4
26543 CJK UNIFIED IDEOGRAPH-#26543, IRGKangXi=0966.171, RSKangXi=128.4
26544 CJK UNIFIED IDEOGRAPH-#26544, IRGKangXi=0966.171, RSKangXi=128.4
26545 CJK UNIFIED IDEOGRAPH-#26545, IRGKangXi=0966.171, RSKangXi=128.4
26546 CJK UNIFIED IDEOGRAPH-#26546, IRGKangXi=0966.171, RSKangXi=128.4
26547 CJK UNIFIED IDEOGRAPH-#26547, IRGKangXi=0966.171, RSKangXi=128.4
26548 CJK UNIFIED IDEOGRAPH-#26548, IRGKangXi=0966.171, RSKangXi=128.4
26549 CJK UNIFIED IDEOGRAPH-#26549, IRGKangXi=0966.171, RSKangXi=128.4
2654A CJK UNIFIED IDEOGRAPH-#2654A, IRGKangXi=0966.171, RSKangXi=128.4
2654B CJK UNIFIED IDEOGRAPH-#2654B, IRGKangXi=0966.171, RSKangXi=128.4
2654C CJK UNIFIED IDEOGRAPH-#2654C, IRGKangXi=0966.171, RSKangXi=128.4
2654D CJK UNIFIED IDEOGRAPH-#2654D, IRGKangXi=0966.171, RSKangXi=128.4
2654E CJK UNIFIED IDEOGRAPH-#2654E, IRGKangXi=0966.171, RSKangXi=128.4
2654F CJK UNIFIED IDEOGRAPH-#2654F, IRGKangXi=0966.171, RSKangXi=128.4
26550 CJK UNIFIED IDEOGRAPH-#26550, IRGKangXi=0966.180, RSKangXi=128.5
26551 CJK UNIFIED IDEOGRAPH-#26551, IRGKangXi=0966.210, RSKangXi=128.5
26552 CJK UNIFIED IDEOGRAPH-#26552, IRGKangXi=0966.260, RSKangXi=128.5, Def{to spy, peep}
26553 CJK UNIFIED IDEOGRAPH-#26553, IRGKangXi=0967.020, RSKangXi=128.5
26554 CJK UNIFIED IDEOGRAPH-#26554, IRGKangXi=0967.040, RSKangXi=128.5
26555 CJK UNIFIED IDEOGRAPH-#26555, IRGKangXi=0967.050, RSKangXi=128.5
26556 CJK UNIFIED IDEOGRAPH-#26556, IRGKangXi=0967.051, RSKangXi=128.5
26557 CJK UNIFIED IDEOGRAPH-#26557, IRGKangXi=0967.051, RSKangXi=128.5
26558 CJK UNIFIED IDEOGRAPH-#26558, IRGKangXi=0967.051, RSKangXi=128.5
26559 CJK UNIFIED IDEOGRAPH-#26559, IRGKangXi=0967.051, RSKangXi=128.5
2655A CJK UNIFIED IDEOGRAPH-#2655A, IRGKangXi=0967.051, RSKangXi=128.5
2655B CJK UNIFIED IDEOGRAPH-#2655B, IRGKangXi=0967.051, RSKangXi=128.5
2655C CJK UNIFIED IDEOGRAPH-#2655C, IRGKangXi=0967.051, RSKangXi=128.5
2655D CJK UNIFIED IDEOGRAPH-#2655D, IRGKangXi=0967.051, RSKangXi=128.5
2655E CJK UNIFIED IDEOGRAPH-#2655E, IRGKangXi=0967.051, RSKangXi=128.5
2655F CJK UNIFIED IDEOGRAPH-#2655F, IRGKangXi=0967.051, RSKangXi=128.5
26560 CJK UNIFIED IDEOGRAPH-#26560, IRGKangXi=0967.060, RSKangXi=128.6
26561 CJK UNIFIED IDEOGRAPH-#26561, IRGKangXi=0967.140, RSKangXi=128.6
26562 CJK UNIFIED IDEOGRAPH-#26562, IRGKangXi=0967.150, RSKangXi=128.6
26563 CJK UNIFIED IDEOGRAPH-#26563, IRGKangXi=0967.161, RSKangXi=128.7
26564 CJK UNIFIED IDEOGRAPH-#26564, IRGKangXi=0967.161, RSKangXi=128.6
26565 CJK UNIFIED IDEOGRAPH-#26565, IRGKangXi=0967.161, RSKangXi=128.6
26566 CJK UNIFIED IDEOGRAPH-#26566, IRGKangXi=0967.161, RSKangXi=128.6
26567 CJK UNIFIED IDEOGRAPH-#26567, IRGKangXi=0967.161, RSKangXi=128.6
26568 CJK UNIFIED IDEOGRAPH-#26568, IRGKangXi=0967.161, RSKangXi=128.6
26569 CJK UNIFIED IDEOGRAPH-#26569, IRGKangXi=0967.161, RSKangXi=128.6
2656A CJK UNIFIED IDEOGRAPH-#2656A, IRGKangXi=0967.161, RSKangXi=128.6
2656B CJK UNIFIED IDEOGRAPH-#2656B, IRGKangXi=0967.161, RSKangXi=128.6
2656C CJK UNIFIED IDEOGRAPH-#2656C, IRGKangXi=0967.161, RSKangXi=128.6
2656D CJK UNIFIED IDEOGRAPH-#2656D, IRGKangXi=0967.161, RSKangXi=128.6
2656E CJK UNIFIED IDEOGRAPH-#2656E, IRGKangXi=0967.161, RSKangXi=128.6
2656F CJK UNIFIED IDEOGRAPH-#2656F, IRGKangXi=0967.161, RSKangXi=128.6
26570 CJK UNIFIED IDEOGRAPH-#26570, IRGKangXi=0967.161, RSKangXi=128.6
26571 CJK UNIFIED IDEOGRAPH-#26571, IRGKangXi=0967.161, RSKangXi=128.6
26572 CJK UNIFIED IDEOGRAPH-#26572, IRGKangXi=0967.161, RSKangXi=128.6
26573 CJK UNIFIED IDEOGRAPH-#26573, IRGKangXi=0967.161, RSKangXi=128.6
26574 CJK UNIFIED IDEOGRAPH-#26574, IRGKangXi=0967.161, RSKangXi=128.6
26575 CJK UNIFIED IDEOGRAPH-#26575, IRGKangXi=0967.170, RSKangXi=128.7
26576 CJK UNIFIED IDEOGRAPH-#26576, IRGKangXi=0967.200, RSKangXi=128.7
26577 CJK UNIFIED IDEOGRAPH-#26577, IRGKangXi=0967.210, RSKangXi=128.7
26578 CJK UNIFIED IDEOGRAPH-#26578, IRGKangXi=0967.250, RSKangXi=128.7
26579 CJK UNIFIED IDEOGRAPH-#26579, IRGKangXi=0967.260, RSKangXi=128.7
2657A CJK UNIFIED IDEOGRAPH-#2657A, IRGKangXi=0967.280, RSKangXi=128.7
2657B CJK UNIFIED IDEOGRAPH-#2657B, IRGKangXi=0967.310, RSKangXi=128.7
2657C CJK UNIFIED IDEOGRAPH-#2657C, IRGKangXi=0967.320, RSKangXi=128.7
2657D CJK UNIFIED IDEOGRAPH-#2657D, IRGKangXi=0967.330, RSKangXi=128.7
2657E CJK UNIFIED IDEOGRAPH-#2657E, IRGKangXi=0967.340, RSKangXi=128.7
2657F CJK UNIFIED IDEOGRAPH-#2657F, IRGKangXi=0967.350, RSKangXi=128.7
26580 CJK UNIFIED IDEOGRAPH-#26580, IRGKangXi=0967.360, RSKangXi=128.7
26581 CJK UNIFIED IDEOGRAPH-#26581, IRGKangXi=0967.361, RSKangXi=128.7
26582 CJK UNIFIED IDEOGRAPH-#26582, IRGKangXi=0967.361, RSKangXi=128.7
26583 CJK UNIFIED IDEOGRAPH-#26583, IRGKangXi=0967.361, RSKangXi=128.7
26584 CJK UNIFIED IDEOGRAPH-#26584, IRGKangXi=0967.361, RSKangXi=128.7
26585 CJK UNIFIED IDEOGRAPH-#26585, IRGKangXi=0967.361, RSKangXi=128.7
26586 CJK UNIFIED IDEOGRAPH-#26586, IRGKangXi=0967.361, RSKangXi=128.7
26587 CJK UNIFIED IDEOGRAPH-#26587, IRGKangXi=0967.361, RSKangXi=128.7
26588 CJK UNIFIED IDEOGRAPH-#26588, IRGKangXi=0967.390, RSKangXi=128.8
26589 CJK UNIFIED IDEOGRAPH-#26589, IRGKangXi=0967.400, RSKangXi=128.8
2658A CJK UNIFIED IDEOGRAPH-#2658A, IRGKangXi=0968.020, RSKangXi=128.8
2658B CJK UNIFIED IDEOGRAPH-#2658B, IRGKangXi=0968.040, RSKangXi=128.8
2658C CJK UNIFIED IDEOGRAPH-#2658C, IRGKangXi=0968.080, RSKangXi=128.8
2658D CJK UNIFIED IDEOGRAPH-#2658D, IRGKangXi=0968.100, RSKangXi=128.8
2658E CJK UNIFIED IDEOGRAPH-#2658E, IRGKangXi=0968.170, RSKangXi=128.8
2658F CJK UNIFIED IDEOGRAPH-#2658F, IRGKangXi=0968.200, RSKangXi=128.8
26590 CJK UNIFIED IDEOGRAPH-#26590, IRGKangXi=0968.220, RSKangXi=128.8
26591 CJK UNIFIED IDEOGRAPH-#26591, IRGKangXi=0968.221, RSKangXi=128.8
26592 CJK UNIFIED IDEOGRAPH-#26592, IRGKangXi=0968.221, RSKangXi=128.8
26593 CJK UNIFIED IDEOGRAPH-#26593, IRGKangXi=0968.221, RSKangXi=128.8
26594 CJK UNIFIED IDEOGRAPH-#26594, IRGKangXi=0968.221, RSKangXi=128.8
26595 CJK UNIFIED IDEOGRAPH-#26595, IRGKangXi=0968.221, RSKangXi=128.8
26596 CJK UNIFIED IDEOGRAPH-#26596, IRGKangXi=0968.221, RSKangXi=128.8
26597 CJK UNIFIED IDEOGRAPH-#26597, IRGKangXi=0968.221, RSKangXi=128.7
26598 CJK UNIFIED IDEOGRAPH-#26598, IRGKangXi=0968.221, RSKangXi=128.8
26599 CJK UNIFIED IDEOGRAPH-#26599, IRGKangXi=0968.221, RSKangXi=128.8
2659A CJK UNIFIED IDEOGRAPH-#2659A, IRGKangXi=0968.221, RSKangXi=128.8
2659B CJK UNIFIED IDEOGRAPH-#2659B, IRGKangXi=0968.221, RSKangXi=128.8
2659C CJK UNIFIED IDEOGRAPH-#2659C, IRGKangXi=0968.221, RSKangXi=128.8
2659D CJK UNIFIED IDEOGRAPH-#2659D, IRGKangXi=0968.221, RSKangXi=128.8
2659E CJK UNIFIED IDEOGRAPH-#2659E, IRGKangXi=0968.221, RSKangXi=128.8
2659F CJK UNIFIED IDEOGRAPH-#2659F, IRGKangXi=0968.221, RSKangXi=128.8
265A0 CJK UNIFIED IDEOGRAPH-#265A0, IRGKangXi=0968.221, RSKangXi=128.8
265A1 CJK UNIFIED IDEOGRAPH-#265A1, IRGKangXi=0968.221, RSKangXi=128.8
265A2 CJK UNIFIED IDEOGRAPH-#265A2, IRGKangXi=0968.230, RSKangXi=128.9
265A3 CJK UNIFIED IDEOGRAPH-#265A3, IRGKangXi=0968.250, RSKangXi=128.9
265A4 CJK UNIFIED IDEOGRAPH-#265A4, IRGKangXi=0968.260, RSKangXi=128.9
265A5 CJK UNIFIED IDEOGRAPH-#265A5, IRGKangXi=0968.280, RSKangXi=128.9
265A6 CJK UNIFIED IDEOGRAPH-#265A6, IRGKangXi=0968.290, RSKangXi=128.9
265A7 CJK UNIFIED IDEOGRAPH-#265A7, IRGKangXi=0968.310, RSKangXi=128.9
265A8 CJK UNIFIED IDEOGRAPH-#265A8, IRGKangXi=0968.340, RSKangXi=128.9
265A9 CJK UNIFIED IDEOGRAPH-#265A9, IRGKangXi=0968.350, RSKangXi=128.9
265AA CJK UNIFIED IDEOGRAPH-#265AA, IRGKangXi=0968.360, RSKangXi=128.9
265AB CJK UNIFIED IDEOGRAPH-#265AB, IRGKangXi=0968.380, RSKangXi=128.9
265AC CJK UNIFIED IDEOGRAPH-#265AC, IRGKangXi=0968.390, RSKangXi=128.9
265AD CJK UNIFIED IDEOGRAPH-#265AD, IRGKangXi=0968.391, RSKangXi=128.9
265AE CJK UNIFIED IDEOGRAPH-#265AE, IRGKangXi=0968.391, RSKangXi=128.9
265AF CJK UNIFIED IDEOGRAPH-#265AF, IRGKangXi=0968.391, RSKangXi=128.9
265B0 CJK UNIFIED IDEOGRAPH-#265B0, IRGKangXi=0968.391, RSKangXi=128.9
265B1 CJK UNIFIED IDEOGRAPH-#265B1, IRGKangXi=0968.391, RSKangXi=128.9
265B2 CJK UNIFIED IDEOGRAPH-#265B2, IRGKangXi=0968.391, RSKangXi=128.9
265B3 CJK UNIFIED IDEOGRAPH-#265B3, IRGKangXi=0968.391, RSKangXi=128.9
265B4 CJK UNIFIED IDEOGRAPH-#265B4, IRGKangXi=0968.391, RSKangXi=128.9
265B5 CJK UNIFIED IDEOGRAPH-#265B5, IRGKangXi=0968.391, RSKangXi=128.9
265B6 CJK UNIFIED IDEOGRAPH-#265B6, IRGKangXi=0968.391, RSKangXi=128.9
265B7 CJK UNIFIED IDEOGRAPH-#265B7, IRGKangXi=0968.391, RSKangXi=128.9
265B8 CJK UNIFIED IDEOGRAPH-#265B8, IRGKangXi=0968.391, RSKangXi=128.9
265B9 CJK UNIFIED IDEOGRAPH-#265B9, IRGKangXi=0968.391, RSKangXi=128.9
265BA CJK UNIFIED IDEOGRAPH-#265BA, IRGKangXi=0968.391, RSKangXi=128.9
265BB CJK UNIFIED IDEOGRAPH-#265BB, IRGKangXi=0968.391, RSKangXi=128.9
265BC CJK UNIFIED IDEOGRAPH-#265BC, IRGKangXi=0968.400, RSKangXi=128.10
265BD CJK UNIFIED IDEOGRAPH-#265BD, IRGKangXi=0968.410, RSKangXi=128.10
265BE CJK UNIFIED IDEOGRAPH-#265BE, IRGKangXi=0968.460, RSKangXi=128.10
265BF CJK UNIFIED IDEOGRAPH-#265BF, IRGKangXi=0968.470, RSKangXi=128.10, Def{(Cant.) to hang down; to lower one's head}
265C0 CJK UNIFIED IDEOGRAPH-#265C0, IRGKangXi=0968.480, RSKangXi=128.10
265C1 CJK UNIFIED IDEOGRAPH-#265C1, IRGKangXi=0969.010, RSKangXi=128.10
265C2 CJK UNIFIED IDEOGRAPH-#265C2, IRGKangXi=0969.020, RSKangXi=128.10
265C3 CJK UNIFIED IDEOGRAPH-#265C3, IRGKangXi=0969.040, RSKangXi=128.10
265C4 CJK UNIFIED IDEOGRAPH-#265C4, IRGKangXi=0969.041, RSKangXi=128.10
265C5 CJK UNIFIED IDEOGRAPH-#265C5, IRGKangXi=0969.041, RSKangXi=128.10
265C6 CJK UNIFIED IDEOGRAPH-#265C6, IRGKangXi=0969.041, RSKangXi=128.10
265C7 CJK UNIFIED IDEOGRAPH-#265C7, IRGKangXi=0969.041, RSKangXi=128.9
265C8 CJK UNIFIED IDEOGRAPH-#265C8, IRGKangXi=0969.041, RSKangXi=128.10
265C9 CJK UNIFIED IDEOGRAPH-#265C9, IRGKangXi=0969.041, RSKangXi=128.10
265CA CJK UNIFIED IDEOGRAPH-#265CA, IRGKangXi=0969.041, RSKangXi=128.10
265CB CJK UNIFIED IDEOGRAPH-#265CB, IRGKangXi=0969.041, RSKangXi=128.10
265CC CJK UNIFIED IDEOGRAPH-#265CC, IRGKangXi=0969.041, RSKangXi=128.10
265CD CJK UNIFIED IDEOGRAPH-#265CD, IRGKangXi=0969.041, RSKangXi=128.10
265CE CJK UNIFIED IDEOGRAPH-#265CE, IRGKangXi=0969.041, RSKangXi=128.10
265CF CJK UNIFIED IDEOGRAPH-#265CF, IRGKangXi=0969.041, RSKangXi=128.10
265D0 CJK UNIFIED IDEOGRAPH-#265D0, IRGKangXi=0969.070, RSKangXi=128.11
265D1 CJK UNIFIED IDEOGRAPH-#265D1, IRGKangXi=0969.080, RSKangXi=128.11
265D2 CJK UNIFIED IDEOGRAPH-#265D2, IRGKangXi=0969.100, RSKangXi=128.11
265D3 CJK UNIFIED IDEOGRAPH-#265D3, IRGKangXi=0969.120, RSKangXi=128.11
265D4 CJK UNIFIED IDEOGRAPH-#265D4, IRGKangXi=0969.140, RSKangXi=128.11
265D5 CJK UNIFIED IDEOGRAPH-#265D5, IRGKangXi=0969.150, RSKangXi=128.11
265D6 CJK UNIFIED IDEOGRAPH-#265D6, IRGKangXi=0969.170, RSKangXi=128.11
265D7 CJK UNIFIED IDEOGRAPH-#265D7, IRGKangXi=0969.220, RSKangXi=128.11
265D8 CJK UNIFIED IDEOGRAPH-#265D8, IRGKangXi=0969.221, RSKangXi=128.11
265D9 CJK UNIFIED IDEOGRAPH-#265D9, IRGKangXi=0969.221, RSKangXi=128.11
265DA CJK UNIFIED IDEOGRAPH-#265DA, IRGKangXi=0969.221, RSKangXi=128.11
265DB CJK UNIFIED IDEOGRAPH-#265DB, IRGKangXi=0969.221, RSKangXi=128.11
265DC CJK UNIFIED IDEOGRAPH-#265DC, IRGKangXi=0969.221, RSKangXi=128.11
265DD CJK UNIFIED IDEOGRAPH-#265DD, IRGKangXi=0969.221, RSKangXi=128.11
265DE CJK UNIFIED IDEOGRAPH-#265DE, IRGKangXi=0969.221, RSKangXi=128.11
265DF CJK UNIFIED IDEOGRAPH-#265DF, IRGKangXi=0969.230, RSKangXi=128.12
265E0 CJK UNIFIED IDEOGRAPH-#265E0, IRGKangXi=0969.250, RSKangXi=128.12
265E1 CJK UNIFIED IDEOGRAPH-#265E1, IRGKangXi=0969.260, RSKangXi=128.12
265E2 CJK UNIFIED IDEOGRAPH-#265E2, IRGKangXi=0969.270, RSKangXi=128.12
265E3 CJK UNIFIED IDEOGRAPH-#265E3, IRGKangXi=0970.010, RSKangXi=128.12
265E4 CJK UNIFIED IDEOGRAPH-#265E4, IRGKangXi=0970.020, RSKangXi=128.12
265E5 CJK UNIFIED IDEOGRAPH-#265E5, IRGKangXi=0970.030, RSKangXi=128.12
265E6 CJK UNIFIED IDEOGRAPH-#265E6, IRGKangXi=0970.050, RSKangXi=128.12
265E7 CJK UNIFIED IDEOGRAPH-#265E7, IRGKangXi=0970.060, RSKangXi=128.12
265E8 CJK UNIFIED IDEOGRAPH-#265E8, IRGKangXi=0970.070, RSKangXi=128.12
265E9 CJK UNIFIED IDEOGRAPH-#265E9, IRGKangXi=0970.090, RSKangXi=128.12
265EA CJK UNIFIED IDEOGRAPH-#265EA, IRGKangXi=0970.091, RSKangXi=128.12
265EB CJK UNIFIED IDEOGRAPH-#265EB, IRGKangXi=0970.091, RSKangXi=128.12
265EC CJK UNIFIED IDEOGRAPH-#265EC, IRGKangXi=0970.091, RSKangXi=128.12
265ED CJK UNIFIED IDEOGRAPH-#265ED, IRGKangXi=0970.091, RSKangXi=128.12
265EE CJK UNIFIED IDEOGRAPH-#265EE, IRGKangXi=0970.091, RSKangXi=128.12
265EF CJK UNIFIED IDEOGRAPH-#265EF, IRGKangXi=0970.091, RSKangXi=128.12
265F0 CJK UNIFIED IDEOGRAPH-#265F0, IRGKangXi=0970.091, RSKangXi=128.12
265F1 CJK UNIFIED IDEOGRAPH-#265F1, IRGKangXi=0970.091, RSKangXi=128.12
265F2 CJK UNIFIED IDEOGRAPH-#265F2, IRGKangXi=0970.091, RSKangXi=128.12
265F3 CJK UNIFIED IDEOGRAPH-#265F3, IRGKangXi=0970.100, RSKangXi=128.13
265F4 CJK UNIFIED IDEOGRAPH-#265F4, IRGKangXi=0970.110, RSKangXi=128.13
265F5 CJK UNIFIED IDEOGRAPH-#265F5, IRGKangXi=0970.120, RSKangXi=128.13
265F6 CJK UNIFIED IDEOGRAPH-#265F6, IRGKangXi=0970.140, RSKangXi=128.13
265F7 CJK UNIFIED IDEOGRAPH-#265F7, IRGKangXi=0970.150, RSKangXi=128.13
265F8 CJK UNIFIED IDEOGRAPH-#265F8, IRGKangXi=0970.151, RSKangXi=128.13
265F9 CJK UNIFIED IDEOGRAPH-#265F9, IRGKangXi=0970.151, RSKangXi=128.13
265FA CJK UNIFIED IDEOGRAPH-#265FA, IRGKangXi=0970.151, RSKangXi=128.13
265FB CJK UNIFIED IDEOGRAPH-#265FB, IRGKangXi=0970.151, RSKangXi=128.13
265FC CJK UNIFIED IDEOGRAPH-#265FC, IRGKangXi=0970.151, RSKangXi=128.13
265FD CJK UNIFIED IDEOGRAPH-#265FD, IRGKangXi=0970.151, RSKangXi=128.13
265FE CJK UNIFIED IDEOGRAPH-#265FE, IRGKangXi=0970.180, RSKangXi=128.14
265FF CJK UNIFIED IDEOGRAPH-#265FF, IRGKangXi=0970.190, RSKangXi=128.14
26600 CJK UNIFIED IDEOGRAPH-#26600, IRGKangXi=0970.211, RSKangXi=128.14
26601 CJK UNIFIED IDEOGRAPH-#26601, IRGKangXi=0970.211, RSKangXi=128.14
26602 CJK UNIFIED IDEOGRAPH-#26602, IRGKangXi=0970.211, RSKangXi=128.14
26603 CJK UNIFIED IDEOGRAPH-#26603, IRGKangXi=0970.211, RSKangXi=128.14
26604 CJK UNIFIED IDEOGRAPH-#26604, IRGKangXi=0970.211, RSKangXi=128.14
26605 CJK UNIFIED IDEOGRAPH-#26605, IRGKangXi=0970.220, RSKangXi=128.15
26606 CJK UNIFIED IDEOGRAPH-#26606, IRGKangXi=0970.221, RSKangXi=128.15
26607 CJK UNIFIED IDEOGRAPH-#26607, IRGKangXi=0970.221, RSKangXi=128.15
26608 CJK UNIFIED IDEOGRAPH-#26608, IRGKangXi=0970.221, RSKangXi=128.15
26609 CJK UNIFIED IDEOGRAPH-#26609, IRGKangXi=0970.221, RSKangXi=128.15
2660A CJK UNIFIED IDEOGRAPH-#2660A, IRGKangXi=0970.230, RSKangXi=128.16
2660B CJK UNIFIED IDEOGRAPH-#2660B, IRGKangXi=0970.271, RSKangXi=128.16
2660C CJK UNIFIED IDEOGRAPH-#2660C, IRGKangXi=0970.271, RSKangXi=128.16
2660D CJK UNIFIED IDEOGRAPH-#2660D, IRGKangXi=0970.280, RSKangXi=128.17
2660E CJK UNIFIED IDEOGRAPH-#2660E, IRGKangXi=0970.281, RSKangXi=128.17
2660F CJK UNIFIED IDEOGRAPH-#2660F, IRGKangXi=0970.281, RSKangXi=128.18
26610 CJK UNIFIED IDEOGRAPH-#26610, IRGKangXi=0970.281, RSKangXi=128.19
26611 CJK UNIFIED IDEOGRAPH-#26611, IRGKangXi=0970.281, RSKangXi=128.20
26612 CJK UNIFIED IDEOGRAPH-#26612, IRGKangXi=0971.020, RSKangXi=129.-1
26613 CJK UNIFIED IDEOGRAPH-#26613, IRGKangXi=0971.030, RSKangXi=129.2
26614 CJK UNIFIED IDEOGRAPH-#26614, IRGKangXi=0971.050, RSKangXi=129.3
26615 CJK UNIFIED IDEOGRAPH-#26615, IRGKangXi=0971.080, RSKangXi=129.5
26616 CJK UNIFIED IDEOGRAPH-#26616, IRGKangXi=0971.081, RSKangXi=129.5
26617 CJK UNIFIED IDEOGRAPH-#26617, IRGKangXi=0971.081, RSKangXi=129.5
26618 CJK UNIFIED IDEOGRAPH-#26618, IRGKangXi=0971.090, RSKangXi=129.6
26619 CJK UNIFIED IDEOGRAPH-#26619, IRGKangXi=0971.091, RSKangXi=129.6
2661A CJK UNIFIED IDEOGRAPH-#2661A, IRGKangXi=0971.091, RSKangXi=129.6
2661B CJK UNIFIED IDEOGRAPH-#2661B, IRGKangXi=0971.091, RSKangXi=129.7
2661C CJK UNIFIED IDEOGRAPH-#2661C, IRGKangXi=0972.011, RSKangXi=129.7
2661D CJK UNIFIED IDEOGRAPH-#2661D, IRGKangXi=0972.031, RSKangXi=129.8
2661E CJK UNIFIED IDEOGRAPH-#2661E, IRGKangXi=0972.031, RSKangXi=129.8
2661F CJK UNIFIED IDEOGRAPH-#2661F, IRGKangXi=0972.031, RSKangXi=129.8
26620 CJK UNIFIED IDEOGRAPH-#26620, IRGKangXi=0972.040, RSKangXi=129.9
26621 CJK UNIFIED IDEOGRAPH-#26621, IRGKangXi=0972.050, RSKangXi=129.9
26622 CJK UNIFIED IDEOGRAPH-#26622, IRGKangXi=0972.051, RSKangXi=129.9
26623 CJK UNIFIED IDEOGRAPH-#26623, IRGKangXi=0972.060, RSKangXi=129.10
26624 CJK UNIFIED IDEOGRAPH-#26624, IRGKangXi=0972.070, RSKangXi=129.11
26625 CJK UNIFIED IDEOGRAPH-#26625, IRGKangXi=0972.071, RSKangXi=129.11
26626 CJK UNIFIED IDEOGRAPH-#26626, IRGKangXi=0972.071, RSKangXi=129.11
26627 CJK UNIFIED IDEOGRAPH-#26627, IRGKangXi=0972.071, RSKangXi=129.13
26628 CJK UNIFIED IDEOGRAPH-#26628, IRGKangXi=0972.080, RSKangXi=129.14
26629 CJK UNIFIED IDEOGRAPH-#26629, IRGKangXi=0973.060, RSKangXi=130.2, Def{(Cant.) chin}
2662A CJK UNIFIED IDEOGRAPH-#2662A, IRGKangXi=0973.080, RSKangXi=130.2
2662B CJK UNIFIED IDEOGRAPH-#2662B, IRGKangXi=0973.120, RSKangXi=130.2
2662C CJK UNIFIED IDEOGRAPH-#2662C, IRGKangXi=0973.130, RSKangXi=130.2
2662D CJK UNIFIED IDEOGRAPH-#2662D, IRGKangXi=0973.140, RSKangXi=130.2
2662E CJK UNIFIED IDEOGRAPH-#2662E, IRGKangXi=0973.151, RSKangXi=130.2
2662F CJK UNIFIED IDEOGRAPH-#2662F, IRGKangXi=0973.151, RSKangXi=130.2
26630 CJK UNIFIED IDEOGRAPH-#26630, IRGKangXi=0973.151, RSKangXi=130.2
26631 CJK UNIFIED IDEOGRAPH-#26631, IRGKangXi=0973.151, RSKangXi=130.2
26632 CJK UNIFIED IDEOGRAPH-#26632, IRGKangXi=0973.151, RSKangXi=130.2
26633 CJK UNIFIED IDEOGRAPH-#26633, IRGKangXi=0973.151, RSKangXi=130.2
26634 CJK UNIFIED IDEOGRAPH-#26634, IRGKangXi=0973.220, RSKangXi=130.3
26635 CJK UNIFIED IDEOGRAPH-#26635, IRGKangXi=0974.010, RSKangXi=130.3
26636 CJK UNIFIED IDEOGRAPH-#26636, IRGKangXi=0974.030, RSKangXi=130.3
26637 CJK UNIFIED IDEOGRAPH-#26637, IRGKangXi=0974.110, RSKangXi=130.3
26638 CJK UNIFIED IDEOGRAPH-#26638, IRGKangXi=0974.131, RSKangXi=130.3
26639 CJK UNIFIED IDEOGRAPH-#26639, IRGKangXi=0974.131, RSKangXi=130.3
2663A CJK UNIFIED IDEOGRAPH-#2663A, IRGKangXi=0974.131, RSKangXi=130.3
2663B CJK UNIFIED IDEOGRAPH-#2663B, IRGKangXi=0974.131, RSKangXi=130.3
2663C CJK UNIFIED IDEOGRAPH-#2663C, IRGKangXi=0974.131, RSKangXi=130.3
2663D CJK UNIFIED IDEOGRAPH-#2663D, IRGKangXi=0974.131, RSKangXi=130.3
2663E CJK UNIFIED IDEOGRAPH-#2663E, IRGKangXi=0974.131, RSKangXi=130.3
2663F CJK UNIFIED IDEOGRAPH-#2663F, IRGKangXi=0974.210, RSKangXi=130.4
26640 CJK UNIFIED IDEOGRAPH-#26640, IRGKangXi=0975.020, RSKangXi=130.4
26641 CJK UNIFIED IDEOGRAPH-#26641, IRGKangXi=0975.060, RSKangXi=130.4
26642 CJK UNIFIED IDEOGRAPH-#26642, IRGKangXi=0975.080, RSKangXi=130.4
26643 CJK UNIFIED IDEOGRAPH-#26643, IRGKangXi=0975.170, RSKangXi=130.4
26644 CJK UNIFIED IDEOGRAPH-#26644, IRGKangXi=0975.180, RSKangXi=130.4
26645 CJK UNIFIED IDEOGRAPH-#26645, IRGKangXi=0975.190, RSKangXi=130.4
26646 CJK UNIFIED IDEOGRAPH-#26646, IRGKangXi=0975.200, RSKangXi=130.4
26647 CJK UNIFIED IDEOGRAPH-#26647, IRGKangXi=0976.150, RSKangXi=130.4
26648 CJK UNIFIED IDEOGRAPH-#26648, IRGKangXi=0977.010, RSKangXi=130.4
26649 CJK UNIFIED IDEOGRAPH-#26649, IRGKangXi=0977.020, RSKangXi=130.4
2664A CJK UNIFIED IDEOGRAPH-#2664A, IRGKangXi=0977.030, RSKangXi=130.4
2664B CJK UNIFIED IDEOGRAPH-#2664B, IRGKangXi=0977.040, RSKangXi=130.4
2664C CJK UNIFIED IDEOGRAPH-#2664C, IRGKangXi=0977.041, RSKangXi=130.4
2664D CJK UNIFIED IDEOGRAPH-#2664D, IRGKangXi=0977.041, RSKangXi=130.4
2664E CJK UNIFIED IDEOGRAPH-#2664E, IRGKangXi=0977.041, RSKangXi=130.4
2664F CJK UNIFIED IDEOGRAPH-#2664F, IRGKangXi=0977.041, RSKangXi=130.4
26650 CJK UNIFIED IDEOGRAPH-#26650, IRGKangXi=0977.041, RSKangXi=130.4
26651 CJK UNIFIED IDEOGRAPH-#26651, IRGKangXi=0977.041, RSKangXi=130.4
26652 CJK UNIFIED IDEOGRAPH-#26652, IRGKangXi=0977.041, RSKangXi=130.4
26653 CJK UNIFIED IDEOGRAPH-#26653, IRGKangXi=0977.041, RSKangXi=130.4
26654 CJK UNIFIED IDEOGRAPH-#26654, IRGKangXi=0977.041, RSKangXi=130.4
26655 CJK UNIFIED IDEOGRAPH-#26655, IRGKangXi=0977.041, RSKangXi=130.4
26656 CJK UNIFIED IDEOGRAPH-#26656, IRGKangXi=0977.041, RSKangXi=130.4
26657 CJK UNIFIED IDEOGRAPH-#26657, IRGKangXi=0977.041, RSKangXi=130.4
26658 CJK UNIFIED IDEOGRAPH-#26658, IRGKangXi=0977.041, RSKangXi=130.4
26659 CJK UNIFIED IDEOGRAPH-#26659, IRGKangXi=0977.041, RSKangXi=130.4
2665A CJK UNIFIED IDEOGRAPH-#2665A, IRGKangXi=0977.041, RSKangXi=130.4
2665B CJK UNIFIED IDEOGRAPH-#2665B, IRGKangXi=0977.041, RSKangXi=130.4
2665C CJK UNIFIED IDEOGRAPH-#2665C, IRGKangXi=0977.041, RSKangXi=130.4
2665D CJK UNIFIED IDEOGRAPH-#2665D, IRGKangXi=0977.041, RSKangXi=130.4
2665E CJK UNIFIED IDEOGRAPH-#2665E, IRGKangXi=0977.041, RSKangXi=130.4
2665F CJK UNIFIED IDEOGRAPH-#2665F, IRGKangXi=0977.041, RSKangXi=130.4
26660 CJK UNIFIED IDEOGRAPH-#26660, IRGKangXi=0977.041, RSKangXi=130.4
26661 CJK UNIFIED IDEOGRAPH-#26661, IRGKangXi=0977.041, RSKangXi=130.4
26662 CJK UNIFIED IDEOGRAPH-#26662, IRGKangXi=0977.041, RSKangXi=130.4
26663 CJK UNIFIED IDEOGRAPH-#26663, IRGKangXi=0977.041, RSKangXi=130.4
26664 CJK UNIFIED IDEOGRAPH-#26664, IRGKangXi=0977.041, RSKangXi=130.4
26665 CJK UNIFIED IDEOGRAPH-#26665, IRGKangXi=0977.041, RSKangXi=130.4
26666 CJK UNIFIED IDEOGRAPH-#26666, IRGKangXi=0977.041, RSKangXi=130.4
26667 CJK UNIFIED IDEOGRAPH-#26667, IRGKangXi=0977.041, RSKangXi=130.4
26668 CJK UNIFIED IDEOGRAPH-#26668, IRGKangXi=0977.041, RSKangXi=130.4
26669 CJK UNIFIED IDEOGRAPH-#26669, IRGKangXi=0977.041, RSKangXi=130.4
2666A CJK UNIFIED IDEOGRAPH-#2666A, IRGKangXi=0977.080, RSKangXi=130.5
2666B CJK UNIFIED IDEOGRAPH-#2666B, IRGKangXi=0977.110, RSKangXi=130.5
2666C CJK UNIFIED IDEOGRAPH-#2666C, IRGKangXi=0977.160, RSKangXi=130.5
2666D CJK UNIFIED IDEOGRAPH-#2666D, IRGKangXi=0977.190, RSKangXi=130.5
2666E CJK UNIFIED IDEOGRAPH-#2666E, IRGKangXi=0977.230, RSKangXi=130.5
2666F CJK UNIFIED IDEOGRAPH-#2666F, IRGKangXi=0977.240, RSKangXi=130.5
26670 CJK UNIFIED IDEOGRAPH-#26670, IRGKangXi=0978.040, RSKangXi=130.5
26671 CJK UNIFIED IDEOGRAPH-#26671, IRGKangXi=0978.080, RSKangXi=130.5
26672 CJK UNIFIED IDEOGRAPH-#26672, IRGKangXi=0978.090, RSKangXi=130.5
26673 CJK UNIFIED IDEOGRAPH-#26673, IRGKangXi=0978.170, RSKangXi=130.5
26674 CJK UNIFIED IDEOGRAPH-#26674, IRGKangXi=0979.010, RSKangXi=130.5
26675 CJK UNIFIED IDEOGRAPH-#26675, IRGKangXi=0979.020, RSKangXi=130.5, Def{the wrist; universal joint}
26676 CJK UNIFIED IDEOGRAPH-#26676, IRGKangXi=0980.010, RSKangXi=130.5
26677 CJK UNIFIED IDEOGRAPH-#26677, IRGKangXi=0980.020, RSKangXi=130.5
26678 CJK UNIFIED IDEOGRAPH-#26678, IRGKangXi=0980.100, RSKangXi=130.5
26679 CJK UNIFIED IDEOGRAPH-#26679, IRGKangXi=0980.110, RSKangXi=130.5
2667A CJK UNIFIED IDEOGRAPH-#2667A, IRGKangXi=0980.120, RSKangXi=130.5
2667B CJK UNIFIED IDEOGRAPH-#2667B, IRGKangXi=0980.130, RSKangXi=130.5
2667C CJK UNIFIED IDEOGRAPH-#2667C, IRGKangXi=0980.140, RSKangXi=130.5, Def{a putrid carcase}
2667D CJK UNIFIED IDEOGRAPH-#2667D, IRGKangXi=0980.141, RSKangXi=130.5
2667E CJK UNIFIED IDEOGRAPH-#2667E, IRGKangXi=0980.141, RSKangXi=130.5
2667F CJK UNIFIED IDEOGRAPH-#2667F, IRGKangXi=0980.141, RSKangXi=130.5
26680 CJK UNIFIED IDEOGRAPH-#26680, IRGKangXi=0980.141, RSKangXi=130.5
26681 CJK UNIFIED IDEOGRAPH-#26681, IRGKangXi=0980.141, RSKangXi=130.5
26682 CJK UNIFIED IDEOGRAPH-#26682, IRGKangXi=0980.141, RSKangXi=130.5
26683 CJK UNIFIED IDEOGRAPH-#26683, IRGKangXi=0980.141, RSKangXi=130.5
26684 CJK UNIFIED IDEOGRAPH-#26684, IRGKangXi=0980.141, RSKangXi=130.5
26685 CJK UNIFIED IDEOGRAPH-#26685, IRGKangXi=0980.141, RSKangXi=130.5
26686 CJK UNIFIED IDEOGRAPH-#26686, IRGKangXi=0980.141, RSKangXi=130.5
26687 CJK UNIFIED IDEOGRAPH-#26687, IRGKangXi=0980.141, RSKangXi=130.5
26688 CJK UNIFIED IDEOGRAPH-#26688, IRGKangXi=0980.141, RSKangXi=130.5
26689 CJK UNIFIED IDEOGRAPH-#26689, IRGKangXi=0980.141, RSKangXi=130.5
2668A CJK UNIFIED IDEOGRAPH-#2668A, IRGKangXi=0980.141, RSKangXi=130.5
2668B CJK UNIFIED IDEOGRAPH-#2668B, IRGKangXi=0980.141, RSKangXi=130.5
2668C CJK UNIFIED IDEOGRAPH-#2668C, IRGKangXi=0980.141, RSKangXi=130.5
2668D CJK UNIFIED IDEOGRAPH-#2668D, IRGKangXi=0980.141, RSKangXi=130.5
2668E CJK UNIFIED IDEOGRAPH-#2668E, IRGKangXi=0980.141, RSKangXi=130.5
2668F CJK UNIFIED IDEOGRAPH-#2668F, IRGKangXi=0980.141, RSKangXi=130.5
26690 CJK UNIFIED IDEOGRAPH-#26690, IRGKangXi=0980.141, RSKangXi=130.5
26691 CJK UNIFIED IDEOGRAPH-#26691, IRGKangXi=0980.141, RSKangXi=130.5
26692 CJK UNIFIED IDEOGRAPH-#26692, IRGKangXi=0980.141, RSKangXi=130.5
26693 CJK UNIFIED IDEOGRAPH-#26693, IRGKangXi=0980.141, RSKangXi=130.5, Def{fat}
26694 CJK UNIFIED IDEOGRAPH-#26694, IRGKangXi=0980.141, RSKangXi=130.5
26695 CJK UNIFIED IDEOGRAPH-#26695, IRGKangXi=0980.141, RSKangXi=130.5
26696 CJK UNIFIED IDEOGRAPH-#26696, IRGKangXi=0980.141, RSKangXi=130.5, Def{(Cant.) to wink}
26697 CJK UNIFIED IDEOGRAPH-#26697, IRGKangXi=0980.141, RSKangXi=130.5
26698 CJK UNIFIED IDEOGRAPH-#26698, IRGKangXi=0980.141, RSKangXi=130.5
26699 CJK UNIFIED IDEOGRAPH-#26699, IRGKangXi=0980.141, RSKangXi=130.5
2669A CJK UNIFIED IDEOGRAPH-#2669A, IRGKangXi=0980.141, RSKangXi=130.5
2669B CJK UNIFIED IDEOGRAPH-#2669B, IRGKangXi=0980.141, RSKangXi=130.5
2669C CJK UNIFIED IDEOGRAPH-#2669C, IRGKangXi=0980.141, RSKangXi=130.5
2669D CJK UNIFIED IDEOGRAPH-#2669D, IRGKangXi=0980.150, RSKangXi=130.6
2669E CJK UNIFIED IDEOGRAPH-#2669E, IRGKangXi=0980.200, RSKangXi=130.6
2669F CJK UNIFIED IDEOGRAPH-#2669F, IRGKangXi=0981.010, RSKangXi=130.6
266A0 CJK UNIFIED IDEOGRAPH-#266A0, IRGKangXi=0981.020, RSKangXi=130.6
266A1 CJK UNIFIED IDEOGRAPH-#266A1, IRGKangXi=0981.100, RSKangXi=130.6
266A2 CJK UNIFIED IDEOGRAPH-#266A2, IRGKangXi=0981.130, RSKangXi=130.6
266A3 CJK UNIFIED IDEOGRAPH-#266A3, IRGKangXi=0981.140, RSKangXi=130.6
266A4 CJK UNIFIED IDEOGRAPH-#266A4, IRGKangXi=0981.170, RSKangXi=130.6
266A5 CJK UNIFIED IDEOGRAPH-#266A5, IRGKangXi=0981.210, RSKangXi=130.6
266A6 CJK UNIFIED IDEOGRAPH-#266A6, IRGKangXi=0981.220, RSKangXi=130.6
266A7 CJK UNIFIED IDEOGRAPH-#266A7, IRGKangXi=0982.070, RSKangXi=130.6
266A8 CJK UNIFIED IDEOGRAPH-#266A8, IRGKangXi=0982.100, RSKangXi=130.6
266A9 CJK UNIFIED IDEOGRAPH-#266A9, IRGKangXi=0982.110, RSKangXi=130.6
266AA CJK UNIFIED IDEOGRAPH-#266AA, IRGKangXi=0982.130, RSKangXi=130.6
266AB CJK UNIFIED IDEOGRAPH-#266AB, IRGKangXi=0982.140, RSKangXi=130.6
266AC CJK UNIFIED IDEOGRAPH-#266AC, IRGKangXi=0982.150, RSKangXi=130.6
266AD CJK UNIFIED IDEOGRAPH-#266AD, IRGKangXi=0982.160, RSKangXi=130.6
266AE CJK UNIFIED IDEOGRAPH-#266AE, IRGKangXi=0982.170, RSKangXi=130.6
266AF CJK UNIFIED IDEOGRAPH-#266AF, IRGKangXi=0982.171, RSKangXi=130.6
266B0 CJK UNIFIED IDEOGRAPH-#266B0, IRGKangXi=0982.171, RSKangXi=130.6
266B1 CJK UNIFIED IDEOGRAPH-#266B1, IRGKangXi=0982.171, RSKangXi=130.6
266B2 CJK UNIFIED IDEOGRAPH-#266B2, IRGKangXi=0982.171, RSKangXi=130.6
266B3 CJK UNIFIED IDEOGRAPH-#266B3, IRGKangXi=0982.171, RSKangXi=130.6
266B4 CJK UNIFIED IDEOGRAPH-#266B4, IRGKangXi=0982.171, RSKangXi=130.6
266B5 CJK UNIFIED IDEOGRAPH-#266B5, IRGKangXi=0982.171, RSKangXi=130.6
266B6 CJK UNIFIED IDEOGRAPH-#266B6, IRGKangXi=0982.171, RSKangXi=130.6
266B7 CJK UNIFIED IDEOGRAPH-#266B7, IRGKangXi=0982.171, RSKangXi=130.6
266B8 CJK UNIFIED IDEOGRAPH-#266B8, IRGKangXi=0982.171, RSKangXi=130.6
266B9 CJK UNIFIED IDEOGRAPH-#266B9, IRGKangXi=0982.171, RSKangXi=130.6
266BA CJK UNIFIED IDEOGRAPH-#266BA, IRGKangXi=0982.171, RSKangXi=130.6
266BB CJK UNIFIED IDEOGRAPH-#266BB, IRGKangXi=0982.171, RSKangXi=130.6
266BC CJK UNIFIED IDEOGRAPH-#266BC, IRGKangXi=0982.171, RSKangXi=130.6
266BD CJK UNIFIED IDEOGRAPH-#266BD, IRGKangXi=0982.171, RSKangXi=130.6
266BE CJK UNIFIED IDEOGRAPH-#266BE, IRGKangXi=0982.171, RSKangXi=130.6
266BF CJK UNIFIED IDEOGRAPH-#266BF, IRGKangXi=0982.171, RSKangXi=130.6
266C0 CJK UNIFIED IDEOGRAPH-#266C0, IRGKangXi=0982.171, RSKangXi=130.6
266C1 CJK UNIFIED IDEOGRAPH-#266C1, IRGKangXi=0982.171, RSKangXi=130.6
266C2 CJK UNIFIED IDEOGRAPH-#266C2, IRGKangXi=0982.171, RSKangXi=130.6
266C3 CJK UNIFIED IDEOGRAPH-#266C3, IRGKangXi=0982.171, RSKangXi=130.6
266C4 CJK UNIFIED IDEOGRAPH-#266C4, IRGKangXi=0982.171, RSKangXi=130.6
266C5 CJK UNIFIED IDEOGRAPH-#266C5, IRGKangXi=0982.171, RSKangXi=130.6
266C6 CJK UNIFIED IDEOGRAPH-#266C6, IRGKangXi=0982.171, RSKangXi=130.6
266C7 CJK UNIFIED IDEOGRAPH-#266C7, IRGKangXi=0982.171, RSKangXi=130.6
266C8 CJK UNIFIED IDEOGRAPH-#266C8, IRGKangXi=0982.171, RSKangXi=130.6
266C9 CJK UNIFIED IDEOGRAPH-#266C9, IRGKangXi=0982.171, RSKangXi=130.6
266CA CJK UNIFIED IDEOGRAPH-#266CA, IRGKangXi=0982.171, RSKangXi=130.6
266CB CJK UNIFIED IDEOGRAPH-#266CB, IRGKangXi=0982.171, RSKangXi=130.6
266CC CJK UNIFIED IDEOGRAPH-#266CC, IRGKangXi=0982.171, RSKangXi=130.6
266CD CJK UNIFIED IDEOGRAPH-#266CD, IRGKangXi=0982.171, RSKangXi=130.6
266CE CJK UNIFIED IDEOGRAPH-#266CE, IRGKangXi=0982.171, RSKangXi=130.6
266CF CJK UNIFIED IDEOGRAPH-#266CF, IRGKangXi=0982.171, RSKangXi=130.6, Def{buttocks}
266D0 CJK UNIFIED IDEOGRAPH-#266D0, IRGKangXi=0982.171, RSKangXi=130.6
266D1 CJK UNIFIED IDEOGRAPH-#266D1, IRGKangXi=0982.171, RSKangXi=130.6
266D2 CJK UNIFIED IDEOGRAPH-#266D2, IRGKangXi=0982.171, RSKangXi=130.6
266D3 CJK UNIFIED IDEOGRAPH-#266D3, IRGKangXi=0982.171, RSKangXi=130.6
266D4 CJK UNIFIED IDEOGRAPH-#266D4, IRGKangXi=0982.190, RSKangXi=130.7
266D5 CJK UNIFIED IDEOGRAPH-#266D5, IRGKangXi=0982.240, RSKangXi=130.7
266D6 CJK UNIFIED IDEOGRAPH-#266D6, IRGKangXi=0983.040, RSKangXi=130.7
266D7 CJK UNIFIED IDEOGRAPH-#266D7, IRGKangXi=0983.080, RSKangXi=130.7
266D8 CJK UNIFIED IDEOGRAPH-#266D8, IRGKangXi=0983.090, RSKangXi=130.7
266D9 CJK UNIFIED IDEOGRAPH-#266D9, IRGKangXi=0983.130, RSKangXi=130.7
266DA CJK UNIFIED IDEOGRAPH-#266DA, IRGKangXi=0983.200, RSKangXi=130.7, Def{oily}
266DB CJK UNIFIED IDEOGRAPH-#266DB, IRGKangXi=0984.060, RSKangXi=130.7
266DC CJK UNIFIED IDEOGRAPH-#266DC, IRGKangXi=0984.070, RSKangXi=130.7
266DD CJK UNIFIED IDEOGRAPH-#266DD, IRGKangXi=0984.100, RSKangXi=130.7
266DE CJK UNIFIED IDEOGRAPH-#266DE, IRGKangXi=0984.110, RSKangXi=130.7
266DF CJK UNIFIED IDEOGRAPH-#266DF, IRGKangXi=0985.030, RSKangXi=130.7
266E0 CJK UNIFIED IDEOGRAPH-#266E0, IRGKangXi=0985.040, RSKangXi=130.7
266E1 CJK UNIFIED IDEOGRAPH-#266E1, IRGKangXi=0985.050, RSKangXi=130.7
266E2 CJK UNIFIED IDEOGRAPH-#266E2, IRGKangXi=0985.060, RSKangXi=130.7
266E3 CJK UNIFIED IDEOGRAPH-#266E3, IRGKangXi=0985.070, RSKangXi=130.7
266E4 CJK UNIFIED IDEOGRAPH-#266E4, IRGKangXi=0985.080, RSKangXi=130.7
266E5 CJK UNIFIED IDEOGRAPH-#266E5, IRGKangXi=0985.090, RSKangXi=130.7
266E6 CJK UNIFIED IDEOGRAPH-#266E6, IRGKangXi=0985.100, RSKangXi=130.7
266E7 CJK UNIFIED IDEOGRAPH-#266E7, IRGKangXi=0985.110, RSKangXi=130.7
266E8 CJK UNIFIED IDEOGRAPH-#266E8, IRGKangXi=0985.111, RSKangXi=130.7
266E9 CJK UNIFIED IDEOGRAPH-#266E9, IRGKangXi=0985.111, RSKangXi=130.7
266EA CJK UNIFIED IDEOGRAPH-#266EA, IRGKangXi=0985.111, RSKangXi=130.7
266EB CJK UNIFIED IDEOGRAPH-#266EB, IRGKangXi=0985.111, RSKangXi=130.7
266EC CJK UNIFIED IDEOGRAPH-#266EC, IRGKangXi=0985.111, RSKangXi=130.7
266ED CJK UNIFIED IDEOGRAPH-#266ED, IRGKangXi=0985.111, RSKangXi=130.7
266EE CJK UNIFIED IDEOGRAPH-#266EE, IRGKangXi=0985.111, RSKangXi=130.7
266EF CJK UNIFIED IDEOGRAPH-#266EF, IRGKangXi=0985.111, RSKangXi=130.7
266F0 CJK UNIFIED IDEOGRAPH-#266F0, IRGKangXi=0985.111, RSKangXi=130.7
266F1 CJK UNIFIED IDEOGRAPH-#266F1, IRGKangXi=0985.111, RSKangXi=130.7
266F2 CJK UNIFIED IDEOGRAPH-#266F2, IRGKangXi=0985.111, RSKangXi=130.7
266F3 CJK UNIFIED IDEOGRAPH-#266F3, IRGKangXi=0985.111, RSKangXi=130.7
266F4 CJK UNIFIED IDEOGRAPH-#266F4, IRGKangXi=0985.111, RSKangXi=130.7
266F5 CJK UNIFIED IDEOGRAPH-#266F5, IRGKangXi=0985.111, RSKangXi=130.7
266F6 CJK UNIFIED IDEOGRAPH-#266F6, IRGKangXi=0985.111, RSKangXi=130.7
266F7 CJK UNIFIED IDEOGRAPH-#266F7, IRGKangXi=0985.111, RSKangXi=130.7
266F8 CJK UNIFIED IDEOGRAPH-#266F8, IRGKangXi=0985.111, RSKangXi=130.7
266F9 CJK UNIFIED IDEOGRAPH-#266F9, IRGKangXi=0985.111, RSKangXi=130.7
266FA CJK UNIFIED IDEOGRAPH-#266FA, IRGKangXi=0985.111, RSKangXi=130.7
266FB CJK UNIFIED IDEOGRAPH-#266FB, IRGKangXi=0985.111, RSKangXi=130.7
266FC CJK UNIFIED IDEOGRAPH-#266FC, IRGKangXi=0985.111, RSKangXi=130.7
266FD CJK UNIFIED IDEOGRAPH-#266FD, IRGKangXi=0985.111, RSKangXi=130.7
266FE CJK UNIFIED IDEOGRAPH-#266FE, IRGKangXi=0985.111, RSKangXi=130.7
266FF CJK UNIFIED IDEOGRAPH-#266FF, IRGKangXi=0985.111, RSKangXi=130.7
26700 CJK UNIFIED IDEOGRAPH-#26700, IRGKangXi=0985.111, RSKangXi=130.7
26701 CJK UNIFIED IDEOGRAPH-#26701, IRGKangXi=0985.111, RSKangXi=130.7
26702 CJK UNIFIED IDEOGRAPH-#26702, IRGKangXi=0985.111, RSKangXi=130.7
26703 CJK UNIFIED IDEOGRAPH-#26703, IRGKangXi=0985.111, RSKangXi=130.7
26704 CJK UNIFIED IDEOGRAPH-#26704, IRGKangXi=0985.111, RSKangXi=130.7
26705 CJK UNIFIED IDEOGRAPH-#26705, IRGKangXi=0985.111, RSKangXi=130.7
26706 CJK UNIFIED IDEOGRAPH-#26706, IRGKangXi=0985.120, RSKangXi=130.8
26707 CJK UNIFIED IDEOGRAPH-#26707, IRGKangXi=0985.130, RSKangXi=130.8
26708 CJK UNIFIED IDEOGRAPH-#26708, IRGKangXi=0985.190, RSKangXi=130.8
26709 CJK UNIFIED IDEOGRAPH-#26709, IRGKangXi=0985.240, RSKangXi=130.8
2670A CJK UNIFIED IDEOGRAPH-#2670A, IRGKangXi=0985.280, RSKangXi=130.8
2670B CJK UNIFIED IDEOGRAPH-#2670B, IRGKangXi=0986.030, RSKangXi=130.8
2670C CJK UNIFIED IDEOGRAPH-#2670C, IRGKangXi=0986.040, RSKangXi=130.8
2670D CJK UNIFIED IDEOGRAPH-#2670D, IRGKangXi=0986.060, RSKangXi=130.8
2670E CJK UNIFIED IDEOGRAPH-#2670E, IRGKangXi=0986.090, RSKangXi=130.8
2670F CJK UNIFIED IDEOGRAPH-#2670F, IRGKangXi=0986.110, RSKangXi=130.8
26710 CJK UNIFIED IDEOGRAPH-#26710, IRGKangXi=0986.120, RSKangXi=130.8
26711 CJK UNIFIED IDEOGRAPH-#26711, IRGKangXi=0986.130, RSKangXi=130.8
26712 CJK UNIFIED IDEOGRAPH-#26712, IRGKangXi=0986.190, RSKangXi=130.8
26713 CJK UNIFIED IDEOGRAPH-#26713, IRGKangXi=0987.010, RSKangXi=130.8
26714 CJK UNIFIED IDEOGRAPH-#26714, IRGKangXi=0987.040, RSKangXi=130.8
26715 CJK UNIFIED IDEOGRAPH-#26715, IRGKangXi=0987.120, RSKangXi=130.8
26716 CJK UNIFIED IDEOGRAPH-#26716, IRGKangXi=0987.130, RSKangXi=130.8, Def{to stretch, spread}
26717 CJK UNIFIED IDEOGRAPH-#26717, IRGKangXi=0987.170, RSKangXi=130.8
26718 CJK UNIFIED IDEOGRAPH-#26718, IRGKangXi=0987.180, RSKangXi=130.8
26719 CJK UNIFIED IDEOGRAPH-#26719, IRGKangXi=0987.190, RSKangXi=130.8
2671A CJK UNIFIED IDEOGRAPH-#2671A, IRGKangXi=0987.200, RSKangXi=130.8
2671B CJK UNIFIED IDEOGRAPH-#2671B, IRGKangXi=0987.220, RSKangXi=130.8
2671C CJK UNIFIED IDEOGRAPH-#2671C, IRGKangXi=0987.230, RSKangXi=130.8
2671D CJK UNIFIED IDEOGRAPH-#2671D, IRGKangXi=0987.231, RSKangXi=130.8
2671E CJK UNIFIED IDEOGRAPH-#2671E, IRGKangXi=0987.231, RSKangXi=130.8
2671F CJK UNIFIED IDEOGRAPH-#2671F, IRGKangXi=0987.231, RSKangXi=130.8
26720 CJK UNIFIED IDEOGRAPH-#26720, IRGKangXi=0987.231, RSKangXi=130.8
26721 CJK UNIFIED IDEOGRAPH-#26721, IRGKangXi=0987.231, RSKangXi=130.8
26722 CJK UNIFIED IDEOGRAPH-#26722, IRGKangXi=0987.231, RSKangXi=130.8
26723 CJK UNIFIED IDEOGRAPH-#26723, IRGKangXi=0987.231, RSKangXi=130.8
26724 CJK UNIFIED IDEOGRAPH-#26724, IRGKangXi=0987.231, RSKangXi=130.8
26725 CJK UNIFIED IDEOGRAPH-#26725, IRGKangXi=0987.231, RSKangXi=130.8
26726 CJK UNIFIED IDEOGRAPH-#26726, IRGKangXi=0987.231, RSKangXi=130.8
26727 CJK UNIFIED IDEOGRAPH-#26727, IRGKangXi=0987.231, RSKangXi=130.8
26728 CJK UNIFIED IDEOGRAPH-#26728, IRGKangXi=0987.231, RSKangXi=130.8
26729 CJK UNIFIED IDEOGRAPH-#26729, IRGKangXi=0987.231, RSKangXi=130.8
2672A CJK UNIFIED IDEOGRAPH-#2672A, IRGKangXi=0987.231, RSKangXi=130.8
2672B CJK UNIFIED IDEOGRAPH-#2672B, IRGKangXi=0987.231, RSKangXi=130.8
2672C CJK UNIFIED IDEOGRAPH-#2672C, IRGKangXi=0987.231, RSKangXi=130.8
2672D CJK UNIFIED IDEOGRAPH-#2672D, IRGKangXi=0987.231, RSKangXi=130.8
2672E CJK UNIFIED IDEOGRAPH-#2672E, IRGKangXi=0987.231, RSKangXi=130.8
2672F CJK UNIFIED IDEOGRAPH-#2672F, IRGKangXi=0987.231, RSKangXi=130.8
26730 CJK UNIFIED IDEOGRAPH-#26730, IRGKangXi=0987.231, RSKangXi=130.8
26731 CJK UNIFIED IDEOGRAPH-#26731, IRGKangXi=0987.231, RSKangXi=130.8
26732 CJK UNIFIED IDEOGRAPH-#26732, IRGKangXi=0987.231, RSKangXi=130.8
26733 CJK UNIFIED IDEOGRAPH-#26733, IRGKangXi=0987.231, RSKangXi=74.8
26734 CJK UNIFIED IDEOGRAPH-#26734, IRGKangXi=0987.231, RSKangXi=130.8
26735 CJK UNIFIED IDEOGRAPH-#26735, IRGKangXi=0987.231, RSKangXi=130.8
26736 CJK UNIFIED IDEOGRAPH-#26736, IRGKangXi=0987.231, RSKangXi=130.8
26737 CJK UNIFIED IDEOGRAPH-#26737, IRGKangXi=0987.231, RSKangXi=130.8
26738 CJK UNIFIED IDEOGRAPH-#26738, IRGKangXi=0987.231, RSKangXi=130.8
26739 CJK UNIFIED IDEOGRAPH-#26739, IRGKangXi=0987.231, RSKangXi=130.8
2673A CJK UNIFIED IDEOGRAPH-#2673A, IRGKangXi=0987.231, RSKangXi=130.8
2673B CJK UNIFIED IDEOGRAPH-#2673B, IRGKangXi=0987.231, RSKangXi=130.8
2673C CJK UNIFIED IDEOGRAPH-#2673C, IRGKangXi=0987.231, RSKangXi=130.8
2673D CJK UNIFIED IDEOGRAPH-#2673D, IRGKangXi=0987.231, RSKangXi=130.8
2673E CJK UNIFIED IDEOGRAPH-#2673E, IRGKangXi=0987.231, RSKangXi=130.8
2673F CJK UNIFIED IDEOGRAPH-#2673F, IRGKangXi=0987.231, RSKangXi=130.8
26740 CJK UNIFIED IDEOGRAPH-#26740, IRGKangXi=0987.231, RSKangXi=130.8
26741 CJK UNIFIED IDEOGRAPH-#26741, IRGKangXi=0987.231, RSKangXi=130.8
26742 CJK UNIFIED IDEOGRAPH-#26742, IRGKangXi=0987.231, RSKangXi=130.8
26743 CJK UNIFIED IDEOGRAPH-#26743, IRGKangXi=0987.231, RSKangXi=130.8
26744 CJK UNIFIED IDEOGRAPH-#26744, IRGKangXi=0987.231, RSKangXi=130.8
26745 CJK UNIFIED IDEOGRAPH-#26745, IRGKangXi=0987.231, RSKangXi=130.8
26746 CJK UNIFIED IDEOGRAPH-#26746, IRGKangXi=0987.231, RSKangXi=130.8
26747 CJK UNIFIED IDEOGRAPH-#26747, IRGKangXi=0987.231, RSKangXi=130.8
26748 CJK UNIFIED IDEOGRAPH-#26748, IRGKangXi=0987.231, RSKangXi=130.8
26749 CJK UNIFIED IDEOGRAPH-#26749, IRGKangXi=0987.231, RSKangXi=130.8
2674A CJK UNIFIED IDEOGRAPH-#2674A, IRGKangXi=0987.231, RSKangXi=130.8
2674B CJK UNIFIED IDEOGRAPH-#2674B, IRGKangXi=0987.231, RSKangXi=130.8
2674C CJK UNIFIED IDEOGRAPH-#2674C, IRGKangXi=0987.231, RSKangXi=130.8
2674D CJK UNIFIED IDEOGRAPH-#2674D, IRGKangXi=0987.231, RSKangXi=130.8
2674E CJK UNIFIED IDEOGRAPH-#2674E, IRGKangXi=0987.231, RSKangXi=130.8
2674F CJK UNIFIED IDEOGRAPH-#2674F, IRGKangXi=0987.231, RSKangXi=130.8
26750 CJK UNIFIED IDEOGRAPH-#26750, IRGKangXi=0987.231, RSKangXi=130.8
26751 CJK UNIFIED IDEOGRAPH-#26751, IRGKangXi=0987.231, RSKangXi=130.8
26752 CJK UNIFIED IDEOGRAPH-#26752, IRGKangXi=0987.231, RSKangXi=130.8
26753 CJK UNIFIED IDEOGRAPH-#26753, IRGKangXi=0987.231, RSKangXi=130.8
26754 CJK UNIFIED IDEOGRAPH-#26754, IRGKangXi=0987.231, RSKangXi=130.8
26755 CJK UNIFIED IDEOGRAPH-#26755, IRGKangXi=0987.231, RSKangXi=130.8
26756 CJK UNIFIED IDEOGRAPH-#26756, IRGKangXi=0987.231, RSKangXi=130.8
26757 CJK UNIFIED IDEOGRAPH-#26757, IRGKangXi=0987.231, RSKangXi=130.8
26758 CJK UNIFIED IDEOGRAPH-#26758, IRGKangXi=0987.231, RSKangXi=130.8
26759 CJK UNIFIED IDEOGRAPH-#26759, IRGKangXi=0987.231, RSKangXi=130.8
2675A CJK UNIFIED IDEOGRAPH-#2675A, IRGKangXi=0987.240, RSKangXi=130.9
2675B CJK UNIFIED IDEOGRAPH-#2675B, IRGKangXi=0987.250, RSKangXi=130.9
2675C CJK UNIFIED IDEOGRAPH-#2675C, IRGKangXi=0987.260, RSKangXi=130.9
2675D CJK UNIFIED IDEOGRAPH-#2675D, IRGKangXi=0988.020, RSKangXi=130.9
2675E CJK UNIFIED IDEOGRAPH-#2675E, IRGKangXi=0988.050, RSKangXi=130.9
2675F CJK UNIFIED IDEOGRAPH-#2675F, IRGKangXi=0988.070, RSKangXi=130.9
26760 CJK UNIFIED IDEOGRAPH-#26760, IRGKangXi=0988.140, RSKangXi=130.9
26761 CJK UNIFIED IDEOGRAPH-#26761, IRGKangXi=0988.180, RSKangXi=130.9
26762 CJK UNIFIED IDEOGRAPH-#26762, IRGKangXi=0988.220, RSKangXi=130.9
26763 CJK UNIFIED IDEOGRAPH-#26763, IRGKangXi=0988.230, RSKangXi=130.9
26764 CJK UNIFIED IDEOGRAPH-#26764, IRGKangXi=0988.250, RSKangXi=130.9
26765 CJK UNIFIED IDEOGRAPH-#26765, IRGKangXi=0988.260, RSKangXi=130.9
26766 CJK UNIFIED IDEOGRAPH-#26766, IRGKangXi=0988.300, RSKangXi=130.9
26767 CJK UNIFIED IDEOGRAPH-#26767, IRGKangXi=0989.020, RSKangXi=130.9
26768 CJK UNIFIED IDEOGRAPH-#26768, IRGKangXi=0989.040, RSKangXi=130.9
26769 CJK UNIFIED IDEOGRAPH-#26769, IRGKangXi=0989.060, RSKangXi=130.9
2676A CJK UNIFIED IDEOGRAPH-#2676A, IRGKangXi=0989.110, RSKangXi=130.9
2676B CJK UNIFIED IDEOGRAPH-#2676B, IRGKangXi=0989.140, RSKangXi=130.9
2676C CJK UNIFIED IDEOGRAPH-#2676C, IRGKangXi=0989.150, RSKangXi=130.9
2676D CJK UNIFIED IDEOGRAPH-#2676D, IRGKangXi=0989.180, RSKangXi=130.9
2676E CJK UNIFIED IDEOGRAPH-#2676E, IRGKangXi=0989.270, RSKangXi=130.9
2676F CJK UNIFIED IDEOGRAPH-#2676F, IRGKangXi=0990.030, RSKangXi=130.9
26770 CJK UNIFIED IDEOGRAPH-#26770, IRGKangXi=0990.040, RSKangXi=130.9
26771 CJK UNIFIED IDEOGRAPH-#26771, IRGKangXi=0990.050, RSKangXi=130.9
26772 CJK UNIFIED IDEOGRAPH-#26772, IRGKangXi=0990.060, RSKangXi=130.9
26773 CJK UNIFIED IDEOGRAPH-#26773, IRGKangXi=0990.070, RSKangXi=130.9
26774 CJK UNIFIED IDEOGRAPH-#26774, IRGKangXi=0990.080, RSKangXi=130.9
26775 CJK UNIFIED IDEOGRAPH-#26775, IRGKangXi=0990.090, RSKangXi=130.9
26776 CJK UNIFIED IDEOGRAPH-#26776, IRGKangXi=0990.100, RSKangXi=130.9
26777 CJK UNIFIED IDEOGRAPH-#26777, IRGKangXi=0990.110, RSKangXi=130.9
26778 CJK UNIFIED IDEOGRAPH-#26778, IRGKangXi=0990.130, RSKangXi=130.9
26779 CJK UNIFIED IDEOGRAPH-#26779, IRGKangXi=0990.131, RSKangXi=130.9
2677A CJK UNIFIED IDEOGRAPH-#2677A, IRGKangXi=0990.131, RSKangXi=130.9
2677B CJK UNIFIED IDEOGRAPH-#2677B, IRGKangXi=0990.131, RSKangXi=130.9
2677C CJK UNIFIED IDEOGRAPH-#2677C, IRGKangXi=0990.131, RSKangXi=130.9
2677D CJK UNIFIED IDEOGRAPH-#2677D, IRGKangXi=0990.131, RSKangXi=130.9
2677E CJK UNIFIED IDEOGRAPH-#2677E, IRGKangXi=0990.131, RSKangXi=130.9
2677F CJK UNIFIED IDEOGRAPH-#2677F, IRGKangXi=0990.131, RSKangXi=130.9
26780 CJK UNIFIED IDEOGRAPH-#26780, IRGKangXi=0990.131, RSKangXi=130.9
26781 CJK UNIFIED IDEOGRAPH-#26781, IRGKangXi=0990.131, RSKangXi=130.9
26782 CJK UNIFIED IDEOGRAPH-#26782, IRGKangXi=0990.131, RSKangXi=130.9
26783 CJK UNIFIED IDEOGRAPH-#26783, IRGKangXi=0990.131, RSKangXi=130.9
26784 CJK UNIFIED IDEOGRAPH-#26784, IRGKangXi=0990.131, RSKangXi=130.9
26785 CJK UNIFIED IDEOGRAPH-#26785, IRGKangXi=0990.131, RSKangXi=130.9
26786 CJK UNIFIED IDEOGRAPH-#26786, IRGKangXi=0990.131, RSKangXi=130.9
26787 CJK UNIFIED IDEOGRAPH-#26787, IRGKangXi=0990.131, RSKangXi=130.9
26788 CJK UNIFIED IDEOGRAPH-#26788, IRGKangXi=0990.131, RSKangXi=130.9
26789 CJK UNIFIED IDEOGRAPH-#26789, IRGKangXi=0990.131, RSKangXi=130.9
2678A CJK UNIFIED IDEOGRAPH-#2678A, IRGKangXi=0990.131, RSKangXi=130.9
2678B CJK UNIFIED IDEOGRAPH-#2678B, IRGKangXi=0990.131, RSKangXi=130.9
2678C CJK UNIFIED IDEOGRAPH-#2678C, IRGKangXi=0990.131, RSKangXi=130.9
2678D CJK UNIFIED IDEOGRAPH-#2678D, IRGKangXi=0990.131, RSKangXi=130.9
2678E CJK UNIFIED IDEOGRAPH-#2678E, IRGKangXi=0990.131, RSKangXi=130.9
2678F CJK UNIFIED IDEOGRAPH-#2678F, IRGKangXi=0990.131, RSKangXi=130.9
26790 CJK UNIFIED IDEOGRAPH-#26790, IRGKangXi=0990.131, RSKangXi=130.9
26791 CJK UNIFIED IDEOGRAPH-#26791, IRGKangXi=0990.131, RSKangXi=130.9
26792 CJK UNIFIED IDEOGRAPH-#26792, IRGKangXi=0990.131, RSKangXi=130.9
26793 CJK UNIFIED IDEOGRAPH-#26793, IRGKangXi=0990.131, RSKangXi=130.9
26794 CJK UNIFIED IDEOGRAPH-#26794, IRGKangXi=0990.131, RSKangXi=130.9
26795 CJK UNIFIED IDEOGRAPH-#26795, IRGKangXi=0990.131, RSKangXi=130.9
26796 CJK UNIFIED IDEOGRAPH-#26796, IRGKangXi=0990.131, RSKangXi=130.9
26797 CJK UNIFIED IDEOGRAPH-#26797, IRGKangXi=0990.131, RSKangXi=130.9
26798 CJK UNIFIED IDEOGRAPH-#26798, IRGKangXi=0990.131, RSKangXi=130.9
26799 CJK UNIFIED IDEOGRAPH-#26799, IRGKangXi=0990.200, RSKangXi=130.10
2679A CJK UNIFIED IDEOGRAPH-#2679A, IRGKangXi=0990.280, RSKangXi=130.10
2679B CJK UNIFIED IDEOGRAPH-#2679B, IRGKangXi=0990.310, RSKangXi=130.10
2679C CJK UNIFIED IDEOGRAPH-#2679C, IRGKangXi=0990.320, RSKangXi=130.10
2679D CJK UNIFIED IDEOGRAPH-#2679D, IRGKangXi=0991.020, RSKangXi=130.10
2679E CJK UNIFIED IDEOGRAPH-#2679E, IRGKangXi=0991.050, RSKangXi=130.10
2679F CJK UNIFIED IDEOGRAPH-#2679F, IRGKangXi=0991.080, RSKangXi=130.10
267A0 CJK UNIFIED IDEOGRAPH-#267A0, IRGKangXi=0991.100, RSKangXi=130.10
267A1 CJK UNIFIED IDEOGRAPH-#267A1, IRGKangXi=0991.110, RSKangXi=130.10
267A2 CJK UNIFIED IDEOGRAPH-#267A2, IRGKangXi=0991.120, RSKangXi=130.10
267A3 CJK UNIFIED IDEOGRAPH-#267A3, IRGKangXi=0991.140, RSKangXi=130.10, Def{rank; rancid; fetid}
267A4 CJK UNIFIED IDEOGRAPH-#267A4, IRGKangXi=0991.150, RSKangXi=130.10
267A5 CJK UNIFIED IDEOGRAPH-#267A5, IRGKangXi=0991.160, RSKangXi=130.10
267A6 CJK UNIFIED IDEOGRAPH-#267A6, IRGKangXi=0991.170, RSKangXi=130.10
267A7 CJK UNIFIED IDEOGRAPH-#267A7, IRGKangXi=0991.180, RSKangXi=130.10
267A8 CJK UNIFIED IDEOGRAPH-#267A8, IRGKangXi=0991.190, RSKangXi=130.10
267A9 CJK UNIFIED IDEOGRAPH-#267A9, IRGKangXi=0991.200, RSKangXi=130.10
267AA CJK UNIFIED IDEOGRAPH-#267AA, IRGKangXi=0991.230, RSKangXi=130.10
267AB CJK UNIFIED IDEOGRAPH-#267AB, IRGKangXi=0991.240, RSKangXi=130.10
267AC CJK UNIFIED IDEOGRAPH-#267AC, IRGKangXi=0991.280, RSKangXi=130.10
267AD CJK UNIFIED IDEOGRAPH-#267AD, IRGKangXi=0991.300, RSKangXi=130.10
267AE CJK UNIFIED IDEOGRAPH-#267AE, IRGKangXi=0992.020, RSKangXi=130.10
267AF CJK UNIFIED IDEOGRAPH-#267AF, IRGKangXi=0992.040, RSKangXi=130.10
267B0 CJK UNIFIED IDEOGRAPH-#267B0, IRGKangXi=0992.050, RSKangXi=130.10
267B1 CJK UNIFIED IDEOGRAPH-#267B1, IRGKangXi=0992.060, RSKangXi=130.10
267B2 CJK UNIFIED IDEOGRAPH-#267B2, IRGKangXi=0992.070, RSKangXi=130.10
267B3 CJK UNIFIED IDEOGRAPH-#267B3, IRGKangXi=0992.071, RSKangXi=130.10
267B4 CJK UNIFIED IDEOGRAPH-#267B4, IRGKangXi=0992.071, RSKangXi=130.10
267B5 CJK UNIFIED IDEOGRAPH-#267B5, IRGKangXi=0992.071, RSKangXi=130.10
267B6 CJK UNIFIED IDEOGRAPH-#267B6, IRGKangXi=0992.071, RSKangXi=130.10
267B7 CJK UNIFIED IDEOGRAPH-#267B7, IRGKangXi=0992.071, RSKangXi=130.10
267B8 CJK UNIFIED IDEOGRAPH-#267B8, IRGKangXi=0992.071, RSKangXi=130.10
267B9 CJK UNIFIED IDEOGRAPH-#267B9, IRGKangXi=0992.071, RSKangXi=130.10
267BA CJK UNIFIED IDEOGRAPH-#267BA, IRGKangXi=0992.071, RSKangXi=130.10
267BB CJK UNIFIED IDEOGRAPH-#267BB, IRGKangXi=0992.071, RSKangXi=130.10
267BC CJK UNIFIED IDEOGRAPH-#267BC, IRGKangXi=0992.071, RSKangXi=130.10
267BD CJK UNIFIED IDEOGRAPH-#267BD, IRGKangXi=0992.071, RSKangXi=130.10
267BE CJK UNIFIED IDEOGRAPH-#267BE, IRGKangXi=0992.071, RSKangXi=130.10
267BF CJK UNIFIED IDEOGRAPH-#267BF, IRGKangXi=0992.071, RSKangXi=130.10
267C0 CJK UNIFIED IDEOGRAPH-#267C0, IRGKangXi=0992.071, RSKangXi=130.10
267C1 CJK UNIFIED IDEOGRAPH-#267C1, IRGKangXi=0992.071, RSKangXi=130.10
267C2 CJK UNIFIED IDEOGRAPH-#267C2, IRGKangXi=0992.071, RSKangXi=130.10
267C3 CJK UNIFIED IDEOGRAPH-#267C3, IRGKangXi=0992.071, RSKangXi=130.10
267C4 CJK UNIFIED IDEOGRAPH-#267C4, IRGKangXi=0992.071, RSKangXi=130.10
267C5 CJK UNIFIED IDEOGRAPH-#267C5, IRGKangXi=0992.071, RSKangXi=130.10
267C6 CJK UNIFIED IDEOGRAPH-#267C6, IRGKangXi=0992.071, RSKangXi=130.10
267C7 CJK UNIFIED IDEOGRAPH-#267C7, IRGKangXi=0992.071, RSKangXi=130.10
267C8 CJK UNIFIED IDEOGRAPH-#267C8, IRGKangXi=0992.071, RSKangXi=130.10
267C9 CJK UNIFIED IDEOGRAPH-#267C9, IRGKangXi=0992.071, RSKangXi=130.10
267CA CJK UNIFIED IDEOGRAPH-#267CA, IRGKangXi=0992.071, RSKangXi=130.10
267CB CJK UNIFIED IDEOGRAPH-#267CB, IRGKangXi=0992.071, RSKangXi=130.10
267CC CJK UNIFIED IDEOGRAPH-#267CC, IRGKangXi=0992.071, RSKangXi=130.10, Def{muscle}
267CD CJK UNIFIED IDEOGRAPH-#267CD, IRGKangXi=0992.071, RSKangXi=130.10
267CE CJK UNIFIED IDEOGRAPH-#267CE, IRGKangXi=0992.071, RSKangXi=130.10
267CF CJK UNIFIED IDEOGRAPH-#267CF, IRGKangXi=0992.071, RSKangXi=130.10
267D0 CJK UNIFIED IDEOGRAPH-#267D0, IRGKangXi=0992.071, RSKangXi=130.10
267D1 CJK UNIFIED IDEOGRAPH-#267D1, IRGKangXi=0992.071, RSKangXi=130.10
267D2 CJK UNIFIED IDEOGRAPH-#267D2, IRGKangXi=0992.071, RSKangXi=130.10
267D3 CJK UNIFIED IDEOGRAPH-#267D3, IRGKangXi=0992.071, RSKangXi=130.9
267D4 CJK UNIFIED IDEOGRAPH-#267D4, IRGKangXi=0992.071, RSKangXi=130.9
267D5 CJK UNIFIED IDEOGRAPH-#267D5, IRGKangXi=0992.071, RSKangXi=130.10
267D6 CJK UNIFIED IDEOGRAPH-#267D6, IRGKangXi=0992.071, RSKangXi=130.10
267D7 CJK UNIFIED IDEOGRAPH-#267D7, IRGKangXi=0992.071, RSKangXi=130.10
267D8 CJK UNIFIED IDEOGRAPH-#267D8, IRGKangXi=0992.090, RSKangXi=130.11
267D9 CJK UNIFIED IDEOGRAPH-#267D9, IRGKangXi=0992.170, RSKangXi=130.11
267DA CJK UNIFIED IDEOGRAPH-#267DA, IRGKangXi=0992.180, RSKangXi=130.11
267DB CJK UNIFIED IDEOGRAPH-#267DB, IRGKangXi=0992.260, RSKangXi=130.11
267DC CJK UNIFIED IDEOGRAPH-#267DC, IRGKangXi=0992.270, RSKangXi=130.11
267DD CJK UNIFIED IDEOGRAPH-#267DD, IRGKangXi=0992.290, RSKangXi=130.11
267DE CJK UNIFIED IDEOGRAPH-#267DE, IRGKangXi=0993.020, RSKangXi=130.11
267DF CJK UNIFIED IDEOGRAPH-#267DF, IRGKangXi=0993.030, RSKangXi=130.11
267E0 CJK UNIFIED IDEOGRAPH-#267E0, IRGKangXi=0993.100, RSKangXi=130.11
267E1 CJK UNIFIED IDEOGRAPH-#267E1, IRGKangXi=0993.130, RSKangXi=130.11
267E2 CJK UNIFIED IDEOGRAPH-#267E2, IRGKangXi=0993.140, RSKangXi=130.11
267E3 CJK UNIFIED IDEOGRAPH-#267E3, IRGKangXi=0993.150, RSKangXi=130.11
267E4 CJK UNIFIED IDEOGRAPH-#267E4, IRGKangXi=0993.170, RSKangXi=130.11, Def{viands, delicacies}
267E5 CJK UNIFIED IDEOGRAPH-#267E5, IRGKangXi=0993.180, RSKangXi=130.11
267E6 CJK UNIFIED IDEOGRAPH-#267E6, IRGKangXi=0993.190, RSKangXi=130.11
267E7 CJK UNIFIED IDEOGRAPH-#267E7, IRGKangXi=0993.200, RSKangXi=130.11
267E8 CJK UNIFIED IDEOGRAPH-#267E8, IRGKangXi=0993.201, RSKangXi=130.11
267E9 CJK UNIFIED IDEOGRAPH-#267E9, IRGKangXi=0993.201, RSKangXi=130.11
267EA CJK UNIFIED IDEOGRAPH-#267EA, IRGKangXi=0993.201, RSKangXi=130.11
267EB CJK UNIFIED IDEOGRAPH-#267EB, IRGKangXi=0993.201, RSKangXi=130.11
267EC CJK UNIFIED IDEOGRAPH-#267EC, IRGKangXi=0993.201, RSKangXi=130.11
267ED CJK UNIFIED IDEOGRAPH-#267ED, IRGKangXi=0993.201, RSKangXi=130.11
267EE CJK UNIFIED IDEOGRAPH-#267EE, IRGKangXi=0993.201, RSKangXi=130.11
267EF CJK UNIFIED IDEOGRAPH-#267EF, IRGKangXi=0993.201, RSKangXi=130.11
267F0 CJK UNIFIED IDEOGRAPH-#267F0, IRGKangXi=0993.201, RSKangXi=130.11
267F1 CJK UNIFIED IDEOGRAPH-#267F1, IRGKangXi=0993.201, RSKangXi=130.11
267F2 CJK UNIFIED IDEOGRAPH-#267F2, IRGKangXi=0993.201, RSKangXi=130.11
267F3 CJK UNIFIED IDEOGRAPH-#267F3, IRGKangXi=0993.201, RSKangXi=130.11
267F4 CJK UNIFIED IDEOGRAPH-#267F4, IRGKangXi=0993.201, RSKangXi=130.11
267F5 CJK UNIFIED IDEOGRAPH-#267F5, IRGKangXi=0993.201, RSKangXi=130.11
267F6 CJK UNIFIED IDEOGRAPH-#267F6, IRGKangXi=0993.201, RSKangXi=130.11
267F7 CJK UNIFIED IDEOGRAPH-#267F7, IRGKangXi=0993.201, RSKangXi=130.11
267F8 CJK UNIFIED IDEOGRAPH-#267F8, IRGKangXi=0993.201, RSKangXi=130.11
267F9 CJK UNIFIED IDEOGRAPH-#267F9, IRGKangXi=0993.201, RSKangXi=130.11
267FA CJK UNIFIED IDEOGRAPH-#267FA, IRGKangXi=0993.201, RSKangXi=130.11
267FB CJK UNIFIED IDEOGRAPH-#267FB, IRGKangXi=0993.201, RSKangXi=130.11
267FC CJK UNIFIED IDEOGRAPH-#267FC, IRGKangXi=0993.201, RSKangXi=130.11
267FD CJK UNIFIED IDEOGRAPH-#267FD, IRGKangXi=0993.201, RSKangXi=130.11
267FE CJK UNIFIED IDEOGRAPH-#267FE, IRGKangXi=0993.201, RSKangXi=130.11
267FF CJK UNIFIED IDEOGRAPH-#267FF, IRGKangXi=0993.201, RSKangXi=130.11
26800 CJK UNIFIED IDEOGRAPH-#26800, IRGKangXi=0993.201, RSKangXi=130.11
26801 CJK UNIFIED IDEOGRAPH-#26801, IRGKangXi=0993.201, RSKangXi=130.11
26802 CJK UNIFIED IDEOGRAPH-#26802, IRGKangXi=0993.201, RSKangXi=130.11
26803 CJK UNIFIED IDEOGRAPH-#26803, IRGKangXi=0994.030, RSKangXi=130.12
26804 CJK UNIFIED IDEOGRAPH-#26804, IRGKangXi=0994.060, RSKangXi=130.12
26805 CJK UNIFIED IDEOGRAPH-#26805, IRGKangXi=0994.110, RSKangXi=130.12
26806 CJK UNIFIED IDEOGRAPH-#26806, IRGKangXi=0994.140, RSKangXi=130.12
26807 CJK UNIFIED IDEOGRAPH-#26807, IRGKangXi=0994.150, RSKangXi=130.12
26808 CJK UNIFIED IDEOGRAPH-#26808, IRGKangXi=0994.170, RSKangXi=130.12
26809 CJK UNIFIED IDEOGRAPH-#26809, IRGKangXi=0994.180, RSKangXi=130.12
2680A CJK UNIFIED IDEOGRAPH-#2680A, IRGKangXi=0994.210, RSKangXi=130.12
2680B CJK UNIFIED IDEOGRAPH-#2680B, IRGKangXi=0994.220, RSKangXi=130.12
2680C CJK UNIFIED IDEOGRAPH-#2680C, IRGKangXi=0994.230, RSKangXi=130.12
2680D CJK UNIFIED IDEOGRAPH-#2680D, IRGKangXi=0994.260, RSKangXi=130.12
2680E CJK UNIFIED IDEOGRAPH-#2680E, IRGKangXi=0994.280, RSKangXi=130.12
2680F CJK UNIFIED IDEOGRAPH-#2680F, IRGKangXi=0994.290, RSKangXi=130.12
26810 CJK UNIFIED IDEOGRAPH-#26810, IRGKangXi=0995.020, RSKangXi=130.12
26811 CJK UNIFIED IDEOGRAPH-#26811, IRGKangXi=0995.030, RSKangXi=130.12
26812 CJK UNIFIED IDEOGRAPH-#26812, IRGKangXi=0995.050, RSKangXi=130.12
26813 CJK UNIFIED IDEOGRAPH-#26813, IRGKangXi=0995.060, RSKangXi=130.12
26814 CJK UNIFIED IDEOGRAPH-#26814, IRGKangXi=0995.080, RSKangXi=130.12
26815 CJK UNIFIED IDEOGRAPH-#26815, IRGKangXi=0995.090, RSKangXi=130.12
26816 CJK UNIFIED IDEOGRAPH-#26816, IRGKangXi=0995.100, RSKangXi=130.12
26817 CJK UNIFIED IDEOGRAPH-#26817, IRGKangXi=0995.110, RSKangXi=130.12
26818 CJK UNIFIED IDEOGRAPH-#26818, IRGKangXi=0995.111, RSKangXi=130.12
26819 CJK UNIFIED IDEOGRAPH-#26819, IRGKangXi=0995.111, RSKangXi=130.12
2681A CJK UNIFIED IDEOGRAPH-#2681A, IRGKangXi=0995.111, RSKangXi=130.12
2681B CJK UNIFIED IDEOGRAPH-#2681B, IRGKangXi=0995.111, RSKangXi=130.12
2681C CJK UNIFIED IDEOGRAPH-#2681C, IRGKangXi=0995.111, RSKangXi=130.12
2681D CJK UNIFIED IDEOGRAPH-#2681D, IRGKangXi=0995.111, RSKangXi=130.12
2681E CJK UNIFIED IDEOGRAPH-#2681E, IRGKangXi=0995.111, RSKangXi=130.12
2681F CJK UNIFIED IDEOGRAPH-#2681F, IRGKangXi=0995.111, RSKangXi=130.12
26820 CJK UNIFIED IDEOGRAPH-#26820, IRGKangXi=0995.111, RSKangXi=130.12
26821 CJK UNIFIED IDEOGRAPH-#26821, IRGKangXi=0995.111, RSKangXi=130.12
26822 CJK UNIFIED IDEOGRAPH-#26822, IRGKangXi=0995.111, RSKangXi=130.12
26823 CJK UNIFIED IDEOGRAPH-#26823, IRGKangXi=0995.111, RSKangXi=130.12
26824 CJK UNIFIED IDEOGRAPH-#26824, IRGKangXi=0995.111, RSKangXi=130.12
26825 CJK UNIFIED IDEOGRAPH-#26825, IRGKangXi=0995.111, RSKangXi=130.12
26826 CJK UNIFIED IDEOGRAPH-#26826, IRGKangXi=0995.111, RSKangXi=130.12
26827 CJK UNIFIED IDEOGRAPH-#26827, IRGKangXi=0995.111, RSKangXi=130.12
26828 CJK UNIFIED IDEOGRAPH-#26828, IRGKangXi=0995.111, RSKangXi=130.12
26829 CJK UNIFIED IDEOGRAPH-#26829, IRGKangXi=0995.111, RSKangXi=130.12
2682A CJK UNIFIED IDEOGRAPH-#2682A, IRGKangXi=0995.111, RSKangXi=130.12
2682B CJK UNIFIED IDEOGRAPH-#2682B, IRGKangXi=0995.111, RSKangXi=130.12
2682C CJK UNIFIED IDEOGRAPH-#2682C, IRGKangXi=0995.111, RSKangXi=130.12
2682D CJK UNIFIED IDEOGRAPH-#2682D, IRGKangXi=0995.111, RSKangXi=130.12
2682E CJK UNIFIED IDEOGRAPH-#2682E, IRGKangXi=0995.111, RSKangXi=130.12
2682F CJK UNIFIED IDEOGRAPH-#2682F, IRGKangXi=0995.111, RSKangXi=130.12
26830 CJK UNIFIED IDEOGRAPH-#26830, IRGKangXi=0995.111, RSKangXi=130.12
26831 CJK UNIFIED IDEOGRAPH-#26831, IRGKangXi=0995.111, RSKangXi=130.12
26832 CJK UNIFIED IDEOGRAPH-#26832, IRGKangXi=0995.111, RSKangXi=130.12
26833 CJK UNIFIED IDEOGRAPH-#26833, IRGKangXi=0995.111, RSKangXi=130.12
26834 CJK UNIFIED IDEOGRAPH-#26834, IRGKangXi=0995.111, RSKangXi=130.12
26835 CJK UNIFIED IDEOGRAPH-#26835, IRGKangXi=0995.111, RSKangXi=130.12
26836 CJK UNIFIED IDEOGRAPH-#26836, IRGKangXi=0995.111, RSKangXi=130.12
26837 CJK UNIFIED IDEOGRAPH-#26837, IRGKangXi=0995.111, RSKangXi=130.12
26838 CJK UNIFIED IDEOGRAPH-#26838, IRGKangXi=0995.111, RSKangXi=130.12
26839 CJK UNIFIED IDEOGRAPH-#26839, IRGKangXi=0995.111, RSKangXi=130.12
2683A CJK UNIFIED IDEOGRAPH-#2683A, IRGKangXi=0995.111, RSKangXi=130.12
2683B CJK UNIFIED IDEOGRAPH-#2683B, IRGKangXi=0995.111, RSKangXi=130.12
2683C CJK UNIFIED IDEOGRAPH-#2683C, IRGKangXi=0995.111, RSKangXi=130.12
2683D CJK UNIFIED IDEOGRAPH-#2683D, IRGKangXi=0995.111, RSKangXi=130.12
2683E CJK UNIFIED IDEOGRAPH-#2683E, IRGKangXi=0995.220, RSKangXi=130.13
2683F CJK UNIFIED IDEOGRAPH-#2683F, IRGKangXi=0995.240, RSKangXi=130.13
26840 CJK UNIFIED IDEOGRAPH-#26840, IRGKangXi=0996.010, RSKangXi=130.13
26841 CJK UNIFIED IDEOGRAPH-#26841, IRGKangXi=0996.020, RSKangXi=130.13
26842 CJK UNIFIED IDEOGRAPH-#26842, IRGKangXi=0996.070, RSKangXi=130.13
26843 CJK UNIFIED IDEOGRAPH-#26843, IRGKangXi=0996.080, RSKangXi=130.13
26844 CJK UNIFIED IDEOGRAPH-#26844, IRGKangXi=0996.111, RSKangXi=130.12
26845 CJK UNIFIED IDEOGRAPH-#26845, IRGKangXi=0996.190, RSKangXi=130.13
26846 CJK UNIFIED IDEOGRAPH-#26846, IRGKangXi=0996.210, RSKangXi=130.13, Def{(Cant., vulg.) anus}
26847 CJK UNIFIED IDEOGRAPH-#26847, IRGKangXi=0996.220, RSKangXi=130.13
26848 CJK UNIFIED IDEOGRAPH-#26848, IRGKangXi=0996.240, RSKangXi=130.13
26849 CJK UNIFIED IDEOGRAPH-#26849, IRGKangXi=0996.241, RSKangXi=130.13
2684A CJK UNIFIED IDEOGRAPH-#2684A, IRGKangXi=0996.241, RSKangXi=130.13
2684B CJK UNIFIED IDEOGRAPH-#2684B, IRGKangXi=0996.241, RSKangXi=130.13
2684C CJK UNIFIED IDEOGRAPH-#2684C, IRGKangXi=0996.241, RSKangXi=130.13
2684D CJK UNIFIED IDEOGRAPH-#2684D, IRGKangXi=0996.241, RSKangXi=130.13
2684E CJK UNIFIED IDEOGRAPH-#2684E, IRGKangXi=0996.241, RSKangXi=130.14
2684F CJK UNIFIED IDEOGRAPH-#2684F, IRGKangXi=0996.241, RSKangXi=130.13
26850 CJK UNIFIED IDEOGRAPH-#26850, IRGKangXi=0996.241, RSKangXi=130.13
26851 CJK UNIFIED IDEOGRAPH-#26851, IRGKangXi=0996.241, RSKangXi=130.13
26852 CJK UNIFIED IDEOGRAPH-#26852, IRGKangXi=0996.241, RSKangXi=130.13
26853 CJK UNIFIED IDEOGRAPH-#26853, IRGKangXi=0996.241, RSKangXi=130.13
26854 CJK UNIFIED IDEOGRAPH-#26854, IRGKangXi=0996.241, RSKangXi=130.13
26855 CJK UNIFIED IDEOGRAPH-#26855, IRGKangXi=0996.241, RSKangXi=130.13
26856 CJK UNIFIED IDEOGRAPH-#26856, IRGKangXi=0996.241, RSKangXi=74.13
26857 CJK UNIFIED IDEOGRAPH-#26857, IRGKangXi=0996.241, RSKangXi=61.13
26858 CJK UNIFIED IDEOGRAPH-#26858, IRGKangXi=0996.241, RSKangXi=130.13
26859 CJK UNIFIED IDEOGRAPH-#26859, IRGKangXi=0996.241, RSKangXi=130.13
2685A CJK UNIFIED IDEOGRAPH-#2685A, IRGKangXi=0996.241, RSKangXi=130.13
2685B CJK UNIFIED IDEOGRAPH-#2685B, IRGKangXi=0996.241, RSKangXi=130.13
2685C CJK UNIFIED IDEOGRAPH-#2685C, IRGKangXi=0996.241, RSKangXi=130.13
2685D CJK UNIFIED IDEOGRAPH-#2685D, IRGKangXi=0996.241, RSKangXi=130.13
2685E CJK UNIFIED IDEOGRAPH-#2685E, IRGKangXi=0996.241, RSKangXi=130.13
2685F CJK UNIFIED IDEOGRAPH-#2685F, IRGKangXi=0996.241, RSKangXi=130.13
26860 CJK UNIFIED IDEOGRAPH-#26860, IRGKangXi=0996.241, RSKangXi=130.13
26861 CJK UNIFIED IDEOGRAPH-#26861, IRGKangXi=0996.241, RSKangXi=130.13
26862 CJK UNIFIED IDEOGRAPH-#26862, IRGKangXi=0996.241, RSKangXi=130.13
26863 CJK UNIFIED IDEOGRAPH-#26863, IRGKangXi=0996.241, RSKangXi=130.13
26864 CJK UNIFIED IDEOGRAPH-#26864, IRGKangXi=0996.241, RSKangXi=130.13
26865 CJK UNIFIED IDEOGRAPH-#26865, IRGKangXi=0996.241, RSKangXi=130.13
26866 CJK UNIFIED IDEOGRAPH-#26866, IRGKangXi=0996.241, RSKangXi=130.13
26867 CJK UNIFIED IDEOGRAPH-#26867, IRGKangXi=0996.241, RSKangXi=130.13
26868 CJK UNIFIED IDEOGRAPH-#26868, IRGKangXi=0996.241, RSKangXi=130.13
26869 CJK UNIFIED IDEOGRAPH-#26869, IRGKangXi=0996.241, RSKangXi=130.13
2686A CJK UNIFIED IDEOGRAPH-#2686A, IRGKangXi=0996.241, RSKangXi=130.13
2686B CJK UNIFIED IDEOGRAPH-#2686B, IRGKangXi=0996.241, RSKangXi=130.13
2686C CJK UNIFIED IDEOGRAPH-#2686C, IRGKangXi=0996.241, RSKangXi=130.13
2686D CJK UNIFIED IDEOGRAPH-#2686D, IRGKangXi=0996.241, RSKangXi=130.13
2686E CJK UNIFIED IDEOGRAPH-#2686E, IRGKangXi=0996.241, RSKangXi=130.12
2686F CJK UNIFIED IDEOGRAPH-#2686F, IRGKangXi=0996.241, RSKangXi=130.13
26870 CJK UNIFIED IDEOGRAPH-#26870, IRGKangXi=0996.260, RSKangXi=130.14
26871 CJK UNIFIED IDEOGRAPH-#26871, IRGKangXi=0996.270, RSKangXi=130.14
26872 CJK UNIFIED IDEOGRAPH-#26872, IRGKangXi=0996.280, RSKangXi=130.14
26873 CJK UNIFIED IDEOGRAPH-#26873, IRGKangXi=0996.290, RSKangXi=130.14
26874 CJK UNIFIED IDEOGRAPH-#26874, IRGKangXi=0997.010, RSKangXi=130.14
26875 CJK UNIFIED IDEOGRAPH-#26875, IRGKangXi=0997.040, RSKangXi=130.14
26876 CJK UNIFIED IDEOGRAPH-#26876, IRGKangXi=0997.050, RSKangXi=130.14
26877 CJK UNIFIED IDEOGRAPH-#26877, IRGKangXi=0997.060, RSKangXi=130.14
26878 CJK UNIFIED IDEOGRAPH-#26878, IRGKangXi=0997.070, RSKangXi=130.14
26879 CJK UNIFIED IDEOGRAPH-#26879, IRGKangXi=0997.110, RSKangXi=130.14
2687A CJK UNIFIED IDEOGRAPH-#2687A, IRGKangXi=0997.120, RSKangXi=130.14
2687B CJK UNIFIED IDEOGRAPH-#2687B, IRGKangXi=0997.140, RSKangXi=130.14
2687C CJK UNIFIED IDEOGRAPH-#2687C, IRGKangXi=0997.150, RSKangXi=130.14
2687D CJK UNIFIED IDEOGRAPH-#2687D, IRGKangXi=0997.160, RSKangXi=130.14
2687E CJK UNIFIED IDEOGRAPH-#2687E, IRGKangXi=0997.161, RSKangXi=130.14
2687F CJK UNIFIED IDEOGRAPH-#2687F, IRGKangXi=0997.161, RSKangXi=130.14
26880 CJK UNIFIED IDEOGRAPH-#26880, IRGKangXi=0997.161, RSKangXi=130.14
26881 CJK UNIFIED IDEOGRAPH-#26881, IRGKangXi=0997.161, RSKangXi=130.14
26882 CJK UNIFIED IDEOGRAPH-#26882, IRGKangXi=0997.161, RSKangXi=130.14
26883 CJK UNIFIED IDEOGRAPH-#26883, IRGKangXi=0997.161, RSKangXi=130.14
26884 CJK UNIFIED IDEOGRAPH-#26884, IRGKangXi=0997.161, RSKangXi=130.14
26885 CJK UNIFIED IDEOGRAPH-#26885, IRGKangXi=0997.161, RSKangXi=130.14
26886 CJK UNIFIED IDEOGRAPH-#26886, IRGKangXi=0997.161, RSKangXi=130.14
26887 CJK UNIFIED IDEOGRAPH-#26887, IRGKangXi=0997.161, RSKangXi=130.14
26888 CJK UNIFIED IDEOGRAPH-#26888, IRGKangXi=0997.161, RSKangXi=130.14
26889 CJK UNIFIED IDEOGRAPH-#26889, IRGKangXi=0997.161, RSKangXi=130.14
2688A CJK UNIFIED IDEOGRAPH-#2688A, IRGKangXi=0997.170, RSKangXi=130.15, Def{(Cant.) blister}
2688B CJK UNIFIED IDEOGRAPH-#2688B, IRGKangXi=0997.180, RSKangXi=130.15
2688C CJK UNIFIED IDEOGRAPH-#2688C, IRGKangXi=0997.190, RSKangXi=130.15, Def{an abortion, miscarriage}
2688D CJK UNIFIED IDEOGRAPH-#2688D, IRGKangXi=0997.200, RSKangXi=130.15
2688E CJK UNIFIED IDEOGRAPH-#2688E, IRGKangXi=0997.210, RSKangXi=130.15
2688F CJK UNIFIED IDEOGRAPH-#2688F, IRGKangXi=0997.260, RSKangXi=130.15
26890 CJK UNIFIED IDEOGRAPH-#26890, IRGKangXi=0997.310, RSKangXi=130.15
26891 CJK UNIFIED IDEOGRAPH-#26891, IRGKangXi=0998.010, RSKangXi=130.15
26892 CJK UNIFIED IDEOGRAPH-#26892, IRGKangXi=0998.020, RSKangXi=130.15
26893 CJK UNIFIED IDEOGRAPH-#26893, IRGKangXi=0998.021, RSKangXi=130.15, Def{(Cant.) mole on skin}
26894 CJK UNIFIED IDEOGRAPH-#26894, IRGKangXi=0998.021, RSKangXi=130.15
26895 CJK UNIFIED IDEOGRAPH-#26895, IRGKangXi=0998.021, RSKangXi=130.15
26896 CJK UNIFIED IDEOGRAPH-#26896, IRGKangXi=0998.021, RSKangXi=130.15
26897 CJK UNIFIED IDEOGRAPH-#26897, IRGKangXi=0998.021, RSKangXi=130.15
26898 CJK UNIFIED IDEOGRAPH-#26898, IRGKangXi=0998.021, RSKangXi=130.15
26899 CJK UNIFIED IDEOGRAPH-#26899, IRGKangXi=0998.021, RSKangXi=130.15
2689A CJK UNIFIED IDEOGRAPH-#2689A, IRGKangXi=0998.021, RSKangXi=130.15
2689B CJK UNIFIED IDEOGRAPH-#2689B, IRGKangXi=0998.021, RSKangXi=130.15
2689C CJK UNIFIED IDEOGRAPH-#2689C, IRGKangXi=0998.021, RSKangXi=130.15
2689D CJK UNIFIED IDEOGRAPH-#2689D, IRGKangXi=0998.021, RSKangXi=130.15
2689E CJK UNIFIED IDEOGRAPH-#2689E, IRGKangXi=0998.021, RSKangXi=130.15
2689F CJK UNIFIED IDEOGRAPH-#2689F, IRGKangXi=0998.021, RSKangXi=130.15
268A0 CJK UNIFIED IDEOGRAPH-#268A0, IRGKangXi=0998.021, RSKangXi=130.15
268A1 CJK UNIFIED IDEOGRAPH-#268A1, IRGKangXi=0998.021, RSKangXi=130.15
268A2 CJK UNIFIED IDEOGRAPH-#268A2, IRGKangXi=0998.021, RSKangXi=130.15
268A3 CJK UNIFIED IDEOGRAPH-#268A3, IRGKangXi=0998.021, RSKangXi=130.15
268A4 CJK UNIFIED IDEOGRAPH-#268A4, IRGKangXi=0998.021, RSKangXi=130.15
268A5 CJK UNIFIED IDEOGRAPH-#268A5, IRGKangXi=0998.050, RSKangXi=130.16
268A6 CJK UNIFIED IDEOGRAPH-#268A6, IRGKangXi=0998.060, RSKangXi=130.16
268A7 CJK UNIFIED IDEOGRAPH-#268A7, IRGKangXi=0998.070, RSKangXi=130.16
268A8 CJK UNIFIED IDEOGRAPH-#268A8, IRGKangXi=0998.080, RSKangXi=130.16
268A9 CJK UNIFIED IDEOGRAPH-#268A9, IRGKangXi=0998.100, RSKangXi=130.16
268AA CJK UNIFIED IDEOGRAPH-#268AA, IRGKangXi=0998.110, RSKangXi=130.16
268AB CJK UNIFIED IDEOGRAPH-#268AB, IRGKangXi=0998.140, RSKangXi=130.16
268AC CJK UNIFIED IDEOGRAPH-#268AC, IRGKangXi=0998.141, RSKangXi=130.16
268AD CJK UNIFIED IDEOGRAPH-#268AD, IRGKangXi=0998.141, RSKangXi=130.16
268AE CJK UNIFIED IDEOGRAPH-#268AE, IRGKangXi=0998.141, RSKangXi=130.16
268AF CJK UNIFIED IDEOGRAPH-#268AF, IRGKangXi=0998.141, RSKangXi=130.16
268B0 CJK UNIFIED IDEOGRAPH-#268B0, IRGKangXi=0998.141, RSKangXi=130.16
268B1 CJK UNIFIED IDEOGRAPH-#268B1, IRGKangXi=0998.141, RSKangXi=130.16
268B2 CJK UNIFIED IDEOGRAPH-#268B2, IRGKangXi=0998.141, RSKangXi=130.16
268B3 CJK UNIFIED IDEOGRAPH-#268B3, IRGKangXi=0998.141, RSKangXi=130.16
268B4 CJK UNIFIED IDEOGRAPH-#268B4, IRGKangXi=0998.141, RSKangXi=130.16
268B5 CJK UNIFIED IDEOGRAPH-#268B5, IRGKangXi=0998.141, RSKangXi=130.16
268B6 CJK UNIFIED IDEOGRAPH-#268B6, IRGKangXi=0998.141, RSKangXi=130.16
268B7 CJK UNIFIED IDEOGRAPH-#268B7, IRGKangXi=0998.141, RSKangXi=130.16
268B8 CJK UNIFIED IDEOGRAPH-#268B8, IRGKangXi=0998.210, RSKangXi=130.17
268B9 CJK UNIFIED IDEOGRAPH-#268B9, IRGKangXi=0998.220, RSKangXi=130.17
268BA CJK UNIFIED IDEOGRAPH-#268BA, IRGKangXi=0998.230, RSKangXi=130.17
268BB CJK UNIFIED IDEOGRAPH-#268BB, IRGKangXi=0998.240, RSKangXi=130.17
268BC CJK UNIFIED IDEOGRAPH-#268BC, IRGKangXi=0998.241, RSKangXi=130.17
268BD CJK UNIFIED IDEOGRAPH-#268BD, IRGKangXi=0998.241, RSKangXi=130.17
268BE CJK UNIFIED IDEOGRAPH-#268BE, IRGKangXi=0998.241, RSKangXi=130.17
268BF CJK UNIFIED IDEOGRAPH-#268BF, IRGKangXi=0998.250, RSKangXi=130.18
268C0 CJK UNIFIED IDEOGRAPH-#268C0, IRGKangXi=0998.260, RSKangXi=130.18
268C1 CJK UNIFIED IDEOGRAPH-#268C1, IRGKangXi=0998.300, RSKangXi=130.18
268C2 CJK UNIFIED IDEOGRAPH-#268C2, IRGKangXi=0998.301, RSKangXi=130.18
268C3 CJK UNIFIED IDEOGRAPH-#268C3, IRGKangXi=0998.301, RSKangXi=130.18
268C4 CJK UNIFIED IDEOGRAPH-#268C4, IRGKangXi=0998.301, RSKangXi=130.18
268C5 CJK UNIFIED IDEOGRAPH-#268C5, IRGKangXi=0998.301, RSKangXi=130.18
268C6 CJK UNIFIED IDEOGRAPH-#268C6, IRGKangXi=0999.010, RSKangXi=130.19
268C7 CJK UNIFIED IDEOGRAPH-#268C7, IRGKangXi=0999.020, RSKangXi=130.19, Def{(Cant.) buttocks}
268C8 CJK UNIFIED IDEOGRAPH-#268C8, IRGKangXi=0999.040, RSKangXi=130.19
268C9 CJK UNIFIED IDEOGRAPH-#268C9, IRGKangXi=0999.050, RSKangXi=130.19
268CA CJK UNIFIED IDEOGRAPH-#268CA, IRGKangXi=0999.060, RSKangXi=130.19
268CB CJK UNIFIED IDEOGRAPH-#268CB, IRGKangXi=0999.070, RSKangXi=130.19
268CC CJK UNIFIED IDEOGRAPH-#268CC, IRGKangXi=0999.071, RSKangXi=130.19
268CD CJK UNIFIED IDEOGRAPH-#268CD, IRGKangXi=0999.071, RSKangXi=130.19
268CE CJK UNIFIED IDEOGRAPH-#268CE, IRGKangXi=0999.071, RSKangXi=130.19
268CF CJK UNIFIED IDEOGRAPH-#268CF, IRGKangXi=0999.071, RSKangXi=130.19
268D0 CJK UNIFIED IDEOGRAPH-#268D0, IRGKangXi=0999.071, RSKangXi=130.19
268D1 CJK UNIFIED IDEOGRAPH-#268D1, IRGKangXi=0999.080, RSKangXi=130.20
268D2 CJK UNIFIED IDEOGRAPH-#268D2, IRGKangXi=0999.090, RSKangXi=130.20
268D3 CJK UNIFIED IDEOGRAPH-#268D3, IRGKangXi=0999.100, RSKangXi=130.20
268D4 CJK UNIFIED IDEOGRAPH-#268D4, IRGKangXi=0999.101, RSKangXi=130.20
268D5 CJK UNIFIED IDEOGRAPH-#268D5, IRGKangXi=0999.101, RSKangXi=130.20
268D6 CJK UNIFIED IDEOGRAPH-#268D6, IRGKangXi=0999.101, RSKangXi=130.21
268D7 CJK UNIFIED IDEOGRAPH-#268D7, IRGKangXi=0999.101, RSKangXi=130.21
268D8 CJK UNIFIED IDEOGRAPH-#268D8, IRGKangXi=0999.101, RSKangXi=130.22
268D9 CJK UNIFIED IDEOGRAPH-#268D9, IRGKangXi=0999.101, RSKangXi=130.22
268DA CJK UNIFIED IDEOGRAPH-#268DA, IRGKangXi=0999.101, RSKangXi=130.22
268DB CJK UNIFIED IDEOGRAPH-#268DB, IRGKangXi=0999.110, RSKangXi=130.23
268DC CJK UNIFIED IDEOGRAPH-#268DC, IRGKangXi=0999.120, RSKangXi=130.24
268DD CJK UNIFIED IDEOGRAPH-#268DD, IRGKangXi=0999.150, RSKangXi=131.0
268DE CJK UNIFIED IDEOGRAPH-#268DE, IRGKangXi=0999.151, RSKangXi=131.0
268DF CJK UNIFIED IDEOGRAPH-#268DF, IRGKangXi=0999.180, RSKangXi=131.3
268E0 CJK UNIFIED IDEOGRAPH-#268E0, IRGKangXi=0999.190, RSKangXi=131.4
268E1 CJK UNIFIED IDEOGRAPH-#268E1, IRGKangXi=0999.191, RSKangXi=131.4
268E2 CJK UNIFIED IDEOGRAPH-#268E2, IRGKangXi=0999.191, RSKangXi=131.4
268E3 CJK UNIFIED IDEOGRAPH-#268E3, IRGKangXi=0999.191, RSKangXi=131.4
268E4 CJK UNIFIED IDEOGRAPH-#268E4, IRGKangXi=0999.210, RSKangXi=131.5
268E5 CJK UNIFIED IDEOGRAPH-#268E5, IRGKangXi=0999.211, RSKangXi=131.5
268E6 CJK UNIFIED IDEOGRAPH-#268E6, IRGKangXi=0999.221, RSKangXi=131.6
268E7 CJK UNIFIED IDEOGRAPH-#268E7, IRGKangXi=0999.221, RSKangXi=131.6
268E8 CJK UNIFIED IDEOGRAPH-#268E8, IRGKangXi=0999.221, RSKangXi=131.6
268E9 CJK UNIFIED IDEOGRAPH-#268E9, IRGKangXi=0999.221, RSKangXi=131.6
268EA CJK UNIFIED IDEOGRAPH-#268EA, IRGKangXi=0999.231, RSKangXi=131.10
268EB CJK UNIFIED IDEOGRAPH-#268EB, IRGKangXi=0999.231, RSKangXi=131.8
268EC CJK UNIFIED IDEOGRAPH-#268EC, IRGKangXi=0999.231, RSKangXi=131.8
268ED CJK UNIFIED IDEOGRAPH-#268ED, IRGKangXi=0999.231, RSKangXi=131.9
268EE CJK UNIFIED IDEOGRAPH-#268EE, IRGKangXi=0999.231, RSKangXi=131.8
268EF CJK UNIFIED IDEOGRAPH-#268EF, IRGKangXi=0999.231, RSKangXi=131.9
268F0 CJK UNIFIED IDEOGRAPH-#268F0, IRGKangXi=1000.011, RSKangXi=131.11
268F1 CJK UNIFIED IDEOGRAPH-#268F1, IRGKangXi=1000.011, RSKangXi=131.11, Def{mysterious, occult}
268F2 CJK UNIFIED IDEOGRAPH-#268F2, IRGKangXi=1000.040, RSKangXi=131.12
268F3 CJK UNIFIED IDEOGRAPH-#268F3, IRGKangXi=1000.041, RSKangXi=131.12
268F4 CJK UNIFIED IDEOGRAPH-#268F4, IRGKangXi=1000.050, RSKangXi=131.15
268F5 CJK UNIFIED IDEOGRAPH-#268F5, IRGKangXi=1000.051, RSKangXi=131.15
268F6 CJK UNIFIED IDEOGRAPH-#268F6, IRGKangXi=1000.051, RSKangXi=131.16
268F7 CJK UNIFIED IDEOGRAPH-#268F7, IRGKangXi=1000.060, RSKangXi=131.23
268F8 CJK UNIFIED IDEOGRAPH-#268F8, IRGKangXi=1000.061, RSKangXi=131.25
268F9 CJK UNIFIED IDEOGRAPH-#268F9, IRGKangXi=1000.090, RSKangXi=132.0
268FA CJK UNIFIED IDEOGRAPH-#268FA, IRGKangXi=1000.100, RSKangXi=132.1
268FB CJK UNIFIED IDEOGRAPH-#268FB, IRGKangXi=1000.120, RSKangXi=132.1
268FC CJK UNIFIED IDEOGRAPH-#268FC, IRGKangXi=1000.121, RSKangXi=132.1
268FD CJK UNIFIED IDEOGRAPH-#268FD, IRGKangXi=1000.130, RSKangXi=132.2
268FE CJK UNIFIED IDEOGRAPH-#268FE, IRGKangXi=1000.140, RSKangXi=132.3
268FF CJK UNIFIED IDEOGRAPH-#268FF, IRGKangXi=1000.150, RSKangXi=132.3
26900 CJK UNIFIED IDEOGRAPH-#26900, IRGKangXi=1000.151, RSKangXi=132.3
26901 CJK UNIFIED IDEOGRAPH-#26901, IRGKangXi=1000.160, RSKangXi=132.4
26902 CJK UNIFIED IDEOGRAPH-#26902, IRGKangXi=1000.170, RSKangXi=132.4
26903 CJK UNIFIED IDEOGRAPH-#26903, IRGKangXi=1000.180, RSKangXi=132.4
26904 CJK UNIFIED IDEOGRAPH-#26904, IRGKangXi=1000.201, RSKangXi=132.4
26905 CJK UNIFIED IDEOGRAPH-#26905, IRGKangXi=1000.201, RSKangXi=132.4
26906 CJK UNIFIED IDEOGRAPH-#26906, IRGKangXi=1000.201, RSKangXi=132.4
26907 CJK UNIFIED IDEOGRAPH-#26907, IRGKangXi=1000.201, RSKangXi=132.4
26908 CJK UNIFIED IDEOGRAPH-#26908, IRGKangXi=1000.201, RSKangXi=132.4
26909 CJK UNIFIED IDEOGRAPH-#26909, IRGKangXi=1000.201, RSKangXi=132.4
2690A CJK UNIFIED IDEOGRAPH-#2690A, IRGKangXi=1000.201, RSKangXi=132.4
2690B CJK UNIFIED IDEOGRAPH-#2690B, IRGKangXi=1000.201, RSKangXi=132.4
2690C CJK UNIFIED IDEOGRAPH-#2690C, IRGKangXi=1000.210, RSKangXi=132.5
2690D CJK UNIFIED IDEOGRAPH-#2690D, IRGKangXi=1000.220, RSKangXi=132.5
2690E CJK UNIFIED IDEOGRAPH-#2690E, IRGKangXi=1000.221, RSKangXi=132.5, Def{a marsh, pool; high; the fifth month}
2690F CJK UNIFIED IDEOGRAPH-#2690F, IRGKangXi=1000.221, RSKangXi=132.5
26910 CJK UNIFIED IDEOGRAPH-#26910, IRGKangXi=1000.260, RSKangXi=132.6
26911 CJK UNIFIED IDEOGRAPH-#26911, IRGKangXi=1000.261, RSKangXi=132.6
26912 CJK UNIFIED IDEOGRAPH-#26912, IRGKangXi=1000.261, RSKangXi=132.6
26913 CJK UNIFIED IDEOGRAPH-#26913, IRGKangXi=1000.261, RSKangXi=132.6
26914 CJK UNIFIED IDEOGRAPH-#26914, IRGKangXi=1000.261, RSKangXi=132.7
26915 CJK UNIFIED IDEOGRAPH-#26915, IRGKangXi=1000.270, RSKangXi=132.8
26916 CJK UNIFIED IDEOGRAPH-#26916, IRGKangXi=1000.271, RSKangXi=132.8
26917 CJK UNIFIED IDEOGRAPH-#26917, IRGKangXi=1000.271, RSKangXi=132.8
26918 CJK UNIFIED IDEOGRAPH-#26918, IRGKangXi=1000.290, RSKangXi=132.9
26919 CJK UNIFIED IDEOGRAPH-#26919, IRGKangXi=1000.300, RSKangXi=132.9
2691A CJK UNIFIED IDEOGRAPH-#2691A, IRGKangXi=1000.310, RSKangXi=132.9
2691B CJK UNIFIED IDEOGRAPH-#2691B, IRGKangXi=1000.311, RSKangXi=132.9
2691C CJK UNIFIED IDEOGRAPH-#2691C, IRGKangXi=1000.311, RSKangXi=132.9
2691D CJK UNIFIED IDEOGRAPH-#2691D, IRGKangXi=1000.311, RSKangXi=132.9
2691E CJK UNIFIED IDEOGRAPH-#2691E, IRGKangXi=1001.010, RSKangXi=132.10
2691F CJK UNIFIED IDEOGRAPH-#2691F, IRGKangXi=1001.020, RSKangXi=132.10
26920 CJK UNIFIED IDEOGRAPH-#26920, IRGKangXi=1001.021, RSKangXi=132.10
26921 CJK UNIFIED IDEOGRAPH-#26921, IRGKangXi=1001.030, RSKangXi=132.11
26922 CJK UNIFIED IDEOGRAPH-#26922, IRGKangXi=1001.040, RSKangXi=132.11
26923 CJK UNIFIED IDEOGRAPH-#26923, IRGKangXi=1001.050, RSKangXi=132.11
26924 CJK UNIFIED IDEOGRAPH-#26924, IRGKangXi=1001.051, RSKangXi=132.11
26925 CJK UNIFIED IDEOGRAPH-#26925, IRGKangXi=1001.051, RSKangXi=132.12
26926 CJK UNIFIED IDEOGRAPH-#26926, IRGKangXi=1001.060, RSKangXi=132.13, Def{(Cant.) a smell, scent}
26927 CJK UNIFIED IDEOGRAPH-#26927, IRGKangXi=1001.070, RSKangXi=132.13
26928 CJK UNIFIED IDEOGRAPH-#26928, IRGKangXi=1001.080, RSKangXi=132.13
26929 CJK UNIFIED IDEOGRAPH-#26929, IRGKangXi=1001.081, RSKangXi=132.13
2692A CJK UNIFIED IDEOGRAPH-#2692A, IRGKangXi=1001.081, RSKangXi=132.13
2692B CJK UNIFIED IDEOGRAPH-#2692B, IRGKangXi=1001.090, RSKangXi=132.14
2692C CJK UNIFIED IDEOGRAPH-#2692C, IRGKangXi=1001.100, RSKangXi=132.14
2692D CJK UNIFIED IDEOGRAPH-#2692D, IRGKangXi=1001.101, RSKangXi=132.14
2692E CJK UNIFIED IDEOGRAPH-#2692E, IRGKangXi=1001.101, RSKangXi=132.14
2692F CJK UNIFIED IDEOGRAPH-#2692F, IRGKangXi=1001.101, RSKangXi=132.15
26930 CJK UNIFIED IDEOGRAPH-#26930, IRGKangXi=1001.101, RSKangXi=132.15
26931 CJK UNIFIED IDEOGRAPH-#26931, IRGKangXi=1001.101, RSKangXi=132.18
26932 CJK UNIFIED IDEOGRAPH-#26932, IRGKangXi=1001.101, RSKangXi=132.20
26933 CJK UNIFIED IDEOGRAPH-#26933, IRGKangXi=1001.160, RSKangXi=133.0
26934 CJK UNIFIED IDEOGRAPH-#26934, IRGKangXi=1001.170, RSKangXi=133.0
26935 CJK UNIFIED IDEOGRAPH-#26935, IRGKangXi=1001.180, RSKangXi=133.2
26936 CJK UNIFIED IDEOGRAPH-#26936, IRGKangXi=1001.190, RSKangXi=133.3
26937 CJK UNIFIED IDEOGRAPH-#26937, IRGKangXi=1001.191, RSKangXi=133.3
26938 CJK UNIFIED IDEOGRAPH-#26938, IRGKangXi=1001.191, RSKangXi=133.3
26939 CJK UNIFIED IDEOGRAPH-#26939, IRGKangXi=1001.200, RSKangXi=133.4
2693A CJK UNIFIED IDEOGRAPH-#2693A, IRGKangXi=1001.201, RSKangXi=133.4
2693B CJK UNIFIED IDEOGRAPH-#2693B, IRGKangXi=1001.210, RSKangXi=133.5
2693C CJK UNIFIED IDEOGRAPH-#2693C, IRGKangXi=1001.211, RSKangXi=133.5
2693D CJK UNIFIED IDEOGRAPH-#2693D, IRGKangXi=1001.211, RSKangXi=133.5
2693E CJK UNIFIED IDEOGRAPH-#2693E, IRGKangXi=1001.211, RSKangXi=133.5
2693F CJK UNIFIED IDEOGRAPH-#2693F, IRGKangXi=1001.230, RSKangXi=133.6
26940 CJK UNIFIED IDEOGRAPH-#26940, IRGKangXi=1002.021, RSKangXi=133.6
26941 CJK UNIFIED IDEOGRAPH-#26941, IRGKangXi=1002.041, RSKangXi=133.7
26942 CJK UNIFIED IDEOGRAPH-#26942, IRGKangXi=1002.080, RSKangXi=133.8
26943 CJK UNIFIED IDEOGRAPH-#26943, IRGKangXi=1002.081, RSKangXi=133.8
26944 CJK UNIFIED IDEOGRAPH-#26944, IRGKangXi=1002.081, RSKangXi=133.8
26945 CJK UNIFIED IDEOGRAPH-#26945, IRGKangXi=1002.090, RSKangXi=133.9
26946 CJK UNIFIED IDEOGRAPH-#26946, IRGKangXi=1002.100, RSKangXi=133.9
26947 CJK UNIFIED IDEOGRAPH-#26947, IRGKangXi=1002.101, RSKangXi=133.9
26948 CJK UNIFIED IDEOGRAPH-#26948, IRGKangXi=1002.101, RSKangXi=32.11
26949 CJK UNIFIED IDEOGRAPH-#26949, IRGKangXi=1002.120, RSKangXi=133.10
2694A CJK UNIFIED IDEOGRAPH-#2694A, IRGKangXi=1002.130, RSKangXi=133.10
2694B CJK UNIFIED IDEOGRAPH-#2694B, IRGKangXi=1002.140, RSKangXi=133.10
2694C CJK UNIFIED IDEOGRAPH-#2694C, IRGKangXi=1002.141, RSKangXi=133.10
2694D CJK UNIFIED IDEOGRAPH-#2694D, IRGKangXi=1002.141, RSKangXi=133.10
2694E CJK UNIFIED IDEOGRAPH-#2694E, IRGKangXi=1002.150, RSKangXi=133.11
2694F CJK UNIFIED IDEOGRAPH-#2694F, IRGKangXi=1002.160, RSKangXi=133.12
26950 CJK UNIFIED IDEOGRAPH-#26950, IRGKangXi=1002.170, RSKangXi=133.12
26951 CJK UNIFIED IDEOGRAPH-#26951, IRGKangXi=1003.020, RSKangXi=134.0
26952 CJK UNIFIED IDEOGRAPH-#26952, IRGKangXi=1003.030, RSKangXi=134.0
26953 CJK UNIFIED IDEOGRAPH-#26953, IRGKangXi=1003.031, RSKangXi=134.0
26954 CJK UNIFIED IDEOGRAPH-#26954, IRGKangXi=1003.031, RSKangXi=134.1
26955 CJK UNIFIED IDEOGRAPH-#26955, IRGKangXi=1003.051, RSKangXi=134.2
26956 CJK UNIFIED IDEOGRAPH-#26956, IRGKangXi=1003.051, RSKangXi=134.2
26957 CJK UNIFIED IDEOGRAPH-#26957, IRGKangXi=1003.061, RSKangXi=134.3
26958 CJK UNIFIED IDEOGRAPH-#26958, IRGKangXi=1003.070, RSKangXi=134.3
26959 CJK UNIFIED IDEOGRAPH-#26959, IRGKangXi=1003.071, RSKangXi=134.2
2695A CJK UNIFIED IDEOGRAPH-#2695A, IRGKangXi=1003.071, RSKangXi=134.3
2695B CJK UNIFIED IDEOGRAPH-#2695B, IRGKangXi=1003.071, RSKangXi=134.3
2695C CJK UNIFIED IDEOGRAPH-#2695C, IRGKangXi=1003.071, RSKangXi=134.3
2695D CJK UNIFIED IDEOGRAPH-#2695D, IRGKangXi=1003.080, RSKangXi=134.4
2695E CJK UNIFIED IDEOGRAPH-#2695E, IRGKangXi=1003.120, RSKangXi=134.4
2695F CJK UNIFIED IDEOGRAPH-#2695F, IRGKangXi=1003.150, RSKangXi=134.4
26960 CJK UNIFIED IDEOGRAPH-#26960, IRGKangXi=1003.160, RSKangXi=134.4
26961 CJK UNIFIED IDEOGRAPH-#26961, IRGKangXi=1003.170, RSKangXi=134.4
26962 CJK UNIFIED IDEOGRAPH-#26962, IRGKangXi=1003.171, RSKangXi=134.4
26963 CJK UNIFIED IDEOGRAPH-#26963, IRGKangXi=1003.171, RSKangXi=134.4
26964 CJK UNIFIED IDEOGRAPH-#26964, IRGKangXi=1003.171, RSKangXi=134.4
26965 CJK UNIFIED IDEOGRAPH-#26965, IRGKangXi=1003.180, RSKangXi=134.5
26966 CJK UNIFIED IDEOGRAPH-#26966, IRGKangXi=1003.190, RSKangXi=134.5
26967 CJK UNIFIED IDEOGRAPH-#26967, IRGKangXi=1004.010, RSKangXi=134.5
26968 CJK UNIFIED IDEOGRAPH-#26968, IRGKangXi=1004.020, RSKangXi=134.5
26969 CJK UNIFIED IDEOGRAPH-#26969, IRGKangXi=1004.030, RSKangXi=134.5
2696A CJK UNIFIED IDEOGRAPH-#2696A, IRGKangXi=1004.040, RSKangXi=134.5
2696B CJK UNIFIED IDEOGRAPH-#2696B, IRGKangXi=1004.041, RSKangXi=134.5
2696C CJK UNIFIED IDEOGRAPH-#2696C, IRGKangXi=1004.041, RSKangXi=134.5
2696D CJK UNIFIED IDEOGRAPH-#2696D, IRGKangXi=1004.050, RSKangXi=134.6
2696E CJK UNIFIED IDEOGRAPH-#2696E, IRGKangXi=1004.070, RSKangXi=134.6
2696F CJK UNIFIED IDEOGRAPH-#2696F, IRGKangXi=1004.071, RSKangXi=134.6, Def{to learn}
26970 CJK UNIFIED IDEOGRAPH-#26970, IRGKangXi=1004.071, RSKangXi=134.6
26971 CJK UNIFIED IDEOGRAPH-#26971, IRGKangXi=1004.071, RSKangXi=134.6
26972 CJK UNIFIED IDEOGRAPH-#26972, IRGKangXi=1004.071, RSKangXi=134.6
26973 CJK UNIFIED IDEOGRAPH-#26973, IRGKangXi=1004.080, RSKangXi=134.7
26974 CJK UNIFIED IDEOGRAPH-#26974, IRGKangXi=1004.100, RSKangXi=134.7
26975 CJK UNIFIED IDEOGRAPH-#26975, IRGKangXi=1004.110, RSKangXi=134.7
26976 CJK UNIFIED IDEOGRAPH-#26976, IRGKangXi=1004.120, RSKangXi=134.7
26977 CJK UNIFIED IDEOGRAPH-#26977, IRGKangXi=1004.121, RSKangXi=134.7
26978 CJK UNIFIED IDEOGRAPH-#26978, IRGKangXi=1004.121, RSKangXi=134.7
26979 CJK UNIFIED IDEOGRAPH-#26979, IRGKangXi=1004.121, RSKangXi=134.7
2697A CJK UNIFIED IDEOGRAPH-#2697A, IRGKangXi=1004.121, RSKangXi=134.7
2697B CJK UNIFIED IDEOGRAPH-#2697B, IRGKangXi=1005.010, RSKangXi=134.8
2697C CJK UNIFIED IDEOGRAPH-#2697C, IRGKangXi=1005.020, RSKangXi=134.8
2697D CJK UNIFIED IDEOGRAPH-#2697D, IRGKangXi=1005.021, RSKangXi=134.8
2697E CJK UNIFIED IDEOGRAPH-#2697E, IRGKangXi=1005.021, RSKangXi=134.8
2697F CJK UNIFIED IDEOGRAPH-#2697F, IRGKangXi=1005.021, RSKangXi=134.8
26980 CJK UNIFIED IDEOGRAPH-#26980, IRGKangXi=1005.021, RSKangXi=134.8
26981 CJK UNIFIED IDEOGRAPH-#26981, IRGKangXi=1005.021, RSKangXi=134.8
26982 CJK UNIFIED IDEOGRAPH-#26982, IRGKangXi=1005.021, RSKangXi=134.8
26983 CJK UNIFIED IDEOGRAPH-#26983, IRGKangXi=1005.021, RSKangXi=134.8
26984 CJK UNIFIED IDEOGRAPH-#26984, IRGKangXi=1005.021, RSKangXi=134.8
26985 CJK UNIFIED IDEOGRAPH-#26985, IRGKangXi=1005.040, RSKangXi=134.9
26986 CJK UNIFIED IDEOGRAPH-#26986, IRGKangXi=1005.060, RSKangXi=134.9
26987 CJK UNIFIED IDEOGRAPH-#26987, IRGKangXi=1005.070, RSKangXi=134.9
26988 CJK UNIFIED IDEOGRAPH-#26988, IRGKangXi=1005.080, RSKangXi=134.9
26989 CJK UNIFIED IDEOGRAPH-#26989, IRGKangXi=1005.090, RSKangXi=134.9
2698A CJK UNIFIED IDEOGRAPH-#2698A, IRGKangXi=1005.091, RSKangXi=134.9
2698B CJK UNIFIED IDEOGRAPH-#2698B, IRGKangXi=1005.091, RSKangXi=134.9
2698C CJK UNIFIED IDEOGRAPH-#2698C, IRGKangXi=1005.091, RSKangXi=134.9
2698D CJK UNIFIED IDEOGRAPH-#2698D, IRGKangXi=1005.091, RSKangXi=134.9
2698E CJK UNIFIED IDEOGRAPH-#2698E, IRGKangXi=1005.091, RSKangXi=134.9
2698F CJK UNIFIED IDEOGRAPH-#2698F, IRGKangXi=1005.110, RSKangXi=134.10
26990 CJK UNIFIED IDEOGRAPH-#26990, IRGKangXi=1005.120, RSKangXi=134.10
26991 CJK UNIFIED IDEOGRAPH-#26991, IRGKangXi=1005.130, RSKangXi=134.10
26992 CJK UNIFIED IDEOGRAPH-#26992, IRGKangXi=1005.131, RSKangXi=134.10
26993 CJK UNIFIED IDEOGRAPH-#26993, IRGKangXi=1005.131, RSKangXi=134.10
26994 CJK UNIFIED IDEOGRAPH-#26994, IRGKangXi=1005.131, RSKangXi=114.11
26995 CJK UNIFIED IDEOGRAPH-#26995, IRGKangXi=1005.131, RSKangXi=134.10
26996 CJK UNIFIED IDEOGRAPH-#26996, IRGKangXi=1005.131, RSKangXi=134.10
26997 CJK UNIFIED IDEOGRAPH-#26997, IRGKangXi=1005.131, RSKangXi=134.10
26998 CJK UNIFIED IDEOGRAPH-#26998, IRGKangXi=1005.140, RSKangXi=134.11
26999 CJK UNIFIED IDEOGRAPH-#26999, IRGKangXi=1005.150, RSKangXi=134.11, Def{variant of 挙 U+6319, to raise, lift up; to recommend}
2699A CJK UNIFIED IDEOGRAPH-#2699A, IRGKangXi=1005.180, RSKangXi=134.11
2699B CJK UNIFIED IDEOGRAPH-#2699B, IRGKangXi=1005.181, RSKangXi=134.11
2699C CJK UNIFIED IDEOGRAPH-#2699C, IRGKangXi=1005.181, RSKangXi=134.11
2699D CJK UNIFIED IDEOGRAPH-#2699D, IRGKangXi=1005.181, RSKangXi=134.11
2699E CJK UNIFIED IDEOGRAPH-#2699E, IRGKangXi=1005.181, RSKangXi=134.11
2699F CJK UNIFIED IDEOGRAPH-#2699F, IRGKangXi=1005.181, RSKangXi=134.11
269A0 CJK UNIFIED IDEOGRAPH-#269A0, IRGKangXi=1005.181, RSKangXi=134.11
269A1 CJK UNIFIED IDEOGRAPH-#269A1, IRGKangXi=1005.190, RSKangXi=134.12
269A2 CJK UNIFIED IDEOGRAPH-#269A2, IRGKangXi=1005.200, RSKangXi=134.12
269A3 CJK UNIFIED IDEOGRAPH-#269A3, IRGKangXi=1005.210, RSKangXi=134.12
269A4 CJK UNIFIED IDEOGRAPH-#269A4, IRGKangXi=1006.020, RSKangXi=134.12
269A5 CJK UNIFIED IDEOGRAPH-#269A5, IRGKangXi=1006.030, RSKangXi=134.12
269A6 CJK UNIFIED IDEOGRAPH-#269A6, IRGKangXi=1006.040, RSKangXi=134.12
269A7 CJK UNIFIED IDEOGRAPH-#269A7, IRGKangXi=1006.050, RSKangXi=134.12
269A8 CJK UNIFIED IDEOGRAPH-#269A8, IRGKangXi=1006.051, RSKangXi=86.14
269A9 CJK UNIFIED IDEOGRAPH-#269A9, IRGKangXi=1006.070, RSKangXi=134.13
269AA CJK UNIFIED IDEOGRAPH-#269AA, IRGKangXi=1006.080, RSKangXi=134.13
269AB CJK UNIFIED IDEOGRAPH-#269AB, IRGKangXi=1006.090, RSKangXi=134.13
269AC CJK UNIFIED IDEOGRAPH-#269AC, IRGKangXi=1006.100, RSKangXi=134.13
269AD CJK UNIFIED IDEOGRAPH-#269AD, IRGKangXi=1006.101, RSKangXi=134.14
269AE CJK UNIFIED IDEOGRAPH-#269AE, IRGKangXi=1006.101, RSKangXi=134.14
269AF CJK UNIFIED IDEOGRAPH-#269AF, IRGKangXi=1006.101, RSKangXi=134.13
269B0 CJK UNIFIED IDEOGRAPH-#269B0, IRGKangXi=1006.110, RSKangXi=134.14
269B1 CJK UNIFIED IDEOGRAPH-#269B1, IRGKangXi=1006.120, RSKangXi=134.14
269B2 CJK UNIFIED IDEOGRAPH-#269B2, IRGKangXi=1006.130, RSKangXi=134.14
269B3 CJK UNIFIED IDEOGRAPH-#269B3, IRGKangXi=1006.131, RSKangXi=134.14
269B4 CJK UNIFIED IDEOGRAPH-#269B4, IRGKangXi=1006.131, RSKangXi=134.14
269B5 CJK UNIFIED IDEOGRAPH-#269B5, IRGKangXi=1006.131, RSKangXi=134.14
269B6 CJK UNIFIED IDEOGRAPH-#269B6, IRGKangXi=1006.140, RSKangXi=134.15
269B7 CJK UNIFIED IDEOGRAPH-#269B7, IRGKangXi=1006.141, RSKangXi=134.15
269B8 CJK UNIFIED IDEOGRAPH-#269B8, IRGKangXi=1006.141, RSKangXi=134.15
269B9 CJK UNIFIED IDEOGRAPH-#269B9, IRGKangXi=1006.141, RSKangXi=134.16
269BA CJK UNIFIED IDEOGRAPH-#269BA, IRGKangXi=1006.150, RSKangXi=134.17
269BB CJK UNIFIED IDEOGRAPH-#269BB, IRGKangXi=1006.151, RSKangXi=134.17
269BC CJK UNIFIED IDEOGRAPH-#269BC, IRGKangXi=1006.160, RSKangXi=134.18
269BD CJK UNIFIED IDEOGRAPH-#269BD, IRGKangXi=1006.170, RSKangXi=134.19
269BE CJK UNIFIED IDEOGRAPH-#269BE, IRGKangXi=1006.180, RSKangXi=134.19
269BF CJK UNIFIED IDEOGRAPH-#269BF, IRGKangXi=1006.181, RSKangXi=134.19
269C0 CJK UNIFIED IDEOGRAPH-#269C0, IRGKangXi=1006.181, RSKangXi=134.20
269C1 CJK UNIFIED IDEOGRAPH-#269C1, IRGKangXi=1006.190, RSKangXi=134.21
269C2 CJK UNIFIED IDEOGRAPH-#269C2, IRGKangXi=1006.200, RSKangXi=134.21
269C3 CJK UNIFIED IDEOGRAPH-#269C3, IRGKangXi=1006.201, RSKangXi=134.24
269C4 CJK UNIFIED IDEOGRAPH-#269C4, IRGKangXi=1006.210, RSKangXi=134.36
269C5 CJK UNIFIED IDEOGRAPH-#269C5, IRGKangXi=1006.211, RSKangXi=134.42
269C6 CJK UNIFIED IDEOGRAPH-#269C6, IRGKangXi=1006.221, RSKangXi=135.1
269C7 CJK UNIFIED IDEOGRAPH-#269C7, IRGKangXi=1007.010, RSKangXi=135.3
269C8 CJK UNIFIED IDEOGRAPH-#269C8, IRGKangXi=1007.020, RSKangXi=135.4
269C9 CJK UNIFIED IDEOGRAPH-#269C9, IRGKangXi=1007.040, RSKangXi=135.4
269CA CJK UNIFIED IDEOGRAPH-#269CA, IRGKangXi=1007.060, RSKangXi=135.4
269CB CJK UNIFIED IDEOGRAPH-#269CB, IRGKangXi=1007.071, RSKangXi=135.4
269CC CJK UNIFIED IDEOGRAPH-#269CC, IRGKangXi=1007.071, RSKangXi=135.4
269CD CJK UNIFIED IDEOGRAPH-#269CD, IRGKangXi=1007.071, RSKangXi=135.4
269CE CJK UNIFIED IDEOGRAPH-#269CE, IRGKangXi=1007.071, RSKangXi=135.4
269CF CJK UNIFIED IDEOGRAPH-#269CF, IRGKangXi=1007.071, RSKangXi=135.4
269D0 CJK UNIFIED IDEOGRAPH-#269D0, IRGKangXi=1007.071, RSKangXi=135.4
269D1 CJK UNIFIED IDEOGRAPH-#269D1, IRGKangXi=1007.081, RSKangXi=135.5
269D2 CJK UNIFIED IDEOGRAPH-#269D2, IRGKangXi=1007.081, RSKangXi=135.5
269D3 CJK UNIFIED IDEOGRAPH-#269D3, IRGKangXi=1007.081, RSKangXi=135.5
269D4 CJK UNIFIED IDEOGRAPH-#269D4, IRGKangXi=1007.081, RSKangXi=135.5
269D5 CJK UNIFIED IDEOGRAPH-#269D5, IRGKangXi=1007.090, RSKangXi=135.6
269D6 CJK UNIFIED IDEOGRAPH-#269D6, IRGKangXi=1007.100, RSKangXi=135.6
269D7 CJK UNIFIED IDEOGRAPH-#269D7, IRGKangXi=1007.120, RSKangXi=135.6
269D8 CJK UNIFIED IDEOGRAPH-#269D8, IRGKangXi=1007.121, RSKangXi=135.6
269D9 CJK UNIFIED IDEOGRAPH-#269D9, IRGKangXi=1007.121, RSKangXi=135.6
269DA CJK UNIFIED IDEOGRAPH-#269DA, IRGKangXi=1007.121, RSKangXi=135.6
269DB CJK UNIFIED IDEOGRAPH-#269DB, IRGKangXi=1007.121, RSKangXi=135.6
269DC CJK UNIFIED IDEOGRAPH-#269DC, IRGKangXi=1007.121, RSKangXi=135.6
269DD CJK UNIFIED IDEOGRAPH-#269DD, IRGKangXi=1007.130, RSKangXi=135.7
269DE CJK UNIFIED IDEOGRAPH-#269DE, IRGKangXi=1007.141, RSKangXi=135.7
269DF CJK UNIFIED IDEOGRAPH-#269DF, IRGKangXi=1007.150, RSKangXi=135.8
269E0 CJK UNIFIED IDEOGRAPH-#269E0, IRGKangXi=1007.170, RSKangXi=135.8
269E1 CJK UNIFIED IDEOGRAPH-#269E1, IRGKangXi=1007.190, RSKangXi=135.8
269E2 CJK UNIFIED IDEOGRAPH-#269E2, IRGKangXi=1007.200, RSKangXi=135.8
269E3 CJK UNIFIED IDEOGRAPH-#269E3, IRGKangXi=1007.201, RSKangXi=135.8
269E4 CJK UNIFIED IDEOGRAPH-#269E4, IRGKangXi=1007.201, RSKangXi=135.8
269E5 CJK UNIFIED IDEOGRAPH-#269E5, IRGKangXi=1007.201, RSKangXi=135.8
269E6 CJK UNIFIED IDEOGRAPH-#269E6, IRGKangXi=1007.201, RSKangXi=135.8
269E7 CJK UNIFIED IDEOGRAPH-#269E7, IRGKangXi=1007.210, RSKangXi=135.9
269E8 CJK UNIFIED IDEOGRAPH-#269E8, IRGKangXi=1007.221, RSKangXi=135.9
269E9 CJK UNIFIED IDEOGRAPH-#269E9, IRGKangXi=1007.221, RSKangXi=135.9
269EA CJK UNIFIED IDEOGRAPH-#269EA, IRGKangXi=1007.221, RSKangXi=135.9
269EB CJK UNIFIED IDEOGRAPH-#269EB, IRGKangXi=1007.221, RSKangXi=135.9
269EC CJK UNIFIED IDEOGRAPH-#269EC, IRGKangXi=1007.221, RSKangXi=135.9
269ED CJK UNIFIED IDEOGRAPH-#269ED, IRGKangXi=1007.230, RSKangXi=135.10
269EE CJK UNIFIED IDEOGRAPH-#269EE, IRGKangXi=1007.240, RSKangXi=135.10
269EF CJK UNIFIED IDEOGRAPH-#269EF, IRGKangXi=1007.251, RSKangXi=135.10
269F0 CJK UNIFIED IDEOGRAPH-#269F0, IRGKangXi=1007.251, RSKangXi=135.10
269F1 CJK UNIFIED IDEOGRAPH-#269F1, IRGKangXi=1008.010, RSKangXi=135.11
269F2 CJK UNIFIED IDEOGRAPH-#269F2, IRGKangXi=1008.011, RSKangXi=135.11, Def{(Cant.) to dribble, spit; to pester, nag}
269F3 CJK UNIFIED IDEOGRAPH-#269F3, IRGKangXi=1008.011, RSKangXi=135.11
269F4 CJK UNIFIED IDEOGRAPH-#269F4, IRGKangXi=1008.020, RSKangXi=135.12
269F5 CJK UNIFIED IDEOGRAPH-#269F5, IRGKangXi=1008.040, RSKangXi=135.12
269F6 CJK UNIFIED IDEOGRAPH-#269F6, IRGKangXi=1008.041, RSKangXi=135.12
269F7 CJK UNIFIED IDEOGRAPH-#269F7, IRGKangXi=1008.051, RSKangXi=135.13
269F8 CJK UNIFIED IDEOGRAPH-#269F8, IRGKangXi=1008.051, RSKangXi=135.14
269F9 CJK UNIFIED IDEOGRAPH-#269F9, IRGKangXi=1008.060, RSKangXi=135.15
269FA CJK UNIFIED IDEOGRAPH-#269FA, IRGKangXi=1008.061, RSKangXi=135.16, Def{(Cant.) to lick, lap up}
269FB CJK UNIFIED IDEOGRAPH-#269FB, IRGKangXi=1008.070, RSKangXi=135.17
269FC CJK UNIFIED IDEOGRAPH-#269FC, IRGKangXi=1008.080, RSKangXi=135.17
269FD CJK UNIFIED IDEOGRAPH-#269FD, IRGKangXi=1008.081, RSKangXi=135.20
269FE CJK UNIFIED IDEOGRAPH-#269FE, IRGKangXi=1008.181, RSKangXi=136.9
269FF CJK UNIFIED IDEOGRAPH-#269FF, IRGKangXi=1008.181, RSKangXi=136.9
26A00 CJK UNIFIED IDEOGRAPH-#26A00, IRGKangXi=1008.191, RSKangXi=136.12
26A01 CJK UNIFIED IDEOGRAPH-#26A01, IRGKangXi=1008.200, RSKangXi=136.14
26A02 CJK UNIFIED IDEOGRAPH-#26A02, IRGKangXi=1008.211, RSKangXi=136.17
26A03 CJK UNIFIED IDEOGRAPH-#26A03, IRGKangXi=1008.211, RSKangXi=136.16
26A04 CJK UNIFIED IDEOGRAPH-#26A04, IRGKangXi=1008.220, RSKangXi=136.18
26A05 CJK UNIFIED IDEOGRAPH-#26A05, IRGKangXi=1008.221, RSKangXi=136.19
26A06 CJK UNIFIED IDEOGRAPH-#26A06, IRGKangXi=1008.230, RSKangXi=136.21
26A07 CJK UNIFIED IDEOGRAPH-#26A07, IRGKangXi=1009.010, RSKangXi=137.1
26A08 CJK UNIFIED IDEOGRAPH-#26A08, IRGKangXi=1009.030, RSKangXi=137.2
26A09 CJK UNIFIED IDEOGRAPH-#26A09, IRGKangXi=1009.040, RSKangXi=137.2
26A0A CJK UNIFIED IDEOGRAPH-#26A0A, IRGKangXi=1009.051, RSKangXi=137.2
26A0B CJK UNIFIED IDEOGRAPH-#26A0B, IRGKangXi=1009.051, RSKangXi=137.2
26A0C CJK UNIFIED IDEOGRAPH-#26A0C, IRGKangXi=1009.051, RSKangXi=137.2
26A0D CJK UNIFIED IDEOGRAPH-#26A0D, IRGKangXi=1009.051, RSKangXi=137.2
26A0E CJK UNIFIED IDEOGRAPH-#26A0E, IRGKangXi=1009.100, RSKangXi=137.3
26A0F CJK UNIFIED IDEOGRAPH-#26A0F, IRGKangXi=1009.110, RSKangXi=137.3
26A10 CJK UNIFIED IDEOGRAPH-#26A10, IRGKangXi=1009.120, RSKangXi=137.3
26A11 CJK UNIFIED IDEOGRAPH-#26A11, IRGKangXi=1009.121, RSKangXi=137.3
26A12 CJK UNIFIED IDEOGRAPH-#26A12, IRGKangXi=1009.121, RSKangXi=137.3
26A13 CJK UNIFIED IDEOGRAPH-#26A13, IRGKangXi=1009.121, RSKangXi=137.3
26A14 CJK UNIFIED IDEOGRAPH-#26A14, IRGKangXi=1009.121, RSKangXi=137.3
26A15 CJK UNIFIED IDEOGRAPH-#26A15, IRGKangXi=1009.130, RSKangXi=137.4
26A16 CJK UNIFIED IDEOGRAPH-#26A16, IRGKangXi=1009.150, RSKangXi=137.4
26A17 CJK UNIFIED IDEOGRAPH-#26A17, IRGKangXi=1009.160, RSKangXi=137.4
26A18 CJK UNIFIED IDEOGRAPH-#26A18, IRGKangXi=1009.170, RSKangXi=137.4
26A19 CJK UNIFIED IDEOGRAPH-#26A19, IRGKangXi=1009.180, RSKangXi=137.4
26A1A CJK UNIFIED IDEOGRAPH-#26A1A, IRGKangXi=1009.200, RSKangXi=137.4
26A1B CJK UNIFIED IDEOGRAPH-#26A1B, IRGKangXi=1009.250, RSKangXi=137.4
26A1C CJK UNIFIED IDEOGRAPH-#26A1C, IRGKangXi=1009.290, RSKangXi=137.4
26A1D CJK UNIFIED IDEOGRAPH-#26A1D, IRGKangXi=1010.010, RSKangXi=137.4
26A1E CJK UNIFIED IDEOGRAPH-#26A1E, IRGKangXi=1010.021, RSKangXi=137.4
26A1F CJK UNIFIED IDEOGRAPH-#26A1F, IRGKangXi=1010.021, RSKangXi=137.4
26A20 CJK UNIFIED IDEOGRAPH-#26A20, IRGKangXi=1010.021, RSKangXi=137.4
26A21 CJK UNIFIED IDEOGRAPH-#26A21, IRGKangXi=1010.060, RSKangXi=137.5
26A22 CJK UNIFIED IDEOGRAPH-#26A22, IRGKangXi=1010.090, RSKangXi=137.5
26A23 CJK UNIFIED IDEOGRAPH-#26A23, IRGKangXi=1010.150, RSKangXi=137.5
26A24 CJK UNIFIED IDEOGRAPH-#26A24, IRGKangXi=1010.160, RSKangXi=137.5
26A25 CJK UNIFIED IDEOGRAPH-#26A25, IRGKangXi=1010.180, RSKangXi=137.5
26A26 CJK UNIFIED IDEOGRAPH-#26A26, IRGKangXi=1010.190, RSKangXi=137.5
26A27 CJK UNIFIED IDEOGRAPH-#26A27, IRGKangXi=1010.200, RSKangXi=137.5
26A28 CJK UNIFIED IDEOGRAPH-#26A28, IRGKangXi=1010.220, RSKangXi=137.5
26A29 CJK UNIFIED IDEOGRAPH-#26A29, IRGKangXi=1010.221, RSKangXi=137.5
26A2A CJK UNIFIED IDEOGRAPH-#26A2A, IRGKangXi=1010.221, RSKangXi=137.5
26A2B CJK UNIFIED IDEOGRAPH-#26A2B, IRGKangXi=1010.221, RSKangXi=137.5
26A2C CJK UNIFIED IDEOGRAPH-#26A2C, IRGKangXi=1010.221, RSKangXi=137.5
26A2D CJK UNIFIED IDEOGRAPH-#26A2D, IRGKangXi=1010.221, RSKangXi=137.5
26A2E CJK UNIFIED IDEOGRAPH-#26A2E, IRGKangXi=1010.221, RSKangXi=137.5
26A2F CJK UNIFIED IDEOGRAPH-#26A2F, IRGKangXi=1010.230, RSKangXi=137.6
26A30 CJK UNIFIED IDEOGRAPH-#26A30, IRGKangXi=1010.250, RSKangXi=137.6
26A31 CJK UNIFIED IDEOGRAPH-#26A31, IRGKangXi=1010.260, RSKangXi=137.6
26A32 CJK UNIFIED IDEOGRAPH-#26A32, IRGKangXi=1010.270, RSKangXi=137.6
26A33 CJK UNIFIED IDEOGRAPH-#26A33, IRGKangXi=1010.300, RSKangXi=137.7
26A34 CJK UNIFIED IDEOGRAPH-#26A34, IRGKangXi=1010.320, RSKangXi=137.6
26A35 CJK UNIFIED IDEOGRAPH-#26A35, IRGKangXi=1010.330, RSKangXi=137.6
26A36 CJK UNIFIED IDEOGRAPH-#26A36, IRGKangXi=1010.350, RSKangXi=137.6
26A37 CJK UNIFIED IDEOGRAPH-#26A37, IRGKangXi=1010.351, RSKangXi=137.6
26A38 CJK UNIFIED IDEOGRAPH-#26A38, IRGKangXi=1010.351, RSKangXi=137.6
26A39 CJK UNIFIED IDEOGRAPH-#26A39, IRGKangXi=1010.351, RSKangXi=137.6
26A3A CJK UNIFIED IDEOGRAPH-#26A3A, IRGKangXi=1010.351, RSKangXi=137.6
26A3B CJK UNIFIED IDEOGRAPH-#26A3B, IRGKangXi=1010.351, RSKangXi=137.6
26A3C CJK UNIFIED IDEOGRAPH-#26A3C, IRGKangXi=1010.351, RSKangXi=137.6
26A3D CJK UNIFIED IDEOGRAPH-#26A3D, IRGKangXi=1011.050, RSKangXi=137.7
26A3E CJK UNIFIED IDEOGRAPH-#26A3E, IRGKangXi=1011.110, RSKangXi=137.7
26A3F CJK UNIFIED IDEOGRAPH-#26A3F, IRGKangXi=1011.120, RSKangXi=137.7
26A40 CJK UNIFIED IDEOGRAPH-#26A40, IRGKangXi=1011.121, RSKangXi=137.7
26A41 CJK UNIFIED IDEOGRAPH-#26A41, IRGKangXi=1011.121, RSKangXi=137.7
26A42 CJK UNIFIED IDEOGRAPH-#26A42, IRGKangXi=1011.121, RSKangXi=137.7
26A43 CJK UNIFIED IDEOGRAPH-#26A43, IRGKangXi=1011.121, RSKangXi=137.7
26A44 CJK UNIFIED IDEOGRAPH-#26A44, IRGKangXi=1011.121, RSKangXi=137.7
26A45 CJK UNIFIED IDEOGRAPH-#26A45, IRGKangXi=1011.121, RSKangXi=137.7
26A46 CJK UNIFIED IDEOGRAPH-#26A46, IRGKangXi=1011.121, RSKangXi=137.7
26A47 CJK UNIFIED IDEOGRAPH-#26A47, IRGKangXi=1011.121, RSKangXi=137.7
26A48 CJK UNIFIED IDEOGRAPH-#26A48, IRGKangXi=1011.121, RSKangXi=137.7
26A49 CJK UNIFIED IDEOGRAPH-#26A49, IRGKangXi=1011.121, RSKangXi=137.7
26A4A CJK UNIFIED IDEOGRAPH-#26A4A, IRGKangXi=1011.170, RSKangXi=137.8
26A4B CJK UNIFIED IDEOGRAPH-#26A4B, IRGKangXi=1011.180, RSKangXi=137.8
26A4C CJK UNIFIED IDEOGRAPH-#26A4C, IRGKangXi=1011.230, RSKangXi=137.8
26A4D CJK UNIFIED IDEOGRAPH-#26A4D, IRGKangXi=1011.240, RSKangXi=137.8
26A4E CJK UNIFIED IDEOGRAPH-#26A4E, IRGKangXi=1011.260, RSKangXi=137.8
26A4F CJK UNIFIED IDEOGRAPH-#26A4F, IRGKangXi=1011.270, RSKangXi=137.8
26A50 CJK UNIFIED IDEOGRAPH-#26A50, IRGKangXi=1011.271, RSKangXi=137.8
26A51 CJK UNIFIED IDEOGRAPH-#26A51, IRGKangXi=1011.271, RSKangXi=137.8
26A52 CJK UNIFIED IDEOGRAPH-#26A52, IRGKangXi=1011.271, RSKangXi=137.8
26A53 CJK UNIFIED IDEOGRAPH-#26A53, IRGKangXi=1011.271, RSKangXi=137.8
26A54 CJK UNIFIED IDEOGRAPH-#26A54, IRGKangXi=1011.271, RSKangXi=137.8
26A55 CJK UNIFIED IDEOGRAPH-#26A55, IRGKangXi=1011.271, RSKangXi=137.8
26A56 CJK UNIFIED IDEOGRAPH-#26A56, IRGKangXi=1011.271, RSKangXi=137.8
26A57 CJK UNIFIED IDEOGRAPH-#26A57, IRGKangXi=1011.271, RSKangXi=137.8
26A58 CJK UNIFIED IDEOGRAPH-#26A58, IRGKangXi=1011.271, RSKangXi=137.8
26A59 CJK UNIFIED IDEOGRAPH-#26A59, IRGKangXi=1011.271, RSKangXi=137.8
26A5A CJK UNIFIED IDEOGRAPH-#26A5A, IRGKangXi=1011.271, RSKangXi=137.8
26A5B CJK UNIFIED IDEOGRAPH-#26A5B, IRGKangXi=1011.271, RSKangXi=137.8
26A5C CJK UNIFIED IDEOGRAPH-#26A5C, IRGKangXi=1011.271, RSKangXi=137.8
26A5D CJK UNIFIED IDEOGRAPH-#26A5D, IRGKangXi=1011.280, RSKangXi=137.9
26A5E CJK UNIFIED IDEOGRAPH-#26A5E, IRGKangXi=1011.290, RSKangXi=137.9
26A5F CJK UNIFIED IDEOGRAPH-#26A5F, IRGKangXi=1011.300, RSKangXi=137.9
26A60 CJK UNIFIED IDEOGRAPH-#26A60, IRGKangXi=1011.310, RSKangXi=137.9
26A61 CJK UNIFIED IDEOGRAPH-#26A61, IRGKangXi=1011.330, RSKangXi=137.9
26A62 CJK UNIFIED IDEOGRAPH-#26A62, IRGKangXi=1011.340, RSKangXi=137.9
26A63 CJK UNIFIED IDEOGRAPH-#26A63, IRGKangXi=1011.350, RSKangXi=137.9
26A64 CJK UNIFIED IDEOGRAPH-#26A64, IRGKangXi=1011.380, RSKangXi=137.9
26A65 CJK UNIFIED IDEOGRAPH-#26A65, IRGKangXi=1011.420, RSKangXi=137.9
26A66 CJK UNIFIED IDEOGRAPH-#26A66, IRGKangXi=1011.460, RSKangXi=137.9
26A67 CJK UNIFIED IDEOGRAPH-#26A67, IRGKangXi=1011.470, RSKangXi=137.9
26A68 CJK UNIFIED IDEOGRAPH-#26A68, IRGKangXi=1011.480, RSKangXi=137.9
26A69 CJK UNIFIED IDEOGRAPH-#26A69, IRGKangXi=1011.490, RSKangXi=137.9
26A6A CJK UNIFIED IDEOGRAPH-#26A6A, IRGKangXi=1011.500, RSKangXi=137.9
26A6B CJK UNIFIED IDEOGRAPH-#26A6B, IRGKangXi=1011.510, RSKangXi=137.9
26A6C CJK UNIFIED IDEOGRAPH-#26A6C, IRGKangXi=1011.511, RSKangXi=137.9
26A6D CJK UNIFIED IDEOGRAPH-#26A6D, IRGKangXi=1011.511, RSKangXi=137.9
26A6E CJK UNIFIED IDEOGRAPH-#26A6E, IRGKangXi=1011.511, RSKangXi=137.9
26A6F CJK UNIFIED IDEOGRAPH-#26A6F, IRGKangXi=1011.511, RSKangXi=137.9
26A70 CJK UNIFIED IDEOGRAPH-#26A70, IRGKangXi=1011.511, RSKangXi=137.9
26A71 CJK UNIFIED IDEOGRAPH-#26A71, IRGKangXi=1011.511, RSKangXi=137.9
26A72 CJK UNIFIED IDEOGRAPH-#26A72, IRGKangXi=1011.511, RSKangXi=137.9
26A73 CJK UNIFIED IDEOGRAPH-#26A73, IRGKangXi=1011.511, RSKangXi=137.9
26A74 CJK UNIFIED IDEOGRAPH-#26A74, IRGKangXi=1011.520, RSKangXi=137.10
26A75 CJK UNIFIED IDEOGRAPH-#26A75, IRGKangXi=1011.530, RSKangXi=137.10
26A76 CJK UNIFIED IDEOGRAPH-#26A76, IRGKangXi=1012.010, RSKangXi=137.10
26A77 CJK UNIFIED IDEOGRAPH-#26A77, IRGKangXi=1012.020, RSKangXi=137.10
26A78 CJK UNIFIED IDEOGRAPH-#26A78, IRGKangXi=1012.030, RSKangXi=137.10
26A79 CJK UNIFIED IDEOGRAPH-#26A79, IRGKangXi=1012.050, RSKangXi=137.10
26A7A CJK UNIFIED IDEOGRAPH-#26A7A, IRGKangXi=1012.060, RSKangXi=137.10
26A7B CJK UNIFIED IDEOGRAPH-#26A7B, IRGKangXi=1012.070, RSKangXi=137.10
26A7C CJK UNIFIED IDEOGRAPH-#26A7C, IRGKangXi=1012.120, RSKangXi=137.10
26A7D CJK UNIFIED IDEOGRAPH-#26A7D, IRGKangXi=1012.130, RSKangXi=137.10
26A7E CJK UNIFIED IDEOGRAPH-#26A7E, IRGKangXi=1012.131, RSKangXi=137.10
26A7F CJK UNIFIED IDEOGRAPH-#26A7F, IRGKangXi=1012.131, RSKangXi=137.9
26A80 CJK UNIFIED IDEOGRAPH-#26A80, IRGKangXi=1012.131, RSKangXi=137.10
26A81 CJK UNIFIED IDEOGRAPH-#26A81, IRGKangXi=1012.131, RSKangXi=137.10
26A82 CJK UNIFIED IDEOGRAPH-#26A82, IRGKangXi=1012.131, RSKangXi=137.10
26A83 CJK UNIFIED IDEOGRAPH-#26A83, IRGKangXi=1012.131, RSKangXi=137.10
26A84 CJK UNIFIED IDEOGRAPH-#26A84, IRGKangXi=1012.131, RSKangXi=137.10
26A85 CJK UNIFIED IDEOGRAPH-#26A85, IRGKangXi=1012.131, RSKangXi=137.10
26A86 CJK UNIFIED IDEOGRAPH-#26A86, IRGKangXi=1012.160, RSKangXi=137.11
26A87 CJK UNIFIED IDEOGRAPH-#26A87, IRGKangXi=1012.170, RSKangXi=137.11
26A88 CJK UNIFIED IDEOGRAPH-#26A88, IRGKangXi=1012.190, RSKangXi=137.11, Def{(Cant.) to kneel}
26A89 CJK UNIFIED IDEOGRAPH-#26A89, IRGKangXi=1012.240, RSKangXi=137.11
26A8A CJK UNIFIED IDEOGRAPH-#26A8A, IRGKangXi=1012.250, RSKangXi=137.11
26A8B CJK UNIFIED IDEOGRAPH-#26A8B, IRGKangXi=1012.270, RSKangXi=137.11
26A8C CJK UNIFIED IDEOGRAPH-#26A8C, IRGKangXi=1012.281, RSKangXi=137.11
26A8D CJK UNIFIED IDEOGRAPH-#26A8D, IRGKangXi=1012.281, RSKangXi=137.11
26A8E CJK UNIFIED IDEOGRAPH-#26A8E, IRGKangXi=1012.281, RSKangXi=137.11
26A8F CJK UNIFIED IDEOGRAPH-#26A8F, IRGKangXi=1012.281, RSKangXi=137.11
26A90 CJK UNIFIED IDEOGRAPH-#26A90, IRGKangXi=1012.281, RSKangXi=137.11
26A91 CJK UNIFIED IDEOGRAPH-#26A91, IRGKangXi=1012.290, RSKangXi=137.12
26A92 CJK UNIFIED IDEOGRAPH-#26A92, IRGKangXi=1012.300, RSKangXi=137.12
26A93 CJK UNIFIED IDEOGRAPH-#26A93, IRGKangXi=1012.310, RSKangXi=137.12
26A94 CJK UNIFIED IDEOGRAPH-#26A94, IRGKangXi=1012.320, RSKangXi=137.12
26A95 CJK UNIFIED IDEOGRAPH-#26A95, IRGKangXi=1012.330, RSKangXi=137.12
26A96 CJK UNIFIED IDEOGRAPH-#26A96, IRGKangXi=1012.340, RSKangXi=137.12
26A97 CJK UNIFIED IDEOGRAPH-#26A97, IRGKangXi=1012.360, RSKangXi=137.12
26A98 CJK UNIFIED IDEOGRAPH-#26A98, IRGKangXi=1012.370, RSKangXi=137.12
26A99 CJK UNIFIED IDEOGRAPH-#26A99, IRGKangXi=1012.380, RSKangXi=137.12
26A9A CJK UNIFIED IDEOGRAPH-#26A9A, IRGKangXi=1012.390, RSKangXi=137.12
26A9B CJK UNIFIED IDEOGRAPH-#26A9B, IRGKangXi=1012.420, RSKangXi=137.12
26A9C CJK UNIFIED IDEOGRAPH-#26A9C, IRGKangXi=1012.430, RSKangXi=137.12
26A9D CJK UNIFIED IDEOGRAPH-#26A9D, IRGKangXi=1012.440, RSKangXi=137.12
26A9E CJK UNIFIED IDEOGRAPH-#26A9E, IRGKangXi=1012.441, RSKangXi=137.12
26A9F CJK UNIFIED IDEOGRAPH-#26A9F, IRGKangXi=1012.441, RSKangXi=137.12
26AA0 CJK UNIFIED IDEOGRAPH-#26AA0, IRGKangXi=1012.441, RSKangXi=137.12
26AA1 CJK UNIFIED IDEOGRAPH-#26AA1, IRGKangXi=1012.441, RSKangXi=137.12
26AA2 CJK UNIFIED IDEOGRAPH-#26AA2, IRGKangXi=1012.441, RSKangXi=137.12
26AA3 CJK UNIFIED IDEOGRAPH-#26AA3, IRGKangXi=1012.441, RSKangXi=137.12
26AA4 CJK UNIFIED IDEOGRAPH-#26AA4, IRGKangXi=1012.441, RSKangXi=137.12
26AA5 CJK UNIFIED IDEOGRAPH-#26AA5, IRGKangXi=1012.441, RSKangXi=137.12
26AA6 CJK UNIFIED IDEOGRAPH-#26AA6, IRGKangXi=1012.441, RSKangXi=137.12
26AA7 CJK UNIFIED IDEOGRAPH-#26AA7, IRGKangXi=1012.441, RSKangXi=137.12
26AA8 CJK UNIFIED IDEOGRAPH-#26AA8, IRGKangXi=1012.441, RSKangXi=137.13
26AA9 CJK UNIFIED IDEOGRAPH-#26AA9, IRGKangXi=1012.470, RSKangXi=137.13
26AAA CJK UNIFIED IDEOGRAPH-#26AAA, IRGKangXi=1012.480, RSKangXi=137.13
26AAB CJK UNIFIED IDEOGRAPH-#26AAB, IRGKangXi=1012.490, RSKangXi=137.13
26AAC CJK UNIFIED IDEOGRAPH-#26AAC, IRGKangXi=1012.500, RSKangXi=137.13
26AAD CJK UNIFIED IDEOGRAPH-#26AAD, IRGKangXi=1012.530, RSKangXi=137.13
26AAE CJK UNIFIED IDEOGRAPH-#26AAE, IRGKangXi=1012.550, RSKangXi=137.13
26AAF CJK UNIFIED IDEOGRAPH-#26AAF, IRGKangXi=1012.561, RSKangXi=137.13
26AB0 CJK UNIFIED IDEOGRAPH-#26AB0, IRGKangXi=1012.561, RSKangXi=137.13
26AB1 CJK UNIFIED IDEOGRAPH-#26AB1, IRGKangXi=1013.060, RSKangXi=137.14
26AB2 CJK UNIFIED IDEOGRAPH-#26AB2, IRGKangXi=1013.061, RSKangXi=137.14
26AB3 CJK UNIFIED IDEOGRAPH-#26AB3, IRGKangXi=1013.061, RSKangXi=137.14
26AB4 CJK UNIFIED IDEOGRAPH-#26AB4, IRGKangXi=1013.061, RSKangXi=137.14
26AB5 CJK UNIFIED IDEOGRAPH-#26AB5, IRGKangXi=1013.061, RSKangXi=137.14
26AB6 CJK UNIFIED IDEOGRAPH-#26AB6, IRGKangXi=1013.070, RSKangXi=137.15
26AB7 CJK UNIFIED IDEOGRAPH-#26AB7, IRGKangXi=1013.080, RSKangXi=137.15
26AB8 CJK UNIFIED IDEOGRAPH-#26AB8, IRGKangXi=1013.100, RSKangXi=137.15
26AB9 CJK UNIFIED IDEOGRAPH-#26AB9, IRGKangXi=1013.101, RSKangXi=108.16
26ABA CJK UNIFIED IDEOGRAPH-#26ABA, IRGKangXi=1013.101, RSKangXi=137.15
26ABB CJK UNIFIED IDEOGRAPH-#26ABB, IRGKangXi=1013.101, RSKangXi=137.15
26ABC CJK UNIFIED IDEOGRAPH-#26ABC, IRGKangXi=1013.101, RSKangXi=137.15
26ABD CJK UNIFIED IDEOGRAPH-#26ABD, IRGKangXi=1013.120, RSKangXi=137.16
26ABE CJK UNIFIED IDEOGRAPH-#26ABE, IRGKangXi=1013.130, RSKangXi=137.16
26ABF CJK UNIFIED IDEOGRAPH-#26ABF, IRGKangXi=1013.140, RSKangXi=137.16
26AC0 CJK UNIFIED IDEOGRAPH-#26AC0, IRGKangXi=1013.150, RSKangXi=137.16
26AC1 CJK UNIFIED IDEOGRAPH-#26AC1, IRGKangXi=1013.151, RSKangXi=137.16
26AC2 CJK UNIFIED IDEOGRAPH-#26AC2, IRGKangXi=1013.151, RSKangXi=137.16
26AC3 CJK UNIFIED IDEOGRAPH-#26AC3, IRGKangXi=1013.170, RSKangXi=137.17
26AC4 CJK UNIFIED IDEOGRAPH-#26AC4, IRGKangXi=1013.171, RSKangXi=137.17
26AC5 CJK UNIFIED IDEOGRAPH-#26AC5, IRGKangXi=1013.190, RSKangXi=137.19
26AC6 CJK UNIFIED IDEOGRAPH-#26AC6, IRGKangXi=1013.191, RSKangXi=137.19
26AC7 CJK UNIFIED IDEOGRAPH-#26AC7, IRGKangXi=1013.191, RSKangXi=137.20
26AC8 CJK UNIFIED IDEOGRAPH-#26AC8, IRGKangXi=1013.200, RSKangXi=137.21
26AC9 CJK UNIFIED IDEOGRAPH-#26AC9, IRGKangXi=1013.201, RSKangXi=137.20
26ACA CJK UNIFIED IDEOGRAPH-#26ACA, IRGKangXi=1013.210, RSKangXi=137.24
26ACB CJK UNIFIED IDEOGRAPH-#26ACB, IRGKangXi=1013.270, RSKangXi=138.3
26ACC CJK UNIFIED IDEOGRAPH-#26ACC, IRGKangXi=1013.271, RSKangXi=138.5
26ACD CJK UNIFIED IDEOGRAPH-#26ACD, IRGKangXi=1013.271, RSKangXi=138.5
26ACE CJK UNIFIED IDEOGRAPH-#26ACE, IRGKangXi=1013.280, RSKangXi=138.6
26ACF CJK UNIFIED IDEOGRAPH-#26ACF, IRGKangXi=1013.281, RSKangXi=138.7
26AD0 CJK UNIFIED IDEOGRAPH-#26AD0, IRGKangXi=1013.281, RSKangXi=138.9
26AD1 CJK UNIFIED IDEOGRAPH-#26AD1, IRGKangXi=1013.311, RSKangXi=138.11
26AD2 CJK UNIFIED IDEOGRAPH-#26AD2, IRGKangXi=1014.010, RSKangXi=138.14
26AD3 CJK UNIFIED IDEOGRAPH-#26AD3, IRGKangXi=1014.031, RSKangXi=139.3
26AD4 CJK UNIFIED IDEOGRAPH-#26AD4, IRGKangXi=1014.070, RSKangXi=139.5
26AD5 CJK UNIFIED IDEOGRAPH-#26AD5, IRGKangXi=1014.080, RSKangXi=139.5
26AD6 CJK UNIFIED IDEOGRAPH-#26AD6, IRGKangXi=1014.081, RSKangXi=139.5
26AD7 CJK UNIFIED IDEOGRAPH-#26AD7, IRGKangXi=1014.081, RSKangXi=139.5
26AD8 CJK UNIFIED IDEOGRAPH-#26AD8, IRGKangXi=1014.081, RSKangXi=139.5
26AD9 CJK UNIFIED IDEOGRAPH-#26AD9, IRGKangXi=1014.081, RSKangXi=139.5
26ADA CJK UNIFIED IDEOGRAPH-#26ADA, IRGKangXi=1014.081, RSKangXi=139.6
26ADB CJK UNIFIED IDEOGRAPH-#26ADB, IRGKangXi=1014.090, RSKangXi=139.7
26ADC CJK UNIFIED IDEOGRAPH-#26ADC, IRGKangXi=1014.100, RSKangXi=139.7
26ADD CJK UNIFIED IDEOGRAPH-#26ADD, IRGKangXi=1014.101, RSKangXi=139.7
26ADE CJK UNIFIED IDEOGRAPH-#26ADE, IRGKangXi=1014.120, RSKangXi=139.8
26ADF CJK UNIFIED IDEOGRAPH-#26ADF, IRGKangXi=1014.121, RSKangXi=139.8
26AE0 CJK UNIFIED IDEOGRAPH-#26AE0, IRGKangXi=1014.121, RSKangXi=139.8
26AE1 CJK UNIFIED IDEOGRAPH-#26AE1, IRGKangXi=1014.121, RSKangXi=139.8
26AE2 CJK UNIFIED IDEOGRAPH-#26AE2, IRGKangXi=1014.121, RSKangXi=139.8
26AE3 CJK UNIFIED IDEOGRAPH-#26AE3, IRGKangXi=1014.121, RSKangXi=139.8
26AE4 CJK UNIFIED IDEOGRAPH-#26AE4, IRGKangXi=1014.121, RSKangXi=139.9
26AE5 CJK UNIFIED IDEOGRAPH-#26AE5, IRGKangXi=1014.121, RSKangXi=139.9
26AE6 CJK UNIFIED IDEOGRAPH-#26AE6, IRGKangXi=1014.121, RSKangXi=139.9
26AE7 CJK UNIFIED IDEOGRAPH-#26AE7, IRGKangXi=1014.121, RSKangXi=139.9
26AE8 CJK UNIFIED IDEOGRAPH-#26AE8, IRGKangXi=1014.121, RSKangXi=139.9
26AE9 CJK UNIFIED IDEOGRAPH-#26AE9, IRGKangXi=1014.121, RSKangXi=139.9
26AEA CJK UNIFIED IDEOGRAPH-#26AEA, IRGKangXi=1014.140, RSKangXi=139.10
26AEB CJK UNIFIED IDEOGRAPH-#26AEB, IRGKangXi=1014.150, RSKangXi=139.10
26AEC CJK UNIFIED IDEOGRAPH-#26AEC, IRGKangXi=1014.160, RSKangXi=139.10
26AED CJK UNIFIED IDEOGRAPH-#26AED, IRGKangXi=1014.171, RSKangXi=139.10
26AEE CJK UNIFIED IDEOGRAPH-#26AEE, IRGKangXi=1014.171, RSKangXi=139.10
26AEF CJK UNIFIED IDEOGRAPH-#26AEF, IRGKangXi=1014.210, RSKangXi=139.14
26AF0 CJK UNIFIED IDEOGRAPH-#26AF0, IRGKangXi=1014.220, RSKangXi=139.14
26AF1 CJK UNIFIED IDEOGRAPH-#26AF1, IRGKangXi=1014.221, RSKangXi=139.14
26AF2 CJK UNIFIED IDEOGRAPH-#26AF2, IRGKangXi=1014.241, RSKangXi=139.19
26AF3 CJK UNIFIED IDEOGRAPH-#26AF3, IRGKangXi=1017.020, RSKangXi=140.1
26AF4 CJK UNIFIED IDEOGRAPH-#26AF4, IRGKangXi=1017.030, RSKangXi=140.1
26AF5 CJK UNIFIED IDEOGRAPH-#26AF5, IRGKangXi=1017.031, RSKangXi=140.1
26AF6 CJK UNIFIED IDEOGRAPH-#26AF6, IRGKangXi=1017.080, RSKangXi=140.2
26AF7 CJK UNIFIED IDEOGRAPH-#26AF7, IRGKangXi=1017.120, RSKangXi=140.2
26AF8 CJK UNIFIED IDEOGRAPH-#26AF8, IRGKangXi=1017.140, RSKangXi=140.2
26AF9 CJK UNIFIED IDEOGRAPH-#26AF9, IRGKangXi=1017.160, RSKangXi=140.2
26AFA CJK UNIFIED IDEOGRAPH-#26AFA, IRGKangXi=1017.170, RSKangXi=140.2
26AFB CJK UNIFIED IDEOGRAPH-#26AFB, IRGKangXi=1017.180, RSKangXi=140.2
26AFC CJK UNIFIED IDEOGRAPH-#26AFC, IRGKangXi=1017.190, RSKangXi=140.2
26AFD CJK UNIFIED IDEOGRAPH-#26AFD, IRGKangXi=1017.191, RSKangXi=140.2
26AFE CJK UNIFIED IDEOGRAPH-#26AFE, IRGKangXi=1017.191, RSKangXi=140.2
26AFF CJK UNIFIED IDEOGRAPH-#26AFF, IRGKangXi=1017.191, RSKangXi=140.2
26B00 CJK UNIFIED IDEOGRAPH-#26B00, IRGKangXi=1017.191, RSKangXi=140.2
26B01 CJK UNIFIED IDEOGRAPH-#26B01, IRGKangXi=1017.210, RSKangXi=140.3
26B02 CJK UNIFIED IDEOGRAPH-#26B02, IRGKangXi=1018.100, RSKangXi=140.3
26B03 CJK UNIFIED IDEOGRAPH-#26B03, IRGKangXi=1018.110, RSKangXi=140.3
26B04 CJK UNIFIED IDEOGRAPH-#26B04, IRGKangXi=1018.140, RSKangXi=140.3
26B05 CJK UNIFIED IDEOGRAPH-#26B05, IRGKangXi=1018.150, RSKangXi=140.3
26B06 CJK UNIFIED IDEOGRAPH-#26B06, IRGKangXi=1018.210, RSKangXi=140.3
26B07 CJK UNIFIED IDEOGRAPH-#26B07, IRGKangXi=1019.030, RSKangXi=140.3
26B08 CJK UNIFIED IDEOGRAPH-#26B08, IRGKangXi=1019.040, RSKangXi=140.3
26B09 CJK UNIFIED IDEOGRAPH-#26B09, IRGKangXi=1019.050, RSKangXi=140.3
26B0A CJK UNIFIED IDEOGRAPH-#26B0A, IRGKangXi=1019.061, RSKangXi=140.3
26B0B CJK UNIFIED IDEOGRAPH-#26B0B, IRGKangXi=1019.061, RSKangXi=140.3
26B0C CJK UNIFIED IDEOGRAPH-#26B0C, IRGKangXi=1019.061, RSKangXi=140.3
26B0D CJK UNIFIED IDEOGRAPH-#26B0D, IRGKangXi=1019.061, RSKangXi=140.3
26B0E CJK UNIFIED IDEOGRAPH-#26B0E, IRGKangXi=1019.061, RSKangXi=140.3
26B0F CJK UNIFIED IDEOGRAPH-#26B0F, IRGKangXi=1019.061, RSKangXi=140.3
26B10 CJK UNIFIED IDEOGRAPH-#26B10, IRGKangXi=1019.061, RSKangXi=140.3
26B11 CJK UNIFIED IDEOGRAPH-#26B11, IRGKangXi=1019.061, RSKangXi=140.3
26B12 CJK UNIFIED IDEOGRAPH-#26B12, IRGKangXi=1019.061, RSKangXi=140.3
26B13 CJK UNIFIED IDEOGRAPH-#26B13, IRGKangXi=1019.140, RSKangXi=140.4
26B14 CJK UNIFIED IDEOGRAPH-#26B14, IRGKangXi=1019.230, RSKangXi=140.4
26B15 CJK UNIFIED IDEOGRAPH-#26B15, IRGKangXi=1019.270, RSKangXi=140.4
26B16 CJK UNIFIED IDEOGRAPH-#26B16, IRGKangXi=1019.280, RSKangXi=140.4
26B17 CJK UNIFIED IDEOGRAPH-#26B17, IRGKangXi=1019.290, RSKangXi=140.4
26B18 CJK UNIFIED IDEOGRAPH-#26B18, IRGKangXi=1020.030, RSKangXi=140.4
26B19 CJK UNIFIED IDEOGRAPH-#26B19, IRGKangXi=1020.050, RSKangXi=140.4
26B1A CJK UNIFIED IDEOGRAPH-#26B1A, IRGKangXi=1020.110, RSKangXi=140.4
26B1B CJK UNIFIED IDEOGRAPH-#26B1B, IRGKangXi=1020.140, RSKangXi=140.4
26B1C CJK UNIFIED IDEOGRAPH-#26B1C, IRGKangXi=1022.010, RSKangXi=140.4
26B1D CJK UNIFIED IDEOGRAPH-#26B1D, IRGKangXi=1022.020, RSKangXi=140.4
26B1E CJK UNIFIED IDEOGRAPH-#26B1E, IRGKangXi=1022.040, RSKangXi=140.4
26B1F CJK UNIFIED IDEOGRAPH-#26B1F, IRGKangXi=1022.050, RSKangXi=140.4
26B20 CJK UNIFIED IDEOGRAPH-#26B20, IRGKangXi=1022.060, RSKangXi=140.4
26B21 CJK UNIFIED IDEOGRAPH-#26B21, IRGKangXi=1022.090, RSKangXi=140.4
26B22 CJK UNIFIED IDEOGRAPH-#26B22, IRGKangXi=1022.100, RSKangXi=140.4
26B23 CJK UNIFIED IDEOGRAPH-#26B23, IRGKangXi=1022.110, RSKangXi=140.4
26B24 CJK UNIFIED IDEOGRAPH-#26B24, IRGKangXi=1022.120, RSKangXi=140.4
26B25 CJK UNIFIED IDEOGRAPH-#26B25, IRGKangXi=1022.130, RSKangXi=140.4
26B26 CJK UNIFIED IDEOGRAPH-#26B26, IRGKangXi=1022.170, RSKangXi=140.4
26B27 CJK UNIFIED IDEOGRAPH-#26B27, IRGKangXi=1022.180, RSKangXi=140.4
26B28 CJK UNIFIED IDEOGRAPH-#26B28, IRGKangXi=1022.181, RSKangXi=140.4
26B29 CJK UNIFIED IDEOGRAPH-#26B29, IRGKangXi=1022.181, RSKangXi=140.4
26B2A CJK UNIFIED IDEOGRAPH-#26B2A, IRGKangXi=1022.181, RSKangXi=140.4
26B2B CJK UNIFIED IDEOGRAPH-#26B2B, IRGKangXi=1022.181, RSKangXi=140.4
26B2C CJK UNIFIED IDEOGRAPH-#26B2C, IRGKangXi=1022.181, RSKangXi=140.4
26B2D CJK UNIFIED IDEOGRAPH-#26B2D, IRGKangXi=1022.181, RSKangXi=140.4
26B2E CJK UNIFIED IDEOGRAPH-#26B2E, IRGKangXi=1022.181, RSKangXi=140.4
26B2F CJK UNIFIED IDEOGRAPH-#26B2F, IRGKangXi=1022.181, RSKangXi=140.4
26B30 CJK UNIFIED IDEOGRAPH-#26B30, IRGKangXi=1022.181, RSKangXi=140.4
26B31 CJK UNIFIED IDEOGRAPH-#26B31, IRGKangXi=1022.181, RSKangXi=140.4
26B32 CJK UNIFIED IDEOGRAPH-#26B32, IRGKangXi=1022.181, RSKangXi=140.4
26B33 CJK UNIFIED IDEOGRAPH-#26B33, IRGKangXi=1022.181, RSKangXi=140.4
26B34 CJK UNIFIED IDEOGRAPH-#26B34, IRGKangXi=1022.181, RSKangXi=140.4
26B35 CJK UNIFIED IDEOGRAPH-#26B35, IRGKangXi=1022.181, RSKangXi=140.4
26B36 CJK UNIFIED IDEOGRAPH-#26B36, IRGKangXi=1022.181, RSKangXi=140.4
26B37 CJK UNIFIED IDEOGRAPH-#26B37, IRGKangXi=1022.200, RSKangXi=140.5
26B38 CJK UNIFIED IDEOGRAPH-#26B38, IRGKangXi=1024.130, RSKangXi=140.5
26B39 CJK UNIFIED IDEOGRAPH-#26B39, IRGKangXi=1024.150, RSKangXi=140.5
26B3A CJK UNIFIED IDEOGRAPH-#26B3A, IRGKangXi=1025.010, RSKangXi=140.5
26B3B CJK UNIFIED IDEOGRAPH-#26B3B, IRGKangXi=1025.020, RSKangXi=140.5
26B3C CJK UNIFIED IDEOGRAPH-#26B3C, IRGKangXi=1025.060, RSKangXi=140.5
26B3D CJK UNIFIED IDEOGRAPH-#26B3D, IRGKangXi=1025.080, RSKangXi=140.5
26B3E CJK UNIFIED IDEOGRAPH-#26B3E, IRGKangXi=1026.050, RSKangXi=140.5
26B3F CJK UNIFIED IDEOGRAPH-#26B3F, IRGKangXi=1027.020, RSKangXi=140.5
26B40 CJK UNIFIED IDEOGRAPH-#26B40, IRGKangXi=1027.060, RSKangXi=140.5
26B41 CJK UNIFIED IDEOGRAPH-#26B41, IRGKangXi=1027.070, RSKangXi=140.5
26B42 CJK UNIFIED IDEOGRAPH-#26B42, IRGKangXi=1027.080, RSKangXi=140.5
26B43 CJK UNIFIED IDEOGRAPH-#26B43, IRGKangXi=1027.090, RSKangXi=140.5
26B44 CJK UNIFIED IDEOGRAPH-#26B44, IRGKangXi=1027.110, RSKangXi=140.5
26B45 CJK UNIFIED IDEOGRAPH-#26B45, IRGKangXi=1027.130, RSKangXi=140.5
26B46 CJK UNIFIED IDEOGRAPH-#26B46, IRGKangXi=1027.140, RSKangXi=140.5
26B47 CJK UNIFIED IDEOGRAPH-#26B47, IRGKangXi=1027.150, RSKangXi=140.5
26B48 CJK UNIFIED IDEOGRAPH-#26B48, IRGKangXi=1027.160, RSKangXi=140.5
26B49 CJK UNIFIED IDEOGRAPH-#26B49, IRGKangXi=1027.180, RSKangXi=140.5
26B4A CJK UNIFIED IDEOGRAPH-#26B4A, IRGKangXi=1027.190, RSKangXi=140.5
26B4B CJK UNIFIED IDEOGRAPH-#26B4B, IRGKangXi=1027.200, RSKangXi=140.5
26B4C CJK UNIFIED IDEOGRAPH-#26B4C, IRGKangXi=1027.201, RSKangXi=140.5
26B4D CJK UNIFIED IDEOGRAPH-#26B4D, IRGKangXi=1027.201, RSKangXi=140.5
26B4E CJK UNIFIED IDEOGRAPH-#26B4E, IRGKangXi=1027.201, RSKangXi=140.5
26B4F CJK UNIFIED IDEOGRAPH-#26B4F, IRGKangXi=1027.201, RSKangXi=140.5
26B50 CJK UNIFIED IDEOGRAPH-#26B50, IRGKangXi=1027.201, RSKangXi=140.5
26B51 CJK UNIFIED IDEOGRAPH-#26B51, IRGKangXi=1027.201, RSKangXi=140.5
26B52 CJK UNIFIED IDEOGRAPH-#26B52, IRGKangXi=1027.201, RSKangXi=140.5
26B53 CJK UNIFIED IDEOGRAPH-#26B53, IRGKangXi=1027.201, RSKangXi=140.5
26B54 CJK UNIFIED IDEOGRAPH-#26B54, IRGKangXi=1027.201, RSKangXi=140.5
26B55 CJK UNIFIED IDEOGRAPH-#26B55, IRGKangXi=1027.201, RSKangXi=140.5
26B56 CJK UNIFIED IDEOGRAPH-#26B56, IRGKangXi=1027.201, RSKangXi=140.5
26B57 CJK UNIFIED IDEOGRAPH-#26B57, IRGKangXi=1027.201, RSKangXi=140.5
26B58 CJK UNIFIED IDEOGRAPH-#26B58, IRGKangXi=1027.201, RSKangXi=140.5
26B59 CJK UNIFIED IDEOGRAPH-#26B59, IRGKangXi=1027.201, RSKangXi=140.5
26B5A CJK UNIFIED IDEOGRAPH-#26B5A, IRGKangXi=1027.201, RSKangXi=140.5
26B5B CJK UNIFIED IDEOGRAPH-#26B5B, IRGKangXi=1027.201, RSKangXi=140.5
26B5C CJK UNIFIED IDEOGRAPH-#26B5C, IRGKangXi=1027.201, RSKangXi=140.5
26B5D CJK UNIFIED IDEOGRAPH-#26B5D, IRGKangXi=1027.201, RSKangXi=140.5
26B5E CJK UNIFIED IDEOGRAPH-#26B5E, IRGKangXi=1027.201, RSKangXi=140.5
26B5F CJK UNIFIED IDEOGRAPH-#26B5F, IRGKangXi=1027.201, RSKangXi=140.5
26B60 CJK UNIFIED IDEOGRAPH-#26B60, IRGKangXi=1027.201, RSKangXi=140.5
26B61 CJK UNIFIED IDEOGRAPH-#26B61, IRGKangXi=1027.201, RSKangXi=140.5
26B62 CJK UNIFIED IDEOGRAPH-#26B62, IRGKangXi=1027.201, RSKangXi=140.5
26B63 CJK UNIFIED IDEOGRAPH-#26B63, IRGKangXi=1027.201, RSKangXi=140.5
26B64 CJK UNIFIED IDEOGRAPH-#26B64, IRGKangXi=1027.201, RSKangXi=140.5
26B65 CJK UNIFIED IDEOGRAPH-#26B65, IRGKangXi=1027.201, RSKangXi=140.5
26B66 CJK UNIFIED IDEOGRAPH-#26B66, IRGKangXi=1027.201, RSKangXi=140.5
26B67 CJK UNIFIED IDEOGRAPH-#26B67, IRGKangXi=1027.201, RSKangXi=140.5
26B68 CJK UNIFIED IDEOGRAPH-#26B68, IRGKangXi=1027.201, RSKangXi=140.5
26B69 CJK UNIFIED IDEOGRAPH-#26B69, IRGKangXi=1027.201, RSKangXi=140.5
26B6A CJK UNIFIED IDEOGRAPH-#26B6A, IRGKangXi=1027.201, RSKangXi=140.5
26B6B CJK UNIFIED IDEOGRAPH-#26B6B, IRGKangXi=1027.201, RSKangXi=140.5
26B6C CJK UNIFIED IDEOGRAPH-#26B6C, IRGKangXi=1027.201, RSKangXi=140.5
26B6D CJK UNIFIED IDEOGRAPH-#26B6D, IRGKangXi=1027.240, RSKangXi=140.6
26B6E CJK UNIFIED IDEOGRAPH-#26B6E, IRGKangXi=1027.290, RSKangXi=140.6
26B6F CJK UNIFIED IDEOGRAPH-#26B6F, IRGKangXi=1027.300, RSKangXi=140.6
26B70 CJK UNIFIED IDEOGRAPH-#26B70, IRGKangXi=1027.310, RSKangXi=140.6
26B71 CJK UNIFIED IDEOGRAPH-#26B71, IRGKangXi=1027.350, RSKangXi=140.6
26B72 CJK UNIFIED IDEOGRAPH-#26B72, IRGKangXi=1028.010, RSKangXi=140.6
26B73 CJK UNIFIED IDEOGRAPH-#26B73, IRGKangXi=1028.020, RSKangXi=140.6
26B74 CJK UNIFIED IDEOGRAPH-#26B74, IRGKangXi=1028.030, RSKangXi=140.6
26B75 CJK UNIFIED IDEOGRAPH-#26B75, IRGKangXi=1028.040, RSKangXi=140.6
26B76 CJK UNIFIED IDEOGRAPH-#26B76, IRGKangXi=1028.160, RSKangXi=140.6
26B77 CJK UNIFIED IDEOGRAPH-#26B77, IRGKangXi=1028.180, RSKangXi=140.6
26B78 CJK UNIFIED IDEOGRAPH-#26B78, IRGKangXi=1029.060, RSKangXi=140.6
26B79 CJK UNIFIED IDEOGRAPH-#26B79, IRGKangXi=1029.090, RSKangXi=140.6
26B7A CJK UNIFIED IDEOGRAPH-#26B7A, IRGKangXi=1029.120, RSKangXi=140.6
26B7B CJK UNIFIED IDEOGRAPH-#26B7B, IRGKangXi=1030.030, RSKangXi=140.6
26B7C CJK UNIFIED IDEOGRAPH-#26B7C, IRGKangXi=1030.070, RSKangXi=140.6
26B7D CJK UNIFIED IDEOGRAPH-#26B7D, IRGKangXi=1030.090, RSKangXi=140.6
26B7E CJK UNIFIED IDEOGRAPH-#26B7E, IRGKangXi=1031.110, RSKangXi=140.6
26B7F CJK UNIFIED IDEOGRAPH-#26B7F, IRGKangXi=1031.120, RSKangXi=140.6
26B80 CJK UNIFIED IDEOGRAPH-#26B80, IRGKangXi=1031.130, RSKangXi=140.6
26B81 CJK UNIFIED IDEOGRAPH-#26B81, IRGKangXi=1031.140, RSKangXi=140.6
26B82 CJK UNIFIED IDEOGRAPH-#26B82, IRGKangXi=1031.160, RSKangXi=140.6
26B83 CJK UNIFIED IDEOGRAPH-#26B83, IRGKangXi=1031.170, RSKangXi=140.6
26B84 CJK UNIFIED IDEOGRAPH-#26B84, IRGKangXi=1031.190, RSKangXi=140.6
26B85 CJK UNIFIED IDEOGRAPH-#26B85, IRGKangXi=1031.200, RSKangXi=140.6
26B86 CJK UNIFIED IDEOGRAPH-#26B86, IRGKangXi=1031.220, RSKangXi=140.6
26B87 CJK UNIFIED IDEOGRAPH-#26B87, IRGKangXi=1031.230, RSKangXi=140.6
26B88 CJK UNIFIED IDEOGRAPH-#26B88, IRGKangXi=1031.240, RSKangXi=140.6
26B89 CJK UNIFIED IDEOGRAPH-#26B89, IRGKangXi=1031.250, RSKangXi=140.6
26B8A CJK UNIFIED IDEOGRAPH-#26B8A, IRGKangXi=1031.270, RSKangXi=140.6
26B8B CJK UNIFIED IDEOGRAPH-#26B8B, IRGKangXi=1031.280, RSKangXi=140.6
26B8C CJK UNIFIED IDEOGRAPH-#26B8C, IRGKangXi=1031.290, RSKangXi=140.6
26B8D CJK UNIFIED IDEOGRAPH-#26B8D, IRGKangXi=1031.300, RSKangXi=140.6
26B8E CJK UNIFIED IDEOGRAPH-#26B8E, IRGKangXi=1031.320, RSKangXi=140.6
26B8F CJK UNIFIED IDEOGRAPH-#26B8F, IRGKangXi=1031.330, RSKangXi=140.6
26B90 CJK UNIFIED IDEOGRAPH-#26B90, IRGKangXi=1031.340, RSKangXi=140.6
26B91 CJK UNIFIED IDEOGRAPH-#26B91, IRGKangXi=1031.350, RSKangXi=140.6
26B92 CJK UNIFIED IDEOGRAPH-#26B92, IRGKangXi=1031.370, RSKangXi=140.6
26B93 CJK UNIFIED IDEOGRAPH-#26B93, IRGKangXi=1031.380, RSKangXi=140.6
26B94 CJK UNIFIED IDEOGRAPH-#26B94, IRGKangXi=1031.381, RSKangXi=140.6
26B95 CJK UNIFIED IDEOGRAPH-#26B95, IRGKangXi=1031.381, RSKangXi=140.6
26B96 CJK UNIFIED IDEOGRAPH-#26B96, IRGKangXi=1031.381, RSKangXi=140.6
26B97 CJK UNIFIED IDEOGRAPH-#26B97, IRGKangXi=1031.381, RSKangXi=140.6
26B98 CJK UNIFIED IDEOGRAPH-#26B98, IRGKangXi=1031.381, RSKangXi=140.6
26B99 CJK UNIFIED IDEOGRAPH-#26B99, IRGKangXi=1031.381, RSKangXi=140.6
26B9A CJK UNIFIED IDEOGRAPH-#26B9A, IRGKangXi=1031.381, RSKangXi=140.6
26B9B CJK UNIFIED IDEOGRAPH-#26B9B, IRGKangXi=1031.381, RSKangXi=140.6
26B9C CJK UNIFIED IDEOGRAPH-#26B9C, IRGKangXi=1031.381, RSKangXi=140.6
26B9D CJK UNIFIED IDEOGRAPH-#26B9D, IRGKangXi=1031.381, RSKangXi=140.6
26B9E CJK UNIFIED IDEOGRAPH-#26B9E, IRGKangXi=1031.381, RSKangXi=140.6
26B9F CJK UNIFIED IDEOGRAPH-#26B9F, IRGKangXi=1031.381, RSKangXi=140.6
26BA0 CJK UNIFIED IDEOGRAPH-#26BA0, IRGKangXi=1031.381, RSKangXi=140.6
26BA1 CJK UNIFIED IDEOGRAPH-#26BA1, IRGKangXi=1031.381, RSKangXi=140.6
26BA2 CJK UNIFIED IDEOGRAPH-#26BA2, IRGKangXi=1031.381, RSKangXi=140.6
26BA3 CJK UNIFIED IDEOGRAPH-#26BA3, IRGKangXi=1031.381, RSKangXi=140.6
26BA4 CJK UNIFIED IDEOGRAPH-#26BA4, IRGKangXi=1031.381, RSKangXi=140.6
26BA5 CJK UNIFIED IDEOGRAPH-#26BA5, IRGKangXi=1031.381, RSKangXi=140.6
26BA6 CJK UNIFIED IDEOGRAPH-#26BA6, IRGKangXi=1031.381, RSKangXi=140.6
26BA7 CJK UNIFIED IDEOGRAPH-#26BA7, IRGKangXi=1031.381, RSKangXi=140.6
26BA8 CJK UNIFIED IDEOGRAPH-#26BA8, IRGKangXi=1031.381, RSKangXi=140.6
26BA9 CJK UNIFIED IDEOGRAPH-#26BA9, IRGKangXi=1031.381, RSKangXi=140.6
26BAA CJK UNIFIED IDEOGRAPH-#26BAA, IRGKangXi=1031.381, RSKangXi=140.6
26BAB CJK UNIFIED IDEOGRAPH-#26BAB, IRGKangXi=1031.381, RSKangXi=140.6
26BAC CJK UNIFIED IDEOGRAPH-#26BAC, IRGKangXi=1031.381, RSKangXi=140.6
26BAD CJK UNIFIED IDEOGRAPH-#26BAD, IRGKangXi=1031.381, RSKangXi=140.6
26BAE CJK UNIFIED IDEOGRAPH-#26BAE, IRGKangXi=1031.381, RSKangXi=140.6
26BAF CJK UNIFIED IDEOGRAPH-#26BAF, IRGKangXi=1031.381, RSKangXi=140.6
26BB0 CJK UNIFIED IDEOGRAPH-#26BB0, IRGKangXi=1031.381, RSKangXi=140.6
26BB1 CJK UNIFIED IDEOGRAPH-#26BB1, IRGKangXi=1031.381, RSKangXi=140.6
26BB2 CJK UNIFIED IDEOGRAPH-#26BB2, IRGKangXi=1031.381, RSKangXi=140.6
26BB3 CJK UNIFIED IDEOGRAPH-#26BB3, IRGKangXi=1031.381, RSKangXi=140.6
26BB4 CJK UNIFIED IDEOGRAPH-#26BB4, IRGKangXi=1031.381, RSKangXi=140.6
26BB5 CJK UNIFIED IDEOGRAPH-#26BB5, IRGKangXi=1031.381, RSKangXi=140.6
26BB6 CJK UNIFIED IDEOGRAPH-#26BB6, IRGKangXi=1031.410, RSKangXi=140.7
26BB7 CJK UNIFIED IDEOGRAPH-#26BB7, IRGKangXi=1031.420, RSKangXi=140.7
26BB8 CJK UNIFIED IDEOGRAPH-#26BB8, IRGKangXi=1032.030, RSKangXi=140.7
26BB9 CJK UNIFIED IDEOGRAPH-#26BB9, IRGKangXi=1032.050, RSKangXi=140.7
26BBA CJK UNIFIED IDEOGRAPH-#26BBA, IRGKangXi=1032.150, RSKangXi=140.7
26BBB CJK UNIFIED IDEOGRAPH-#26BBB, IRGKangXi=1032.190, RSKangXi=140.7
26BBC CJK UNIFIED IDEOGRAPH-#26BBC, IRGKangXi=1032.200, RSKangXi=140.7
26BBD CJK UNIFIED IDEOGRAPH-#26BBD, IRGKangXi=1033.010, RSKangXi=140.7
26BBE CJK UNIFIED IDEOGRAPH-#26BBE, IRGKangXi=1033.020, RSKangXi=140.7
26BBF CJK UNIFIED IDEOGRAPH-#26BBF, IRGKangXi=1033.030, RSKangXi=140.7
26BC0 CJK UNIFIED IDEOGRAPH-#26BC0, IRGKangXi=1033.060, RSKangXi=140.7
26BC1 CJK UNIFIED IDEOGRAPH-#26BC1, IRGKangXi=1033.070, RSKangXi=140.7
26BC2 CJK UNIFIED IDEOGRAPH-#26BC2, IRGKangXi=1033.080, RSKangXi=140.7
26BC3 CJK UNIFIED IDEOGRAPH-#26BC3, IRGKangXi=1033.090, RSKangXi=140.7
26BC4 CJK UNIFIED IDEOGRAPH-#26BC4, IRGKangXi=1033.140, RSKangXi=140.7
26BC5 CJK UNIFIED IDEOGRAPH-#26BC5, IRGKangXi=1033.150, RSKangXi=140.7
26BC6 CJK UNIFIED IDEOGRAPH-#26BC6, IRGKangXi=1033.160, RSKangXi=140.7
26BC7 CJK UNIFIED IDEOGRAPH-#26BC7, IRGKangXi=1033.290, RSKangXi=140.7
26BC8 CJK UNIFIED IDEOGRAPH-#26BC8, IRGKangXi=1034.060, RSKangXi=140.7
26BC9 CJK UNIFIED IDEOGRAPH-#26BC9, IRGKangXi=1034.080, RSKangXi=140.7
26BCA CJK UNIFIED IDEOGRAPH-#26BCA, IRGKangXi=1035.020, RSKangXi=140.7
26BCB CJK UNIFIED IDEOGRAPH-#26BCB, IRGKangXi=1035.030, RSKangXi=140.7
26BCC CJK UNIFIED IDEOGRAPH-#26BCC, IRGKangXi=1035.050, RSKangXi=140.7
26BCD CJK UNIFIED IDEOGRAPH-#26BCD, IRGKangXi=1035.170, RSKangXi=140.7
26BCE CJK UNIFIED IDEOGRAPH-#26BCE, IRGKangXi=1035.180, RSKangXi=140.7
26BCF CJK UNIFIED IDEOGRAPH-#26BCF, IRGKangXi=1035.190, RSKangXi=140.7
26BD0 CJK UNIFIED IDEOGRAPH-#26BD0, IRGKangXi=1035.210, RSKangXi=140.7
26BD1 CJK UNIFIED IDEOGRAPH-#26BD1, IRGKangXi=1035.220, RSKangXi=140.7
26BD2 CJK UNIFIED IDEOGRAPH-#26BD2, IRGKangXi=1036.010, RSKangXi=140.7
26BD3 CJK UNIFIED IDEOGRAPH-#26BD3, IRGKangXi=1036.020, RSKangXi=140.7
26BD4 CJK UNIFIED IDEOGRAPH-#26BD4, IRGKangXi=1036.040, RSKangXi=140.7
26BD5 CJK UNIFIED IDEOGRAPH-#26BD5, IRGKangXi=1036.060, RSKangXi=140.7
26BD6 CJK UNIFIED IDEOGRAPH-#26BD6, IRGKangXi=1036.070, RSKangXi=140.7
26BD7 CJK UNIFIED IDEOGRAPH-#26BD7, IRGKangXi=1036.080, RSKangXi=140.7
26BD8 CJK UNIFIED IDEOGRAPH-#26BD8, IRGKangXi=1036.090, RSKangXi=140.7
26BD9 CJK UNIFIED IDEOGRAPH-#26BD9, IRGKangXi=1036.100, RSKangXi=140.7
26BDA CJK UNIFIED IDEOGRAPH-#26BDA, IRGKangXi=1036.110, RSKangXi=140.7
26BDB CJK UNIFIED IDEOGRAPH-#26BDB, IRGKangXi=1036.130, RSKangXi=140.7
26BDC CJK UNIFIED IDEOGRAPH-#26BDC, IRGKangXi=1036.140, RSKangXi=140.7
26BDD CJK UNIFIED IDEOGRAPH-#26BDD, IRGKangXi=1036.150, RSKangXi=140.7
26BDE CJK UNIFIED IDEOGRAPH-#26BDE, IRGKangXi=1036.160, RSKangXi=140.7
26BDF CJK UNIFIED IDEOGRAPH-#26BDF, IRGKangXi=1036.170, RSKangXi=140.7
26BE0 CJK UNIFIED IDEOGRAPH-#26BE0, IRGKangXi=1036.180, RSKangXi=140.7
26BE1 CJK UNIFIED IDEOGRAPH-#26BE1, IRGKangXi=1036.200, RSKangXi=140.7
26BE2 CJK UNIFIED IDEOGRAPH-#26BE2, IRGKangXi=1036.210, RSKangXi=140.7
26BE3 CJK UNIFIED IDEOGRAPH-#26BE3, IRGKangXi=1036.220, RSKangXi=140.7
26BE4 CJK UNIFIED IDEOGRAPH-#26BE4, IRGKangXi=1036.230, RSKangXi=140.7
26BE5 CJK UNIFIED IDEOGRAPH-#26BE5, IRGKangXi=1036.240, RSKangXi=140.7
26BE6 CJK UNIFIED IDEOGRAPH-#26BE6, IRGKangXi=1036.250, RSKangXi=140.7
26BE7 CJK UNIFIED IDEOGRAPH-#26BE7, IRGKangXi=1036.260, RSKangXi=140.7
26BE8 CJK UNIFIED IDEOGRAPH-#26BE8, IRGKangXi=1036.270, RSKangXi=140.7
26BE9 CJK UNIFIED IDEOGRAPH-#26BE9, IRGKangXi=1036.290, RSKangXi=140.7
26BEA CJK UNIFIED IDEOGRAPH-#26BEA, IRGKangXi=1036.300, RSKangXi=140.7
26BEB CJK UNIFIED IDEOGRAPH-#26BEB, IRGKangXi=1036.310, RSKangXi=140.7
26BEC CJK UNIFIED IDEOGRAPH-#26BEC, IRGKangXi=1036.320, RSKangXi=140.7
26BED CJK UNIFIED IDEOGRAPH-#26BED, IRGKangXi=1036.330, RSKangXi=140.7
26BEE CJK UNIFIED IDEOGRAPH-#26BEE, IRGKangXi=1036.340, RSKangXi=140.7
26BEF CJK UNIFIED IDEOGRAPH-#26BEF, IRGKangXi=1036.350, RSKangXi=140.7
26BF0 CJK UNIFIED IDEOGRAPH-#26BF0, IRGKangXi=1036.360, RSKangXi=140.7
26BF1 CJK UNIFIED IDEOGRAPH-#26BF1, IRGKangXi=1036.370, RSKangXi=140.8
26BF2 CJK UNIFIED IDEOGRAPH-#26BF2, IRGKangXi=1036.380, RSKangXi=140.7
26BF3 CJK UNIFIED IDEOGRAPH-#26BF3, IRGKangXi=1036.390, RSKangXi=140.7
26BF4 CJK UNIFIED IDEOGRAPH-#26BF4, IRGKangXi=1036.400, RSKangXi=140.7
26BF5 CJK UNIFIED IDEOGRAPH-#26BF5, IRGKangXi=1036.401, RSKangXi=140.7
26BF6 CJK UNIFIED IDEOGRAPH-#26BF6, IRGKangXi=1036.401, RSKangXi=140.7
26BF7 CJK UNIFIED IDEOGRAPH-#26BF7, IRGKangXi=1036.401, RSKangXi=140.7
26BF8 CJK UNIFIED IDEOGRAPH-#26BF8, IRGKangXi=1036.401, RSKangXi=140.7
26BF9 CJK UNIFIED IDEOGRAPH-#26BF9, IRGKangXi=1036.401, RSKangXi=140.7
26BFA CJK UNIFIED IDEOGRAPH-#26BFA, IRGKangXi=1036.401, RSKangXi=140.7
26BFB CJK UNIFIED IDEOGRAPH-#26BFB, IRGKangXi=1036.401, RSKangXi=140.7
26BFC CJK UNIFIED IDEOGRAPH-#26BFC, IRGKangXi=1036.401, RSKangXi=140.7
26BFD CJK UNIFIED IDEOGRAPH-#26BFD, IRGKangXi=1036.401, RSKangXi=140.7
26BFE CJK UNIFIED IDEOGRAPH-#26BFE, IRGKangXi=1036.401, RSKangXi=140.7
26BFF CJK UNIFIED IDEOGRAPH-#26BFF, IRGKangXi=1036.401, RSKangXi=140.7
26C00 CJK UNIFIED IDEOGRAPH-#26C00, IRGKangXi=1036.401, RSKangXi=140.7
26C01 CJK UNIFIED IDEOGRAPH-#26C01, IRGKangXi=1036.401, RSKangXi=140.7
26C02 CJK UNIFIED IDEOGRAPH-#26C02, IRGKangXi=1036.401, RSKangXi=140.7
26C03 CJK UNIFIED IDEOGRAPH-#26C03, IRGKangXi=1036.401, RSKangXi=140.7
26C04 CJK UNIFIED IDEOGRAPH-#26C04, IRGKangXi=1036.401, RSKangXi=140.7
26C05 CJK UNIFIED IDEOGRAPH-#26C05, IRGKangXi=1036.401, RSKangXi=140.7
26C06 CJK UNIFIED IDEOGRAPH-#26C06, IRGKangXi=1036.401, RSKangXi=140.7
26C07 CJK UNIFIED IDEOGRAPH-#26C07, IRGKangXi=1036.401, RSKangXi=140.7
26C08 CJK UNIFIED IDEOGRAPH-#26C08, IRGKangXi=1036.401, RSKangXi=140.7
26C09 CJK UNIFIED IDEOGRAPH-#26C09, IRGKangXi=1036.401, RSKangXi=140.7
26C0A CJK UNIFIED IDEOGRAPH-#26C0A, IRGKangXi=1036.401, RSKangXi=140.7
26C0B CJK UNIFIED IDEOGRAPH-#26C0B, IRGKangXi=1036.401, RSKangXi=140.7
26C0C CJK UNIFIED IDEOGRAPH-#26C0C, IRGKangXi=1036.401, RSKangXi=140.7
26C0D CJK UNIFIED IDEOGRAPH-#26C0D, IRGKangXi=1036.401, RSKangXi=140.7
26C0E CJK UNIFIED IDEOGRAPH-#26C0E, IRGKangXi=1036.401, RSKangXi=140.7
26C0F CJK UNIFIED IDEOGRAPH-#26C0F, IRGKangXi=1036.401, RSKangXi=140.7
26C10 CJK UNIFIED IDEOGRAPH-#26C10, IRGKangXi=1036.401, RSKangXi=140.7
26C11 CJK UNIFIED IDEOGRAPH-#26C11, IRGKangXi=1036.401, RSKangXi=140.7
26C12 CJK UNIFIED IDEOGRAPH-#26C12, IRGKangXi=1036.401, RSKangXi=140.7
26C13 CJK UNIFIED IDEOGRAPH-#26C13, IRGKangXi=1036.401, RSKangXi=140.7
26C14 CJK UNIFIED IDEOGRAPH-#26C14, IRGKangXi=1036.401, RSKangXi=140.7
26C15 CJK UNIFIED IDEOGRAPH-#26C15, IRGKangXi=1036.401, RSKangXi=140.7
26C16 CJK UNIFIED IDEOGRAPH-#26C16, IRGKangXi=1036.401, RSKangXi=140.8
26C17 CJK UNIFIED IDEOGRAPH-#26C17, IRGKangXi=1036.401, RSKangXi=140.7
26C18 CJK UNIFIED IDEOGRAPH-#26C18, IRGKangXi=1036.401, RSKangXi=140.7
26C19 CJK UNIFIED IDEOGRAPH-#26C19, IRGKangXi=1036.401, RSKangXi=140.7
26C1A CJK UNIFIED IDEOGRAPH-#26C1A, IRGKangXi=1036.401, RSKangXi=140.7
26C1B CJK UNIFIED IDEOGRAPH-#26C1B, IRGKangXi=1036.401, RSKangXi=140.7
26C1C CJK UNIFIED IDEOGRAPH-#26C1C, IRGKangXi=1036.401, RSKangXi=140.7
26C1D CJK UNIFIED IDEOGRAPH-#26C1D, IRGKangXi=1036.401, RSKangXi=140.7
26C1E CJK UNIFIED IDEOGRAPH-#26C1E, IRGKangXi=1036.401, RSKangXi=140.7
26C1F CJK UNIFIED IDEOGRAPH-#26C1F, IRGKangXi=1036.401, RSKangXi=140.7
26C20 CJK UNIFIED IDEOGRAPH-#26C20, IRGKangXi=1036.401, RSKangXi=140.7
26C21 CJK UNIFIED IDEOGRAPH-#26C21, IRGKangXi=1036.401, RSKangXi=140.7
26C22 CJK UNIFIED IDEOGRAPH-#26C22, IRGKangXi=1036.401, RSKangXi=140.7
26C23 CJK UNIFIED IDEOGRAPH-#26C23, IRGKangXi=1036.401, RSKangXi=140.7
26C24 CJK UNIFIED IDEOGRAPH-#26C24, IRGKangXi=1036.401, RSKangXi=140.7
26C25 CJK UNIFIED IDEOGRAPH-#26C25, IRGKangXi=1036.401, RSKangXi=140.7
26C26 CJK UNIFIED IDEOGRAPH-#26C26, IRGKangXi=1036.401, RSKangXi=140.7
26C27 CJK UNIFIED IDEOGRAPH-#26C27, IRGKangXi=1036.401, RSKangXi=140.7
26C28 CJK UNIFIED IDEOGRAPH-#26C28, IRGKangXi=1036.401, RSKangXi=140.7
26C29 CJK UNIFIED IDEOGRAPH-#26C29, IRGKangXi=1036.401, RSKangXi=140.7
26C2A CJK UNIFIED IDEOGRAPH-#26C2A, IRGKangXi=1036.460, RSKangXi=140.8
26C2B CJK UNIFIED IDEOGRAPH-#26C2B, IRGKangXi=1036.480, RSKangXi=140.8
26C2C CJK UNIFIED IDEOGRAPH-#26C2C, IRGKangXi=1037.010, RSKangXi=140.8
26C2D CJK UNIFIED IDEOGRAPH-#26C2D, IRGKangXi=1037.020, RSKangXi=140.8
26C2E CJK UNIFIED IDEOGRAPH-#26C2E, IRGKangXi=1037.030, RSKangXi=140.8
26C2F CJK UNIFIED IDEOGRAPH-#26C2F, IRGKangXi=1037.060, RSKangXi=140.8
26C30 CJK UNIFIED IDEOGRAPH-#26C30, IRGKangXi=1037.070, RSKangXi=140.8
26C31 CJK UNIFIED IDEOGRAPH-#26C31, IRGKangXi=1037.090, RSKangXi=140.8
26C32 CJK UNIFIED IDEOGRAPH-#26C32, IRGKangXi=1037.130, RSKangXi=140.8
26C33 CJK UNIFIED IDEOGRAPH-#26C33, IRGKangXi=1037.160, RSKangXi=140.8
26C34 CJK UNIFIED IDEOGRAPH-#26C34, IRGKangXi=1037.170, RSKangXi=140.8
26C35 CJK UNIFIED IDEOGRAPH-#26C35, IRGKangXi=1037.190, RSKangXi=140.8
26C36 CJK UNIFIED IDEOGRAPH-#26C36, IRGKangXi=1037.210, RSKangXi=140.8
26C37 CJK UNIFIED IDEOGRAPH-#26C37, IRGKangXi=1037.300, RSKangXi=140.8
26C38 CJK UNIFIED IDEOGRAPH-#26C38, IRGKangXi=1037.320, RSKangXi=140.8
26C39 CJK UNIFIED IDEOGRAPH-#26C39, IRGKangXi=1038.010, RSKangXi=140.8
26C3A CJK UNIFIED IDEOGRAPH-#26C3A, IRGKangXi=1038.110, RSKangXi=140.8
26C3B CJK UNIFIED IDEOGRAPH-#26C3B, IRGKangXi=1038.140, RSKangXi=140.8
26C3C CJK UNIFIED IDEOGRAPH-#26C3C, IRGKangXi=1038.160, RSKangXi=140.8
26C3D CJK UNIFIED IDEOGRAPH-#26C3D, IRGKangXi=1038.200, RSKangXi=140.8
26C3E CJK UNIFIED IDEOGRAPH-#26C3E, IRGKangXi=1038.230, RSKangXi=140.8
26C3F CJK UNIFIED IDEOGRAPH-#26C3F, IRGKangXi=1038.280, RSKangXi=140.8
26C40 CJK UNIFIED IDEOGRAPH-#26C40, IRGKangXi=1039.100, RSKangXi=140.8
26C41 CJK UNIFIED IDEOGRAPH-#26C41, IRGKangXi=1039.110, RSKangXi=140.8
26C42 CJK UNIFIED IDEOGRAPH-#26C42, IRGKangXi=1039.120, RSKangXi=140.8
26C43 CJK UNIFIED IDEOGRAPH-#26C43, IRGKangXi=1039.160, RSKangXi=140.8
26C44 CJK UNIFIED IDEOGRAPH-#26C44, IRGKangXi=1039.190, RSKangXi=140.8, Def{mushroom}
26C45 CJK UNIFIED IDEOGRAPH-#26C45, IRGKangXi=1039.230, RSKangXi=140.8
26C46 CJK UNIFIED IDEOGRAPH-#26C46, IRGKangXi=1039.240, RSKangXi=140.8
26C47 CJK UNIFIED IDEOGRAPH-#26C47, IRGKangXi=1039.250, RSKangXi=140.8
26C48 CJK UNIFIED IDEOGRAPH-#26C48, IRGKangXi=1039.270, RSKangXi=140.8
26C49 CJK UNIFIED IDEOGRAPH-#26C49, IRGKangXi=1039.280, RSKangXi=140.8
26C4A CJK UNIFIED IDEOGRAPH-#26C4A, IRGKangXi=1040.010, RSKangXi=140.8
26C4B CJK UNIFIED IDEOGRAPH-#26C4B, IRGKangXi=1040.030, RSKangXi=140.8
26C4C CJK UNIFIED IDEOGRAPH-#26C4C, IRGKangXi=1040.050, RSKangXi=140.8
26C4D CJK UNIFIED IDEOGRAPH-#26C4D, IRGKangXi=1040.120, RSKangXi=140.8
26C4E CJK UNIFIED IDEOGRAPH-#26C4E, IRGKangXi=1040.180, RSKangXi=140.8
26C4F CJK UNIFIED IDEOGRAPH-#26C4F, IRGKangXi=1040.190, RSKangXi=140.8
26C50 CJK UNIFIED IDEOGRAPH-#26C50, IRGKangXi=1040.200, RSKangXi=140.8
26C51 CJK UNIFIED IDEOGRAPH-#26C51, IRGKangXi=1040.230, RSKangXi=140.8
26C52 CJK UNIFIED IDEOGRAPH-#26C52, IRGKangXi=1040.280, RSKangXi=140.8
26C53 CJK UNIFIED IDEOGRAPH-#26C53, IRGKangXi=1040.320, RSKangXi=140.8
26C54 CJK UNIFIED IDEOGRAPH-#26C54, IRGKangXi=1041.010, RSKangXi=14.8
26C55 CJK UNIFIED IDEOGRAPH-#26C55, IRGKangXi=1041.030, RSKangXi=140.8
26C56 CJK UNIFIED IDEOGRAPH-#26C56, IRGKangXi=1041.140, RSKangXi=140.8, Def{wolfsbane}
26C57 CJK UNIFIED IDEOGRAPH-#26C57, IRGKangXi=1041.150, RSKangXi=140.8
26C58 CJK UNIFIED IDEOGRAPH-#26C58, IRGKangXi=1041.160, RSKangXi=140.8
26C59 CJK UNIFIED IDEOGRAPH-#26C59, IRGKangXi=1041.170, RSKangXi=140.8
26C5A CJK UNIFIED IDEOGRAPH-#26C5A, IRGKangXi=1041.210, RSKangXi=140.8
26C5B CJK UNIFIED IDEOGRAPH-#26C5B, IRGKangXi=1041.220, RSKangXi=140.8
26C5C CJK UNIFIED IDEOGRAPH-#26C5C, IRGKangXi=1041.230, RSKangXi=140.8
26C5D CJK UNIFIED IDEOGRAPH-#26C5D, IRGKangXi=1041.240, RSKangXi=140.8
26C5E CJK UNIFIED IDEOGRAPH-#26C5E, IRGKangXi=1041.250, RSKangXi=140.8
26C5F CJK UNIFIED IDEOGRAPH-#26C5F, IRGKangXi=1041.260, RSKangXi=140.8
26C60 CJK UNIFIED IDEOGRAPH-#26C60, IRGKangXi=1041.270, RSKangXi=140.8
26C61 CJK UNIFIED IDEOGRAPH-#26C61, IRGKangXi=1041.280, RSKangXi=140.8
26C62 CJK UNIFIED IDEOGRAPH-#26C62, IRGKangXi=1041.290, RSKangXi=140.8
26C63 CJK UNIFIED IDEOGRAPH-#26C63, IRGKangXi=1041.300, RSKangXi=140.8
26C64 CJK UNIFIED IDEOGRAPH-#26C64, IRGKangXi=1041.310, RSKangXi=140.8
26C65 CJK UNIFIED IDEOGRAPH-#26C65, IRGKangXi=1041.320, RSKangXi=140.8
26C66 CJK UNIFIED IDEOGRAPH-#26C66, IRGKangXi=1041.330, RSKangXi=140.8
26C67 CJK UNIFIED IDEOGRAPH-#26C67, IRGKangXi=1041.350, RSKangXi=140.8
26C68 CJK UNIFIED IDEOGRAPH-#26C68, IRGKangXi=1042.010, RSKangXi=140.8
26C69 CJK UNIFIED IDEOGRAPH-#26C69, IRGKangXi=1042.020, RSKangXi=140.8
26C6A CJK UNIFIED IDEOGRAPH-#26C6A, IRGKangXi=1042.040, RSKangXi=140.8
26C6B CJK UNIFIED IDEOGRAPH-#26C6B, IRGKangXi=1042.050, RSKangXi=140.8
26C6C CJK UNIFIED IDEOGRAPH-#26C6C, IRGKangXi=1042.060, RSKangXi=140.8
26C6D CJK UNIFIED IDEOGRAPH-#26C6D, IRGKangXi=1042.070, RSKangXi=140.8
26C6E CJK UNIFIED IDEOGRAPH-#26C6E, IRGKangXi=1042.100, RSKangXi=140.8
26C6F CJK UNIFIED IDEOGRAPH-#26C6F, IRGKangXi=1042.110, RSKangXi=140.8
26C70 CJK UNIFIED IDEOGRAPH-#26C70, IRGKangXi=1042.120, RSKangXi=140.8
26C71 CJK UNIFIED IDEOGRAPH-#26C71, IRGKangXi=1042.130, RSKangXi=140.8
26C72 CJK UNIFIED IDEOGRAPH-#26C72, IRGKangXi=1042.140, RSKangXi=140.8
26C73 CJK UNIFIED IDEOGRAPH-#26C73, IRGKangXi=1042.150, RSKangXi=140.8
26C74 CJK UNIFIED IDEOGRAPH-#26C74, IRGKangXi=1042.160, RSKangXi=140.8
26C75 CJK UNIFIED IDEOGRAPH-#26C75, IRGKangXi=1042.170, RSKangXi=140.8
26C76 CJK UNIFIED IDEOGRAPH-#26C76, IRGKangXi=1042.180, RSKangXi=140.8
26C77 CJK UNIFIED IDEOGRAPH-#26C77, IRGKangXi=1042.190, RSKangXi=140.8
26C78 CJK UNIFIED IDEOGRAPH-#26C78, IRGKangXi=1042.210, RSKangXi=140.8
26C79 CJK UNIFIED IDEOGRAPH-#26C79, IRGKangXi=1042.220, RSKangXi=140.8
26C7A CJK UNIFIED IDEOGRAPH-#26C7A, IRGKangXi=1042.230, RSKangXi=140.8
26C7B CJK UNIFIED IDEOGRAPH-#26C7B, IRGKangXi=1042.240, RSKangXi=140.8
26C7C CJK UNIFIED IDEOGRAPH-#26C7C, IRGKangXi=1042.260, RSKangXi=140.8
26C7D CJK UNIFIED IDEOGRAPH-#26C7D, IRGKangXi=1042.261, RSKangXi=140.8
26C7E CJK UNIFIED IDEOGRAPH-#26C7E, IRGKangXi=1042.261, RSKangXi=140.8
26C7F CJK UNIFIED IDEOGRAPH-#26C7F, IRGKangXi=1042.261, RSKangXi=140.8
26C80 CJK UNIFIED IDEOGRAPH-#26C80, IRGKangXi=1042.261, RSKangXi=140.8
26C81 CJK UNIFIED IDEOGRAPH-#26C81, IRGKangXi=1042.261, RSKangXi=140.8
26C82 CJK UNIFIED IDEOGRAPH-#26C82, IRGKangXi=1042.261, RSKangXi=140.8
26C83 CJK UNIFIED IDEOGRAPH-#26C83, IRGKangXi=1042.261, RSKangXi=140.8
26C84 CJK UNIFIED IDEOGRAPH-#26C84, IRGKangXi=1042.261, RSKangXi=140.8
26C85 CJK UNIFIED IDEOGRAPH-#26C85, IRGKangXi=1042.261, RSKangXi=140.8
26C86 CJK UNIFIED IDEOGRAPH-#26C86, IRGKangXi=1042.261, RSKangXi=140.8
26C87 CJK UNIFIED IDEOGRAPH-#26C87, IRGKangXi=1042.261, RSKangXi=140.8
26C88 CJK UNIFIED IDEOGRAPH-#26C88, IRGKangXi=1042.261, RSKangXi=140.8
26C89 CJK UNIFIED IDEOGRAPH-#26C89, IRGKangXi=1042.261, RSKangXi=140.8
26C8A CJK UNIFIED IDEOGRAPH-#26C8A, IRGKangXi=1042.261, RSKangXi=140.8
26C8B CJK UNIFIED IDEOGRAPH-#26C8B, IRGKangXi=1042.261, RSKangXi=140.8
26C8C CJK UNIFIED IDEOGRAPH-#26C8C, IRGKangXi=1042.261, RSKangXi=140.8
26C8D CJK UNIFIED IDEOGRAPH-#26C8D, IRGKangXi=1042.261, RSKangXi=140.8
26C8E CJK UNIFIED IDEOGRAPH-#26C8E, IRGKangXi=1042.261, RSKangXi=140.8
26C8F CJK UNIFIED IDEOGRAPH-#26C8F, IRGKangXi=1042.261, RSKangXi=140.8
26C90 CJK UNIFIED IDEOGRAPH-#26C90, IRGKangXi=1042.261, RSKangXi=140.8
26C91 CJK UNIFIED IDEOGRAPH-#26C91, IRGKangXi=1042.261, RSKangXi=140.8
26C92 CJK UNIFIED IDEOGRAPH-#26C92, IRGKangXi=1042.261, RSKangXi=140.8
26C93 CJK UNIFIED IDEOGRAPH-#26C93, IRGKangXi=1042.261, RSKangXi=140.8
26C94 CJK UNIFIED IDEOGRAPH-#26C94, IRGKangXi=1042.261, RSKangXi=140.8
26C95 CJK UNIFIED IDEOGRAPH-#26C95, IRGKangXi=1042.261, RSKangXi=140.8
26C96 CJK UNIFIED IDEOGRAPH-#26C96, IRGKangXi=1042.261, RSKangXi=140.8
26C97 CJK UNIFIED IDEOGRAPH-#26C97, IRGKangXi=1042.261, RSKangXi=140.8
26C98 CJK UNIFIED IDEOGRAPH-#26C98, IRGKangXi=1042.261, RSKangXi=140.8
26C99 CJK UNIFIED IDEOGRAPH-#26C99, IRGKangXi=1042.261, RSKangXi=140.8
26C9A CJK UNIFIED IDEOGRAPH-#26C9A, IRGKangXi=1042.261, RSKangXi=140.8
26C9B CJK UNIFIED IDEOGRAPH-#26C9B, IRGKangXi=1042.261, RSKangXi=140.8
26C9C CJK UNIFIED IDEOGRAPH-#26C9C, IRGKangXi=1042.261, RSKangXi=140.8
26C9D CJK UNIFIED IDEOGRAPH-#26C9D, IRGKangXi=1042.261, RSKangXi=140.8
26C9E CJK UNIFIED IDEOGRAPH-#26C9E, IRGKangXi=1042.261, RSKangXi=140.8
26C9F CJK UNIFIED IDEOGRAPH-#26C9F, IRGKangXi=1042.261, RSKangXi=140.8
26CA0 CJK UNIFIED IDEOGRAPH-#26CA0, IRGKangXi=1042.261, RSKangXi=140.8
26CA1 CJK UNIFIED IDEOGRAPH-#26CA1, IRGKangXi=1042.261, RSKangXi=140.8
26CA2 CJK UNIFIED IDEOGRAPH-#26CA2, IRGKangXi=1042.261, RSKangXi=140.8
26CA3 CJK UNIFIED IDEOGRAPH-#26CA3, IRGKangXi=1042.261, RSKangXi=140.8
26CA4 CJK UNIFIED IDEOGRAPH-#26CA4, IRGKangXi=1042.261, RSKangXi=140.8
26CA5 CJK UNIFIED IDEOGRAPH-#26CA5, IRGKangXi=1042.261, RSKangXi=140.8
26CA6 CJK UNIFIED IDEOGRAPH-#26CA6, IRGKangXi=1042.261, RSKangXi=140.8
26CA7 CJK UNIFIED IDEOGRAPH-#26CA7, IRGKangXi=1042.261, RSKangXi=140.8
26CA8 CJK UNIFIED IDEOGRAPH-#26CA8, IRGKangXi=1042.261, RSKangXi=140.8
26CA9 CJK UNIFIED IDEOGRAPH-#26CA9, IRGKangXi=1042.261, RSKangXi=140.8
26CAA CJK UNIFIED IDEOGRAPH-#26CAA, IRGKangXi=1042.261, RSKangXi=140.8
26CAB CJK UNIFIED IDEOGRAPH-#26CAB, IRGKangXi=1042.261, RSKangXi=140.8
26CAC CJK UNIFIED IDEOGRAPH-#26CAC, IRGKangXi=1042.261, RSKangXi=140.8
26CAD CJK UNIFIED IDEOGRAPH-#26CAD, IRGKangXi=1042.261, RSKangXi=140.8
26CAE CJK UNIFIED IDEOGRAPH-#26CAE, IRGKangXi=1042.261, RSKangXi=140.8
26CAF CJK UNIFIED IDEOGRAPH-#26CAF, IRGKangXi=1042.261, RSKangXi=140.8
26CB0 CJK UNIFIED IDEOGRAPH-#26CB0, IRGKangXi=1042.261, RSKangXi=140.8
26CB1 CJK UNIFIED IDEOGRAPH-#26CB1, IRGKangXi=1042.261, RSKangXi=140.8
26CB2 CJK UNIFIED IDEOGRAPH-#26CB2, IRGKangXi=1042.261, RSKangXi=140.8
26CB3 CJK UNIFIED IDEOGRAPH-#26CB3, IRGKangXi=1042.261, RSKangXi=140.8
26CB4 CJK UNIFIED IDEOGRAPH-#26CB4, IRGKangXi=1042.261, RSKangXi=140.8
26CB5 CJK UNIFIED IDEOGRAPH-#26CB5, IRGKangXi=1042.261, RSKangXi=140.8
26CB6 CJK UNIFIED IDEOGRAPH-#26CB6, IRGKangXi=1042.261, RSKangXi=140.8
26CB7 CJK UNIFIED IDEOGRAPH-#26CB7, IRGKangXi=1042.261, RSKangXi=140.8, Def{to arrive, enter}
26CB8 CJK UNIFIED IDEOGRAPH-#26CB8, IRGKangXi=1042.261, RSKangXi=140.8
26CB9 CJK UNIFIED IDEOGRAPH-#26CB9, IRGKangXi=1042.261, RSKangXi=140.8
26CBA CJK UNIFIED IDEOGRAPH-#26CBA, IRGKangXi=1042.261, RSKangXi=140.8
26CBB CJK UNIFIED IDEOGRAPH-#26CBB, IRGKangXi=1042.261, RSKangXi=140.8
26CBC CJK UNIFIED IDEOGRAPH-#26CBC, IRGKangXi=1042.261, RSKangXi=140.8
26CBD CJK UNIFIED IDEOGRAPH-#26CBD, IRGKangXi=1042.261, RSKangXi=140.8
26CBE CJK UNIFIED IDEOGRAPH-#26CBE, IRGKangXi=1042.261, RSKangXi=140.8
26CBF CJK UNIFIED IDEOGRAPH-#26CBF, IRGKangXi=1042.261, RSKangXi=140.8
26CC0 CJK UNIFIED IDEOGRAPH-#26CC0, IRGKangXi=1042.261, RSKangXi=140.8
26CC1 CJK UNIFIED IDEOGRAPH-#26CC1, IRGKangXi=1042.290, RSKangXi=140.9
26CC2 CJK UNIFIED IDEOGRAPH-#26CC2, IRGKangXi=1042.460, RSKangXi=140.9
26CC3 CJK UNIFIED IDEOGRAPH-#26CC3, IRGKangXi=1043.020, RSKangXi=140.9
26CC4 CJK UNIFIED IDEOGRAPH-#26CC4, IRGKangXi=1043.040, RSKangXi=140.9
26CC5 CJK UNIFIED IDEOGRAPH-#26CC5, IRGKangXi=1043.060, RSKangXi=140.9
26CC6 CJK UNIFIED IDEOGRAPH-#26CC6, IRGKangXi=1043.120, RSKangXi=140.9
26CC7 CJK UNIFIED IDEOGRAPH-#26CC7, IRGKangXi=1043.140, RSKangXi=140.9
26CC8 CJK UNIFIED IDEOGRAPH-#26CC8, IRGKangXi=1043.170, RSKangXi=140.9
26CC9 CJK UNIFIED IDEOGRAPH-#26CC9, IRGKangXi=1043.190, RSKangXi=140.9
26CCA CJK UNIFIED IDEOGRAPH-#26CCA, IRGKangXi=1043.200, RSKangXi=140.9
26CCB CJK UNIFIED IDEOGRAPH-#26CCB, IRGKangXi=1043.210, RSKangXi=140.9
26CCC CJK UNIFIED IDEOGRAPH-#26CCC, IRGKangXi=1043.230, RSKangXi=140.9
26CCD CJK UNIFIED IDEOGRAPH-#26CCD, IRGKangXi=1043.260, RSKangXi=140.9
26CCE CJK UNIFIED IDEOGRAPH-#26CCE, IRGKangXi=1043.270, RSKangXi=140.9
26CCF CJK UNIFIED IDEOGRAPH-#26CCF, IRGKangXi=1043.280, RSKangXi=140.9
26CD0 CJK UNIFIED IDEOGRAPH-#26CD0, IRGKangXi=1043.310, RSKangXi=140.9
26CD1 CJK UNIFIED IDEOGRAPH-#26CD1, IRGKangXi=1044.010, RSKangXi=140.9
26CD2 CJK UNIFIED IDEOGRAPH-#26CD2, IRGKangXi=1044.050, RSKangXi=140.9
26CD3 CJK UNIFIED IDEOGRAPH-#26CD3, IRGKangXi=1044.060, RSKangXi=140.9
26CD4 CJK UNIFIED IDEOGRAPH-#26CD4, IRGKangXi=1044.070, RSKangXi=140.9
26CD5 CJK UNIFIED IDEOGRAPH-#26CD5, IRGKangXi=1044.080, RSKangXi=140.9
26CD6 CJK UNIFIED IDEOGRAPH-#26CD6, IRGKangXi=1044.120, RSKangXi=140.9
26CD7 CJK UNIFIED IDEOGRAPH-#26CD7, IRGKangXi=1044.170, RSKangXi=140.9
26CD8 CJK UNIFIED IDEOGRAPH-#26CD8, IRGKangXi=1044.240, RSKangXi=140.9
26CD9 CJK UNIFIED IDEOGRAPH-#26CD9, IRGKangXi=1045.010, RSKangXi=140.9
26CDA CJK UNIFIED IDEOGRAPH-#26CDA, IRGKangXi=1045.050, RSKangXi=140.9
26CDB CJK UNIFIED IDEOGRAPH-#26CDB, IRGKangXi=1045.070, RSKangXi=140.9
26CDC CJK UNIFIED IDEOGRAPH-#26CDC, IRGKangXi=1045.090, RSKangXi=140.9
26CDD CJK UNIFIED IDEOGRAPH-#26CDD, IRGKangXi=1045.130, RSKangXi=140.9
26CDE CJK UNIFIED IDEOGRAPH-#26CDE, IRGKangXi=1045.160, RSKangXi=140.9
26CDF CJK UNIFIED IDEOGRAPH-#26CDF, IRGKangXi=1045.190, RSKangXi=140.9
26CE0 CJK UNIFIED IDEOGRAPH-#26CE0, IRGKangXi=1045.210, RSKangXi=140.9
26CE1 CJK UNIFIED IDEOGRAPH-#26CE1, IRGKangXi=1045.250, RSKangXi=140.9
26CE2 CJK UNIFIED IDEOGRAPH-#26CE2, IRGKangXi=1045.300, RSKangXi=140.9
26CE3 CJK UNIFIED IDEOGRAPH-#26CE3, IRGKangXi=1046.010, RSKangXi=140.9
26CE4 CJK UNIFIED IDEOGRAPH-#26CE4, IRGKangXi=1046.020, RSKangXi=140.9
26CE5 CJK UNIFIED IDEOGRAPH-#26CE5, IRGKangXi=1046.030, RSKangXi=140.9
26CE6 CJK UNIFIED IDEOGRAPH-#26CE6, IRGKangXi=1046.040, RSKangXi=140.9
26CE7 CJK UNIFIED IDEOGRAPH-#26CE7, IRGKangXi=1046.130, RSKangXi=140.9
26CE8 CJK UNIFIED IDEOGRAPH-#26CE8, IRGKangXi=1046.220, RSKangXi=140.9
26CE9 CJK UNIFIED IDEOGRAPH-#26CE9, IRGKangXi=1046.240, RSKangXi=140.9
26CEA CJK UNIFIED IDEOGRAPH-#26CEA, IRGKangXi=1047.050, RSKangXi=140.9
26CEB CJK UNIFIED IDEOGRAPH-#26CEB, IRGKangXi=1047.060, RSKangXi=140.9
26CEC CJK UNIFIED IDEOGRAPH-#26CEC, IRGKangXi=1047.070, RSKangXi=140.9
26CED CJK UNIFIED IDEOGRAPH-#26CED, IRGKangXi=1047.080, RSKangXi=140.9
26CEE CJK UNIFIED IDEOGRAPH-#26CEE, IRGKangXi=1047.110, RSKangXi=140.9
26CEF CJK UNIFIED IDEOGRAPH-#26CEF, IRGKangXi=1047.140, RSKangXi=140.9
26CF0 CJK UNIFIED IDEOGRAPH-#26CF0, IRGKangXi=1047.150, RSKangXi=140.9
26CF1 CJK UNIFIED IDEOGRAPH-#26CF1, IRGKangXi=1047.160, RSKangXi=140.9
26CF2 CJK UNIFIED IDEOGRAPH-#26CF2, IRGKangXi=1047.170, RSKangXi=140.9
26CF3 CJK UNIFIED IDEOGRAPH-#26CF3, IRGKangXi=1047.180, RSKangXi=140.9
26CF4 CJK UNIFIED IDEOGRAPH-#26CF4, IRGKangXi=1047.190, RSKangXi=140.9
26CF5 CJK UNIFIED IDEOGRAPH-#26CF5, IRGKangXi=1047.200, RSKangXi=140.9
26CF6 CJK UNIFIED IDEOGRAPH-#26CF6, IRGKangXi=1047.210, RSKangXi=140.9
26CF7 CJK UNIFIED IDEOGRAPH-#26CF7, IRGKangXi=1047.220, RSKangXi=140.9
26CF8 CJK UNIFIED IDEOGRAPH-#26CF8, IRGKangXi=1047.230, RSKangXi=140.9
26CF9 CJK UNIFIED IDEOGRAPH-#26CF9, IRGKangXi=1047.240, RSKangXi=140.9
26CFA CJK UNIFIED IDEOGRAPH-#26CFA, IRGKangXi=1047.260, RSKangXi=140.9
26CFB CJK UNIFIED IDEOGRAPH-#26CFB, IRGKangXi=1047.270, RSKangXi=140.9
26CFC CJK UNIFIED IDEOGRAPH-#26CFC, IRGKangXi=1047.280, RSKangXi=140.9
26CFD CJK UNIFIED IDEOGRAPH-#26CFD, IRGKangXi=1047.290, RSKangXi=140.9
26CFE CJK UNIFIED IDEOGRAPH-#26CFE, IRGKangXi=1047.300, RSKangXi=140.9
26CFF CJK UNIFIED IDEOGRAPH-#26CFF, IRGKangXi=1047.310, RSKangXi=140.9
26D00 CJK UNIFIED IDEOGRAPH-#26D00, IRGKangXi=1047.330, RSKangXi=140.9
26D01 CJK UNIFIED IDEOGRAPH-#26D01, IRGKangXi=1047.350, RSKangXi=140.9
26D02 CJK UNIFIED IDEOGRAPH-#26D02, IRGKangXi=1047.360, RSKangXi=140.9
26D03 CJK UNIFIED IDEOGRAPH-#26D03, IRGKangXi=1047.380, RSKangXi=140.9
26D04 CJK UNIFIED IDEOGRAPH-#26D04, IRGKangXi=1047.390, RSKangXi=140.9
26D05 CJK UNIFIED IDEOGRAPH-#26D05, IRGKangXi=1047.400, RSKangXi=140.9
26D06 CJK UNIFIED IDEOGRAPH-#26D06, IRGKangXi=1047.410, RSKangXi=140.9
26D07 CJK UNIFIED IDEOGRAPH-#26D07, IRGKangXi=1047.420, RSKangXi=140.9
26D08 CJK UNIFIED IDEOGRAPH-#26D08, IRGKangXi=1047.430, RSKangXi=140.9
26D09 CJK UNIFIED IDEOGRAPH-#26D09, IRGKangXi=1047.440, RSKangXi=140.9
26D0A CJK UNIFIED IDEOGRAPH-#26D0A, IRGKangXi=1047.450, RSKangXi=140.9
26D0B CJK UNIFIED IDEOGRAPH-#26D0B, IRGKangXi=1047.460, RSKangXi=140.9
26D0C CJK UNIFIED IDEOGRAPH-#26D0C, IRGKangXi=1047.470, RSKangXi=140.9
26D0D CJK UNIFIED IDEOGRAPH-#26D0D, IRGKangXi=1047.480, RSKangXi=140.9
26D0E CJK UNIFIED IDEOGRAPH-#26D0E, IRGKangXi=1047.490, RSKangXi=140.9
26D0F CJK UNIFIED IDEOGRAPH-#26D0F, IRGKangXi=1047.500, RSKangXi=140.9
26D10 CJK UNIFIED IDEOGRAPH-#26D10, IRGKangXi=1047.520, RSKangXi=140.9
26D11 CJK UNIFIED IDEOGRAPH-#26D11, IRGKangXi=1047.530, RSKangXi=140.9
26D12 CJK UNIFIED IDEOGRAPH-#26D12, IRGKangXi=1047.540, RSKangXi=140.9
26D13 CJK UNIFIED IDEOGRAPH-#26D13, IRGKangXi=1047.550, RSKangXi=140.9
26D14 CJK UNIFIED IDEOGRAPH-#26D14, IRGKangXi=1047.560, RSKangXi=140.9
26D15 CJK UNIFIED IDEOGRAPH-#26D15, IRGKangXi=1047.570, RSKangXi=140.9
26D16 CJK UNIFIED IDEOGRAPH-#26D16, IRGKangXi=1047.580, RSKangXi=140.9
26D17 CJK UNIFIED IDEOGRAPH-#26D17, IRGKangXi=1047.590, RSKangXi=140.9
26D18 CJK UNIFIED IDEOGRAPH-#26D18, IRGKangXi=1047.600, RSKangXi=140.9
26D19 CJK UNIFIED IDEOGRAPH-#26D19, IRGKangXi=1047.610, RSKangXi=140.9
26D1A CJK UNIFIED IDEOGRAPH-#26D1A, IRGKangXi=1047.620, RSKangXi=140.9
26D1B CJK UNIFIED IDEOGRAPH-#26D1B, IRGKangXi=1047.630, RSKangXi=140.9
26D1C CJK UNIFIED IDEOGRAPH-#26D1C, IRGKangXi=1047.640, RSKangXi=140.9
26D1D CJK UNIFIED IDEOGRAPH-#26D1D, IRGKangXi=1047.650, RSKangXi=140.9
26D1E CJK UNIFIED IDEOGRAPH-#26D1E, IRGKangXi=1047.660, RSKangXi=140.9
26D1F CJK UNIFIED IDEOGRAPH-#26D1F, IRGKangXi=1047.671, RSKangXi=140.9
26D20 CJK UNIFIED IDEOGRAPH-#26D20, IRGKangXi=1047.671, RSKangXi=140.9
26D21 CJK UNIFIED IDEOGRAPH-#26D21, IRGKangXi=1047.671, RSKangXi=140.9
26D22 CJK UNIFIED IDEOGRAPH-#26D22, IRGKangXi=1047.671, RSKangXi=140.9
26D23 CJK UNIFIED IDEOGRAPH-#26D23, IRGKangXi=1047.671, RSKangXi=140.9
26D24 CJK UNIFIED IDEOGRAPH-#26D24, IRGKangXi=1047.671, RSKangXi=140.9
26D25 CJK UNIFIED IDEOGRAPH-#26D25, IRGKangXi=1047.671, RSKangXi=140.9
26D26 CJK UNIFIED IDEOGRAPH-#26D26, IRGKangXi=1047.671, RSKangXi=140.9
26D27 CJK UNIFIED IDEOGRAPH-#26D27, IRGKangXi=1047.671, RSKangXi=140.9
26D28 CJK UNIFIED IDEOGRAPH-#26D28, IRGKangXi=1047.671, RSKangXi=140.9
26D29 CJK UNIFIED IDEOGRAPH-#26D29, IRGKangXi=1047.671, RSKangXi=140.9
26D2A CJK UNIFIED IDEOGRAPH-#26D2A, IRGKangXi=1047.671, RSKangXi=140.9
26D2B CJK UNIFIED IDEOGRAPH-#26D2B, IRGKangXi=1047.671, RSKangXi=140.9
26D2C CJK UNIFIED IDEOGRAPH-#26D2C, IRGKangXi=1047.671, RSKangXi=140.9
26D2D CJK UNIFIED IDEOGRAPH-#26D2D, IRGKangXi=1047.671, RSKangXi=140.9
26D2E CJK UNIFIED IDEOGRAPH-#26D2E, IRGKangXi=1047.671, RSKangXi=140.9
26D2F CJK UNIFIED IDEOGRAPH-#26D2F, IRGKangXi=1047.671, RSKangXi=140.9
26D30 CJK UNIFIED IDEOGRAPH-#26D30, IRGKangXi=1047.671, RSKangXi=140.9
26D31 CJK UNIFIED IDEOGRAPH-#26D31, IRGKangXi=1047.671, RSKangXi=140.9
26D32 CJK UNIFIED IDEOGRAPH-#26D32, IRGKangXi=1047.671, RSKangXi=140.9
26D33 CJK UNIFIED IDEOGRAPH-#26D33, IRGKangXi=1047.671, RSKangXi=140.9
26D34 CJK UNIFIED IDEOGRAPH-#26D34, IRGKangXi=1047.671, RSKangXi=140.9
26D35 CJK UNIFIED IDEOGRAPH-#26D35, IRGKangXi=1047.671, RSKangXi=140.9
26D36 CJK UNIFIED IDEOGRAPH-#26D36, IRGKangXi=1047.671, RSKangXi=85.10
26D37 CJK UNIFIED IDEOGRAPH-#26D37, IRGKangXi=1047.671, RSKangXi=140.9
26D38 CJK UNIFIED IDEOGRAPH-#26D38, IRGKangXi=1047.671, RSKangXi=140.9
26D39 CJK UNIFIED IDEOGRAPH-#26D39, IRGKangXi=1047.671, RSKangXi=140.9
26D3A CJK UNIFIED IDEOGRAPH-#26D3A, IRGKangXi=1047.671, RSKangXi=140.9
26D3B CJK UNIFIED IDEOGRAPH-#26D3B, IRGKangXi=1047.671, RSKangXi=140.9
26D3C CJK UNIFIED IDEOGRAPH-#26D3C, IRGKangXi=1047.671, RSKangXi=140.9
26D3D CJK UNIFIED IDEOGRAPH-#26D3D, IRGKangXi=1047.671, RSKangXi=140.9
26D3E CJK UNIFIED IDEOGRAPH-#26D3E, IRGKangXi=1047.671, RSKangXi=140.9
26D3F CJK UNIFIED IDEOGRAPH-#26D3F, IRGKangXi=1047.671, RSKangXi=140.9
26D40 CJK UNIFIED IDEOGRAPH-#26D40, IRGKangXi=1047.671, RSKangXi=140.9
26D41 CJK UNIFIED IDEOGRAPH-#26D41, IRGKangXi=1047.671, RSKangXi=140.9
26D42 CJK UNIFIED IDEOGRAPH-#26D42, IRGKangXi=1047.671, RSKangXi=140.9
26D43 CJK UNIFIED IDEOGRAPH-#26D43, IRGKangXi=1047.671, RSKangXi=140.9
26D44 CJK UNIFIED IDEOGRAPH-#26D44, IRGKangXi=1047.671, RSKangXi=140.9
26D45 CJK UNIFIED IDEOGRAPH-#26D45, IRGKangXi=1047.671, RSKangXi=140.9
26D46 CJK UNIFIED IDEOGRAPH-#26D46, IRGKangXi=1047.671, RSKangXi=140.9
26D47 CJK UNIFIED IDEOGRAPH-#26D47, IRGKangXi=1047.671, RSKangXi=140.10
26D48 CJK UNIFIED IDEOGRAPH-#26D48, IRGKangXi=1047.671, RSKangXi=140.9
26D49 CJK UNIFIED IDEOGRAPH-#26D49, IRGKangXi=1047.671, RSKangXi=140.9
26D4A CJK UNIFIED IDEOGRAPH-#26D4A, IRGKangXi=1047.671, RSKangXi=140.9
26D4B CJK UNIFIED IDEOGRAPH-#26D4B, IRGKangXi=1047.671, RSKangXi=140.9
26D4C CJK UNIFIED IDEOGRAPH-#26D4C, IRGKangXi=1047.671, RSKangXi=140.9
26D4D CJK UNIFIED IDEOGRAPH-#26D4D, IRGKangXi=1047.671, RSKangXi=140.9
26D4E CJK UNIFIED IDEOGRAPH-#26D4E, IRGKangXi=1047.671, RSKangXi=140.9
26D4F CJK UNIFIED IDEOGRAPH-#26D4F, IRGKangXi=1047.671, RSKangXi=140.9
26D50 CJK UNIFIED IDEOGRAPH-#26D50, IRGKangXi=1047.671, RSKangXi=140.9
26D51 CJK UNIFIED IDEOGRAPH-#26D51, IRGKangXi=1047.671, RSKangXi=140.9
26D52 CJK UNIFIED IDEOGRAPH-#26D52, IRGKangXi=1047.671, RSKangXi=140.9
26D53 CJK UNIFIED IDEOGRAPH-#26D53, IRGKangXi=1047.671, RSKangXi=140.9
26D54 CJK UNIFIED IDEOGRAPH-#26D54, IRGKangXi=1047.671, RSKangXi=140.9
26D55 CJK UNIFIED IDEOGRAPH-#26D55, IRGKangXi=1047.671, RSKangXi=140.9
26D56 CJK UNIFIED IDEOGRAPH-#26D56, IRGKangXi=1047.671, RSKangXi=140.9
26D57 CJK UNIFIED IDEOGRAPH-#26D57, IRGKangXi=1047.671, RSKangXi=140.9
26D58 CJK UNIFIED IDEOGRAPH-#26D58, IRGKangXi=1047.671, RSKangXi=140.9
26D59 CJK UNIFIED IDEOGRAPH-#26D59, IRGKangXi=1047.671, RSKangXi=140.9
26D5A CJK UNIFIED IDEOGRAPH-#26D5A, IRGKangXi=1047.671, RSKangXi=140.9
26D5B CJK UNIFIED IDEOGRAPH-#26D5B, IRGKangXi=1047.671, RSKangXi=140.9
26D5C CJK UNIFIED IDEOGRAPH-#26D5C, IRGKangXi=1047.671, RSKangXi=140.9
26D5D CJK UNIFIED IDEOGRAPH-#26D5D, IRGKangXi=1047.671, RSKangXi=140.9
26D5E CJK UNIFIED IDEOGRAPH-#26D5E, IRGKangXi=1047.671, RSKangXi=140.9
26D5F CJK UNIFIED IDEOGRAPH-#26D5F, IRGKangXi=1047.671, RSKangXi=140.9
26D60 CJK UNIFIED IDEOGRAPH-#26D60, IRGKangXi=1047.671, RSKangXi=140.9
26D61 CJK UNIFIED IDEOGRAPH-#26D61, IRGKangXi=1047.680, RSKangXi=140.10
26D62 CJK UNIFIED IDEOGRAPH-#26D62, IRGKangXi=1047.700, RSKangXi=140.10
26D63 CJK UNIFIED IDEOGRAPH-#26D63, IRGKangXi=1048.020, RSKangXi=140.10
26D64 CJK UNIFIED IDEOGRAPH-#26D64, IRGKangXi=1048.060, RSKangXi=140.10
26D65 CJK UNIFIED IDEOGRAPH-#26D65, IRGKangXi=1048.080, RSKangXi=140.10
26D66 CJK UNIFIED IDEOGRAPH-#26D66, IRGKangXi=1048.110, RSKangXi=140.10
26D67 CJK UNIFIED IDEOGRAPH-#26D67, IRGKangXi=1048.130, RSKangXi=140.10
26D68 CJK UNIFIED IDEOGRAPH-#26D68, IRGKangXi=1048.170, RSKangXi=140.10
26D69 CJK UNIFIED IDEOGRAPH-#26D69, IRGKangXi=1048.190, RSKangXi=140.10
26D6A CJK UNIFIED IDEOGRAPH-#26D6A, IRGKangXi=1048.200, RSKangXi=140.10
26D6B CJK UNIFIED IDEOGRAPH-#26D6B, IRGKangXi=1048.230, RSKangXi=140.10
26D6C CJK UNIFIED IDEOGRAPH-#26D6C, IRGKangXi=1048.270, RSKangXi=140.10
26D6D CJK UNIFIED IDEOGRAPH-#26D6D, IRGKangXi=1048.290, RSKangXi=140.10
26D6E CJK UNIFIED IDEOGRAPH-#26D6E, IRGKangXi=1048.300, RSKangXi=140.10
26D6F CJK UNIFIED IDEOGRAPH-#26D6F, IRGKangXi=1048.330, RSKangXi=140.10
26D70 CJK UNIFIED IDEOGRAPH-#26D70, IRGKangXi=1049.040, RSKangXi=140.10
26D71 CJK UNIFIED IDEOGRAPH-#26D71, IRGKangXi=1049.050, RSKangXi=140.10
26D72 CJK UNIFIED IDEOGRAPH-#26D72, IRGKangXi=1049.060, RSKangXi=140.10
26D73 CJK UNIFIED IDEOGRAPH-#26D73, IRGKangXi=1049.070, RSKangXi=140.10
26D74 CJK UNIFIED IDEOGRAPH-#26D74, IRGKangXi=1049.100, RSKangXi=140.10
26D75 CJK UNIFIED IDEOGRAPH-#26D75, IRGKangXi=1049.110, RSKangXi=140.10
26D76 CJK UNIFIED IDEOGRAPH-#26D76, IRGKangXi=1049.120, RSKangXi=140.10
26D77 CJK UNIFIED IDEOGRAPH-#26D77, IRGKangXi=1049.130, RSKangXi=140.10
26D78 CJK UNIFIED IDEOGRAPH-#26D78, IRGKangXi=1049.150, RSKangXi=140.10
26D79 CJK UNIFIED IDEOGRAPH-#26D79, IRGKangXi=1049.230, RSKangXi=140.10
26D7A CJK UNIFIED IDEOGRAPH-#26D7A, IRGKangXi=1049.250, RSKangXi=140.10
26D7B CJK UNIFIED IDEOGRAPH-#26D7B, IRGKangXi=1049.290, RSKangXi=140.10
26D7C CJK UNIFIED IDEOGRAPH-#26D7C, IRGKangXi=1049.300, RSKangXi=140.10
26D7D CJK UNIFIED IDEOGRAPH-#26D7D, IRGKangXi=1049.310, RSKangXi=140.10
26D7E CJK UNIFIED IDEOGRAPH-#26D7E, IRGKangXi=1049.320, RSKangXi=140.10
26D7F CJK UNIFIED IDEOGRAPH-#26D7F, IRGKangXi=1049.340, RSKangXi=140.10
26D80 CJK UNIFIED IDEOGRAPH-#26D80, IRGKangXi=1050.090, RSKangXi=140.10
26D81 CJK UNIFIED IDEOGRAPH-#26D81, IRGKangXi=1050.130, RSKangXi=140.10
26D82 CJK UNIFIED IDEOGRAPH-#26D82, IRGKangXi=1050.140, RSKangXi=140.10
26D83 CJK UNIFIED IDEOGRAPH-#26D83, IRGKangXi=1050.150, RSKangXi=140.10
26D84 CJK UNIFIED IDEOGRAPH-#26D84, IRGKangXi=1050.190, RSKangXi=140.10
26D85 CJK UNIFIED IDEOGRAPH-#26D85, IRGKangXi=1050.230, RSKangXi=140.10
26D86 CJK UNIFIED IDEOGRAPH-#26D86, IRGKangXi=1050.240, RSKangXi=140.10
26D87 CJK UNIFIED IDEOGRAPH-#26D87, IRGKangXi=1050.270, RSKangXi=140.10
26D88 CJK UNIFIED IDEOGRAPH-#26D88, IRGKangXi=1050.280, RSKangXi=140.10
26D89 CJK UNIFIED IDEOGRAPH-#26D89, IRGKangXi=1050.290, RSKangXi=140.10
26D8A CJK UNIFIED IDEOGRAPH-#26D8A, IRGKangXi=1051.030, RSKangXi=140.10
26D8B CJK UNIFIED IDEOGRAPH-#26D8B, IRGKangXi=1051.090, RSKangXi=140.10
26D8C CJK UNIFIED IDEOGRAPH-#26D8C, IRGKangXi=1051.190, RSKangXi=140.10
26D8D CJK UNIFIED IDEOGRAPH-#26D8D, IRGKangXi=1051.210, RSKangXi=140.10
26D8E CJK UNIFIED IDEOGRAPH-#26D8E, IRGKangXi=1051.280, RSKangXi=140.10
26D8F CJK UNIFIED IDEOGRAPH-#26D8F, IRGKangXi=1051.290, RSKangXi=140.10
26D90 CJK UNIFIED IDEOGRAPH-#26D90, IRGKangXi=1051.300, RSKangXi=140.10
26D91 CJK UNIFIED IDEOGRAPH-#26D91, IRGKangXi=1051.310, RSKangXi=140.10
26D92 CJK UNIFIED IDEOGRAPH-#26D92, IRGKangXi=1051.320, RSKangXi=140.10
26D93 CJK UNIFIED IDEOGRAPH-#26D93, IRGKangXi=1051.330, RSKangXi=140.10
26D94 CJK UNIFIED IDEOGRAPH-#26D94, IRGKangXi=1051.340, RSKangXi=140.10
26D95 CJK UNIFIED IDEOGRAPH-#26D95, IRGKangXi=1051.360, RSKangXi=140.10
26D96 CJK UNIFIED IDEOGRAPH-#26D96, IRGKangXi=1051.370, RSKangXi=140.10
26D97 CJK UNIFIED IDEOGRAPH-#26D97, IRGKangXi=1051.380, RSKangXi=140.10
26D98 CJK UNIFIED IDEOGRAPH-#26D98, IRGKangXi=1052.010, RSKangXi=140.10
26D99 CJK UNIFIED IDEOGRAPH-#26D99, IRGKangXi=1052.020, RSKangXi=140.10
26D9A CJK UNIFIED IDEOGRAPH-#26D9A, IRGKangXi=1052.040, RSKangXi=140.10
26D9B CJK UNIFIED IDEOGRAPH-#26D9B, IRGKangXi=1052.050, RSKangXi=140.10
26D9C CJK UNIFIED IDEOGRAPH-#26D9C, IRGKangXi=1052.051, RSKangXi=140.10
26D9D CJK UNIFIED IDEOGRAPH-#26D9D, IRGKangXi=1052.051, RSKangXi=140.10
26D9E CJK UNIFIED IDEOGRAPH-#26D9E, IRGKangXi=1052.051, RSKangXi=140.10
26D9F CJK UNIFIED IDEOGRAPH-#26D9F, IRGKangXi=1052.051, RSKangXi=140.10
26DA0 CJK UNIFIED IDEOGRAPH-#26DA0, IRGKangXi=1052.051, RSKangXi=140.10
26DA1 CJK UNIFIED IDEOGRAPH-#26DA1, IRGKangXi=1052.051, RSKangXi=140.10
26DA2 CJK UNIFIED IDEOGRAPH-#26DA2, IRGKangXi=1052.051, RSKangXi=140.10
26DA3 CJK UNIFIED IDEOGRAPH-#26DA3, IRGKangXi=1052.051, RSKangXi=140.10
26DA4 CJK UNIFIED IDEOGRAPH-#26DA4, IRGKangXi=1052.051, RSKangXi=140.10
26DA5 CJK UNIFIED IDEOGRAPH-#26DA5, IRGKangXi=1052.051, RSKangXi=140.10
26DA6 CJK UNIFIED IDEOGRAPH-#26DA6, IRGKangXi=1052.051, RSKangXi=140.10
26DA7 CJK UNIFIED IDEOGRAPH-#26DA7, IRGKangXi=1052.051, RSKangXi=140.10
26DA8 CJK UNIFIED IDEOGRAPH-#26DA8, IRGKangXi=1052.051, RSKangXi=140.10
26DA9 CJK UNIFIED IDEOGRAPH-#26DA9, IRGKangXi=1052.051, RSKangXi=140.10
26DAA CJK UNIFIED IDEOGRAPH-#26DAA, IRGKangXi=1052.051, RSKangXi=140.10
26DAB CJK UNIFIED IDEOGRAPH-#26DAB, IRGKangXi=1052.051, RSKangXi=140.10
26DAC CJK UNIFIED IDEOGRAPH-#26DAC, IRGKangXi=1052.051, RSKangXi=140.10
26DAD CJK UNIFIED IDEOGRAPH-#26DAD, IRGKangXi=1052.051, RSKangXi=140.10
26DAE CJK UNIFIED IDEOGRAPH-#26DAE, IRGKangXi=1052.051, RSKangXi=140.10
26DAF CJK UNIFIED IDEOGRAPH-#26DAF, IRGKangXi=1052.051, RSKangXi=140.10
26DB0 CJK UNIFIED IDEOGRAPH-#26DB0, IRGKangXi=1052.051, RSKangXi=140.10
26DB1 CJK UNIFIED IDEOGRAPH-#26DB1, IRGKangXi=1052.051, RSKangXi=140.10
26DB2 CJK UNIFIED IDEOGRAPH-#26DB2, IRGKangXi=1052.051, RSKangXi=140.10, Def{cardamom seeds}
26DB3 CJK UNIFIED IDEOGRAPH-#26DB3, IRGKangXi=1052.051, RSKangXi=140.10
26DB4 CJK UNIFIED IDEOGRAPH-#26DB4, IRGKangXi=1052.051, RSKangXi=140.10
26DB5 CJK UNIFIED IDEOGRAPH-#26DB5, IRGKangXi=1052.051, RSKangXi=140.10
26DB6 CJK UNIFIED IDEOGRAPH-#26DB6, IRGKangXi=1052.051, RSKangXi=140.10
26DB7 CJK UNIFIED IDEOGRAPH-#26DB7, IRGKangXi=1052.051, RSKangXi=140.10
26DB8 CJK UNIFIED IDEOGRAPH-#26DB8, IRGKangXi=1052.051, RSKangXi=140.10
26DB9 CJK UNIFIED IDEOGRAPH-#26DB9, IRGKangXi=1052.051, RSKangXi=140.10
26DBA CJK UNIFIED IDEOGRAPH-#26DBA, IRGKangXi=1052.051, RSKangXi=140.10
26DBB CJK UNIFIED IDEOGRAPH-#26DBB, IRGKangXi=1052.051, RSKangXi=140.10
26DBC CJK UNIFIED IDEOGRAPH-#26DBC, IRGKangXi=1052.051, RSKangXi=140.10
26DBD CJK UNIFIED IDEOGRAPH-#26DBD, IRGKangXi=1052.051, RSKangXi=140.10
26DBE CJK UNIFIED IDEOGRAPH-#26DBE, IRGKangXi=1052.051, RSKangXi=140.10
26DBF CJK UNIFIED IDEOGRAPH-#26DBF, IRGKangXi=1052.051, RSKangXi=140.10
26DC0 CJK UNIFIED IDEOGRAPH-#26DC0, IRGKangXi=1052.051, RSKangXi=140.10
26DC1 CJK UNIFIED IDEOGRAPH-#26DC1, IRGKangXi=1052.051, RSKangXi=140.10
26DC2 CJK UNIFIED IDEOGRAPH-#26DC2, IRGKangXi=1052.051, RSKangXi=140.10
26DC3 CJK UNIFIED IDEOGRAPH-#26DC3, IRGKangXi=1052.051, RSKangXi=140.10
26DC4 CJK UNIFIED IDEOGRAPH-#26DC4, IRGKangXi=1052.051, RSKangXi=140.10
26DC5 CJK UNIFIED IDEOGRAPH-#26DC5, IRGKangXi=1052.051, RSKangXi=140.10
26DC6 CJK UNIFIED IDEOGRAPH-#26DC6, IRGKangXi=1052.051, RSKangXi=140.10
26DC7 CJK UNIFIED IDEOGRAPH-#26DC7, IRGKangXi=1052.051, RSKangXi=140.10
26DC8 CJK UNIFIED IDEOGRAPH-#26DC8, IRGKangXi=1052.051, RSKangXi=140.10
26DC9 CJK UNIFIED IDEOGRAPH-#26DC9, IRGKangXi=1052.051, RSKangXi=140.10
26DCA CJK UNIFIED IDEOGRAPH-#26DCA, IRGKangXi=1052.051, RSKangXi=140.10
26DCB CJK UNIFIED IDEOGRAPH-#26DCB, IRGKangXi=1052.051, RSKangXi=140.10
26DCC CJK UNIFIED IDEOGRAPH-#26DCC, IRGKangXi=1052.051, RSKangXi=140.10
26DCD CJK UNIFIED IDEOGRAPH-#26DCD, IRGKangXi=1052.051, RSKangXi=140.10
26DCE CJK UNIFIED IDEOGRAPH-#26DCE, IRGKangXi=1052.051, RSKangXi=140.10
26DCF CJK UNIFIED IDEOGRAPH-#26DCF, IRGKangXi=1052.051, RSKangXi=140.10
26DD0 CJK UNIFIED IDEOGRAPH-#26DD0, IRGKangXi=1052.051, RSKangXi=140.10
26DD1 CJK UNIFIED IDEOGRAPH-#26DD1, IRGKangXi=1052.051, RSKangXi=140.10
26DD2 CJK UNIFIED IDEOGRAPH-#26DD2, IRGKangXi=1052.051, RSKangXi=140.10
26DD3 CJK UNIFIED IDEOGRAPH-#26DD3, IRGKangXi=1052.051, RSKangXi=140.10
26DD4 CJK UNIFIED IDEOGRAPH-#26DD4, IRGKangXi=1052.051, RSKangXi=140.10
26DD5 CJK UNIFIED IDEOGRAPH-#26DD5, IRGKangXi=1052.051, RSKangXi=140.10
26DD6 CJK UNIFIED IDEOGRAPH-#26DD6, IRGKangXi=1052.051, RSKangXi=140.10
26DD7 CJK UNIFIED IDEOGRAPH-#26DD7, IRGKangXi=1052.051, RSKangXi=140.10
26DD8 CJK UNIFIED IDEOGRAPH-#26DD8, IRGKangXi=1052.051, RSKangXi=140.10
26DD9 CJK UNIFIED IDEOGRAPH-#26DD9, IRGKangXi=1052.051, RSKangXi=140.10
26DDA CJK UNIFIED IDEOGRAPH-#26DDA, IRGKangXi=1052.051, RSKangXi=140.10
26DDB CJK UNIFIED IDEOGRAPH-#26DDB, IRGKangXi=1052.051, RSKangXi=140.10
26DDC CJK UNIFIED IDEOGRAPH-#26DDC, IRGKangXi=1052.051, RSKangXi=140.10
26DDD CJK UNIFIED IDEOGRAPH-#26DDD, IRGKangXi=1052.051, RSKangXi=140.10, Def{to cut grass; hay}
26DDE CJK UNIFIED IDEOGRAPH-#26DDE, IRGKangXi=1052.051, RSKangXi=140.10
26DDF CJK UNIFIED IDEOGRAPH-#26DDF, IRGKangXi=1052.051, RSKangXi=140.10
26DE0 CJK UNIFIED IDEOGRAPH-#26DE0, IRGKangXi=1052.051, RSKangXi=140.10
26DE1 CJK UNIFIED IDEOGRAPH-#26DE1, IRGKangXi=1052.051, RSKangXi=140.10
26DE2 CJK UNIFIED IDEOGRAPH-#26DE2, IRGKangXi=1052.051, RSKangXi=140.10
26DE3 CJK UNIFIED IDEOGRAPH-#26DE3, IRGKangXi=1052.051, RSKangXi=140.10
26DE4 CJK UNIFIED IDEOGRAPH-#26DE4, IRGKangXi=1052.051, RSKangXi=140.10
26DE5 CJK UNIFIED IDEOGRAPH-#26DE5, IRGKangXi=1052.051, RSKangXi=140.10
26DE6 CJK UNIFIED IDEOGRAPH-#26DE6, IRGKangXi=1052.051, RSKangXi=140.10
26DE7 CJK UNIFIED IDEOGRAPH-#26DE7, IRGKangXi=1052.051, RSKangXi=140.10
26DE8 CJK UNIFIED IDEOGRAPH-#26DE8, IRGKangXi=1052.051, RSKangXi=140.10
26DE9 CJK UNIFIED IDEOGRAPH-#26DE9, IRGKangXi=1052.051, RSKangXi=140.10
26DEA CJK UNIFIED IDEOGRAPH-#26DEA, IRGKangXi=1052.051, RSKangXi=140.10
26DEB CJK UNIFIED IDEOGRAPH-#26DEB, IRGKangXi=1052.051, RSKangXi=140.10
26DEC CJK UNIFIED IDEOGRAPH-#26DEC, IRGKangXi=1052.051, RSKangXi=140.10
26DED CJK UNIFIED IDEOGRAPH-#26DED, IRGKangXi=1052.051, RSKangXi=140.10
26DEE CJK UNIFIED IDEOGRAPH-#26DEE, IRGKangXi=1052.051, RSKangXi=140.10
26DEF CJK UNIFIED IDEOGRAPH-#26DEF, IRGKangXi=1052.051, RSKangXi=140.10
26DF0 CJK UNIFIED IDEOGRAPH-#26DF0, IRGKangXi=1052.051, RSKangXi=140.10
26DF1 CJK UNIFIED IDEOGRAPH-#26DF1, IRGKangXi=1052.051, RSKangXi=140.10
26DF2 CJK UNIFIED IDEOGRAPH-#26DF2, IRGKangXi=1052.051, RSKangXi=140.10
26DF3 CJK UNIFIED IDEOGRAPH-#26DF3, IRGKangXi=1052.051, RSKangXi=140.10
26DF4 CJK UNIFIED IDEOGRAPH-#26DF4, IRGKangXi=1052.051, RSKangXi=140.10
26DF5 CJK UNIFIED IDEOGRAPH-#26DF5, IRGKangXi=1052.051, RSKangXi=140.10
26DF6 CJK UNIFIED IDEOGRAPH-#26DF6, IRGKangXi=1052.051, RSKangXi=140.10
26DF7 CJK UNIFIED IDEOGRAPH-#26DF7, IRGKangXi=1052.051, RSKangXi=140.10
26DF8 CJK UNIFIED IDEOGRAPH-#26DF8, IRGKangXi=1052.051, RSKangXi=140.10
26DF9 CJK UNIFIED IDEOGRAPH-#26DF9, IRGKangXi=1052.051, RSKangXi=140.10
26DFA CJK UNIFIED IDEOGRAPH-#26DFA, IRGKangXi=1052.051, RSKangXi=140.10
26DFB CJK UNIFIED IDEOGRAPH-#26DFB, IRGKangXi=1052.051, RSKangXi=140.10
26DFC CJK UNIFIED IDEOGRAPH-#26DFC, IRGKangXi=1052.051, RSKangXi=140.10
26DFD CJK UNIFIED IDEOGRAPH-#26DFD, IRGKangXi=1052.051, RSKangXi=140.10
26DFE CJK UNIFIED IDEOGRAPH-#26DFE, IRGKangXi=1052.051, RSKangXi=140.10
26DFF CJK UNIFIED IDEOGRAPH-#26DFF, IRGKangXi=1052.110, RSKangXi=140.11
26E00 CJK UNIFIED IDEOGRAPH-#26E00, IRGKangXi=1052.180, RSKangXi=140.11
26E01 CJK UNIFIED IDEOGRAPH-#26E01, IRGKangXi=1052.210, RSKangXi=140.11
26E02 CJK UNIFIED IDEOGRAPH-#26E02, IRGKangXi=1052.230, RSKangXi=140.11
26E03 CJK UNIFIED IDEOGRAPH-#26E03, IRGKangXi=1052.280, RSKangXi=140.11
26E04 CJK UNIFIED IDEOGRAPH-#26E04, IRGKangXi=1052.350, RSKangXi=140.11
26E05 CJK UNIFIED IDEOGRAPH-#26E05, IRGKangXi=1052.360, RSKangXi=140.11
26E06 CJK UNIFIED IDEOGRAPH-#26E06, IRGKangXi=1053.090, RSKangXi=140.11
26E07 CJK UNIFIED IDEOGRAPH-#26E07, IRGKangXi=1053.140, RSKangXi=140.11
26E08 CJK UNIFIED IDEOGRAPH-#26E08, IRGKangXi=1053.210, RSKangXi=140.11
26E09 CJK UNIFIED IDEOGRAPH-#26E09, IRGKangXi=1053.220, RSKangXi=140.11
26E0A CJK UNIFIED IDEOGRAPH-#26E0A, IRGKangXi=1053.250, RSKangXi=140.11
26E0B CJK UNIFIED IDEOGRAPH-#26E0B, IRGKangXi=1053.280, RSKangXi=140.11
26E0C CJK UNIFIED IDEOGRAPH-#26E0C, IRGKangXi=1053.300, RSKangXi=140.11
26E0D CJK UNIFIED IDEOGRAPH-#26E0D, IRGKangXi=1053.310, RSKangXi=140.11
26E0E CJK UNIFIED IDEOGRAPH-#26E0E, IRGKangXi=1053.340, RSKangXi=140.11
26E0F CJK UNIFIED IDEOGRAPH-#26E0F, IRGKangXi=1053.350, RSKangXi=140.11
26E10 CJK UNIFIED IDEOGRAPH-#26E10, IRGKangXi=1054.010, RSKangXi=140.11
26E11 CJK UNIFIED IDEOGRAPH-#26E11, IRGKangXi=1054.040, RSKangXi=140.11
26E12 CJK UNIFIED IDEOGRAPH-#26E12, IRGKangXi=1054.080, RSKangXi=140.11
26E13 CJK UNIFIED IDEOGRAPH-#26E13, IRGKangXi=1054.100, RSKangXi=140.11
26E14 CJK UNIFIED IDEOGRAPH-#26E14, IRGKangXi=1054.130, RSKangXi=140.11
26E15 CJK UNIFIED IDEOGRAPH-#26E15, IRGKangXi=1054.150, RSKangXi=140.11
26E16 CJK UNIFIED IDEOGRAPH-#26E16, IRGKangXi=1054.180, RSKangXi=140.11
26E17 CJK UNIFIED IDEOGRAPH-#26E17, IRGKangXi=1054.190, RSKangXi=140.11
26E18 CJK UNIFIED IDEOGRAPH-#26E18, IRGKangXi=1054.240, RSKangXi=140.11
26E19 CJK UNIFIED IDEOGRAPH-#26E19, IRGKangXi=1054.250, RSKangXi=140.11
26E1A CJK UNIFIED IDEOGRAPH-#26E1A, IRGKangXi=1054.280, RSKangXi=140.11
26E1B CJK UNIFIED IDEOGRAPH-#26E1B, IRGKangXi=1054.320, RSKangXi=140.11
26E1C CJK UNIFIED IDEOGRAPH-#26E1C, IRGKangXi=1054.360, RSKangXi=140.11
26E1D CJK UNIFIED IDEOGRAPH-#26E1D, IRGKangXi=1055.020, RSKangXi=140.11
26E1E CJK UNIFIED IDEOGRAPH-#26E1E, IRGKangXi=1055.080, RSKangXi=140.11
26E1F CJK UNIFIED IDEOGRAPH-#26E1F, IRGKangXi=1055.100, RSKangXi=140.11
26E20 CJK UNIFIED IDEOGRAPH-#26E20, IRGKangXi=1055.130, RSKangXi=140.11
26E21 CJK UNIFIED IDEOGRAPH-#26E21, IRGKangXi=1055.150, RSKangXi=140.11
26E22 CJK UNIFIED IDEOGRAPH-#26E22, IRGKangXi=1055.170, RSKangXi=140.11
26E23 CJK UNIFIED IDEOGRAPH-#26E23, IRGKangXi=1055.210, RSKangXi=140.11
26E24 CJK UNIFIED IDEOGRAPH-#26E24, IRGKangXi=1055.220, RSKangXi=140.11
26E25 CJK UNIFIED IDEOGRAPH-#26E25, IRGKangXi=1055.280, RSKangXi=140.11
26E26 CJK UNIFIED IDEOGRAPH-#26E26, IRGKangXi=1055.290, RSKangXi=140.11
26E27 CJK UNIFIED IDEOGRAPH-#26E27, IRGKangXi=1055.300, RSKangXi=140.11
26E28 CJK UNIFIED IDEOGRAPH-#26E28, IRGKangXi=1055.310, RSKangXi=140.11
26E29 CJK UNIFIED IDEOGRAPH-#26E29, IRGKangXi=1055.320, RSKangXi=140.11
26E2A CJK UNIFIED IDEOGRAPH-#26E2A, IRGKangXi=1055.330, RSKangXi=140.11
26E2B CJK UNIFIED IDEOGRAPH-#26E2B, IRGKangXi=1055.360, RSKangXi=140.11
26E2C CJK UNIFIED IDEOGRAPH-#26E2C, IRGKangXi=1055.370, RSKangXi=140.11
26E2D CJK UNIFIED IDEOGRAPH-#26E2D, IRGKangXi=1055.380, RSKangXi=140.11
26E2E CJK UNIFIED IDEOGRAPH-#26E2E, IRGKangXi=1055.390, RSKangXi=140.11
26E2F CJK UNIFIED IDEOGRAPH-#26E2F, IRGKangXi=1055.400, RSKangXi=140.11
26E30 CJK UNIFIED IDEOGRAPH-#26E30, IRGKangXi=1055.410, RSKangXi=140.11
26E31 CJK UNIFIED IDEOGRAPH-#26E31, IRGKangXi=1056.010, RSKangXi=140.11
26E32 CJK UNIFIED IDEOGRAPH-#26E32, IRGKangXi=1056.020, RSKangXi=140.11
26E33 CJK UNIFIED IDEOGRAPH-#26E33, IRGKangXi=1056.030, RSKangXi=140.11
26E34 CJK UNIFIED IDEOGRAPH-#26E34, IRGKangXi=1056.040, RSKangXi=140.11
26E35 CJK UNIFIED IDEOGRAPH-#26E35, IRGKangXi=1056.050, RSKangXi=140.11
26E36 CJK UNIFIED IDEOGRAPH-#26E36, IRGKangXi=1056.060, RSKangXi=140.11
26E37 CJK UNIFIED IDEOGRAPH-#26E37, IRGKangXi=1056.070, RSKangXi=140.11
26E38 CJK UNIFIED IDEOGRAPH-#26E38, IRGKangXi=1056.080, RSKangXi=140.11
26E39 CJK UNIFIED IDEOGRAPH-#26E39, IRGKangXi=1056.090, RSKangXi=140.11
26E3A CJK UNIFIED IDEOGRAPH-#26E3A, IRGKangXi=1056.120, RSKangXi=140.11
26E3B CJK UNIFIED IDEOGRAPH-#26E3B, IRGKangXi=1056.121, RSKangXi=140.11
26E3C CJK UNIFIED IDEOGRAPH-#26E3C, IRGKangXi=1056.121, RSKangXi=140.11
26E3D CJK UNIFIED IDEOGRAPH-#26E3D, IRGKangXi=1056.121, RSKangXi=140.12
26E3E CJK UNIFIED IDEOGRAPH-#26E3E, IRGKangXi=1056.121, RSKangXi=140.11
26E3F CJK UNIFIED IDEOGRAPH-#26E3F, IRGKangXi=1056.121, RSKangXi=140.11
26E40 CJK UNIFIED IDEOGRAPH-#26E40, IRGKangXi=1056.121, RSKangXi=140.11
26E41 CJK UNIFIED IDEOGRAPH-#26E41, IRGKangXi=1056.121, RSKangXi=140.11
26E42 CJK UNIFIED IDEOGRAPH-#26E42, IRGKangXi=1056.121, RSKangXi=140.11
26E43 CJK UNIFIED IDEOGRAPH-#26E43, IRGKangXi=1056.121, RSKangXi=140.11
26E44 CJK UNIFIED IDEOGRAPH-#26E44, IRGKangXi=1056.121, RSKangXi=140.11
26E45 CJK UNIFIED IDEOGRAPH-#26E45, IRGKangXi=1056.121, RSKangXi=140.11
26E46 CJK UNIFIED IDEOGRAPH-#26E46, IRGKangXi=1056.121, RSKangXi=140.11
26E47 CJK UNIFIED IDEOGRAPH-#26E47, IRGKangXi=1056.121, RSKangXi=140.11
26E48 CJK UNIFIED IDEOGRAPH-#26E48, IRGKangXi=1056.121, RSKangXi=140.11
26E49 CJK UNIFIED IDEOGRAPH-#26E49, IRGKangXi=1056.121, RSKangXi=140.11
26E4A CJK UNIFIED IDEOGRAPH-#26E4A, IRGKangXi=1056.121, RSKangXi=140.11
26E4B CJK UNIFIED IDEOGRAPH-#26E4B, IRGKangXi=1056.121, RSKangXi=140.11
26E4C CJK UNIFIED IDEOGRAPH-#26E4C, IRGKangXi=1056.121, RSKangXi=140.11
26E4D CJK UNIFIED IDEOGRAPH-#26E4D, IRGKangXi=1056.121, RSKangXi=140.11
26E4E CJK UNIFIED IDEOGRAPH-#26E4E, IRGKangXi=1056.121, RSKangXi=140.11
26E4F CJK UNIFIED IDEOGRAPH-#26E4F, IRGKangXi=1056.121, RSKangXi=140.11
26E50 CJK UNIFIED IDEOGRAPH-#26E50, IRGKangXi=1056.121, RSKangXi=140.11
26E51 CJK UNIFIED IDEOGRAPH-#26E51, IRGKangXi=1056.121, RSKangXi=140.11
26E52 CJK UNIFIED IDEOGRAPH-#26E52, IRGKangXi=1056.121, RSKangXi=140.11
26E53 CJK UNIFIED IDEOGRAPH-#26E53, IRGKangXi=1056.121, RSKangXi=140.11
26E54 CJK UNIFIED IDEOGRAPH-#26E54, IRGKangXi=1056.121, RSKangXi=140.11
26E55 CJK UNIFIED IDEOGRAPH-#26E55, IRGKangXi=1056.121, RSKangXi=140.11
26E56 CJK UNIFIED IDEOGRAPH-#26E56, IRGKangXi=1056.121, RSKangXi=140.11
26E57 CJK UNIFIED IDEOGRAPH-#26E57, IRGKangXi=1056.121, RSKangXi=140.11
26E58 CJK UNIFIED IDEOGRAPH-#26E58, IRGKangXi=1056.121, RSKangXi=140.11
26E59 CJK UNIFIED IDEOGRAPH-#26E59, IRGKangXi=1056.121, RSKangXi=140.11
26E5A CJK UNIFIED IDEOGRAPH-#26E5A, IRGKangXi=1056.121, RSKangXi=140.11
26E5B CJK UNIFIED IDEOGRAPH-#26E5B, IRGKangXi=1056.121, RSKangXi=140.11
26E5C CJK UNIFIED IDEOGRAPH-#26E5C, IRGKangXi=1056.121, RSKangXi=140.11
26E5D CJK UNIFIED IDEOGRAPH-#26E5D, IRGKangXi=1056.121, RSKangXi=140.11
26E5E CJK UNIFIED IDEOGRAPH-#26E5E, IRGKangXi=1056.121, RSKangXi=140.11
26E5F CJK UNIFIED IDEOGRAPH-#26E5F, IRGKangXi=1056.121, RSKangXi=140.11
26E60 CJK UNIFIED IDEOGRAPH-#26E60, IRGKangXi=1056.121, RSKangXi=140.11
26E61 CJK UNIFIED IDEOGRAPH-#26E61, IRGKangXi=1056.121, RSKangXi=140.11
26E62 CJK UNIFIED IDEOGRAPH-#26E62, IRGKangXi=1056.121, RSKangXi=140.11
26E63 CJK UNIFIED IDEOGRAPH-#26E63, IRGKangXi=1056.121, RSKangXi=140.11
26E64 CJK UNIFIED IDEOGRAPH-#26E64, IRGKangXi=1056.121, RSKangXi=140.11
26E65 CJK UNIFIED IDEOGRAPH-#26E65, IRGKangXi=1056.121, RSKangXi=140.11
26E66 CJK UNIFIED IDEOGRAPH-#26E66, IRGKangXi=1056.121, RSKangXi=140.11
26E67 CJK UNIFIED IDEOGRAPH-#26E67, IRGKangXi=1056.121, RSKangXi=140.11
26E68 CJK UNIFIED IDEOGRAPH-#26E68, IRGKangXi=1056.121, RSKangXi=140.11
26E69 CJK UNIFIED IDEOGRAPH-#26E69, IRGKangXi=1056.121, RSKangXi=140.11
26E6A CJK UNIFIED IDEOGRAPH-#26E6A, IRGKangXi=1056.121, RSKangXi=140.11
26E6B CJK UNIFIED IDEOGRAPH-#26E6B, IRGKangXi=1056.121, RSKangXi=140.11
26E6C CJK UNIFIED IDEOGRAPH-#26E6C, IRGKangXi=1056.121, RSKangXi=140.11
26E6D CJK UNIFIED IDEOGRAPH-#26E6D, IRGKangXi=1056.121, RSKangXi=140.11
26E6E CJK UNIFIED IDEOGRAPH-#26E6E, IRGKangXi=1056.121, RSKangXi=140.11
26E6F CJK UNIFIED IDEOGRAPH-#26E6F, IRGKangXi=1056.121, RSKangXi=140.11
26E70 CJK UNIFIED IDEOGRAPH-#26E70, IRGKangXi=1056.121, RSKangXi=140.11
26E71 CJK UNIFIED IDEOGRAPH-#26E71, IRGKangXi=1056.121, RSKangXi=140.11
26E72 CJK UNIFIED IDEOGRAPH-#26E72, IRGKangXi=1056.121, RSKangXi=140.11
26E73 CJK UNIFIED IDEOGRAPH-#26E73, IRGKangXi=1056.121, RSKangXi=140.11
26E74 CJK UNIFIED IDEOGRAPH-#26E74, IRGKangXi=1056.121, RSKangXi=140.11
26E75 CJK UNIFIED IDEOGRAPH-#26E75, IRGKangXi=1056.121, RSKangXi=140.11
26E76 CJK UNIFIED IDEOGRAPH-#26E76, IRGKangXi=1056.121, RSKangXi=140.11
26E77 CJK UNIFIED IDEOGRAPH-#26E77, IRGKangXi=1056.121, RSKangXi=140.11
26E78 CJK UNIFIED IDEOGRAPH-#26E78, IRGKangXi=1056.121, RSKangXi=140.11
26E79 CJK UNIFIED IDEOGRAPH-#26E79, IRGKangXi=1056.121, RSKangXi=140.11
26E7A CJK UNIFIED IDEOGRAPH-#26E7A, IRGKangXi=1056.121, RSKangXi=140.11
26E7B CJK UNIFIED IDEOGRAPH-#26E7B, IRGKangXi=1056.121, RSKangXi=140.11
26E7C CJK UNIFIED IDEOGRAPH-#26E7C, IRGKangXi=1056.121, RSKangXi=140.11
26E7D CJK UNIFIED IDEOGRAPH-#26E7D, IRGKangXi=1056.121, RSKangXi=140.11
26E7E CJK UNIFIED IDEOGRAPH-#26E7E, IRGKangXi=1056.121, RSKangXi=140.11
26E7F CJK UNIFIED IDEOGRAPH-#26E7F, IRGKangXi=1056.121, RSKangXi=140.11
26E80 CJK UNIFIED IDEOGRAPH-#26E80, IRGKangXi=1056.121, RSKangXi=140.11
26E81 CJK UNIFIED IDEOGRAPH-#26E81, IRGKangXi=1056.121, RSKangXi=140.11
26E82 CJK UNIFIED IDEOGRAPH-#26E82, IRGKangXi=1056.121, RSKangXi=140.11
26E83 CJK UNIFIED IDEOGRAPH-#26E83, IRGKangXi=1056.121, RSKangXi=140.11
26E84 CJK UNIFIED IDEOGRAPH-#26E84, IRGKangXi=1056.121, RSKangXi=140.11
26E85 CJK UNIFIED IDEOGRAPH-#26E85, IRGKangXi=1056.121, RSKangXi=140.26
26E86 CJK UNIFIED IDEOGRAPH-#26E86, IRGKangXi=1056.130, RSKangXi=140.12
26E87 CJK UNIFIED IDEOGRAPH-#26E87, IRGKangXi=1056.140, RSKangXi=140.12
26E88 CJK UNIFIED IDEOGRAPH-#26E88, IRGKangXi=1056.160, RSKangXi=140.12
26E89 CJK UNIFIED IDEOGRAPH-#26E89, IRGKangXi=1056.180, RSKangXi=140.12
26E8A CJK UNIFIED IDEOGRAPH-#26E8A, IRGKangXi=1056.230, RSKangXi=140.12
26E8B CJK UNIFIED IDEOGRAPH-#26E8B, IRGKangXi=1056.270, RSKangXi=140.12
26E8C CJK UNIFIED IDEOGRAPH-#26E8C, IRGKangXi=1056.280, RSKangXi=140.12
26E8D CJK UNIFIED IDEOGRAPH-#26E8D, IRGKangXi=1056.320, RSKangXi=140.12
26E8E CJK UNIFIED IDEOGRAPH-#26E8E, IRGKangXi=1056.340, RSKangXi=140.12
26E8F CJK UNIFIED IDEOGRAPH-#26E8F, IRGKangXi=1056.350, RSKangXi=140.12
26E90 CJK UNIFIED IDEOGRAPH-#26E90, IRGKangXi=1056.370, RSKangXi=140.12
26E91 CJK UNIFIED IDEOGRAPH-#26E91, IRGKangXi=1056.390, RSKangXi=140.12
26E92 CJK UNIFIED IDEOGRAPH-#26E92, IRGKangXi=1056.400, RSKangXi=140.12
26E93 CJK UNIFIED IDEOGRAPH-#26E93, IRGKangXi=1056.440, RSKangXi=140.12
26E94 CJK UNIFIED IDEOGRAPH-#26E94, IRGKangXi=1056.450, RSKangXi=140.12
26E95 CJK UNIFIED IDEOGRAPH-#26E95, IRGKangXi=1056.460, RSKangXi=140.12
26E96 CJK UNIFIED IDEOGRAPH-#26E96, IRGKangXi=1057.010, RSKangXi=140.12
26E97 CJK UNIFIED IDEOGRAPH-#26E97, IRGKangXi=1057.030, RSKangXi=140.12
26E98 CJK UNIFIED IDEOGRAPH-#26E98, IRGKangXi=1057.050, RSKangXi=140.12
26E99 CJK UNIFIED IDEOGRAPH-#26E99, IRGKangXi=1057.100, RSKangXi=140.12
26E9A CJK UNIFIED IDEOGRAPH-#26E9A, IRGKangXi=1057.110, RSKangXi=140.12
26E9B CJK UNIFIED IDEOGRAPH-#26E9B, IRGKangXi=1057.120, RSKangXi=140.12
26E9C CJK UNIFIED IDEOGRAPH-#26E9C, IRGKangXi=1057.130, RSKangXi=140.12, Def{to weed; a plant}
26E9D CJK UNIFIED IDEOGRAPH-#26E9D, IRGKangXi=1057.150, RSKangXi=140.12
26E9E CJK UNIFIED IDEOGRAPH-#26E9E, IRGKangXi=1057.160, RSKangXi=140.12
26E9F CJK UNIFIED IDEOGRAPH-#26E9F, IRGKangXi=1057.170, RSKangXi=140.12
26EA0 CJK UNIFIED IDEOGRAPH-#26EA0, IRGKangXi=1057.190, RSKangXi=140.12
26EA1 CJK UNIFIED IDEOGRAPH-#26EA1, IRGKangXi=1057.230, RSKangXi=140.12
26EA2 CJK UNIFIED IDEOGRAPH-#26EA2, IRGKangXi=1057.250, RSKangXi=140.12
26EA3 CJK UNIFIED IDEOGRAPH-#26EA3, IRGKangXi=1057.280, RSKangXi=140.12
26EA4 CJK UNIFIED IDEOGRAPH-#26EA4, IRGKangXi=1057.290, RSKangXi=140.12
26EA5 CJK UNIFIED IDEOGRAPH-#26EA5, IRGKangXi=1057.310, RSKangXi=140.12
26EA6 CJK UNIFIED IDEOGRAPH-#26EA6, IRGKangXi=1057.340, RSKangXi=140.12
26EA7 CJK UNIFIED IDEOGRAPH-#26EA7, IRGKangXi=1057.380, RSKangXi=140.12
26EA8 CJK UNIFIED IDEOGRAPH-#26EA8, IRGKangXi=1057.400, RSKangXi=140.12
26EA9 CJK UNIFIED IDEOGRAPH-#26EA9, IRGKangXi=1058.010, RSKangXi=140.12
26EAA CJK UNIFIED IDEOGRAPH-#26EAA, IRGKangXi=1058.040, RSKangXi=140.12
26EAB CJK UNIFIED IDEOGRAPH-#26EAB, IRGKangXi=1058.070, RSKangXi=140.12
26EAC CJK UNIFIED IDEOGRAPH-#26EAC, IRGKangXi=1058.090, RSKangXi=140.12
26EAD CJK UNIFIED IDEOGRAPH-#26EAD, IRGKangXi=1058.120, RSKangXi=140.12
26EAE CJK UNIFIED IDEOGRAPH-#26EAE, IRGKangXi=1058.170, RSKangXi=140.12
26EAF CJK UNIFIED IDEOGRAPH-#26EAF, IRGKangXi=1058.180, RSKangXi=140.12
26EB0 CJK UNIFIED IDEOGRAPH-#26EB0, IRGKangXi=1058.210, RSKangXi=140.12
26EB1 CJK UNIFIED IDEOGRAPH-#26EB1, IRGKangXi=1058.220, RSKangXi=140.12
26EB2 CJK UNIFIED IDEOGRAPH-#26EB2, IRGKangXi=1058.240, RSKangXi=140.12
26EB3 CJK UNIFIED IDEOGRAPH-#26EB3, IRGKangXi=1058.270, RSKangXi=140.12
26EB4 CJK UNIFIED IDEOGRAPH-#26EB4, IRGKangXi=1058.300, RSKangXi=140.12
26EB5 CJK UNIFIED IDEOGRAPH-#26EB5, IRGKangXi=1058.320, RSKangXi=140.12
26EB6 CJK UNIFIED IDEOGRAPH-#26EB6, IRGKangXi=1058.330, RSKangXi=140.12
26EB7 CJK UNIFIED IDEOGRAPH-#26EB7, IRGKangXi=1058.340, RSKangXi=140.12
26EB8 CJK UNIFIED IDEOGRAPH-#26EB8, IRGKangXi=1058.380, RSKangXi=140.12
26EB9 CJK UNIFIED IDEOGRAPH-#26EB9, IRGKangXi=1058.400, RSKangXi=140.12
26EBA CJK UNIFIED IDEOGRAPH-#26EBA, IRGKangXi=1059.010, RSKangXi=140.12
26EBB CJK UNIFIED IDEOGRAPH-#26EBB, IRGKangXi=1059.030, RSKangXi=140.12
26EBC CJK UNIFIED IDEOGRAPH-#26EBC, IRGKangXi=1059.040, RSKangXi=140.12
26EBD CJK UNIFIED IDEOGRAPH-#26EBD, IRGKangXi=1059.090, RSKangXi=140.12
26EBE CJK UNIFIED IDEOGRAPH-#26EBE, IRGKangXi=1059.130, RSKangXi=140.12
26EBF CJK UNIFIED IDEOGRAPH-#26EBF, IRGKangXi=1059.140, RSKangXi=140.12
26EC0 CJK UNIFIED IDEOGRAPH-#26EC0, IRGKangXi=1059.150, RSKangXi=140.12
26EC1 CJK UNIFIED IDEOGRAPH-#26EC1, IRGKangXi=1059.160, RSKangXi=140.12
26EC2 CJK UNIFIED IDEOGRAPH-#26EC2, IRGKangXi=1059.170, RSKangXi=140.12
26EC3 CJK UNIFIED IDEOGRAPH-#26EC3, IRGKangXi=1059.180, RSKangXi=140.12
26EC4 CJK UNIFIED IDEOGRAPH-#26EC4, IRGKangXi=1059.190, RSKangXi=140.12
26EC5 CJK UNIFIED IDEOGRAPH-#26EC5, IRGKangXi=1059.200, RSKangXi=140.12
26EC6 CJK UNIFIED IDEOGRAPH-#26EC6, IRGKangXi=1059.210, RSKangXi=140.12
26EC7 CJK UNIFIED IDEOGRAPH-#26EC7, IRGKangXi=1059.220, RSKangXi=140.12
26EC8 CJK UNIFIED IDEOGRAPH-#26EC8, IRGKangXi=1059.230, RSKangXi=140.12
26EC9 CJK UNIFIED IDEOGRAPH-#26EC9, IRGKangXi=1059.240, RSKangXi=140.12
26ECA CJK UNIFIED IDEOGRAPH-#26ECA, IRGKangXi=1059.260, RSKangXi=140.12
26ECB CJK UNIFIED IDEOGRAPH-#26ECB, IRGKangXi=1059.270, RSKangXi=140.12
26ECC CJK UNIFIED IDEOGRAPH-#26ECC, IRGKangXi=1059.280, RSKangXi=140.12
26ECD CJK UNIFIED IDEOGRAPH-#26ECD, IRGKangXi=1059.290, RSKangXi=140.12
26ECE CJK UNIFIED IDEOGRAPH-#26ECE, IRGKangXi=1059.291, RSKangXi=140.12
26ECF CJK UNIFIED IDEOGRAPH-#26ECF, IRGKangXi=1059.291, RSKangXi=140.12
26ED0 CJK UNIFIED IDEOGRAPH-#26ED0, IRGKangXi=1059.291, RSKangXi=140.12, Def{(Cant.) to fry in oil}
26ED1 CJK UNIFIED IDEOGRAPH-#26ED1, IRGKangXi=1059.291, RSKangXi=140.12
26ED2 CJK UNIFIED IDEOGRAPH-#26ED2, IRGKangXi=1059.291, RSKangXi=140.12
26ED3 CJK UNIFIED IDEOGRAPH-#26ED3, IRGKangXi=1059.291, RSKangXi=140.12
26ED4 CJK UNIFIED IDEOGRAPH-#26ED4, IRGKangXi=1059.291, RSKangXi=140.12
26ED5 CJK UNIFIED IDEOGRAPH-#26ED5, IRGKangXi=1059.291, RSKangXi=140.12
26ED6 CJK UNIFIED IDEOGRAPH-#26ED6, IRGKangXi=1059.291, RSKangXi=140.12
26ED7 CJK UNIFIED IDEOGRAPH-#26ED7, IRGKangXi=1059.291, RSKangXi=140.12
26ED8 CJK UNIFIED IDEOGRAPH-#26ED8, IRGKangXi=1059.291, RSKangXi=140.12
26ED9 CJK UNIFIED IDEOGRAPH-#26ED9, IRGKangXi=1059.291, RSKangXi=140.12
26EDA CJK UNIFIED IDEOGRAPH-#26EDA, IRGKangXi=1059.291, RSKangXi=140.12
26EDB CJK UNIFIED IDEOGRAPH-#26EDB, IRGKangXi=1059.291, RSKangXi=140.12
26EDC CJK UNIFIED IDEOGRAPH-#26EDC, IRGKangXi=1059.291, RSKangXi=140.12
26EDD CJK UNIFIED IDEOGRAPH-#26EDD, IRGKangXi=1059.291, RSKangXi=140.12
26EDE CJK UNIFIED IDEOGRAPH-#26EDE, IRGKangXi=1059.291, RSKangXi=140.12
26EDF CJK UNIFIED IDEOGRAPH-#26EDF, IRGKangXi=1059.291, RSKangXi=140.12
26EE0 CJK UNIFIED IDEOGRAPH-#26EE0, IRGKangXi=1059.291, RSKangXi=140.12
26EE1 CJK UNIFIED IDEOGRAPH-#26EE1, IRGKangXi=1059.291, RSKangXi=140.12
26EE2 CJK UNIFIED IDEOGRAPH-#26EE2, IRGKangXi=1059.291, RSKangXi=140.12
26EE3 CJK UNIFIED IDEOGRAPH-#26EE3, IRGKangXi=1059.291, RSKangXi=140.12
26EE4 CJK UNIFIED IDEOGRAPH-#26EE4, IRGKangXi=1059.291, RSKangXi=140.12
26EE5 CJK UNIFIED IDEOGRAPH-#26EE5, IRGKangXi=1059.291, RSKangXi=140.12
26EE6 CJK UNIFIED IDEOGRAPH-#26EE6, IRGKangXi=1059.291, RSKangXi=140.12
26EE7 CJK UNIFIED IDEOGRAPH-#26EE7, IRGKangXi=1059.291, RSKangXi=140.12
26EE8 CJK UNIFIED IDEOGRAPH-#26EE8, IRGKangXi=1059.291, RSKangXi=140.12
26EE9 CJK UNIFIED IDEOGRAPH-#26EE9, IRGKangXi=1059.291, RSKangXi=140.12
26EEA CJK UNIFIED IDEOGRAPH-#26EEA, IRGKangXi=1059.291, RSKangXi=140.12
26EEB CJK UNIFIED IDEOGRAPH-#26EEB, IRGKangXi=1059.291, RSKangXi=140.12
26EEC CJK UNIFIED IDEOGRAPH-#26EEC, IRGKangXi=1059.291, RSKangXi=140.12
26EED CJK UNIFIED IDEOGRAPH-#26EED, IRGKangXi=1059.291, RSKangXi=140.12
26EEE CJK UNIFIED IDEOGRAPH-#26EEE, IRGKangXi=1059.291, RSKangXi=140.12
26EEF CJK UNIFIED IDEOGRAPH-#26EEF, IRGKangXi=1059.291, RSKangXi=140.12
26EF0 CJK UNIFIED IDEOGRAPH-#26EF0, IRGKangXi=1059.291, RSKangXi=140.12
26EF1 CJK UNIFIED IDEOGRAPH-#26EF1, IRGKangXi=1059.291, RSKangXi=140.12
26EF2 CJK UNIFIED IDEOGRAPH-#26EF2, IRGKangXi=1059.291, RSKangXi=140.12
26EF3 CJK UNIFIED IDEOGRAPH-#26EF3, IRGKangXi=1059.291, RSKangXi=140.12
26EF4 CJK UNIFIED IDEOGRAPH-#26EF4, IRGKangXi=1059.291, RSKangXi=140.12
26EF5 CJK UNIFIED IDEOGRAPH-#26EF5, IRGKangXi=1059.291, RSKangXi=140.12
26EF6 CJK UNIFIED IDEOGRAPH-#26EF6, IRGKangXi=1059.291, RSKangXi=140.12
26EF7 CJK UNIFIED IDEOGRAPH-#26EF7, IRGKangXi=1059.291, RSKangXi=140.12
26EF8 CJK UNIFIED IDEOGRAPH-#26EF8, IRGKangXi=1059.291, RSKangXi=140.12
26EF9 CJK UNIFIED IDEOGRAPH-#26EF9, IRGKangXi=1059.291, RSKangXi=140.12
26EFA CJK UNIFIED IDEOGRAPH-#26EFA, IRGKangXi=1059.291, RSKangXi=140.12
26EFB CJK UNIFIED IDEOGRAPH-#26EFB, IRGKangXi=1059.291, RSKangXi=140.12
26EFC CJK UNIFIED IDEOGRAPH-#26EFC, IRGKangXi=1059.291, RSKangXi=140.12
26EFD CJK UNIFIED IDEOGRAPH-#26EFD, IRGKangXi=1059.291, RSKangXi=140.12
26EFE CJK UNIFIED IDEOGRAPH-#26EFE, IRGKangXi=1059.291, RSKangXi=140.13
26EFF CJK UNIFIED IDEOGRAPH-#26EFF, IRGKangXi=1059.291, RSKangXi=140.12
26F00 CJK UNIFIED IDEOGRAPH-#26F00, IRGKangXi=1059.291, RSKangXi=140.12
26F01 CJK UNIFIED IDEOGRAPH-#26F01, IRGKangXi=1059.291, RSKangXi=140.12
26F02 CJK UNIFIED IDEOGRAPH-#26F02, IRGKangXi=1059.291, RSKangXi=140.12
26F03 CJK UNIFIED IDEOGRAPH-#26F03, IRGKangXi=1059.291, RSKangXi=140.12
26F04 CJK UNIFIED IDEOGRAPH-#26F04, IRGKangXi=1059.291, RSKangXi=140.12
26F05 CJK UNIFIED IDEOGRAPH-#26F05, IRGKangXi=1059.291, RSKangXi=140.12
26F06 CJK UNIFIED IDEOGRAPH-#26F06, IRGKangXi=1059.291, RSKangXi=140.12
26F07 CJK UNIFIED IDEOGRAPH-#26F07, IRGKangXi=1059.291, RSKangXi=140.12
26F08 CJK UNIFIED IDEOGRAPH-#26F08, IRGKangXi=1059.291, RSKangXi=140.12
26F09 CJK UNIFIED IDEOGRAPH-#26F09, IRGKangXi=1059.291, RSKangXi=140.12
26F0A CJK UNIFIED IDEOGRAPH-#26F0A, IRGKangXi=1059.291, RSKangXi=140.12
26F0B CJK UNIFIED IDEOGRAPH-#26F0B, IRGKangXi=1059.291, RSKangXi=140.12
26F0C CJK UNIFIED IDEOGRAPH-#26F0C, IRGKangXi=1059.291, RSKangXi=140.12
26F0D CJK UNIFIED IDEOGRAPH-#26F0D, IRGKangXi=1059.291, RSKangXi=140.12
26F0E CJK UNIFIED IDEOGRAPH-#26F0E, IRGKangXi=1059.291, RSKangXi=140.12
26F0F CJK UNIFIED IDEOGRAPH-#26F0F, IRGKangXi=1059.291, RSKangXi=140.12
26F10 CJK UNIFIED IDEOGRAPH-#26F10, IRGKangXi=1059.291, RSKangXi=140.12
26F11 CJK UNIFIED IDEOGRAPH-#26F11, IRGKangXi=1059.291, RSKangXi=140.12
26F12 CJK UNIFIED IDEOGRAPH-#26F12, IRGKangXi=1059.291, RSKangXi=140.12
26F13 CJK UNIFIED IDEOGRAPH-#26F13, IRGKangXi=1059.291, RSKangXi=140.12
26F14 CJK UNIFIED IDEOGRAPH-#26F14, IRGKangXi=1059.291, RSKangXi=140.12
26F15 CJK UNIFIED IDEOGRAPH-#26F15, IRGKangXi=1059.291, RSKangXi=140.12
26F16 CJK UNIFIED IDEOGRAPH-#26F16, IRGKangXi=1059.291, RSKangXi=140.12
26F17 CJK UNIFIED IDEOGRAPH-#26F17, IRGKangXi=1059.291, RSKangXi=140.12
26F18 CJK UNIFIED IDEOGRAPH-#26F18, IRGKangXi=1059.291, RSKangXi=140.12
26F19 CJK UNIFIED IDEOGRAPH-#26F19, IRGKangXi=1059.291, RSKangXi=140.12
26F1A CJK UNIFIED IDEOGRAPH-#26F1A, IRGKangXi=1059.291, RSKangXi=140.12
26F1B CJK UNIFIED IDEOGRAPH-#26F1B, IRGKangXi=1059.291, RSKangXi=140.12
26F1C CJK UNIFIED IDEOGRAPH-#26F1C, IRGKangXi=1059.291, RSKangXi=140.12
26F1D CJK UNIFIED IDEOGRAPH-#26F1D, IRGKangXi=1059.291, RSKangXi=140.12
26F1E CJK UNIFIED IDEOGRAPH-#26F1E, IRGKangXi=1059.291, RSKangXi=140.12
26F1F CJK UNIFIED IDEOGRAPH-#26F1F, IRGKangXi=1059.291, RSKangXi=140.12
26F20 CJK UNIFIED IDEOGRAPH-#26F20, IRGKangXi=1059.291, RSKangXi=140.12
26F21 CJK UNIFIED IDEOGRAPH-#26F21, IRGKangXi=1059.291, RSKangXi=140.12
26F22 CJK UNIFIED IDEOGRAPH-#26F22, IRGKangXi=1059.291, RSKangXi=140.12
26F23 CJK UNIFIED IDEOGRAPH-#26F23, IRGKangXi=1059.291, RSKangXi=140.12
26F24 CJK UNIFIED IDEOGRAPH-#26F24, IRGKangXi=1059.291, RSKangXi=140.12
26F25 CJK UNIFIED IDEOGRAPH-#26F25, IRGKangXi=1059.291, RSKangXi=140.12
26F26 CJK UNIFIED IDEOGRAPH-#26F26, IRGKangXi=1059.291, RSKangXi=140.12
26F27 CJK UNIFIED IDEOGRAPH-#26F27, IRGKangXi=1059.291, RSKangXi=140.12
26F28 CJK UNIFIED IDEOGRAPH-#26F28, IRGKangXi=1059.291, RSKangXi=140.12
26F29 CJK UNIFIED IDEOGRAPH-#26F29, IRGKangXi=1059.300, RSKangXi=140.13
26F2A CJK UNIFIED IDEOGRAPH-#26F2A, IRGKangXi=1059.310, RSKangXi=140.13
26F2B CJK UNIFIED IDEOGRAPH-#26F2B, IRGKangXi=1059.320, RSKangXi=140.13
26F2C CJK UNIFIED IDEOGRAPH-#26F2C, IRGKangXi=1059.360, RSKangXi=140.13
26F2D CJK UNIFIED IDEOGRAPH-#26F2D, IRGKangXi=1059.370, RSKangXi=140.13
26F2E CJK UNIFIED IDEOGRAPH-#26F2E, IRGKangXi=1059.390, RSKangXi=140.13
26F2F CJK UNIFIED IDEOGRAPH-#26F2F, IRGKangXi=1059.470, RSKangXi=140.13, Def{dock}
26F30 CJK UNIFIED IDEOGRAPH-#26F30, IRGKangXi=1059.500, RSKangXi=140.13
26F31 CJK UNIFIED IDEOGRAPH-#26F31, IRGKangXi=1060.020, RSKangXi=140.13
26F32 CJK UNIFIED IDEOGRAPH-#26F32, IRGKangXi=1060.030, RSKangXi=140.13
26F33 CJK UNIFIED IDEOGRAPH-#26F33, IRGKangXi=1060.050, RSKangXi=140.13
26F34 CJK UNIFIED IDEOGRAPH-#26F34, IRGKangXi=1060.060, RSKangXi=140.13
26F35 CJK UNIFIED IDEOGRAPH-#26F35, IRGKangXi=1060.080, RSKangXi=140.13
26F36 CJK UNIFIED IDEOGRAPH-#26F36, IRGKangXi=1060.100, RSKangXi=140.13
26F37 CJK UNIFIED IDEOGRAPH-#26F37, IRGKangXi=1060.110, RSKangXi=140.13
26F38 CJK UNIFIED IDEOGRAPH-#26F38, IRGKangXi=1060.150, RSKangXi=140.13
26F39 CJK UNIFIED IDEOGRAPH-#26F39, IRGKangXi=1060.180, RSKangXi=140.13
26F3A CJK UNIFIED IDEOGRAPH-#26F3A, IRGKangXi=1060.190, RSKangXi=140.13
26F3B CJK UNIFIED IDEOGRAPH-#26F3B, IRGKangXi=1060.200, RSKangXi=140.13
26F3C CJK UNIFIED IDEOGRAPH-#26F3C, IRGKangXi=1060.250, RSKangXi=140.13
26F3D CJK UNIFIED IDEOGRAPH-#26F3D, IRGKangXi=1060.270, RSKangXi=140.13
26F3E CJK UNIFIED IDEOGRAPH-#26F3E, IRGKangXi=1060.300, RSKangXi=140.13
26F3F CJK UNIFIED IDEOGRAPH-#26F3F, IRGKangXi=1061.010, RSKangXi=140.13
26F40 CJK UNIFIED IDEOGRAPH-#26F40, IRGKangXi=1061.020, RSKangXi=140.13
26F41 CJK UNIFIED IDEOGRAPH-#26F41, IRGKangXi=1061.060, RSKangXi=140.13
26F42 CJK UNIFIED IDEOGRAPH-#26F42, IRGKangXi=1061.080, RSKangXi=140.13
26F43 CJK UNIFIED IDEOGRAPH-#26F43, IRGKangXi=1061.140, RSKangXi=140.13
26F44 CJK UNIFIED IDEOGRAPH-#26F44, IRGKangXi=1061.160, RSKangXi=140.13
26F45 CJK UNIFIED IDEOGRAPH-#26F45, IRGKangXi=1061.230, RSKangXi=140.13
26F46 CJK UNIFIED IDEOGRAPH-#26F46, IRGKangXi=1061.250, RSKangXi=140.13
26F47 CJK UNIFIED IDEOGRAPH-#26F47, IRGKangXi=1061.270, RSKangXi=140.13
26F48 CJK UNIFIED IDEOGRAPH-#26F48, IRGKangXi=1061.290, RSKangXi=140.13
26F49 CJK UNIFIED IDEOGRAPH-#26F49, IRGKangXi=1061.320, RSKangXi=140.13
26F4A CJK UNIFIED IDEOGRAPH-#26F4A, IRGKangXi=1061.330, RSKangXi=140.13, Def{a chestnut horse}
26F4B CJK UNIFIED IDEOGRAPH-#26F4B, IRGKangXi=1061.340, RSKangXi=140.13
26F4C CJK UNIFIED IDEOGRAPH-#26F4C, IRGKangXi=1061.350, RSKangXi=140.13
26F4D CJK UNIFIED IDEOGRAPH-#26F4D, IRGKangXi=1061.360, RSKangXi=140.13
26F4E CJK UNIFIED IDEOGRAPH-#26F4E, IRGKangXi=1061.370, RSKangXi=140.13
26F4F CJK UNIFIED IDEOGRAPH-#26F4F, IRGKangXi=1062.040, RSKangXi=140.13
26F50 CJK UNIFIED IDEOGRAPH-#26F50, IRGKangXi=1062.100, RSKangXi=140.13
26F51 CJK UNIFIED IDEOGRAPH-#26F51, IRGKangXi=1062.110, RSKangXi=140.13
26F52 CJK UNIFIED IDEOGRAPH-#26F52, IRGKangXi=1062.120, RSKangXi=140.13
26F53 CJK UNIFIED IDEOGRAPH-#26F53, IRGKangXi=1062.130, RSKangXi=140.13
26F54 CJK UNIFIED IDEOGRAPH-#26F54, IRGKangXi=1062.140, RSKangXi=140.13
26F55 CJK UNIFIED IDEOGRAPH-#26F55, IRGKangXi=1062.150, RSKangXi=140.13
26F56 CJK UNIFIED IDEOGRAPH-#26F56, IRGKangXi=1062.160, RSKangXi=140.13
26F57 CJK UNIFIED IDEOGRAPH-#26F57, IRGKangXi=1062.170, RSKangXi=140.13
26F58 CJK UNIFIED IDEOGRAPH-#26F58, IRGKangXi=1062.180, RSKangXi=140.13
26F59 CJK UNIFIED IDEOGRAPH-#26F59, IRGKangXi=1062.190, RSKangXi=140.13
26F5A CJK UNIFIED IDEOGRAPH-#26F5A, IRGKangXi=1062.200, RSKangXi=140.13
26F5B CJK UNIFIED IDEOGRAPH-#26F5B, IRGKangXi=1062.210, RSKangXi=140.13
26F5C CJK UNIFIED IDEOGRAPH-#26F5C, IRGKangXi=1062.220, RSKangXi=140.13
26F5D CJK UNIFIED IDEOGRAPH-#26F5D, IRGKangXi=1062.230, RSKangXi=140.13
26F5E CJK UNIFIED IDEOGRAPH-#26F5E, IRGKangXi=1062.240, RSKangXi=140.13
26F5F CJK UNIFIED IDEOGRAPH-#26F5F, IRGKangXi=1062.250, RSKangXi=140.13
26F60 CJK UNIFIED IDEOGRAPH-#26F60, IRGKangXi=1062.260, RSKangXi=140.13
26F61 CJK UNIFIED IDEOGRAPH-#26F61, IRGKangXi=1062.270, RSKangXi=140.13
26F62 CJK UNIFIED IDEOGRAPH-#26F62, IRGKangXi=1062.280, RSKangXi=140.13
26F63 CJK UNIFIED IDEOGRAPH-#26F63, IRGKangXi=1062.290, RSKangXi=140.13
26F64 CJK UNIFIED IDEOGRAPH-#26F64, IRGKangXi=1062.300, RSKangXi=140.13
26F65 CJK UNIFIED IDEOGRAPH-#26F65, IRGKangXi=1062.310, RSKangXi=140.13
26F66 CJK UNIFIED IDEOGRAPH-#26F66, IRGKangXi=1062.320, RSKangXi=140.13
26F67 CJK UNIFIED IDEOGRAPH-#26F67, IRGKangXi=1062.330, RSKangXi=140.13
26F68 CJK UNIFIED IDEOGRAPH-#26F68, IRGKangXi=1062.340, RSKangXi=140.13
26F69 CJK UNIFIED IDEOGRAPH-#26F69, IRGKangXi=1062.350, RSKangXi=140.13
26F6A CJK UNIFIED IDEOGRAPH-#26F6A, IRGKangXi=1062.370, RSKangXi=140.13
26F6B CJK UNIFIED IDEOGRAPH-#26F6B, IRGKangXi=1062.380, RSKangXi=140.13
26F6C CJK UNIFIED IDEOGRAPH-#26F6C, IRGKangXi=1062.390, RSKangXi=140.13
26F6D CJK UNIFIED IDEOGRAPH-#26F6D, IRGKangXi=1062.400, RSKangXi=140.12
26F6E CJK UNIFIED IDEOGRAPH-#26F6E, IRGKangXi=1062.410, RSKangXi=140.13
26F6F CJK UNIFIED IDEOGRAPH-#26F6F, IRGKangXi=1062.430, RSKangXi=140.13
26F70 CJK UNIFIED IDEOGRAPH-#26F70, IRGKangXi=1062.431, RSKangXi=140.13
26F71 CJK UNIFIED IDEOGRAPH-#26F71, IRGKangXi=1062.440, RSKangXi=140.13
26F72 CJK UNIFIED IDEOGRAPH-#26F72, IRGKangXi=1062.441, RSKangXi=140.13
26F73 CJK UNIFIED IDEOGRAPH-#26F73, IRGKangXi=1062.441, RSKangXi=140.13
26F74 CJK UNIFIED IDEOGRAPH-#26F74, IRGKangXi=1062.441, RSKangXi=140.13
26F75 CJK UNIFIED IDEOGRAPH-#26F75, IRGKangXi=1062.441, RSKangXi=140.13
26F76 CJK UNIFIED IDEOGRAPH-#26F76, IRGKangXi=1062.441, RSKangXi=140.13
26F77 CJK UNIFIED IDEOGRAPH-#26F77, IRGKangXi=1062.441, RSKangXi=140.13
26F78 CJK UNIFIED IDEOGRAPH-#26F78, IRGKangXi=1062.441, RSKangXi=140.13
26F79 CJK UNIFIED IDEOGRAPH-#26F79, IRGKangXi=1062.441, RSKangXi=140.13
26F7A CJK UNIFIED IDEOGRAPH-#26F7A, IRGKangXi=1062.441, RSKangXi=140.13
26F7B CJK UNIFIED IDEOGRAPH-#26F7B, IRGKangXi=1062.441, RSKangXi=140.13
26F7C CJK UNIFIED IDEOGRAPH-#26F7C, IRGKangXi=1062.441, RSKangXi=140.13
26F7D CJK UNIFIED IDEOGRAPH-#26F7D, IRGKangXi=1062.441, RSKangXi=140.13
26F7E CJK UNIFIED IDEOGRAPH-#26F7E, IRGKangXi=1062.441, RSKangXi=140.13
26F7F CJK UNIFIED IDEOGRAPH-#26F7F, IRGKangXi=1062.441, RSKangXi=140.13
26F80 CJK UNIFIED IDEOGRAPH-#26F80, IRGKangXi=1062.441, RSKangXi=140.13
26F81 CJK UNIFIED IDEOGRAPH-#26F81, IRGKangXi=1062.441, RSKangXi=140.13
26F82 CJK UNIFIED IDEOGRAPH-#26F82, IRGKangXi=1062.441, RSKangXi=140.13
26F83 CJK UNIFIED IDEOGRAPH-#26F83, IRGKangXi=1062.441, RSKangXi=140.13
26F84 CJK UNIFIED IDEOGRAPH-#26F84, IRGKangXi=1062.441, RSKangXi=140.13
26F85 CJK UNIFIED IDEOGRAPH-#26F85, IRGKangXi=1062.441, RSKangXi=140.13
26F86 CJK UNIFIED IDEOGRAPH-#26F86, IRGKangXi=1062.441, RSKangXi=140.13
26F87 CJK UNIFIED IDEOGRAPH-#26F87, IRGKangXi=1062.441, RSKangXi=140.13
26F88 CJK UNIFIED IDEOGRAPH-#26F88, IRGKangXi=1062.441, RSKangXi=140.13
26F89 CJK UNIFIED IDEOGRAPH-#26F89, IRGKangXi=1062.441, RSKangXi=140.13
26F8A CJK UNIFIED IDEOGRAPH-#26F8A, IRGKangXi=1062.441, RSKangXi=140.13
26F8B CJK UNIFIED IDEOGRAPH-#26F8B, IRGKangXi=1062.441, RSKangXi=140.13
26F8C CJK UNIFIED IDEOGRAPH-#26F8C, IRGKangXi=1062.441, RSKangXi=140.13
26F8D CJK UNIFIED IDEOGRAPH-#26F8D, IRGKangXi=1062.441, RSKangXi=140.13
26F8E CJK UNIFIED IDEOGRAPH-#26F8E, IRGKangXi=1062.441, RSKangXi=140.13
26F8F CJK UNIFIED IDEOGRAPH-#26F8F, IRGKangXi=1062.441, RSKangXi=140.13
26F90 CJK UNIFIED IDEOGRAPH-#26F90, IRGKangXi=1062.441, RSKangXi=140.13
26F91 CJK UNIFIED IDEOGRAPH-#26F91, IRGKangXi=1062.441, RSKangXi=140.13
26F92 CJK UNIFIED IDEOGRAPH-#26F92, IRGKangXi=1062.441, RSKangXi=140.13
26F93 CJK UNIFIED IDEOGRAPH-#26F93, IRGKangXi=1062.441, RSKangXi=140.13
26F94 CJK UNIFIED IDEOGRAPH-#26F94, IRGKangXi=1062.441, RSKangXi=140.13
26F95 CJK UNIFIED IDEOGRAPH-#26F95, IRGKangXi=1062.441, RSKangXi=140.13
26F96 CJK UNIFIED IDEOGRAPH-#26F96, IRGKangXi=1062.441, RSKangXi=140.13
26F97 CJK UNIFIED IDEOGRAPH-#26F97, IRGKangXi=1062.441, RSKangXi=140.13
26F98 CJK UNIFIED IDEOGRAPH-#26F98, IRGKangXi=1062.441, RSKangXi=140.13
26F99 CJK UNIFIED IDEOGRAPH-#26F99, IRGKangXi=1062.441, RSKangXi=140.13
26F9A CJK UNIFIED IDEOGRAPH-#26F9A, IRGKangXi=1062.441, RSKangXi=140.13
26F9B CJK UNIFIED IDEOGRAPH-#26F9B, IRGKangXi=1062.441, RSKangXi=140.13
26F9C CJK UNIFIED IDEOGRAPH-#26F9C, IRGKangXi=1062.441, RSKangXi=140.13
26F9D CJK UNIFIED IDEOGRAPH-#26F9D, IRGKangXi=1062.441, RSKangXi=140.13
26F9E CJK UNIFIED IDEOGRAPH-#26F9E, IRGKangXi=1062.441, RSKangXi=140.13
26F9F CJK UNIFIED IDEOGRAPH-#26F9F, IRGKangXi=1062.441, RSKangXi=140.13
26FA0 CJK UNIFIED IDEOGRAPH-#26FA0, IRGKangXi=1062.441, RSKangXi=140.13
26FA1 CJK UNIFIED IDEOGRAPH-#26FA1, IRGKangXi=1062.441, RSKangXi=140.13
26FA2 CJK UNIFIED IDEOGRAPH-#26FA2, IRGKangXi=1062.441, RSKangXi=140.13
26FA3 CJK UNIFIED IDEOGRAPH-#26FA3, IRGKangXi=1062.441, RSKangXi=140.13
26FA4 CJK UNIFIED IDEOGRAPH-#26FA4, IRGKangXi=1062.441, RSKangXi=140.13
26FA5 CJK UNIFIED IDEOGRAPH-#26FA5, IRGKangXi=1062.441, RSKangXi=140.13
26FA6 CJK UNIFIED IDEOGRAPH-#26FA6, IRGKangXi=1062.441, RSKangXi=140.13
26FA7 CJK UNIFIED IDEOGRAPH-#26FA7, IRGKangXi=1062.441, RSKangXi=140.13
26FA8 CJK UNIFIED IDEOGRAPH-#26FA8, IRGKangXi=1062.441, RSKangXi=140.13
26FA9 CJK UNIFIED IDEOGRAPH-#26FA9, IRGKangXi=1062.441, RSKangXi=140.13
26FAA CJK UNIFIED IDEOGRAPH-#26FAA, IRGKangXi=1062.441, RSKangXi=140.14
26FAB CJK UNIFIED IDEOGRAPH-#26FAB, IRGKangXi=1062.530, RSKangXi=140.14
26FAC CJK UNIFIED IDEOGRAPH-#26FAC, IRGKangXi=1062.540, RSKangXi=140.14
26FAD CJK UNIFIED IDEOGRAPH-#26FAD, IRGKangXi=1063.010, RSKangXi=140.14
26FAE CJK UNIFIED IDEOGRAPH-#26FAE, IRGKangXi=1063.050, RSKangXi=140.14
26FAF CJK UNIFIED IDEOGRAPH-#26FAF, IRGKangXi=1063.060, RSKangXi=140.14
26FB0 CJK UNIFIED IDEOGRAPH-#26FB0, IRGKangXi=1063.090, RSKangXi=140.14
26FB1 CJK UNIFIED IDEOGRAPH-#26FB1, IRGKangXi=1063.110, RSKangXi=140.14
26FB2 CJK UNIFIED IDEOGRAPH-#26FB2, IRGKangXi=1063.130, RSKangXi=140.14
26FB3 CJK UNIFIED IDEOGRAPH-#26FB3, IRGKangXi=1063.150, RSKangXi=140.14
26FB4 CJK UNIFIED IDEOGRAPH-#26FB4, IRGKangXi=1063.170, RSKangXi=140.14
26FB5 CJK UNIFIED IDEOGRAPH-#26FB5, IRGKangXi=1063.200, RSKangXi=140.14
26FB6 CJK UNIFIED IDEOGRAPH-#26FB6, IRGKangXi=1063.260, RSKangXi=140.14
26FB7 CJK UNIFIED IDEOGRAPH-#26FB7, IRGKangXi=1063.270, RSKangXi=140.14
26FB8 CJK UNIFIED IDEOGRAPH-#26FB8, IRGKangXi=1063.290, RSKangXi=140.14
26FB9 CJK UNIFIED IDEOGRAPH-#26FB9, IRGKangXi=1063.300, RSKangXi=140.14
26FBA CJK UNIFIED IDEOGRAPH-#26FBA, IRGKangXi=1063.350, RSKangXi=140.14
26FBB CJK UNIFIED IDEOGRAPH-#26FBB, IRGKangXi=1063.370, RSKangXi=140.14
26FBC CJK UNIFIED IDEOGRAPH-#26FBC, IRGKangXi=1063.390, RSKangXi=140.14
26FBD CJK UNIFIED IDEOGRAPH-#26FBD, IRGKangXi=1063.400, RSKangXi=140.14
26FBE CJK UNIFIED IDEOGRAPH-#26FBE, IRGKangXi=1063.410, RSKangXi=140.14
26FBF CJK UNIFIED IDEOGRAPH-#26FBF, IRGKangXi=1064.010, RSKangXi=140.14
26FC0 CJK UNIFIED IDEOGRAPH-#26FC0, IRGKangXi=1064.020, RSKangXi=140.14
26FC1 CJK UNIFIED IDEOGRAPH-#26FC1, IRGKangXi=1064.030, RSKangXi=140.14
26FC2 CJK UNIFIED IDEOGRAPH-#26FC2, IRGKangXi=1064.050, RSKangXi=140.14
26FC3 CJK UNIFIED IDEOGRAPH-#26FC3, IRGKangXi=1064.090, RSKangXi=140.14
26FC4 CJK UNIFIED IDEOGRAPH-#26FC4, IRGKangXi=1064.100, RSKangXi=140.14
26FC5 CJK UNIFIED IDEOGRAPH-#26FC5, IRGKangXi=1064.110, RSKangXi=140.14
26FC6 CJK UNIFIED IDEOGRAPH-#26FC6, IRGKangXi=1064.120, RSKangXi=140.14
26FC7 CJK UNIFIED IDEOGRAPH-#26FC7, IRGKangXi=1064.130, RSKangXi=140.14
26FC8 CJK UNIFIED IDEOGRAPH-#26FC8, IRGKangXi=1064.140, RSKangXi=140.14
26FC9 CJK UNIFIED IDEOGRAPH-#26FC9, IRGKangXi=1064.170, RSKangXi=140.14
26FCA CJK UNIFIED IDEOGRAPH-#26FCA, IRGKangXi=1064.180, RSKangXi=140.14
26FCB CJK UNIFIED IDEOGRAPH-#26FCB, IRGKangXi=1064.190, RSKangXi=140.14
26FCC CJK UNIFIED IDEOGRAPH-#26FCC, IRGKangXi=1064.210, RSKangXi=140.14
26FCD CJK UNIFIED IDEOGRAPH-#26FCD, IRGKangXi=1064.240, RSKangXi=140.14
26FCE CJK UNIFIED IDEOGRAPH-#26FCE, IRGKangXi=1064.250, RSKangXi=140.14
26FCF CJK UNIFIED IDEOGRAPH-#26FCF, IRGKangXi=1064.280, RSKangXi=140.14
26FD0 CJK UNIFIED IDEOGRAPH-#26FD0, IRGKangXi=1064.300, RSKangXi=140.14
26FD1 CJK UNIFIED IDEOGRAPH-#26FD1, IRGKangXi=1064.320, RSKangXi=140.14
26FD2 CJK UNIFIED IDEOGRAPH-#26FD2, IRGKangXi=1064.330, RSKangXi=140.14
26FD3 CJK UNIFIED IDEOGRAPH-#26FD3, IRGKangXi=1064.340, RSKangXi=140.14
26FD4 CJK UNIFIED IDEOGRAPH-#26FD4, IRGKangXi=1064.350, RSKangXi=140.15
26FD5 CJK UNIFIED IDEOGRAPH-#26FD5, IRGKangXi=1064.370, RSKangXi=140.15
26FD6 CJK UNIFIED IDEOGRAPH-#26FD6, IRGKangXi=1064.380, RSKangXi=140.14
26FD7 CJK UNIFIED IDEOGRAPH-#26FD7, IRGKangXi=1064.390, RSKangXi=140.14
26FD8 CJK UNIFIED IDEOGRAPH-#26FD8, IRGKangXi=1064.400, RSKangXi=140.14
26FD9 CJK UNIFIED IDEOGRAPH-#26FD9, IRGKangXi=1064.410, RSKangXi=140.14
26FDA CJK UNIFIED IDEOGRAPH-#26FDA, IRGKangXi=1064.421, RSKangXi=140.14
26FDB CJK UNIFIED IDEOGRAPH-#26FDB, IRGKangXi=1064.421, RSKangXi=140.14
26FDC CJK UNIFIED IDEOGRAPH-#26FDC, IRGKangXi=1064.421, RSKangXi=140.14
26FDD CJK UNIFIED IDEOGRAPH-#26FDD, IRGKangXi=1064.421, RSKangXi=140.15
26FDE CJK UNIFIED IDEOGRAPH-#26FDE, IRGKangXi=1064.421, RSKangXi=140.14
26FDF CJK UNIFIED IDEOGRAPH-#26FDF, IRGKangXi=1064.421, RSKangXi=140.14
26FE0 CJK UNIFIED IDEOGRAPH-#26FE0, IRGKangXi=1064.421, RSKangXi=140.14
26FE1 CJK UNIFIED IDEOGRAPH-#26FE1, IRGKangXi=1064.421, RSKangXi=140.13
26FE2 CJK UNIFIED IDEOGRAPH-#26FE2, IRGKangXi=1064.421, RSKangXi=140.14
26FE3 CJK UNIFIED IDEOGRAPH-#26FE3, IRGKangXi=1064.421, RSKangXi=140.14
26FE4 CJK UNIFIED IDEOGRAPH-#26FE4, IRGKangXi=1064.421, RSKangXi=140.14
26FE5 CJK UNIFIED IDEOGRAPH-#26FE5, IRGKangXi=1064.421, RSKangXi=140.14
26FE6 CJK UNIFIED IDEOGRAPH-#26FE6, IRGKangXi=1064.421, RSKangXi=140.14
26FE7 CJK UNIFIED IDEOGRAPH-#26FE7, IRGKangXi=1064.421, RSKangXi=140.14
26FE8 CJK UNIFIED IDEOGRAPH-#26FE8, IRGKangXi=1064.421, RSKangXi=140.14
26FE9 CJK UNIFIED IDEOGRAPH-#26FE9, IRGKangXi=1064.421, RSKangXi=140.14
26FEA CJK UNIFIED IDEOGRAPH-#26FEA, IRGKangXi=1064.421, RSKangXi=140.14
26FEB CJK UNIFIED IDEOGRAPH-#26FEB, IRGKangXi=1064.421, RSKangXi=140.14
26FEC CJK UNIFIED IDEOGRAPH-#26FEC, IRGKangXi=1064.421, RSKangXi=140.14
26FED CJK UNIFIED IDEOGRAPH-#26FED, IRGKangXi=1064.421, RSKangXi=140.14
26FEE CJK UNIFIED IDEOGRAPH-#26FEE, IRGKangXi=1064.421, RSKangXi=140.14
26FEF CJK UNIFIED IDEOGRAPH-#26FEF, IRGKangXi=1064.421, RSKangXi=140.14
26FF0 CJK UNIFIED IDEOGRAPH-#26FF0, IRGKangXi=1064.421, RSKangXi=140.14
26FF1 CJK UNIFIED IDEOGRAPH-#26FF1, IRGKangXi=1064.421, RSKangXi=140.14
26FF2 CJK UNIFIED IDEOGRAPH-#26FF2, IRGKangXi=1064.421, RSKangXi=140.14
26FF3 CJK UNIFIED IDEOGRAPH-#26FF3, IRGKangXi=1064.421, RSKangXi=140.14
26FF4 CJK UNIFIED IDEOGRAPH-#26FF4, IRGKangXi=1064.421, RSKangXi=140.14
26FF5 CJK UNIFIED IDEOGRAPH-#26FF5, IRGKangXi=1064.421, RSKangXi=140.14
26FF6 CJK UNIFIED IDEOGRAPH-#26FF6, IRGKangXi=1064.421, RSKangXi=140.14
26FF7 CJK UNIFIED IDEOGRAPH-#26FF7, IRGKangXi=1064.421, RSKangXi=140.14
26FF8 CJK UNIFIED IDEOGRAPH-#26FF8, IRGKangXi=1064.421, RSKangXi=140.13
26FF9 CJK UNIFIED IDEOGRAPH-#26FF9, IRGKangXi=1064.421, RSKangXi=140.14
26FFA CJK UNIFIED IDEOGRAPH-#26FFA, IRGKangXi=1064.421, RSKangXi=140.14
26FFB CJK UNIFIED IDEOGRAPH-#26FFB, IRGKangXi=1064.421, RSKangXi=140.14
26FFC CJK UNIFIED IDEOGRAPH-#26FFC, IRGKangXi=1064.421, RSKangXi=140.14
26FFD CJK UNIFIED IDEOGRAPH-#26FFD, IRGKangXi=1064.421, RSKangXi=140.14
26FFE CJK UNIFIED IDEOGRAPH-#26FFE, IRGKangXi=1064.421, RSKangXi=140.14
26FFF CJK UNIFIED IDEOGRAPH-#26FFF, IRGKangXi=1064.421, RSKangXi=140.14
27000 CJK UNIFIED IDEOGRAPH-#27000, IRGKangXi=1064.421, RSKangXi=140.14
27001 CJK UNIFIED IDEOGRAPH-#27001, IRGKangXi=1064.421, RSKangXi=140.14
27002 CJK UNIFIED IDEOGRAPH-#27002, IRGKangXi=1064.421, RSKangXi=140.14
27003 CJK UNIFIED IDEOGRAPH-#27003, IRGKangXi=1064.421, RSKangXi=140.14
27004 CJK UNIFIED IDEOGRAPH-#27004, IRGKangXi=1064.421, RSKangXi=140.14
27005 CJK UNIFIED IDEOGRAPH-#27005, IRGKangXi=1064.421, RSKangXi=140.14
27006 CJK UNIFIED IDEOGRAPH-#27006, IRGKangXi=1064.421, RSKangXi=140.14
27007 CJK UNIFIED IDEOGRAPH-#27007, IRGKangXi=1064.421, RSKangXi=140.14
27008 CJK UNIFIED IDEOGRAPH-#27008, IRGKangXi=1064.421, RSKangXi=140.14
27009 CJK UNIFIED IDEOGRAPH-#27009, IRGKangXi=1064.421, RSKangXi=140.14
2700A CJK UNIFIED IDEOGRAPH-#2700A, IRGKangXi=1064.421, RSKangXi=140.14
2700B CJK UNIFIED IDEOGRAPH-#2700B, IRGKangXi=1064.421, RSKangXi=140.14
2700C CJK UNIFIED IDEOGRAPH-#2700C, IRGKangXi=1064.421, RSKangXi=140.14
2700D CJK UNIFIED IDEOGRAPH-#2700D, IRGKangXi=1064.421, RSKangXi=140.14
2700E CJK UNIFIED IDEOGRAPH-#2700E, IRGKangXi=1064.421, RSKangXi=140.14
2700F CJK UNIFIED IDEOGRAPH-#2700F, IRGKangXi=1064.421, RSKangXi=140.14
27010 CJK UNIFIED IDEOGRAPH-#27010, IRGKangXi=1064.421, RSKangXi=140.14
27011 CJK UNIFIED IDEOGRAPH-#27011, IRGKangXi=1064.421, RSKangXi=140.14
27012 CJK UNIFIED IDEOGRAPH-#27012, IRGKangXi=1064.421, RSKangXi=140.14
27013 CJK UNIFIED IDEOGRAPH-#27013, IRGKangXi=1064.421, RSKangXi=140.14
27014 CJK UNIFIED IDEOGRAPH-#27014, IRGKangXi=1064.421, RSKangXi=140.14
27015 CJK UNIFIED IDEOGRAPH-#27015, IRGKangXi=1064.421, RSKangXi=140.14
27016 CJK UNIFIED IDEOGRAPH-#27016, IRGKangXi=1064.421, RSKangXi=140.14
27017 CJK UNIFIED IDEOGRAPH-#27017, IRGKangXi=1064.421, RSKangXi=140.14
27018 CJK UNIFIED IDEOGRAPH-#27018, IRGKangXi=1064.421, RSKangXi=140.14
27019 CJK UNIFIED IDEOGRAPH-#27019, IRGKangXi=1064.421, RSKangXi=140.14
2701A CJK UNIFIED IDEOGRAPH-#2701A, IRGKangXi=1064.421, RSKangXi=140.14
2701B CJK UNIFIED IDEOGRAPH-#2701B, IRGKangXi=1064.421, RSKangXi=140.14
2701C CJK UNIFIED IDEOGRAPH-#2701C, IRGKangXi=1064.421, RSKangXi=140.14
2701D CJK UNIFIED IDEOGRAPH-#2701D, IRGKangXi=1064.421, RSKangXi=140.14
2701E CJK UNIFIED IDEOGRAPH-#2701E, IRGKangXi=1064.421, RSKangXi=140.14
2701F CJK UNIFIED IDEOGRAPH-#2701F, IRGKangXi=1064.421, RSKangXi=140.14
27020 CJK UNIFIED IDEOGRAPH-#27020, IRGKangXi=1064.430, RSKangXi=140.15
27021 CJK UNIFIED IDEOGRAPH-#27021, IRGKangXi=1065.030, RSKangXi=140.15
27022 CJK UNIFIED IDEOGRAPH-#27022, IRGKangXi=1065.040, RSKangXi=140.15
27023 CJK UNIFIED IDEOGRAPH-#27023, IRGKangXi=1065.050, RSKangXi=140.15
27024 CJK UNIFIED IDEOGRAPH-#27024, IRGKangXi=1065.070, RSKangXi=140.15
27025 CJK UNIFIED IDEOGRAPH-#27025, IRGKangXi=1065.080, RSKangXi=140.15
27026 CJK UNIFIED IDEOGRAPH-#27026, IRGKangXi=1065.100, RSKangXi=140.15
27027 CJK UNIFIED IDEOGRAPH-#27027, IRGKangXi=1065.110, RSKangXi=140.15
27028 CJK UNIFIED IDEOGRAPH-#27028, IRGKangXi=1065.120, RSKangXi=140.15
27029 CJK UNIFIED IDEOGRAPH-#27029, IRGKangXi=1065.130, RSKangXi=140.15
2702A CJK UNIFIED IDEOGRAPH-#2702A, IRGKangXi=1065.140, RSKangXi=140.15
2702B CJK UNIFIED IDEOGRAPH-#2702B, IRGKangXi=1065.150, RSKangXi=140.15
2702C CJK UNIFIED IDEOGRAPH-#2702C, IRGKangXi=1065.180, RSKangXi=140.15
2702D CJK UNIFIED IDEOGRAPH-#2702D, IRGKangXi=1065.190, RSKangXi=140.15
2702E CJK UNIFIED IDEOGRAPH-#2702E, IRGKangXi=1065.200, RSKangXi=140.15
2702F CJK UNIFIED IDEOGRAPH-#2702F, IRGKangXi=1065.220, RSKangXi=140.15
27030 CJK UNIFIED IDEOGRAPH-#27030, IRGKangXi=1065.230, RSKangXi=140.15
27031 CJK UNIFIED IDEOGRAPH-#27031, IRGKangXi=1065.240, RSKangXi=140.15
27032 CJK UNIFIED IDEOGRAPH-#27032, IRGKangXi=1065.290, RSKangXi=140.15
27033 CJK UNIFIED IDEOGRAPH-#27033, IRGKangXi=1065.310, RSKangXi=140.15
27034 CJK UNIFIED IDEOGRAPH-#27034, IRGKangXi=1065.320, RSKangXi=140.15
27035 CJK UNIFIED IDEOGRAPH-#27035, IRGKangXi=1065.330, RSKangXi=140.15
27036 CJK UNIFIED IDEOGRAPH-#27036, IRGKangXi=1065.360, RSKangXi=140.15
27037 CJK UNIFIED IDEOGRAPH-#27037, IRGKangXi=1065.370, RSKangXi=140.15
27038 CJK UNIFIED IDEOGRAPH-#27038, IRGKangXi=1065.380, RSKangXi=140.15
27039 CJK UNIFIED IDEOGRAPH-#27039, IRGKangXi=1066.040, RSKangXi=140.15
2703A CJK UNIFIED IDEOGRAPH-#2703A, IRGKangXi=1066.060, RSKangXi=140.15
2703B CJK UNIFIED IDEOGRAPH-#2703B, IRGKangXi=1066.100, RSKangXi=140.15
2703C CJK UNIFIED IDEOGRAPH-#2703C, IRGKangXi=1066.120, RSKangXi=140.15
2703D CJK UNIFIED IDEOGRAPH-#2703D, IRGKangXi=1066.170, RSKangXi=140.15
2703E CJK UNIFIED IDEOGRAPH-#2703E, IRGKangXi=1066.190, RSKangXi=140.15
2703F CJK UNIFIED IDEOGRAPH-#2703F, IRGKangXi=1066.210, RSKangXi=140.15
27040 CJK UNIFIED IDEOGRAPH-#27040, IRGKangXi=1066.220, RSKangXi=140.15
27041 CJK UNIFIED IDEOGRAPH-#27041, IRGKangXi=1066.230, RSKangXi=140.15
27042 CJK UNIFIED IDEOGRAPH-#27042, IRGKangXi=1066.240, RSKangXi=140.15
27043 CJK UNIFIED IDEOGRAPH-#27043, IRGKangXi=1066.250, RSKangXi=140.15
27044 CJK UNIFIED IDEOGRAPH-#27044, IRGKangXi=1066.260, RSKangXi=140.15
27045 CJK UNIFIED IDEOGRAPH-#27045, IRGKangXi=1066.280, RSKangXi=140.15
27046 CJK UNIFIED IDEOGRAPH-#27046, IRGKangXi=1066.290, RSKangXi=140.15
27047 CJK UNIFIED IDEOGRAPH-#27047, IRGKangXi=1066.300, RSKangXi=140.15
27048 CJK UNIFIED IDEOGRAPH-#27048, IRGKangXi=1066.310, RSKangXi=140.15
27049 CJK UNIFIED IDEOGRAPH-#27049, IRGKangXi=1066.320, RSKangXi=140.15
2704A CJK UNIFIED IDEOGRAPH-#2704A, IRGKangXi=1066.330, RSKangXi=140.15
2704B CJK UNIFIED IDEOGRAPH-#2704B, IRGKangXi=1066.340, RSKangXi=140.15
2704C CJK UNIFIED IDEOGRAPH-#2704C, IRGKangXi=1066.350, RSKangXi=140.15
2704D CJK UNIFIED IDEOGRAPH-#2704D, IRGKangXi=1066.360, RSKangXi=140.15
2704E CJK UNIFIED IDEOGRAPH-#2704E, IRGKangXi=1066.370, RSKangXi=140.15
2704F CJK UNIFIED IDEOGRAPH-#2704F, IRGKangXi=1066.371, RSKangXi=140.15
27050 CJK UNIFIED IDEOGRAPH-#27050, IRGKangXi=1066.371, RSKangXi=140.15
27051 CJK UNIFIED IDEOGRAPH-#27051, IRGKangXi=1066.371, RSKangXi=140.15
27052 CJK UNIFIED IDEOGRAPH-#27052, IRGKangXi=1066.371, RSKangXi=140.15
27053 CJK UNIFIED IDEOGRAPH-#27053, IRGKangXi=1066.371, RSKangXi=140.15
27054 CJK UNIFIED IDEOGRAPH-#27054, IRGKangXi=1066.371, RSKangXi=140.15
27055 CJK UNIFIED IDEOGRAPH-#27055, IRGKangXi=1066.371, RSKangXi=140.15
27056 CJK UNIFIED IDEOGRAPH-#27056, IRGKangXi=1066.371, RSKangXi=140.15
27057 CJK UNIFIED IDEOGRAPH-#27057, IRGKangXi=1066.371, RSKangXi=140.15
27058 CJK UNIFIED IDEOGRAPH-#27058, IRGKangXi=1066.371, RSKangXi=140.15
27059 CJK UNIFIED IDEOGRAPH-#27059, IRGKangXi=1066.371, RSKangXi=140.15
2705A CJK UNIFIED IDEOGRAPH-#2705A, IRGKangXi=1066.371, RSKangXi=140.15
2705B CJK UNIFIED IDEOGRAPH-#2705B, IRGKangXi=1066.371, RSKangXi=140.15
2705C CJK UNIFIED IDEOGRAPH-#2705C, IRGKangXi=1066.371, RSKangXi=140.15
2705D CJK UNIFIED IDEOGRAPH-#2705D, IRGKangXi=1066.371, RSKangXi=140.15
2705E CJK UNIFIED IDEOGRAPH-#2705E, IRGKangXi=1066.371, RSKangXi=140.15
2705F CJK UNIFIED IDEOGRAPH-#2705F, IRGKangXi=1066.371, RSKangXi=140.15
27060 CJK UNIFIED IDEOGRAPH-#27060, IRGKangXi=1066.371, RSKangXi=140.15
27061 CJK UNIFIED IDEOGRAPH-#27061, IRGKangXi=1066.371, RSKangXi=140.15
27062 CJK UNIFIED IDEOGRAPH-#27062, IRGKangXi=1066.371, RSKangXi=140.15
27063 CJK UNIFIED IDEOGRAPH-#27063, IRGKangXi=1066.371, RSKangXi=140.15
27064 CJK UNIFIED IDEOGRAPH-#27064, IRGKangXi=1066.371, RSKangXi=140.15
27065 CJK UNIFIED IDEOGRAPH-#27065, IRGKangXi=1066.371, RSKangXi=140.15
27066 CJK UNIFIED IDEOGRAPH-#27066, IRGKangXi=1066.371, RSKangXi=140.15
27067 CJK UNIFIED IDEOGRAPH-#27067, IRGKangXi=1066.371, RSKangXi=140.15
27068 CJK UNIFIED IDEOGRAPH-#27068, IRGKangXi=1066.371, RSKangXi=140.15
27069 CJK UNIFIED IDEOGRAPH-#27069, IRGKangXi=1066.371, RSKangXi=140.15
2706A CJK UNIFIED IDEOGRAPH-#2706A, IRGKangXi=1066.371, RSKangXi=140.15
2706B CJK UNIFIED IDEOGRAPH-#2706B, IRGKangXi=1066.371, RSKangXi=140.15
2706C CJK UNIFIED IDEOGRAPH-#2706C, IRGKangXi=1066.371, RSKangXi=140.15
2706D CJK UNIFIED IDEOGRAPH-#2706D, IRGKangXi=1066.371, RSKangXi=140.15
2706E CJK UNIFIED IDEOGRAPH-#2706E, IRGKangXi=1066.371, RSKangXi=140.15
2706F CJK UNIFIED IDEOGRAPH-#2706F, IRGKangXi=1066.371, RSKangXi=140.15
27070 CJK UNIFIED IDEOGRAPH-#27070, IRGKangXi=1066.371, RSKangXi=140.15
27071 CJK UNIFIED IDEOGRAPH-#27071, IRGKangXi=1066.371, RSKangXi=140.15
27072 CJK UNIFIED IDEOGRAPH-#27072, IRGKangXi=1066.371, RSKangXi=140.15
27073 CJK UNIFIED IDEOGRAPH-#27073, IRGKangXi=1066.371, RSKangXi=140.15
27074 CJK UNIFIED IDEOGRAPH-#27074, IRGKangXi=1066.371, RSKangXi=140.15
27075 CJK UNIFIED IDEOGRAPH-#27075, IRGKangXi=1066.371, RSKangXi=140.15
27076 CJK UNIFIED IDEOGRAPH-#27076, IRGKangXi=1066.371, RSKangXi=140.15
27077 CJK UNIFIED IDEOGRAPH-#27077, IRGKangXi=1066.371, RSKangXi=140.15
27078 CJK UNIFIED IDEOGRAPH-#27078, IRGKangXi=1066.371, RSKangXi=140.15
27079 CJK UNIFIED IDEOGRAPH-#27079, IRGKangXi=1066.371, RSKangXi=140.15
2707A CJK UNIFIED IDEOGRAPH-#2707A, IRGKangXi=1066.371, RSKangXi=140.15
2707B CJK UNIFIED IDEOGRAPH-#2707B, IRGKangXi=1066.371, RSKangXi=140.15
2707C CJK UNIFIED IDEOGRAPH-#2707C, IRGKangXi=1066.380, RSKangXi=140.16
2707D CJK UNIFIED IDEOGRAPH-#2707D, IRGKangXi=1066.390, RSKangXi=140.16
2707E CJK UNIFIED IDEOGRAPH-#2707E, IRGKangXi=1066.430, RSKangXi=140.16
2707F CJK UNIFIED IDEOGRAPH-#2707F, IRGKangXi=1066.440, RSKangXi=140.16
27080 CJK UNIFIED IDEOGRAPH-#27080, IRGKangXi=1067.030, RSKangXi=140.16
27081 CJK UNIFIED IDEOGRAPH-#27081, IRGKangXi=1067.040, RSKangXi=140.16
27082 CJK UNIFIED IDEOGRAPH-#27082, IRGKangXi=1067.050, RSKangXi=140.16
27083 CJK UNIFIED IDEOGRAPH-#27083, IRGKangXi=1067.060, RSKangXi=140.16
27084 CJK UNIFIED IDEOGRAPH-#27084, IRGKangXi=1067.080, RSKangXi=140.16
27085 CJK UNIFIED IDEOGRAPH-#27085, IRGKangXi=1067.100, RSKangXi=140.16
27086 CJK UNIFIED IDEOGRAPH-#27086, IRGKangXi=1067.230, RSKangXi=140.16
27087 CJK UNIFIED IDEOGRAPH-#27087, IRGKangXi=1067.250, RSKangXi=140.16
27088 CJK UNIFIED IDEOGRAPH-#27088, IRGKangXi=1067.280, RSKangXi=140.16
27089 CJK UNIFIED IDEOGRAPH-#27089, IRGKangXi=1067.290, RSKangXi=140.16
2708A CJK UNIFIED IDEOGRAPH-#2708A, IRGKangXi=1068.010, RSKangXi=140.16
2708B CJK UNIFIED IDEOGRAPH-#2708B, IRGKangXi=1068.030, RSKangXi=140.16
2708C CJK UNIFIED IDEOGRAPH-#2708C, IRGKangXi=1068.040, RSKangXi=140.16
2708D CJK UNIFIED IDEOGRAPH-#2708D, IRGKangXi=1068.060, RSKangXi=140.16
2708E CJK UNIFIED IDEOGRAPH-#2708E, IRGKangXi=1068.080, RSKangXi=140.16
2708F CJK UNIFIED IDEOGRAPH-#2708F, IRGKangXi=1068.120, RSKangXi=140.16
27090 CJK UNIFIED IDEOGRAPH-#27090, IRGKangXi=1068.160, RSKangXi=140.16
27091 CJK UNIFIED IDEOGRAPH-#27091, IRGKangXi=1068.170, RSKangXi=140.16
27092 CJK UNIFIED IDEOGRAPH-#27092, IRGKangXi=1068.190, RSKangXi=140.16
27093 CJK UNIFIED IDEOGRAPH-#27093, IRGKangXi=1068.200, RSKangXi=140.16
27094 CJK UNIFIED IDEOGRAPH-#27094, IRGKangXi=1068.210, RSKangXi=140.16
27095 CJK UNIFIED IDEOGRAPH-#27095, IRGKangXi=1068.220, RSKangXi=140.16
27096 CJK UNIFIED IDEOGRAPH-#27096, IRGKangXi=1068.230, RSKangXi=140.16
27097 CJK UNIFIED IDEOGRAPH-#27097, IRGKangXi=1068.240, RSKangXi=140.16
27098 CJK UNIFIED IDEOGRAPH-#27098, IRGKangXi=1068.250, RSKangXi=140.16
27099 CJK UNIFIED IDEOGRAPH-#27099, IRGKangXi=1068.260, RSKangXi=140.16
2709A CJK UNIFIED IDEOGRAPH-#2709A, IRGKangXi=1068.280, RSKangXi=140.16
2709B CJK UNIFIED IDEOGRAPH-#2709B, IRGKangXi=1068.290, RSKangXi=140.16
2709C CJK UNIFIED IDEOGRAPH-#2709C, IRGKangXi=1068.300, RSKangXi=140.16
2709D CJK UNIFIED IDEOGRAPH-#2709D, IRGKangXi=1068.310, RSKangXi=140.16
2709E CJK UNIFIED IDEOGRAPH-#2709E, IRGKangXi=1068.330, RSKangXi=140.16
2709F CJK UNIFIED IDEOGRAPH-#2709F, IRGKangXi=1068.340, RSKangXi=140.16
270A0 CJK UNIFIED IDEOGRAPH-#270A0, IRGKangXi=1068.350, RSKangXi=140.16
270A1 CJK UNIFIED IDEOGRAPH-#270A1, IRGKangXi=1068.370, RSKangXi=140.16
270A2 CJK UNIFIED IDEOGRAPH-#270A2, IRGKangXi=1068.380, RSKangXi=140.16
270A3 CJK UNIFIED IDEOGRAPH-#270A3, IRGKangXi=1068.390, RSKangXi=140.16
270A4 CJK UNIFIED IDEOGRAPH-#270A4, IRGKangXi=1068.400, RSKangXi=140.16
270A5 CJK UNIFIED IDEOGRAPH-#270A5, IRGKangXi=1068.410, RSKangXi=140.16
270A6 CJK UNIFIED IDEOGRAPH-#270A6, IRGKangXi=1068.420, RSKangXi=140.16
270A7 CJK UNIFIED IDEOGRAPH-#270A7, IRGKangXi=1069.010, RSKangXi=140.16
270A8 CJK UNIFIED IDEOGRAPH-#270A8, IRGKangXi=1069.020, RSKangXi=140.16
270A9 CJK UNIFIED IDEOGRAPH-#270A9, IRGKangXi=1069.030, RSKangXi=140.16
270AA CJK UNIFIED IDEOGRAPH-#270AA, IRGKangXi=1069.040, RSKangXi=140.16
270AB CJK UNIFIED IDEOGRAPH-#270AB, IRGKangXi=1069.060, RSKangXi=140.16
270AC CJK UNIFIED IDEOGRAPH-#270AC, IRGKangXi=1069.061, RSKangXi=140.16
270AD CJK UNIFIED IDEOGRAPH-#270AD, IRGKangXi=1069.061, RSKangXi=140.16
270AE CJK UNIFIED IDEOGRAPH-#270AE, IRGKangXi=1069.061, RSKangXi=140.16
270AF CJK UNIFIED IDEOGRAPH-#270AF, IRGKangXi=1069.061, RSKangXi=140.16
270B0 CJK UNIFIED IDEOGRAPH-#270B0, IRGKangXi=1069.061, RSKangXi=140.16
270B1 CJK UNIFIED IDEOGRAPH-#270B1, IRGKangXi=1069.061, RSKangXi=140.16
270B2 CJK UNIFIED IDEOGRAPH-#270B2, IRGKangXi=1069.061, RSKangXi=140.16
270B3 CJK UNIFIED IDEOGRAPH-#270B3, IRGKangXi=1069.061, RSKangXi=140.16
270B4 CJK UNIFIED IDEOGRAPH-#270B4, IRGKangXi=1069.061, RSKangXi=140.16
270B5 CJK UNIFIED IDEOGRAPH-#270B5, IRGKangXi=1069.061, RSKangXi=140.16
270B6 CJK UNIFIED IDEOGRAPH-#270B6, IRGKangXi=1069.061, RSKangXi=140.16
270B7 CJK UNIFIED IDEOGRAPH-#270B7, IRGKangXi=1069.061, RSKangXi=140.16
270B8 CJK UNIFIED IDEOGRAPH-#270B8, IRGKangXi=1069.061, RSKangXi=140.16
270B9 CJK UNIFIED IDEOGRAPH-#270B9, IRGKangXi=1069.061, RSKangXi=140.16
270BA CJK UNIFIED IDEOGRAPH-#270BA, IRGKangXi=1069.061, RSKangXi=140.16
270BB CJK UNIFIED IDEOGRAPH-#270BB, IRGKangXi=1069.061, RSKangXi=140.16
270BC CJK UNIFIED IDEOGRAPH-#270BC, IRGKangXi=1069.061, RSKangXi=140.16
270BD CJK UNIFIED IDEOGRAPH-#270BD, IRGKangXi=1069.061, RSKangXi=140.16
270BE CJK UNIFIED IDEOGRAPH-#270BE, IRGKangXi=1069.061, RSKangXi=140.16
270BF CJK UNIFIED IDEOGRAPH-#270BF, IRGKangXi=1069.061, RSKangXi=140.16
270C0 CJK UNIFIED IDEOGRAPH-#270C0, IRGKangXi=1069.061, RSKangXi=140.16
270C1 CJK UNIFIED IDEOGRAPH-#270C1, IRGKangXi=1069.061, RSKangXi=140.16
270C2 CJK UNIFIED IDEOGRAPH-#270C2, IRGKangXi=1069.061, RSKangXi=140.16
270C3 CJK UNIFIED IDEOGRAPH-#270C3, IRGKangXi=1069.061, RSKangXi=140.16
270C4 CJK UNIFIED IDEOGRAPH-#270C4, IRGKangXi=1069.061, RSKangXi=140.16
270C5 CJK UNIFIED IDEOGRAPH-#270C5, IRGKangXi=1069.061, RSKangXi=140.16
270C6 CJK UNIFIED IDEOGRAPH-#270C6, IRGKangXi=1069.061, RSKangXi=140.16
270C7 CJK UNIFIED IDEOGRAPH-#270C7, IRGKangXi=1069.061, RSKangXi=140.16
270C8 CJK UNIFIED IDEOGRAPH-#270C8, IRGKangXi=1069.061, RSKangXi=140.16
270C9 CJK UNIFIED IDEOGRAPH-#270C9, IRGKangXi=1069.061, RSKangXi=140.16
270CA CJK UNIFIED IDEOGRAPH-#270CA, IRGKangXi=1069.061, RSKangXi=140.16
270CB CJK UNIFIED IDEOGRAPH-#270CB, IRGKangXi=1069.061, RSKangXi=140.16
270CC CJK UNIFIED IDEOGRAPH-#270CC, IRGKangXi=1069.061, RSKangXi=140.15
270CD CJK UNIFIED IDEOGRAPH-#270CD, IRGKangXi=1069.061, RSKangXi=140.17
270CE CJK UNIFIED IDEOGRAPH-#270CE, IRGKangXi=1069.061, RSKangXi=140.16
270CF CJK UNIFIED IDEOGRAPH-#270CF, IRGKangXi=1069.110, RSKangXi=140.17
270D0 CJK UNIFIED IDEOGRAPH-#270D0, IRGKangXi=1069.160, RSKangXi=140.17
270D1 CJK UNIFIED IDEOGRAPH-#270D1, IRGKangXi=1069.180, RSKangXi=140.17
270D2 CJK UNIFIED IDEOGRAPH-#270D2, IRGKangXi=1069.210, RSKangXi=140.17
270D3 CJK UNIFIED IDEOGRAPH-#270D3, IRGKangXi=1069.220, RSKangXi=140.17
270D4 CJK UNIFIED IDEOGRAPH-#270D4, IRGKangXi=1069.260, RSKangXi=140.17
270D5 CJK UNIFIED IDEOGRAPH-#270D5, IRGKangXi=1069.270, RSKangXi=140.17
270D6 CJK UNIFIED IDEOGRAPH-#270D6, IRGKangXi=1069.290, RSKangXi=140.17
270D7 CJK UNIFIED IDEOGRAPH-#270D7, IRGKangXi=1069.300, RSKangXi=140.17
270D8 CJK UNIFIED IDEOGRAPH-#270D8, IRGKangXi=1069.310, RSKangXi=140.17
270D9 CJK UNIFIED IDEOGRAPH-#270D9, IRGKangXi=1069.340, RSKangXi=140.17
270DA CJK UNIFIED IDEOGRAPH-#270DA, IRGKangXi=1069.380, RSKangXi=140.17
270DB CJK UNIFIED IDEOGRAPH-#270DB, IRGKangXi=1070.010, RSKangXi=140.17
270DC CJK UNIFIED IDEOGRAPH-#270DC, IRGKangXi=1070.040, RSKangXi=140.17
270DD CJK UNIFIED IDEOGRAPH-#270DD, IRGKangXi=1070.050, RSKangXi=140.17
270DE CJK UNIFIED IDEOGRAPH-#270DE, IRGKangXi=1070.100, RSKangXi=140.17
270DF CJK UNIFIED IDEOGRAPH-#270DF, IRGKangXi=1070.130, RSKangXi=140.17
270E0 CJK UNIFIED IDEOGRAPH-#270E0, IRGKangXi=1070.140, RSKangXi=140.17
270E1 CJK UNIFIED IDEOGRAPH-#270E1, IRGKangXi=1070.160, RSKangXi=140.17
270E2 CJK UNIFIED IDEOGRAPH-#270E2, IRGKangXi=1070.170, RSKangXi=140.17
270E3 CJK UNIFIED IDEOGRAPH-#270E3, IRGKangXi=1070.180, RSKangXi=140.17
270E4 CJK UNIFIED IDEOGRAPH-#270E4, IRGKangXi=1070.190, RSKangXi=140.17
270E5 CJK UNIFIED IDEOGRAPH-#270E5, IRGKangXi=1070.200, RSKangXi=140.17
270E6 CJK UNIFIED IDEOGRAPH-#270E6, IRGKangXi=1070.210, RSKangXi=140.17
270E7 CJK UNIFIED IDEOGRAPH-#270E7, IRGKangXi=1070.220, RSKangXi=140.17
270E8 CJK UNIFIED IDEOGRAPH-#270E8, IRGKangXi=1070.230, RSKangXi=140.17
270E9 CJK UNIFIED IDEOGRAPH-#270E9, IRGKangXi=1070.250, RSKangXi=140.17
270EA CJK UNIFIED IDEOGRAPH-#270EA, IRGKangXi=1070.260, RSKangXi=140.17
270EB CJK UNIFIED IDEOGRAPH-#270EB, IRGKangXi=1070.270, RSKangXi=140.17
270EC CJK UNIFIED IDEOGRAPH-#270EC, IRGKangXi=1070.280, RSKangXi=140.17
270ED CJK UNIFIED IDEOGRAPH-#270ED, IRGKangXi=1070.290, RSKangXi=140.17
270EE CJK UNIFIED IDEOGRAPH-#270EE, IRGKangXi=1070.300, RSKangXi=140.17
270EF CJK UNIFIED IDEOGRAPH-#270EF, IRGKangXi=1070.310, RSKangXi=140.17
270F0 CJK UNIFIED IDEOGRAPH-#270F0, IRGKangXi=1070.320, RSKangXi=140.17
270F1 CJK UNIFIED IDEOGRAPH-#270F1, IRGKangXi=1070.321, RSKangXi=140.17
270F2 CJK UNIFIED IDEOGRAPH-#270F2, IRGKangXi=1070.321, RSKangXi=140.17
270F3 CJK UNIFIED IDEOGRAPH-#270F3, IRGKangXi=1070.321, RSKangXi=140.17
270F4 CJK UNIFIED IDEOGRAPH-#270F4, IRGKangXi=1070.321, RSKangXi=140.17
270F5 CJK UNIFIED IDEOGRAPH-#270F5, IRGKangXi=1070.321, RSKangXi=140.17
270F6 CJK UNIFIED IDEOGRAPH-#270F6, IRGKangXi=1070.321, RSKangXi=140.17
270F7 CJK UNIFIED IDEOGRAPH-#270F7, IRGKangXi=1070.321, RSKangXi=140.17
270F8 CJK UNIFIED IDEOGRAPH-#270F8, IRGKangXi=1070.321, RSKangXi=140.17
270F9 CJK UNIFIED IDEOGRAPH-#270F9, IRGKangXi=1070.321, RSKangXi=140.17
270FA CJK UNIFIED IDEOGRAPH-#270FA, IRGKangXi=1070.321, RSKangXi=140.17
270FB CJK UNIFIED IDEOGRAPH-#270FB, IRGKangXi=1070.321, RSKangXi=140.17
270FC CJK UNIFIED IDEOGRAPH-#270FC, IRGKangXi=1070.321, RSKangXi=140.17
270FD CJK UNIFIED IDEOGRAPH-#270FD, IRGKangXi=1070.321, RSKangXi=140.17
270FE CJK UNIFIED IDEOGRAPH-#270FE, IRGKangXi=1070.321, RSKangXi=140.17
270FF CJK UNIFIED IDEOGRAPH-#270FF, IRGKangXi=1070.321, RSKangXi=140.17
27100 CJK UNIFIED IDEOGRAPH-#27100, IRGKangXi=1070.321, RSKangXi=140.17
27101 CJK UNIFIED IDEOGRAPH-#27101, IRGKangXi=1070.321, RSKangXi=140.17
27102 CJK UNIFIED IDEOGRAPH-#27102, IRGKangXi=1070.321, RSKangXi=140.17
27103 CJK UNIFIED IDEOGRAPH-#27103, IRGKangXi=1070.321, RSKangXi=140.17
27104 CJK UNIFIED IDEOGRAPH-#27104, IRGKangXi=1070.321, RSKangXi=140.17
27105 CJK UNIFIED IDEOGRAPH-#27105, IRGKangXi=1070.321, RSKangXi=140.17
27106 CJK UNIFIED IDEOGRAPH-#27106, IRGKangXi=1070.321, RSKangXi=140.17
27107 CJK UNIFIED IDEOGRAPH-#27107, IRGKangXi=1070.321, RSKangXi=140.17
27108 CJK UNIFIED IDEOGRAPH-#27108, IRGKangXi=1070.321, RSKangXi=140.17
27109 CJK UNIFIED IDEOGRAPH-#27109, IRGKangXi=1070.321, RSKangXi=140.17
2710A CJK UNIFIED IDEOGRAPH-#2710A, IRGKangXi=1070.321, RSKangXi=140.17
2710B CJK UNIFIED IDEOGRAPH-#2710B, IRGKangXi=1070.321, RSKangXi=140.17
2710C CJK UNIFIED IDEOGRAPH-#2710C, IRGKangXi=1070.321, RSKangXi=140.17
2710D CJK UNIFIED IDEOGRAPH-#2710D, IRGKangXi=1070.330, RSKangXi=140.18
2710E CJK UNIFIED IDEOGRAPH-#2710E, IRGKangXi=1070.350, RSKangXi=140.18
2710F CJK UNIFIED IDEOGRAPH-#2710F, IRGKangXi=1070.400, RSKangXi=140.18
27110 CJK UNIFIED IDEOGRAPH-#27110, IRGKangXi=1070.410, RSKangXi=140.18
27111 CJK UNIFIED IDEOGRAPH-#27111, IRGKangXi=1070.430, RSKangXi=140.18
27112 CJK UNIFIED IDEOGRAPH-#27112, IRGKangXi=1070.440, RSKangXi=140.18
27113 CJK UNIFIED IDEOGRAPH-#27113, IRGKangXi=1070.450, RSKangXi=140.18
27114 CJK UNIFIED IDEOGRAPH-#27114, IRGKangXi=1071.010, RSKangXi=140.18
27115 CJK UNIFIED IDEOGRAPH-#27115, IRGKangXi=1071.040, RSKangXi=140.18
27116 CJK UNIFIED IDEOGRAPH-#27116, IRGKangXi=1071.060, RSKangXi=140.18
27117 CJK UNIFIED IDEOGRAPH-#27117, IRGKangXi=1071.070, RSKangXi=140.18
27118 CJK UNIFIED IDEOGRAPH-#27118, IRGKangXi=1071.080, RSKangXi=140.18
27119 CJK UNIFIED IDEOGRAPH-#27119, IRGKangXi=1071.090, RSKangXi=140.18
2711A CJK UNIFIED IDEOGRAPH-#2711A, IRGKangXi=1071.100, RSKangXi=140.18
2711B CJK UNIFIED IDEOGRAPH-#2711B, IRGKangXi=1071.110, RSKangXi=140.18
2711C CJK UNIFIED IDEOGRAPH-#2711C, IRGKangXi=1071.120, RSKangXi=140.18
2711D CJK UNIFIED IDEOGRAPH-#2711D, IRGKangXi=1071.130, RSKangXi=140.18
2711E CJK UNIFIED IDEOGRAPH-#2711E, IRGKangXi=1071.140, RSKangXi=140.18
2711F CJK UNIFIED IDEOGRAPH-#2711F, IRGKangXi=1071.150, RSKangXi=140.18
27120 CJK UNIFIED IDEOGRAPH-#27120, IRGKangXi=1071.160, RSKangXi=140.18
27121 CJK UNIFIED IDEOGRAPH-#27121, IRGKangXi=1071.170, RSKangXi=140.18
27122 CJK UNIFIED IDEOGRAPH-#27122, IRGKangXi=1071.180, RSKangXi=140.18
27123 CJK UNIFIED IDEOGRAPH-#27123, IRGKangXi=1071.190, RSKangXi=140.18
27124 CJK UNIFIED IDEOGRAPH-#27124, IRGKangXi=1071.200, RSKangXi=140.18
27125 CJK UNIFIED IDEOGRAPH-#27125, IRGKangXi=1071.201, RSKangXi=140.18
27126 CJK UNIFIED IDEOGRAPH-#27126, IRGKangXi=1071.201, RSKangXi=140.18
27127 CJK UNIFIED IDEOGRAPH-#27127, IRGKangXi=1071.201, RSKangXi=140.18
27128 CJK UNIFIED IDEOGRAPH-#27128, IRGKangXi=1071.201, RSKangXi=140.18
27129 CJK UNIFIED IDEOGRAPH-#27129, IRGKangXi=1071.201, RSKangXi=140.18
2712A CJK UNIFIED IDEOGRAPH-#2712A, IRGKangXi=1071.201, RSKangXi=140.18
2712B CJK UNIFIED IDEOGRAPH-#2712B, IRGKangXi=1071.201, RSKangXi=140.18
2712C CJK UNIFIED IDEOGRAPH-#2712C, IRGKangXi=1071.201, RSKangXi=140.18
2712D CJK UNIFIED IDEOGRAPH-#2712D, IRGKangXi=1071.201, RSKangXi=140.18
2712E CJK UNIFIED IDEOGRAPH-#2712E, IRGKangXi=1071.201, RSKangXi=140.18
2712F CJK UNIFIED IDEOGRAPH-#2712F, IRGKangXi=1071.201, RSKangXi=140.18
27130 CJK UNIFIED IDEOGRAPH-#27130, IRGKangXi=1071.201, RSKangXi=140.18
27131 CJK UNIFIED IDEOGRAPH-#27131, IRGKangXi=1071.201, RSKangXi=140.18
27132 CJK UNIFIED IDEOGRAPH-#27132, IRGKangXi=1071.201, RSKangXi=140.18
27133 CJK UNIFIED IDEOGRAPH-#27133, IRGKangXi=1071.201, RSKangXi=140.18
27134 CJK UNIFIED IDEOGRAPH-#27134, IRGKangXi=1071.201, RSKangXi=140.18
27135 CJK UNIFIED IDEOGRAPH-#27135, IRGKangXi=1071.201, RSKangXi=140.18
27136 CJK UNIFIED IDEOGRAPH-#27136, IRGKangXi=1071.240, RSKangXi=140.19
27137 CJK UNIFIED IDEOGRAPH-#27137, IRGKangXi=1071.250, RSKangXi=140.19
27138 CJK UNIFIED IDEOGRAPH-#27138, IRGKangXi=1071.260, RSKangXi=140.19
27139 CJK UNIFIED IDEOGRAPH-#27139, IRGKangXi=1071.320, RSKangXi=140.19
2713A CJK UNIFIED IDEOGRAPH-#2713A, IRGKangXi=1071.330, RSKangXi=140.19
2713B CJK UNIFIED IDEOGRAPH-#2713B, IRGKangXi=1071.360, RSKangXi=140.19
2713C CJK UNIFIED IDEOGRAPH-#2713C, IRGKangXi=1071.390, RSKangXi=140.19
2713D CJK UNIFIED IDEOGRAPH-#2713D, IRGKangXi=1071.410, RSKangXi=140.19
2713E CJK UNIFIED IDEOGRAPH-#2713E, IRGKangXi=1071.420, RSKangXi=140.19
2713F CJK UNIFIED IDEOGRAPH-#2713F, IRGKangXi=1071.430, RSKangXi=140.19
27140 CJK UNIFIED IDEOGRAPH-#27140, IRGKangXi=1071.440, RSKangXi=140.19
27141 CJK UNIFIED IDEOGRAPH-#27141, IRGKangXi=1071.450, RSKangXi=140.19
27142 CJK UNIFIED IDEOGRAPH-#27142, IRGKangXi=1071.460, RSKangXi=140.19
27143 CJK UNIFIED IDEOGRAPH-#27143, IRGKangXi=1071.470, RSKangXi=140.19
27144 CJK UNIFIED IDEOGRAPH-#27144, IRGKangXi=1071.480, RSKangXi=140.19
27145 CJK UNIFIED IDEOGRAPH-#27145, IRGKangXi=1071.490, RSKangXi=40.19
27146 CJK UNIFIED IDEOGRAPH-#27146, IRGKangXi=1071.500, RSKangXi=140.19
27147 CJK UNIFIED IDEOGRAPH-#27147, IRGKangXi=1072.010, RSKangXi=140.19
27148 CJK UNIFIED IDEOGRAPH-#27148, IRGKangXi=1072.020, RSKangXi=140.19
27149 CJK UNIFIED IDEOGRAPH-#27149, IRGKangXi=1072.030, RSKangXi=140.19
2714A CJK UNIFIED IDEOGRAPH-#2714A, IRGKangXi=1072.040, RSKangXi=140.19
2714B CJK UNIFIED IDEOGRAPH-#2714B, IRGKangXi=1072.050, RSKangXi=140.19
2714C CJK UNIFIED IDEOGRAPH-#2714C, IRGKangXi=1072.060, RSKangXi=140.19
2714D CJK UNIFIED IDEOGRAPH-#2714D, IRGKangXi=1072.070, RSKangXi=140.19
2714E CJK UNIFIED IDEOGRAPH-#2714E, IRGKangXi=1072.071, RSKangXi=140.19
2714F CJK UNIFIED IDEOGRAPH-#2714F, IRGKangXi=1072.071, RSKangXi=140.19
27150 CJK UNIFIED IDEOGRAPH-#27150, IRGKangXi=1072.071, RSKangXi=140.19
27151 CJK UNIFIED IDEOGRAPH-#27151, IRGKangXi=1072.071, RSKangXi=140.19
27152 CJK UNIFIED IDEOGRAPH-#27152, IRGKangXi=1072.071, RSKangXi=140.19
27153 CJK UNIFIED IDEOGRAPH-#27153, IRGKangXi=1072.071, RSKangXi=140.19
27154 CJK UNIFIED IDEOGRAPH-#27154, IRGKangXi=1072.071, RSKangXi=140.19
27155 CJK UNIFIED IDEOGRAPH-#27155, IRGKangXi=1072.071, RSKangXi=140.19
27156 CJK UNIFIED IDEOGRAPH-#27156, IRGKangXi=1072.090, RSKangXi=140.20
27157 CJK UNIFIED IDEOGRAPH-#27157, IRGKangXi=1072.100, RSKangXi=140.20
27158 CJK UNIFIED IDEOGRAPH-#27158, IRGKangXi=1072.110, RSKangXi=140.20
27159 CJK UNIFIED IDEOGRAPH-#27159, IRGKangXi=1072.130, RSKangXi=140.20
2715A CJK UNIFIED IDEOGRAPH-#2715A, IRGKangXi=1072.140, RSKangXi=140.20
2715B CJK UNIFIED IDEOGRAPH-#2715B, IRGKangXi=1072.160, RSKangXi=140.20
2715C CJK UNIFIED IDEOGRAPH-#2715C, IRGKangXi=1072.170, RSKangXi=140.20
2715D CJK UNIFIED IDEOGRAPH-#2715D, IRGKangXi=1072.180, RSKangXi=140.20
2715E CJK UNIFIED IDEOGRAPH-#2715E, IRGKangXi=1072.190, RSKangXi=140.20
2715F CJK UNIFIED IDEOGRAPH-#2715F, IRGKangXi=1072.200, RSKangXi=140.20
27160 CJK UNIFIED IDEOGRAPH-#27160, IRGKangXi=1072.210, RSKangXi=140.20
27161 CJK UNIFIED IDEOGRAPH-#27161, IRGKangXi=1072.220, RSKangXi=140.20
27162 CJK UNIFIED IDEOGRAPH-#27162, IRGKangXi=1072.230, RSKangXi=140.20
27163 CJK UNIFIED IDEOGRAPH-#27163, IRGKangXi=1072.240, RSKangXi=140.20
27164 CJK UNIFIED IDEOGRAPH-#27164, IRGKangXi=1072.241, RSKangXi=140.20
27165 CJK UNIFIED IDEOGRAPH-#27165, IRGKangXi=1072.241, RSKangXi=140.20
27166 CJK UNIFIED IDEOGRAPH-#27166, IRGKangXi=1072.241, RSKangXi=140.20
27167 CJK UNIFIED IDEOGRAPH-#27167, IRGKangXi=1072.241, RSKangXi=140.20
27168 CJK UNIFIED IDEOGRAPH-#27168, IRGKangXi=1072.241, RSKangXi=140.20
27169 CJK UNIFIED IDEOGRAPH-#27169, IRGKangXi=1072.241, RSKangXi=140.20
2716A CJK UNIFIED IDEOGRAPH-#2716A, IRGKangXi=1072.241, RSKangXi=140.20
2716B CJK UNIFIED IDEOGRAPH-#2716B, IRGKangXi=1072.241, RSKangXi=140.20
2716C CJK UNIFIED IDEOGRAPH-#2716C, IRGKangXi=1072.241, RSKangXi=140.20
2716D CJK UNIFIED IDEOGRAPH-#2716D, IRGKangXi=1072.241, RSKangXi=140.20
2716E CJK UNIFIED IDEOGRAPH-#2716E, IRGKangXi=1072.260, RSKangXi=140.21
2716F CJK UNIFIED IDEOGRAPH-#2716F, IRGKangXi=1072.300, RSKangXi=140.21
27170 CJK UNIFIED IDEOGRAPH-#27170, IRGKangXi=1072.310, RSKangXi=140.21
27171 CJK UNIFIED IDEOGRAPH-#27171, IRGKangXi=1072.320, RSKangXi=140.21
27172 CJK UNIFIED IDEOGRAPH-#27172, IRGKangXi=1072.340, RSKangXi=140.21
27173 CJK UNIFIED IDEOGRAPH-#27173, IRGKangXi=1072.350, RSKangXi=140.21
27174 CJK UNIFIED IDEOGRAPH-#27174, IRGKangXi=1072.351, RSKangXi=140.21
27175 CJK UNIFIED IDEOGRAPH-#27175, IRGKangXi=1072.351, RSKangXi=140.24
27176 CJK UNIFIED IDEOGRAPH-#27176, IRGKangXi=1072.351, RSKangXi=140.21
27177 CJK UNIFIED IDEOGRAPH-#27177, IRGKangXi=1072.351, RSKangXi=140.21
27178 CJK UNIFIED IDEOGRAPH-#27178, IRGKangXi=1072.351, RSKangXi=140.21
27179 CJK UNIFIED IDEOGRAPH-#27179, IRGKangXi=1072.351, RSKangXi=140.21
2717A CJK UNIFIED IDEOGRAPH-#2717A, IRGKangXi=1072.360, RSKangXi=140.22
2717B CJK UNIFIED IDEOGRAPH-#2717B, IRGKangXi=1072.370, RSKangXi=140.22
2717C CJK UNIFIED IDEOGRAPH-#2717C, IRGKangXi=1072.380, RSKangXi=140.22
2717D CJK UNIFIED IDEOGRAPH-#2717D, IRGKangXi=1072.390, RSKangXi=140.22
2717E CJK UNIFIED IDEOGRAPH-#2717E, IRGKangXi=1072.410, RSKangXi=140.22
2717F CJK UNIFIED IDEOGRAPH-#2717F, IRGKangXi=1072.421, RSKangXi=140.22
27180 CJK UNIFIED IDEOGRAPH-#27180, IRGKangXi=1072.421, RSKangXi=140.22
27181 CJK UNIFIED IDEOGRAPH-#27181, IRGKangXi=1072.421, RSKangXi=140.22
27182 CJK UNIFIED IDEOGRAPH-#27182, IRGKangXi=1072.421, RSKangXi=140.22
27183 CJK UNIFIED IDEOGRAPH-#27183, IRGKangXi=1072.421, RSKangXi=140.22
27184 CJK UNIFIED IDEOGRAPH-#27184, IRGKangXi=1072.421, RSKangXi=140.22
27185 CJK UNIFIED IDEOGRAPH-#27185, IRGKangXi=1072.421, RSKangXi=140.22
27186 CJK UNIFIED IDEOGRAPH-#27186, IRGKangXi=1072.421, RSKangXi=113.21
27187 CJK UNIFIED IDEOGRAPH-#27187, IRGKangXi=1072.460, RSKangXi=140.23
27188 CJK UNIFIED IDEOGRAPH-#27188, IRGKangXi=1072.470, RSKangXi=140.23
27189 CJK UNIFIED IDEOGRAPH-#27189, IRGKangXi=1072.480, RSKangXi=140.23
2718A CJK UNIFIED IDEOGRAPH-#2718A, IRGKangXi=1072.490, RSKangXi=140.23
2718B CJK UNIFIED IDEOGRAPH-#2718B, IRGKangXi=1072.491, RSKangXi=140.23
2718C CJK UNIFIED IDEOGRAPH-#2718C, IRGKangXi=1072.491, RSKangXi=140.23
2718D CJK UNIFIED IDEOGRAPH-#2718D, IRGKangXi=1072.491, RSKangXi=140.23
2718E CJK UNIFIED IDEOGRAPH-#2718E, IRGKangXi=1072.491, RSKangXi=140.23
2718F CJK UNIFIED IDEOGRAPH-#2718F, IRGKangXi=1072.510, RSKangXi=140.24
27190 CJK UNIFIED IDEOGRAPH-#27190, IRGKangXi=1072.530, RSKangXi=140.24
27191 CJK UNIFIED IDEOGRAPH-#27191, IRGKangXi=1072.540, RSKangXi=140.24
27192 CJK UNIFIED IDEOGRAPH-#27192, IRGKangXi=1072.550, RSKangXi=140.24
27193 CJK UNIFIED IDEOGRAPH-#27193, IRGKangXi=1072.590, RSKangXi=140.33
27194 CJK UNIFIED IDEOGRAPH-#27194, IRGKangXi=1072.600, RSKangXi=140.25
27195 CJK UNIFIED IDEOGRAPH-#27195, IRGKangXi=1072.610, RSKangXi=140.25
27196 CJK UNIFIED IDEOGRAPH-#27196, IRGKangXi=1072.620, RSKangXi=140.26
27197 CJK UNIFIED IDEOGRAPH-#27197, IRGKangXi=1072.630, RSKangXi=140.27
27198 CJK UNIFIED IDEOGRAPH-#27198, IRGKangXi=1072.640, RSKangXi=140.39
27199 CJK UNIFIED IDEOGRAPH-#27199, IRGKangXi=1072.650, RSKangXi=140.29
2719A CJK UNIFIED IDEOGRAPH-#2719A, IRGKangXi=1072.651, RSKangXi=140.26
2719B CJK UNIFIED IDEOGRAPH-#2719B, IRGKangXi=1073.071, RSKangXi=141.2
2719C CJK UNIFIED IDEOGRAPH-#2719C, IRGKangXi=1073.080, RSKangXi=141.3
2719D CJK UNIFIED IDEOGRAPH-#2719D, IRGKangXi=1073.120, RSKangXi=141.3
2719E CJK UNIFIED IDEOGRAPH-#2719E, IRGKangXi=1073.121, RSKangXi=141.3
2719F CJK UNIFIED IDEOGRAPH-#2719F, IRGKangXi=1073.191, RSKangXi=141.4
271A0 CJK UNIFIED IDEOGRAPH-#271A0, IRGKangXi=1073.191, RSKangXi=141.4
271A1 CJK UNIFIED IDEOGRAPH-#271A1, IRGKangXi=1073.191, RSKangXi=141.4
271A2 CJK UNIFIED IDEOGRAPH-#271A2, IRGKangXi=1073.191, RSKangXi=141.4
271A3 CJK UNIFIED IDEOGRAPH-#271A3, IRGKangXi=1073.200, RSKangXi=141.5
271A4 CJK UNIFIED IDEOGRAPH-#271A4, IRGKangXi=1073.220, RSKangXi=141.5
271A5 CJK UNIFIED IDEOGRAPH-#271A5, IRGKangXi=1073.230, RSKangXi=141.5
271A6 CJK UNIFIED IDEOGRAPH-#271A6, IRGKangXi=1073.240, RSKangXi=141.5
271A7 CJK UNIFIED IDEOGRAPH-#271A7, IRGKangXi=1074.050, RSKangXi=141.5
271A8 CJK UNIFIED IDEOGRAPH-#271A8, IRGKangXi=1074.060, RSKangXi=141.5
271A9 CJK UNIFIED IDEOGRAPH-#271A9, IRGKangXi=1074.070, RSKangXi=141.5
271AA CJK UNIFIED IDEOGRAPH-#271AA, IRGKangXi=1074.080, RSKangXi=141.5
271AB CJK UNIFIED IDEOGRAPH-#271AB, IRGKangXi=1074.090, RSKangXi=141.5
271AC CJK UNIFIED IDEOGRAPH-#271AC, IRGKangXi=1074.100, RSKangXi=141.5
271AD CJK UNIFIED IDEOGRAPH-#271AD, IRGKangXi=1074.101, RSKangXi=141.5
271AE CJK UNIFIED IDEOGRAPH-#271AE, IRGKangXi=1074.101, RSKangXi=141.5
271AF CJK UNIFIED IDEOGRAPH-#271AF, IRGKangXi=1074.101, RSKangXi=141.5
271B0 CJK UNIFIED IDEOGRAPH-#271B0, IRGKangXi=1074.101, RSKangXi=141.5
271B1 CJK UNIFIED IDEOGRAPH-#271B1, IRGKangXi=1074.160, RSKangXi=141.6
271B2 CJK UNIFIED IDEOGRAPH-#271B2, IRGKangXi=1074.171, RSKangXi=141.6
271B3 CJK UNIFIED IDEOGRAPH-#271B3, IRGKangXi=1074.171, RSKangXi=141.6
271B4 CJK UNIFIED IDEOGRAPH-#271B4, IRGKangXi=1074.171, RSKangXi=141.6
271B5 CJK UNIFIED IDEOGRAPH-#271B5, IRGKangXi=1074.171, RSKangXi=141.6
271B6 CJK UNIFIED IDEOGRAPH-#271B6, IRGKangXi=1074.171, RSKangXi=141.6
271B7 CJK UNIFIED IDEOGRAPH-#271B7, IRGKangXi=1074.171, RSKangXi=141.6
271B8 CJK UNIFIED IDEOGRAPH-#271B8, IRGKangXi=1074.171, RSKangXi=141.6
271B9 CJK UNIFIED IDEOGRAPH-#271B9, IRGKangXi=1074.171, RSKangXi=141.6
271BA CJK UNIFIED IDEOGRAPH-#271BA, IRGKangXi=1074.190, RSKangXi=141.7
271BB CJK UNIFIED IDEOGRAPH-#271BB, IRGKangXi=1074.220, RSKangXi=141.7
271BC CJK UNIFIED IDEOGRAPH-#271BC, IRGKangXi=1074.270, RSKangXi=141.7
271BD CJK UNIFIED IDEOGRAPH-#271BD, IRGKangXi=1075.010, RSKangXi=141.7
271BE CJK UNIFIED IDEOGRAPH-#271BE, IRGKangXi=1075.020, RSKangXi=141.7
271BF CJK UNIFIED IDEOGRAPH-#271BF, IRGKangXi=1075.030, RSKangXi=141.7
271C0 CJK UNIFIED IDEOGRAPH-#271C0, IRGKangXi=1075.031, RSKangXi=141.7
271C1 CJK UNIFIED IDEOGRAPH-#271C1, IRGKangXi=1075.040, RSKangXi=141.8
271C2 CJK UNIFIED IDEOGRAPH-#271C2, IRGKangXi=1075.060, RSKangXi=141.8
271C3 CJK UNIFIED IDEOGRAPH-#271C3, IRGKangXi=1075.070, RSKangXi=141.8
271C4 CJK UNIFIED IDEOGRAPH-#271C4, IRGKangXi=1075.100, RSKangXi=141.8
271C5 CJK UNIFIED IDEOGRAPH-#271C5, IRGKangXi=1075.120, RSKangXi=141.8
271C6 CJK UNIFIED IDEOGRAPH-#271C6, IRGKangXi=1075.130, RSKangXi=141.8
271C7 CJK UNIFIED IDEOGRAPH-#271C7, IRGKangXi=1075.140, RSKangXi=141.8
271C8 CJK UNIFIED IDEOGRAPH-#271C8, IRGKangXi=1075.150, RSKangXi=141.8
271C9 CJK UNIFIED IDEOGRAPH-#271C9, IRGKangXi=1075.151, RSKangXi=141.8
271CA CJK UNIFIED IDEOGRAPH-#271CA, IRGKangXi=1075.151, RSKangXi=141.8
271CB CJK UNIFIED IDEOGRAPH-#271CB, IRGKangXi=1075.151, RSKangXi=141.8
271CC CJK UNIFIED IDEOGRAPH-#271CC, IRGKangXi=1075.151, RSKangXi=141.8
271CD CJK UNIFIED IDEOGRAPH-#271CD, IRGKangXi=1075.151, RSKangXi=141.8
271CE CJK UNIFIED IDEOGRAPH-#271CE, IRGKangXi=1075.151, RSKangXi=141.8
271CF CJK UNIFIED IDEOGRAPH-#271CF, IRGKangXi=1075.160, RSKangXi=141.9
271D0 CJK UNIFIED IDEOGRAPH-#271D0, IRGKangXi=1075.190, RSKangXi=141.9
271D1 CJK UNIFIED IDEOGRAPH-#271D1, IRGKangXi=1075.200, RSKangXi=141.9
271D2 CJK UNIFIED IDEOGRAPH-#271D2, IRGKangXi=1075.220, RSKangXi=141.9
271D3 CJK UNIFIED IDEOGRAPH-#271D3, IRGKangXi=1075.230, RSKangXi=141.9
271D4 CJK UNIFIED IDEOGRAPH-#271D4, IRGKangXi=1075.240, RSKangXi=141.9
271D5 CJK UNIFIED IDEOGRAPH-#271D5, IRGKangXi=1075.241, RSKangXi=141.9
271D6 CJK UNIFIED IDEOGRAPH-#271D6, IRGKangXi=1075.241, RSKangXi=141.9
271D7 CJK UNIFIED IDEOGRAPH-#271D7, IRGKangXi=1075.241, RSKangXi=141.9
271D8 CJK UNIFIED IDEOGRAPH-#271D8, IRGKangXi=1075.241, RSKangXi=141.9
271D9 CJK UNIFIED IDEOGRAPH-#271D9, IRGKangXi=1075.241, RSKangXi=141.9
271DA CJK UNIFIED IDEOGRAPH-#271DA, IRGKangXi=1075.241, RSKangXi=141.9
271DB CJK UNIFIED IDEOGRAPH-#271DB, IRGKangXi=1075.241, RSKangXi=141.9
271DC CJK UNIFIED IDEOGRAPH-#271DC, IRGKangXi=1075.260, RSKangXi=141.10
271DD CJK UNIFIED IDEOGRAPH-#271DD, IRGKangXi=1075.280, RSKangXi=141.10
271DE CJK UNIFIED IDEOGRAPH-#271DE, IRGKangXi=1075.290, RSKangXi=141.10
271DF CJK UNIFIED IDEOGRAPH-#271DF, IRGKangXi=1075.300, RSKangXi=141.10
271E0 CJK UNIFIED IDEOGRAPH-#271E0, IRGKangXi=1075.320, RSKangXi=141.10
271E1 CJK UNIFIED IDEOGRAPH-#271E1, IRGKangXi=1075.330, RSKangXi=141.10
271E2 CJK UNIFIED IDEOGRAPH-#271E2, IRGKangXi=1075.340, RSKangXi=141.10
271E3 CJK UNIFIED IDEOGRAPH-#271E3, IRGKangXi=1075.350, RSKangXi=141.10
271E4 CJK UNIFIED IDEOGRAPH-#271E4, IRGKangXi=1075.360, RSKangXi=141.10
271E5 CJK UNIFIED IDEOGRAPH-#271E5, IRGKangXi=1075.370, RSKangXi=141.10
271E6 CJK UNIFIED IDEOGRAPH-#271E6, IRGKangXi=1075.380, RSKangXi=141.10
271E7 CJK UNIFIED IDEOGRAPH-#271E7, IRGKangXi=1075.390, RSKangXi=141.10
271E8 CJK UNIFIED IDEOGRAPH-#271E8, IRGKangXi=1075.401, RSKangXi=141.10
271E9 CJK UNIFIED IDEOGRAPH-#271E9, IRGKangXi=1075.401, RSKangXi=141.10
271EA CJK UNIFIED IDEOGRAPH-#271EA, IRGKangXi=1075.401, RSKangXi=141.10
271EB CJK UNIFIED IDEOGRAPH-#271EB, IRGKangXi=1075.401, RSKangXi=141.10
271EC CJK UNIFIED IDEOGRAPH-#271EC, IRGKangXi=1075.401, RSKangXi=141.10
271ED CJK UNIFIED IDEOGRAPH-#271ED, IRGKangXi=1075.401, RSKangXi=141.10
271EE CJK UNIFIED IDEOGRAPH-#271EE, IRGKangXi=1075.401, RSKangXi=141.10
271EF CJK UNIFIED IDEOGRAPH-#271EF, IRGKangXi=1075.401, RSKangXi=141.10
271F0 CJK UNIFIED IDEOGRAPH-#271F0, IRGKangXi=1075.401, RSKangXi=141.10
271F1 CJK UNIFIED IDEOGRAPH-#271F1, IRGKangXi=1075.410, RSKangXi=141.11
271F2 CJK UNIFIED IDEOGRAPH-#271F2, IRGKangXi=1075.450, RSKangXi=141.11
271F3 CJK UNIFIED IDEOGRAPH-#271F3, IRGKangXi=1075.451, RSKangXi=141.11
271F4 CJK UNIFIED IDEOGRAPH-#271F4, IRGKangXi=1075.451, RSKangXi=141.11
271F5 CJK UNIFIED IDEOGRAPH-#271F5, IRGKangXi=1075.451, RSKangXi=141.11
271F6 CJK UNIFIED IDEOGRAPH-#271F6, IRGKangXi=1075.451, RSKangXi=141.11
271F7 CJK UNIFIED IDEOGRAPH-#271F7, IRGKangXi=1075.451, RSKangXi=141.11
271F8 CJK UNIFIED IDEOGRAPH-#271F8, IRGKangXi=1075.451, RSKangXi=141.11
271F9 CJK UNIFIED IDEOGRAPH-#271F9, IRGKangXi=1075.451, RSKangXi=141.11
271FA CJK UNIFIED IDEOGRAPH-#271FA, IRGKangXi=1075.451, RSKangXi=141.11
271FB CJK UNIFIED IDEOGRAPH-#271FB, IRGKangXi=1075.470, RSKangXi=141.12
271FC CJK UNIFIED IDEOGRAPH-#271FC, IRGKangXi=1075.480, RSKangXi=141.12
271FD CJK UNIFIED IDEOGRAPH-#271FD, IRGKangXi=1075.500, RSKangXi=141.12
271FE CJK UNIFIED IDEOGRAPH-#271FE, IRGKangXi=1075.510, RSKangXi=141.12
271FF CJK UNIFIED IDEOGRAPH-#271FF, IRGKangXi=1075.520, RSKangXi=141.12
27200 CJK UNIFIED IDEOGRAPH-#27200, IRGKangXi=1075.540, RSKangXi=141.12
27201 CJK UNIFIED IDEOGRAPH-#27201, IRGKangXi=1076.010, RSKangXi=141.12
27202 CJK UNIFIED IDEOGRAPH-#27202, IRGKangXi=1076.011, RSKangXi=141.13
27203 CJK UNIFIED IDEOGRAPH-#27203, IRGKangXi=1076.011, RSKangXi=141.12
27204 CJK UNIFIED IDEOGRAPH-#27204, IRGKangXi=1076.011, RSKangXi=141.12
27205 CJK UNIFIED IDEOGRAPH-#27205, IRGKangXi=1076.020, RSKangXi=141.13
27206 CJK UNIFIED IDEOGRAPH-#27206, IRGKangXi=1076.030, RSKangXi=141.13
27207 CJK UNIFIED IDEOGRAPH-#27207, IRGKangXi=1076.050, RSKangXi=141.13
27208 CJK UNIFIED IDEOGRAPH-#27208, IRGKangXi=1076.060, RSKangXi=141.13
27209 CJK UNIFIED IDEOGRAPH-#27209, IRGKangXi=1076.070, RSKangXi=141.13
2720A CJK UNIFIED IDEOGRAPH-#2720A, IRGKangXi=1076.071, RSKangXi=141.13
2720B CJK UNIFIED IDEOGRAPH-#2720B, IRGKangXi=1076.080, RSKangXi=141.14
2720C CJK UNIFIED IDEOGRAPH-#2720C, IRGKangXi=1076.090, RSKangXi=141.14
2720D CJK UNIFIED IDEOGRAPH-#2720D, IRGKangXi=1076.100, RSKangXi=141.14
2720E CJK UNIFIED IDEOGRAPH-#2720E, IRGKangXi=1076.110, RSKangXi=141.14
2720F CJK UNIFIED IDEOGRAPH-#2720F, IRGKangXi=1076.111, RSKangXi=141.14
27210 CJK UNIFIED IDEOGRAPH-#27210, IRGKangXi=1076.111, RSKangXi=184.11
27211 CJK UNIFIED IDEOGRAPH-#27211, IRGKangXi=1076.120, RSKangXi=141.15
27212 CJK UNIFIED IDEOGRAPH-#27212, IRGKangXi=1076.130, RSKangXi=141.15
27213 CJK UNIFIED IDEOGRAPH-#27213, IRGKangXi=1076.140, RSKangXi=141.15
27214 CJK UNIFIED IDEOGRAPH-#27214, IRGKangXi=1076.141, RSKangXi=141.15
27215 CJK UNIFIED IDEOGRAPH-#27215, IRGKangXi=1076.141, RSKangXi=141.15
27216 CJK UNIFIED IDEOGRAPH-#27216, IRGKangXi=1076.141, RSKangXi=141.15
27217 CJK UNIFIED IDEOGRAPH-#27217, IRGKangXi=1076.141, RSKangXi=141.15
27218 CJK UNIFIED IDEOGRAPH-#27218, IRGKangXi=1076.150, RSKangXi=141.16
27219 CJK UNIFIED IDEOGRAPH-#27219, IRGKangXi=1076.151, RSKangXi=141.16
2721A CJK UNIFIED IDEOGRAPH-#2721A, IRGKangXi=1076.160, RSKangXi=141.17
2721B CJK UNIFIED IDEOGRAPH-#2721B, IRGKangXi=1076.161, RSKangXi=141.17
2721C CJK UNIFIED IDEOGRAPH-#2721C, IRGKangXi=1076.180, RSKangXi=141.20
2721D CJK UNIFIED IDEOGRAPH-#2721D, IRGKangXi=1076.210, RSKangXi=142.1
2721E CJK UNIFIED IDEOGRAPH-#2721E, IRGKangXi=1076.211, RSKangXi=142.1
2721F CJK UNIFIED IDEOGRAPH-#2721F, IRGKangXi=1076.270, RSKangXi=142.2
27220 CJK UNIFIED IDEOGRAPH-#27220, IRGKangXi=1076.290, RSKangXi=142.2
27221 CJK UNIFIED IDEOGRAPH-#27221, IRGKangXi=1076.291, RSKangXi=142.2
27222 CJK UNIFIED IDEOGRAPH-#27222, IRGKangXi=1076.291, RSKangXi=142.2
27223 CJK UNIFIED IDEOGRAPH-#27223, IRGKangXi=1076.291, RSKangXi=142.2
27224 CJK UNIFIED IDEOGRAPH-#27224, IRGKangXi=1076.291, RSKangXi=142.2
27225 CJK UNIFIED IDEOGRAPH-#27225, IRGKangXi=1076.291, RSKangXi=142.2
27226 CJK UNIFIED IDEOGRAPH-#27226, IRGKangXi=1076.291, RSKangXi=142.2
27227 CJK UNIFIED IDEOGRAPH-#27227, IRGKangXi=1076.291, RSKangXi=142.2
27228 CJK UNIFIED IDEOGRAPH-#27228, IRGKangXi=1076.350, RSKangXi=142.3
27229 CJK UNIFIED IDEOGRAPH-#27229, IRGKangXi=1076.370, RSKangXi=142.3
2722A CJK UNIFIED IDEOGRAPH-#2722A, IRGKangXi=1076.390, RSKangXi=142.3
2722B CJK UNIFIED IDEOGRAPH-#2722B, IRGKangXi=1077.010, RSKangXi=142.3
2722C CJK UNIFIED IDEOGRAPH-#2722C, IRGKangXi=1077.020, RSKangXi=142.3
2722D CJK UNIFIED IDEOGRAPH-#2722D, IRGKangXi=1077.050, RSKangXi=142.3
2722E CJK UNIFIED IDEOGRAPH-#2722E, IRGKangXi=1077.080, RSKangXi=142.3
2722F CJK UNIFIED IDEOGRAPH-#2722F, IRGKangXi=1077.090, RSKangXi=142.3
27230 CJK UNIFIED IDEOGRAPH-#27230, IRGKangXi=1077.110, RSKangXi=142.3
27231 CJK UNIFIED IDEOGRAPH-#27231, IRGKangXi=1077.111, RSKangXi=142.3
27232 CJK UNIFIED IDEOGRAPH-#27232, IRGKangXi=1077.111, RSKangXi=142.3
27233 CJK UNIFIED IDEOGRAPH-#27233, IRGKangXi=1077.111, RSKangXi=142.3
27234 CJK UNIFIED IDEOGRAPH-#27234, IRGKangXi=1077.111, RSKangXi=142.3
27235 CJK UNIFIED IDEOGRAPH-#27235, IRGKangXi=1077.111, RSKangXi=142.3
27236 CJK UNIFIED IDEOGRAPH-#27236, IRGKangXi=1077.111, RSKangXi=142.3
27237 CJK UNIFIED IDEOGRAPH-#27237, IRGKangXi=1077.111, RSKangXi=142.3
27238 CJK UNIFIED IDEOGRAPH-#27238, IRGKangXi=1077.111, RSKangXi=142.3
27239 CJK UNIFIED IDEOGRAPH-#27239, IRGKangXi=1077.111, RSKangXi=142.3
2723A CJK UNIFIED IDEOGRAPH-#2723A, IRGKangXi=1077.111, RSKangXi=142.3
2723B CJK UNIFIED IDEOGRAPH-#2723B, IRGKangXi=1077.230, RSKangXi=142.4
2723C CJK UNIFIED IDEOGRAPH-#2723C, IRGKangXi=1077.260, RSKangXi=142.4
2723D CJK UNIFIED IDEOGRAPH-#2723D, IRGKangXi=1077.290, RSKangXi=142.4
2723E CJK UNIFIED IDEOGRAPH-#2723E, IRGKangXi=1077.300, RSKangXi=142.4
2723F CJK UNIFIED IDEOGRAPH-#2723F, IRGKangXi=1077.310, RSKangXi=142.4
27240 CJK UNIFIED IDEOGRAPH-#27240, IRGKangXi=1077.320, RSKangXi=142.4
27241 CJK UNIFIED IDEOGRAPH-#27241, IRGKangXi=1077.340, RSKangXi=142.4
27242 CJK UNIFIED IDEOGRAPH-#27242, IRGKangXi=1077.390, RSKangXi=142.4
27243 CJK UNIFIED IDEOGRAPH-#27243, IRGKangXi=1077.410, RSKangXi=142.4
27244 CJK UNIFIED IDEOGRAPH-#27244, IRGKangXi=1078.010, RSKangXi=142.4
27245 CJK UNIFIED IDEOGRAPH-#27245, IRGKangXi=1078.040, RSKangXi=142.4
27246 CJK UNIFIED IDEOGRAPH-#27246, IRGKangXi=1078.060, RSKangXi=142.4
27247 CJK UNIFIED IDEOGRAPH-#27247, IRGKangXi=1078.110, RSKangXi=142.4
27248 CJK UNIFIED IDEOGRAPH-#27248, IRGKangXi=1078.240, RSKangXi=142.4
27249 CJK UNIFIED IDEOGRAPH-#27249, IRGKangXi=1078.270, RSKangXi=142.4
2724A CJK UNIFIED IDEOGRAPH-#2724A, IRGKangXi=1079.020, RSKangXi=142.4
2724B CJK UNIFIED IDEOGRAPH-#2724B, IRGKangXi=1079.030, RSKangXi=142.4
2724C CJK UNIFIED IDEOGRAPH-#2724C, IRGKangXi=1079.040, RSKangXi=142.4
2724D CJK UNIFIED IDEOGRAPH-#2724D, IRGKangXi=1079.050, RSKangXi=142.4
2724E CJK UNIFIED IDEOGRAPH-#2724E, IRGKangXi=1079.060, RSKangXi=142.4
2724F CJK UNIFIED IDEOGRAPH-#2724F, IRGKangXi=1079.070, RSKangXi=142.4
27250 CJK UNIFIED IDEOGRAPH-#27250, IRGKangXi=1079.080, RSKangXi=142.4
27251 CJK UNIFIED IDEOGRAPH-#27251, IRGKangXi=1079.100, RSKangXi=142.4
27252 CJK UNIFIED IDEOGRAPH-#27252, IRGKangXi=1079.101, RSKangXi=142.4
27253 CJK UNIFIED IDEOGRAPH-#27253, IRGKangXi=1079.101, RSKangXi=142.4
27254 CJK UNIFIED IDEOGRAPH-#27254, IRGKangXi=1079.101, RSKangXi=142.4
27255 CJK UNIFIED IDEOGRAPH-#27255, IRGKangXi=1079.101, RSKangXi=142.4
27256 CJK UNIFIED IDEOGRAPH-#27256, IRGKangXi=1079.101, RSKangXi=142.4
27257 CJK UNIFIED IDEOGRAPH-#27257, IRGKangXi=1079.101, RSKangXi=142.4
27258 CJK UNIFIED IDEOGRAPH-#27258, IRGKangXi=1079.101, RSKangXi=142.4
27259 CJK UNIFIED IDEOGRAPH-#27259, IRGKangXi=1079.101, RSKangXi=142.4
2725A CJK UNIFIED IDEOGRAPH-#2725A, IRGKangXi=1079.101, RSKangXi=142.4
2725B CJK UNIFIED IDEOGRAPH-#2725B, IRGKangXi=1079.101, RSKangXi=142.4
2725C CJK UNIFIED IDEOGRAPH-#2725C, IRGKangXi=1079.101, RSKangXi=142.4
2725D CJK UNIFIED IDEOGRAPH-#2725D, IRGKangXi=1079.101, RSKangXi=142.4
2725E CJK UNIFIED IDEOGRAPH-#2725E, IRGKangXi=1079.170, RSKangXi=142.5
2725F CJK UNIFIED IDEOGRAPH-#2725F, IRGKangXi=1079.230, RSKangXi=142.5
27260 CJK UNIFIED IDEOGRAPH-#27260, IRGKangXi=1079.310, RSKangXi=142.5
27261 CJK UNIFIED IDEOGRAPH-#27261, IRGKangXi=1079.330, RSKangXi=142.5
27262 CJK UNIFIED IDEOGRAPH-#27262, IRGKangXi=1079.340, RSKangXi=142.5
27263 CJK UNIFIED IDEOGRAPH-#27263, IRGKangXi=1079.380, RSKangXi=142.5
27264 CJK UNIFIED IDEOGRAPH-#27264, IRGKangXi=1079.390, RSKangXi=142.5
27265 CJK UNIFIED IDEOGRAPH-#27265, IRGKangXi=1080.010, RSKangXi=142.5
27266 CJK UNIFIED IDEOGRAPH-#27266, IRGKangXi=1080.020, RSKangXi=142.5
27267 CJK UNIFIED IDEOGRAPH-#27267, IRGKangXi=1080.060, RSKangXi=142.5
27268 CJK UNIFIED IDEOGRAPH-#27268, IRGKangXi=1080.070, RSKangXi=142.5
27269 CJK UNIFIED IDEOGRAPH-#27269, IRGKangXi=1080.080, RSKangXi=142.5
2726A CJK UNIFIED IDEOGRAPH-#2726A, IRGKangXi=1080.090, RSKangXi=142.5
2726B CJK UNIFIED IDEOGRAPH-#2726B, IRGKangXi=1080.100, RSKangXi=142.5
2726C CJK UNIFIED IDEOGRAPH-#2726C, IRGKangXi=1080.130, RSKangXi=142.5
2726D CJK UNIFIED IDEOGRAPH-#2726D, IRGKangXi=1080.180, RSKangXi=142.5
2726E CJK UNIFIED IDEOGRAPH-#2726E, IRGKangXi=1080.210, RSKangXi=142.5
2726F CJK UNIFIED IDEOGRAPH-#2726F, IRGKangXi=1080.220, RSKangXi=142.5
27270 CJK UNIFIED IDEOGRAPH-#27270, IRGKangXi=1080.230, RSKangXi=142.5
27271 CJK UNIFIED IDEOGRAPH-#27271, IRGKangXi=1081.010, RSKangXi=142.5
27272 CJK UNIFIED IDEOGRAPH-#27272, IRGKangXi=1081.020, RSKangXi=142.5
27273 CJK UNIFIED IDEOGRAPH-#27273, IRGKangXi=1081.040, RSKangXi=142.5
27274 CJK UNIFIED IDEOGRAPH-#27274, IRGKangXi=1081.060, RSKangXi=142.5
27275 CJK UNIFIED IDEOGRAPH-#27275, IRGKangXi=1081.070, RSKangXi=142.5
27276 CJK UNIFIED IDEOGRAPH-#27276, IRGKangXi=1081.080, RSKangXi=142.5
27277 CJK UNIFIED IDEOGRAPH-#27277, IRGKangXi=1081.100, RSKangXi=142.5
27278 CJK UNIFIED IDEOGRAPH-#27278, IRGKangXi=1081.111, RSKangXi=142.5
27279 CJK UNIFIED IDEOGRAPH-#27279, IRGKangXi=1081.111, RSKangXi=142.5
2727A CJK UNIFIED IDEOGRAPH-#2727A, IRGKangXi=1081.111, RSKangXi=142.5
2727B CJK UNIFIED IDEOGRAPH-#2727B, IRGKangXi=1081.111, RSKangXi=142.5
2727C CJK UNIFIED IDEOGRAPH-#2727C, IRGKangXi=1081.111, RSKangXi=142.5
2727D CJK UNIFIED IDEOGRAPH-#2727D, IRGKangXi=1081.111, RSKangXi=142.5
2727E CJK UNIFIED IDEOGRAPH-#2727E, IRGKangXi=1081.111, RSKangXi=142.5
2727F CJK UNIFIED IDEOGRAPH-#2727F, IRGKangXi=1081.111, RSKangXi=142.5
27280 CJK UNIFIED IDEOGRAPH-#27280, IRGKangXi=1081.111, RSKangXi=142.5
27281 CJK UNIFIED IDEOGRAPH-#27281, IRGKangXi=1081.111, RSKangXi=142.5
27282 CJK UNIFIED IDEOGRAPH-#27282, IRGKangXi=1081.111, RSKangXi=142.5
27283 CJK UNIFIED IDEOGRAPH-#27283, IRGKangXi=1081.111, RSKangXi=142.5
27284 CJK UNIFIED IDEOGRAPH-#27284, IRGKangXi=1081.111, RSKangXi=142.5
27285 CJK UNIFIED IDEOGRAPH-#27285, IRGKangXi=1081.111, RSKangXi=142.5, Def{(Cant.) frog, toad}
27286 CJK UNIFIED IDEOGRAPH-#27286, IRGKangXi=1081.111, RSKangXi=142.5
27287 CJK UNIFIED IDEOGRAPH-#27287, IRGKangXi=1081.111, RSKangXi=142.5
27288 CJK UNIFIED IDEOGRAPH-#27288, IRGKangXi=1081.111, RSKangXi=142.5
27289 CJK UNIFIED IDEOGRAPH-#27289, IRGKangXi=1081.111, RSKangXi=142.5
2728A CJK UNIFIED IDEOGRAPH-#2728A, IRGKangXi=1081.111, RSKangXi=142.5
2728B CJK UNIFIED IDEOGRAPH-#2728B, IRGKangXi=1081.111, RSKangXi=142.5
2728C CJK UNIFIED IDEOGRAPH-#2728C, IRGKangXi=1081.111, RSKangXi=142.5
2728D CJK UNIFIED IDEOGRAPH-#2728D, IRGKangXi=1081.111, RSKangXi=142.5
2728E CJK UNIFIED IDEOGRAPH-#2728E, IRGKangXi=1081.111, RSKangXi=142.5
2728F CJK UNIFIED IDEOGRAPH-#2728F, IRGKangXi=1081.160, RSKangXi=142.6
27290 CJK UNIFIED IDEOGRAPH-#27290, IRGKangXi=1081.190, RSKangXi=142.6
27291 CJK UNIFIED IDEOGRAPH-#27291, IRGKangXi=1081.210, RSKangXi=142.6
27292 CJK UNIFIED IDEOGRAPH-#27292, IRGKangXi=1081.280, RSKangXi=142.6
27293 CJK UNIFIED IDEOGRAPH-#27293, IRGKangXi=1081.290, RSKangXi=142.6
27294 CJK UNIFIED IDEOGRAPH-#27294, IRGKangXi=1081.340, RSKangXi=142.6
27295 CJK UNIFIED IDEOGRAPH-#27295, IRGKangXi=1081.390, RSKangXi=142.6
27296 CJK UNIFIED IDEOGRAPH-#27296, IRGKangXi=1082.010, RSKangXi=142.6
27297 CJK UNIFIED IDEOGRAPH-#27297, IRGKangXi=1082.020, RSKangXi=142.6
27298 CJK UNIFIED IDEOGRAPH-#27298, IRGKangXi=1082.040, RSKangXi=142.6
27299 CJK UNIFIED IDEOGRAPH-#27299, IRGKangXi=1082.060, RSKangXi=142.6
2729A CJK UNIFIED IDEOGRAPH-#2729A, IRGKangXi=1082.070, RSKangXi=142.6
2729B CJK UNIFIED IDEOGRAPH-#2729B, IRGKangXi=1082.110, RSKangXi=142.6
2729C CJK UNIFIED IDEOGRAPH-#2729C, IRGKangXi=1082.130, RSKangXi=142.6
2729D CJK UNIFIED IDEOGRAPH-#2729D, IRGKangXi=1082.160, RSKangXi=142.6
2729E CJK UNIFIED IDEOGRAPH-#2729E, IRGKangXi=1082.170, RSKangXi=142.6
2729F CJK UNIFIED IDEOGRAPH-#2729F, IRGKangXi=1082.190, RSKangXi=142.6
272A0 CJK UNIFIED IDEOGRAPH-#272A0, IRGKangXi=1082.240, RSKangXi=142.6
272A1 CJK UNIFIED IDEOGRAPH-#272A1, IRGKangXi=1082.260, RSKangXi=142.6
272A2 CJK UNIFIED IDEOGRAPH-#272A2, IRGKangXi=1082.270, RSKangXi=142.6
272A3 CJK UNIFIED IDEOGRAPH-#272A3, IRGKangXi=1082.280, RSKangXi=142.6
272A4 CJK UNIFIED IDEOGRAPH-#272A4, IRGKangXi=1082.310, RSKangXi=142.6
272A5 CJK UNIFIED IDEOGRAPH-#272A5, IRGKangXi=1082.320, RSKangXi=142.6
272A6 CJK UNIFIED IDEOGRAPH-#272A6, IRGKangXi=1082.330, RSKangXi=142.6
272A7 CJK UNIFIED IDEOGRAPH-#272A7, IRGKangXi=1083.030, RSKangXi=142.6
272A8 CJK UNIFIED IDEOGRAPH-#272A8, IRGKangXi=1083.040, RSKangXi=142.6
272A9 CJK UNIFIED IDEOGRAPH-#272A9, IRGKangXi=1083.050, RSKangXi=142.6
272AA CJK UNIFIED IDEOGRAPH-#272AA, IRGKangXi=1083.060, RSKangXi=142.6
272AB CJK UNIFIED IDEOGRAPH-#272AB, IRGKangXi=1083.070, RSKangXi=142.7
272AC CJK UNIFIED IDEOGRAPH-#272AC, IRGKangXi=1083.080, RSKangXi=142.6
272AD CJK UNIFIED IDEOGRAPH-#272AD, IRGKangXi=1083.090, RSKangXi=142.6
272AE CJK UNIFIED IDEOGRAPH-#272AE, IRGKangXi=1083.110, RSKangXi=142.7
272AF CJK UNIFIED IDEOGRAPH-#272AF, IRGKangXi=1083.120, RSKangXi=142.6
272B0 CJK UNIFIED IDEOGRAPH-#272B0, IRGKangXi=1083.130, RSKangXi=142.6
272B1 CJK UNIFIED IDEOGRAPH-#272B1, IRGKangXi=1083.140, RSKangXi=142.6
272B2 CJK UNIFIED IDEOGRAPH-#272B2, IRGKangXi=1083.150, RSKangXi=142.6
272B3 CJK UNIFIED IDEOGRAPH-#272B3, IRGKangXi=1083.151, RSKangXi=142.6
272B4 CJK UNIFIED IDEOGRAPH-#272B4, IRGKangXi=1083.151, RSKangXi=142.6
272B5 CJK UNIFIED IDEOGRAPH-#272B5, IRGKangXi=1083.151, RSKangXi=142.6
272B6 CJK UNIFIED IDEOGRAPH-#272B6, IRGKangXi=1083.151, RSKangXi=142.6, Def{(Cant.) insect sting}
272B7 CJK UNIFIED IDEOGRAPH-#272B7, IRGKangXi=1083.151, RSKangXi=142.6
272B8 CJK UNIFIED IDEOGRAPH-#272B8, IRGKangXi=1083.151, RSKangXi=142.6
272B9 CJK UNIFIED IDEOGRAPH-#272B9, IRGKangXi=1083.151, RSKangXi=142.6
272BA CJK UNIFIED IDEOGRAPH-#272BA, IRGKangXi=1083.151, RSKangXi=142.6
272BB CJK UNIFIED IDEOGRAPH-#272BB, IRGKangXi=1083.151, RSKangXi=142.6
272BC CJK UNIFIED IDEOGRAPH-#272BC, IRGKangXi=1083.151, RSKangXi=142.6
272BD CJK UNIFIED IDEOGRAPH-#272BD, IRGKangXi=1083.151, RSKangXi=142.6
272BE CJK UNIFIED IDEOGRAPH-#272BE, IRGKangXi=1083.151, RSKangXi=142.6
272BF CJK UNIFIED IDEOGRAPH-#272BF, IRGKangXi=1083.151, RSKangXi=142.6
272C0 CJK UNIFIED IDEOGRAPH-#272C0, IRGKangXi=1083.151, RSKangXi=142.6
272C1 CJK UNIFIED IDEOGRAPH-#272C1, IRGKangXi=1083.151, RSKangXi=142.6
272C2 CJK UNIFIED IDEOGRAPH-#272C2, IRGKangXi=1083.151, RSKangXi=142.6
272C3 CJK UNIFIED IDEOGRAPH-#272C3, IRGKangXi=1083.151, RSKangXi=142.6
272C4 CJK UNIFIED IDEOGRAPH-#272C4, IRGKangXi=1083.151, RSKangXi=142.6
272C5 CJK UNIFIED IDEOGRAPH-#272C5, IRGKangXi=1083.151, RSKangXi=142.6
272C6 CJK UNIFIED IDEOGRAPH-#272C6, IRGKangXi=1083.151, RSKangXi=142.6
272C7 CJK UNIFIED IDEOGRAPH-#272C7, IRGKangXi=1083.151, RSKangXi=142.6
272C8 CJK UNIFIED IDEOGRAPH-#272C8, IRGKangXi=1083.190, RSKangXi=142.7
272C9 CJK UNIFIED IDEOGRAPH-#272C9, IRGKangXi=1083.220, RSKangXi=142.7
272CA CJK UNIFIED IDEOGRAPH-#272CA, IRGKangXi=1083.230, RSKangXi=142.7, Def{(Cant.) a large butterfly}
272CB CJK UNIFIED IDEOGRAPH-#272CB, IRGKangXi=1083.240, RSKangXi=142.7
272CC CJK UNIFIED IDEOGRAPH-#272CC, IRGKangXi=1084.100, RSKangXi=142.7
272CD CJK UNIFIED IDEOGRAPH-#272CD, IRGKangXi=1084.140, RSKangXi=142.7, Def{to sting, a sting}
272CE CJK UNIFIED IDEOGRAPH-#272CE, IRGKangXi=1084.150, RSKangXi=142.7
272CF CJK UNIFIED IDEOGRAPH-#272CF, IRGKangXi=1084.170, RSKangXi=142.7
272D0 CJK UNIFIED IDEOGRAPH-#272D0, IRGKangXi=1084.180, RSKangXi=142.7
272D1 CJK UNIFIED IDEOGRAPH-#272D1, IRGKangXi=1084.190, RSKangXi=142.7
272D2 CJK UNIFIED IDEOGRAPH-#272D2, IRGKangXi=1084.210, RSKangXi=142.7
272D3 CJK UNIFIED IDEOGRAPH-#272D3, IRGKangXi=1084.230, RSKangXi=142.7
272D4 CJK UNIFIED IDEOGRAPH-#272D4, IRGKangXi=1085.030, RSKangXi=142.7
272D5 CJK UNIFIED IDEOGRAPH-#272D5, IRGKangXi=1085.040, RSKangXi=142.7
272D6 CJK UNIFIED IDEOGRAPH-#272D6, IRGKangXi=1085.060, RSKangXi=142.7
272D7 CJK UNIFIED IDEOGRAPH-#272D7, IRGKangXi=1085.090, RSKangXi=142.7
272D8 CJK UNIFIED IDEOGRAPH-#272D8, IRGKangXi=1085.140, RSKangXi=142.7
272D9 CJK UNIFIED IDEOGRAPH-#272D9, IRGKangXi=1085.150, RSKangXi=142.7
272DA CJK UNIFIED IDEOGRAPH-#272DA, IRGKangXi=1085.170, RSKangXi=142.7
272DB CJK UNIFIED IDEOGRAPH-#272DB, IRGKangXi=1085.180, RSKangXi=142.7
272DC CJK UNIFIED IDEOGRAPH-#272DC, IRGKangXi=1085.190, RSKangXi=142.7
272DD CJK UNIFIED IDEOGRAPH-#272DD, IRGKangXi=1085.200, RSKangXi=142.7
272DE CJK UNIFIED IDEOGRAPH-#272DE, IRGKangXi=1085.210, RSKangXi=142.8
272DF CJK UNIFIED IDEOGRAPH-#272DF, IRGKangXi=1085.220, RSKangXi=142.7
272E0 CJK UNIFIED IDEOGRAPH-#272E0, IRGKangXi=1085.240, RSKangXi=142.7
272E1 CJK UNIFIED IDEOGRAPH-#272E1, IRGKangXi=1085.250, RSKangXi=142.7
272E2 CJK UNIFIED IDEOGRAPH-#272E2, IRGKangXi=1085.261, RSKangXi=142.7
272E3 CJK UNIFIED IDEOGRAPH-#272E3, IRGKangXi=1085.261, RSKangXi=142.7
272E4 CJK UNIFIED IDEOGRAPH-#272E4, IRGKangXi=1085.261, RSKangXi=142.7
272E5 CJK UNIFIED IDEOGRAPH-#272E5, IRGKangXi=1085.261, RSKangXi=142.7
272E6 CJK UNIFIED IDEOGRAPH-#272E6, IRGKangXi=1085.261, RSKangXi=142.7, Def{(Cant.) a dragonfly; a small boat without a sail}
272E7 CJK UNIFIED IDEOGRAPH-#272E7, IRGKangXi=1085.261, RSKangXi=142.7
272E8 CJK UNIFIED IDEOGRAPH-#272E8, IRGKangXi=1085.261, RSKangXi=142.7
272E9 CJK UNIFIED IDEOGRAPH-#272E9, IRGKangXi=1085.261, RSKangXi=142.7
272EA CJK UNIFIED IDEOGRAPH-#272EA, IRGKangXi=1085.261, RSKangXi=142.7
272EB CJK UNIFIED IDEOGRAPH-#272EB, IRGKangXi=1085.261, RSKangXi=142.7
272EC CJK UNIFIED IDEOGRAPH-#272EC, IRGKangXi=1085.261, RSKangXi=142.7
272ED CJK UNIFIED IDEOGRAPH-#272ED, IRGKangXi=1085.261, RSKangXi=142.7
272EE CJK UNIFIED IDEOGRAPH-#272EE, IRGKangXi=1085.261, RSKangXi=142.7
272EF CJK UNIFIED IDEOGRAPH-#272EF, IRGKangXi=1085.261, RSKangXi=142.7
272F0 CJK UNIFIED IDEOGRAPH-#272F0, IRGKangXi=1085.261, RSKangXi=142.7
272F1 CJK UNIFIED IDEOGRAPH-#272F1, IRGKangXi=1085.261, RSKangXi=142.7
272F2 CJK UNIFIED IDEOGRAPH-#272F2, IRGKangXi=1085.261, RSKangXi=142.7
272F3 CJK UNIFIED IDEOGRAPH-#272F3, IRGKangXi=1085.261, RSKangXi=142.7
272F4 CJK UNIFIED IDEOGRAPH-#272F4, IRGKangXi=1085.261, RSKangXi=142.7
272F5 CJK UNIFIED IDEOGRAPH-#272F5, IRGKangXi=1085.261, RSKangXi=142.7
272F6 CJK UNIFIED IDEOGRAPH-#272F6, IRGKangXi=1085.261, RSKangXi=142.7
272F7 CJK UNIFIED IDEOGRAPH-#272F7, IRGKangXi=1085.261, RSKangXi=142.7
272F8 CJK UNIFIED IDEOGRAPH-#272F8, IRGKangXi=1085.261, RSKangXi=142.7
272F9 CJK UNIFIED IDEOGRAPH-#272F9, IRGKangXi=1085.261, RSKangXi=142.7
272FA CJK UNIFIED IDEOGRAPH-#272FA, IRGKangXi=1085.261, RSKangXi=142.7
272FB CJK UNIFIED IDEOGRAPH-#272FB, IRGKangXi=1085.261, RSKangXi=142.7
272FC CJK UNIFIED IDEOGRAPH-#272FC, IRGKangXi=1085.261, RSKangXi=142.7
272FD CJK UNIFIED IDEOGRAPH-#272FD, IRGKangXi=1085.261, RSKangXi=142.7
272FE CJK UNIFIED IDEOGRAPH-#272FE, IRGKangXi=1085.261, RSKangXi=142.7
272FF CJK UNIFIED IDEOGRAPH-#272FF, IRGKangXi=1085.261, RSKangXi=142.7
27300 CJK UNIFIED IDEOGRAPH-#27300, IRGKangXi=1085.261, RSKangXi=142.7
27301 CJK UNIFIED IDEOGRAPH-#27301, IRGKangXi=1085.261, RSKangXi=142.7
27302 CJK UNIFIED IDEOGRAPH-#27302, IRGKangXi=1085.261, RSKangXi=142.7
27303 CJK UNIFIED IDEOGRAPH-#27303, IRGKangXi=1085.280, RSKangXi=142.8
27304 CJK UNIFIED IDEOGRAPH-#27304, IRGKangXi=1085.290, RSKangXi=142.8
27305 CJK UNIFIED IDEOGRAPH-#27305, IRGKangXi=1085.320, RSKangXi=142.8
27306 CJK UNIFIED IDEOGRAPH-#27306, IRGKangXi=1085.330, RSKangXi=142.8
27307 CJK UNIFIED IDEOGRAPH-#27307, IRGKangXi=1085.340, RSKangXi=142.8, Def{(Cant.) a large butterfly}
27308 CJK UNIFIED IDEOGRAPH-#27308, IRGKangXi=1086.030, RSKangXi=142.8
27309 CJK UNIFIED IDEOGRAPH-#27309, IRGKangXi=1086.050, RSKangXi=142.8
2730A CJK UNIFIED IDEOGRAPH-#2730A, IRGKangXi=1086.080, RSKangXi=142.8
2730B CJK UNIFIED IDEOGRAPH-#2730B, IRGKangXi=1086.100, RSKangXi=142.8
2730C CJK UNIFIED IDEOGRAPH-#2730C, IRGKangXi=1086.120, RSKangXi=142.8
2730D CJK UNIFIED IDEOGRAPH-#2730D, IRGKangXi=1086.220, RSKangXi=142.8
2730E CJK UNIFIED IDEOGRAPH-#2730E, IRGKangXi=1087.030, RSKangXi=142.8
2730F CJK UNIFIED IDEOGRAPH-#2730F, IRGKangXi=1087.040, RSKangXi=142.8
27310 CJK UNIFIED IDEOGRAPH-#27310, IRGKangXi=1087.060, RSKangXi=142.8
27311 CJK UNIFIED IDEOGRAPH-#27311, IRGKangXi=1087.090, RSKangXi=142.8
27312 CJK UNIFIED IDEOGRAPH-#27312, IRGKangXi=1087.110, RSKangXi=142.8
27313 CJK UNIFIED IDEOGRAPH-#27313, IRGKangXi=1087.140, RSKangXi=142.8, Def{a grasshopper, locust}
27314 CJK UNIFIED IDEOGRAPH-#27314, IRGKangXi=1087.170, RSKangXi=142.8
27315 CJK UNIFIED IDEOGRAPH-#27315, IRGKangXi=1087.180, RSKangXi=142.8
27316 CJK UNIFIED IDEOGRAPH-#27316, IRGKangXi=1087.210, RSKangXi=142.8
27317 CJK UNIFIED IDEOGRAPH-#27317, IRGKangXi=1087.270, RSKangXi=142.8
27318 CJK UNIFIED IDEOGRAPH-#27318, IRGKangXi=1087.300, RSKangXi=142.8
27319 CJK UNIFIED IDEOGRAPH-#27319, IRGKangXi=1088.020, RSKangXi=142.8
2731A CJK UNIFIED IDEOGRAPH-#2731A, IRGKangXi=1088.040, RSKangXi=142.8
2731B CJK UNIFIED IDEOGRAPH-#2731B, IRGKangXi=1088.150, RSKangXi=142.8
2731C CJK UNIFIED IDEOGRAPH-#2731C, IRGKangXi=1088.160, RSKangXi=142.8
2731D CJK UNIFIED IDEOGRAPH-#2731D, IRGKangXi=1088.170, RSKangXi=142.8
2731E CJK UNIFIED IDEOGRAPH-#2731E, IRGKangXi=1088.180, RSKangXi=142.7
2731F CJK UNIFIED IDEOGRAPH-#2731F, IRGKangXi=1088.190, RSKangXi=142.8
27320 CJK UNIFIED IDEOGRAPH-#27320, IRGKangXi=1088.200, RSKangXi=142.8
27321 CJK UNIFIED IDEOGRAPH-#27321, IRGKangXi=1088.210, RSKangXi=142.8
27322 CJK UNIFIED IDEOGRAPH-#27322, IRGKangXi=1088.220, RSKangXi=142.8
27323 CJK UNIFIED IDEOGRAPH-#27323, IRGKangXi=1088.230, RSKangXi=142.8
27324 CJK UNIFIED IDEOGRAPH-#27324, IRGKangXi=1088.240, RSKangXi=142.8
27325 CJK UNIFIED IDEOGRAPH-#27325, IRGKangXi=1088.250, RSKangXi=142.8
27326 CJK UNIFIED IDEOGRAPH-#27326, IRGKangXi=1088.260, RSKangXi=142.8
27327 CJK UNIFIED IDEOGRAPH-#27327, IRGKangXi=1088.270, RSKangXi=142.8
27328 CJK UNIFIED IDEOGRAPH-#27328, IRGKangXi=1088.280, RSKangXi=142.8
27329 CJK UNIFIED IDEOGRAPH-#27329, IRGKangXi=1088.290, RSKangXi=142.8
2732A CJK UNIFIED IDEOGRAPH-#2732A, IRGKangXi=1088.300, RSKangXi=142.8
2732B CJK UNIFIED IDEOGRAPH-#2732B, IRGKangXi=1088.310, RSKangXi=142.8
2732C CJK UNIFIED IDEOGRAPH-#2732C, IRGKangXi=1088.320, RSKangXi=142.8
2732D CJK UNIFIED IDEOGRAPH-#2732D, IRGKangXi=1088.340, RSKangXi=142.8
2732E CJK UNIFIED IDEOGRAPH-#2732E, IRGKangXi=1088.341, RSKangXi=142.8
2732F CJK UNIFIED IDEOGRAPH-#2732F, IRGKangXi=1088.341, RSKangXi=142.8
27330 CJK UNIFIED IDEOGRAPH-#27330, IRGKangXi=1088.341, RSKangXi=142.9
27331 CJK UNIFIED IDEOGRAPH-#27331, IRGKangXi=1088.341, RSKangXi=142.8
27332 CJK UNIFIED IDEOGRAPH-#27332, IRGKangXi=1088.341, RSKangXi=142.8
27333 CJK UNIFIED IDEOGRAPH-#27333, IRGKangXi=1088.341, RSKangXi=142.8
27334 CJK UNIFIED IDEOGRAPH-#27334, IRGKangXi=1088.341, RSKangXi=142.8
27335 CJK UNIFIED IDEOGRAPH-#27335, IRGKangXi=1088.341, RSKangXi=142.8
27336 CJK UNIFIED IDEOGRAPH-#27336, IRGKangXi=1088.341, RSKangXi=142.8
27337 CJK UNIFIED IDEOGRAPH-#27337, IRGKangXi=1088.341, RSKangXi=142.8
27338 CJK UNIFIED IDEOGRAPH-#27338, IRGKangXi=1088.341, RSKangXi=142.8
27339 CJK UNIFIED IDEOGRAPH-#27339, IRGKangXi=1088.341, RSKangXi=142.8
2733A CJK UNIFIED IDEOGRAPH-#2733A, IRGKangXi=1088.341, RSKangXi=142.8
2733B CJK UNIFIED IDEOGRAPH-#2733B, IRGKangXi=1088.341, RSKangXi=142.8
2733C CJK UNIFIED IDEOGRAPH-#2733C, IRGKangXi=1088.341, RSKangXi=142.8
2733D CJK UNIFIED IDEOGRAPH-#2733D, IRGKangXi=1088.341, RSKangXi=142.8
2733E CJK UNIFIED IDEOGRAPH-#2733E, IRGKangXi=1088.341, RSKangXi=142.8
2733F CJK UNIFIED IDEOGRAPH-#2733F, IRGKangXi=1088.341, RSKangXi=142.8
27340 CJK UNIFIED IDEOGRAPH-#27340, IRGKangXi=1088.341, RSKangXi=142.8
27341 CJK UNIFIED IDEOGRAPH-#27341, IRGKangXi=1088.341, RSKangXi=142.8
27342 CJK UNIFIED IDEOGRAPH-#27342, IRGKangXi=1088.341, RSKangXi=142.8
27343 CJK UNIFIED IDEOGRAPH-#27343, IRGKangXi=1088.341, RSKangXi=142.8
27344 CJK UNIFIED IDEOGRAPH-#27344, IRGKangXi=1088.341, RSKangXi=142.8
27345 CJK UNIFIED IDEOGRAPH-#27345, IRGKangXi=1088.341, RSKangXi=142.8
27346 CJK UNIFIED IDEOGRAPH-#27346, IRGKangXi=1088.341, RSKangXi=142.8
27347 CJK UNIFIED IDEOGRAPH-#27347, IRGKangXi=1088.341, RSKangXi=142.8
27348 CJK UNIFIED IDEOGRAPH-#27348, IRGKangXi=1088.341, RSKangXi=142.8
27349 CJK UNIFIED IDEOGRAPH-#27349, IRGKangXi=1088.341, RSKangXi=142.8
2734A CJK UNIFIED IDEOGRAPH-#2734A, IRGKangXi=1088.341, RSKangXi=142.8
2734B CJK UNIFIED IDEOGRAPH-#2734B, IRGKangXi=1088.341, RSKangXi=142.8
2734C CJK UNIFIED IDEOGRAPH-#2734C, IRGKangXi=1088.341, RSKangXi=142.8
2734D CJK UNIFIED IDEOGRAPH-#2734D, IRGKangXi=1088.341, RSKangXi=142.8
2734E CJK UNIFIED IDEOGRAPH-#2734E, IRGKangXi=1088.341, RSKangXi=142.8
2734F CJK UNIFIED IDEOGRAPH-#2734F, IRGKangXi=1088.341, RSKangXi=142.8
27350 CJK UNIFIED IDEOGRAPH-#27350, IRGKangXi=1088.341, RSKangXi=142.8
27351 CJK UNIFIED IDEOGRAPH-#27351, IRGKangXi=1088.341, RSKangXi=142.8
27352 CJK UNIFIED IDEOGRAPH-#27352, IRGKangXi=1088.360, RSKangXi=142.9
27353 CJK UNIFIED IDEOGRAPH-#27353, IRGKangXi=1088.380, RSKangXi=142.9
27354 CJK UNIFIED IDEOGRAPH-#27354, IRGKangXi=1089.020, RSKangXi=142.9
27355 CJK UNIFIED IDEOGRAPH-#27355, IRGKangXi=1089.060, RSKangXi=142.9
27356 CJK UNIFIED IDEOGRAPH-#27356, IRGKangXi=1089.090, RSKangXi=142.9
27357 CJK UNIFIED IDEOGRAPH-#27357, IRGKangXi=1089.150, RSKangXi=142.9
27358 CJK UNIFIED IDEOGRAPH-#27358, IRGKangXi=1089.170, RSKangXi=142.9
27359 CJK UNIFIED IDEOGRAPH-#27359, IRGKangXi=1089.190, RSKangXi=142.9
2735A CJK UNIFIED IDEOGRAPH-#2735A, IRGKangXi=1089.210, RSKangXi=142.9
2735B CJK UNIFIED IDEOGRAPH-#2735B, IRGKangXi=1089.250, RSKangXi=142.9
2735C CJK UNIFIED IDEOGRAPH-#2735C, IRGKangXi=1089.270, RSKangXi=142.9
2735D CJK UNIFIED IDEOGRAPH-#2735D, IRGKangXi=1089.280, RSKangXi=142.9
2735E CJK UNIFIED IDEOGRAPH-#2735E, IRGKangXi=1090.030, RSKangXi=142.9
2735F CJK UNIFIED IDEOGRAPH-#2735F, IRGKangXi=1090.120, RSKangXi=142.9
27360 CJK UNIFIED IDEOGRAPH-#27360, IRGKangXi=1090.130, RSKangXi=142.9
27361 CJK UNIFIED IDEOGRAPH-#27361, IRGKangXi=1090.140, RSKangXi=142.9
27362 CJK UNIFIED IDEOGRAPH-#27362, IRGKangXi=1090.200, RSKangXi=142.9
27363 CJK UNIFIED IDEOGRAPH-#27363, IRGKangXi=1091.020, RSKangXi=142.9
27364 CJK UNIFIED IDEOGRAPH-#27364, IRGKangXi=1091.030, RSKangXi=142.9
27365 CJK UNIFIED IDEOGRAPH-#27365, IRGKangXi=1091.040, RSKangXi=142.9
27366 CJK UNIFIED IDEOGRAPH-#27366, IRGKangXi=1091.050, RSKangXi=142.9
27367 CJK UNIFIED IDEOGRAPH-#27367, IRGKangXi=1091.060, RSKangXi=142.9
27368 CJK UNIFIED IDEOGRAPH-#27368, IRGKangXi=1091.090, RSKangXi=142.9
27369 CJK UNIFIED IDEOGRAPH-#27369, IRGKangXi=1091.110, RSKangXi=142.9
2736A CJK UNIFIED IDEOGRAPH-#2736A, IRGKangXi=1091.130, RSKangXi=142.9
2736B CJK UNIFIED IDEOGRAPH-#2736B, IRGKangXi=1091.150, RSKangXi=142.9
2736C CJK UNIFIED IDEOGRAPH-#2736C, IRGKangXi=1091.160, RSKangXi=142.9
2736D CJK UNIFIED IDEOGRAPH-#2736D, IRGKangXi=1091.170, RSKangXi=142.9
2736E CJK UNIFIED IDEOGRAPH-#2736E, IRGKangXi=1091.180, RSKangXi=142.9
2736F CJK UNIFIED IDEOGRAPH-#2736F, IRGKangXi=1091.190, RSKangXi=142.9
27370 CJK UNIFIED IDEOGRAPH-#27370, IRGKangXi=1091.230, RSKangXi=142.9
27371 CJK UNIFIED IDEOGRAPH-#27371, IRGKangXi=1091.240, RSKangXi=142.9
27372 CJK UNIFIED IDEOGRAPH-#27372, IRGKangXi=1091.270, RSKangXi=142.9
27373 CJK UNIFIED IDEOGRAPH-#27373, IRGKangXi=1092.010, RSKangXi=142.9
27374 CJK UNIFIED IDEOGRAPH-#27374, IRGKangXi=1092.020, RSKangXi=142.9
27375 CJK UNIFIED IDEOGRAPH-#27375, IRGKangXi=1092.040, RSKangXi=142.9
27376 CJK UNIFIED IDEOGRAPH-#27376, IRGKangXi=1092.050, RSKangXi=142.9
27377 CJK UNIFIED IDEOGRAPH-#27377, IRGKangXi=1092.060, RSKangXi=142.9
27378 CJK UNIFIED IDEOGRAPH-#27378, IRGKangXi=1092.070, RSKangXi=142.9
27379 CJK UNIFIED IDEOGRAPH-#27379, IRGKangXi=1092.080, RSKangXi=142.9
2737A CJK UNIFIED IDEOGRAPH-#2737A, IRGKangXi=1092.090, RSKangXi=142.9
2737B CJK UNIFIED IDEOGRAPH-#2737B, IRGKangXi=1092.100, RSKangXi=142.9
2737C CJK UNIFIED IDEOGRAPH-#2737C, IRGKangXi=1092.110, RSKangXi=142.9
2737D CJK UNIFIED IDEOGRAPH-#2737D, IRGKangXi=1092.120, RSKangXi=142.9
2737E CJK UNIFIED IDEOGRAPH-#2737E, IRGKangXi=1092.130, RSKangXi=142.9
2737F CJK UNIFIED IDEOGRAPH-#2737F, IRGKangXi=1092.140, RSKangXi=142.9
27380 CJK UNIFIED IDEOGRAPH-#27380, IRGKangXi=1092.150, RSKangXi=142.9
27381 CJK UNIFIED IDEOGRAPH-#27381, IRGKangXi=1092.160, RSKangXi=142.9
27382 CJK UNIFIED IDEOGRAPH-#27382, IRGKangXi=1092.180, RSKangXi=142.9
27383 CJK UNIFIED IDEOGRAPH-#27383, IRGKangXi=1092.190, RSKangXi=142.9
27384 CJK UNIFIED IDEOGRAPH-#27384, IRGKangXi=1092.210, RSKangXi=142.9
27385 CJK UNIFIED IDEOGRAPH-#27385, IRGKangXi=1092.211, RSKangXi=142.9
27386 CJK UNIFIED IDEOGRAPH-#27386, IRGKangXi=1092.211, RSKangXi=142.9
27387 CJK UNIFIED IDEOGRAPH-#27387, IRGKangXi=1092.211, RSKangXi=142.9
27388 CJK UNIFIED IDEOGRAPH-#27388, IRGKangXi=1092.211, RSKangXi=142.9
27389 CJK UNIFIED IDEOGRAPH-#27389, IRGKangXi=1092.211, RSKangXi=142.9
2738A CJK UNIFIED IDEOGRAPH-#2738A, IRGKangXi=1092.211, RSKangXi=142.9
2738B CJK UNIFIED IDEOGRAPH-#2738B, IRGKangXi=1092.211, RSKangXi=142.9
2738C CJK UNIFIED IDEOGRAPH-#2738C, IRGKangXi=1092.211, RSKangXi=142.9
2738D CJK UNIFIED IDEOGRAPH-#2738D, IRGKangXi=1092.211, RSKangXi=142.9
2738E CJK UNIFIED IDEOGRAPH-#2738E, IRGKangXi=1092.211, RSKangXi=142.9
2738F CJK UNIFIED IDEOGRAPH-#2738F, IRGKangXi=1092.211, RSKangXi=142.9
27390 CJK UNIFIED IDEOGRAPH-#27390, IRGKangXi=1092.211, RSKangXi=142.9
27391 CJK UNIFIED IDEOGRAPH-#27391, IRGKangXi=1092.211, RSKangXi=142.9
27392 CJK UNIFIED IDEOGRAPH-#27392, IRGKangXi=1092.211, RSKangXi=142.9
27393 CJK UNIFIED IDEOGRAPH-#27393, IRGKangXi=1092.211, RSKangXi=142.9
27394 CJK UNIFIED IDEOGRAPH-#27394, IRGKangXi=1092.211, RSKangXi=142.9
27395 CJK UNIFIED IDEOGRAPH-#27395, IRGKangXi=1092.211, RSKangXi=142.9
27396 CJK UNIFIED IDEOGRAPH-#27396, IRGKangXi=1092.211, RSKangXi=142.9
27397 CJK UNIFIED IDEOGRAPH-#27397, IRGKangXi=1092.211, RSKangXi=142.9
27398 CJK UNIFIED IDEOGRAPH-#27398, IRGKangXi=1092.211, RSKangXi=142.9
27399 CJK UNIFIED IDEOGRAPH-#27399, IRGKangXi=1092.211, RSKangXi=142.9
2739A CJK UNIFIED IDEOGRAPH-#2739A, IRGKangXi=1092.211, RSKangXi=142.9
2739B CJK UNIFIED IDEOGRAPH-#2739B, IRGKangXi=1092.211, RSKangXi=142.9
2739C CJK UNIFIED IDEOGRAPH-#2739C, IRGKangXi=1092.211, RSKangXi=142.9
2739D CJK UNIFIED IDEOGRAPH-#2739D, IRGKangXi=1092.211, RSKangXi=142.9
2739E CJK UNIFIED IDEOGRAPH-#2739E, IRGKangXi=1092.211, RSKangXi=142.9
2739F CJK UNIFIED IDEOGRAPH-#2739F, IRGKangXi=1092.211, RSKangXi=142.9
273A0 CJK UNIFIED IDEOGRAPH-#273A0, IRGKangXi=1092.211, RSKangXi=142.9
273A1 CJK UNIFIED IDEOGRAPH-#273A1, IRGKangXi=1092.250, RSKangXi=142.10
273A2 CJK UNIFIED IDEOGRAPH-#273A2, IRGKangXi=1092.280, RSKangXi=142.10
273A3 CJK UNIFIED IDEOGRAPH-#273A3, IRGKangXi=1092.290, RSKangXi=142.10
273A4 CJK UNIFIED IDEOGRAPH-#273A4, IRGKangXi=1092.330, RSKangXi=142.10
273A5 CJK UNIFIED IDEOGRAPH-#273A5, IRGKangXi=1092.350, RSKangXi=142.10
273A6 CJK UNIFIED IDEOGRAPH-#273A6, IRGKangXi=1092.360, RSKangXi=142.10
273A7 CJK UNIFIED IDEOGRAPH-#273A7, IRGKangXi=1092.380, RSKangXi=142.10
273A8 CJK UNIFIED IDEOGRAPH-#273A8, IRGKangXi=1092.400, RSKangXi=142.10
273A9 CJK UNIFIED IDEOGRAPH-#273A9, IRGKangXi=1093.040, RSKangXi=142.10
273AA CJK UNIFIED IDEOGRAPH-#273AA, IRGKangXi=1093.060, RSKangXi=142.10
273AB CJK UNIFIED IDEOGRAPH-#273AB, IRGKangXi=1093.070, RSKangXi=142.10
273AC CJK UNIFIED IDEOGRAPH-#273AC, IRGKangXi=1093.100, RSKangXi=142.10
273AD CJK UNIFIED IDEOGRAPH-#273AD, IRGKangXi=1093.110, RSKangXi=142.10
273AE CJK UNIFIED IDEOGRAPH-#273AE, IRGKangXi=1093.130, RSKangXi=142.10
273AF CJK UNIFIED IDEOGRAPH-#273AF, IRGKangXi=1093.150, RSKangXi=142.10
273B0 CJK UNIFIED IDEOGRAPH-#273B0, IRGKangXi=1093.160, RSKangXi=142.10
273B1 CJK UNIFIED IDEOGRAPH-#273B1, IRGKangXi=1093.180, RSKangXi=142.10
273B2 CJK UNIFIED IDEOGRAPH-#273B2, IRGKangXi=1093.190, RSKangXi=142.10
273B3 CJK UNIFIED IDEOGRAPH-#273B3, IRGKangXi=1093.200, RSKangXi=142.10
273B4 CJK UNIFIED IDEOGRAPH-#273B4, IRGKangXi=1093.220, RSKangXi=142.10
273B5 CJK UNIFIED IDEOGRAPH-#273B5, IRGKangXi=1093.250, RSKangXi=142.10
273B6 CJK UNIFIED IDEOGRAPH-#273B6, IRGKangXi=1093.290, RSKangXi=142.10
273B7 CJK UNIFIED IDEOGRAPH-#273B7, IRGKangXi=1093.310, RSKangXi=142.10
273B8 CJK UNIFIED IDEOGRAPH-#273B8, IRGKangXi=1093.320, RSKangXi=142.10
273B9 CJK UNIFIED IDEOGRAPH-#273B9, IRGKangXi=1093.340, RSKangXi=142.10
273BA CJK UNIFIED IDEOGRAPH-#273BA, IRGKangXi=1093.370, RSKangXi=142.10
273BB CJK UNIFIED IDEOGRAPH-#273BB, IRGKangXi=1093.390, RSKangXi=142.10
273BC CJK UNIFIED IDEOGRAPH-#273BC, IRGKangXi=1093.470, RSKangXi=142.10
273BD CJK UNIFIED IDEOGRAPH-#273BD, IRGKangXi=1094.010, RSKangXi=142.10
273BE CJK UNIFIED IDEOGRAPH-#273BE, IRGKangXi=1094.020, RSKangXi=142.10
273BF CJK UNIFIED IDEOGRAPH-#273BF, IRGKangXi=1094.030, RSKangXi=142.10
273C0 CJK UNIFIED IDEOGRAPH-#273C0, IRGKangXi=1094.040, RSKangXi=142.10
273C1 CJK UNIFIED IDEOGRAPH-#273C1, IRGKangXi=1094.050, RSKangXi=142.10
273C2 CJK UNIFIED IDEOGRAPH-#273C2, IRGKangXi=1094.060, RSKangXi=142.10
273C3 CJK UNIFIED IDEOGRAPH-#273C3, IRGKangXi=1094.070, RSKangXi=142.10
273C4 CJK UNIFIED IDEOGRAPH-#273C4, IRGKangXi=1094.080, RSKangXi=142.10
273C5 CJK UNIFIED IDEOGRAPH-#273C5, IRGKangXi=1094.100, RSKangXi=142.10
273C6 CJK UNIFIED IDEOGRAPH-#273C6, IRGKangXi=1094.110, RSKangXi=142.10
273C7 CJK UNIFIED IDEOGRAPH-#273C7, IRGKangXi=1094.120, RSKangXi=142.9
273C8 CJK UNIFIED IDEOGRAPH-#273C8, IRGKangXi=1094.130, RSKangXi=142.10
273C9 CJK UNIFIED IDEOGRAPH-#273C9, IRGKangXi=1094.140, RSKangXi=142.10
273CA CJK UNIFIED IDEOGRAPH-#273CA, IRGKangXi=1094.150, RSKangXi=142.10
273CB CJK UNIFIED IDEOGRAPH-#273CB, IRGKangXi=1094.160, RSKangXi=142.10
273CC CJK UNIFIED IDEOGRAPH-#273CC, IRGKangXi=1094.170, RSKangXi=142.10
273CD CJK UNIFIED IDEOGRAPH-#273CD, IRGKangXi=1094.180, RSKangXi=142.10
273CE CJK UNIFIED IDEOGRAPH-#273CE, IRGKangXi=1094.190, RSKangXi=142.10
273CF CJK UNIFIED IDEOGRAPH-#273CF, IRGKangXi=1094.210, RSKangXi=142.10
273D0 CJK UNIFIED IDEOGRAPH-#273D0, IRGKangXi=1094.220, RSKangXi=142.10
273D1 CJK UNIFIED IDEOGRAPH-#273D1, IRGKangXi=1094.230, RSKangXi=142.10
273D2 CJK UNIFIED IDEOGRAPH-#273D2, IRGKangXi=1094.240, RSKangXi=142.10
273D3 CJK UNIFIED IDEOGRAPH-#273D3, IRGKangXi=1094.250, RSKangXi=142.10
273D4 CJK UNIFIED IDEOGRAPH-#273D4, IRGKangXi=1094.260, RSKangXi=142.10
273D5 CJK UNIFIED IDEOGRAPH-#273D5, IRGKangXi=1094.270, RSKangXi=142.10
273D6 CJK UNIFIED IDEOGRAPH-#273D6, IRGKangXi=1094.271, RSKangXi=142.10
273D7 CJK UNIFIED IDEOGRAPH-#273D7, IRGKangXi=1094.271, RSKangXi=142.10
273D8 CJK UNIFIED IDEOGRAPH-#273D8, IRGKangXi=1094.271, RSKangXi=142.10
273D9 CJK UNIFIED IDEOGRAPH-#273D9, IRGKangXi=1094.271, RSKangXi=142.10
273DA CJK UNIFIED IDEOGRAPH-#273DA, IRGKangXi=1094.271, RSKangXi=142.10
273DB CJK UNIFIED IDEOGRAPH-#273DB, IRGKangXi=1094.271, RSKangXi=142.10
273DC CJK UNIFIED IDEOGRAPH-#273DC, IRGKangXi=1094.271, RSKangXi=142.10
273DD CJK UNIFIED IDEOGRAPH-#273DD, IRGKangXi=1094.271, RSKangXi=142.10
273DE CJK UNIFIED IDEOGRAPH-#273DE, IRGKangXi=1094.271, RSKangXi=142.10
273DF CJK UNIFIED IDEOGRAPH-#273DF, IRGKangXi=1094.271, RSKangXi=142.10
273E0 CJK UNIFIED IDEOGRAPH-#273E0, IRGKangXi=1094.271, RSKangXi=142.10
273E1 CJK UNIFIED IDEOGRAPH-#273E1, IRGKangXi=1094.271, RSKangXi=142.10
273E2 CJK UNIFIED IDEOGRAPH-#273E2, IRGKangXi=1094.271, RSKangXi=142.10
273E3 CJK UNIFIED IDEOGRAPH-#273E3, IRGKangXi=1094.271, RSKangXi=142.10
273E4 CJK UNIFIED IDEOGRAPH-#273E4, IRGKangXi=1094.271, RSKangXi=142.10
273E5 CJK UNIFIED IDEOGRAPH-#273E5, IRGKangXi=1094.271, RSKangXi=142.10
273E6 CJK UNIFIED IDEOGRAPH-#273E6, IRGKangXi=1094.271, RSKangXi=142.10
273E7 CJK UNIFIED IDEOGRAPH-#273E7, IRGKangXi=1094.271, RSKangXi=142.10
273E8 CJK UNIFIED IDEOGRAPH-#273E8, IRGKangXi=1094.271, RSKangXi=142.10
273E9 CJK UNIFIED IDEOGRAPH-#273E9, IRGKangXi=1094.271, RSKangXi=142.10
273EA CJK UNIFIED IDEOGRAPH-#273EA, IRGKangXi=1094.271, RSKangXi=142.10
273EB CJK UNIFIED IDEOGRAPH-#273EB, IRGKangXi=1094.271, RSKangXi=142.10
273EC CJK UNIFIED IDEOGRAPH-#273EC, IRGKangXi=1094.271, RSKangXi=142.10
273ED CJK UNIFIED IDEOGRAPH-#273ED, IRGKangXi=1094.271, RSKangXi=142.10
273EE CJK UNIFIED IDEOGRAPH-#273EE, IRGKangXi=1094.271, RSKangXi=142.10
273EF CJK UNIFIED IDEOGRAPH-#273EF, IRGKangXi=1094.271, RSKangXi=142.10
273F0 CJK UNIFIED IDEOGRAPH-#273F0, IRGKangXi=1094.271, RSKangXi=142.10
273F1 CJK UNIFIED IDEOGRAPH-#273F1, IRGKangXi=1094.271, RSKangXi=142.10
273F2 CJK UNIFIED IDEOGRAPH-#273F2, IRGKangXi=1094.271, RSKangXi=142.10
273F3 CJK UNIFIED IDEOGRAPH-#273F3, IRGKangXi=1094.271, RSKangXi=142.10
273F4 CJK UNIFIED IDEOGRAPH-#273F4, IRGKangXi=1094.271, RSKangXi=142.10
273F5 CJK UNIFIED IDEOGRAPH-#273F5, IRGKangXi=1094.271, RSKangXi=142.10
273F6 CJK UNIFIED IDEOGRAPH-#273F6, IRGKangXi=1094.271, RSKangXi=142.10
273F7 CJK UNIFIED IDEOGRAPH-#273F7, IRGKangXi=1094.271, RSKangXi=142.10
273F8 CJK UNIFIED IDEOGRAPH-#273F8, IRGKangXi=1094.290, RSKangXi=142.11
273F9 CJK UNIFIED IDEOGRAPH-#273F9, IRGKangXi=1094.300, RSKangXi=142.11
273FA CJK UNIFIED IDEOGRAPH-#273FA, IRGKangXi=1094.310, RSKangXi=142.11
273FB CJK UNIFIED IDEOGRAPH-#273FB, IRGKangXi=1094.320, RSKangXi=142.11
273FC CJK UNIFIED IDEOGRAPH-#273FC, IRGKangXi=1094.330, RSKangXi=142.11
273FD CJK UNIFIED IDEOGRAPH-#273FD, IRGKangXi=1094.350, RSKangXi=142.11
273FE CJK UNIFIED IDEOGRAPH-#273FE, IRGKangXi=1094.370, RSKangXi=142.11
273FF CJK UNIFIED IDEOGRAPH-#273FF, IRGKangXi=1094.390, RSKangXi=142.11
27400 CJK UNIFIED IDEOGRAPH-#27400, IRGKangXi=1094.400, RSKangXi=142.11
27401 CJK UNIFIED IDEOGRAPH-#27401, IRGKangXi=1094.410, RSKangXi=142.11
27402 CJK UNIFIED IDEOGRAPH-#27402, IRGKangXi=1094.420, RSKangXi=142.11
27403 CJK UNIFIED IDEOGRAPH-#27403, IRGKangXi=1094.430, RSKangXi=142.11
27404 CJK UNIFIED IDEOGRAPH-#27404, IRGKangXi=1094.440, RSKangXi=142.11
27405 CJK UNIFIED IDEOGRAPH-#27405, IRGKangXi=1094.450, RSKangXi=142.11, Def{maggots, centipedes}
27406 CJK UNIFIED IDEOGRAPH-#27406, IRGKangXi=1094.470, RSKangXi=142.11
27407 CJK UNIFIED IDEOGRAPH-#27407, IRGKangXi=1095.010, RSKangXi=142.11
27408 CJK UNIFIED IDEOGRAPH-#27408, IRGKangXi=1095.080, RSKangXi=142.11
27409 CJK UNIFIED IDEOGRAPH-#27409, IRGKangXi=1095.130, RSKangXi=142.11
2740A CJK UNIFIED IDEOGRAPH-#2740A, IRGKangXi=1095.200, RSKangXi=142.11
2740B CJK UNIFIED IDEOGRAPH-#2740B, IRGKangXi=1095.220, RSKangXi=142.11
2740C CJK UNIFIED IDEOGRAPH-#2740C, IRGKangXi=1095.230, RSKangXi=142.11
2740D CJK UNIFIED IDEOGRAPH-#2740D, IRGKangXi=1095.240, RSKangXi=142.11
2740E CJK UNIFIED IDEOGRAPH-#2740E, IRGKangXi=1095.270, RSKangXi=142.11
2740F CJK UNIFIED IDEOGRAPH-#2740F, IRGKangXi=1095.280, RSKangXi=142.11
27410 CJK UNIFIED IDEOGRAPH-#27410, IRGKangXi=1095.320, RSKangXi=142.11
27411 CJK UNIFIED IDEOGRAPH-#27411, IRGKangXi=1095.350, RSKangXi=142.11
27412 CJK UNIFIED IDEOGRAPH-#27412, IRGKangXi=1096.050, RSKangXi=142.11
27413 CJK UNIFIED IDEOGRAPH-#27413, IRGKangXi=1096.110, RSKangXi=142.11
27414 CJK UNIFIED IDEOGRAPH-#27414, IRGKangXi=1096.120, RSKangXi=142.11
27415 CJK UNIFIED IDEOGRAPH-#27415, IRGKangXi=1096.160, RSKangXi=142.11
27416 CJK UNIFIED IDEOGRAPH-#27416, IRGKangXi=1096.170, RSKangXi=142.11
27417 CJK UNIFIED IDEOGRAPH-#27417, IRGKangXi=1096.180, RSKangXi=142.11
27418 CJK UNIFIED IDEOGRAPH-#27418, IRGKangXi=1096.190, RSKangXi=142.11
27419 CJK UNIFIED IDEOGRAPH-#27419, IRGKangXi=1096.200, RSKangXi=142.11
2741A CJK UNIFIED IDEOGRAPH-#2741A, IRGKangXi=1096.210, RSKangXi=142.11
2741B CJK UNIFIED IDEOGRAPH-#2741B, IRGKangXi=1096.230, RSKangXi=142.11
2741C CJK UNIFIED IDEOGRAPH-#2741C, IRGKangXi=1096.240, RSKangXi=142.11
2741D CJK UNIFIED IDEOGRAPH-#2741D, IRGKangXi=1096.250, RSKangXi=142.11
2741E CJK UNIFIED IDEOGRAPH-#2741E, IRGKangXi=1096.260, RSKangXi=142.11
2741F CJK UNIFIED IDEOGRAPH-#2741F, IRGKangXi=1096.270, RSKangXi=142.11
27420 CJK UNIFIED IDEOGRAPH-#27420, IRGKangXi=1096.271, RSKangXi=142.11
27421 CJK UNIFIED IDEOGRAPH-#27421, IRGKangXi=1096.271, RSKangXi=142.11
27422 CJK UNIFIED IDEOGRAPH-#27422, IRGKangXi=1096.271, RSKangXi=142.11, Def{an oyster}
27423 CJK UNIFIED IDEOGRAPH-#27423, IRGKangXi=1096.271, RSKangXi=142.11
27424 CJK UNIFIED IDEOGRAPH-#27424, IRGKangXi=1096.271, RSKangXi=142.11
27425 CJK UNIFIED IDEOGRAPH-#27425, IRGKangXi=1096.271, RSKangXi=142.11
27426 CJK UNIFIED IDEOGRAPH-#27426, IRGKangXi=1096.271, RSKangXi=142.11
27427 CJK UNIFIED IDEOGRAPH-#27427, IRGKangXi=1096.271, RSKangXi=142.11
27428 CJK UNIFIED IDEOGRAPH-#27428, IRGKangXi=1096.271, RSKangXi=142.11
27429 CJK UNIFIED IDEOGRAPH-#27429, IRGKangXi=1096.271, RSKangXi=142.11
2742A CJK UNIFIED IDEOGRAPH-#2742A, IRGKangXi=1096.271, RSKangXi=142.11
2742B CJK UNIFIED IDEOGRAPH-#2742B, IRGKangXi=1096.271, RSKangXi=142.11
2742C CJK UNIFIED IDEOGRAPH-#2742C, IRGKangXi=1096.271, RSKangXi=142.11
2742D CJK UNIFIED IDEOGRAPH-#2742D, IRGKangXi=1096.271, RSKangXi=142.11
2742E CJK UNIFIED IDEOGRAPH-#2742E, IRGKangXi=1096.271, RSKangXi=142.11
2742F CJK UNIFIED IDEOGRAPH-#2742F, IRGKangXi=1096.271, RSKangXi=142.11
27430 CJK UNIFIED IDEOGRAPH-#27430, IRGKangXi=1096.271, RSKangXi=122.13
27431 CJK UNIFIED IDEOGRAPH-#27431, IRGKangXi=1096.271, RSKangXi=142.11
27432 CJK UNIFIED IDEOGRAPH-#27432, IRGKangXi=1096.271, RSKangXi=142.11
27433 CJK UNIFIED IDEOGRAPH-#27433, IRGKangXi=1096.271, RSKangXi=142.11
27434 CJK UNIFIED IDEOGRAPH-#27434, IRGKangXi=1096.271, RSKangXi=142.11
27435 CJK UNIFIED IDEOGRAPH-#27435, IRGKangXi=1096.271, RSKangXi=142.11
27436 CJK UNIFIED IDEOGRAPH-#27436, IRGKangXi=1096.271, RSKangXi=142.11
27437 CJK UNIFIED IDEOGRAPH-#27437, IRGKangXi=1096.271, RSKangXi=142.11
27438 CJK UNIFIED IDEOGRAPH-#27438, IRGKangXi=1096.271, RSKangXi=142.11
27439 CJK UNIFIED IDEOGRAPH-#27439, IRGKangXi=1096.271, RSKangXi=142.11
2743A CJK UNIFIED IDEOGRAPH-#2743A, IRGKangXi=1096.271, RSKangXi=142.11
2743B CJK UNIFIED IDEOGRAPH-#2743B, IRGKangXi=1096.271, RSKangXi=142.11
2743C CJK UNIFIED IDEOGRAPH-#2743C, IRGKangXi=1096.271, RSKangXi=142.11
2743D CJK UNIFIED IDEOGRAPH-#2743D, IRGKangXi=1096.271, RSKangXi=142.11
2743E CJK UNIFIED IDEOGRAPH-#2743E, IRGKangXi=1096.271, RSKangXi=142.11
2743F CJK UNIFIED IDEOGRAPH-#2743F, IRGKangXi=1096.271, RSKangXi=142.11
27440 CJK UNIFIED IDEOGRAPH-#27440, IRGKangXi=1096.271, RSKangXi=142.11
27441 CJK UNIFIED IDEOGRAPH-#27441, IRGKangXi=1096.271
27442 CJK UNIFIED IDEOGRAPH-#27442, IRGKangXi=1096.271, RSKangXi=142.11
27443 CJK UNIFIED IDEOGRAPH-#27443, IRGKangXi=1096.271, RSKangXi=142.11
27444 CJK UNIFIED IDEOGRAPH-#27444, IRGKangXi=1096.280, RSKangXi=142.12
27445 CJK UNIFIED IDEOGRAPH-#27445, IRGKangXi=1096.320, RSKangXi=142.12
27446 CJK UNIFIED IDEOGRAPH-#27446, IRGKangXi=1097.020, RSKangXi=142.12
27447 CJK UNIFIED IDEOGRAPH-#27447, IRGKangXi=1097.030, RSKangXi=142.12
27448 CJK UNIFIED IDEOGRAPH-#27448, IRGKangXi=1097.050, RSKangXi=142.12
27449 CJK UNIFIED IDEOGRAPH-#27449, IRGKangXi=1097.080, RSKangXi=142.12
2744A CJK UNIFIED IDEOGRAPH-#2744A, IRGKangXi=1097.130, RSKangXi=142.12
2744B CJK UNIFIED IDEOGRAPH-#2744B, IRGKangXi=1097.200, RSKangXi=142.12
2744C CJK UNIFIED IDEOGRAPH-#2744C, IRGKangXi=1097.220, RSKangXi=142.12
2744D CJK UNIFIED IDEOGRAPH-#2744D, IRGKangXi=1097.230, RSKangXi=142.12
2744E CJK UNIFIED IDEOGRAPH-#2744E, IRGKangXi=1097.240, RSKangXi=142.12
2744F CJK UNIFIED IDEOGRAPH-#2744F, IRGKangXi=1097.260, RSKangXi=142.12
27450 CJK UNIFIED IDEOGRAPH-#27450, IRGKangXi=1097.270, RSKangXi=142.12
27451 CJK UNIFIED IDEOGRAPH-#27451, IRGKangXi=1097.280, RSKangXi=142.12
27452 CJK UNIFIED IDEOGRAPH-#27452, IRGKangXi=1097.290, RSKangXi=142.12
27453 CJK UNIFIED IDEOGRAPH-#27453, IRGKangXi=1098.010, RSKangXi=142.12
27454 CJK UNIFIED IDEOGRAPH-#27454, IRGKangXi=1098.020, RSKangXi=142.12
27455 CJK UNIFIED IDEOGRAPH-#27455, IRGKangXi=1098.030, RSKangXi=142.12
27456 CJK UNIFIED IDEOGRAPH-#27456, IRGKangXi=1098.040, RSKangXi=142.12
27457 CJK UNIFIED IDEOGRAPH-#27457, IRGKangXi=1098.090, RSKangXi=142.12
27458 CJK UNIFIED IDEOGRAPH-#27458, IRGKangXi=1098.110, RSKangXi=142.12
27459 CJK UNIFIED IDEOGRAPH-#27459, IRGKangXi=1098.120, RSKangXi=142.12
2745A CJK UNIFIED IDEOGRAPH-#2745A, IRGKangXi=1098.130, RSKangXi=142.12
2745B CJK UNIFIED IDEOGRAPH-#2745B, IRGKangXi=1098.140, RSKangXi=142.12
2745C CJK UNIFIED IDEOGRAPH-#2745C, IRGKangXi=1098.180, RSKangXi=142.12
2745D CJK UNIFIED IDEOGRAPH-#2745D, IRGKangXi=1098.190, RSKangXi=142.12
2745E CJK UNIFIED IDEOGRAPH-#2745E, IRGKangXi=1098.200, RSKangXi=142.12
2745F CJK UNIFIED IDEOGRAPH-#2745F, IRGKangXi=1098.210, RSKangXi=142.12
27460 CJK UNIFIED IDEOGRAPH-#27460, IRGKangXi=1098.220, RSKangXi=142.12
27461 CJK UNIFIED IDEOGRAPH-#27461, IRGKangXi=1098.230, RSKangXi=142.12
27462 CJK UNIFIED IDEOGRAPH-#27462, IRGKangXi=1098.240, RSKangXi=142.12
27463 CJK UNIFIED IDEOGRAPH-#27463, IRGKangXi=1098.250, RSKangXi=142.12
27464 CJK UNIFIED IDEOGRAPH-#27464, IRGKangXi=1098.260, RSKangXi=142.12
27465 CJK UNIFIED IDEOGRAPH-#27465, IRGKangXi=1098.270, RSKangXi=142.12
27466 CJK UNIFIED IDEOGRAPH-#27466, IRGKangXi=1098.280, RSKangXi=142.12
27467 CJK UNIFIED IDEOGRAPH-#27467, IRGKangXi=1098.290, RSKangXi=142.12
27468 CJK UNIFIED IDEOGRAPH-#27468, IRGKangXi=1098.300, RSKangXi=142.12
27469 CJK UNIFIED IDEOGRAPH-#27469, IRGKangXi=1098.310, RSKangXi=142.12
2746A CJK UNIFIED IDEOGRAPH-#2746A, IRGKangXi=1098.320, RSKangXi=142.12
2746B CJK UNIFIED IDEOGRAPH-#2746B, IRGKangXi=1098.330, RSKangXi=142.12
2746C CJK UNIFIED IDEOGRAPH-#2746C, IRGKangXi=1098.340, RSKangXi=142.12
2746D CJK UNIFIED IDEOGRAPH-#2746D, IRGKangXi=1098.350, RSKangXi=142.12
2746E CJK UNIFIED IDEOGRAPH-#2746E, IRGKangXi=1098.360, RSKangXi=142.12
2746F CJK UNIFIED IDEOGRAPH-#2746F, IRGKangXi=1098.370, RSKangXi=142.12
27470 CJK UNIFIED IDEOGRAPH-#27470, IRGKangXi=1098.380, RSKangXi=142.12
27471 CJK UNIFIED IDEOGRAPH-#27471, IRGKangXi=1098.390, RSKangXi=142.12
27472 CJK UNIFIED IDEOGRAPH-#27472, IRGKangXi=1098.400, RSKangXi=142.12
27473 CJK UNIFIED IDEOGRAPH-#27473, IRGKangXi=1098.420, RSKangXi=142.12
27474 CJK UNIFIED IDEOGRAPH-#27474, IRGKangXi=1098.430, RSKangXi=142.12
27475 CJK UNIFIED IDEOGRAPH-#27475, IRGKangXi=1098.440, RSKangXi=142.12
27476 CJK UNIFIED IDEOGRAPH-#27476, IRGKangXi=1098.441, RSKangXi=142.12
27477 CJK UNIFIED IDEOGRAPH-#27477, IRGKangXi=1098.441, RSKangXi=142.12
27478 CJK UNIFIED IDEOGRAPH-#27478, IRGKangXi=1098.441, RSKangXi=142.12
27479 CJK UNIFIED IDEOGRAPH-#27479, IRGKangXi=1098.441, RSKangXi=142.12
2747A CJK UNIFIED IDEOGRAPH-#2747A, IRGKangXi=1098.441, RSKangXi=142.12
2747B CJK UNIFIED IDEOGRAPH-#2747B, IRGKangXi=1098.441, RSKangXi=142.12
2747C CJK UNIFIED IDEOGRAPH-#2747C, IRGKangXi=1098.441, RSKangXi=142.12
2747D CJK UNIFIED IDEOGRAPH-#2747D, IRGKangXi=1098.441, RSKangXi=142.12
2747E CJK UNIFIED IDEOGRAPH-#2747E, IRGKangXi=1098.441, RSKangXi=142.12
2747F CJK UNIFIED IDEOGRAPH-#2747F, IRGKangXi=1098.441, RSKangXi=142.12
27480 CJK UNIFIED IDEOGRAPH-#27480, IRGKangXi=1098.441, RSKangXi=142.12
27481 CJK UNIFIED IDEOGRAPH-#27481, IRGKangXi=1098.441, RSKangXi=142.12
27482 CJK UNIFIED IDEOGRAPH-#27482, IRGKangXi=1098.441, RSKangXi=142.12
27483 CJK UNIFIED IDEOGRAPH-#27483, IRGKangXi=1098.441, RSKangXi=142.12
27484 CJK UNIFIED IDEOGRAPH-#27484, IRGKangXi=1098.441, RSKangXi=142.12
27485 CJK UNIFIED IDEOGRAPH-#27485, IRGKangXi=1098.441, RSKangXi=142.12
27486 CJK UNIFIED IDEOGRAPH-#27486, IRGKangXi=1098.441, RSKangXi=142.12
27487 CJK UNIFIED IDEOGRAPH-#27487, IRGKangXi=1098.441, RSKangXi=142.12
27488 CJK UNIFIED IDEOGRAPH-#27488, IRGKangXi=1098.441, RSKangXi=142.12
27489 CJK UNIFIED IDEOGRAPH-#27489, IRGKangXi=1098.441, RSKangXi=142.12
2748A CJK UNIFIED IDEOGRAPH-#2748A, IRGKangXi=1098.441, RSKangXi=142.12
2748B CJK UNIFIED IDEOGRAPH-#2748B, IRGKangXi=1098.441, RSKangXi=142.12
2748C CJK UNIFIED IDEOGRAPH-#2748C, IRGKangXi=1098.441, RSKangXi=142.12
2748D CJK UNIFIED IDEOGRAPH-#2748D, IRGKangXi=1098.441, RSKangXi=142.12
2748E CJK UNIFIED IDEOGRAPH-#2748E, IRGKangXi=1099.010, RSKangXi=142.13
2748F CJK UNIFIED IDEOGRAPH-#2748F, IRGKangXi=1099.090, RSKangXi=142.13
27490 CJK UNIFIED IDEOGRAPH-#27490, IRGKangXi=1099.140, RSKangXi=142.13
27491 CJK UNIFIED IDEOGRAPH-#27491, IRGKangXi=1099.160, RSKangXi=142.13
27492 CJK UNIFIED IDEOGRAPH-#27492, IRGKangXi=1099.170, RSKangXi=142.13
27493 CJK UNIFIED IDEOGRAPH-#27493, IRGKangXi=1099.180, RSKangXi=142.13
27494 CJK UNIFIED IDEOGRAPH-#27494, IRGKangXi=1099.210, RSKangXi=142.13
27495 CJK UNIFIED IDEOGRAPH-#27495, IRGKangXi=1099.220, RSKangXi=142.13
27496 CJK UNIFIED IDEOGRAPH-#27496, IRGKangXi=1099.230, RSKangXi=142.13
27497 CJK UNIFIED IDEOGRAPH-#27497, IRGKangXi=1100.070, RSKangXi=142.13
27498 CJK UNIFIED IDEOGRAPH-#27498, IRGKangXi=1100.110, RSKangXi=142.13
27499 CJK UNIFIED IDEOGRAPH-#27499, IRGKangXi=1100.130, RSKangXi=142.13
2749A CJK UNIFIED IDEOGRAPH-#2749A, IRGKangXi=1100.140, RSKangXi=142.13
2749B CJK UNIFIED IDEOGRAPH-#2749B, IRGKangXi=1100.150, RSKangXi=142.13
2749C CJK UNIFIED IDEOGRAPH-#2749C, IRGKangXi=1100.160, RSKangXi=142.13
2749D CJK UNIFIED IDEOGRAPH-#2749D, IRGKangXi=1100.170, RSKangXi=142.13
2749E CJK UNIFIED IDEOGRAPH-#2749E, IRGKangXi=1100.180, RSKangXi=142.13
2749F CJK UNIFIED IDEOGRAPH-#2749F, IRGKangXi=1100.190, RSKangXi=142.13
274A0 CJK UNIFIED IDEOGRAPH-#274A0, IRGKangXi=1100.200, RSKangXi=142.13
274A1 CJK UNIFIED IDEOGRAPH-#274A1, IRGKangXi=1100.210, RSKangXi=142.13
274A2 CJK UNIFIED IDEOGRAPH-#274A2, IRGKangXi=1100.220, RSKangXi=142.13
274A3 CJK UNIFIED IDEOGRAPH-#274A3, IRGKangXi=1100.230, RSKangXi=142.13
274A4 CJK UNIFIED IDEOGRAPH-#274A4, IRGKangXi=1100.240, RSKangXi=142.13
274A5 CJK UNIFIED IDEOGRAPH-#274A5, IRGKangXi=1100.250, RSKangXi=142.13
274A6 CJK UNIFIED IDEOGRAPH-#274A6, IRGKangXi=1100.260, RSKangXi=142.13
274A7 CJK UNIFIED IDEOGRAPH-#274A7, IRGKangXi=1100.270, RSKangXi=142.13
274A8 CJK UNIFIED IDEOGRAPH-#274A8, IRGKangXi=1100.290, RSKangXi=142.13
274A9 CJK UNIFIED IDEOGRAPH-#274A9, IRGKangXi=1100.300, RSKangXi=142.13
274AA CJK UNIFIED IDEOGRAPH-#274AA, IRGKangXi=1100.310, RSKangXi=142.13
274AB CJK UNIFIED IDEOGRAPH-#274AB, IRGKangXi=1100.321, RSKangXi=142.13
274AC CJK UNIFIED IDEOGRAPH-#274AC, IRGKangXi=1100.321, RSKangXi=142.13
274AD CJK UNIFIED IDEOGRAPH-#274AD, IRGKangXi=1100.321, RSKangXi=142.13
274AE CJK UNIFIED IDEOGRAPH-#274AE, IRGKangXi=1100.321, RSKangXi=142.13
274AF CJK UNIFIED IDEOGRAPH-#274AF, IRGKangXi=1100.321, RSKangXi=142.13
274B0 CJK UNIFIED IDEOGRAPH-#274B0, IRGKangXi=1100.321, RSKangXi=142.13
274B1 CJK UNIFIED IDEOGRAPH-#274B1, IRGKangXi=1100.321, RSKangXi=142.13
274B2 CJK UNIFIED IDEOGRAPH-#274B2, IRGKangXi=1100.321, RSKangXi=142.13
274B3 CJK UNIFIED IDEOGRAPH-#274B3, IRGKangXi=1100.321, RSKangXi=142.13
274B4 CJK UNIFIED IDEOGRAPH-#274B4, IRGKangXi=1100.321, RSKangXi=142.13
274B5 CJK UNIFIED IDEOGRAPH-#274B5, IRGKangXi=1100.321, RSKangXi=142.13
274B6 CJK UNIFIED IDEOGRAPH-#274B6, IRGKangXi=1100.321, RSKangXi=142.13
274B7 CJK UNIFIED IDEOGRAPH-#274B7, IRGKangXi=1100.321, RSKangXi=142.13
274B8 CJK UNIFIED IDEOGRAPH-#274B8, IRGKangXi=1100.321, RSKangXi=142.13
274B9 CJK UNIFIED IDEOGRAPH-#274B9, IRGKangXi=1100.321, RSKangXi=142.13
274BA CJK UNIFIED IDEOGRAPH-#274BA, IRGKangXi=1100.321, RSKangXi=142.13
274BB CJK UNIFIED IDEOGRAPH-#274BB, IRGKangXi=1100.321, RSKangXi=142.13
274BC CJK UNIFIED IDEOGRAPH-#274BC, IRGKangXi=1100.321, RSKangXi=142.13
274BD CJK UNIFIED IDEOGRAPH-#274BD, IRGKangXi=1100.321, RSKangXi=142.13
274BE CJK UNIFIED IDEOGRAPH-#274BE, IRGKangXi=1100.321, RSKangXi=142.13
274BF CJK UNIFIED IDEOGRAPH-#274BF, IRGKangXi=1100.321, RSKangXi=142.13
274C0 CJK UNIFIED IDEOGRAPH-#274C0, IRGKangXi=1100.321, RSKangXi=142.13
274C1 CJK UNIFIED IDEOGRAPH-#274C1, IRGKangXi=1100.321, RSKangXi=142.13
274C2 CJK UNIFIED IDEOGRAPH-#274C2, IRGKangXi=1100.321, RSKangXi=142.13
274C3 CJK UNIFIED IDEOGRAPH-#274C3, IRGKangXi=1100.321, RSKangXi=142.13
274C4 CJK UNIFIED IDEOGRAPH-#274C4, IRGKangXi=1100.321, RSKangXi=142.13
274C5 CJK UNIFIED IDEOGRAPH-#274C5, IRGKangXi=1100.321, RSKangXi=142.13
274C6 CJK UNIFIED IDEOGRAPH-#274C6, IRGKangXi=1100.321, RSKangXi=142.13
274C7 CJK UNIFIED IDEOGRAPH-#274C7, IRGKangXi=1100.321, RSKangXi=142.13
274C8 CJK UNIFIED IDEOGRAPH-#274C8, IRGKangXi=1100.321, RSKangXi=142.13
274C9 CJK UNIFIED IDEOGRAPH-#274C9, IRGKangXi=1100.340, RSKangXi=142.14
274CA CJK UNIFIED IDEOGRAPH-#274CA, IRGKangXi=1100.370, RSKangXi=142.14
274CB CJK UNIFIED IDEOGRAPH-#274CB, IRGKangXi=1100.380, RSKangXi=142.14
274CC CJK UNIFIED IDEOGRAPH-#274CC, IRGKangXi=1100.400, RSKangXi=142.14
274CD CJK UNIFIED IDEOGRAPH-#274CD, IRGKangXi=1100.420, RSKangXi=142.14, Def{pearl oyster}
274CE CJK UNIFIED IDEOGRAPH-#274CE, IRGKangXi=1100.450, RSKangXi=142.14
274CF CJK UNIFIED IDEOGRAPH-#274CF, IRGKangXi=1100.470, RSKangXi=142.14
274D0 CJK UNIFIED IDEOGRAPH-#274D0, IRGKangXi=1100.510, RSKangXi=142.14
274D1 CJK UNIFIED IDEOGRAPH-#274D1, IRGKangXi=1100.520, RSKangXi=142.14
274D2 CJK UNIFIED IDEOGRAPH-#274D2, IRGKangXi=1101.030, RSKangXi=142.14
274D3 CJK UNIFIED IDEOGRAPH-#274D3, IRGKangXi=1101.050, RSKangXi=142.14
274D4 CJK UNIFIED IDEOGRAPH-#274D4, IRGKangXi=1101.060, RSKangXi=142.14
274D5 CJK UNIFIED IDEOGRAPH-#274D5, IRGKangXi=1101.070, RSKangXi=142.14
274D6 CJK UNIFIED IDEOGRAPH-#274D6, IRGKangXi=1101.080, RSKangXi=142.14
274D7 CJK UNIFIED IDEOGRAPH-#274D7, IRGKangXi=1101.090, RSKangXi=142.14
274D8 CJK UNIFIED IDEOGRAPH-#274D8, IRGKangXi=1101.100, RSKangXi=142.14
274D9 CJK UNIFIED IDEOGRAPH-#274D9, IRGKangXi=1101.110, RSKangXi=142.14
274DA CJK UNIFIED IDEOGRAPH-#274DA, IRGKangXi=1101.120, RSKangXi=142.14
274DB CJK UNIFIED IDEOGRAPH-#274DB, IRGKangXi=1101.130, RSKangXi=142.14
274DC CJK UNIFIED IDEOGRAPH-#274DC, IRGKangXi=1101.140, RSKangXi=142.14
274DD CJK UNIFIED IDEOGRAPH-#274DD, IRGKangXi=1101.150, RSKangXi=142.14
274DE CJK UNIFIED IDEOGRAPH-#274DE, IRGKangXi=1101.160, RSKangXi=142.14
274DF CJK UNIFIED IDEOGRAPH-#274DF, IRGKangXi=1101.170, RSKangXi=142.14
274E0 CJK UNIFIED IDEOGRAPH-#274E0, IRGKangXi=1101.181, RSKangXi=142.14
274E1 CJK UNIFIED IDEOGRAPH-#274E1, IRGKangXi=1101.181, RSKangXi=142.14
274E2 CJK UNIFIED IDEOGRAPH-#274E2, IRGKangXi=1101.181, RSKangXi=142.14
274E3 CJK UNIFIED IDEOGRAPH-#274E3, IRGKangXi=1101.181, RSKangXi=142.14
274E4 CJK UNIFIED IDEOGRAPH-#274E4, IRGKangXi=1101.181, RSKangXi=142.14
274E5 CJK UNIFIED IDEOGRAPH-#274E5, IRGKangXi=1101.181, RSKangXi=142.14
274E6 CJK UNIFIED IDEOGRAPH-#274E6, IRGKangXi=1101.181, RSKangXi=142.14
274E7 CJK UNIFIED IDEOGRAPH-#274E7, IRGKangXi=1101.181, RSKangXi=142.14
274E8 CJK UNIFIED IDEOGRAPH-#274E8, IRGKangXi=1101.181, RSKangXi=142.14
274E9 CJK UNIFIED IDEOGRAPH-#274E9, IRGKangXi=1101.181, RSKangXi=142.14
274EA CJK UNIFIED IDEOGRAPH-#274EA, IRGKangXi=1101.181, RSKangXi=142.14
274EB CJK UNIFIED IDEOGRAPH-#274EB, IRGKangXi=1101.181, RSKangXi=142.14
274EC CJK UNIFIED IDEOGRAPH-#274EC, IRGKangXi=1101.181, RSKangXi=142.14
274ED CJK UNIFIED IDEOGRAPH-#274ED, IRGKangXi=1101.181, RSKangXi=142.14
274EE CJK UNIFIED IDEOGRAPH-#274EE, IRGKangXi=1101.181, RSKangXi=142.14
274EF CJK UNIFIED IDEOGRAPH-#274EF, IRGKangXi=1101.181, RSKangXi=142.14
274F0 CJK UNIFIED IDEOGRAPH-#274F0, IRGKangXi=1101.181, RSKangXi=142.14
274F1 CJK UNIFIED IDEOGRAPH-#274F1, IRGKangXi=1101.200, RSKangXi=142.15
274F2 CJK UNIFIED IDEOGRAPH-#274F2, IRGKangXi=1101.210, RSKangXi=142.15
274F3 CJK UNIFIED IDEOGRAPH-#274F3, IRGKangXi=1101.220, RSKangXi=142.15
274F4 CJK UNIFIED IDEOGRAPH-#274F4, IRGKangXi=1101.260, RSKangXi=142.15
274F5 CJK UNIFIED IDEOGRAPH-#274F5, IRGKangXi=1101.270, RSKangXi=142.15
274F6 CJK UNIFIED IDEOGRAPH-#274F6, IRGKangXi=1101.280, RSKangXi=142.15
274F7 CJK UNIFIED IDEOGRAPH-#274F7, IRGKangXi=1101.320, RSKangXi=142.15
274F8 CJK UNIFIED IDEOGRAPH-#274F8, IRGKangXi=1101.330, RSKangXi=142.15
274F9 CJK UNIFIED IDEOGRAPH-#274F9, IRGKangXi=1101.340, RSKangXi=142.15
274FA CJK UNIFIED IDEOGRAPH-#274FA, IRGKangXi=1101.350, RSKangXi=142.15
274FB CJK UNIFIED IDEOGRAPH-#274FB, IRGKangXi=1101.360, RSKangXi=142.15
274FC CJK UNIFIED IDEOGRAPH-#274FC, IRGKangXi=1101.390, RSKangXi=142.15
274FD CJK UNIFIED IDEOGRAPH-#274FD, IRGKangXi=1102.010, RSKangXi=142.15
274FE CJK UNIFIED IDEOGRAPH-#274FE, IRGKangXi=1102.030, RSKangXi=142.15
274FF CJK UNIFIED IDEOGRAPH-#274FF, IRGKangXi=1102.040, RSKangXi=142.15
27500 CJK UNIFIED IDEOGRAPH-#27500, IRGKangXi=1102.050, RSKangXi=142.15
27501 CJK UNIFIED IDEOGRAPH-#27501, IRGKangXi=1102.060, RSKangXi=142.15
27502 CJK UNIFIED IDEOGRAPH-#27502, IRGKangXi=1102.070, RSKangXi=142.15
27503 CJK UNIFIED IDEOGRAPH-#27503, IRGKangXi=1102.080, RSKangXi=142.15
27504 CJK UNIFIED IDEOGRAPH-#27504, IRGKangXi=1102.090, RSKangXi=142.15
27505 CJK UNIFIED IDEOGRAPH-#27505, IRGKangXi=1102.100, RSKangXi=142.15
27506 CJK UNIFIED IDEOGRAPH-#27506, IRGKangXi=1102.110, RSKangXi=142.15
27507 CJK UNIFIED IDEOGRAPH-#27507, IRGKangXi=1102.120, RSKangXi=142.15
27508 CJK UNIFIED IDEOGRAPH-#27508, IRGKangXi=1102.130, RSKangXi=142.15
27509 CJK UNIFIED IDEOGRAPH-#27509, IRGKangXi=1102.131, RSKangXi=142.15
2750A CJK UNIFIED IDEOGRAPH-#2750A, IRGKangXi=1102.131, RSKangXi=142.15
2750B CJK UNIFIED IDEOGRAPH-#2750B, IRGKangXi=1102.131, RSKangXi=142.15
2750C CJK UNIFIED IDEOGRAPH-#2750C, IRGKangXi=1102.131, RSKangXi=142.15
2750D CJK UNIFIED IDEOGRAPH-#2750D, IRGKangXi=1102.131, RSKangXi=142.15
2750E CJK UNIFIED IDEOGRAPH-#2750E, IRGKangXi=1102.131, RSKangXi=142.15
2750F CJK UNIFIED IDEOGRAPH-#2750F, IRGKangXi=1102.131, RSKangXi=142.15
27510 CJK UNIFIED IDEOGRAPH-#27510, IRGKangXi=1102.131, RSKangXi=142.15
27511 CJK UNIFIED IDEOGRAPH-#27511, IRGKangXi=1102.131, RSKangXi=142.15
27512 CJK UNIFIED IDEOGRAPH-#27512, IRGKangXi=1102.131, RSKangXi=142.15
27513 CJK UNIFIED IDEOGRAPH-#27513, IRGKangXi=1102.131, RSKangXi=142.15
27514 CJK UNIFIED IDEOGRAPH-#27514, IRGKangXi=1102.131, RSKangXi=142.15
27515 CJK UNIFIED IDEOGRAPH-#27515, IRGKangXi=1102.131, RSKangXi=142.15
27516 CJK UNIFIED IDEOGRAPH-#27516, IRGKangXi=1102.131, RSKangXi=142.15
27517 CJK UNIFIED IDEOGRAPH-#27517, IRGKangXi=1102.131, RSKangXi=142.15
27518 CJK UNIFIED IDEOGRAPH-#27518, IRGKangXi=1102.131, RSKangXi=142.15
27519 CJK UNIFIED IDEOGRAPH-#27519, IRGKangXi=1102.131, RSKangXi=142.15
2751A CJK UNIFIED IDEOGRAPH-#2751A, IRGKangXi=1102.131, RSKangXi=142.15
2751B CJK UNIFIED IDEOGRAPH-#2751B, IRGKangXi=1102.131, RSKangXi=142.15
2751C CJK UNIFIED IDEOGRAPH-#2751C, IRGKangXi=1102.131, RSKangXi=142.15
2751D CJK UNIFIED IDEOGRAPH-#2751D, IRGKangXi=1102.150, RSKangXi=142.16
2751E CJK UNIFIED IDEOGRAPH-#2751E, IRGKangXi=1102.160, RSKangXi=142.16
2751F CJK UNIFIED IDEOGRAPH-#2751F, IRGKangXi=1102.190, RSKangXi=142.16
27520 CJK UNIFIED IDEOGRAPH-#27520, IRGKangXi=1102.200, RSKangXi=142.16
27521 CJK UNIFIED IDEOGRAPH-#27521, IRGKangXi=1102.220, RSKangXi=142.16
27522 CJK UNIFIED IDEOGRAPH-#27522, IRGKangXi=1102.240, RSKangXi=142.16
27523 CJK UNIFIED IDEOGRAPH-#27523, IRGKangXi=1102.250, RSKangXi=142.16
27524 CJK UNIFIED IDEOGRAPH-#27524, IRGKangXi=1102.260, RSKangXi=142.16
27525 CJK UNIFIED IDEOGRAPH-#27525, IRGKangXi=1102.280, RSKangXi=142.16
27526 CJK UNIFIED IDEOGRAPH-#27526, IRGKangXi=1102.290, RSKangXi=142.16
27527 CJK UNIFIED IDEOGRAPH-#27527, IRGKangXi=1102.320, RSKangXi=142.16
27528 CJK UNIFIED IDEOGRAPH-#27528, IRGKangXi=1102.340, RSKangXi=142.16
27529 CJK UNIFIED IDEOGRAPH-#27529, IRGKangXi=1102.350, RSKangXi=142.16
2752A CJK UNIFIED IDEOGRAPH-#2752A, IRGKangXi=1102.360, RSKangXi=142.16
2752B CJK UNIFIED IDEOGRAPH-#2752B, IRGKangXi=1102.370, RSKangXi=142.16
2752C CJK UNIFIED IDEOGRAPH-#2752C, IRGKangXi=1102.380, RSKangXi=142.16
2752D CJK UNIFIED IDEOGRAPH-#2752D, IRGKangXi=1102.390, RSKangXi=142.16
2752E CJK UNIFIED IDEOGRAPH-#2752E, IRGKangXi=1102.410, RSKangXi=142.16
2752F CJK UNIFIED IDEOGRAPH-#2752F, IRGKangXi=1102.420, RSKangXi=142.16
27530 CJK UNIFIED IDEOGRAPH-#27530, IRGKangXi=1102.430, RSKangXi=142.16
27531 CJK UNIFIED IDEOGRAPH-#27531, IRGKangXi=1102.440, RSKangXi=142.16
27532 CJK UNIFIED IDEOGRAPH-#27532, IRGKangXi=1102.450, RSKangXi=142.16
27533 CJK UNIFIED IDEOGRAPH-#27533, IRGKangXi=1102.460, RSKangXi=142.16
27534 CJK UNIFIED IDEOGRAPH-#27534, IRGKangXi=1102.480, RSKangXi=142.16
27535 CJK UNIFIED IDEOGRAPH-#27535, IRGKangXi=1102.490, RSKangXi=142.16
27536 CJK UNIFIED IDEOGRAPH-#27536, IRGKangXi=1102.510, RSKangXi=142.16
27537 CJK UNIFIED IDEOGRAPH-#27537, IRGKangXi=1102.520, RSKangXi=142.16
27538 CJK UNIFIED IDEOGRAPH-#27538, IRGKangXi=1102.521, RSKangXi=142.16
27539 CJK UNIFIED IDEOGRAPH-#27539, IRGKangXi=1102.521, RSKangXi=142.16
2753A CJK UNIFIED IDEOGRAPH-#2753A, IRGKangXi=1102.521, RSKangXi=142.16
2753B CJK UNIFIED IDEOGRAPH-#2753B, IRGKangXi=1102.521, RSKangXi=142.16
2753C CJK UNIFIED IDEOGRAPH-#2753C, IRGKangXi=1102.521, RSKangXi=142.16
2753D CJK UNIFIED IDEOGRAPH-#2753D, IRGKangXi=1102.521, RSKangXi=142.16
2753E CJK UNIFIED IDEOGRAPH-#2753E, IRGKangXi=1102.521, RSKangXi=142.16
2753F CJK UNIFIED IDEOGRAPH-#2753F, IRGKangXi=1102.521, RSKangXi=142.16
27540 CJK UNIFIED IDEOGRAPH-#27540, IRGKangXi=1102.521, RSKangXi=142.16
27541 CJK UNIFIED IDEOGRAPH-#27541, IRGKangXi=1102.521, RSKangXi=142.16
27542 CJK UNIFIED IDEOGRAPH-#27542, IRGKangXi=1102.521, RSKangXi=142.16
27543 CJK UNIFIED IDEOGRAPH-#27543, IRGKangXi=1103.050, RSKangXi=142.17
27544 CJK UNIFIED IDEOGRAPH-#27544, IRGKangXi=1103.060, RSKangXi=142.17
27545 CJK UNIFIED IDEOGRAPH-#27545, IRGKangXi=1103.070, RSKangXi=142.17
27546 CJK UNIFIED IDEOGRAPH-#27546, IRGKangXi=1103.080, RSKangXi=142.17
27547 CJK UNIFIED IDEOGRAPH-#27547, IRGKangXi=1103.100, RSKangXi=142.17
27548 CJK UNIFIED IDEOGRAPH-#27548, IRGKangXi=1103.130, RSKangXi=142.17
27549 CJK UNIFIED IDEOGRAPH-#27549, IRGKangXi=1103.140, RSKangXi=142.17
2754A CJK UNIFIED IDEOGRAPH-#2754A, IRGKangXi=1103.150, RSKangXi=142.17
2754B CJK UNIFIED IDEOGRAPH-#2754B, IRGKangXi=1103.160, RSKangXi=142.17
2754C CJK UNIFIED IDEOGRAPH-#2754C, IRGKangXi=1103.170, RSKangXi=142.17
2754D CJK UNIFIED IDEOGRAPH-#2754D, IRGKangXi=1103.190, RSKangXi=142.17
2754E CJK UNIFIED IDEOGRAPH-#2754E, IRGKangXi=1103.200, RSKangXi=142.17
2754F CJK UNIFIED IDEOGRAPH-#2754F, IRGKangXi=1103.210, RSKangXi=142.17
27550 CJK UNIFIED IDEOGRAPH-#27550, IRGKangXi=1103.220, RSKangXi=142.17
27551 CJK UNIFIED IDEOGRAPH-#27551, IRGKangXi=1103.230, RSKangXi=142.17
27552 CJK UNIFIED IDEOGRAPH-#27552, IRGKangXi=1103.240, RSKangXi=142.17
27553 CJK UNIFIED IDEOGRAPH-#27553, IRGKangXi=1103.250, RSKangXi=142.18
27554 CJK UNIFIED IDEOGRAPH-#27554, IRGKangXi=1103.270, RSKangXi=142.17
27555 CJK UNIFIED IDEOGRAPH-#27555, IRGKangXi=1103.290, RSKangXi=142.17
27556 CJK UNIFIED IDEOGRAPH-#27556, IRGKangXi=1103.291, RSKangXi=142.17
27557 CJK UNIFIED IDEOGRAPH-#27557, IRGKangXi=1103.291, RSKangXi=142.17
27558 CJK UNIFIED IDEOGRAPH-#27558, IRGKangXi=1103.291, RSKangXi=142.17
27559 CJK UNIFIED IDEOGRAPH-#27559, IRGKangXi=1103.291, RSKangXi=142.17
2755A CJK UNIFIED IDEOGRAPH-#2755A, IRGKangXi=1103.291, RSKangXi=142.17
2755B CJK UNIFIED IDEOGRAPH-#2755B, IRGKangXi=1103.310, RSKangXi=142.18
2755C CJK UNIFIED IDEOGRAPH-#2755C, IRGKangXi=1103.320, RSKangXi=142.18
2755D CJK UNIFIED IDEOGRAPH-#2755D, IRGKangXi=1104.010, RSKangXi=142.18
2755E CJK UNIFIED IDEOGRAPH-#2755E, IRGKangXi=1104.040, RSKangXi=142.18
2755F CJK UNIFIED IDEOGRAPH-#2755F, IRGKangXi=1104.070, RSKangXi=142.18
27560 CJK UNIFIED IDEOGRAPH-#27560, IRGKangXi=1104.080, RSKangXi=142.18
27561 CJK UNIFIED IDEOGRAPH-#27561, IRGKangXi=1104.090, RSKangXi=142.18
27562 CJK UNIFIED IDEOGRAPH-#27562, IRGKangXi=1104.100, RSKangXi=142.18
27563 CJK UNIFIED IDEOGRAPH-#27563, IRGKangXi=1104.120, RSKangXi=142.18
27564 CJK UNIFIED IDEOGRAPH-#27564, IRGKangXi=1104.130, RSKangXi=142.18
27565 CJK UNIFIED IDEOGRAPH-#27565, IRGKangXi=1104.140, RSKangXi=142.18
27566 CJK UNIFIED IDEOGRAPH-#27566, IRGKangXi=1104.150, RSKangXi=142.18
27567 CJK UNIFIED IDEOGRAPH-#27567, IRGKangXi=1104.160, RSKangXi=142.18
27568 CJK UNIFIED IDEOGRAPH-#27568, IRGKangXi=1104.170, RSKangXi=142.18
27569 CJK UNIFIED IDEOGRAPH-#27569, IRGKangXi=1104.180, RSKangXi=142.18
2756A CJK UNIFIED IDEOGRAPH-#2756A, IRGKangXi=1104.181, RSKangXi=142.18
2756B CJK UNIFIED IDEOGRAPH-#2756B, IRGKangXi=1104.181, RSKangXi=142.18
2756C CJK UNIFIED IDEOGRAPH-#2756C, IRGKangXi=1104.181, RSKangXi=142.18
2756D CJK UNIFIED IDEOGRAPH-#2756D, IRGKangXi=1104.181, RSKangXi=142.18
2756E CJK UNIFIED IDEOGRAPH-#2756E, IRGKangXi=1104.190, RSKangXi=142.19
2756F CJK UNIFIED IDEOGRAPH-#2756F, IRGKangXi=1104.200, RSKangXi=142.19
27570 CJK UNIFIED IDEOGRAPH-#27570, IRGKangXi=1104.210, RSKangXi=142.19
27571 CJK UNIFIED IDEOGRAPH-#27571, IRGKangXi=1104.220, RSKangXi=142.19
27572 CJK UNIFIED IDEOGRAPH-#27572, IRGKangXi=1104.230, RSKangXi=142.19
27573 CJK UNIFIED IDEOGRAPH-#27573, IRGKangXi=1104.240, RSKangXi=142.19
27574 CJK UNIFIED IDEOGRAPH-#27574, IRGKangXi=1104.260, RSKangXi=142.19, Def{(Cant.) a pimple, an insect bite}
27575 CJK UNIFIED IDEOGRAPH-#27575, IRGKangXi=1104.270, RSKangXi=142.19
27576 CJK UNIFIED IDEOGRAPH-#27576, IRGKangXi=1104.290, RSKangXi=142.19
27577 CJK UNIFIED IDEOGRAPH-#27577, IRGKangXi=1104.300, RSKangXi=142.19
27578 CJK UNIFIED IDEOGRAPH-#27578, IRGKangXi=1104.310, RSKangXi=142.19
27579 CJK UNIFIED IDEOGRAPH-#27579, IRGKangXi=1104.320, RSKangXi=142.19
2757A CJK UNIFIED IDEOGRAPH-#2757A, IRGKangXi=1104.330, RSKangXi=142.19
2757B CJK UNIFIED IDEOGRAPH-#2757B, IRGKangXi=1104.331, RSKangXi=142.19
2757C CJK UNIFIED IDEOGRAPH-#2757C, IRGKangXi=1104.331, RSKangXi=142.19
2757D CJK UNIFIED IDEOGRAPH-#2757D, IRGKangXi=1104.340, RSKangXi=142.20
2757E CJK UNIFIED IDEOGRAPH-#2757E, IRGKangXi=1104.350, RSKangXi=142.20
2757F CJK UNIFIED IDEOGRAPH-#2757F, IRGKangXi=1104.360, RSKangXi=142.20
27580 CJK UNIFIED IDEOGRAPH-#27580, IRGKangXi=1104.380, RSKangXi=142.20
27581 CJK UNIFIED IDEOGRAPH-#27581, IRGKangXi=1104.390, RSKangXi=142.20
27582 CJK UNIFIED IDEOGRAPH-#27582, IRGKangXi=1104.400, RSKangXi=142.20
27583 CJK UNIFIED IDEOGRAPH-#27583, IRGKangXi=1104.401, RSKangXi=142.20
27584 CJK UNIFIED IDEOGRAPH-#27584, IRGKangXi=1105.010, RSKangXi=142.21
27585 CJK UNIFIED IDEOGRAPH-#27585, IRGKangXi=1105.020, RSKangXi=142.21
27586 CJK UNIFIED IDEOGRAPH-#27586, IRGKangXi=1105.030, RSKangXi=142.21
27587 CJK UNIFIED IDEOGRAPH-#27587, IRGKangXi=1105.050, RSKangXi=142.21
27588 CJK UNIFIED IDEOGRAPH-#27588, IRGKangXi=1105.060, RSKangXi=142.21
27589 CJK UNIFIED IDEOGRAPH-#27589, IRGKangXi=1105.070, RSKangXi=142.21
2758A CJK UNIFIED IDEOGRAPH-#2758A, IRGKangXi=1105.080, RSKangXi=142.20
2758B CJK UNIFIED IDEOGRAPH-#2758B, IRGKangXi=1105.090, RSKangXi=142.21
2758C CJK UNIFIED IDEOGRAPH-#2758C, IRGKangXi=1105.100, RSKangXi=142.21
2758D CJK UNIFIED IDEOGRAPH-#2758D, IRGKangXi=1105.110, RSKangXi=142.21
2758E CJK UNIFIED IDEOGRAPH-#2758E, IRGKangXi=1105.111, RSKangXi=142.21
2758F CJK UNIFIED IDEOGRAPH-#2758F, IRGKangXi=1105.111, RSKangXi=142.21
27590 CJK UNIFIED IDEOGRAPH-#27590, IRGKangXi=1105.111, RSKangXi=142.21
27591 CJK UNIFIED IDEOGRAPH-#27591, IRGKangXi=1105.120, RSKangXi=142.22
27592 CJK UNIFIED IDEOGRAPH-#27592, IRGKangXi=1105.130, RSKangXi=142.22
27593 CJK UNIFIED IDEOGRAPH-#27593, IRGKangXi=1105.150, RSKangXi=142.22
27594 CJK UNIFIED IDEOGRAPH-#27594, IRGKangXi=1105.170, RSKangXi=142.22
27595 CJK UNIFIED IDEOGRAPH-#27595, IRGKangXi=1105.180, RSKangXi=142.22
27596 CJK UNIFIED IDEOGRAPH-#27596, IRGKangXi=1105.190, RSKangXi=142.22
27597 CJK UNIFIED IDEOGRAPH-#27597, IRGKangXi=1105.200, RSKangXi=142.22
27598 CJK UNIFIED IDEOGRAPH-#27598, IRGKangXi=1105.210, RSKangXi=142.23
27599 CJK UNIFIED IDEOGRAPH-#27599, IRGKangXi=1105.220, RSKangXi=142.23
2759A CJK UNIFIED IDEOGRAPH-#2759A, IRGKangXi=1105.230, RSKangXi=142.23
2759B CJK UNIFIED IDEOGRAPH-#2759B, IRGKangXi=1105.240, RSKangXi=142.23
2759C CJK UNIFIED IDEOGRAPH-#2759C, IRGKangXi=1105.250, RSKangXi=142.24
2759D CJK UNIFIED IDEOGRAPH-#2759D, IRGKangXi=1105.260, RSKangXi=142.24
2759E CJK UNIFIED IDEOGRAPH-#2759E, IRGKangXi=1105.270, RSKangXi=142.24
2759F CJK UNIFIED IDEOGRAPH-#2759F, IRGKangXi=1105.271, RSKangXi=142.24
275A0 CJK UNIFIED IDEOGRAPH-#275A0, IRGKangXi=1105.271, RSKangXi=196.19
275A1 CJK UNIFIED IDEOGRAPH-#275A1, IRGKangXi=1105.271, RSKangXi=142.24
275A2 CJK UNIFIED IDEOGRAPH-#275A2, IRGKangXi=1105.280, RSKangXi=142.25
275A3 CJK UNIFIED IDEOGRAPH-#275A3, IRGKangXi=1105.290, RSKangXi=142.25
275A4 CJK UNIFIED IDEOGRAPH-#275A4, IRGKangXi=1105.300, RSKangXi=142.26
275A5 CJK UNIFIED IDEOGRAPH-#275A5, IRGKangXi=1105.301, RSKangXi=142.26
275A6 CJK UNIFIED IDEOGRAPH-#275A6, IRGKangXi=1105.301, RSKangXi=142.26
275A7 CJK UNIFIED IDEOGRAPH-#275A7, IRGKangXi=1107.020, RSKangXi=142.2
275A8 CJK UNIFIED IDEOGRAPH-#275A8, IRGKangXi=1107.030, RSKangXi=143.2
275A9 CJK UNIFIED IDEOGRAPH-#275A9, IRGKangXi=1107.040, RSKangXi=143.2
275AA CJK UNIFIED IDEOGRAPH-#275AA, IRGKangXi=1107.070, RSKangXi=143.3
275AB CJK UNIFIED IDEOGRAPH-#275AB, IRGKangXi=1107.100, RSKangXi=143.4
275AC CJK UNIFIED IDEOGRAPH-#275AC, IRGKangXi=1107.120, RSKangXi=143.4
275AD CJK UNIFIED IDEOGRAPH-#275AD, IRGKangXi=1107.130, RSKangXi=143.4
275AE CJK UNIFIED IDEOGRAPH-#275AE, IRGKangXi=1107.131, RSKangXi=143.4
275AF CJK UNIFIED IDEOGRAPH-#275AF, IRGKangXi=1107.131, RSKangXi=143.4
275B0 CJK UNIFIED IDEOGRAPH-#275B0, IRGKangXi=1107.151, RSKangXi=143.5
275B1 CJK UNIFIED IDEOGRAPH-#275B1, IRGKangXi=1107.151, RSKangXi=143.5
275B2 CJK UNIFIED IDEOGRAPH-#275B2, IRGKangXi=1107.151, RSKangXi=143.5
275B3 CJK UNIFIED IDEOGRAPH-#275B3, IRGKangXi=1107.200, RSKangXi=143.6
275B4 CJK UNIFIED IDEOGRAPH-#275B4, IRGKangXi=1107.201, RSKangXi=143.6
275B5 CJK UNIFIED IDEOGRAPH-#275B5, IRGKangXi=1107.210, RSKangXi=143.7
275B6 CJK UNIFIED IDEOGRAPH-#275B6, IRGKangXi=1107.230, RSKangXi=143.7
275B7 CJK UNIFIED IDEOGRAPH-#275B7, IRGKangXi=1107.240, RSKangXi=143.7
275B8 CJK UNIFIED IDEOGRAPH-#275B8, IRGKangXi=1107.250, RSKangXi=143.7
275B9 CJK UNIFIED IDEOGRAPH-#275B9, IRGKangXi=1107.260, RSKangXi=143.7
275BA CJK UNIFIED IDEOGRAPH-#275BA, IRGKangXi=1107.270, RSKangXi=143.8
275BB CJK UNIFIED IDEOGRAPH-#275BB, IRGKangXi=1107.280, RSKangXi=143.8
275BC CJK UNIFIED IDEOGRAPH-#275BC, IRGKangXi=1107.300, RSKangXi=143.8
275BD CJK UNIFIED IDEOGRAPH-#275BD, IRGKangXi=1107.310, RSKangXi=143.8
275BE CJK UNIFIED IDEOGRAPH-#275BE, IRGKangXi=1108.010, RSKangXi=143.8
275BF CJK UNIFIED IDEOGRAPH-#275BF, IRGKangXi=1108.011, RSKangXi=143.8
275C0 CJK UNIFIED IDEOGRAPH-#275C0, IRGKangXi=1108.020, RSKangXi=143.9
275C1 CJK UNIFIED IDEOGRAPH-#275C1, IRGKangXi=1108.040, RSKangXi=143.9
275C2 CJK UNIFIED IDEOGRAPH-#275C2, IRGKangXi=1108.050, RSKangXi=143.9
275C3 CJK UNIFIED IDEOGRAPH-#275C3, IRGKangXi=1108.060, RSKangXi=143.9
275C4 CJK UNIFIED IDEOGRAPH-#275C4, IRGKangXi=1108.070, RSKangXi=143.8
275C5 CJK UNIFIED IDEOGRAPH-#275C5, IRGKangXi=1108.071, RSKangXi=143.9
275C6 CJK UNIFIED IDEOGRAPH-#275C6, IRGKangXi=1108.080, RSKangXi=143.10
275C7 CJK UNIFIED IDEOGRAPH-#275C7, IRGKangXi=1108.090, RSKangXi=143.10
275C8 CJK UNIFIED IDEOGRAPH-#275C8, IRGKangXi=1108.100, RSKangXi=143.10
275C9 CJK UNIFIED IDEOGRAPH-#275C9, IRGKangXi=1108.110, RSKangXi=143.10
275CA CJK UNIFIED IDEOGRAPH-#275CA, IRGKangXi=1108.120, RSKangXi=143.10
275CB CJK UNIFIED IDEOGRAPH-#275CB, IRGKangXi=1108.130, RSKangXi=143.11
275CC CJK UNIFIED IDEOGRAPH-#275CC, IRGKangXi=1108.140, RSKangXi=143.11
275CD CJK UNIFIED IDEOGRAPH-#275CD, IRGKangXi=1108.141, RSKangXi=143.11
275CE CJK UNIFIED IDEOGRAPH-#275CE, IRGKangXi=1108.150, RSKangXi=143.12
275CF CJK UNIFIED IDEOGRAPH-#275CF, IRGKangXi=1108.160, RSKangXi=143.12
275D0 CJK UNIFIED IDEOGRAPH-#275D0, IRGKangXi=1108.170, RSKangXi=143.12
275D1 CJK UNIFIED IDEOGRAPH-#275D1, IRGKangXi=1108.180, RSKangXi=143.12
275D2 CJK UNIFIED IDEOGRAPH-#275D2, IRGKangXi=1108.190, RSKangXi=143.12
275D3 CJK UNIFIED IDEOGRAPH-#275D3, IRGKangXi=1108.191, RSKangXi=143.12
275D4 CJK UNIFIED IDEOGRAPH-#275D4, IRGKangXi=1108.200, RSKangXi=143.13
275D5 CJK UNIFIED IDEOGRAPH-#275D5, IRGKangXi=1108.210, RSKangXi=143.13
275D6 CJK UNIFIED IDEOGRAPH-#275D6, IRGKangXi=1108.220, RSKangXi=143.14
275D7 CJK UNIFIED IDEOGRAPH-#275D7, IRGKangXi=1108.230, RSKangXi=143.14, Def{same as 衄 U+8844, a nosebleed}
275D8 CJK UNIFIED IDEOGRAPH-#275D8, IRGKangXi=1108.240, RSKangXi=143.15
275D9 CJK UNIFIED IDEOGRAPH-#275D9, IRGKangXi=1108.260, RSKangXi=143.16
275DA CJK UNIFIED IDEOGRAPH-#275DA, IRGKangXi=1108.270, RSKangXi=143.16
275DB CJK UNIFIED IDEOGRAPH-#275DB, IRGKangXi=1108.290, RSKangXi=143.17
275DC CJK UNIFIED IDEOGRAPH-#275DC, IRGKangXi=1108.300, RSKangXi=143.24
275DD CJK UNIFIED IDEOGRAPH-#275DD, IRGKangXi=1108.320, RSKangXi=144.2
275DE CJK UNIFIED IDEOGRAPH-#275DE, IRGKangXi=1108.330, RSKangXi=144.2
275DF CJK UNIFIED IDEOGRAPH-#275DF, IRGKangXi=1108.340, RSKangXi=144.2
275E0 CJK UNIFIED IDEOGRAPH-#275E0, IRGKangXi=1108.341, RSKangXi=144.2
275E1 CJK UNIFIED IDEOGRAPH-#275E1, IRGKangXi=1109.020, RSKangXi=144.3
275E2 CJK UNIFIED IDEOGRAPH-#275E2, IRGKangXi=1109.030, RSKangXi=144.3
275E3 CJK UNIFIED IDEOGRAPH-#275E3, IRGKangXi=1109.040, RSKangXi=144.3
275E4 CJK UNIFIED IDEOGRAPH-#275E4, IRGKangXi=1109.041, RSKangXi=144.3
275E5 CJK UNIFIED IDEOGRAPH-#275E5, IRGKangXi=1109.041, RSKangXi=144.3
275E6 CJK UNIFIED IDEOGRAPH-#275E6, IRGKangXi=1109.070, RSKangXi=144.4
275E7 CJK UNIFIED IDEOGRAPH-#275E7, IRGKangXi=1109.080, RSKangXi=144.4
275E8 CJK UNIFIED IDEOGRAPH-#275E8, IRGKangXi=1109.090, RSKangXi=144.4
275E9 CJK UNIFIED IDEOGRAPH-#275E9, IRGKangXi=1109.091, RSKangXi=144.4
275EA CJK UNIFIED IDEOGRAPH-#275EA, IRGKangXi=1109.130, RSKangXi=144.5
275EB CJK UNIFIED IDEOGRAPH-#275EB, IRGKangXi=1109.160, RSKangXi=144.6
275EC CJK UNIFIED IDEOGRAPH-#275EC, IRGKangXi=1109.190, RSKangXi=144.6
275ED CJK UNIFIED IDEOGRAPH-#275ED, IRGKangXi=1109.200, RSKangXi=144.6
275EE CJK UNIFIED IDEOGRAPH-#275EE, IRGKangXi=1109.201, RSKangXi=144.6
275EF CJK UNIFIED IDEOGRAPH-#275EF, IRGKangXi=1109.201, RSKangXi=144.6
275F0 CJK UNIFIED IDEOGRAPH-#275F0, IRGKangXi=1109.201, RSKangXi=144.6
275F1 CJK UNIFIED IDEOGRAPH-#275F1, IRGKangXi=1109.201, RSKangXi=144.6
275F2 CJK UNIFIED IDEOGRAPH-#275F2, IRGKangXi=1109.210, RSKangXi=144.7
275F3 CJK UNIFIED IDEOGRAPH-#275F3, IRGKangXi=1109.220, RSKangXi=144.7
275F4 CJK UNIFIED IDEOGRAPH-#275F4, IRGKangXi=1109.230, RSKangXi=144.7, Def{a raised path}
275F5 CJK UNIFIED IDEOGRAPH-#275F5, IRGKangXi=1109.250, RSKangXi=144.7
275F6 CJK UNIFIED IDEOGRAPH-#275F6, IRGKangXi=1109.260, RSKangXi=144.7
275F7 CJK UNIFIED IDEOGRAPH-#275F7, IRGKangXi=1109.261, RSKangXi=144.7, Def{(J) non-standard variant of 術 U+8853, art, skill, special feat; method}
275F8 CJK UNIFIED IDEOGRAPH-#275F8, IRGKangXi=1109.270, RSKangXi=144.8
275F9 CJK UNIFIED IDEOGRAPH-#275F9, IRGKangXi=1110.020, RSKangXi=144.9
275FA CJK UNIFIED IDEOGRAPH-#275FA, IRGKangXi=1110.040, RSKangXi=144.8
275FB CJK UNIFIED IDEOGRAPH-#275FB, IRGKangXi=1110.050, RSKangXi=144.8
275FC CJK UNIFIED IDEOGRAPH-#275FC, IRGKangXi=1110.060, RSKangXi=144.9
275FD CJK UNIFIED IDEOGRAPH-#275FD, IRGKangXi=1110.061, RSKangXi=144.9
275FE CJK UNIFIED IDEOGRAPH-#275FE, IRGKangXi=1110.131, RSKangXi=144.10
275FF CJK UNIFIED IDEOGRAPH-#275FF, IRGKangXi=1110.140, RSKangXi=144.11
27600 CJK UNIFIED IDEOGRAPH-#27600, IRGKangXi=1110.160, RSKangXi=144.11
27601 CJK UNIFIED IDEOGRAPH-#27601, IRGKangXi=1110.161, RSKangXi=144.11
27602 CJK UNIFIED IDEOGRAPH-#27602, IRGKangXi=1110.170, RSKangXi=144.12, Def{to rush at, dash against}
27603 CJK UNIFIED IDEOGRAPH-#27603, IRGKangXi=1110.180, RSKangXi=144.12
27604 CJK UNIFIED IDEOGRAPH-#27604, IRGKangXi=1110.190, RSKangXi=144.13
27605 CJK UNIFIED IDEOGRAPH-#27605, IRGKangXi=1110.210, RSKangXi=144.15
27606 CJK UNIFIED IDEOGRAPH-#27606, IRGKangXi=1110.220, RSKangXi=144.16
27607 CJK UNIFIED IDEOGRAPH-#27607, IRGKangXi=1111.011, RSKangXi=145.-2
27608 CJK UNIFIED IDEOGRAPH-#27608, IRGKangXi=1111.020, RSKangXi=145.2
27609 CJK UNIFIED IDEOGRAPH-#27609, IRGKangXi=1111.040, RSKangXi=145.2
2760A CJK UNIFIED IDEOGRAPH-#2760A, IRGKangXi=1111.050, RSKangXi=145.2
2760B CJK UNIFIED IDEOGRAPH-#2760B, IRGKangXi=1111.060, RSKangXi=145.2
2760C CJK UNIFIED IDEOGRAPH-#2760C, IRGKangXi=1111.061, RSKangXi=145.2
2760D CJK UNIFIED IDEOGRAPH-#2760D, IRGKangXi=1111.080, RSKangXi=145.3
2760E CJK UNIFIED IDEOGRAPH-#2760E, IRGKangXi=1111.110, RSKangXi=145.3
2760F CJK UNIFIED IDEOGRAPH-#2760F, IRGKangXi=1111.120, RSKangXi=145.3
27610 CJK UNIFIED IDEOGRAPH-#27610, IRGKangXi=1111.180, RSKangXi=145.3
27611 CJK UNIFIED IDEOGRAPH-#27611, IRGKangXi=1112.010, RSKangXi=145.3
27612 CJK UNIFIED IDEOGRAPH-#27612, IRGKangXi=1112.030, RSKangXi=145.3
27613 CJK UNIFIED IDEOGRAPH-#27613, IRGKangXi=1112.040, RSKangXi=145.3
27614 CJK UNIFIED IDEOGRAPH-#27614, IRGKangXi=1112.041, RSKangXi=145.3
27615 CJK UNIFIED IDEOGRAPH-#27615, IRGKangXi=1112.041, RSKangXi=145.3
27616 CJK UNIFIED IDEOGRAPH-#27616, IRGKangXi=1112.041, RSKangXi=145.3
27617 CJK UNIFIED IDEOGRAPH-#27617, IRGKangXi=1112.041, RSKangXi=145.3
27618 CJK UNIFIED IDEOGRAPH-#27618, IRGKangXi=1112.041, RSKangXi=145.3
27619 CJK UNIFIED IDEOGRAPH-#27619, IRGKangXi=1112.041, RSKangXi=145.3
2761A CJK UNIFIED IDEOGRAPH-#2761A, IRGKangXi=1112.041, RSKangXi=145.3
2761B CJK UNIFIED IDEOGRAPH-#2761B, IRGKangXi=1112.041, RSKangXi=145.3
2761C CJK UNIFIED IDEOGRAPH-#2761C, IRGKangXi=1112.041, RSKangXi=145.3
2761D CJK UNIFIED IDEOGRAPH-#2761D, IRGKangXi=1112.050, RSKangXi=145.4
2761E CJK UNIFIED IDEOGRAPH-#2761E, IRGKangXi=1112.070, RSKangXi=145.4
2761F CJK UNIFIED IDEOGRAPH-#2761F, IRGKangXi=1112.100, RSKangXi=145.4
27620 CJK UNIFIED IDEOGRAPH-#27620, IRGKangXi=1112.130, RSKangXi=145.4
27621 CJK UNIFIED IDEOGRAPH-#27621, IRGKangXi=1112.210, RSKangXi=145.4
27622 CJK UNIFIED IDEOGRAPH-#27622, IRGKangXi=1112.230, RSKangXi=145.4
27623 CJK UNIFIED IDEOGRAPH-#27623, IRGKangXi=1112.260, RSKangXi=145.4
27624 CJK UNIFIED IDEOGRAPH-#27624, IRGKangXi=1113.070, RSKangXi=145.4
27625 CJK UNIFIED IDEOGRAPH-#27625, IRGKangXi=1113.090, RSKangXi=145.4
27626 CJK UNIFIED IDEOGRAPH-#27626, IRGKangXi=1113.120, RSKangXi=145.4
27627 CJK UNIFIED IDEOGRAPH-#27627, IRGKangXi=1113.130, RSKangXi=145.4
27628 CJK UNIFIED IDEOGRAPH-#27628, IRGKangXi=1113.140, RSKangXi=145.4
27629 CJK UNIFIED IDEOGRAPH-#27629, IRGKangXi=1113.150, RSKangXi=145.4
2762A CJK UNIFIED IDEOGRAPH-#2762A, IRGKangXi=1113.160, RSKangXi=145.4
2762B CJK UNIFIED IDEOGRAPH-#2762B, IRGKangXi=1113.170, RSKangXi=145.4
2762C CJK UNIFIED IDEOGRAPH-#2762C, IRGKangXi=1113.180, RSKangXi=145.4
2762D CJK UNIFIED IDEOGRAPH-#2762D, IRGKangXi=1113.190, RSKangXi=145.4
2762E CJK UNIFIED IDEOGRAPH-#2762E, IRGKangXi=1113.200, RSKangXi=145.4
2762F CJK UNIFIED IDEOGRAPH-#2762F, IRGKangXi=1113.210, RSKangXi=145.4
27630 CJK UNIFIED IDEOGRAPH-#27630, IRGKangXi=1113.220, RSKangXi=145.4
27631 CJK UNIFIED IDEOGRAPH-#27631, IRGKangXi=1113.221, RSKangXi=145.4
27632 CJK UNIFIED IDEOGRAPH-#27632, IRGKangXi=1113.221, RSKangXi=145.4
27633 CJK UNIFIED IDEOGRAPH-#27633, IRGKangXi=1113.221, RSKangXi=145.4
27634 CJK UNIFIED IDEOGRAPH-#27634, IRGKangXi=1113.221, RSKangXi=145.4
27635 CJK UNIFIED IDEOGRAPH-#27635, IRGKangXi=1113.221, RSKangXi=145.4
27636 CJK UNIFIED IDEOGRAPH-#27636, IRGKangXi=1113.221, RSKangXi=145.4
27637 CJK UNIFIED IDEOGRAPH-#27637, IRGKangXi=1113.221, RSKangXi=145.4
27638 CJK UNIFIED IDEOGRAPH-#27638, IRGKangXi=1113.221, RSKangXi=145.4
27639 CJK UNIFIED IDEOGRAPH-#27639, IRGKangXi=1113.221, RSKangXi=145.4, Def{(Cant.) a necktie}
2763A CJK UNIFIED IDEOGRAPH-#2763A, IRGKangXi=1113.221, RSKangXi=145.4
2763B CJK UNIFIED IDEOGRAPH-#2763B, IRGKangXi=1113.221, RSKangXi=145.4
2763C CJK UNIFIED IDEOGRAPH-#2763C, IRGKangXi=1113.221, RSKangXi=145.4
2763D CJK UNIFIED IDEOGRAPH-#2763D, IRGKangXi=1113.250, RSKangXi=145.5
2763E CJK UNIFIED IDEOGRAPH-#2763E, IRGKangXi=1113.341, RSKangXi=145.6
2763F CJK UNIFIED IDEOGRAPH-#2763F, IRGKangXi=1114.020, RSKangXi=145.5
27640 CJK UNIFIED IDEOGRAPH-#27640, IRGKangXi=1114.030, RSKangXi=145.5, Def{old or badly fitting clothes; untidy}
27641 CJK UNIFIED IDEOGRAPH-#27641, IRGKangXi=1114.060, RSKangXi=145.5
27642 CJK UNIFIED IDEOGRAPH-#27642, IRGKangXi=1114.090, RSKangXi=145.5
27643 CJK UNIFIED IDEOGRAPH-#27643, IRGKangXi=1114.130, RSKangXi=145.5
27644 CJK UNIFIED IDEOGRAPH-#27644, IRGKangXi=1114.230, RSKangXi=145.5
27645 CJK UNIFIED IDEOGRAPH-#27645, IRGKangXi=1114.260, RSKangXi=145.5
27646 CJK UNIFIED IDEOGRAPH-#27646, IRGKangXi=1114.320, RSKangXi=145.5
27647 CJK UNIFIED IDEOGRAPH-#27647, IRGKangXi=1114.330, RSKangXi=145.5
27648 CJK UNIFIED IDEOGRAPH-#27648, IRGKangXi=1115.090, RSKangXi=145.5
27649 CJK UNIFIED IDEOGRAPH-#27649, IRGKangXi=1115.110, RSKangXi=145.5
2764A CJK UNIFIED IDEOGRAPH-#2764A, IRGKangXi=1115.120, RSKangXi=145.5
2764B CJK UNIFIED IDEOGRAPH-#2764B, IRGKangXi=1115.130, RSKangXi=145.5
2764C CJK UNIFIED IDEOGRAPH-#2764C, IRGKangXi=1115.140, RSKangXi=145.5
2764D CJK UNIFIED IDEOGRAPH-#2764D, IRGKangXi=1115.150, RSKangXi=145.5
2764E CJK UNIFIED IDEOGRAPH-#2764E, IRGKangXi=1115.170, RSKangXi=145.5
2764F CJK UNIFIED IDEOGRAPH-#2764F, IRGKangXi=1115.180, RSKangXi=145.5
27650 CJK UNIFIED IDEOGRAPH-#27650, IRGKangXi=1115.190, RSKangXi=145.5
27651 CJK UNIFIED IDEOGRAPH-#27651, IRGKangXi=1115.200, RSKangXi=145.5
27652 CJK UNIFIED IDEOGRAPH-#27652, IRGKangXi=1115.210, RSKangXi=145.5
27653 CJK UNIFIED IDEOGRAPH-#27653, IRGKangXi=1115.211, RSKangXi=145.5
27654 CJK UNIFIED IDEOGRAPH-#27654, IRGKangXi=1115.211, RSKangXi=145.5
27655 CJK UNIFIED IDEOGRAPH-#27655, IRGKangXi=1115.211, RSKangXi=145.5
27656 CJK UNIFIED IDEOGRAPH-#27656, IRGKangXi=1115.211, RSKangXi=145.5
27657 CJK UNIFIED IDEOGRAPH-#27657, IRGKangXi=1115.211, RSKangXi=145.5
27658 CJK UNIFIED IDEOGRAPH-#27658, IRGKangXi=1115.211, RSKangXi=145.5
27659 CJK UNIFIED IDEOGRAPH-#27659, IRGKangXi=1115.211, RSKangXi=145.5
2765A CJK UNIFIED IDEOGRAPH-#2765A, IRGKangXi=1115.211, RSKangXi=145.5
2765B CJK UNIFIED IDEOGRAPH-#2765B, IRGKangXi=1115.211, RSKangXi=145.5
2765C CJK UNIFIED IDEOGRAPH-#2765C, IRGKangXi=1115.211, RSKangXi=145.5
2765D CJK UNIFIED IDEOGRAPH-#2765D, IRGKangXi=1115.211, RSKangXi=145.5
2765E CJK UNIFIED IDEOGRAPH-#2765E, IRGKangXi=1115.230, RSKangXi=145.6
2765F CJK UNIFIED IDEOGRAPH-#2765F, IRGKangXi=1115.310, RSKangXi=145.6
27660 CJK UNIFIED IDEOGRAPH-#27660, IRGKangXi=1116.020, RSKangXi=145.6
27661 CJK UNIFIED IDEOGRAPH-#27661, IRGKangXi=1116.040, RSKangXi=145.6
27662 CJK UNIFIED IDEOGRAPH-#27662, IRGKangXi=1116.070, RSKangXi=145.6
27663 CJK UNIFIED IDEOGRAPH-#27663, IRGKangXi=1116.110, RSKangXi=145.6
27664 CJK UNIFIED IDEOGRAPH-#27664, IRGKangXi=1116.140, RSKangXi=145.6
27665 CJK UNIFIED IDEOGRAPH-#27665, IRGKangXi=1116.190, RSKangXi=145.6
27666 CJK UNIFIED IDEOGRAPH-#27666, IRGKangXi=1116.220, RSKangXi=145.6
27667 CJK UNIFIED IDEOGRAPH-#27667, IRGKangXi=1116.230, RSKangXi=145.6
27668 CJK UNIFIED IDEOGRAPH-#27668, IRGKangXi=1116.240, RSKangXi=145.6
27669 CJK UNIFIED IDEOGRAPH-#27669, IRGKangXi=1116.250, RSKangXi=145.6
2766A CJK UNIFIED IDEOGRAPH-#2766A, IRGKangXi=1116.260, RSKangXi=145.6
2766B CJK UNIFIED IDEOGRAPH-#2766B, IRGKangXi=1116.270, RSKangXi=145.6
2766C CJK UNIFIED IDEOGRAPH-#2766C, IRGKangXi=1116.280, RSKangXi=145.6
2766D CJK UNIFIED IDEOGRAPH-#2766D, IRGKangXi=1116.290, RSKangXi=145.6
2766E CJK UNIFIED IDEOGRAPH-#2766E, IRGKangXi=1116.310, RSKangXi=145.6
2766F CJK UNIFIED IDEOGRAPH-#2766F, IRGKangXi=1116.320, RSKangXi=145.6
27670 CJK UNIFIED IDEOGRAPH-#27670, IRGKangXi=1116.340, RSKangXi=145.6
27671 CJK UNIFIED IDEOGRAPH-#27671, IRGKangXi=1116.341, RSKangXi=145.6
27672 CJK UNIFIED IDEOGRAPH-#27672, IRGKangXi=1116.341, RSKangXi=145.6
27673 CJK UNIFIED IDEOGRAPH-#27673, IRGKangXi=1116.341, RSKangXi=145.6
27674 CJK UNIFIED IDEOGRAPH-#27674, IRGKangXi=1116.341, RSKangXi=145.6
27675 CJK UNIFIED IDEOGRAPH-#27675, IRGKangXi=1116.341, RSKangXi=145.6
27676 CJK UNIFIED IDEOGRAPH-#27676, IRGKangXi=1116.341, RSKangXi=145.6
27677 CJK UNIFIED IDEOGRAPH-#27677, IRGKangXi=1116.341, RSKangXi=145.6
27678 CJK UNIFIED IDEOGRAPH-#27678, IRGKangXi=1116.341, RSKangXi=145.6
27679 CJK UNIFIED IDEOGRAPH-#27679, IRGKangXi=1116.341, RSKangXi=145.6
2767A CJK UNIFIED IDEOGRAPH-#2767A, IRGKangXi=1116.341, RSKangXi=145.6
2767B CJK UNIFIED IDEOGRAPH-#2767B, IRGKangXi=1116.341, RSKangXi=145.6
2767C CJK UNIFIED IDEOGRAPH-#2767C, IRGKangXi=1116.341, RSKangXi=145.6
2767D CJK UNIFIED IDEOGRAPH-#2767D, IRGKangXi=1116.341, RSKangXi=145.6
2767E CJK UNIFIED IDEOGRAPH-#2767E, IRGKangXi=1116.341, RSKangXi=145.6
2767F CJK UNIFIED IDEOGRAPH-#2767F, IRGKangXi=1116.341, RSKangXi=145.6
27680 CJK UNIFIED IDEOGRAPH-#27680, IRGKangXi=1116.370, RSKangXi=145.7
27681 CJK UNIFIED IDEOGRAPH-#27681, IRGKangXi=1116.390, RSKangXi=145.7
27682 CJK UNIFIED IDEOGRAPH-#27682, IRGKangXi=1117.010, RSKangXi=145.7
27683 CJK UNIFIED IDEOGRAPH-#27683, IRGKangXi=1117.030, RSKangXi=145.7
27684 CJK UNIFIED IDEOGRAPH-#27684, IRGKangXi=1117.060, RSKangXi=145.7
27685 CJK UNIFIED IDEOGRAPH-#27685, IRGKangXi=1117.090, RSKangXi=145.7, Def{(Cant.) crotch}
27686 CJK UNIFIED IDEOGRAPH-#27686, IRGKangXi=1117.110, RSKangXi=145.7
27687 CJK UNIFIED IDEOGRAPH-#27687, IRGKangXi=1117.180, RSKangXi=145.7
27688 CJK UNIFIED IDEOGRAPH-#27688, IRGKangXi=1117.190, RSKangXi=145.7
27689 CJK UNIFIED IDEOGRAPH-#27689, IRGKangXi=1117.210, RSKangXi=145.7
2768A CJK UNIFIED IDEOGRAPH-#2768A, IRGKangXi=1117.280, RSKangXi=145.7
2768B CJK UNIFIED IDEOGRAPH-#2768B, IRGKangXi=1117.290, RSKangXi=145.7
2768C CJK UNIFIED IDEOGRAPH-#2768C, IRGKangXi=1118.020, RSKangXi=145.7
2768D CJK UNIFIED IDEOGRAPH-#2768D, IRGKangXi=1118.080, RSKangXi=145.7
2768E CJK UNIFIED IDEOGRAPH-#2768E, IRGKangXi=1118.090, RSKangXi=145.7
2768F CJK UNIFIED IDEOGRAPH-#2768F, IRGKangXi=1118.100, RSKangXi=145.7
27690 CJK UNIFIED IDEOGRAPH-#27690, IRGKangXi=1118.110, RSKangXi=145.7
27691 CJK UNIFIED IDEOGRAPH-#27691, IRGKangXi=1118.120, RSKangXi=145.7
27692 CJK UNIFIED IDEOGRAPH-#27692, IRGKangXi=1118.130, RSKangXi=145.7
27693 CJK UNIFIED IDEOGRAPH-#27693, IRGKangXi=1118.131, RSKangXi=145.7
27694 CJK UNIFIED IDEOGRAPH-#27694, IRGKangXi=1118.131, RSKangXi=145.7, Def{(Cant.) a kind of skirt}
27695 CJK UNIFIED IDEOGRAPH-#27695, IRGKangXi=1118.131, RSKangXi=145.7
27696 CJK UNIFIED IDEOGRAPH-#27696, IRGKangXi=1118.131, RSKangXi=145.7
27697 CJK UNIFIED IDEOGRAPH-#27697, IRGKangXi=1118.131, RSKangXi=145.7
27698 CJK UNIFIED IDEOGRAPH-#27698, IRGKangXi=1118.131, RSKangXi=145.7
27699 CJK UNIFIED IDEOGRAPH-#27699, IRGKangXi=1118.131, RSKangXi=145.7
2769A CJK UNIFIED IDEOGRAPH-#2769A, IRGKangXi=1118.131, RSKangXi=145.7
2769B CJK UNIFIED IDEOGRAPH-#2769B, IRGKangXi=1118.131, RSKangXi=145.7
2769C CJK UNIFIED IDEOGRAPH-#2769C, IRGKangXi=1118.131, RSKangXi=145.7
2769D CJK UNIFIED IDEOGRAPH-#2769D, IRGKangXi=1118.131, RSKangXi=145.7
2769E CJK UNIFIED IDEOGRAPH-#2769E, IRGKangXi=1118.131, RSKangXi=145.7
2769F CJK UNIFIED IDEOGRAPH-#2769F, IRGKangXi=1118.131, RSKangXi=145.7
276A0 CJK UNIFIED IDEOGRAPH-#276A0, IRGKangXi=1118.131, RSKangXi=145.7
276A1 CJK UNIFIED IDEOGRAPH-#276A1, IRGKangXi=1118.131, RSKangXi=145.7
276A2 CJK UNIFIED IDEOGRAPH-#276A2, IRGKangXi=1118.131, RSKangXi=145.7
276A3 CJK UNIFIED IDEOGRAPH-#276A3, IRGKangXi=1118.131, RSKangXi=145.7
276A4 CJK UNIFIED IDEOGRAPH-#276A4, IRGKangXi=1118.170, RSKangXi=145.8
276A5 CJK UNIFIED IDEOGRAPH-#276A5, IRGKangXi=1118.270, RSKangXi=145.8
276A6 CJK UNIFIED IDEOGRAPH-#276A6, IRGKangXi=1118.310, RSKangXi=145.8
276A7 CJK UNIFIED IDEOGRAPH-#276A7, IRGKangXi=1118.380, RSKangXi=145.8
276A8 CJK UNIFIED IDEOGRAPH-#276A8, IRGKangXi=1118.390, RSKangXi=145.8
276A9 CJK UNIFIED IDEOGRAPH-#276A9, IRGKangXi=1118.400, RSKangXi=145.8
276AA CJK UNIFIED IDEOGRAPH-#276AA, IRGKangXi=1119.040, RSKangXi=145.8
276AB CJK UNIFIED IDEOGRAPH-#276AB, IRGKangXi=1119.060, RSKangXi=145.8
276AC CJK UNIFIED IDEOGRAPH-#276AC, IRGKangXi=1119.070, RSKangXi=145.8
276AD CJK UNIFIED IDEOGRAPH-#276AD, IRGKangXi=1119.080, RSKangXi=145.8
276AE CJK UNIFIED IDEOGRAPH-#276AE, IRGKangXi=1119.160, RSKangXi=145.8
276AF CJK UNIFIED IDEOGRAPH-#276AF, IRGKangXi=1119.180, RSKangXi=145.8
276B0 CJK UNIFIED IDEOGRAPH-#276B0, IRGKangXi=1119.270, RSKangXi=145.8
276B1 CJK UNIFIED IDEOGRAPH-#276B1, IRGKangXi=1120.010, RSKangXi=145.8
276B2 CJK UNIFIED IDEOGRAPH-#276B2, IRGKangXi=1120.020, RSKangXi=145.8
276B3 CJK UNIFIED IDEOGRAPH-#276B3, IRGKangXi=1120.030, RSKangXi=145.8
276B4 CJK UNIFIED IDEOGRAPH-#276B4, IRGKangXi=1120.060, RSKangXi=145.8
276B5 CJK UNIFIED IDEOGRAPH-#276B5, IRGKangXi=1120.080, RSKangXi=145.8
276B6 CJK UNIFIED IDEOGRAPH-#276B6, IRGKangXi=1120.090, RSKangXi=145.8
276B7 CJK UNIFIED IDEOGRAPH-#276B7, IRGKangXi=1120.100, RSKangXi=145.8
276B8 CJK UNIFIED IDEOGRAPH-#276B8, IRGKangXi=1120.110, RSKangXi=145.8
276B9 CJK UNIFIED IDEOGRAPH-#276B9, IRGKangXi=1120.120, RSKangXi=145.8
276BA CJK UNIFIED IDEOGRAPH-#276BA, IRGKangXi=1120.130, RSKangXi=145.8
276BB CJK UNIFIED IDEOGRAPH-#276BB, IRGKangXi=1120.140, RSKangXi=145.9
276BC CJK UNIFIED IDEOGRAPH-#276BC, IRGKangXi=1120.150, RSKangXi=145.8
276BD CJK UNIFIED IDEOGRAPH-#276BD, IRGKangXi=1120.151, RSKangXi=145.8
276BE CJK UNIFIED IDEOGRAPH-#276BE, IRGKangXi=1120.151, RSKangXi=145.8
276BF CJK UNIFIED IDEOGRAPH-#276BF, IRGKangXi=1120.151, RSKangXi=145.8
276C0 CJK UNIFIED IDEOGRAPH-#276C0, IRGKangXi=1120.151, RSKangXi=145.8
276C1 CJK UNIFIED IDEOGRAPH-#276C1, IRGKangXi=1120.151, RSKangXi=145.8
276C2 CJK UNIFIED IDEOGRAPH-#276C2, IRGKangXi=1120.151, RSKangXi=145.8
276C3 CJK UNIFIED IDEOGRAPH-#276C3, IRGKangXi=1120.151, RSKangXi=145.8
276C4 CJK UNIFIED IDEOGRAPH-#276C4, IRGKangXi=1120.151, RSKangXi=145.8
276C5 CJK UNIFIED IDEOGRAPH-#276C5, IRGKangXi=1120.151, RSKangXi=145.8
276C6 CJK UNIFIED IDEOGRAPH-#276C6, IRGKangXi=1120.151, RSKangXi=145.8
276C7 CJK UNIFIED IDEOGRAPH-#276C7, IRGKangXi=1120.151, RSKangXi=145.8
276C8 CJK UNIFIED IDEOGRAPH-#276C8, IRGKangXi=1120.151, RSKangXi=145.8
276C9 CJK UNIFIED IDEOGRAPH-#276C9, IRGKangXi=1120.151, RSKangXi=145.8
276CA CJK UNIFIED IDEOGRAPH-#276CA, IRGKangXi=1120.151, RSKangXi=145.8
276CB CJK UNIFIED IDEOGRAPH-#276CB, IRGKangXi=1120.151, RSKangXi=145.8
276CC CJK UNIFIED IDEOGRAPH-#276CC, IRGKangXi=1120.151, RSKangXi=145.8
276CD CJK UNIFIED IDEOGRAPH-#276CD, IRGKangXi=1120.151, RSKangXi=145.8
276CE CJK UNIFIED IDEOGRAPH-#276CE, IRGKangXi=1120.151, RSKangXi=145.8
276CF CJK UNIFIED IDEOGRAPH-#276CF, IRGKangXi=1120.170, RSKangXi=145.9
276D0 CJK UNIFIED IDEOGRAPH-#276D0, IRGKangXi=1120.200, RSKangXi=145.9
276D1 CJK UNIFIED IDEOGRAPH-#276D1, IRGKangXi=1120.270, RSKangXi=145.9
276D2 CJK UNIFIED IDEOGRAPH-#276D2, IRGKangXi=1120.280, RSKangXi=145.9
276D3 CJK UNIFIED IDEOGRAPH-#276D3, IRGKangXi=1120.290, RSKangXi=145.9
276D4 CJK UNIFIED IDEOGRAPH-#276D4, IRGKangXi=1120.310, RSKangXi=145.9
276D5 CJK UNIFIED IDEOGRAPH-#276D5, IRGKangXi=1120.320, RSKangXi=145.9
276D6 CJK UNIFIED IDEOGRAPH-#276D6, IRGKangXi=1120.330, RSKangXi=145.9
276D7 CJK UNIFIED IDEOGRAPH-#276D7, IRGKangXi=1120.360, RSKangXi=145.9
276D8 CJK UNIFIED IDEOGRAPH-#276D8, IRGKangXi=1120.390, RSKangXi=145.9
276D9 CJK UNIFIED IDEOGRAPH-#276D9, IRGKangXi=1120.400, RSKangXi=145.9
276DA CJK UNIFIED IDEOGRAPH-#276DA, IRGKangXi=1120.410, RSKangXi=145.9
276DB CJK UNIFIED IDEOGRAPH-#276DB, IRGKangXi=1121.050, RSKangXi=145.9
276DC CJK UNIFIED IDEOGRAPH-#276DC, IRGKangXi=1121.060, RSKangXi=145.9
276DD CJK UNIFIED IDEOGRAPH-#276DD, IRGKangXi=1121.090, RSKangXi=145.9
276DE CJK UNIFIED IDEOGRAPH-#276DE, IRGKangXi=1121.110, RSKangXi=145.9
276DF CJK UNIFIED IDEOGRAPH-#276DF, IRGKangXi=1121.140, RSKangXi=145.9
276E0 CJK UNIFIED IDEOGRAPH-#276E0, IRGKangXi=1121.150, RSKangXi=145.9
276E1 CJK UNIFIED IDEOGRAPH-#276E1, IRGKangXi=1121.200, RSKangXi=145.9
276E2 CJK UNIFIED IDEOGRAPH-#276E2, IRGKangXi=1121.220, RSKangXi=145.9
276E3 CJK UNIFIED IDEOGRAPH-#276E3, IRGKangXi=1121.230, RSKangXi=145.9
276E4 CJK UNIFIED IDEOGRAPH-#276E4, IRGKangXi=1121.240, RSKangXi=145.9
276E5 CJK UNIFIED IDEOGRAPH-#276E5, IRGKangXi=1121.250, RSKangXi=145.9
276E6 CJK UNIFIED IDEOGRAPH-#276E6, IRGKangXi=1121.260, RSKangXi=145.9
276E7 CJK UNIFIED IDEOGRAPH-#276E7, IRGKangXi=1121.270, RSKangXi=145.9
276E8 CJK UNIFIED IDEOGRAPH-#276E8, IRGKangXi=1121.280, RSKangXi=145.9
276E9 CJK UNIFIED IDEOGRAPH-#276E9, IRGKangXi=1121.290, RSKangXi=145.9
276EA CJK UNIFIED IDEOGRAPH-#276EA, IRGKangXi=1121.300, RSKangXi=145.9
276EB CJK UNIFIED IDEOGRAPH-#276EB, IRGKangXi=1121.310, RSKangXi=145.9
276EC CJK UNIFIED IDEOGRAPH-#276EC, IRGKangXi=1121.320, RSKangXi=145.9
276ED CJK UNIFIED IDEOGRAPH-#276ED, IRGKangXi=1121.321, RSKangXi=145.9
276EE CJK UNIFIED IDEOGRAPH-#276EE, IRGKangXi=1121.321, RSKangXi=145.9
276EF CJK UNIFIED IDEOGRAPH-#276EF, IRGKangXi=1121.321, RSKangXi=145.9
276F0 CJK UNIFIED IDEOGRAPH-#276F0, IRGKangXi=1121.321, RSKangXi=145.9
276F1 CJK UNIFIED IDEOGRAPH-#276F1, IRGKangXi=1121.321, RSKangXi=145.9
276F2 CJK UNIFIED IDEOGRAPH-#276F2, IRGKangXi=1121.321, RSKangXi=145.9
276F3 CJK UNIFIED IDEOGRAPH-#276F3, IRGKangXi=1121.321, RSKangXi=145.9
276F4 CJK UNIFIED IDEOGRAPH-#276F4, IRGKangXi=1121.321, RSKangXi=145.9
276F5 CJK UNIFIED IDEOGRAPH-#276F5, IRGKangXi=1121.321, RSKangXi=145.9
276F6 CJK UNIFIED IDEOGRAPH-#276F6, IRGKangXi=1121.321, RSKangXi=145.9
276F7 CJK UNIFIED IDEOGRAPH-#276F7, IRGKangXi=1121.321, RSKangXi=145.9
276F8 CJK UNIFIED IDEOGRAPH-#276F8, IRGKangXi=1121.330, RSKangXi=145.10
276F9 CJK UNIFIED IDEOGRAPH-#276F9, IRGKangXi=1121.370, RSKangXi=145.10
276FA CJK UNIFIED IDEOGRAPH-#276FA, IRGKangXi=1121.380, RSKangXi=145.10
276FB CJK UNIFIED IDEOGRAPH-#276FB, IRGKangXi=1122.020, RSKangXi=145.10
276FC CJK UNIFIED IDEOGRAPH-#276FC, IRGKangXi=1122.030, RSKangXi=145.10
276FD CJK UNIFIED IDEOGRAPH-#276FD, IRGKangXi=1122.040, RSKangXi=145.10
276FE CJK UNIFIED IDEOGRAPH-#276FE, IRGKangXi=1122.050, RSKangXi=145.10
276FF CJK UNIFIED IDEOGRAPH-#276FF, IRGKangXi=1122.100, RSKangXi=145.10
27700 CJK UNIFIED IDEOGRAPH-#27700, IRGKangXi=1122.110, RSKangXi=145.10
27701 CJK UNIFIED IDEOGRAPH-#27701, IRGKangXi=1122.130, RSKangXi=145.10, Def{to make smaller, fit; seam}
27702 CJK UNIFIED IDEOGRAPH-#27702, IRGKangXi=1122.140, RSKangXi=145.10
27703 CJK UNIFIED IDEOGRAPH-#27703, IRGKangXi=1122.160, RSKangXi=145.10
27704 CJK UNIFIED IDEOGRAPH-#27704, IRGKangXi=1122.200, RSKangXi=145.10
27705 CJK UNIFIED IDEOGRAPH-#27705, IRGKangXi=1122.250, RSKangXi=145.10
27706 CJK UNIFIED IDEOGRAPH-#27706, IRGKangXi=1122.270, RSKangXi=145.10
27707 CJK UNIFIED IDEOGRAPH-#27707, IRGKangXi=1122.300, RSKangXi=145.10
27708 CJK UNIFIED IDEOGRAPH-#27708, IRGKangXi=1122.340, RSKangXi=145.10
27709 CJK UNIFIED IDEOGRAPH-#27709, IRGKangXi=1122.350, RSKangXi=145.10
2770A CJK UNIFIED IDEOGRAPH-#2770A, IRGKangXi=1122.360, RSKangXi=145.10
2770B CJK UNIFIED IDEOGRAPH-#2770B, IRGKangXi=1122.370, RSKangXi=145.10
2770C CJK UNIFIED IDEOGRAPH-#2770C, IRGKangXi=1122.380, RSKangXi=145.10
2770D CJK UNIFIED IDEOGRAPH-#2770D, IRGKangXi=1122.390, RSKangXi=145.10
2770E CJK UNIFIED IDEOGRAPH-#2770E, IRGKangXi=1122.391, RSKangXi=145.10
2770F CJK UNIFIED IDEOGRAPH-#2770F, IRGKangXi=1122.391, RSKangXi=145.10
27710 CJK UNIFIED IDEOGRAPH-#27710, IRGKangXi=1122.391, RSKangXi=145.10
27711 CJK UNIFIED IDEOGRAPH-#27711, IRGKangXi=1122.391, RSKangXi=145.10
27712 CJK UNIFIED IDEOGRAPH-#27712, IRGKangXi=1122.391, RSKangXi=145.10
27713 CJK UNIFIED IDEOGRAPH-#27713, IRGKangXi=1122.391, RSKangXi=145.10
27714 CJK UNIFIED IDEOGRAPH-#27714, IRGKangXi=1122.391, RSKangXi=145.10
27715 CJK UNIFIED IDEOGRAPH-#27715, IRGKangXi=1122.391, RSKangXi=145.10
27716 CJK UNIFIED IDEOGRAPH-#27716, IRGKangXi=1122.391, RSKangXi=145.10
27717 CJK UNIFIED IDEOGRAPH-#27717, IRGKangXi=1122.391, RSKangXi=145.10
27718 CJK UNIFIED IDEOGRAPH-#27718, IRGKangXi=1122.391, RSKangXi=145.10
27719 CJK UNIFIED IDEOGRAPH-#27719, IRGKangXi=1122.391, RSKangXi=145.10
2771A CJK UNIFIED IDEOGRAPH-#2771A, IRGKangXi=1122.391, RSKangXi=145.10
2771B CJK UNIFIED IDEOGRAPH-#2771B, IRGKangXi=1122.391, RSKangXi=145.10
2771C CJK UNIFIED IDEOGRAPH-#2771C, IRGKangXi=1122.391, RSKangXi=145.10
2771D CJK UNIFIED IDEOGRAPH-#2771D, IRGKangXi=1123.040, RSKangXi=145.11
2771E CJK UNIFIED IDEOGRAPH-#2771E, IRGKangXi=1123.060, RSKangXi=145.11
2771F CJK UNIFIED IDEOGRAPH-#2771F, IRGKangXi=1123.070, RSKangXi=145.11
27720 CJK UNIFIED IDEOGRAPH-#27720, IRGKangXi=1123.160, RSKangXi=145.11
27721 CJK UNIFIED IDEOGRAPH-#27721, IRGKangXi=1123.170, RSKangXi=145.11
27722 CJK UNIFIED IDEOGRAPH-#27722, IRGKangXi=1123.210, RSKangXi=145.11
27723 CJK UNIFIED IDEOGRAPH-#27723, IRGKangXi=1123.220, RSKangXi=145.11
27724 CJK UNIFIED IDEOGRAPH-#27724, IRGKangXi=1123.230, RSKangXi=145.11
27725 CJK UNIFIED IDEOGRAPH-#27725, IRGKangXi=1123.260, RSKangXi=145.11
27726 CJK UNIFIED IDEOGRAPH-#27726, IRGKangXi=1123.280, RSKangXi=145.11
27727 CJK UNIFIED IDEOGRAPH-#27727, IRGKangXi=1123.300, RSKangXi=145.11
27728 CJK UNIFIED IDEOGRAPH-#27728, IRGKangXi=1124.010, RSKangXi=145.10
27729 CJK UNIFIED IDEOGRAPH-#27729, IRGKangXi=1124.020, RSKangXi=145.11
2772A CJK UNIFIED IDEOGRAPH-#2772A, IRGKangXi=1124.030, RSKangXi=145.11
2772B CJK UNIFIED IDEOGRAPH-#2772B, IRGKangXi=1124.040, RSKangXi=145.11
2772C CJK UNIFIED IDEOGRAPH-#2772C, IRGKangXi=1124.050, RSKangXi=145.11
2772D CJK UNIFIED IDEOGRAPH-#2772D, IRGKangXi=1124.060, RSKangXi=145.12
2772E CJK UNIFIED IDEOGRAPH-#2772E, IRGKangXi=1124.070, RSKangXi=145.11
2772F CJK UNIFIED IDEOGRAPH-#2772F, IRGKangXi=1124.090, RSKangXi=145.11
27730 CJK UNIFIED IDEOGRAPH-#27730, IRGKangXi=1124.100, RSKangXi=145.11
27731 CJK UNIFIED IDEOGRAPH-#27731, IRGKangXi=1124.110, RSKangXi=145.11
27732 CJK UNIFIED IDEOGRAPH-#27732, IRGKangXi=1124.120, RSKangXi=145.11
27733 CJK UNIFIED IDEOGRAPH-#27733, IRGKangXi=1124.140, RSKangXi=145.11
27734 CJK UNIFIED IDEOGRAPH-#27734, IRGKangXi=1124.141, RSKangXi=145.11
27735 CJK UNIFIED IDEOGRAPH-#27735, IRGKangXi=1124.141, RSKangXi=145.11, Def{arid; dry; parched}
27736 CJK UNIFIED IDEOGRAPH-#27736, IRGKangXi=1124.141, RSKangXi=145.11
27737 CJK UNIFIED IDEOGRAPH-#27737, IRGKangXi=1124.141, RSKangXi=145.11
27738 CJK UNIFIED IDEOGRAPH-#27738, IRGKangXi=1124.141, RSKangXi=145.11
27739 CJK UNIFIED IDEOGRAPH-#27739, IRGKangXi=1124.141, RSKangXi=145.11
2773A CJK UNIFIED IDEOGRAPH-#2773A, IRGKangXi=1124.141, RSKangXi=145.11
2773B CJK UNIFIED IDEOGRAPH-#2773B, IRGKangXi=1124.141, RSKangXi=145.11
2773C CJK UNIFIED IDEOGRAPH-#2773C, IRGKangXi=1124.141, RSKangXi=145.11
2773D CJK UNIFIED IDEOGRAPH-#2773D, IRGKangXi=1124.141, RSKangXi=145.11
2773E CJK UNIFIED IDEOGRAPH-#2773E, IRGKangXi=1124.141, RSKangXi=145.11
2773F CJK UNIFIED IDEOGRAPH-#2773F, IRGKangXi=1124.141, RSKangXi=145.11
27740 CJK UNIFIED IDEOGRAPH-#27740, IRGKangXi=1124.141, RSKangXi=145.11
27741 CJK UNIFIED IDEOGRAPH-#27741, IRGKangXi=1124.141, RSKangXi=145.11
27742 CJK UNIFIED IDEOGRAPH-#27742, IRGKangXi=1124.170, RSKangXi=145.12
27743 CJK UNIFIED IDEOGRAPH-#27743, IRGKangXi=1124.180, RSKangXi=145.12
27744 CJK UNIFIED IDEOGRAPH-#27744, IRGKangXi=1124.190, RSKangXi=145.12
27745 CJK UNIFIED IDEOGRAPH-#27745, IRGKangXi=1124.220, RSKangXi=145.12
27746 CJK UNIFIED IDEOGRAPH-#27746, IRGKangXi=1124.240, RSKangXi=145.12
27747 CJK UNIFIED IDEOGRAPH-#27747, IRGKangXi=1124.260, RSKangXi=145.12
27748 CJK UNIFIED IDEOGRAPH-#27748, IRGKangXi=1124.270, RSKangXi=145.12
27749 CJK UNIFIED IDEOGRAPH-#27749, IRGKangXi=1124.280, RSKangXi=145.12
2774A CJK UNIFIED IDEOGRAPH-#2774A, IRGKangXi=1124.290, RSKangXi=145.12
2774B CJK UNIFIED IDEOGRAPH-#2774B, IRGKangXi=1124.320, RSKangXi=145.12
2774C CJK UNIFIED IDEOGRAPH-#2774C, IRGKangXi=1124.350, RSKangXi=145.12
2774D CJK UNIFIED IDEOGRAPH-#2774D, IRGKangXi=1124.380, RSKangXi=145.12
2774E CJK UNIFIED IDEOGRAPH-#2774E, IRGKangXi=1124.390, RSKangXi=145.12
2774F CJK UNIFIED IDEOGRAPH-#2774F, IRGKangXi=1124.410, RSKangXi=145.12
27750 CJK UNIFIED IDEOGRAPH-#27750, IRGKangXi=1124.440, RSKangXi=145.12
27751 CJK UNIFIED IDEOGRAPH-#27751, IRGKangXi=1125.010, RSKangXi=145.12
27752 CJK UNIFIED IDEOGRAPH-#27752, IRGKangXi=1125.020, RSKangXi=145.12
27753 CJK UNIFIED IDEOGRAPH-#27753, IRGKangXi=1125.050, RSKangXi=145.12
27754 CJK UNIFIED IDEOGRAPH-#27754, IRGKangXi=1125.060, RSKangXi=145.12
27755 CJK UNIFIED IDEOGRAPH-#27755, IRGKangXi=1125.070, RSKangXi=145.12
27756 CJK UNIFIED IDEOGRAPH-#27756, IRGKangXi=1125.080, RSKangXi=145.12
27757 CJK UNIFIED IDEOGRAPH-#27757, IRGKangXi=1125.100, RSKangXi=145.12
27758 CJK UNIFIED IDEOGRAPH-#27758, IRGKangXi=1125.110, RSKangXi=145.12
27759 CJK UNIFIED IDEOGRAPH-#27759, IRGKangXi=1125.120, RSKangXi=145.12
2775A CJK UNIFIED IDEOGRAPH-#2775A, IRGKangXi=1125.130, RSKangXi=145.12
2775B CJK UNIFIED IDEOGRAPH-#2775B, IRGKangXi=1125.140, RSKangXi=145.12
2775C CJK UNIFIED IDEOGRAPH-#2775C, IRGKangXi=1125.150, RSKangXi=145.12
2775D CJK UNIFIED IDEOGRAPH-#2775D, IRGKangXi=1125.151, RSKangXi=145.12
2775E CJK UNIFIED IDEOGRAPH-#2775E, IRGKangXi=1125.151, RSKangXi=145.12, Def{(Cant.) 卡𧝞, khaki}
2775F CJK UNIFIED IDEOGRAPH-#2775F, IRGKangXi=1125.151, RSKangXi=145.12
27760 CJK UNIFIED IDEOGRAPH-#27760, IRGKangXi=1125.151, RSKangXi=145.12
27761 CJK UNIFIED IDEOGRAPH-#27761, IRGKangXi=1125.151, RSKangXi=145.12
27762 CJK UNIFIED IDEOGRAPH-#27762, IRGKangXi=1125.151, RSKangXi=145.12
27763 CJK UNIFIED IDEOGRAPH-#27763, IRGKangXi=1125.151, RSKangXi=145.12
27764 CJK UNIFIED IDEOGRAPH-#27764, IRGKangXi=1125.151, RSKangXi=145.12
27765 CJK UNIFIED IDEOGRAPH-#27765, IRGKangXi=1125.151, RSKangXi=145.12
27766 CJK UNIFIED IDEOGRAPH-#27766, IRGKangXi=1125.151, RSKangXi=145.12
27767 CJK UNIFIED IDEOGRAPH-#27767, IRGKangXi=1125.151, RSKangXi=145.12
27768 CJK UNIFIED IDEOGRAPH-#27768, IRGKangXi=1125.151, RSKangXi=145.12
27769 CJK UNIFIED IDEOGRAPH-#27769, IRGKangXi=1125.151, RSKangXi=145.12
2776A CJK UNIFIED IDEOGRAPH-#2776A, IRGKangXi=1125.151, RSKangXi=145.12
2776B CJK UNIFIED IDEOGRAPH-#2776B, IRGKangXi=1125.151, RSKangXi=145.12
2776C CJK UNIFIED IDEOGRAPH-#2776C, IRGKangXi=1125.151, RSKangXi=145.12
2776D CJK UNIFIED IDEOGRAPH-#2776D, IRGKangXi=1125.151, RSKangXi=145.12
2776E CJK UNIFIED IDEOGRAPH-#2776E, IRGKangXi=1125.151, RSKangXi=145.12
2776F CJK UNIFIED IDEOGRAPH-#2776F, IRGKangXi=1125.151, RSKangXi=145.12
27770 CJK UNIFIED IDEOGRAPH-#27770, IRGKangXi=1125.151, RSKangXi=145.12
27771 CJK UNIFIED IDEOGRAPH-#27771, IRGKangXi=1125.160, RSKangXi=145.13
27772 CJK UNIFIED IDEOGRAPH-#27772, IRGKangXi=1125.190, RSKangXi=145.13
27773 CJK UNIFIED IDEOGRAPH-#27773, IRGKangXi=1125.210, RSKangXi=145.13
27774 CJK UNIFIED IDEOGRAPH-#27774, IRGKangXi=1125.230, RSKangXi=145.13
27775 CJK UNIFIED IDEOGRAPH-#27775, IRGKangXi=1125.260, RSKangXi=145.13
27776 CJK UNIFIED IDEOGRAPH-#27776, IRGKangXi=1125.270, RSKangXi=145.13
27777 CJK UNIFIED IDEOGRAPH-#27777, IRGKangXi=1125.320, RSKangXi=145.13
27778 CJK UNIFIED IDEOGRAPH-#27778, IRGKangXi=1125.340, RSKangXi=145.13
27779 CJK UNIFIED IDEOGRAPH-#27779, IRGKangXi=1125.360, RSKangXi=145.13
2777A CJK UNIFIED IDEOGRAPH-#2777A, IRGKangXi=1125.390, RSKangXi=145.13
2777B CJK UNIFIED IDEOGRAPH-#2777B, IRGKangXi=1126.020, RSKangXi=145.13
2777C CJK UNIFIED IDEOGRAPH-#2777C, IRGKangXi=1126.030, RSKangXi=145.13
2777D CJK UNIFIED IDEOGRAPH-#2777D, IRGKangXi=1126.040, RSKangXi=145.13
2777E CJK UNIFIED IDEOGRAPH-#2777E, IRGKangXi=1126.050, RSKangXi=145.13
2777F CJK UNIFIED IDEOGRAPH-#2777F, IRGKangXi=1126.060, RSKangXi=145.13
27780 CJK UNIFIED IDEOGRAPH-#27780, IRGKangXi=1126.070, RSKangXi=145.13
27781 CJK UNIFIED IDEOGRAPH-#27781, IRGKangXi=1126.080, RSKangXi=145.13
27782 CJK UNIFIED IDEOGRAPH-#27782, IRGKangXi=1126.090, RSKangXi=145.13
27783 CJK UNIFIED IDEOGRAPH-#27783, IRGKangXi=1126.091, RSKangXi=145.13
27784 CJK UNIFIED IDEOGRAPH-#27784, IRGKangXi=1126.091, RSKangXi=145.13
27785 CJK UNIFIED IDEOGRAPH-#27785, IRGKangXi=1126.091, RSKangXi=145.13
27786 CJK UNIFIED IDEOGRAPH-#27786, IRGKangXi=1126.091, RSKangXi=145.13
27787 CJK UNIFIED IDEOGRAPH-#27787, IRGKangXi=1126.091, RSKangXi=145.13
27788 CJK UNIFIED IDEOGRAPH-#27788, IRGKangXi=1126.091, RSKangXi=145.13
27789 CJK UNIFIED IDEOGRAPH-#27789, IRGKangXi=1126.091, RSKangXi=145.13
2778A CJK UNIFIED IDEOGRAPH-#2778A, IRGKangXi=1126.091, RSKangXi=145.13
2778B CJK UNIFIED IDEOGRAPH-#2778B, IRGKangXi=1126.091, RSKangXi=145.13
2778C CJK UNIFIED IDEOGRAPH-#2778C, IRGKangXi=1126.091, RSKangXi=145.13
2778D CJK UNIFIED IDEOGRAPH-#2778D, IRGKangXi=1126.100, RSKangXi=145.14
2778E CJK UNIFIED IDEOGRAPH-#2778E, IRGKangXi=1126.120, RSKangXi=145.14
2778F CJK UNIFIED IDEOGRAPH-#2778F, IRGKangXi=1126.130, RSKangXi=145.14
27790 CJK UNIFIED IDEOGRAPH-#27790, IRGKangXi=1126.140, RSKangXi=145.14
27791 CJK UNIFIED IDEOGRAPH-#27791, IRGKangXi=1126.150, RSKangXi=145.14
27792 CJK UNIFIED IDEOGRAPH-#27792, IRGKangXi=1126.160, RSKangXi=145.14
27793 CJK UNIFIED IDEOGRAPH-#27793, IRGKangXi=1126.210, RSKangXi=145.14
27794 CJK UNIFIED IDEOGRAPH-#27794, IRGKangXi=1126.220, RSKangXi=145.14
27795 CJK UNIFIED IDEOGRAPH-#27795, IRGKangXi=1126.260, RSKangXi=145.14
27796 CJK UNIFIED IDEOGRAPH-#27796, IRGKangXi=1126.270, RSKangXi=145.14
27797 CJK UNIFIED IDEOGRAPH-#27797, IRGKangXi=1126.280, RSKangXi=145.15
27798 CJK UNIFIED IDEOGRAPH-#27798, IRGKangXi=1126.290, RSKangXi=145.14
27799 CJK UNIFIED IDEOGRAPH-#27799, IRGKangXi=1126.300, RSKangXi=145.14
2779A CJK UNIFIED IDEOGRAPH-#2779A, IRGKangXi=1126.310, RSKangXi=145.14
2779B CJK UNIFIED IDEOGRAPH-#2779B, IRGKangXi=1126.320, RSKangXi=145.14
2779C CJK UNIFIED IDEOGRAPH-#2779C, IRGKangXi=1126.330, RSKangXi=145.14
2779D CJK UNIFIED IDEOGRAPH-#2779D, IRGKangXi=1126.340, RSKangXi=145.14
2779E CJK UNIFIED IDEOGRAPH-#2779E, IRGKangXi=1126.360, RSKangXi=145.14
2779F CJK UNIFIED IDEOGRAPH-#2779F, IRGKangXi=1126.370, RSKangXi=145.14
277A0 CJK UNIFIED IDEOGRAPH-#277A0, IRGKangXi=1126.371, RSKangXi=145.14
277A1 CJK UNIFIED IDEOGRAPH-#277A1, IRGKangXi=1126.371, RSKangXi=145.14
277A2 CJK UNIFIED IDEOGRAPH-#277A2, IRGKangXi=1126.371, RSKangXi=145.14
277A3 CJK UNIFIED IDEOGRAPH-#277A3, IRGKangXi=1126.371, RSKangXi=145.14
277A4 CJK UNIFIED IDEOGRAPH-#277A4, IRGKangXi=1126.371, RSKangXi=145.14
277A5 CJK UNIFIED IDEOGRAPH-#277A5, IRGKangXi=1126.371, RSKangXi=145.14
277A6 CJK UNIFIED IDEOGRAPH-#277A6, IRGKangXi=1126.371, RSKangXi=145.14
277A7 CJK UNIFIED IDEOGRAPH-#277A7, IRGKangXi=1126.390, RSKangXi=145.15
277A8 CJK UNIFIED IDEOGRAPH-#277A8, IRGKangXi=1126.410, RSKangXi=145.15
277A9 CJK UNIFIED IDEOGRAPH-#277A9, IRGKangXi=1126.430, RSKangXi=145.15
277AA CJK UNIFIED IDEOGRAPH-#277AA, IRGKangXi=1126.470, RSKangXi=145.15, Def{old or badly fitting clothes; untidy}
277AB CJK UNIFIED IDEOGRAPH-#277AB, IRGKangXi=1126.480, RSKangXi=145.15
277AC CJK UNIFIED IDEOGRAPH-#277AC, IRGKangXi=1126.510, RSKangXi=145.15
277AD CJK UNIFIED IDEOGRAPH-#277AD, IRGKangXi=1126.520, RSKangXi=145.15
277AE CJK UNIFIED IDEOGRAPH-#277AE, IRGKangXi=1126.530, RSKangXi=145.15
277AF CJK UNIFIED IDEOGRAPH-#277AF, IRGKangXi=1126.540, RSKangXi=145.15
277B0 CJK UNIFIED IDEOGRAPH-#277B0, IRGKangXi=1126.550, RSKangXi=145.15
277B1 CJK UNIFIED IDEOGRAPH-#277B1, IRGKangXi=1126.560, RSKangXi=145.15
277B2 CJK UNIFIED IDEOGRAPH-#277B2, IRGKangXi=1126.570, RSKangXi=145.16
277B3 CJK UNIFIED IDEOGRAPH-#277B3, IRGKangXi=1126.571, RSKangXi=145.15
277B4 CJK UNIFIED IDEOGRAPH-#277B4, IRGKangXi=1126.571, RSKangXi=145.15
277B5 CJK UNIFIED IDEOGRAPH-#277B5, IRGKangXi=1126.571, RSKangXi=145.15
277B6 CJK UNIFIED IDEOGRAPH-#277B6, IRGKangXi=1126.580, RSKangXi=145.16
277B7 CJK UNIFIED IDEOGRAPH-#277B7, IRGKangXi=1127.020, RSKangXi=145.16
277B8 CJK UNIFIED IDEOGRAPH-#277B8, IRGKangXi=1127.030, RSKangXi=145.16
277B9 CJK UNIFIED IDEOGRAPH-#277B9, IRGKangXi=1127.100, RSKangXi=145.16
277BA CJK UNIFIED IDEOGRAPH-#277BA, IRGKangXi=1127.110, RSKangXi=145.16
277BB CJK UNIFIED IDEOGRAPH-#277BB, IRGKangXi=1127.120, RSKangXi=145.16
277BC CJK UNIFIED IDEOGRAPH-#277BC, IRGKangXi=1127.121, RSKangXi=145.16
277BD CJK UNIFIED IDEOGRAPH-#277BD, IRGKangXi=1127.121, RSKangXi=145.16
277BE CJK UNIFIED IDEOGRAPH-#277BE, IRGKangXi=1127.121, RSKangXi=145.16
277BF CJK UNIFIED IDEOGRAPH-#277BF, IRGKangXi=1127.121, RSKangXi=145.16
277C0 CJK UNIFIED IDEOGRAPH-#277C0, IRGKangXi=1127.121, RSKangXi=145.16
277C1 CJK UNIFIED IDEOGRAPH-#277C1, IRGKangXi=1127.121, RSKangXi=145.16
277C2 CJK UNIFIED IDEOGRAPH-#277C2, IRGKangXi=1127.121, RSKangXi=145.16
277C3 CJK UNIFIED IDEOGRAPH-#277C3, IRGKangXi=1127.140, RSKangXi=145.17
277C4 CJK UNIFIED IDEOGRAPH-#277C4, IRGKangXi=1127.180, RSKangXi=145.17
277C5 CJK UNIFIED IDEOGRAPH-#277C5, IRGKangXi=1127.190, RSKangXi=145.17
277C6 CJK UNIFIED IDEOGRAPH-#277C6, IRGKangXi=1127.191, RSKangXi=145.17
277C7 CJK UNIFIED IDEOGRAPH-#277C7, IRGKangXi=1127.191, RSKangXi=145.17
277C8 CJK UNIFIED IDEOGRAPH-#277C8, IRGKangXi=1127.210, RSKangXi=145.18
277C9 CJK UNIFIED IDEOGRAPH-#277C9, IRGKangXi=1127.250, RSKangXi=145.18
277CA CJK UNIFIED IDEOGRAPH-#277CA, IRGKangXi=1127.260, RSKangXi=145.18
277CB CJK UNIFIED IDEOGRAPH-#277CB, IRGKangXi=1127.261, RSKangXi=145.18
277CC CJK UNIFIED IDEOGRAPH-#277CC, IRGKangXi=1127.320, RSKangXi=145.19
277CD CJK UNIFIED IDEOGRAPH-#277CD, IRGKangXi=1127.340, RSKangXi=145.19
277CE CJK UNIFIED IDEOGRAPH-#277CE, IRGKangXi=1127.350, RSKangXi=145.19
277CF CJK UNIFIED IDEOGRAPH-#277CF, IRGKangXi=1127.351, RSKangXi=145.19
277D0 CJK UNIFIED IDEOGRAPH-#277D0, IRGKangXi=1127.360, RSKangXi=145.20
277D1 CJK UNIFIED IDEOGRAPH-#277D1, IRGKangXi=1127.370, RSKangXi=145.20
277D2 CJK UNIFIED IDEOGRAPH-#277D2, IRGKangXi=1127.371, RSKangXi=145.20
277D3 CJK UNIFIED IDEOGRAPH-#277D3, IRGKangXi=1127.371, RSKangXi=145.20
277D4 CJK UNIFIED IDEOGRAPH-#277D4, IRGKangXi=1127.380, RSKangXi=145.21
277D5 CJK UNIFIED IDEOGRAPH-#277D5, IRGKangXi=1128.010, RSKangXi=145.21
277D6 CJK UNIFIED IDEOGRAPH-#277D6, IRGKangXi=1128.020, RSKangXi=145.21
277D7 CJK UNIFIED IDEOGRAPH-#277D7, IRGKangXi=1128.021, RSKangXi=145.21
277D8 CJK UNIFIED IDEOGRAPH-#277D8, IRGKangXi=1128.030, RSKangXi=145.22
277D9 CJK UNIFIED IDEOGRAPH-#277D9, IRGKangXi=1128.040, RSKangXi=145.24
277DA CJK UNIFIED IDEOGRAPH-#277DA, IRGKangXi=1128.050, RSKangXi=145.24
277DB CJK UNIFIED IDEOGRAPH-#277DB, IRGKangXi=1128.060, RSKangXi=145.26
277DC CJK UNIFIED IDEOGRAPH-#277DC, IRGKangXi=1128.061, RSKangXi=145.28
277DD CJK UNIFIED IDEOGRAPH-#277DD, IRGKangXi=1128.061, RSKangXi=145.28
277DE CJK UNIFIED IDEOGRAPH-#277DE, IRGKangXi=1128.070, RSKangXi=145.32
277DF CJK UNIFIED IDEOGRAPH-#277DF, IRGKangXi=1128.080, RSKangXi=145.32
277E0 CJK UNIFIED IDEOGRAPH-#277E0, IRGKangXi=1128.130, RSKangXi=146.1
277E1 CJK UNIFIED IDEOGRAPH-#277E1, IRGKangXi=1128.131, RSKangXi=146.1
277E2 CJK UNIFIED IDEOGRAPH-#277E2, IRGKangXi=1128.131, RSKangXi=146.1
277E3 CJK UNIFIED IDEOGRAPH-#277E3, IRGKangXi=1128.140, RSKangXi=146.2
277E4 CJK UNIFIED IDEOGRAPH-#277E4, IRGKangXi=1128.200, RSKangXi=146.3
277E5 CJK UNIFIED IDEOGRAPH-#277E5, IRGKangXi=1128.201, RSKangXi=146.3
277E6 CJK UNIFIED IDEOGRAPH-#277E6, IRGKangXi=1128.201, RSKangXi=146.3
277E7 CJK UNIFIED IDEOGRAPH-#277E7, IRGKangXi=1128.210, RSKangXi=146.4
277E8 CJK UNIFIED IDEOGRAPH-#277E8, IRGKangXi=1128.220, RSKangXi=146.4
277E9 CJK UNIFIED IDEOGRAPH-#277E9, IRGKangXi=1128.230, RSKangXi=146.4
277EA CJK UNIFIED IDEOGRAPH-#277EA, IRGKangXi=1128.240, RSKangXi=146.5
277EB CJK UNIFIED IDEOGRAPH-#277EB, IRGKangXi=1128.271, RSKangXi=146.5
277EC CJK UNIFIED IDEOGRAPH-#277EC, IRGKangXi=1128.271, RSKangXi=146.5
277ED CJK UNIFIED IDEOGRAPH-#277ED, IRGKangXi=1128.321, RSKangXi=146.6
277EE CJK UNIFIED IDEOGRAPH-#277EE, IRGKangXi=1128.321, RSKangXi=146.6
277EF CJK UNIFIED IDEOGRAPH-#277EF, IRGKangXi=1128.321, RSKangXi=146.7
277F0 CJK UNIFIED IDEOGRAPH-#277F0, IRGKangXi=1128.321, RSKangXi=146.7
277F1 CJK UNIFIED IDEOGRAPH-#277F1, IRGKangXi=1129.010, RSKangXi=146.8
277F2 CJK UNIFIED IDEOGRAPH-#277F2, IRGKangXi=1129.020, RSKangXi=146.8
277F3 CJK UNIFIED IDEOGRAPH-#277F3, IRGKangXi=1129.030, RSKangXi=146.8
277F4 CJK UNIFIED IDEOGRAPH-#277F4, IRGKangXi=1129.040, RSKangXi=146.8
277F5 CJK UNIFIED IDEOGRAPH-#277F5, IRGKangXi=1129.041, RSKangXi=146.8
277F6 CJK UNIFIED IDEOGRAPH-#277F6, IRGKangXi=1129.041, RSKangXi=146.8
277F7 CJK UNIFIED IDEOGRAPH-#277F7, IRGKangXi=1129.041, RSKangXi=146.8
277F8 CJK UNIFIED IDEOGRAPH-#277F8, IRGKangXi=1129.041, RSKangXi=146.8
277F9 CJK UNIFIED IDEOGRAPH-#277F9, IRGKangXi=1129.050, RSKangXi=146.9
277FA CJK UNIFIED IDEOGRAPH-#277FA, IRGKangXi=1129.051, RSKangXi=146.9
277FB CJK UNIFIED IDEOGRAPH-#277FB, IRGKangXi=1129.051, RSKangXi=146.9
277FC CJK UNIFIED IDEOGRAPH-#277FC, IRGKangXi=1129.060, RSKangXi=146.10
277FD CJK UNIFIED IDEOGRAPH-#277FD, IRGKangXi=1129.070, RSKangXi=146.10
277FE CJK UNIFIED IDEOGRAPH-#277FE, IRGKangXi=1129.071, RSKangXi=146.10
277FF CJK UNIFIED IDEOGRAPH-#277FF, IRGKangXi=1129.080, RSKangXi=146.11
27800 CJK UNIFIED IDEOGRAPH-#27800, IRGKangXi=1129.091, RSKangXi=146.12
27801 CJK UNIFIED IDEOGRAPH-#27801, IRGKangXi=1129.091, RSKangXi=146.12
27802 CJK UNIFIED IDEOGRAPH-#27802, IRGKangXi=1129.120, RSKangXi=146.13
27803 CJK UNIFIED IDEOGRAPH-#27803, IRGKangXi=1129.121, RSKangXi=146.14
27804 CJK UNIFIED IDEOGRAPH-#27804, IRGKangXi=1129.130, RSKangXi=146.15
27805 CJK UNIFIED IDEOGRAPH-#27805, IRGKangXi=1129.151, RSKangXi=146.19
27806 CJK UNIFIED IDEOGRAPH-#27806, IRGKangXi=1133.020, RSKangXi=147.1
27807 CJK UNIFIED IDEOGRAPH-#27807, IRGKangXi=1133.030, RSKangXi=147.1
27808 CJK UNIFIED IDEOGRAPH-#27808, IRGKangXi=1133.031, RSKangXi=147.2
27809 CJK UNIFIED IDEOGRAPH-#27809, IRGKangXi=1133.060, RSKangXi=147.3
2780A CJK UNIFIED IDEOGRAPH-#2780A, IRGKangXi=1133.070, RSKangXi=147.3
2780B CJK UNIFIED IDEOGRAPH-#2780B, IRGKangXi=1133.100, RSKangXi=147.3
2780C CJK UNIFIED IDEOGRAPH-#2780C, IRGKangXi=1133.101
2780D CJK UNIFIED IDEOGRAPH-#2780D, IRGKangXi=1133.101, RSKangXi=147.3
2780E CJK UNIFIED IDEOGRAPH-#2780E, IRGKangXi=1134.050, RSKangXi=147.4
2780F CJK UNIFIED IDEOGRAPH-#2780F, IRGKangXi=1134.080, RSKangXi=147.4
27810 CJK UNIFIED IDEOGRAPH-#27810, IRGKangXi=1134.090, RSKangXi=147.4
27811 CJK UNIFIED IDEOGRAPH-#27811, IRGKangXi=1134.100, RSKangXi=147.4
27812 CJK UNIFIED IDEOGRAPH-#27812, IRGKangXi=1134.110, RSKangXi=147.4
27813 CJK UNIFIED IDEOGRAPH-#27813, IRGKangXi=1134.120, RSKangXi=147.4
27814 CJK UNIFIED IDEOGRAPH-#27814, IRGKangXi=1134.121, RSKangXi=147.4
27815 CJK UNIFIED IDEOGRAPH-#27815, IRGKangXi=1134.121, RSKangXi=147.4
27816 CJK UNIFIED IDEOGRAPH-#27816, IRGKangXi=1134.121, RSKangXi=147.4
27817 CJK UNIFIED IDEOGRAPH-#27817, IRGKangXi=1134.121, RSKangXi=147.4
27818 CJK UNIFIED IDEOGRAPH-#27818, IRGKangXi=1134.121, RSKangXi=147.4
27819 CJK UNIFIED IDEOGRAPH-#27819, IRGKangXi=1134.121, RSKangXi=147.4
2781A CJK UNIFIED IDEOGRAPH-#2781A, IRGKangXi=1134.121, RSKangXi=147.4
2781B CJK UNIFIED IDEOGRAPH-#2781B, IRGKangXi=1134.121, RSKangXi=147.4
2781C CJK UNIFIED IDEOGRAPH-#2781C, IRGKangXi=1134.140, RSKangXi=147.5
2781D CJK UNIFIED IDEOGRAPH-#2781D, IRGKangXi=1134.160, RSKangXi=147.5
2781E CJK UNIFIED IDEOGRAPH-#2781E, IRGKangXi=1134.170, RSKangXi=147.5
2781F CJK UNIFIED IDEOGRAPH-#2781F, IRGKangXi=1134.180, RSKangXi=147.5
27820 CJK UNIFIED IDEOGRAPH-#27820, IRGKangXi=1134.190, RSKangXi=147.5
27821 CJK UNIFIED IDEOGRAPH-#27821, IRGKangXi=1134.300, RSKangXi=147.5
27822 CJK UNIFIED IDEOGRAPH-#27822, IRGKangXi=1134.310, RSKangXi=147.5
27823 CJK UNIFIED IDEOGRAPH-#27823, IRGKangXi=1134.340, RSKangXi=147.5
27824 CJK UNIFIED IDEOGRAPH-#27824, IRGKangXi=1134.361, RSKangXi=147.5
27825 CJK UNIFIED IDEOGRAPH-#27825, IRGKangXi=1134.361, RSKangXi=147.5
27826 CJK UNIFIED IDEOGRAPH-#27826, IRGKangXi=1134.361, RSKangXi=147.5
27827 CJK UNIFIED IDEOGRAPH-#27827, IRGKangXi=1134.361, RSKangXi=147.5
27828 CJK UNIFIED IDEOGRAPH-#27828, IRGKangXi=1135.020, RSKangXi=147.6
27829 CJK UNIFIED IDEOGRAPH-#27829, IRGKangXi=1135.030, RSKangXi=147.6
2782A CJK UNIFIED IDEOGRAPH-#2782A, IRGKangXi=1135.040, RSKangXi=147.6
2782B CJK UNIFIED IDEOGRAPH-#2782B, IRGKangXi=1135.060, RSKangXi=147.6
2782C CJK UNIFIED IDEOGRAPH-#2782C, IRGKangXi=1135.070, RSKangXi=147.6
2782D CJK UNIFIED IDEOGRAPH-#2782D, IRGKangXi=1135.080, RSKangXi=147.6
2782E CJK UNIFIED IDEOGRAPH-#2782E, IRGKangXi=1135.090, RSKangXi=147.6
2782F CJK UNIFIED IDEOGRAPH-#2782F, IRGKangXi=1135.100, RSKangXi=147.6
27830 CJK UNIFIED IDEOGRAPH-#27830, IRGKangXi=1135.101, RSKangXi=147.6
27831 CJK UNIFIED IDEOGRAPH-#27831, IRGKangXi=1135.101, RSKangXi=147.6
27832 CJK UNIFIED IDEOGRAPH-#27832, IRGKangXi=1135.101, RSKangXi=147.6
27833 CJK UNIFIED IDEOGRAPH-#27833, IRGKangXi=1135.101, RSKangXi=147.6
27834 CJK UNIFIED IDEOGRAPH-#27834, IRGKangXi=1135.101, RSKangXi=147.6
27835 CJK UNIFIED IDEOGRAPH-#27835, IRGKangXi=1135.101, RSKangXi=147.6
27836 CJK UNIFIED IDEOGRAPH-#27836, IRGKangXi=1135.101, RSKangXi=147.6
27837 CJK UNIFIED IDEOGRAPH-#27837, IRGKangXi=1135.101, RSKangXi=147.6
27838 CJK UNIFIED IDEOGRAPH-#27838, IRGKangXi=1135.101, RSKangXi=147.6
27839 CJK UNIFIED IDEOGRAPH-#27839, IRGKangXi=1135.101, RSKangXi=147.6
2783A CJK UNIFIED IDEOGRAPH-#2783A, IRGKangXi=1135.101, RSKangXi=147.6
2783B CJK UNIFIED IDEOGRAPH-#2783B, IRGKangXi=1135.120, RSKangXi=147.7
2783C CJK UNIFIED IDEOGRAPH-#2783C, IRGKangXi=1135.140, RSKangXi=147.7
2783D CJK UNIFIED IDEOGRAPH-#2783D, IRGKangXi=1135.170, RSKangXi=147.7
2783E CJK UNIFIED IDEOGRAPH-#2783E, IRGKangXi=1135.190, RSKangXi=147.7
2783F CJK UNIFIED IDEOGRAPH-#2783F, IRGKangXi=1135.200, RSKangXi=147.7
27840 CJK UNIFIED IDEOGRAPH-#27840, IRGKangXi=1135.220, RSKangXi=147.7
27841 CJK UNIFIED IDEOGRAPH-#27841, IRGKangXi=1135.231, RSKangXi=147.7
27842 CJK UNIFIED IDEOGRAPH-#27842, IRGKangXi=1135.231, RSKangXi=147.7
27843 CJK UNIFIED IDEOGRAPH-#27843, IRGKangXi=1135.231, RSKangXi=147.7
27844 CJK UNIFIED IDEOGRAPH-#27844, IRGKangXi=1135.231, RSKangXi=147.7
27845 CJK UNIFIED IDEOGRAPH-#27845, IRGKangXi=1135.231, RSKangXi=147.7
27846 CJK UNIFIED IDEOGRAPH-#27846, IRGKangXi=1135.231, RSKangXi=147.7
27847 CJK UNIFIED IDEOGRAPH-#27847, IRGKangXi=1135.231, RSKangXi=147.7
27848 CJK UNIFIED IDEOGRAPH-#27848, IRGKangXi=1135.231, RSKangXi=147.7
27849 CJK UNIFIED IDEOGRAPH-#27849, IRGKangXi=1135.231, RSKangXi=147.7
2784A CJK UNIFIED IDEOGRAPH-#2784A, IRGKangXi=1135.231, RSKangXi=147.7
2784B CJK UNIFIED IDEOGRAPH-#2784B, IRGKangXi=1135.240, RSKangXi=147.8
2784C CJK UNIFIED IDEOGRAPH-#2784C, IRGKangXi=1135.250, RSKangXi=147.8
2784D CJK UNIFIED IDEOGRAPH-#2784D, IRGKangXi=1135.280, RSKangXi=147.8
2784E CJK UNIFIED IDEOGRAPH-#2784E, IRGKangXi=1135.290, RSKangXi=147.8
2784F CJK UNIFIED IDEOGRAPH-#2784F, IRGKangXi=1135.340, RSKangXi=147.8
27850 CJK UNIFIED IDEOGRAPH-#27850, IRGKangXi=1135.350, RSKangXi=147.8
27851 CJK UNIFIED IDEOGRAPH-#27851, IRGKangXi=1135.360, RSKangXi=147.8
27852 CJK UNIFIED IDEOGRAPH-#27852, IRGKangXi=1135.370, RSKangXi=147.8
27853 CJK UNIFIED IDEOGRAPH-#27853, IRGKangXi=1135.380, RSKangXi=147.8
27854 CJK UNIFIED IDEOGRAPH-#27854, IRGKangXi=1135.381, RSKangXi=147.8
27855 CJK UNIFIED IDEOGRAPH-#27855, IRGKangXi=1135.381, RSKangXi=147.8
27856 CJK UNIFIED IDEOGRAPH-#27856, IRGKangXi=1135.381, RSKangXi=147.8
27857 CJK UNIFIED IDEOGRAPH-#27857, IRGKangXi=1135.381, RSKangXi=147.8
27858 CJK UNIFIED IDEOGRAPH-#27858, IRGKangXi=1135.381, RSKangXi=147.8
27859 CJK UNIFIED IDEOGRAPH-#27859, IRGKangXi=1135.381, RSKangXi=147.8
2785A CJK UNIFIED IDEOGRAPH-#2785A, IRGKangXi=1135.381, RSKangXi=147.8
2785B CJK UNIFIED IDEOGRAPH-#2785B, IRGKangXi=1135.381, RSKangXi=147.8
2785C CJK UNIFIED IDEOGRAPH-#2785C, IRGKangXi=1135.381, RSKangXi=147.8
2785D CJK UNIFIED IDEOGRAPH-#2785D, IRGKangXi=1135.381, RSKangXi=147.8
2785E CJK UNIFIED IDEOGRAPH-#2785E, IRGKangXi=1135.381, RSKangXi=147.8
2785F CJK UNIFIED IDEOGRAPH-#2785F, IRGKangXi=1135.381, RSKangXi=147.8
27860 CJK UNIFIED IDEOGRAPH-#27860, IRGKangXi=1135.381, RSKangXi=147.8
27861 CJK UNIFIED IDEOGRAPH-#27861, IRGKangXi=1135.410, RSKangXi=147.9
27862 CJK UNIFIED IDEOGRAPH-#27862, IRGKangXi=1135.420, RSKangXi=147.9
27863 CJK UNIFIED IDEOGRAPH-#27863, IRGKangXi=1135.430, RSKangXi=147.9, Def{to look at something unhappily}
27864 CJK UNIFIED IDEOGRAPH-#27864, IRGKangXi=1136.010, RSKangXi=147.9
27865 CJK UNIFIED IDEOGRAPH-#27865, IRGKangXi=1136.040, RSKangXi=147.9
27866 CJK UNIFIED IDEOGRAPH-#27866, IRGKangXi=1136.050, RSKangXi=147.9
27867 CJK UNIFIED IDEOGRAPH-#27867, IRGKangXi=1136.090, RSKangXi=147.9
27868 CJK UNIFIED IDEOGRAPH-#27868, IRGKangXi=1136.100, RSKangXi=147.9
27869 CJK UNIFIED IDEOGRAPH-#27869, IRGKangXi=1136.110, RSKangXi=147.9
2786A CJK UNIFIED IDEOGRAPH-#2786A, IRGKangXi=1136.160, RSKangXi=147.9
2786B CJK UNIFIED IDEOGRAPH-#2786B, IRGKangXi=1136.170, RSKangXi=147.9
2786C CJK UNIFIED IDEOGRAPH-#2786C, IRGKangXi=1136.190, RSKangXi=147.9
2786D CJK UNIFIED IDEOGRAPH-#2786D, IRGKangXi=1136.200, RSKangXi=147.9
2786E CJK UNIFIED IDEOGRAPH-#2786E, IRGKangXi=1136.210, RSKangXi=147.9
2786F CJK UNIFIED IDEOGRAPH-#2786F, IRGKangXi=1136.220, RSKangXi=147.9
27870 CJK UNIFIED IDEOGRAPH-#27870, IRGKangXi=1136.221, RSKangXi=147.9
27871 CJK UNIFIED IDEOGRAPH-#27871, IRGKangXi=1136.221, RSKangXi=147.9
27872 CJK UNIFIED IDEOGRAPH-#27872, IRGKangXi=1136.221, RSKangXi=147.9
27873 CJK UNIFIED IDEOGRAPH-#27873, IRGKangXi=1136.221, RSKangXi=147.9
27874 CJK UNIFIED IDEOGRAPH-#27874, IRGKangXi=1136.221, RSKangXi=147.9
27875 CJK UNIFIED IDEOGRAPH-#27875, IRGKangXi=1136.221, RSKangXi=147.9
27876 CJK UNIFIED IDEOGRAPH-#27876, IRGKangXi=1136.221, RSKangXi=147.9
27877 CJK UNIFIED IDEOGRAPH-#27877, IRGKangXi=1136.250, RSKangXi=147.10
27878 CJK UNIFIED IDEOGRAPH-#27878, IRGKangXi=1136.270, RSKangXi=147.10
27879 CJK UNIFIED IDEOGRAPH-#27879, IRGKangXi=1136.300, RSKangXi=147.10
2787A CJK UNIFIED IDEOGRAPH-#2787A, IRGKangXi=1136.330, RSKangXi=147.10
2787B CJK UNIFIED IDEOGRAPH-#2787B, IRGKangXi=1136.340, RSKangXi=147.10
2787C CJK UNIFIED IDEOGRAPH-#2787C, IRGKangXi=1136.341, RSKangXi=147.10
2787D CJK UNIFIED IDEOGRAPH-#2787D, IRGKangXi=1136.341, RSKangXi=147.10
2787E CJK UNIFIED IDEOGRAPH-#2787E, IRGKangXi=1136.341, RSKangXi=147.10
2787F CJK UNIFIED IDEOGRAPH-#2787F, IRGKangXi=1136.341, RSKangXi=147.10
27880 CJK UNIFIED IDEOGRAPH-#27880, IRGKangXi=1136.341, RSKangXi=147.10
27881 CJK UNIFIED IDEOGRAPH-#27881, IRGKangXi=1136.341, RSKangXi=147.10
27882 CJK UNIFIED IDEOGRAPH-#27882, IRGKangXi=1136.350, RSKangXi=147.11
27883 CJK UNIFIED IDEOGRAPH-#27883, IRGKangXi=1137.020, RSKangXi=147.11
27884 CJK UNIFIED IDEOGRAPH-#27884, IRGKangXi=1137.040, RSKangXi=147.11
27885 CJK UNIFIED IDEOGRAPH-#27885, IRGKangXi=1137.080, RSKangXi=147.11
27886 CJK UNIFIED IDEOGRAPH-#27886, IRGKangXi=1137.090, RSKangXi=147.11
27887 CJK UNIFIED IDEOGRAPH-#27887, IRGKangXi=1137.091, RSKangXi=147.11
27888 CJK UNIFIED IDEOGRAPH-#27888, IRGKangXi=1137.091, RSKangXi=147.11
27889 CJK UNIFIED IDEOGRAPH-#27889, IRGKangXi=1137.091, RSKangXi=147.11
2788A CJK UNIFIED IDEOGRAPH-#2788A, IRGKangXi=1137.091, RSKangXi=147.11
2788B CJK UNIFIED IDEOGRAPH-#2788B, IRGKangXi=1137.091, RSKangXi=147.11
2788C CJK UNIFIED IDEOGRAPH-#2788C, IRGKangXi=1137.170, RSKangXi=147.12
2788D CJK UNIFIED IDEOGRAPH-#2788D, IRGKangXi=1137.180, RSKangXi=147.12
2788E CJK UNIFIED IDEOGRAPH-#2788E, IRGKangXi=1137.200, RSKangXi=147.12
2788F CJK UNIFIED IDEOGRAPH-#2788F, IRGKangXi=1137.201, RSKangXi=147.12
27890 CJK UNIFIED IDEOGRAPH-#27890, IRGKangXi=1137.201, RSKangXi=147.12
27891 CJK UNIFIED IDEOGRAPH-#27891, IRGKangXi=1137.201, RSKangXi=147.12
27892 CJK UNIFIED IDEOGRAPH-#27892, IRGKangXi=1137.220, RSKangXi=147.13
27893 CJK UNIFIED IDEOGRAPH-#27893, IRGKangXi=1137.260, RSKangXi=147.13
27894 CJK UNIFIED IDEOGRAPH-#27894, IRGKangXi=1138.010, RSKangXi=147.13
27895 CJK UNIFIED IDEOGRAPH-#27895, IRGKangXi=1138.011, RSKangXi=147.13
27896 CJK UNIFIED IDEOGRAPH-#27896, IRGKangXi=1138.011, RSKangXi=147.13
27897 CJK UNIFIED IDEOGRAPH-#27897, IRGKangXi=1138.011, RSKangXi=147.13
27898 CJK UNIFIED IDEOGRAPH-#27898, IRGKangXi=1138.021, RSKangXi=147.14
27899 CJK UNIFIED IDEOGRAPH-#27899, IRGKangXi=1138.021, RSKangXi=147.14
2789A CJK UNIFIED IDEOGRAPH-#2789A, IRGKangXi=1138.021, RSKangXi=147.14
2789B CJK UNIFIED IDEOGRAPH-#2789B, IRGKangXi=1138.021, RSKangXi=147.14
2789C CJK UNIFIED IDEOGRAPH-#2789C, IRGKangXi=1138.050, RSKangXi=147.15
2789D CJK UNIFIED IDEOGRAPH-#2789D, IRGKangXi=1138.060, RSKangXi=147.15, Def{(Cant.) to stare angrily}
2789E CJK UNIFIED IDEOGRAPH-#2789E, IRGKangXi=1138.090, RSKangXi=147.15
2789F CJK UNIFIED IDEOGRAPH-#2789F, IRGKangXi=1138.091, RSKangXi=147.15
278A0 CJK UNIFIED IDEOGRAPH-#278A0, IRGKangXi=1138.091, RSKangXi=147.15
278A1 CJK UNIFIED IDEOGRAPH-#278A1, IRGKangXi=1138.091, RSKangXi=147.15
278A2 CJK UNIFIED IDEOGRAPH-#278A2, IRGKangXi=1138.100, RSKangXi=147.17
278A3 CJK UNIFIED IDEOGRAPH-#278A3, IRGKangXi=1138.110, RSKangXi=147.17
278A4 CJK UNIFIED IDEOGRAPH-#278A4, IRGKangXi=1138.111, RSKangXi=147.17
278A5 CJK UNIFIED IDEOGRAPH-#278A5, IRGKangXi=1138.111, RSKangXi=147.17
278A6 CJK UNIFIED IDEOGRAPH-#278A6, IRGKangXi=1138.120, RSKangXi=147.18
278A7 CJK UNIFIED IDEOGRAPH-#278A7, IRGKangXi=1138.130, RSKangXi=147.18
278A8 CJK UNIFIED IDEOGRAPH-#278A8, IRGKangXi=1139.010, RSKangXi=147.18
278A9 CJK UNIFIED IDEOGRAPH-#278A9, IRGKangXi=1139.011, RSKangXi=147.18
278AA CJK UNIFIED IDEOGRAPH-#278AA, IRGKangXi=1139.011, RSKangXi=147.18
278AB CJK UNIFIED IDEOGRAPH-#278AB, IRGKangXi=1139.011, RSKangXi=147.18
278AC CJK UNIFIED IDEOGRAPH-#278AC, IRGKangXi=1139.021, RSKangXi=147.19
278AD CJK UNIFIED IDEOGRAPH-#278AD, IRGKangXi=1139.030, RSKangXi=147.20
278AE CJK UNIFIED IDEOGRAPH-#278AE, IRGKangXi=1139.031, RSKangXi=147.21
278AF CJK UNIFIED IDEOGRAPH-#278AF, IRGKangXi=1139.041, RSKangXi=147.27
278B0 CJK UNIFIED IDEOGRAPH-#278B0, IRGKangXi=1139.041, RSKangXi=147.30
278B1 CJK UNIFIED IDEOGRAPH-#278B1, IRGKangXi=1139.050, RSKangXi=147.37
278B2 CJK UNIFIED IDEOGRAPH-#278B2, IRGKangXi=1139.061, RSKangXi=148.0
278B3 CJK UNIFIED IDEOGRAPH-#278B3, IRGKangXi=1140.010, RSKangXi=148.1
278B4 CJK UNIFIED IDEOGRAPH-#278B4, IRGKangXi=1140.020, RSKangXi=148.2
278B5 CJK UNIFIED IDEOGRAPH-#278B5, IRGKangXi=1140.040, RSKangXi=148.2
278B6 CJK UNIFIED IDEOGRAPH-#278B6, IRGKangXi=1140.051, RSKangXi=148.2
278B7 CJK UNIFIED IDEOGRAPH-#278B7, IRGKangXi=1140.060, RSKangXi=148.3
278B8 CJK UNIFIED IDEOGRAPH-#278B8, IRGKangXi=1140.070, RSKangXi=148.3
278B9 CJK UNIFIED IDEOGRAPH-#278B9, IRGKangXi=1140.080, RSKangXi=148.3
278BA CJK UNIFIED IDEOGRAPH-#278BA, IRGKangXi=1140.090, RSKangXi=148.3
278BB CJK UNIFIED IDEOGRAPH-#278BB, IRGKangXi=1140.110, RSKangXi=148.4
278BC CJK UNIFIED IDEOGRAPH-#278BC, IRGKangXi=1140.140, RSKangXi=148.4
278BD CJK UNIFIED IDEOGRAPH-#278BD, IRGKangXi=1140.160, RSKangXi=148.4
278BE CJK UNIFIED IDEOGRAPH-#278BE, IRGKangXi=1140.170, RSKangXi=148.4
278BF CJK UNIFIED IDEOGRAPH-#278BF, IRGKangXi=1140.180, RSKangXi=148.4
278C0 CJK UNIFIED IDEOGRAPH-#278C0, IRGKangXi=1140.190, RSKangXi=148.4
278C1 CJK UNIFIED IDEOGRAPH-#278C1, IRGKangXi=1140.200, RSKangXi=148.4
278C2 CJK UNIFIED IDEOGRAPH-#278C2, IRGKangXi=1140.210, RSKangXi=148.4
278C3 CJK UNIFIED IDEOGRAPH-#278C3, IRGKangXi=1140.230, RSKangXi=148.4
278C4 CJK UNIFIED IDEOGRAPH-#278C4, IRGKangXi=1140.250, RSKangXi=148.4
278C5 CJK UNIFIED IDEOGRAPH-#278C5, IRGKangXi=1140.251, RSKangXi=148.4
278C6 CJK UNIFIED IDEOGRAPH-#278C6, IRGKangXi=1140.251, RSKangXi=148.4
278C7 CJK UNIFIED IDEOGRAPH-#278C7, IRGKangXi=1140.251, RSKangXi=148.4
278C8 CJK UNIFIED IDEOGRAPH-#278C8, IRGKangXi=1140.251, RSKangXi=148.4, Def{(Cant.) to gore}
278C9 CJK UNIFIED IDEOGRAPH-#278C9, IRGKangXi=1140.251, RSKangXi=148.4
278CA CJK UNIFIED IDEOGRAPH-#278CA, IRGKangXi=1140.251, RSKangXi=148.4
278CB CJK UNIFIED IDEOGRAPH-#278CB, IRGKangXi=1140.251, RSKangXi=148.4
278CC CJK UNIFIED IDEOGRAPH-#278CC, IRGKangXi=1140.251, RSKangXi=148.4
278CD CJK UNIFIED IDEOGRAPH-#278CD, IRGKangXi=1140.251, RSKangXi=148.4
278CE CJK UNIFIED IDEOGRAPH-#278CE, IRGKangXi=1140.251, RSKangXi=148.4
278CF CJK UNIFIED IDEOGRAPH-#278CF, IRGKangXi=1140.251, RSKangXi=148.4
278D0 CJK UNIFIED IDEOGRAPH-#278D0, IRGKangXi=1140.251, RSKangXi=148.4
278D1 CJK UNIFIED IDEOGRAPH-#278D1, IRGKangXi=1140.260, RSKangXi=148.5
278D2 CJK UNIFIED IDEOGRAPH-#278D2, IRGKangXi=1140.270, RSKangXi=148.5
278D3 CJK UNIFIED IDEOGRAPH-#278D3, IRGKangXi=1140.280, RSKangXi=148.5
278D4 CJK UNIFIED IDEOGRAPH-#278D4, IRGKangXi=1140.290, RSKangXi=148.5
278D5 CJK UNIFIED IDEOGRAPH-#278D5, IRGKangXi=1140.300, RSKangXi=148.5
278D6 CJK UNIFIED IDEOGRAPH-#278D6, IRGKangXi=1141.010, RSKangXi=148.5
278D7 CJK UNIFIED IDEOGRAPH-#278D7, IRGKangXi=1141.020, RSKangXi=148.5
278D8 CJK UNIFIED IDEOGRAPH-#278D8, IRGKangXi=1141.030, RSKangXi=148.5
278D9 CJK UNIFIED IDEOGRAPH-#278D9, IRGKangXi=1141.040, RSKangXi=148.5
278DA CJK UNIFIED IDEOGRAPH-#278DA, IRGKangXi=1141.060, RSKangXi=148.5
278DB CJK UNIFIED IDEOGRAPH-#278DB, IRGKangXi=1141.070, RSKangXi=148.5
278DC CJK UNIFIED IDEOGRAPH-#278DC, IRGKangXi=1141.100, RSKangXi=148.5
278DD CJK UNIFIED IDEOGRAPH-#278DD, IRGKangXi=1141.101, RSKangXi=148.5
278DE CJK UNIFIED IDEOGRAPH-#278DE, IRGKangXi=1141.101, RSKangXi=148.5
278DF CJK UNIFIED IDEOGRAPH-#278DF, IRGKangXi=1141.101, RSKangXi=148.5
278E0 CJK UNIFIED IDEOGRAPH-#278E0, IRGKangXi=1141.101, RSKangXi=148.5
278E1 CJK UNIFIED IDEOGRAPH-#278E1, IRGKangXi=1141.110, RSKangXi=148.6
278E2 CJK UNIFIED IDEOGRAPH-#278E2, IRGKangXi=1141.120, RSKangXi=148.6
278E3 CJK UNIFIED IDEOGRAPH-#278E3, IRGKangXi=1143.010, RSKangXi=148.6
278E4 CJK UNIFIED IDEOGRAPH-#278E4, IRGKangXi=1143.021, RSKangXi=148.6
278E5 CJK UNIFIED IDEOGRAPH-#278E5, IRGKangXi=1143.021, RSKangXi=148.6
278E6 CJK UNIFIED IDEOGRAPH-#278E6, IRGKangXi=1143.021, RSKangXi=148.6
278E7 CJK UNIFIED IDEOGRAPH-#278E7, IRGKangXi=1143.021, RSKangXi=148.6
278E8 CJK UNIFIED IDEOGRAPH-#278E8, IRGKangXi=1143.030, RSKangXi=148.7
278E9 CJK UNIFIED IDEOGRAPH-#278E9, IRGKangXi=1143.050, RSKangXi=148.7
278EA CJK UNIFIED IDEOGRAPH-#278EA, IRGKangXi=1143.060, RSKangXi=148.7
278EB CJK UNIFIED IDEOGRAPH-#278EB, IRGKangXi=1143.080, RSKangXi=148.7
278EC CJK UNIFIED IDEOGRAPH-#278EC, IRGKangXi=1143.110, RSKangXi=148.7
278ED CJK UNIFIED IDEOGRAPH-#278ED, IRGKangXi=1143.130, RSKangXi=148.7
278EE CJK UNIFIED IDEOGRAPH-#278EE, IRGKangXi=1143.140, RSKangXi=148.7
278EF CJK UNIFIED IDEOGRAPH-#278EF, IRGKangXi=1143.150, RSKangXi=148.7
278F0 CJK UNIFIED IDEOGRAPH-#278F0, IRGKangXi=1143.160, RSKangXi=148.7
278F1 CJK UNIFIED IDEOGRAPH-#278F1, IRGKangXi=1143.161, RSKangXi=148.7
278F2 CJK UNIFIED IDEOGRAPH-#278F2, IRGKangXi=1143.161, RSKangXi=148.7
278F3 CJK UNIFIED IDEOGRAPH-#278F3, IRGKangXi=1143.161, RSKangXi=148.7
278F4 CJK UNIFIED IDEOGRAPH-#278F4, IRGKangXi=1143.190, RSKangXi=148.8, Def{a cup}
278F5 CJK UNIFIED IDEOGRAPH-#278F5, IRGKangXi=1143.200, RSKangXi=148.8
278F6 CJK UNIFIED IDEOGRAPH-#278F6, IRGKangXi=1143.210, RSKangXi=148.8
278F7 CJK UNIFIED IDEOGRAPH-#278F7, IRGKangXi=1143.220, RSKangXi=148.8
278F8 CJK UNIFIED IDEOGRAPH-#278F8, IRGKangXi=1143.230, RSKangXi=148.8
278F9 CJK UNIFIED IDEOGRAPH-#278F9, IRGKangXi=1143.240, RSKangXi=148.8
278FA CJK UNIFIED IDEOGRAPH-#278FA, IRGKangXi=1143.280, RSKangXi=148.8
278FB CJK UNIFIED IDEOGRAPH-#278FB, IRGKangXi=1143.290, RSKangXi=148.8
278FC CJK UNIFIED IDEOGRAPH-#278FC, IRGKangXi=1143.300, RSKangXi=148.8
278FD CJK UNIFIED IDEOGRAPH-#278FD, IRGKangXi=1143.340, RSKangXi=148.8
278FE CJK UNIFIED IDEOGRAPH-#278FE, IRGKangXi=1143.350, RSKangXi=148.8
278FF CJK UNIFIED IDEOGRAPH-#278FF, IRGKangXi=1143.351, RSKangXi=148.8
27900 CJK UNIFIED IDEOGRAPH-#27900, IRGKangXi=1143.351, RSKangXi=148.8
27901 CJK UNIFIED IDEOGRAPH-#27901, IRGKangXi=1143.351, RSKangXi=148.8
27902 CJK UNIFIED IDEOGRAPH-#27902, IRGKangXi=1143.351, RSKangXi=148.8
27903 CJK UNIFIED IDEOGRAPH-#27903, IRGKangXi=1143.351, RSKangXi=148.8
27904 CJK UNIFIED IDEOGRAPH-#27904, IRGKangXi=1143.351, RSKangXi=148.8
27905 CJK UNIFIED IDEOGRAPH-#27905, IRGKangXi=1143.351, RSKangXi=148.8
27906 CJK UNIFIED IDEOGRAPH-#27906, IRGKangXi=1143.351, RSKangXi=148.8
27907 CJK UNIFIED IDEOGRAPH-#27907, IRGKangXi=1143.351, RSKangXi=148.8
27908 CJK UNIFIED IDEOGRAPH-#27908, IRGKangXi=1143.351, RSKangXi=148.8
27909 CJK UNIFIED IDEOGRAPH-#27909, IRGKangXi=1143.351, RSKangXi=148.8
2790A CJK UNIFIED IDEOGRAPH-#2790A, IRGKangXi=1143.351, RSKangXi=148.8
2790B CJK UNIFIED IDEOGRAPH-#2790B, IRGKangXi=1143.370, RSKangXi=148.9
2790C CJK UNIFIED IDEOGRAPH-#2790C, IRGKangXi=1143.390, RSKangXi=148.9
2790D CJK UNIFIED IDEOGRAPH-#2790D, IRGKangXi=1143.400, RSKangXi=148.9
2790E CJK UNIFIED IDEOGRAPH-#2790E, IRGKangXi=1143.410, RSKangXi=148.9
2790F CJK UNIFIED IDEOGRAPH-#2790F, IRGKangXi=1143.420, RSKangXi=148.9
27910 CJK UNIFIED IDEOGRAPH-#27910, IRGKangXi=1144.010, RSKangXi=148.9
27911 CJK UNIFIED IDEOGRAPH-#27911, IRGKangXi=1144.020, RSKangXi=148.9
27912 CJK UNIFIED IDEOGRAPH-#27912, IRGKangXi=1144.030, RSKangXi=148.9
27913 CJK UNIFIED IDEOGRAPH-#27913, IRGKangXi=1144.040, RSKangXi=148.9
27914 CJK UNIFIED IDEOGRAPH-#27914, IRGKangXi=1144.050, RSKangXi=148.9
27915 CJK UNIFIED IDEOGRAPH-#27915, IRGKangXi=1144.060, RSKangXi=148.9
27916 CJK UNIFIED IDEOGRAPH-#27916, IRGKangXi=1144.070, RSKangXi=148.9
27917 CJK UNIFIED IDEOGRAPH-#27917, IRGKangXi=1144.100, RSKangXi=148.9
27918 CJK UNIFIED IDEOGRAPH-#27918, IRGKangXi=1144.101, RSKangXi=148.9
27919 CJK UNIFIED IDEOGRAPH-#27919, IRGKangXi=1144.101, RSKangXi=148.9
2791A CJK UNIFIED IDEOGRAPH-#2791A, IRGKangXi=1144.101, RSKangXi=148.9
2791B CJK UNIFIED IDEOGRAPH-#2791B, IRGKangXi=1144.120, RSKangXi=148.10
2791C CJK UNIFIED IDEOGRAPH-#2791C, IRGKangXi=1144.130, RSKangXi=148.10
2791D CJK UNIFIED IDEOGRAPH-#2791D, IRGKangXi=1144.150, RSKangXi=148.10
2791E CJK UNIFIED IDEOGRAPH-#2791E, IRGKangXi=1144.170, RSKangXi=148.10
2791F CJK UNIFIED IDEOGRAPH-#2791F, IRGKangXi=1144.190, RSKangXi=148.10
27920 CJK UNIFIED IDEOGRAPH-#27920, IRGKangXi=1144.200, RSKangXi=148.10
27921 CJK UNIFIED IDEOGRAPH-#27921, IRGKangXi=1144.210, RSKangXi=148.10
27922 CJK UNIFIED IDEOGRAPH-#27922, IRGKangXi=1144.220, RSKangXi=148.9
27923 CJK UNIFIED IDEOGRAPH-#27923, IRGKangXi=1144.230, RSKangXi=148.10
27924 CJK UNIFIED IDEOGRAPH-#27924, IRGKangXi=1144.231, RSKangXi=148.10
27925 CJK UNIFIED IDEOGRAPH-#27925, IRGKangXi=1144.231, RSKangXi=148.10
27926 CJK UNIFIED IDEOGRAPH-#27926, IRGKangXi=1144.231, RSKangXi=148.10
27927 CJK UNIFIED IDEOGRAPH-#27927, IRGKangXi=1144.231, RSKangXi=148.10
27928 CJK UNIFIED IDEOGRAPH-#27928, IRGKangXi=1144.231, RSKangXi=148.10
27929 CJK UNIFIED IDEOGRAPH-#27929, IRGKangXi=1144.231, RSKangXi=148.10
2792A CJK UNIFIED IDEOGRAPH-#2792A, IRGKangXi=1144.231, RSKangXi=148.10
2792B CJK UNIFIED IDEOGRAPH-#2792B, IRGKangXi=1144.231, RSKangXi=148.10
2792C CJK UNIFIED IDEOGRAPH-#2792C, IRGKangXi=1144.231, RSKangXi=148.10
2792D CJK UNIFIED IDEOGRAPH-#2792D, IRGKangXi=1144.231, RSKangXi=148.10
2792E CJK UNIFIED IDEOGRAPH-#2792E, IRGKangXi=1144.231, RSKangXi=148.10
2792F CJK UNIFIED IDEOGRAPH-#2792F, IRGKangXi=1144.240, RSKangXi=148.11
27930 CJK UNIFIED IDEOGRAPH-#27930, IRGKangXi=1144.270, RSKangXi=148.11
27931 CJK UNIFIED IDEOGRAPH-#27931, IRGKangXi=1144.280, RSKangXi=148.11
27932 CJK UNIFIED IDEOGRAPH-#27932, IRGKangXi=1144.290, RSKangXi=148.11
27933 CJK UNIFIED IDEOGRAPH-#27933, IRGKangXi=1144.300, RSKangXi=148.11
27934 CJK UNIFIED IDEOGRAPH-#27934, IRGKangXi=1144.301, RSKangXi=148.11
27935 CJK UNIFIED IDEOGRAPH-#27935, IRGKangXi=1144.301, RSKangXi=148.11
27936 CJK UNIFIED IDEOGRAPH-#27936, IRGKangXi=1144.301, RSKangXi=148.11
27937 CJK UNIFIED IDEOGRAPH-#27937, IRGKangXi=1144.301, RSKangXi=148.11
27938 CJK UNIFIED IDEOGRAPH-#27938, IRGKangXi=1144.301, RSKangXi=148.11
27939 CJK UNIFIED IDEOGRAPH-#27939, IRGKangXi=1144.301, RSKangXi=148.11
2793A CJK UNIFIED IDEOGRAPH-#2793A, IRGKangXi=1144.310, RSKangXi=148.12
2793B CJK UNIFIED IDEOGRAPH-#2793B, IRGKangXi=1144.330, RSKangXi=148.12
2793C CJK UNIFIED IDEOGRAPH-#2793C, IRGKangXi=1145.020, RSKangXi=148.12
2793D CJK UNIFIED IDEOGRAPH-#2793D, IRGKangXi=1145.050, RSKangXi=148.12
2793E CJK UNIFIED IDEOGRAPH-#2793E, IRGKangXi=1145.070, RSKangXi=148.12
2793F CJK UNIFIED IDEOGRAPH-#2793F, IRGKangXi=1145.080, RSKangXi=148.12
27940 CJK UNIFIED IDEOGRAPH-#27940, IRGKangXi=1145.081, RSKangXi=148.12
27941 CJK UNIFIED IDEOGRAPH-#27941, IRGKangXi=1145.081, RSKangXi=148.12
27942 CJK UNIFIED IDEOGRAPH-#27942, IRGKangXi=1145.081, RSKangXi=148.12
27943 CJK UNIFIED IDEOGRAPH-#27943, IRGKangXi=1145.081, RSKangXi=148.12
27944 CJK UNIFIED IDEOGRAPH-#27944, IRGKangXi=1145.130, RSKangXi=148.13
27945 CJK UNIFIED IDEOGRAPH-#27945, IRGKangXi=1145.151, RSKangXi=148.13
27946 CJK UNIFIED IDEOGRAPH-#27946, IRGKangXi=1145.151, RSKangXi=148.13
27947 CJK UNIFIED IDEOGRAPH-#27947, IRGKangXi=1145.151, RSKangXi=148.13
27948 CJK UNIFIED IDEOGRAPH-#27948, IRGKangXi=1145.170, RSKangXi=148.14
27949 CJK UNIFIED IDEOGRAPH-#27949, IRGKangXi=1145.180, RSKangXi=148.14
2794A CJK UNIFIED IDEOGRAPH-#2794A, IRGKangXi=1145.190, RSKangXi=148.14
2794B CJK UNIFIED IDEOGRAPH-#2794B, IRGKangXi=1145.191, RSKangXi=148.14
2794C CJK UNIFIED IDEOGRAPH-#2794C, IRGKangXi=1145.200, RSKangXi=148.15
2794D CJK UNIFIED IDEOGRAPH-#2794D, IRGKangXi=1145.210, RSKangXi=148.15
2794E CJK UNIFIED IDEOGRAPH-#2794E, IRGKangXi=1145.230, RSKangXi=148.15
2794F CJK UNIFIED IDEOGRAPH-#2794F, IRGKangXi=1145.231, RSKangXi=148.15
27950 CJK UNIFIED IDEOGRAPH-#27950, IRGKangXi=1145.231, RSKangXi=148.15
27951 CJK UNIFIED IDEOGRAPH-#27951, IRGKangXi=1145.240, RSKangXi=148.16
27952 CJK UNIFIED IDEOGRAPH-#27952, IRGKangXi=1145.251, RSKangXi=148.16
27953 CJK UNIFIED IDEOGRAPH-#27953, IRGKangXi=1145.260, RSKangXi=148.17
27954 CJK UNIFIED IDEOGRAPH-#27954, IRGKangXi=1145.271, RSKangXi=148.17
27955 CJK UNIFIED IDEOGRAPH-#27955, IRGKangXi=1145.300, RSKangXi=148.18
27956 CJK UNIFIED IDEOGRAPH-#27956, IRGKangXi=1145.310, RSKangXi=148.19
27957 CJK UNIFIED IDEOGRAPH-#27957, IRGKangXi=1145.311, RSKangXi=148.21
27958 CJK UNIFIED IDEOGRAPH-#27958, IRGKangXi=1145.311, RSKangXi=148.21
27959 CJK UNIFIED IDEOGRAPH-#27959, IRGKangXi=1145.311, RSKangXi=148.22
2795A CJK UNIFIED IDEOGRAPH-#2795A, IRGKangXi=1145.311, RSKangXi=148.22
2795B CJK UNIFIED IDEOGRAPH-#2795B, IRGKangXi=1146.040, RSKangXi=149.-1
2795C CJK UNIFIED IDEOGRAPH-#2795C, IRGKangXi=1146.050, RSKangXi=149.-1
2795D CJK UNIFIED IDEOGRAPH-#2795D, IRGKangXi=1146.060, RSKangXi=149.1
2795E CJK UNIFIED IDEOGRAPH-#2795E, IRGKangXi=1146.061, RSKangXi=149.1
2795F CJK UNIFIED IDEOGRAPH-#2795F, IRGKangXi=1146.061, RSKangXi=149.1
27960 CJK UNIFIED IDEOGRAPH-#27960, IRGKangXi=1147.011, RSKangXi=149.2
27961 CJK UNIFIED IDEOGRAPH-#27961, IRGKangXi=1147.030, RSKangXi=149.3
27962 CJK UNIFIED IDEOGRAPH-#27962, IRGKangXi=1147.100, RSKangXi=149.3
27963 CJK UNIFIED IDEOGRAPH-#27963, IRGKangXi=1147.150, RSKangXi=149.3
27964 CJK UNIFIED IDEOGRAPH-#27964, IRGKangXi=1148.030, RSKangXi=149.3
27965 CJK UNIFIED IDEOGRAPH-#27965, IRGKangXi=1148.090, RSKangXi=149.3
27966 CJK UNIFIED IDEOGRAPH-#27966, IRGKangXi=1149.040, RSKangXi=149.3
27967 CJK UNIFIED IDEOGRAPH-#27967, IRGKangXi=1149.041, RSKangXi=149.3
27968 CJK UNIFIED IDEOGRAPH-#27968, IRGKangXi=1149.041, RSKangXi=149.3
27969 CJK UNIFIED IDEOGRAPH-#27969, IRGKangXi=1149.041, RSKangXi=149.3
2796A CJK UNIFIED IDEOGRAPH-#2796A, IRGKangXi=1149.041, RSKangXi=149.3
2796B CJK UNIFIED IDEOGRAPH-#2796B, IRGKangXi=1149.041, RSKangXi=149.3
2796C CJK UNIFIED IDEOGRAPH-#2796C, IRGKangXi=1149.041, RSKangXi=149.3
2796D CJK UNIFIED IDEOGRAPH-#2796D, IRGKangXi=1149.041, RSKangXi=149.3
2796E CJK UNIFIED IDEOGRAPH-#2796E, IRGKangXi=1149.060, RSKangXi=149.4
2796F CJK UNIFIED IDEOGRAPH-#2796F, IRGKangXi=1149.070, RSKangXi=149.4
27970 CJK UNIFIED IDEOGRAPH-#27970, IRGKangXi=1149.090, RSKangXi=149.4
27971 CJK UNIFIED IDEOGRAPH-#27971, IRGKangXi=1149.140, RSKangXi=149.4
27972 CJK UNIFIED IDEOGRAPH-#27972, IRGKangXi=1150.120, RSKangXi=149.4
27973 CJK UNIFIED IDEOGRAPH-#27973, IRGKangXi=1150.150, RSKangXi=149.4
27974 CJK UNIFIED IDEOGRAPH-#27974, IRGKangXi=1151.010, RSKangXi=149.4
27975 CJK UNIFIED IDEOGRAPH-#27975, IRGKangXi=1151.030, RSKangXi=149.4
27976 CJK UNIFIED IDEOGRAPH-#27976, IRGKangXi=1151.050, RSKangXi=149.4
27977 CJK UNIFIED IDEOGRAPH-#27977, IRGKangXi=1151.150, RSKangXi=149.4
27978 CJK UNIFIED IDEOGRAPH-#27978, IRGKangXi=1151.160, RSKangXi=149.4
27979 CJK UNIFIED IDEOGRAPH-#27979, IRGKangXi=1151.170, RSKangXi=149.4
2797A CJK UNIFIED IDEOGRAPH-#2797A, IRGKangXi=1151.190, RSKangXi=149.4, Def{(Cant.) to fool, deceive, hoodwink}
2797B CJK UNIFIED IDEOGRAPH-#2797B, IRGKangXi=1152.010, RSKangXi=149.4
2797C CJK UNIFIED IDEOGRAPH-#2797C, IRGKangXi=1152.020, RSKangXi=149.4
2797D CJK UNIFIED IDEOGRAPH-#2797D, IRGKangXi=1152.030, RSKangXi=149.4
2797E CJK UNIFIED IDEOGRAPH-#2797E, IRGKangXi=1152.040, RSKangXi=149.4
2797F CJK UNIFIED IDEOGRAPH-#2797F, IRGKangXi=1152.090, RSKangXi=149.4
27980 CJK UNIFIED IDEOGRAPH-#27980, IRGKangXi=1152.100, RSKangXi=149.4
27981 CJK UNIFIED IDEOGRAPH-#27981, IRGKangXi=1152.110, RSKangXi=149.4
27982 CJK UNIFIED IDEOGRAPH-#27982, IRGKangXi=1152.120, RSKangXi=149.4
27983 CJK UNIFIED IDEOGRAPH-#27983, IRGKangXi=1152.121, RSKangXi=149.4
27984 CJK UNIFIED IDEOGRAPH-#27984, IRGKangXi=1152.121, RSKangXi=149.4
27985 CJK UNIFIED IDEOGRAPH-#27985, IRGKangXi=1152.121, RSKangXi=149.4
27986 CJK UNIFIED IDEOGRAPH-#27986, IRGKangXi=1152.121, RSKangXi=149.4
27987 CJK UNIFIED IDEOGRAPH-#27987, IRGKangXi=1152.121, RSKangXi=149.4
27988 CJK UNIFIED IDEOGRAPH-#27988, IRGKangXi=1152.121, RSKangXi=149.4
27989 CJK UNIFIED IDEOGRAPH-#27989, IRGKangXi=1152.121, RSKangXi=149.4
2798A CJK UNIFIED IDEOGRAPH-#2798A, IRGKangXi=1152.121, RSKangXi=149.4
2798B CJK UNIFIED IDEOGRAPH-#2798B, IRGKangXi=1152.121, RSKangXi=149.4
2798C CJK UNIFIED IDEOGRAPH-#2798C, IRGKangXi=1152.121, RSKangXi=149.4
2798D CJK UNIFIED IDEOGRAPH-#2798D, IRGKangXi=1152.121, RSKangXi=149.4
2798E CJK UNIFIED IDEOGRAPH-#2798E, IRGKangXi=1152.121, RSKangXi=149.4
2798F CJK UNIFIED IDEOGRAPH-#2798F, IRGKangXi=1152.121, RSKangXi=149.4
27990 CJK UNIFIED IDEOGRAPH-#27990, IRGKangXi=1152.121, RSKangXi=149.4
27991 CJK UNIFIED IDEOGRAPH-#27991, IRGKangXi=1152.121, RSKangXi=149.4
27992 CJK UNIFIED IDEOGRAPH-#27992, IRGKangXi=1152.121, RSKangXi=149.4
27993 CJK UNIFIED IDEOGRAPH-#27993, IRGKangXi=1152.121, RSKangXi=149.4
27994 CJK UNIFIED IDEOGRAPH-#27994, IRGKangXi=1152.121, RSKangXi=149.4
27995 CJK UNIFIED IDEOGRAPH-#27995, IRGKangXi=1152.121, RSKangXi=149.4
27996 CJK UNIFIED IDEOGRAPH-#27996, IRGKangXi=1152.121, RSKangXi=149.4
27997 CJK UNIFIED IDEOGRAPH-#27997, IRGKangXi=1152.121, RSKangXi=149.4
27998 CJK UNIFIED IDEOGRAPH-#27998, IRGKangXi=1152.121, RSKangXi=149.4
27999 CJK UNIFIED IDEOGRAPH-#27999, IRGKangXi=1152.121, RSKangXi=149.4
2799A CJK UNIFIED IDEOGRAPH-#2799A, IRGKangXi=1152.121, RSKangXi=149.4
2799B CJK UNIFIED IDEOGRAPH-#2799B, IRGKangXi=1152.121, RSKangXi=149.4
2799C CJK UNIFIED IDEOGRAPH-#2799C, IRGKangXi=1152.250, RSKangXi=149.5
2799D CJK UNIFIED IDEOGRAPH-#2799D, IRGKangXi=1152.280, RSKangXi=149.5
2799E CJK UNIFIED IDEOGRAPH-#2799E, IRGKangXi=1153.050, RSKangXi=149.5
2799F CJK UNIFIED IDEOGRAPH-#2799F, IRGKangXi=1153.060, RSKangXi=149.5
279A0 CJK UNIFIED IDEOGRAPH-#279A0, IRGKangXi=1153.120, RSKangXi=149.5, Def{(Cant.) to deceive}
279A1 CJK UNIFIED IDEOGRAPH-#279A1, IRGKangXi=1154.050, RSKangXi=149.5
279A2 CJK UNIFIED IDEOGRAPH-#279A2, IRGKangXi=1154.100, RSKangXi=149.5
279A3 CJK UNIFIED IDEOGRAPH-#279A3, IRGKangXi=1154.140, RSKangXi=149.5
279A4 CJK UNIFIED IDEOGRAPH-#279A4, IRGKangXi=1154.150, RSKangXi=149.5
279A5 CJK UNIFIED IDEOGRAPH-#279A5, IRGKangXi=1154.170, RSKangXi=149.5
279A6 CJK UNIFIED IDEOGRAPH-#279A6, IRGKangXi=1154.190, RSKangXi=149.5
279A7 CJK UNIFIED IDEOGRAPH-#279A7, IRGKangXi=1154.220, RSKangXi=149.5
279A8 CJK UNIFIED IDEOGRAPH-#279A8, IRGKangXi=1155.010, RSKangXi=149.5
279A9 CJK UNIFIED IDEOGRAPH-#279A9, IRGKangXi=1155.040, RSKangXi=149.5
279AA CJK UNIFIED IDEOGRAPH-#279AA, IRGKangXi=1155.070, RSKangXi=149.5
279AB CJK UNIFIED IDEOGRAPH-#279AB, IRGKangXi=1156.080, RSKangXi=149.5
279AC CJK UNIFIED IDEOGRAPH-#279AC, IRGKangXi=1156.130, RSKangXi=149.5
279AD CJK UNIFIED IDEOGRAPH-#279AD, IRGKangXi=1156.150, RSKangXi=149.5
279AE CJK UNIFIED IDEOGRAPH-#279AE, IRGKangXi=1156.160, RSKangXi=149.5
279AF CJK UNIFIED IDEOGRAPH-#279AF, IRGKangXi=1156.170, RSKangXi=149.5
279B0 CJK UNIFIED IDEOGRAPH-#279B0, IRGKangXi=1156.171, RSKangXi=149.5
279B1 CJK UNIFIED IDEOGRAPH-#279B1, IRGKangXi=1156.171, RSKangXi=149.5
279B2 CJK UNIFIED IDEOGRAPH-#279B2, IRGKangXi=1156.171, RSKangXi=149.5
279B3 CJK UNIFIED IDEOGRAPH-#279B3, IRGKangXi=1156.171, RSKangXi=149.5
279B4 CJK UNIFIED IDEOGRAPH-#279B4, IRGKangXi=1156.171, RSKangXi=149.5
279B5 CJK UNIFIED IDEOGRAPH-#279B5, IRGKangXi=1156.171, RSKangXi=149.5
279B6 CJK UNIFIED IDEOGRAPH-#279B6, IRGKangXi=1156.171, RSKangXi=149.5
279B7 CJK UNIFIED IDEOGRAPH-#279B7, IRGKangXi=1156.171, RSKangXi=149.5
279B8 CJK UNIFIED IDEOGRAPH-#279B8, IRGKangXi=1156.171, RSKangXi=149.5
279B9 CJK UNIFIED IDEOGRAPH-#279B9, IRGKangXi=1156.171, RSKangXi=149.5
279BA CJK UNIFIED IDEOGRAPH-#279BA, IRGKangXi=1156.171, RSKangXi=149.5
279BB CJK UNIFIED IDEOGRAPH-#279BB, IRGKangXi=1156.171, RSKangXi=149.5
279BC CJK UNIFIED IDEOGRAPH-#279BC, IRGKangXi=1156.171, RSKangXi=149.5
279BD CJK UNIFIED IDEOGRAPH-#279BD, IRGKangXi=1156.171, RSKangXi=149.5
279BE CJK UNIFIED IDEOGRAPH-#279BE, IRGKangXi=1156.171, RSKangXi=149.5
279BF CJK UNIFIED IDEOGRAPH-#279BF, IRGKangXi=1156.171, RSKangXi=149.5
279C0 CJK UNIFIED IDEOGRAPH-#279C0, IRGKangXi=1156.171, RSKangXi=149.5
279C1 CJK UNIFIED IDEOGRAPH-#279C1, IRGKangXi=1156.171, RSKangXi=149.5
279C2 CJK UNIFIED IDEOGRAPH-#279C2, IRGKangXi=1156.171, RSKangXi=149.5
279C3 CJK UNIFIED IDEOGRAPH-#279C3, IRGKangXi=1157.080, RSKangXi=149.6
279C4 CJK UNIFIED IDEOGRAPH-#279C4, IRGKangXi=1157.100, RSKangXi=149.6
279C5 CJK UNIFIED IDEOGRAPH-#279C5, IRGKangXi=1157.110, RSKangXi=149.6
279C6 CJK UNIFIED IDEOGRAPH-#279C6, IRGKangXi=1157.120, RSKangXi=149.6
279C7 CJK UNIFIED IDEOGRAPH-#279C7, IRGKangXi=1157.180, RSKangXi=149.6
279C8 CJK UNIFIED IDEOGRAPH-#279C8, IRGKangXi=1157.190, RSKangXi=149.6
279C9 CJK UNIFIED IDEOGRAPH-#279C9, IRGKangXi=1157.200, RSKangXi=149.6
279CA CJK UNIFIED IDEOGRAPH-#279CA, IRGKangXi=1158.010, RSKangXi=149.6
279CB CJK UNIFIED IDEOGRAPH-#279CB, IRGKangXi=1158.080, RSKangXi=149.6
279CC CJK UNIFIED IDEOGRAPH-#279CC, IRGKangXi=1158.120, RSKangXi=149.6
279CD CJK UNIFIED IDEOGRAPH-#279CD, IRGKangXi=1158.130, RSKangXi=149.6
279CE CJK UNIFIED IDEOGRAPH-#279CE, IRGKangXi=1158.140, RSKangXi=149.6
279CF CJK UNIFIED IDEOGRAPH-#279CF, IRGKangXi=1159.030, RSKangXi=149.6
279D0 CJK UNIFIED IDEOGRAPH-#279D0, IRGKangXi=1159.040, RSKangXi=149.6
279D1 CJK UNIFIED IDEOGRAPH-#279D1, IRGKangXi=1159.050, RSKangXi=149.6
279D2 CJK UNIFIED IDEOGRAPH-#279D2, IRGKangXi=1159.060, RSKangXi=149.6
279D3 CJK UNIFIED IDEOGRAPH-#279D3, IRGKangXi=1159.090, RSKangXi=149.6
279D4 CJK UNIFIED IDEOGRAPH-#279D4, IRGKangXi=1159.100, RSKangXi=149.6
279D5 CJK UNIFIED IDEOGRAPH-#279D5, IRGKangXi=1159.120, RSKangXi=149.6
279D6 CJK UNIFIED IDEOGRAPH-#279D6, IRGKangXi=1159.140, RSKangXi=149.6
279D7 CJK UNIFIED IDEOGRAPH-#279D7, IRGKangXi=1160.030, RSKangXi=149.6
279D8 CJK UNIFIED IDEOGRAPH-#279D8, IRGKangXi=1160.040, RSKangXi=149.6
279D9 CJK UNIFIED IDEOGRAPH-#279D9, IRGKangXi=1161.040, RSKangXi=149.6
279DA CJK UNIFIED IDEOGRAPH-#279DA, IRGKangXi=1161.060, RSKangXi=149.6
279DB CJK UNIFIED IDEOGRAPH-#279DB, IRGKangXi=1161.070, RSKangXi=149.6
279DC CJK UNIFIED IDEOGRAPH-#279DC, IRGKangXi=1161.080, RSKangXi=149.6
279DD CJK UNIFIED IDEOGRAPH-#279DD, IRGKangXi=1161.090, RSKangXi=149.6, Def{(Cant.) 𧧝𧨊, to bar the way, obstruct}
279DE CJK UNIFIED IDEOGRAPH-#279DE, IRGKangXi=1161.100, RSKangXi=149.6
279DF CJK UNIFIED IDEOGRAPH-#279DF, IRGKangXi=1161.110, RSKangXi=149.6
279E0 CJK UNIFIED IDEOGRAPH-#279E0, IRGKangXi=1161.120, RSKangXi=149.6
279E1 CJK UNIFIED IDEOGRAPH-#279E1, IRGKangXi=1161.140, RSKangXi=149.6
279E2 CJK UNIFIED IDEOGRAPH-#279E2, IRGKangXi=1161.141, RSKangXi=149.6
279E3 CJK UNIFIED IDEOGRAPH-#279E3, IRGKangXi=1161.141, RSKangXi=149.6
279E4 CJK UNIFIED IDEOGRAPH-#279E4, IRGKangXi=1161.141, RSKangXi=149.6
279E5 CJK UNIFIED IDEOGRAPH-#279E5, IRGKangXi=1161.141, RSKangXi=149.6
279E6 CJK UNIFIED IDEOGRAPH-#279E6, IRGKangXi=1161.141, RSKangXi=149.6
279E7 CJK UNIFIED IDEOGRAPH-#279E7, IRGKangXi=1161.141, RSKangXi=149.6
279E8 CJK UNIFIED IDEOGRAPH-#279E8, IRGKangXi=1161.141, RSKangXi=149.6
279E9 CJK UNIFIED IDEOGRAPH-#279E9, IRGKangXi=1161.141, RSKangXi=149.6
279EA CJK UNIFIED IDEOGRAPH-#279EA, IRGKangXi=1161.141, RSKangXi=149.6
279EB CJK UNIFIED IDEOGRAPH-#279EB, IRGKangXi=1161.141, RSKangXi=149.6
279EC CJK UNIFIED IDEOGRAPH-#279EC, IRGKangXi=1161.141, RSKangXi=149.6
279ED CJK UNIFIED IDEOGRAPH-#279ED, IRGKangXi=1161.141, RSKangXi=149.6
279EE CJK UNIFIED IDEOGRAPH-#279EE, IRGKangXi=1161.141, RSKangXi=149.6
279EF CJK UNIFIED IDEOGRAPH-#279EF, IRGKangXi=1161.141, RSKangXi=149.6
279F0 CJK UNIFIED IDEOGRAPH-#279F0, IRGKangXi=1161.141, RSKangXi=149.6
279F1 CJK UNIFIED IDEOGRAPH-#279F1, IRGKangXi=1161.141, RSKangXi=149.6
279F2 CJK UNIFIED IDEOGRAPH-#279F2, IRGKangXi=1161.141, RSKangXi=149.6
279F3 CJK UNIFIED IDEOGRAPH-#279F3, IRGKangXi=1161.141, RSKangXi=149.6
279F4 CJK UNIFIED IDEOGRAPH-#279F4, IRGKangXi=1161.150, RSKangXi=149.7
279F5 CJK UNIFIED IDEOGRAPH-#279F5, IRGKangXi=1161.210, RSKangXi=149.7
279F6 CJK UNIFIED IDEOGRAPH-#279F6, IRGKangXi=1161.280, RSKangXi=149.7
279F7 CJK UNIFIED IDEOGRAPH-#279F7, IRGKangXi=1162.080, RSKangXi=149.7
279F8 CJK UNIFIED IDEOGRAPH-#279F8, IRGKangXi=1162.100, RSKangXi=149.7
279F9 CJK UNIFIED IDEOGRAPH-#279F9, IRGKangXi=1162.120, RSKangXi=149.7
279FA CJK UNIFIED IDEOGRAPH-#279FA, IRGKangXi=1162.130, RSKangXi=149.7
279FB CJK UNIFIED IDEOGRAPH-#279FB, IRGKangXi=1162.180, RSKangXi=149.7
279FC CJK UNIFIED IDEOGRAPH-#279FC, IRGKangXi=1163.010, RSKangXi=149.7
279FD CJK UNIFIED IDEOGRAPH-#279FD, IRGKangXi=1163.060, RSKangXi=149.7
279FE CJK UNIFIED IDEOGRAPH-#279FE, IRGKangXi=1163.090, RSKangXi=149.7
279FF CJK UNIFIED IDEOGRAPH-#279FF, IRGKangXi=1163.100, RSKangXi=149.7
27A00 CJK UNIFIED IDEOGRAPH-#27A00, IRGKangXi=1163.160, RSKangXi=149.7
27A01 CJK UNIFIED IDEOGRAPH-#27A01, IRGKangXi=1163.180, RSKangXi=149.7
27A02 CJK UNIFIED IDEOGRAPH-#27A02, IRGKangXi=1163.220, RSKangXi=149.7
27A03 CJK UNIFIED IDEOGRAPH-#27A03, IRGKangXi=1164.010, RSKangXi=149.7
27A04 CJK UNIFIED IDEOGRAPH-#27A04, IRGKangXi=1164.090, RSKangXi=149.7
27A05 CJK UNIFIED IDEOGRAPH-#27A05, IRGKangXi=1164.110, RSKangXi=149.7
27A06 CJK UNIFIED IDEOGRAPH-#27A06, IRGKangXi=1164.120, RSKangXi=149.7
27A07 CJK UNIFIED IDEOGRAPH-#27A07, IRGKangXi=1164.130, RSKangXi=149.7
27A08 CJK UNIFIED IDEOGRAPH-#27A08, IRGKangXi=1165.010, RSKangXi=149.7
27A09 CJK UNIFIED IDEOGRAPH-#27A09, IRGKangXi=1165.020, RSKangXi=149.7
27A0A CJK UNIFIED IDEOGRAPH-#27A0A, IRGKangXi=1165.030, RSKangXi=149.7, Def{(Cant.) 𧧝𧨊, to bar the way, obstruct}
27A0B CJK UNIFIED IDEOGRAPH-#27A0B, IRGKangXi=1165.050, RSKangXi=149.7
27A0C CJK UNIFIED IDEOGRAPH-#27A0C, IRGKangXi=1165.051, RSKangXi=149.7
27A0D CJK UNIFIED IDEOGRAPH-#27A0D, IRGKangXi=1165.051, RSKangXi=149.7
27A0E CJK UNIFIED IDEOGRAPH-#27A0E, IRGKangXi=1165.051, RSKangXi=149.7
27A0F CJK UNIFIED IDEOGRAPH-#27A0F, IRGKangXi=1165.051, RSKangXi=149.7
27A10 CJK UNIFIED IDEOGRAPH-#27A10, IRGKangXi=1165.051, RSKangXi=149.7
27A11 CJK UNIFIED IDEOGRAPH-#27A11, IRGKangXi=1165.051, RSKangXi=149.7
27A12 CJK UNIFIED IDEOGRAPH-#27A12, IRGKangXi=1165.051, RSKangXi=149.7
27A13 CJK UNIFIED IDEOGRAPH-#27A13, IRGKangXi=1165.051, RSKangXi=149.7
27A14 CJK UNIFIED IDEOGRAPH-#27A14, IRGKangXi=1165.051, RSKangXi=149.7
27A15 CJK UNIFIED IDEOGRAPH-#27A15, IRGKangXi=1165.051, RSKangXi=149.7
27A16 CJK UNIFIED IDEOGRAPH-#27A16, IRGKangXi=1165.051, RSKangXi=149.7
27A17 CJK UNIFIED IDEOGRAPH-#27A17, IRGKangXi=1165.051, RSKangXi=149.7
27A18 CJK UNIFIED IDEOGRAPH-#27A18, IRGKangXi=1165.051, RSKangXi=149.7
27A19 CJK UNIFIED IDEOGRAPH-#27A19, IRGKangXi=1165.051, RSKangXi=149.7
27A1A CJK UNIFIED IDEOGRAPH-#27A1A, IRGKangXi=1165.051, RSKangXi=149.7
27A1B CJK UNIFIED IDEOGRAPH-#27A1B, IRGKangXi=1165.051, RSKangXi=149.7
27A1C CJK UNIFIED IDEOGRAPH-#27A1C, IRGKangXi=1165.051, RSKangXi=149.6
27A1D CJK UNIFIED IDEOGRAPH-#27A1D, IRGKangXi=1165.051, RSKangXi=149.7
27A1E CJK UNIFIED IDEOGRAPH-#27A1E, IRGKangXi=1165.051, RSKangXi=149.7
27A1F CJK UNIFIED IDEOGRAPH-#27A1F, IRGKangXi=1165.051, RSKangXi=149.7
27A20 CJK UNIFIED IDEOGRAPH-#27A20, IRGKangXi=1165.051, RSKangXi=19.7
27A21 CJK UNIFIED IDEOGRAPH-#27A21, IRGKangXi=1165.051, RSKangXi=149.7
27A22 CJK UNIFIED IDEOGRAPH-#27A22, IRGKangXi=1165.051, RSKangXi=149.7
27A23 CJK UNIFIED IDEOGRAPH-#27A23, IRGKangXi=1165.051, RSKangXi=149.7
27A24 CJK UNIFIED IDEOGRAPH-#27A24, IRGKangXi=1165.051, RSKangXi=149.7
27A25 CJK UNIFIED IDEOGRAPH-#27A25, IRGKangXi=1165.051, RSKangXi=149.7
27A26 CJK UNIFIED IDEOGRAPH-#27A26, IRGKangXi=1165.090, RSKangXi=149.8
27A27 CJK UNIFIED IDEOGRAPH-#27A27, IRGKangXi=1165.120, RSKangXi=149.8
27A28 CJK UNIFIED IDEOGRAPH-#27A28, IRGKangXi=1165.160, RSKangXi=149.8
27A29 CJK UNIFIED IDEOGRAPH-#27A29, IRGKangXi=1165.170, RSKangXi=149.8
27A2A CJK UNIFIED IDEOGRAPH-#27A2A, IRGKangXi=1165.210, RSKangXi=149.8
27A2B CJK UNIFIED IDEOGRAPH-#27A2B, IRGKangXi=1165.260, RSKangXi=149.8
27A2C CJK UNIFIED IDEOGRAPH-#27A2C, IRGKangXi=1166.110, RSKangXi=149.8
27A2D CJK UNIFIED IDEOGRAPH-#27A2D, IRGKangXi=1166.120, RSKangXi=149.8
27A2E CJK UNIFIED IDEOGRAPH-#27A2E, IRGKangXi=1166.160, RSKangXi=149.8
27A2F CJK UNIFIED IDEOGRAPH-#27A2F, IRGKangXi=1166.180, RSKangXi=149.8
27A30 CJK UNIFIED IDEOGRAPH-#27A30, IRGKangXi=1166.200, RSKangXi=149.8
27A31 CJK UNIFIED IDEOGRAPH-#27A31, IRGKangXi=1167.030, RSKangXi=149.8
27A32 CJK UNIFIED IDEOGRAPH-#27A32, IRGKangXi=1167.060, RSKangXi=149.8
27A33 CJK UNIFIED IDEOGRAPH-#27A33, IRGKangXi=1167.070, RSKangXi=149.8
27A34 CJK UNIFIED IDEOGRAPH-#27A34, IRGKangXi=1167.080, RSKangXi=149.8
27A35 CJK UNIFIED IDEOGRAPH-#27A35, IRGKangXi=1167.090, RSKangXi=149.8
27A36 CJK UNIFIED IDEOGRAPH-#27A36, IRGKangXi=1167.100, RSKangXi=149.8
27A37 CJK UNIFIED IDEOGRAPH-#27A37, IRGKangXi=1167.120, RSKangXi=149.8
27A38 CJK UNIFIED IDEOGRAPH-#27A38, IRGKangXi=1167.150, RSKangXi=149.8
27A39 CJK UNIFIED IDEOGRAPH-#27A39, IRGKangXi=1167.170, RSKangXi=149.8
27A3A CJK UNIFIED IDEOGRAPH-#27A3A, IRGKangXi=1167.190, RSKangXi=149.8
27A3B CJK UNIFIED IDEOGRAPH-#27A3B, IRGKangXi=1167.200, RSKangXi=149.8
27A3C CJK UNIFIED IDEOGRAPH-#27A3C, IRGKangXi=1168.020, RSKangXi=149.8
27A3D CJK UNIFIED IDEOGRAPH-#27A3D, IRGKangXi=1168.030, RSKangXi=149.8
27A3E CJK UNIFIED IDEOGRAPH-#27A3E, IRGKangXi=1168.080, RSKangXi=149.8, Def{(Cant.) to fool, trick, cheat}
27A3F CJK UNIFIED IDEOGRAPH-#27A3F, IRGKangXi=1169.020, RSKangXi=149.8
27A40 CJK UNIFIED IDEOGRAPH-#27A40, IRGKangXi=1169.030, RSKangXi=149.8
27A41 CJK UNIFIED IDEOGRAPH-#27A41, IRGKangXi=1169.040, RSKangXi=149.8
27A42 CJK UNIFIED IDEOGRAPH-#27A42, IRGKangXi=1169.060, RSKangXi=149.8
27A43 CJK UNIFIED IDEOGRAPH-#27A43, IRGKangXi=1169.090, RSKangXi=149.8
27A44 CJK UNIFIED IDEOGRAPH-#27A44, IRGKangXi=1169.100, RSKangXi=149.8
27A45 CJK UNIFIED IDEOGRAPH-#27A45, IRGKangXi=1169.110, RSKangXi=149.8
27A46 CJK UNIFIED IDEOGRAPH-#27A46, IRGKangXi=1169.120, RSKangXi=149.8
27A47 CJK UNIFIED IDEOGRAPH-#27A47, IRGKangXi=1169.140, RSKangXi=149.8
27A48 CJK UNIFIED IDEOGRAPH-#27A48, IRGKangXi=1169.150, RSKangXi=149.8
27A49 CJK UNIFIED IDEOGRAPH-#27A49, IRGKangXi=1169.151, RSKangXi=149.8
27A4A CJK UNIFIED IDEOGRAPH-#27A4A, IRGKangXi=1169.151, RSKangXi=149.8
27A4B CJK UNIFIED IDEOGRAPH-#27A4B, IRGKangXi=1169.151, RSKangXi=149.8
27A4C CJK UNIFIED IDEOGRAPH-#27A4C, IRGKangXi=1169.151, RSKangXi=149.8
27A4D CJK UNIFIED IDEOGRAPH-#27A4D, IRGKangXi=1169.151, RSKangXi=149.8
27A4E CJK UNIFIED IDEOGRAPH-#27A4E, IRGKangXi=1169.151, RSKangXi=149.8
27A4F CJK UNIFIED IDEOGRAPH-#27A4F, IRGKangXi=1169.151, RSKangXi=149.8
27A50 CJK UNIFIED IDEOGRAPH-#27A50, IRGKangXi=1169.151, RSKangXi=149.8
27A51 CJK UNIFIED IDEOGRAPH-#27A51, IRGKangXi=1169.151, RSKangXi=149.8
27A52 CJK UNIFIED IDEOGRAPH-#27A52, IRGKangXi=1169.151, RSKangXi=149.8
27A53 CJK UNIFIED IDEOGRAPH-#27A53, IRGKangXi=1169.151, RSKangXi=149.8
27A54 CJK UNIFIED IDEOGRAPH-#27A54, IRGKangXi=1169.151, RSKangXi=149.8
27A55 CJK UNIFIED IDEOGRAPH-#27A55, IRGKangXi=1169.151, RSKangXi=149.8
27A56 CJK UNIFIED IDEOGRAPH-#27A56, IRGKangXi=1169.151, RSKangXi=149.8
27A57 CJK UNIFIED IDEOGRAPH-#27A57, IRGKangXi=1169.151, RSKangXi=149.8
27A58 CJK UNIFIED IDEOGRAPH-#27A58, IRGKangXi=1169.151, RSKangXi=149.8
27A59 CJK UNIFIED IDEOGRAPH-#27A59, IRGKangXi=1169.151, RSKangXi=149.8, Def{birthday; to be born, give birth to}
27A5A CJK UNIFIED IDEOGRAPH-#27A5A, IRGKangXi=1169.151, RSKangXi=149.8
27A5B CJK UNIFIED IDEOGRAPH-#27A5B, IRGKangXi=1169.151, RSKangXi=149.8
27A5C CJK UNIFIED IDEOGRAPH-#27A5C, IRGKangXi=1169.151, RSKangXi=149.8
27A5D CJK UNIFIED IDEOGRAPH-#27A5D, IRGKangXi=1169.151, RSKangXi=149.8
27A5E CJK UNIFIED IDEOGRAPH-#27A5E, IRGKangXi=1169.151, RSKangXi=149.8
27A5F CJK UNIFIED IDEOGRAPH-#27A5F, IRGKangXi=1169.151, RSKangXi=149.8
27A60 CJK UNIFIED IDEOGRAPH-#27A60, IRGKangXi=1169.151, RSKangXi=149.8
27A61 CJK UNIFIED IDEOGRAPH-#27A61, IRGKangXi=1169.151, RSKangXi=149.8
27A62 CJK UNIFIED IDEOGRAPH-#27A62, IRGKangXi=1169.151, RSKangXi=149.8
27A63 CJK UNIFIED IDEOGRAPH-#27A63, IRGKangXi=1169.160, RSKangXi=149.9
27A64 CJK UNIFIED IDEOGRAPH-#27A64, IRGKangXi=1169.170, RSKangXi=149.9
27A65 CJK UNIFIED IDEOGRAPH-#27A65, IRGKangXi=1169.180, RSKangXi=149.9
27A66 CJK UNIFIED IDEOGRAPH-#27A66, IRGKangXi=1169.210, RSKangXi=149.9
27A67 CJK UNIFIED IDEOGRAPH-#27A67, IRGKangXi=1169.220, RSKangXi=149.9
27A68 CJK UNIFIED IDEOGRAPH-#27A68, IRGKangXi=1169.230, RSKangXi=149.9
27A69 CJK UNIFIED IDEOGRAPH-#27A69, IRGKangXi=1169.240, RSKangXi=149.9
27A6A CJK UNIFIED IDEOGRAPH-#27A6A, IRGKangXi=1169.280, RSKangXi=149.9
27A6B CJK UNIFIED IDEOGRAPH-#27A6B, IRGKangXi=1169.290, RSKangXi=149.9
27A6C CJK UNIFIED IDEOGRAPH-#27A6C, IRGKangXi=1169.310, RSKangXi=149.9
27A6D CJK UNIFIED IDEOGRAPH-#27A6D, IRGKangXi=1170.020, RSKangXi=149.9
27A6E CJK UNIFIED IDEOGRAPH-#27A6E, IRGKangXi=1170.030, RSKangXi=149.9
27A6F CJK UNIFIED IDEOGRAPH-#27A6F, IRGKangXi=1170.090, RSKangXi=149.9
27A70 CJK UNIFIED IDEOGRAPH-#27A70, IRGKangXi=1170.100, RSKangXi=149.9
27A71 CJK UNIFIED IDEOGRAPH-#27A71, IRGKangXi=1170.150, RSKangXi=149.9
27A72 CJK UNIFIED IDEOGRAPH-#27A72, IRGKangXi=1171.010, RSKangXi=149.9
27A73 CJK UNIFIED IDEOGRAPH-#27A73, IRGKangXi=1171.100, RSKangXi=149.9
27A74 CJK UNIFIED IDEOGRAPH-#27A74, IRGKangXi=1172.010, RSKangXi=149.9
27A75 CJK UNIFIED IDEOGRAPH-#27A75, IRGKangXi=1172.030, RSKangXi=149.9
27A76 CJK UNIFIED IDEOGRAPH-#27A76, IRGKangXi=1172.060, RSKangXi=149.9
27A77 CJK UNIFIED IDEOGRAPH-#27A77, IRGKangXi=1172.070, RSKangXi=149.9
27A78 CJK UNIFIED IDEOGRAPH-#27A78, IRGKangXi=1172.110, RSKangXi=149.9
27A79 CJK UNIFIED IDEOGRAPH-#27A79, IRGKangXi=1172.140, RSKangXi=149.9
27A7A CJK UNIFIED IDEOGRAPH-#27A7A, IRGKangXi=1173.040, RSKangXi=149.9
27A7B CJK UNIFIED IDEOGRAPH-#27A7B, IRGKangXi=1173.110, RSKangXi=149.9
27A7C CJK UNIFIED IDEOGRAPH-#27A7C, IRGKangXi=1174.010, RSKangXi=149.9
27A7D CJK UNIFIED IDEOGRAPH-#27A7D, IRGKangXi=1174.020, RSKangXi=149.9
27A7E CJK UNIFIED IDEOGRAPH-#27A7E, IRGKangXi=1174.030, RSKangXi=149.9
27A7F CJK UNIFIED IDEOGRAPH-#27A7F, IRGKangXi=1174.040, RSKangXi=149.9
27A80 CJK UNIFIED IDEOGRAPH-#27A80, IRGKangXi=1174.050, RSKangXi=149.9
27A81 CJK UNIFIED IDEOGRAPH-#27A81, IRGKangXi=1174.060, RSKangXi=149.9
27A82 CJK UNIFIED IDEOGRAPH-#27A82, IRGKangXi=1174.070, RSKangXi=149.9
27A83 CJK UNIFIED IDEOGRAPH-#27A83, IRGKangXi=1174.080, RSKangXi=149.9
27A84 CJK UNIFIED IDEOGRAPH-#27A84, IRGKangXi=1174.090, RSKangXi=149.9
27A85 CJK UNIFIED IDEOGRAPH-#27A85, IRGKangXi=1174.100, RSKangXi=149.9
27A86 CJK UNIFIED IDEOGRAPH-#27A86, IRGKangXi=1174.110, RSKangXi=149.9
27A87 CJK UNIFIED IDEOGRAPH-#27A87, IRGKangXi=1174.120, RSKangXi=149.9
27A88 CJK UNIFIED IDEOGRAPH-#27A88, IRGKangXi=1174.121, RSKangXi=149.9
27A89 CJK UNIFIED IDEOGRAPH-#27A89, IRGKangXi=1174.121, RSKangXi=149.9
27A8A CJK UNIFIED IDEOGRAPH-#27A8A, IRGKangXi=1174.121, RSKangXi=149.9
27A8B CJK UNIFIED IDEOGRAPH-#27A8B, IRGKangXi=1174.121, RSKangXi=149.9
27A8C CJK UNIFIED IDEOGRAPH-#27A8C, IRGKangXi=1174.121, RSKangXi=149.9
27A8D CJK UNIFIED IDEOGRAPH-#27A8D, IRGKangXi=1174.121, RSKangXi=149.9
27A8E CJK UNIFIED IDEOGRAPH-#27A8E, IRGKangXi=1174.121, RSKangXi=149.9
27A8F CJK UNIFIED IDEOGRAPH-#27A8F, IRGKangXi=1174.121, RSKangXi=149.9
27A90 CJK UNIFIED IDEOGRAPH-#27A90, IRGKangXi=1174.121, RSKangXi=149.9
27A91 CJK UNIFIED IDEOGRAPH-#27A91, IRGKangXi=1174.121, RSKangXi=149.9
27A92 CJK UNIFIED IDEOGRAPH-#27A92, IRGKangXi=1174.121, RSKangXi=149.9
27A93 CJK UNIFIED IDEOGRAPH-#27A93, IRGKangXi=1174.121, RSKangXi=149.9
27A94 CJK UNIFIED IDEOGRAPH-#27A94, IRGKangXi=1174.121, RSKangXi=149.9
27A95 CJK UNIFIED IDEOGRAPH-#27A95, IRGKangXi=1174.121, RSKangXi=149.9
27A96 CJK UNIFIED IDEOGRAPH-#27A96, IRGKangXi=1174.121, RSKangXi=149.9
27A97 CJK UNIFIED IDEOGRAPH-#27A97, IRGKangXi=1174.121, RSKangXi=149.9
27A98 CJK UNIFIED IDEOGRAPH-#27A98, IRGKangXi=1174.150, RSKangXi=149.10
27A99 CJK UNIFIED IDEOGRAPH-#27A99, IRGKangXi=1174.170, RSKangXi=149.10
27A9A CJK UNIFIED IDEOGRAPH-#27A9A, IRGKangXi=1174.180, RSKangXi=149.10
27A9B CJK UNIFIED IDEOGRAPH-#27A9B, IRGKangXi=1174.190, RSKangXi=149.10
27A9C CJK UNIFIED IDEOGRAPH-#27A9C, IRGKangXi=1174.200, RSKangXi=149.10
27A9D CJK UNIFIED IDEOGRAPH-#27A9D, IRGKangXi=1174.210, RSKangXi=149.10
27A9E CJK UNIFIED IDEOGRAPH-#27A9E, IRGKangXi=1174.220, RSKangXi=149.10
27A9F CJK UNIFIED IDEOGRAPH-#27A9F, IRGKangXi=1174.290, RSKangXi=149.10
27AA0 CJK UNIFIED IDEOGRAPH-#27AA0, IRGKangXi=1175.010, RSKangXi=149.10
27AA1 CJK UNIFIED IDEOGRAPH-#27AA1, IRGKangXi=1175.030, RSKangXi=149.10
27AA2 CJK UNIFIED IDEOGRAPH-#27AA2, IRGKangXi=1175.060, RSKangXi=149.10
27AA3 CJK UNIFIED IDEOGRAPH-#27AA3, IRGKangXi=1175.070, RSKangXi=149.10
27AA4 CJK UNIFIED IDEOGRAPH-#27AA4, IRGKangXi=1175.100, RSKangXi=149.10
27AA5 CJK UNIFIED IDEOGRAPH-#27AA5, IRGKangXi=1175.120, RSKangXi=149.10
27AA6 CJK UNIFIED IDEOGRAPH-#27AA6, IRGKangXi=1175.130, RSKangXi=149.10
27AA7 CJK UNIFIED IDEOGRAPH-#27AA7, IRGKangXi=1175.140, RSKangXi=149.10
27AA8 CJK UNIFIED IDEOGRAPH-#27AA8, IRGKangXi=1175.170, RSKangXi=149.10
27AA9 CJK UNIFIED IDEOGRAPH-#27AA9, IRGKangXi=1175.190, RSKangXi=149.10
27AAA CJK UNIFIED IDEOGRAPH-#27AAA, IRGKangXi=1175.220, RSKangXi=149.10
27AAB CJK UNIFIED IDEOGRAPH-#27AAB, IRGKangXi=1176.050, RSKangXi=149.10
27AAC CJK UNIFIED IDEOGRAPH-#27AAC, IRGKangXi=1176.080, RSKangXi=149.10
27AAD CJK UNIFIED IDEOGRAPH-#27AAD, IRGKangXi=1176.090, RSKangXi=149.10
27AAE CJK UNIFIED IDEOGRAPH-#27AAE, IRGKangXi=1176.110, RSKangXi=149.10
27AAF CJK UNIFIED IDEOGRAPH-#27AAF, IRGKangXi=1176.120, RSKangXi=149.10
27AB0 CJK UNIFIED IDEOGRAPH-#27AB0, IRGKangXi=1176.130, RSKangXi=149.10
27AB1 CJK UNIFIED IDEOGRAPH-#27AB1, IRGKangXi=1176.140, RSKangXi=149.10
27AB2 CJK UNIFIED IDEOGRAPH-#27AB2, IRGKangXi=1176.150, RSKangXi=149.10
27AB3 CJK UNIFIED IDEOGRAPH-#27AB3, IRGKangXi=1176.160, RSKangXi=149.10
27AB4 CJK UNIFIED IDEOGRAPH-#27AB4, IRGKangXi=1176.170, RSKangXi=149.10
27AB5 CJK UNIFIED IDEOGRAPH-#27AB5, IRGKangXi=1176.180, RSKangXi=149.10
27AB6 CJK UNIFIED IDEOGRAPH-#27AB6, IRGKangXi=1176.190, RSKangXi=149.10
27AB7 CJK UNIFIED IDEOGRAPH-#27AB7, IRGKangXi=1176.200, RSKangXi=149.10
27AB8 CJK UNIFIED IDEOGRAPH-#27AB8, IRGKangXi=1176.210, RSKangXi=149.10
27AB9 CJK UNIFIED IDEOGRAPH-#27AB9, IRGKangXi=1177.010, RSKangXi=149.10
27ABA CJK UNIFIED IDEOGRAPH-#27ABA, IRGKangXi=1177.020, RSKangXi=149.10
27ABB CJK UNIFIED IDEOGRAPH-#27ABB, IRGKangXi=1177.021, RSKangXi=149.10
27ABC CJK UNIFIED IDEOGRAPH-#27ABC, IRGKangXi=1177.021, RSKangXi=149.10
27ABD CJK UNIFIED IDEOGRAPH-#27ABD, IRGKangXi=1177.021, RSKangXi=149.10
27ABE CJK UNIFIED IDEOGRAPH-#27ABE, IRGKangXi=1177.021, RSKangXi=149.10
27ABF CJK UNIFIED IDEOGRAPH-#27ABF, IRGKangXi=1177.021, RSKangXi=149.10
27AC0 CJK UNIFIED IDEOGRAPH-#27AC0, IRGKangXi=1177.021, RSKangXi=149.10
27AC1 CJK UNIFIED IDEOGRAPH-#27AC1, IRGKangXi=1177.021, RSKangXi=149.10
27AC2 CJK UNIFIED IDEOGRAPH-#27AC2, IRGKangXi=1177.021, RSKangXi=149.10
27AC3 CJK UNIFIED IDEOGRAPH-#27AC3, IRGKangXi=1177.021, RSKangXi=149.10
27AC4 CJK UNIFIED IDEOGRAPH-#27AC4, IRGKangXi=1177.021, RSKangXi=149.10
27AC5 CJK UNIFIED IDEOGRAPH-#27AC5, IRGKangXi=1177.021, RSKangXi=149.10
27AC6 CJK UNIFIED IDEOGRAPH-#27AC6, IRGKangXi=1177.021, RSKangXi=149.10
27AC7 CJK UNIFIED IDEOGRAPH-#27AC7, IRGKangXi=1177.021, RSKangXi=149.10
27AC8 CJK UNIFIED IDEOGRAPH-#27AC8, IRGKangXi=1177.021, RSKangXi=149.10
27AC9 CJK UNIFIED IDEOGRAPH-#27AC9, IRGKangXi=1177.021, RSKangXi=149.10
27ACA CJK UNIFIED IDEOGRAPH-#27ACA, IRGKangXi=1177.021, RSKangXi=149.10
27ACB CJK UNIFIED IDEOGRAPH-#27ACB, IRGKangXi=1177.021, RSKangXi=149.10
27ACC CJK UNIFIED IDEOGRAPH-#27ACC, IRGKangXi=1177.021, RSKangXi=149.10
27ACD CJK UNIFIED IDEOGRAPH-#27ACD, IRGKangXi=1177.021, RSKangXi=149.10
27ACE CJK UNIFIED IDEOGRAPH-#27ACE, IRGKangXi=1177.021, RSKangXi=149.10
27ACF CJK UNIFIED IDEOGRAPH-#27ACF, IRGKangXi=1177.021, RSKangXi=149.10
27AD0 CJK UNIFIED IDEOGRAPH-#27AD0, IRGKangXi=1177.021, RSKangXi=149.10
27AD1 CJK UNIFIED IDEOGRAPH-#27AD1, IRGKangXi=1177.021, RSKangXi=149.10
27AD2 CJK UNIFIED IDEOGRAPH-#27AD2, IRGKangXi=1177.050, RSKangXi=149.11
27AD3 CJK UNIFIED IDEOGRAPH-#27AD3, IRGKangXi=1177.090, RSKangXi=149.11
27AD4 CJK UNIFIED IDEOGRAPH-#27AD4, IRGKangXi=1177.100, RSKangXi=149.11
27AD5 CJK UNIFIED IDEOGRAPH-#27AD5, IRGKangXi=1177.120, RSKangXi=149.11
27AD6 CJK UNIFIED IDEOGRAPH-#27AD6, IRGKangXi=1177.130, RSKangXi=149.11
27AD7 CJK UNIFIED IDEOGRAPH-#27AD7, IRGKangXi=1177.200, RSKangXi=149.11
27AD8 CJK UNIFIED IDEOGRAPH-#27AD8, IRGKangXi=1177.230, RSKangXi=149.11
27AD9 CJK UNIFIED IDEOGRAPH-#27AD9, IRGKangXi=1177.240, RSKangXi=149.11
27ADA CJK UNIFIED IDEOGRAPH-#27ADA, IRGKangXi=1177.250, RSKangXi=149.11
27ADB CJK UNIFIED IDEOGRAPH-#27ADB, IRGKangXi=1177.260, RSKangXi=149.11
27ADC CJK UNIFIED IDEOGRAPH-#27ADC, IRGKangXi=1178.020, RSKangXi=149.11
27ADD CJK UNIFIED IDEOGRAPH-#27ADD, IRGKangXi=1178.030, RSKangXi=149.11
27ADE CJK UNIFIED IDEOGRAPH-#27ADE, IRGKangXi=1178.040, RSKangXi=149.11
27ADF CJK UNIFIED IDEOGRAPH-#27ADF, IRGKangXi=1178.080, RSKangXi=149.11
27AE0 CJK UNIFIED IDEOGRAPH-#27AE0, IRGKangXi=1178.120, RSKangXi=149.11
27AE1 CJK UNIFIED IDEOGRAPH-#27AE1, IRGKangXi=1178.150, RSKangXi=149.11
27AE2 CJK UNIFIED IDEOGRAPH-#27AE2, IRGKangXi=1178.170, RSKangXi=149.11
27AE3 CJK UNIFIED IDEOGRAPH-#27AE3, IRGKangXi=1178.210, RSKangXi=149.11
27AE4 CJK UNIFIED IDEOGRAPH-#27AE4, IRGKangXi=1178.250, RSKangXi=149.11
27AE5 CJK UNIFIED IDEOGRAPH-#27AE5, IRGKangXi=1179.010, RSKangXi=149.11
27AE6 CJK UNIFIED IDEOGRAPH-#27AE6, IRGKangXi=1179.030, RSKangXi=149.11
27AE7 CJK UNIFIED IDEOGRAPH-#27AE7, IRGKangXi=1179.050, RSKangXi=149.11
27AE8 CJK UNIFIED IDEOGRAPH-#27AE8, IRGKangXi=1179.070, RSKangXi=149.11
27AE9 CJK UNIFIED IDEOGRAPH-#27AE9, IRGKangXi=1179.080, RSKangXi=149.11
27AEA CJK UNIFIED IDEOGRAPH-#27AEA, IRGKangXi=1179.090, RSKangXi=149.11
27AEB CJK UNIFIED IDEOGRAPH-#27AEB, IRGKangXi=1179.100, RSKangXi=149.11
27AEC CJK UNIFIED IDEOGRAPH-#27AEC, IRGKangXi=1179.110, RSKangXi=149.11
27AED CJK UNIFIED IDEOGRAPH-#27AED, IRGKangXi=1179.120, RSKangXi=149.11
27AEE CJK UNIFIED IDEOGRAPH-#27AEE, IRGKangXi=1179.130, RSKangXi=149.11
27AEF CJK UNIFIED IDEOGRAPH-#27AEF, IRGKangXi=1179.140, RSKangXi=149.11
27AF0 CJK UNIFIED IDEOGRAPH-#27AF0, IRGKangXi=1179.150, RSKangXi=149.11
27AF1 CJK UNIFIED IDEOGRAPH-#27AF1, IRGKangXi=1179.160, RSKangXi=149.11
27AF2 CJK UNIFIED IDEOGRAPH-#27AF2, IRGKangXi=1179.170, RSKangXi=149.11
27AF3 CJK UNIFIED IDEOGRAPH-#27AF3, IRGKangXi=1179.171, RSKangXi=149.11
27AF4 CJK UNIFIED IDEOGRAPH-#27AF4, IRGKangXi=1179.171, RSKangXi=149.11
27AF5 CJK UNIFIED IDEOGRAPH-#27AF5, IRGKangXi=1179.171, RSKangXi=149.11
27AF6 CJK UNIFIED IDEOGRAPH-#27AF6, IRGKangXi=1179.171, RSKangXi=149.11
27AF7 CJK UNIFIED IDEOGRAPH-#27AF7, IRGKangXi=1179.171, RSKangXi=149.11
27AF8 CJK UNIFIED IDEOGRAPH-#27AF8, IRGKangXi=1179.171, RSKangXi=149.11
27AF9 CJK UNIFIED IDEOGRAPH-#27AF9, IRGKangXi=1179.171, RSKangXi=149.11
27AFA CJK UNIFIED IDEOGRAPH-#27AFA, IRGKangXi=1179.171, RSKangXi=149.11
27AFB CJK UNIFIED IDEOGRAPH-#27AFB, IRGKangXi=1179.171, RSKangXi=149.11
27AFC CJK UNIFIED IDEOGRAPH-#27AFC, IRGKangXi=1179.171, RSKangXi=149.11
27AFD CJK UNIFIED IDEOGRAPH-#27AFD, IRGKangXi=1179.171, RSKangXi=149.11
27AFE CJK UNIFIED IDEOGRAPH-#27AFE, IRGKangXi=1179.200, RSKangXi=149.12
27AFF CJK UNIFIED IDEOGRAPH-#27AFF, IRGKangXi=1179.220, RSKangXi=149.12
27B00 CJK UNIFIED IDEOGRAPH-#27B00, IRGKangXi=1179.240, RSKangXi=149.12
27B01 CJK UNIFIED IDEOGRAPH-#27B01, IRGKangXi=1179.250, RSKangXi=149.12
27B02 CJK UNIFIED IDEOGRAPH-#27B02, IRGKangXi=1179.260, RSKangXi=149.12
27B03 CJK UNIFIED IDEOGRAPH-#27B03, IRGKangXi=1180.040, RSKangXi=149.12
27B04 CJK UNIFIED IDEOGRAPH-#27B04, IRGKangXi=1180.070, RSKangXi=149.12
27B05 CJK UNIFIED IDEOGRAPH-#27B05, IRGKangXi=1180.090, RSKangXi=149.12
27B06 CJK UNIFIED IDEOGRAPH-#27B06, IRGKangXi=1180.120, RSKangXi=149.12
27B07 CJK UNIFIED IDEOGRAPH-#27B07, IRGKangXi=1180.190, RSKangXi=149.12
27B08 CJK UNIFIED IDEOGRAPH-#27B08, IRGKangXi=1180.210, RSKangXi=149.12
27B09 CJK UNIFIED IDEOGRAPH-#27B09, IRGKangXi=1180.230, RSKangXi=149.12
27B0A CJK UNIFIED IDEOGRAPH-#27B0A, IRGKangXi=1180.240, RSKangXi=149.12
27B0B CJK UNIFIED IDEOGRAPH-#27B0B, IRGKangXi=1181.030, RSKangXi=149.12
27B0C CJK UNIFIED IDEOGRAPH-#27B0C, IRGKangXi=1181.060, RSKangXi=149.12
27B0D CJK UNIFIED IDEOGRAPH-#27B0D, IRGKangXi=1181.080, RSKangXi=149.12
27B0E CJK UNIFIED IDEOGRAPH-#27B0E, IRGKangXi=1181.120, RSKangXi=149.12
27B0F CJK UNIFIED IDEOGRAPH-#27B0F, IRGKangXi=1182.010, RSKangXi=149.12
27B10 CJK UNIFIED IDEOGRAPH-#27B10, IRGKangXi=1182.040, RSKangXi=149.12
27B11 CJK UNIFIED IDEOGRAPH-#27B11, IRGKangXi=1182.060, RSKangXi=149.12
27B12 CJK UNIFIED IDEOGRAPH-#27B12, IRGKangXi=1182.070, RSKangXi=149.12
27B13 CJK UNIFIED IDEOGRAPH-#27B13, IRGKangXi=1182.080, RSKangXi=149.12
27B14 CJK UNIFIED IDEOGRAPH-#27B14, IRGKangXi=1182.090, RSKangXi=149.12
27B15 CJK UNIFIED IDEOGRAPH-#27B15, IRGKangXi=1182.100, RSKangXi=149.12
27B16 CJK UNIFIED IDEOGRAPH-#27B16, IRGKangXi=1182.110, RSKangXi=149.12
27B17 CJK UNIFIED IDEOGRAPH-#27B17, IRGKangXi=1182.111, RSKangXi=149.12
27B18 CJK UNIFIED IDEOGRAPH-#27B18, IRGKangXi=1182.111, RSKangXi=149.12
27B19 CJK UNIFIED IDEOGRAPH-#27B19, IRGKangXi=1182.111, RSKangXi=149.12
27B1A CJK UNIFIED IDEOGRAPH-#27B1A, IRGKangXi=1182.111, RSKangXi=149.12
27B1B CJK UNIFIED IDEOGRAPH-#27B1B, IRGKangXi=1182.111, RSKangXi=149.12
27B1C CJK UNIFIED IDEOGRAPH-#27B1C, IRGKangXi=1182.111, RSKangXi=149.12
27B1D CJK UNIFIED IDEOGRAPH-#27B1D, IRGKangXi=1182.111, RSKangXi=149.12
27B1E CJK UNIFIED IDEOGRAPH-#27B1E, IRGKangXi=1182.111, RSKangXi=149.12
27B1F CJK UNIFIED IDEOGRAPH-#27B1F, IRGKangXi=1182.111, RSKangXi=149.12
27B20 CJK UNIFIED IDEOGRAPH-#27B20, IRGKangXi=1182.111, RSKangXi=149.12
27B21 CJK UNIFIED IDEOGRAPH-#27B21, IRGKangXi=1182.111, RSKangXi=149.12
27B22 CJK UNIFIED IDEOGRAPH-#27B22, IRGKangXi=1182.111, RSKangXi=149.12
27B23 CJK UNIFIED IDEOGRAPH-#27B23, IRGKangXi=1182.111, RSKangXi=149.12
27B24 CJK UNIFIED IDEOGRAPH-#27B24, IRGKangXi=1182.111, RSKangXi=149.12
27B25 CJK UNIFIED IDEOGRAPH-#27B25, IRGKangXi=1182.111, RSKangXi=149.12
27B26 CJK UNIFIED IDEOGRAPH-#27B26, IRGKangXi=1182.111, RSKangXi=149.12
27B27 CJK UNIFIED IDEOGRAPH-#27B27, IRGKangXi=1182.180, RSKangXi=149.13
27B28 CJK UNIFIED IDEOGRAPH-#27B28, IRGKangXi=1182.230, RSKangXi=149.13, Def{ringing, spacious}
27B29 CJK UNIFIED IDEOGRAPH-#27B29, IRGKangXi=1183.070, RSKangXi=149.13
27B2A CJK UNIFIED IDEOGRAPH-#27B2A, IRGKangXi=1183.100, RSKangXi=149.13
27B2B CJK UNIFIED IDEOGRAPH-#27B2B, IRGKangXi=1183.120, RSKangXi=149.13
27B2C CJK UNIFIED IDEOGRAPH-#27B2C, IRGKangXi=1183.130, RSKangXi=149.13
27B2D CJK UNIFIED IDEOGRAPH-#27B2D, IRGKangXi=1183.150, RSKangXi=149.13
27B2E CJK UNIFIED IDEOGRAPH-#27B2E, IRGKangXi=1183.200, RSKangXi=149.13
27B2F CJK UNIFIED IDEOGRAPH-#27B2F, IRGKangXi=1183.210, RSKangXi=149.13
27B30 CJK UNIFIED IDEOGRAPH-#27B30, IRGKangXi=1183.220, RSKangXi=149.13
27B31 CJK UNIFIED IDEOGRAPH-#27B31, IRGKangXi=1183.230, RSKangXi=149.13
27B32 CJK UNIFIED IDEOGRAPH-#27B32, IRGKangXi=1184.030, RSKangXi=149.13
27B33 CJK UNIFIED IDEOGRAPH-#27B33, IRGKangXi=1184.040, RSKangXi=149.13
27B34 CJK UNIFIED IDEOGRAPH-#27B34, IRGKangXi=1184.050, RSKangXi=149.13
27B35 CJK UNIFIED IDEOGRAPH-#27B35, IRGKangXi=1184.060, RSKangXi=149.13
27B36 CJK UNIFIED IDEOGRAPH-#27B36, IRGKangXi=1184.080, RSKangXi=149.13
27B37 CJK UNIFIED IDEOGRAPH-#27B37, IRGKangXi=1184.081, RSKangXi=149.13
27B38 CJK UNIFIED IDEOGRAPH-#27B38, IRGKangXi=1184.081, RSKangXi=149.13
27B39 CJK UNIFIED IDEOGRAPH-#27B39, IRGKangXi=1184.081, RSKangXi=149.13
27B3A CJK UNIFIED IDEOGRAPH-#27B3A, IRGKangXi=1184.081, RSKangXi=149.13
27B3B CJK UNIFIED IDEOGRAPH-#27B3B, IRGKangXi=1184.081, RSKangXi=149.13
27B3C CJK UNIFIED IDEOGRAPH-#27B3C, IRGKangXi=1184.081, RSKangXi=149.13
27B3D CJK UNIFIED IDEOGRAPH-#27B3D, IRGKangXi=1184.081, RSKangXi=149.13
27B3E CJK UNIFIED IDEOGRAPH-#27B3E, IRGKangXi=1184.081, RSKangXi=149.13
27B3F CJK UNIFIED IDEOGRAPH-#27B3F, IRGKangXi=1184.081, RSKangXi=149.13
27B40 CJK UNIFIED IDEOGRAPH-#27B40, IRGKangXi=1184.081, RSKangXi=149.13
27B41 CJK UNIFIED IDEOGRAPH-#27B41, IRGKangXi=1184.081, RSKangXi=149.13
27B42 CJK UNIFIED IDEOGRAPH-#27B42, IRGKangXi=1184.090, RSKangXi=149.14
27B43 CJK UNIFIED IDEOGRAPH-#27B43, IRGKangXi=1184.120, RSKangXi=149.14
27B44 CJK UNIFIED IDEOGRAPH-#27B44, IRGKangXi=1184.160, RSKangXi=149.14
27B45 CJK UNIFIED IDEOGRAPH-#27B45, IRGKangXi=1184.180, RSKangXi=149.14
27B46 CJK UNIFIED IDEOGRAPH-#27B46, IRGKangXi=1184.230, RSKangXi=149.14
27B47 CJK UNIFIED IDEOGRAPH-#27B47, IRGKangXi=1184.240, RSKangXi=149.14
27B48 CJK UNIFIED IDEOGRAPH-#27B48, IRGKangXi=1184.280, RSKangXi=149.14
27B49 CJK UNIFIED IDEOGRAPH-#27B49, IRGKangXi=1184.290, RSKangXi=149.14
27B4A CJK UNIFIED IDEOGRAPH-#27B4A, IRGKangXi=1184.310, RSKangXi=149.14
27B4B CJK UNIFIED IDEOGRAPH-#27B4B, IRGKangXi=1185.020, RSKangXi=149.14
27B4C CJK UNIFIED IDEOGRAPH-#27B4C, IRGKangXi=1185.030, RSKangXi=149.14
27B4D CJK UNIFIED IDEOGRAPH-#27B4D, IRGKangXi=1185.040, RSKangXi=149.14
27B4E CJK UNIFIED IDEOGRAPH-#27B4E, IRGKangXi=1185.060, RSKangXi=149.14
27B4F CJK UNIFIED IDEOGRAPH-#27B4F, IRGKangXi=1185.080, RSKangXi=149.14
27B50 CJK UNIFIED IDEOGRAPH-#27B50, IRGKangXi=1185.100, RSKangXi=149.14
27B51 CJK UNIFIED IDEOGRAPH-#27B51, IRGKangXi=1185.110, RSKangXi=149.15
27B52 CJK UNIFIED IDEOGRAPH-#27B52, IRGKangXi=1185.120, RSKangXi=149.14
27B53 CJK UNIFIED IDEOGRAPH-#27B53, IRGKangXi=1185.140, RSKangXi=149.14
27B54 CJK UNIFIED IDEOGRAPH-#27B54, IRGKangXi=1185.150, RSKangXi=149.14
27B55 CJK UNIFIED IDEOGRAPH-#27B55, IRGKangXi=1185.160, RSKangXi=149.14
27B56 CJK UNIFIED IDEOGRAPH-#27B56, IRGKangXi=1185.170, RSKangXi=149.14
27B57 CJK UNIFIED IDEOGRAPH-#27B57, IRGKangXi=1185.171, RSKangXi=149.14
27B58 CJK UNIFIED IDEOGRAPH-#27B58, IRGKangXi=1185.171, RSKangXi=149.14
27B59 CJK UNIFIED IDEOGRAPH-#27B59, IRGKangXi=1185.171, RSKangXi=149.14
27B5A CJK UNIFIED IDEOGRAPH-#27B5A, IRGKangXi=1185.171, RSKangXi=149.14
27B5B CJK UNIFIED IDEOGRAPH-#27B5B, IRGKangXi=1185.171, RSKangXi=149.14
27B5C CJK UNIFIED IDEOGRAPH-#27B5C, IRGKangXi=1185.190, RSKangXi=149.15, Def{to deceive}
27B5D CJK UNIFIED IDEOGRAPH-#27B5D, IRGKangXi=1185.200, RSKangXi=149.15
27B5E CJK UNIFIED IDEOGRAPH-#27B5E, IRGKangXi=1185.210, RSKangXi=149.15
27B5F CJK UNIFIED IDEOGRAPH-#27B5F, IRGKangXi=1185.220, RSKangXi=149.15
27B60 CJK UNIFIED IDEOGRAPH-#27B60, IRGKangXi=1185.240, RSKangXi=149.15
27B61 CJK UNIFIED IDEOGRAPH-#27B61, IRGKangXi=1185.280, RSKangXi=149.15
27B62 CJK UNIFIED IDEOGRAPH-#27B62, IRGKangXi=1185.290, RSKangXi=149.15
27B63 CJK UNIFIED IDEOGRAPH-#27B63, IRGKangXi=1185.310, RSKangXi=149.15
27B64 CJK UNIFIED IDEOGRAPH-#27B64, IRGKangXi=1185.320, RSKangXi=149.15
27B65 CJK UNIFIED IDEOGRAPH-#27B65, IRGKangXi=1185.330, RSKangXi=149.15
27B66 CJK UNIFIED IDEOGRAPH-#27B66, IRGKangXi=1185.340, RSKangXi=149.15
27B67 CJK UNIFIED IDEOGRAPH-#27B67, IRGKangXi=1185.370, RSKangXi=149.15
27B68 CJK UNIFIED IDEOGRAPH-#27B68, IRGKangXi=1186.020, RSKangXi=149.15
27B69 CJK UNIFIED IDEOGRAPH-#27B69, IRGKangXi=1186.030, RSKangXi=149.15
27B6A CJK UNIFIED IDEOGRAPH-#27B6A, IRGKangXi=1186.040, RSKangXi=149.15
27B6B CJK UNIFIED IDEOGRAPH-#27B6B, IRGKangXi=1186.050, RSKangXi=149.15
27B6C CJK UNIFIED IDEOGRAPH-#27B6C, IRGKangXi=1186.060, RSKangXi=149.15
27B6D CJK UNIFIED IDEOGRAPH-#27B6D, IRGKangXi=1186.070, RSKangXi=149.15
27B6E CJK UNIFIED IDEOGRAPH-#27B6E, IRGKangXi=1186.071, RSKangXi=149.15
27B6F CJK UNIFIED IDEOGRAPH-#27B6F, IRGKangXi=1186.071, RSKangXi=149.15
27B70 CJK UNIFIED IDEOGRAPH-#27B70, IRGKangXi=1186.071, RSKangXi=149.15
27B71 CJK UNIFIED IDEOGRAPH-#27B71, IRGKangXi=1186.071, RSKangXi=149.15
27B72 CJK UNIFIED IDEOGRAPH-#27B72, IRGKangXi=1186.071, RSKangXi=149.15
27B73 CJK UNIFIED IDEOGRAPH-#27B73, IRGKangXi=1186.071, RSKangXi=149.15
27B74 CJK UNIFIED IDEOGRAPH-#27B74, IRGKangXi=1186.071, RSKangXi=149.15
27B75 CJK UNIFIED IDEOGRAPH-#27B75, IRGKangXi=1186.071, RSKangXi=149.15
27B76 CJK UNIFIED IDEOGRAPH-#27B76, IRGKangXi=1186.071, RSKangXi=149.15
27B77 CJK UNIFIED IDEOGRAPH-#27B77, IRGKangXi=1186.071, RSKangXi=149.15
27B78 CJK UNIFIED IDEOGRAPH-#27B78, IRGKangXi=1186.160, RSKangXi=149.16
27B79 CJK UNIFIED IDEOGRAPH-#27B79, IRGKangXi=1186.170, RSKangXi=149.16
27B7A CJK UNIFIED IDEOGRAPH-#27B7A, IRGKangXi=1187.010, RSKangXi=149.16
27B7B CJK UNIFIED IDEOGRAPH-#27B7B, IRGKangXi=1187.020, RSKangXi=149.16
27B7C CJK UNIFIED IDEOGRAPH-#27B7C, IRGKangXi=1187.040, RSKangXi=149.16
27B7D CJK UNIFIED IDEOGRAPH-#27B7D, IRGKangXi=1187.050, RSKangXi=149.16
27B7E CJK UNIFIED IDEOGRAPH-#27B7E, IRGKangXi=1187.060, RSKangXi=149.16
27B7F CJK UNIFIED IDEOGRAPH-#27B7F, IRGKangXi=1187.070, RSKangXi=149.16
27B80 CJK UNIFIED IDEOGRAPH-#27B80, IRGKangXi=1187.071, RSKangXi=149.16
27B81 CJK UNIFIED IDEOGRAPH-#27B81, IRGKangXi=1187.071, RSKangXi=149.16
27B82 CJK UNIFIED IDEOGRAPH-#27B82, IRGKangXi=1187.071, RSKangXi=149.16
27B83 CJK UNIFIED IDEOGRAPH-#27B83, IRGKangXi=1187.071, RSKangXi=149.16
27B84 CJK UNIFIED IDEOGRAPH-#27B84, IRGKangXi=1187.071, RSKangXi=149.16
27B85 CJK UNIFIED IDEOGRAPH-#27B85, IRGKangXi=1187.100, RSKangXi=149.17
27B86 CJK UNIFIED IDEOGRAPH-#27B86, IRGKangXi=1187.110, RSKangXi=149.17
27B87 CJK UNIFIED IDEOGRAPH-#27B87, IRGKangXi=1187.140, RSKangXi=149.17
27B88 CJK UNIFIED IDEOGRAPH-#27B88, IRGKangXi=1187.170, RSKangXi=149.17
27B89 CJK UNIFIED IDEOGRAPH-#27B89, IRGKangXi=1187.190, RSKangXi=149.17
27B8A CJK UNIFIED IDEOGRAPH-#27B8A, IRGKangXi=1187.200, RSKangXi=149.17
27B8B CJK UNIFIED IDEOGRAPH-#27B8B, IRGKangXi=1187.201, RSKangXi=149.17
27B8C CJK UNIFIED IDEOGRAPH-#27B8C, IRGKangXi=1187.201, RSKangXi=149.17
27B8D CJK UNIFIED IDEOGRAPH-#27B8D, IRGKangXi=1187.201, RSKangXi=149.17
27B8E CJK UNIFIED IDEOGRAPH-#27B8E, IRGKangXi=1187.201, RSKangXi=149.17
27B8F CJK UNIFIED IDEOGRAPH-#27B8F, IRGKangXi=1187.201, RSKangXi=149.17
27B90 CJK UNIFIED IDEOGRAPH-#27B90, IRGKangXi=1187.201, RSKangXi=149.17
27B91 CJK UNIFIED IDEOGRAPH-#27B91, IRGKangXi=1187.220, RSKangXi=149.18
27B92 CJK UNIFIED IDEOGRAPH-#27B92, IRGKangXi=1187.230, RSKangXi=149.18
27B93 CJK UNIFIED IDEOGRAPH-#27B93, IRGKangXi=1188.010, RSKangXi=149.18
27B94 CJK UNIFIED IDEOGRAPH-#27B94, IRGKangXi=1188.020, RSKangXi=149.18
27B95 CJK UNIFIED IDEOGRAPH-#27B95, IRGKangXi=1188.021, RSKangXi=149.18
27B96 CJK UNIFIED IDEOGRAPH-#27B96, IRGKangXi=1188.021, RSKangXi=149.18
27B97 CJK UNIFIED IDEOGRAPH-#27B97, IRGKangXi=1188.021, RSKangXi=149.18
27B98 CJK UNIFIED IDEOGRAPH-#27B98, IRGKangXi=1188.021, RSKangXi=149.18
27B99 CJK UNIFIED IDEOGRAPH-#27B99, IRGKangXi=1188.030, RSKangXi=149.19
27B9A CJK UNIFIED IDEOGRAPH-#27B9A, IRGKangXi=1188.060, RSKangXi=149.19
27B9B CJK UNIFIED IDEOGRAPH-#27B9B, IRGKangXi=1188.070, RSKangXi=149.19
27B9C CJK UNIFIED IDEOGRAPH-#27B9C, IRGKangXi=1188.071, RSKangXi=149.19
27B9D CJK UNIFIED IDEOGRAPH-#27B9D, IRGKangXi=1188.071, RSKangXi=149.19
27B9E CJK UNIFIED IDEOGRAPH-#27B9E, IRGKangXi=1188.110, RSKangXi=149.20
27B9F CJK UNIFIED IDEOGRAPH-#27B9F, IRGKangXi=1188.120, RSKangXi=149.20
27BA0 CJK UNIFIED IDEOGRAPH-#27BA0, IRGKangXi=1188.121, RSKangXi=149.20
27BA1 CJK UNIFIED IDEOGRAPH-#27BA1, IRGKangXi=1188.121, RSKangXi=149.20
27BA2 CJK UNIFIED IDEOGRAPH-#27BA2, IRGKangXi=1188.130, RSKangXi=149.21
27BA3 CJK UNIFIED IDEOGRAPH-#27BA3, IRGKangXi=1188.140, RSKangXi=149.21
27BA4 CJK UNIFIED IDEOGRAPH-#27BA4, IRGKangXi=1188.141, RSKangXi=149.21
27BA5 CJK UNIFIED IDEOGRAPH-#27BA5, IRGKangXi=1188.141, RSKangXi=30.25
27BA6 CJK UNIFIED IDEOGRAPH-#27BA6, IRGKangXi=1188.141, RSKangXi=149.21
27BA7 CJK UNIFIED IDEOGRAPH-#27BA7, IRGKangXi=1188.141, RSKangXi=149.21
27BA8 CJK UNIFIED IDEOGRAPH-#27BA8, IRGKangXi=1188.170, RSKangXi=149.22
27BA9 CJK UNIFIED IDEOGRAPH-#27BA9, IRGKangXi=1188.180, RSKangXi=149.32
27BAA CJK UNIFIED IDEOGRAPH-#27BAA, IRGKangXi=1188.181, RSKangXi=149.5
27BAB CJK UNIFIED IDEOGRAPH-#27BAB, IRGKangXi=1189.020, RSKangXi=150.0
27BAC CJK UNIFIED IDEOGRAPH-#27BAC, IRGKangXi=1189.040, RSKangXi=150.3
27BAD CJK UNIFIED IDEOGRAPH-#27BAD, IRGKangXi=1189.070, RSKangXi=150.3
27BAE CJK UNIFIED IDEOGRAPH-#27BAE, IRGKangXi=1189.080, RSKangXi=150.3
27BAF CJK UNIFIED IDEOGRAPH-#27BAF, IRGKangXi=1189.090, RSKangXi=150.4
27BB0 CJK UNIFIED IDEOGRAPH-#27BB0, IRGKangXi=1189.110, RSKangXi=150.4
27BB1 CJK UNIFIED IDEOGRAPH-#27BB1, IRGKangXi=1189.130, RSKangXi=150.4
27BB2 CJK UNIFIED IDEOGRAPH-#27BB2, IRGKangXi=1190.010, RSKangXi=150.4
27BB3 CJK UNIFIED IDEOGRAPH-#27BB3, IRGKangXi=1190.020, RSKangXi=150.5
27BB4 CJK UNIFIED IDEOGRAPH-#27BB4, IRGKangXi=1190.041, RSKangXi=150.5
27BB5 CJK UNIFIED IDEOGRAPH-#27BB5, IRGKangXi=1190.050, RSKangXi=150.6
27BB6 CJK UNIFIED IDEOGRAPH-#27BB6, IRGKangXi=1190.070, RSKangXi=150.6
27BB7 CJK UNIFIED IDEOGRAPH-#27BB7, IRGKangXi=1190.080, RSKangXi=150.6
27BB8 CJK UNIFIED IDEOGRAPH-#27BB8, IRGKangXi=1190.090, RSKangXi=150.7
27BB9 CJK UNIFIED IDEOGRAPH-#27BB9, IRGKangXi=1190.111, RSKangXi=150.7
27BBA CJK UNIFIED IDEOGRAPH-#27BBA, IRGKangXi=1190.130, RSKangXi=150.8
27BBB CJK UNIFIED IDEOGRAPH-#27BBB, IRGKangXi=1190.140, RSKangXi=150.8
27BBC CJK UNIFIED IDEOGRAPH-#27BBC, IRGKangXi=1190.150, RSKangXi=150.8
27BBD CJK UNIFIED IDEOGRAPH-#27BBD, IRGKangXi=1190.160, RSKangXi=150.8
27BBE CJK UNIFIED IDEOGRAPH-#27BBE, IRGKangXi=1190.171, RSKangXi=150.8
27BBF CJK UNIFIED IDEOGRAPH-#27BBF, IRGKangXi=1190.171, RSKangXi=150.8
27BC0 CJK UNIFIED IDEOGRAPH-#27BC0, IRGKangXi=1190.180, RSKangXi=150.9
27BC1 CJK UNIFIED IDEOGRAPH-#27BC1, IRGKangXi=1190.190, RSKangXi=150.9
27BC2 CJK UNIFIED IDEOGRAPH-#27BC2, IRGKangXi=1190.200, RSKangXi=150.9
27BC3 CJK UNIFIED IDEOGRAPH-#27BC3, IRGKangXi=1190.201, RSKangXi=150.9
27BC4 CJK UNIFIED IDEOGRAPH-#27BC4, IRGKangXi=1190.201, RSKangXi=150.9
27BC5 CJK UNIFIED IDEOGRAPH-#27BC5, IRGKangXi=1190.201, RSKangXi=150.9
27BC6 CJK UNIFIED IDEOGRAPH-#27BC6, IRGKangXi=1190.240, RSKangXi=150.10
27BC7 CJK UNIFIED IDEOGRAPH-#27BC7, IRGKangXi=1190.241, RSKangXi=150.10
27BC8 CJK UNIFIED IDEOGRAPH-#27BC8, IRGKangXi=1190.241, RSKangXi=150.10
27BC9 CJK UNIFIED IDEOGRAPH-#27BC9, IRGKangXi=1190.241, RSKangXi=150.10
27BCA CJK UNIFIED IDEOGRAPH-#27BCA, IRGKangXi=1190.260, RSKangXi=150.11
27BCB CJK UNIFIED IDEOGRAPH-#27BCB, IRGKangXi=1190.280, RSKangXi=150.12
27BCC CJK UNIFIED IDEOGRAPH-#27BCC, IRGKangXi=1190.290, RSKangXi=150.12
27BCD CJK UNIFIED IDEOGRAPH-#27BCD, IRGKangXi=1191.010, RSKangXi=150.12
27BCE CJK UNIFIED IDEOGRAPH-#27BCE, IRGKangXi=1191.030, RSKangXi=150.12
27BCF CJK UNIFIED IDEOGRAPH-#27BCF, IRGKangXi=1191.040, RSKangXi=150.12
27BD0 CJK UNIFIED IDEOGRAPH-#27BD0, IRGKangXi=1191.050, RSKangXi=150.12
27BD1 CJK UNIFIED IDEOGRAPH-#27BD1, IRGKangXi=1191.051, RSKangXi=150.12
27BD2 CJK UNIFIED IDEOGRAPH-#27BD2, IRGKangXi=1191.051, RSKangXi=150.12
27BD3 CJK UNIFIED IDEOGRAPH-#27BD3, IRGKangXi=1191.060, RSKangXi=150.13
27BD4 CJK UNIFIED IDEOGRAPH-#27BD4, IRGKangXi=1191.061, RSKangXi=150.13
27BD5 CJK UNIFIED IDEOGRAPH-#27BD5, IRGKangXi=1191.070, RSKangXi=150.14
27BD6 CJK UNIFIED IDEOGRAPH-#27BD6, IRGKangXi=1191.071, RSKangXi=150.14
27BD7 CJK UNIFIED IDEOGRAPH-#27BD7, IRGKangXi=1191.111, RSKangXi=150.18
27BD8 CJK UNIFIED IDEOGRAPH-#27BD8, IRGKangXi=1191.120, RSKangXi=150.20
27BD9 CJK UNIFIED IDEOGRAPH-#27BD9, IRGKangXi=1191.130, RSKangXi=150.24
27BDA CJK UNIFIED IDEOGRAPH-#27BDA, IRGKangXi=1191.171, RSKangXi=151.2
27BDB CJK UNIFIED IDEOGRAPH-#27BDB, IRGKangXi=1191.190, RSKangXi=151.3
27BDC CJK UNIFIED IDEOGRAPH-#27BDC, IRGKangXi=1191.210, RSKangXi=151.3
27BDD CJK UNIFIED IDEOGRAPH-#27BDD, IRGKangXi=1191.211, RSKangXi=151.3
27BDE CJK UNIFIED IDEOGRAPH-#27BDE, IRGKangXi=1191.231, RSKangXi=151.4
27BDF CJK UNIFIED IDEOGRAPH-#27BDF, IRGKangXi=1191.231, RSKangXi=151.4
27BE0 CJK UNIFIED IDEOGRAPH-#27BE0, IRGKangXi=1192.010, RSKangXi=151.5
27BE1 CJK UNIFIED IDEOGRAPH-#27BE1, IRGKangXi=1192.020, RSKangXi=151.5
27BE2 CJK UNIFIED IDEOGRAPH-#27BE2, IRGKangXi=1192.030, RSKangXi=151.5
27BE3 CJK UNIFIED IDEOGRAPH-#27BE3, IRGKangXi=1192.031, RSKangXi=151.5
27BE4 CJK UNIFIED IDEOGRAPH-#27BE4, IRGKangXi=1192.031, RSKangXi=151.5
27BE5 CJK UNIFIED IDEOGRAPH-#27BE5, IRGKangXi=1192.040, RSKangXi=151.6
27BE6 CJK UNIFIED IDEOGRAPH-#27BE6, IRGKangXi=1192.060, RSKangXi=151.6
27BE7 CJK UNIFIED IDEOGRAPH-#27BE7, IRGKangXi=1192.091, RSKangXi=32.10
27BE8 CJK UNIFIED IDEOGRAPH-#27BE8, IRGKangXi=1192.091, RSKangXi=151.6
27BE9 CJK UNIFIED IDEOGRAPH-#27BE9, IRGKangXi=1192.110, RSKangXi=151.7
27BEA CJK UNIFIED IDEOGRAPH-#27BEA, IRGKangXi=1192.120, RSKangXi=151.7
27BEB CJK UNIFIED IDEOGRAPH-#27BEB, IRGKangXi=1192.130, RSKangXi=151.7
27BEC CJK UNIFIED IDEOGRAPH-#27BEC, IRGKangXi=1192.141, RSKangXi=151.7
27BED CJK UNIFIED IDEOGRAPH-#27BED, IRGKangXi=1192.150, RSKangXi=151.8
27BEE CJK UNIFIED IDEOGRAPH-#27BEE, IRGKangXi=1192.180, RSKangXi=151.8
27BEF CJK UNIFIED IDEOGRAPH-#27BEF, IRGKangXi=1192.190, RSKangXi=151.8
27BF0 CJK UNIFIED IDEOGRAPH-#27BF0, IRGKangXi=1192.200, RSKangXi=151.8
27BF1 CJK UNIFIED IDEOGRAPH-#27BF1, IRGKangXi=1192.230, RSKangXi=151.8
27BF2 CJK UNIFIED IDEOGRAPH-#27BF2, IRGKangXi=1192.231, RSKangXi=151.8
27BF3 CJK UNIFIED IDEOGRAPH-#27BF3, IRGKangXi=1192.231, RSKangXi=151.8
27BF4 CJK UNIFIED IDEOGRAPH-#27BF4, IRGKangXi=1192.231, RSKangXi=151.8
27BF5 CJK UNIFIED IDEOGRAPH-#27BF5, IRGKangXi=1192.231, RSKangXi=151.8
27BF6 CJK UNIFIED IDEOGRAPH-#27BF6, IRGKangXi=1192.231, RSKangXi=151.8
27BF7 CJK UNIFIED IDEOGRAPH-#27BF7, IRGKangXi=1192.240, RSKangXi=151.9
27BF8 CJK UNIFIED IDEOGRAPH-#27BF8, IRGKangXi=1192.270, RSKangXi=151.9
27BF9 CJK UNIFIED IDEOGRAPH-#27BF9, IRGKangXi=1192.291, RSKangXi=151.9
27BFA CJK UNIFIED IDEOGRAPH-#27BFA, IRGKangXi=1192.291, RSKangXi=151.9
27BFB CJK UNIFIED IDEOGRAPH-#27BFB, IRGKangXi=1192.291, RSKangXi=151.9
27BFC CJK UNIFIED IDEOGRAPH-#27BFC, IRGKangXi=1193.040, RSKangXi=151.10
27BFD CJK UNIFIED IDEOGRAPH-#27BFD, IRGKangXi=1193.050, RSKangXi=151.10
27BFE CJK UNIFIED IDEOGRAPH-#27BFE, IRGKangXi=1193.060, RSKangXi=151.10
27BFF CJK UNIFIED IDEOGRAPH-#27BFF, IRGKangXi=1193.070, RSKangXi=151.10
27C00 CJK UNIFIED IDEOGRAPH-#27C00, IRGKangXi=1193.091, RSKangXi=151.10
27C01 CJK UNIFIED IDEOGRAPH-#27C01, IRGKangXi=1193.091, RSKangXi=151.10
27C02 CJK UNIFIED IDEOGRAPH-#27C02, IRGKangXi=1193.091, RSKangXi=151.10
27C03 CJK UNIFIED IDEOGRAPH-#27C03, IRGKangXi=1193.100, RSKangXi=151.11
27C04 CJK UNIFIED IDEOGRAPH-#27C04, IRGKangXi=1193.110, RSKangXi=151.11
27C05 CJK UNIFIED IDEOGRAPH-#27C05, IRGKangXi=1193.150, RSKangXi=151.11
27C06 CJK UNIFIED IDEOGRAPH-#27C06, IRGKangXi=1193.160, RSKangXi=151.11
27C07 CJK UNIFIED IDEOGRAPH-#27C07, IRGKangXi=1193.170, RSKangXi=151.11
27C08 CJK UNIFIED IDEOGRAPH-#27C08, IRGKangXi=1193.171, RSKangXi=151.10
27C09 CJK UNIFIED IDEOGRAPH-#27C09, IRGKangXi=1193.180, RSKangXi=151.12
27C0A CJK UNIFIED IDEOGRAPH-#27C0A, IRGKangXi=1193.190, RSKangXi=151.12, Def{a rumbling sound}
27C0B CJK UNIFIED IDEOGRAPH-#27C0B, IRGKangXi=1193.200, RSKangXi=151.12
27C0C CJK UNIFIED IDEOGRAPH-#27C0C, IRGKangXi=1193.210, RSKangXi=151.12
27C0D CJK UNIFIED IDEOGRAPH-#27C0D, IRGKangXi=1193.220, RSKangXi=151.12
27C0E CJK UNIFIED IDEOGRAPH-#27C0E, IRGKangXi=1193.221, RSKangXi=151.12
27C0F CJK UNIFIED IDEOGRAPH-#27C0F, IRGKangXi=1193.221, RSKangXi=151.12
27C10 CJK UNIFIED IDEOGRAPH-#27C10, IRGKangXi=1193.221, RSKangXi=151.12
27C11 CJK UNIFIED IDEOGRAPH-#27C11, IRGKangXi=1193.230, RSKangXi=151.13
27C12 CJK UNIFIED IDEOGRAPH-#27C12, IRGKangXi=1193.250, RSKangXi=151.13
27C13 CJK UNIFIED IDEOGRAPH-#27C13, IRGKangXi=1193.260, RSKangXi=151.13
27C14 CJK UNIFIED IDEOGRAPH-#27C14, IRGKangXi=1193.261, RSKangXi=151.13
27C15 CJK UNIFIED IDEOGRAPH-#27C15, IRGKangXi=1193.261, RSKangXi=151.13
27C16 CJK UNIFIED IDEOGRAPH-#27C16, IRGKangXi=1193.261, RSKangXi=151.13
27C17 CJK UNIFIED IDEOGRAPH-#27C17, IRGKangXi=1193.271, RSKangXi=151.14
27C18 CJK UNIFIED IDEOGRAPH-#27C18, IRGKangXi=1193.271, RSKangXi=151.14
27C19 CJK UNIFIED IDEOGRAPH-#27C19, IRGKangXi=1193.280, RSKangXi=151.15
27C1A CJK UNIFIED IDEOGRAPH-#27C1A, IRGKangXi=1193.281, RSKangXi=151.15
27C1B CJK UNIFIED IDEOGRAPH-#27C1B, IRGKangXi=1193.281, RSKangXi=151.15
27C1C CJK UNIFIED IDEOGRAPH-#27C1C, IRGKangXi=1193.281, RSKangXi=151.15
27C1D CJK UNIFIED IDEOGRAPH-#27C1D, IRGKangXi=1193.281, RSKangXi=151.16
27C1E CJK UNIFIED IDEOGRAPH-#27C1E, IRGKangXi=1193.281, RSKangXi=151.16
27C1F CJK UNIFIED IDEOGRAPH-#27C1F, IRGKangXi=1193.281, RSKangXi=151.16
27C20 CJK UNIFIED IDEOGRAPH-#27C20, IRGKangXi=1193.290, RSKangXi=151.17
27C21 CJK UNIFIED IDEOGRAPH-#27C21, IRGKangXi=1193.310, RSKangXi=151.18
27C22 CJK UNIFIED IDEOGRAPH-#27C22, IRGKangXi=1193.320, RSKangXi=151.18
27C23 CJK UNIFIED IDEOGRAPH-#27C23, IRGKangXi=1194.010, RSKangXi=151.20
27C24 CJK UNIFIED IDEOGRAPH-#27C24, IRGKangXi=1194.011, RSKangXi=151.20
27C25 CJK UNIFIED IDEOGRAPH-#27C25, IRGKangXi=1194.030, RSKangXi=151.22
27C26 CJK UNIFIED IDEOGRAPH-#27C26, IRGKangXi=1194.081, RSKangXi=152.1
27C27 CJK UNIFIED IDEOGRAPH-#27C27, IRGKangXi=1194.090, RSKangXi=152.-1, Def{to assemble}
27C28 CJK UNIFIED IDEOGRAPH-#27C28, IRGKangXi=1194.091, RSKangXi=152.-1
27C29 CJK UNIFIED IDEOGRAPH-#27C29, IRGKangXi=1194.100, RSKangXi=152.2
27C2A CJK UNIFIED IDEOGRAPH-#27C2A, IRGKangXi=1194.110, RSKangXi=152.3
27C2B CJK UNIFIED IDEOGRAPH-#27C2B, IRGKangXi=1194.130, RSKangXi=152.3
27C2C CJK UNIFIED IDEOGRAPH-#27C2C, IRGKangXi=1194.150, RSKangXi=152.3
27C2D CJK UNIFIED IDEOGRAPH-#27C2D, IRGKangXi=1194.151, RSKangXi=152.3
27C2E CJK UNIFIED IDEOGRAPH-#27C2E, IRGKangXi=1194.180, RSKangXi=152.4
27C2F CJK UNIFIED IDEOGRAPH-#27C2F, IRGKangXi=1194.190, RSKangXi=152.4
27C30 CJK UNIFIED IDEOGRAPH-#27C30, IRGKangXi=1194.210, RSKangXi=152.4
27C31 CJK UNIFIED IDEOGRAPH-#27C31, IRGKangXi=1195.020, RSKangXi=152.4
27C32 CJK UNIFIED IDEOGRAPH-#27C32, IRGKangXi=1195.070, RSKangXi=152.4
27C33 CJK UNIFIED IDEOGRAPH-#27C33, IRGKangXi=1195.080, RSKangXi=152.4
27C34 CJK UNIFIED IDEOGRAPH-#27C34, IRGKangXi=1195.091, RSKangXi=152.4
27C35 CJK UNIFIED IDEOGRAPH-#27C35, IRGKangXi=1195.130, RSKangXi=152.5
27C36 CJK UNIFIED IDEOGRAPH-#27C36, IRGKangXi=1195.140, RSKangXi=152.5
27C37 CJK UNIFIED IDEOGRAPH-#27C37, IRGKangXi=1195.160, RSKangXi=152.5
27C38 CJK UNIFIED IDEOGRAPH-#27C38, IRGKangXi=1195.170, RSKangXi=152.5
27C39 CJK UNIFIED IDEOGRAPH-#27C39, IRGKangXi=1195.180, RSKangXi=152.5
27C3A CJK UNIFIED IDEOGRAPH-#27C3A, IRGKangXi=1195.190, RSKangXi=152.5
27C3B CJK UNIFIED IDEOGRAPH-#27C3B, IRGKangXi=1195.200, RSKangXi=152.5
27C3C CJK UNIFIED IDEOGRAPH-#27C3C, IRGKangXi=1195.230, RSKangXi=152.5
27C3D CJK UNIFIED IDEOGRAPH-#27C3D, IRGKangXi=1196.010, RSKangXi=152.5
27C3E CJK UNIFIED IDEOGRAPH-#27C3E, IRGKangXi=1196.011, RSKangXi=152.5
27C3F CJK UNIFIED IDEOGRAPH-#27C3F, IRGKangXi=1196.020, RSKangXi=152.6
27C40 CJK UNIFIED IDEOGRAPH-#27C40, IRGKangXi=1196.030, RSKangXi=152.6
27C41 CJK UNIFIED IDEOGRAPH-#27C41, IRGKangXi=1196.050, RSKangXi=152.6
27C42 CJK UNIFIED IDEOGRAPH-#27C42, IRGKangXi=1196.060, RSKangXi=152.6
27C43 CJK UNIFIED IDEOGRAPH-#27C43, IRGKangXi=1196.070, RSKangXi=152.6
27C44 CJK UNIFIED IDEOGRAPH-#27C44, IRGKangXi=1196.080, RSKangXi=152.6
27C45 CJK UNIFIED IDEOGRAPH-#27C45, IRGKangXi=1196.090, RSKangXi=152.6
27C46 CJK UNIFIED IDEOGRAPH-#27C46, IRGKangXi=1196.120, RSKangXi=152.6
27C47 CJK UNIFIED IDEOGRAPH-#27C47, IRGKangXi=1196.130, RSKangXi=152.6
27C48 CJK UNIFIED IDEOGRAPH-#27C48, IRGKangXi=1196.160, RSKangXi=152.6
27C49 CJK UNIFIED IDEOGRAPH-#27C49, IRGKangXi=1196.170, RSKangXi=152.6
27C4A CJK UNIFIED IDEOGRAPH-#27C4A, IRGKangXi=1196.180, RSKangXi=152.6
27C4B CJK UNIFIED IDEOGRAPH-#27C4B, IRGKangXi=1196.181, RSKangXi=152.6
27C4C CJK UNIFIED IDEOGRAPH-#27C4C, IRGKangXi=1196.181, RSKangXi=152.6
27C4D CJK UNIFIED IDEOGRAPH-#27C4D, IRGKangXi=1196.200, RSKangXi=152.7
27C4E CJK UNIFIED IDEOGRAPH-#27C4E, IRGKangXi=1196.210, RSKangXi=152.7
27C4F CJK UNIFIED IDEOGRAPH-#27C4F, IRGKangXi=1196.220, RSKangXi=152.7
27C50 CJK UNIFIED IDEOGRAPH-#27C50, IRGKangXi=1196.230, RSKangXi=152.7
27C51 CJK UNIFIED IDEOGRAPH-#27C51, IRGKangXi=1196.240, RSKangXi=152.7
27C52 CJK UNIFIED IDEOGRAPH-#27C52, IRGKangXi=1196.250, RSKangXi=152.7
27C53 CJK UNIFIED IDEOGRAPH-#27C53, IRGKangXi=1196.260, RSKangXi=152.7
27C54 CJK UNIFIED IDEOGRAPH-#27C54, IRGKangXi=1196.270, RSKangXi=152.7
27C55 CJK UNIFIED IDEOGRAPH-#27C55, IRGKangXi=1196.280, RSKangXi=152.7
27C56 CJK UNIFIED IDEOGRAPH-#27C56, IRGKangXi=1197.030, RSKangXi=152.7
27C57 CJK UNIFIED IDEOGRAPH-#27C57, IRGKangXi=1197.040, RSKangXi=152.7
27C58 CJK UNIFIED IDEOGRAPH-#27C58, IRGKangXi=1197.050, RSKangXi=152.8
27C59 CJK UNIFIED IDEOGRAPH-#27C59, IRGKangXi=1197.060, RSKangXi=152.8
27C5A CJK UNIFIED IDEOGRAPH-#27C5A, IRGKangXi=1197.070, RSKangXi=152.8
27C5B CJK UNIFIED IDEOGRAPH-#27C5B, IRGKangXi=1197.080, RSKangXi=152.8
27C5C CJK UNIFIED IDEOGRAPH-#27C5C, IRGKangXi=1197.100, RSKangXi=152.8
27C5D CJK UNIFIED IDEOGRAPH-#27C5D, IRGKangXi=1197.110, RSKangXi=152.8
27C5E CJK UNIFIED IDEOGRAPH-#27C5E, IRGKangXi=1197.120, RSKangXi=152.8
27C5F CJK UNIFIED IDEOGRAPH-#27C5F, IRGKangXi=1197.130, RSKangXi=152.8
27C60 CJK UNIFIED IDEOGRAPH-#27C60, IRGKangXi=1197.140, RSKangXi=152.8
27C61 CJK UNIFIED IDEOGRAPH-#27C61, IRGKangXi=1197.160, RSKangXi=152.8
27C62 CJK UNIFIED IDEOGRAPH-#27C62, IRGKangXi=1197.180, RSKangXi=152.8
27C63 CJK UNIFIED IDEOGRAPH-#27C63, IRGKangXi=1197.190, RSKangXi=152.8
27C64 CJK UNIFIED IDEOGRAPH-#27C64, IRGKangXi=1197.191, RSKangXi=152.8
27C65 CJK UNIFIED IDEOGRAPH-#27C65, IRGKangXi=1197.191, RSKangXi=152.8
27C66 CJK UNIFIED IDEOGRAPH-#27C66, IRGKangXi=1197.191, RSKangXi=152.8
27C67 CJK UNIFIED IDEOGRAPH-#27C67, IRGKangXi=1197.191, RSKangXi=152.8
27C68 CJK UNIFIED IDEOGRAPH-#27C68, IRGKangXi=1197.220, RSKangXi=152.9
27C69 CJK UNIFIED IDEOGRAPH-#27C69, IRGKangXi=1197.230, RSKangXi=152.9
27C6A CJK UNIFIED IDEOGRAPH-#27C6A, IRGKangXi=1197.240, RSKangXi=152.9
27C6B CJK UNIFIED IDEOGRAPH-#27C6B, IRGKangXi=1198.010, RSKangXi=152.9
27C6C CJK UNIFIED IDEOGRAPH-#27C6C, IRGKangXi=1198.030, RSKangXi=152.9
27C6D CJK UNIFIED IDEOGRAPH-#27C6D, IRGKangXi=1198.040, RSKangXi=152.9
27C6E CJK UNIFIED IDEOGRAPH-#27C6E, IRGKangXi=1198.060, RSKangXi=152.9
27C6F CJK UNIFIED IDEOGRAPH-#27C6F, IRGKangXi=1198.070, RSKangXi=152.9
27C70 CJK UNIFIED IDEOGRAPH-#27C70, IRGKangXi=1198.080, RSKangXi=152.9
27C71 CJK UNIFIED IDEOGRAPH-#27C71, IRGKangXi=1198.081, RSKangXi=152.9
27C72 CJK UNIFIED IDEOGRAPH-#27C72, IRGKangXi=1198.090, RSKangXi=152.10
27C73 CJK UNIFIED IDEOGRAPH-#27C73, IRGKangXi=1198.120, RSKangXi=152.10
27C74 CJK UNIFIED IDEOGRAPH-#27C74, IRGKangXi=1198.130, RSKangXi=152.10
27C75 CJK UNIFIED IDEOGRAPH-#27C75, IRGKangXi=1198.150, RSKangXi=152.10
27C76 CJK UNIFIED IDEOGRAPH-#27C76, IRGKangXi=1198.180, RSKangXi=152.10
27C77 CJK UNIFIED IDEOGRAPH-#27C77, IRGKangXi=1198.181, RSKangXi=152.10
27C78 CJK UNIFIED IDEOGRAPH-#27C78, IRGKangXi=1198.181, RSKangXi=152.10
27C79 CJK UNIFIED IDEOGRAPH-#27C79, IRGKangXi=1198.181, RSKangXi=152.10
27C7A CJK UNIFIED IDEOGRAPH-#27C7A, IRGKangXi=1198.181, RSKangXi=152.10
27C7B CJK UNIFIED IDEOGRAPH-#27C7B, IRGKangXi=1198.190, RSKangXi=152.11
27C7C CJK UNIFIED IDEOGRAPH-#27C7C, IRGKangXi=1198.200, RSKangXi=152.11
27C7D CJK UNIFIED IDEOGRAPH-#27C7D, IRGKangXi=1198.210, RSKangXi=152.11
27C7E CJK UNIFIED IDEOGRAPH-#27C7E, IRGKangXi=1199.040, RSKangXi=152.11
27C7F CJK UNIFIED IDEOGRAPH-#27C7F, IRGKangXi=1199.050, RSKangXi=152.11
27C80 CJK UNIFIED IDEOGRAPH-#27C80, IRGKangXi=1199.060, RSKangXi=152.11
27C81 CJK UNIFIED IDEOGRAPH-#27C81, IRGKangXi=1199.061, RSKangXi=152.11
27C82 CJK UNIFIED IDEOGRAPH-#27C82, IRGKangXi=1199.090, RSKangXi=152.12
27C83 CJK UNIFIED IDEOGRAPH-#27C83, IRGKangXi=1199.110, RSKangXi=152.12
27C84 CJK UNIFIED IDEOGRAPH-#27C84, IRGKangXi=1199.120, RSKangXi=152.12
27C85 CJK UNIFIED IDEOGRAPH-#27C85, IRGKangXi=1199.130, RSKangXi=152.12
27C86 CJK UNIFIED IDEOGRAPH-#27C86, IRGKangXi=1199.141, RSKangXi=152.12
27C87 CJK UNIFIED IDEOGRAPH-#27C87, IRGKangXi=1199.150, RSKangXi=152.13
27C88 CJK UNIFIED IDEOGRAPH-#27C88, IRGKangXi=1199.160, RSKangXi=152.13
27C89 CJK UNIFIED IDEOGRAPH-#27C89, IRGKangXi=1199.170, RSKangXi=152.13
27C8A CJK UNIFIED IDEOGRAPH-#27C8A, IRGKangXi=1199.171, RSKangXi=152.13
27C8B CJK UNIFIED IDEOGRAPH-#27C8B, IRGKangXi=1199.171, RSKangXi=152.13
27C8C CJK UNIFIED IDEOGRAPH-#27C8C, IRGKangXi=1199.180, RSKangXi=152.14
27C8D CJK UNIFIED IDEOGRAPH-#27C8D, IRGKangXi=1199.190, RSKangXi=152.14
27C8E CJK UNIFIED IDEOGRAPH-#27C8E, IRGKangXi=1199.210, RSKangXi=152.14
27C8F CJK UNIFIED IDEOGRAPH-#27C8F, IRGKangXi=1199.220, RSKangXi=152.14
27C90 CJK UNIFIED IDEOGRAPH-#27C90, IRGKangXi=1199.230, RSKangXi=152.15
27C91 CJK UNIFIED IDEOGRAPH-#27C91, IRGKangXi=1199.240, RSKangXi=152.15
27C92 CJK UNIFIED IDEOGRAPH-#27C92, IRGKangXi=1199.260, RSKangXi=152.15
27C93 CJK UNIFIED IDEOGRAPH-#27C93, IRGKangXi=1199.261, RSKangXi=152.15
27C94 CJK UNIFIED IDEOGRAPH-#27C94, IRGKangXi=1199.270, RSKangXi=152.16
27C95 CJK UNIFIED IDEOGRAPH-#27C95, IRGKangXi=1199.280, RSKangXi=152.16
27C96 CJK UNIFIED IDEOGRAPH-#27C96, IRGKangXi=1199.281, RSKangXi=152.16
27C97 CJK UNIFIED IDEOGRAPH-#27C97, IRGKangXi=1199.281, RSKangXi=152.15
27C98 CJK UNIFIED IDEOGRAPH-#27C98, IRGKangXi=1199.290, RSKangXi=152.17
27C99 CJK UNIFIED IDEOGRAPH-#27C99, IRGKangXi=1199.291, RSKangXi=152.17
27C9A CJK UNIFIED IDEOGRAPH-#27C9A, IRGKangXi=1199.300, RSKangXi=152.18
27C9B CJK UNIFIED IDEOGRAPH-#27C9B, IRGKangXi=1199.330, RSKangXi=152.18
27C9C CJK UNIFIED IDEOGRAPH-#27C9C, IRGKangXi=1199.340, RSKangXi=152.18
27C9D CJK UNIFIED IDEOGRAPH-#27C9D, IRGKangXi=1199.350, RSKangXi=152.20
27C9E CJK UNIFIED IDEOGRAPH-#27C9E, IRGKangXi=1199.351, RSKangXi=152.22
27C9F CJK UNIFIED IDEOGRAPH-#27C9F, IRGKangXi=1199.351, RSKangXi=152.29
27CA0 CJK UNIFIED IDEOGRAPH-#27CA0, IRGKangXi=1199.361, RSKangXi=153.1
27CA1 CJK UNIFIED IDEOGRAPH-#27CA1, IRGKangXi=1199.370, RSKangXi=153.2
27CA2 CJK UNIFIED IDEOGRAPH-#27CA2, IRGKangXi=1199.380, RSKangXi=153.3
27CA3 CJK UNIFIED IDEOGRAPH-#27CA3, IRGKangXi=1200.021, RSKangXi=153.3
27CA4 CJK UNIFIED IDEOGRAPH-#27CA4, IRGKangXi=1200.040, RSKangXi=153.4
27CA5 CJK UNIFIED IDEOGRAPH-#27CA5, IRGKangXi=1200.060, RSKangXi=153.4
27CA6 CJK UNIFIED IDEOGRAPH-#27CA6, IRGKangXi=1200.070, RSKangXi=153.4
27CA7 CJK UNIFIED IDEOGRAPH-#27CA7, IRGKangXi=1200.080, RSKangXi=153.4
27CA8 CJK UNIFIED IDEOGRAPH-#27CA8, IRGKangXi=1200.110, RSKangXi=153.4
27CA9 CJK UNIFIED IDEOGRAPH-#27CA9, IRGKangXi=1200.121, RSKangXi=153.4
27CAA CJK UNIFIED IDEOGRAPH-#27CAA, IRGKangXi=1200.121, RSKangXi=153.4
27CAB CJK UNIFIED IDEOGRAPH-#27CAB, IRGKangXi=1200.121, RSKangXi=153.4
27CAC CJK UNIFIED IDEOGRAPH-#27CAC, IRGKangXi=1200.130, RSKangXi=153.5
27CAD CJK UNIFIED IDEOGRAPH-#27CAD, IRGKangXi=1200.170, RSKangXi=153.5
27CAE CJK UNIFIED IDEOGRAPH-#27CAE, IRGKangXi=1200.180, RSKangXi=153.5
27CAF CJK UNIFIED IDEOGRAPH-#27CAF, IRGKangXi=1200.190, RSKangXi=153.5
27CB0 CJK UNIFIED IDEOGRAPH-#27CB0, IRGKangXi=1200.200, RSKangXi=153.5
27CB1 CJK UNIFIED IDEOGRAPH-#27CB1, IRGKangXi=1200.210, RSKangXi=153.5
27CB2 CJK UNIFIED IDEOGRAPH-#27CB2, IRGKangXi=1200.220, RSKangXi=153.5
27CB3 CJK UNIFIED IDEOGRAPH-#27CB3, IRGKangXi=1200.230, RSKangXi=153.5
27CB4 CJK UNIFIED IDEOGRAPH-#27CB4, IRGKangXi=1200.240, RSKangXi=153.5
27CB5 CJK UNIFIED IDEOGRAPH-#27CB5, IRGKangXi=1200.300, RSKangXi=153.5
27CB6 CJK UNIFIED IDEOGRAPH-#27CB6, IRGKangXi=1200.310, RSKangXi=153.5
27CB7 CJK UNIFIED IDEOGRAPH-#27CB7, IRGKangXi=1200.320, RSKangXi=153.5
27CB8 CJK UNIFIED IDEOGRAPH-#27CB8, IRGKangXi=1200.321, RSKangXi=153.5
27CB9 CJK UNIFIED IDEOGRAPH-#27CB9, IRGKangXi=1200.321, RSKangXi=153.5
27CBA CJK UNIFIED IDEOGRAPH-#27CBA, IRGKangXi=1200.321, RSKangXi=153.5
27CBB CJK UNIFIED IDEOGRAPH-#27CBB, IRGKangXi=1200.321, RSKangXi=153.5
27CBC CJK UNIFIED IDEOGRAPH-#27CBC, IRGKangXi=1200.321, RSKangXi=153.5
27CBD CJK UNIFIED IDEOGRAPH-#27CBD, IRGKangXi=1200.321, RSKangXi=153.5
27CBE CJK UNIFIED IDEOGRAPH-#27CBE, IRGKangXi=1200.330, RSKangXi=153.6
27CBF CJK UNIFIED IDEOGRAPH-#27CBF, IRGKangXi=1201.010, RSKangXi=153.6
27CC0 CJK UNIFIED IDEOGRAPH-#27CC0, IRGKangXi=1201.030, RSKangXi=153.6
27CC1 CJK UNIFIED IDEOGRAPH-#27CC1, IRGKangXi=1201.050, RSKangXi=153.6
27CC2 CJK UNIFIED IDEOGRAPH-#27CC2, IRGKangXi=1201.080, RSKangXi=153.6
27CC3 CJK UNIFIED IDEOGRAPH-#27CC3, IRGKangXi=1201.090, RSKangXi=153.6
27CC4 CJK UNIFIED IDEOGRAPH-#27CC4, IRGKangXi=1201.100, RSKangXi=153.6
27CC5 CJK UNIFIED IDEOGRAPH-#27CC5, IRGKangXi=1201.150, RSKangXi=153.6
27CC6 CJK UNIFIED IDEOGRAPH-#27CC6, IRGKangXi=1201.160, RSKangXi=153.6
27CC7 CJK UNIFIED IDEOGRAPH-#27CC7, IRGKangXi=1201.170, RSKangXi=153.6
27CC8 CJK UNIFIED IDEOGRAPH-#27CC8, IRGKangXi=1201.171, RSKangXi=153.6
27CC9 CJK UNIFIED IDEOGRAPH-#27CC9, IRGKangXi=1201.171, RSKangXi=153.6
27CCA CJK UNIFIED IDEOGRAPH-#27CCA, IRGKangXi=1201.210, RSKangXi=153.7
27CCB CJK UNIFIED IDEOGRAPH-#27CCB, IRGKangXi=1201.220, RSKangXi=153.7
27CCC CJK UNIFIED IDEOGRAPH-#27CCC, IRGKangXi=1201.240, RSKangXi=153.7
27CCD CJK UNIFIED IDEOGRAPH-#27CCD, IRGKangXi=1202.010, RSKangXi=153.7
27CCE CJK UNIFIED IDEOGRAPH-#27CCE, IRGKangXi=1202.020, RSKangXi=153.7
27CCF CJK UNIFIED IDEOGRAPH-#27CCF, IRGKangXi=1202.030, RSKangXi=153.7
27CD0 CJK UNIFIED IDEOGRAPH-#27CD0, IRGKangXi=1202.040, RSKangXi=153.7
27CD1 CJK UNIFIED IDEOGRAPH-#27CD1, IRGKangXi=1202.050, RSKangXi=153.7
27CD2 CJK UNIFIED IDEOGRAPH-#27CD2, IRGKangXi=1202.060, RSKangXi=153.7
27CD3 CJK UNIFIED IDEOGRAPH-#27CD3, IRGKangXi=1202.061, RSKangXi=153.7
27CD4 CJK UNIFIED IDEOGRAPH-#27CD4, IRGKangXi=1202.061, RSKangXi=153.7
27CD5 CJK UNIFIED IDEOGRAPH-#27CD5, IRGKangXi=1202.061, RSKangXi=153.7
27CD6 CJK UNIFIED IDEOGRAPH-#27CD6, IRGKangXi=1202.061, RSKangXi=153.7
27CD7 CJK UNIFIED IDEOGRAPH-#27CD7, IRGKangXi=1202.061, RSKangXi=153.7
27CD8 CJK UNIFIED IDEOGRAPH-#27CD8, IRGKangXi=1202.061, RSKangXi=153.7
27CD9 CJK UNIFIED IDEOGRAPH-#27CD9, IRGKangXi=1202.070, RSKangXi=153.8
27CDA CJK UNIFIED IDEOGRAPH-#27CDA, IRGKangXi=1202.080, RSKangXi=153.8
27CDB CJK UNIFIED IDEOGRAPH-#27CDB, IRGKangXi=1202.090, RSKangXi=153.8
27CDC CJK UNIFIED IDEOGRAPH-#27CDC, IRGKangXi=1202.110, RSKangXi=153.8
27CDD CJK UNIFIED IDEOGRAPH-#27CDD, IRGKangXi=1202.120, RSKangXi=153.8
27CDE CJK UNIFIED IDEOGRAPH-#27CDE, IRGKangXi=1202.130, RSKangXi=153.8
27CDF CJK UNIFIED IDEOGRAPH-#27CDF, IRGKangXi=1202.140, RSKangXi=153.8
27CE0 CJK UNIFIED IDEOGRAPH-#27CE0, IRGKangXi=1202.170, RSKangXi=153.8
27CE1 CJK UNIFIED IDEOGRAPH-#27CE1, IRGKangXi=1202.190, RSKangXi=153.8
27CE2 CJK UNIFIED IDEOGRAPH-#27CE2, IRGKangXi=1202.191, RSKangXi=153.8
27CE3 CJK UNIFIED IDEOGRAPH-#27CE3, IRGKangXi=1202.191, RSKangXi=153.8
27CE4 CJK UNIFIED IDEOGRAPH-#27CE4, IRGKangXi=1202.191, RSKangXi=153.8
27CE5 CJK UNIFIED IDEOGRAPH-#27CE5, IRGKangXi=1202.191, RSKangXi=153.8
27CE6 CJK UNIFIED IDEOGRAPH-#27CE6, IRGKangXi=1202.200, RSKangXi=153.9
27CE7 CJK UNIFIED IDEOGRAPH-#27CE7, IRGKangXi=1202.240, RSKangXi=153.9
27CE8 CJK UNIFIED IDEOGRAPH-#27CE8, IRGKangXi=1202.250, RSKangXi=153.9
27CE9 CJK UNIFIED IDEOGRAPH-#27CE9, IRGKangXi=1202.270, RSKangXi=153.9
27CEA CJK UNIFIED IDEOGRAPH-#27CEA, IRGKangXi=1202.280, RSKangXi=153.9
27CEB CJK UNIFIED IDEOGRAPH-#27CEB, IRGKangXi=1202.290, RSKangXi=153.9
27CEC CJK UNIFIED IDEOGRAPH-#27CEC, IRGKangXi=1202.310, RSKangXi=153.9
27CED CJK UNIFIED IDEOGRAPH-#27CED, IRGKangXi=1202.320, RSKangXi=153.9
27CEE CJK UNIFIED IDEOGRAPH-#27CEE, IRGKangXi=1202.330, RSKangXi=153.9
27CEF CJK UNIFIED IDEOGRAPH-#27CEF, IRGKangXi=1202.340, RSKangXi=153.9
27CF0 CJK UNIFIED IDEOGRAPH-#27CF0, IRGKangXi=1202.341, RSKangXi=153.9
27CF1 CJK UNIFIED IDEOGRAPH-#27CF1, IRGKangXi=1202.341, RSKangXi=153.8
27CF2 CJK UNIFIED IDEOGRAPH-#27CF2, IRGKangXi=1202.341, RSKangXi=153.9
27CF3 CJK UNIFIED IDEOGRAPH-#27CF3, IRGKangXi=1202.341, RSKangXi=153.9
27CF4 CJK UNIFIED IDEOGRAPH-#27CF4, IRGKangXi=1202.341, RSKangXi=153.9
27CF5 CJK UNIFIED IDEOGRAPH-#27CF5, IRGKangXi=1202.350, RSKangXi=153.10
27CF6 CJK UNIFIED IDEOGRAPH-#27CF6, IRGKangXi=1202.360, RSKangXi=153.10
27CF7 CJK UNIFIED IDEOGRAPH-#27CF7, IRGKangXi=1202.370, RSKangXi=153.10
27CF8 CJK UNIFIED IDEOGRAPH-#27CF8, IRGKangXi=1202.390, RSKangXi=153.10
27CF9 CJK UNIFIED IDEOGRAPH-#27CF9, IRGKangXi=1202.410, RSKangXi=153.10
27CFA CJK UNIFIED IDEOGRAPH-#27CFA, IRGKangXi=1203.030, RSKangXi=153.10
27CFB CJK UNIFIED IDEOGRAPH-#27CFB, IRGKangXi=1203.040, RSKangXi=153.10
27CFC CJK UNIFIED IDEOGRAPH-#27CFC, IRGKangXi=1203.050, RSKangXi=153.10
27CFD CJK UNIFIED IDEOGRAPH-#27CFD, IRGKangXi=1203.051, RSKangXi=153.10
27CFE CJK UNIFIED IDEOGRAPH-#27CFE, IRGKangXi=1203.051, RSKangXi=153.10
27CFF CJK UNIFIED IDEOGRAPH-#27CFF, IRGKangXi=1203.051, RSKangXi=153.10
27D00 CJK UNIFIED IDEOGRAPH-#27D00, IRGKangXi=1203.051, RSKangXi=153.10
27D01 CJK UNIFIED IDEOGRAPH-#27D01, IRGKangXi=1203.060, RSKangXi=153.11
27D02 CJK UNIFIED IDEOGRAPH-#27D02, IRGKangXi=1203.070, RSKangXi=153.11
27D03 CJK UNIFIED IDEOGRAPH-#27D03, IRGKangXi=1203.090, RSKangXi=153.11
27D04 CJK UNIFIED IDEOGRAPH-#27D04, IRGKangXi=1203.120, RSKangXi=153.11
27D05 CJK UNIFIED IDEOGRAPH-#27D05, IRGKangXi=1203.150, RSKangXi=153.11
27D06 CJK UNIFIED IDEOGRAPH-#27D06, IRGKangXi=1203.160, RSKangXi=153.12
27D07 CJK UNIFIED IDEOGRAPH-#27D07, IRGKangXi=1203.170, RSKangXi=153.11
27D08 CJK UNIFIED IDEOGRAPH-#27D08, IRGKangXi=1203.171, RSKangXi=153.11
27D09 CJK UNIFIED IDEOGRAPH-#27D09, IRGKangXi=1203.171, RSKangXi=153.11
27D0A CJK UNIFIED IDEOGRAPH-#27D0A, IRGKangXi=1203.171, RSKangXi=153.11
27D0B CJK UNIFIED IDEOGRAPH-#27D0B, IRGKangXi=1203.171, RSKangXi=153.11
27D0C CJK UNIFIED IDEOGRAPH-#27D0C, IRGKangXi=1203.200, RSKangXi=153.12
27D0D CJK UNIFIED IDEOGRAPH-#27D0D, IRGKangXi=1203.230, RSKangXi=153.12
27D0E CJK UNIFIED IDEOGRAPH-#27D0E, IRGKangXi=1203.250, RSKangXi=153.12
27D0F CJK UNIFIED IDEOGRAPH-#27D0F, IRGKangXi=1203.260, RSKangXi=153.12
27D10 CJK UNIFIED IDEOGRAPH-#27D10, IRGKangXi=1203.270, RSKangXi=153.13
27D11 CJK UNIFIED IDEOGRAPH-#27D11, IRGKangXi=1203.271, RSKangXi=153.12
27D12 CJK UNIFIED IDEOGRAPH-#27D12, IRGKangXi=1203.271, RSKangXi=153.12
27D13 CJK UNIFIED IDEOGRAPH-#27D13, IRGKangXi=1203.271, RSKangXi=153.12
27D14 CJK UNIFIED IDEOGRAPH-#27D14, IRGKangXi=1203.271, RSKangXi=153.12
27D15 CJK UNIFIED IDEOGRAPH-#27D15, IRGKangXi=1203.271, RSKangXi=153.12
27D16 CJK UNIFIED IDEOGRAPH-#27D16, IRGKangXi=1203.280, RSKangXi=153.13
27D17 CJK UNIFIED IDEOGRAPH-#27D17, IRGKangXi=1203.290, RSKangXi=153.13
27D18 CJK UNIFIED IDEOGRAPH-#27D18, IRGKangXi=1203.300, RSKangXi=153.13
27D19 CJK UNIFIED IDEOGRAPH-#27D19, IRGKangXi=1203.310, RSKangXi=153.13
27D1A CJK UNIFIED IDEOGRAPH-#27D1A, IRGKangXi=1203.320, RSKangXi=153.13
27D1B CJK UNIFIED IDEOGRAPH-#27D1B, IRGKangXi=1203.321, RSKangXi=153.13
27D1C CJK UNIFIED IDEOGRAPH-#27D1C, IRGKangXi=1203.321, RSKangXi=153.13
27D1D CJK UNIFIED IDEOGRAPH-#27D1D, IRGKangXi=1203.330, RSKangXi=153.14
27D1E CJK UNIFIED IDEOGRAPH-#27D1E, IRGKangXi=1203.340, RSKangXi=153.14
27D1F CJK UNIFIED IDEOGRAPH-#27D1F, IRGKangXi=1203.350, RSKangXi=153.15
27D20 CJK UNIFIED IDEOGRAPH-#27D20, IRGKangXi=1203.360, RSKangXi=153.16
27D21 CJK UNIFIED IDEOGRAPH-#27D21, IRGKangXi=1203.370, RSKangXi=153.16
27D22 CJK UNIFIED IDEOGRAPH-#27D22, IRGKangXi=1203.371, RSKangXi=153.17
27D23 CJK UNIFIED IDEOGRAPH-#27D23, IRGKangXi=1203.400, RSKangXi=153.20
27D24 CJK UNIFIED IDEOGRAPH-#27D24, IRGKangXi=1204.020, RSKangXi=154.2
27D25 CJK UNIFIED IDEOGRAPH-#27D25, IRGKangXi=1204.070, RSKangXi=154.2
27D26 CJK UNIFIED IDEOGRAPH-#27D26, IRGKangXi=1204.080, RSKangXi=154.2
27D27 CJK UNIFIED IDEOGRAPH-#27D27, IRGKangXi=1204.081, RSKangXi=154.2
27D28 CJK UNIFIED IDEOGRAPH-#27D28, IRGKangXi=1204.081, RSKangXi=154.2
27D29 CJK UNIFIED IDEOGRAPH-#27D29, IRGKangXi=1204.081, RSKangXi=154.2
27D2A CJK UNIFIED IDEOGRAPH-#27D2A, IRGKangXi=1204.090, RSKangXi=154.3, Def{fragments}
27D2B CJK UNIFIED IDEOGRAPH-#27D2B, IRGKangXi=1204.100, RSKangXi=154.3
27D2C CJK UNIFIED IDEOGRAPH-#27D2C, IRGKangXi=1205.040, RSKangXi=154.3
27D2D CJK UNIFIED IDEOGRAPH-#27D2D, IRGKangXi=1205.050, RSKangXi=154.3
27D2E CJK UNIFIED IDEOGRAPH-#27D2E, IRGKangXi=1205.051, RSKangXi=154.3
27D2F CJK UNIFIED IDEOGRAPH-#27D2F, IRGKangXi=1205.051, RSKangXi=154.3, Def{(Cant.) to carry on the back}
27D30 CJK UNIFIED IDEOGRAPH-#27D30, IRGKangXi=1205.051, RSKangXi=154.3
27D31 CJK UNIFIED IDEOGRAPH-#27D31, IRGKangXi=1205.051, RSKangXi=154.3
27D32 CJK UNIFIED IDEOGRAPH-#27D32, IRGKangXi=1205.051, RSKangXi=154.3
27D33 CJK UNIFIED IDEOGRAPH-#27D33, IRGKangXi=1205.070, RSKangXi=154.4
27D34 CJK UNIFIED IDEOGRAPH-#27D34, IRGKangXi=1205.180, RSKangXi=154.4
27D35 CJK UNIFIED IDEOGRAPH-#27D35, IRGKangXi=1206.010, RSKangXi=154.4
27D36 CJK UNIFIED IDEOGRAPH-#27D36, IRGKangXi=1206.020, RSKangXi=154.4
27D37 CJK UNIFIED IDEOGRAPH-#27D37, IRGKangXi=1206.030, RSKangXi=154.4
27D38 CJK UNIFIED IDEOGRAPH-#27D38, IRGKangXi=1206.040, RSKangXi=154.4
27D39 CJK UNIFIED IDEOGRAPH-#27D39, IRGKangXi=1206.050, RSKangXi=154.4
27D3A CJK UNIFIED IDEOGRAPH-#27D3A, IRGKangXi=1206.060, RSKangXi=154.4
27D3B CJK UNIFIED IDEOGRAPH-#27D3B, IRGKangXi=1206.061, RSKangXi=154.4
27D3C CJK UNIFIED IDEOGRAPH-#27D3C, IRGKangXi=1206.061, RSKangXi=154.4
27D3D CJK UNIFIED IDEOGRAPH-#27D3D, IRGKangXi=1206.061, RSKangXi=154.4
27D3E CJK UNIFIED IDEOGRAPH-#27D3E, IRGKangXi=1206.061, RSKangXi=154.4
27D3F CJK UNIFIED IDEOGRAPH-#27D3F, IRGKangXi=1206.061, RSKangXi=154.4
27D40 CJK UNIFIED IDEOGRAPH-#27D40, IRGKangXi=1206.061, RSKangXi=154.4
27D41 CJK UNIFIED IDEOGRAPH-#27D41, IRGKangXi=1206.061, RSKangXi=154.4
27D42 CJK UNIFIED IDEOGRAPH-#27D42, IRGKangXi=1206.061, RSKangXi=154.4
27D43 CJK UNIFIED IDEOGRAPH-#27D43, IRGKangXi=1206.061, RSKangXi=154.4
27D44 CJK UNIFIED IDEOGRAPH-#27D44, IRGKangXi=1206.061, RSKangXi=154.4
27D45 CJK UNIFIED IDEOGRAPH-#27D45, IRGKangXi=1206.061, RSKangXi=154.4
27D46 CJK UNIFIED IDEOGRAPH-#27D46, IRGKangXi=1206.061, RSKangXi=154.4
27D47 CJK UNIFIED IDEOGRAPH-#27D47, IRGKangXi=1206.061, RSKangXi=154.4
27D48 CJK UNIFIED IDEOGRAPH-#27D48, IRGKangXi=1206.061, RSKangXi=154.4
27D49 CJK UNIFIED IDEOGRAPH-#27D49, IRGKangXi=1206.080, RSKangXi=154.5
27D4A CJK UNIFIED IDEOGRAPH-#27D4A, IRGKangXi=1206.190, RSKangXi=154.5
27D4B CJK UNIFIED IDEOGRAPH-#27D4B, IRGKangXi=1207.020, RSKangXi=154.5
27D4C CJK UNIFIED IDEOGRAPH-#27D4C, IRGKangXi=1207.030, RSKangXi=154.5
27D4D CJK UNIFIED IDEOGRAPH-#27D4D, IRGKangXi=1207.090, RSKangXi=154.5
27D4E CJK UNIFIED IDEOGRAPH-#27D4E, IRGKangXi=1207.100, RSKangXi=154.5
27D4F CJK UNIFIED IDEOGRAPH-#27D4F, IRGKangXi=1207.150, RSKangXi=154.5
27D50 CJK UNIFIED IDEOGRAPH-#27D50, IRGKangXi=1207.160, RSKangXi=154.5
27D51 CJK UNIFIED IDEOGRAPH-#27D51, IRGKangXi=1207.170, RSKangXi=154.5
27D52 CJK UNIFIED IDEOGRAPH-#27D52, IRGKangXi=1207.171, RSKangXi=154.5
27D53 CJK UNIFIED IDEOGRAPH-#27D53, IRGKangXi=1207.171, RSKangXi=154.5
27D54 CJK UNIFIED IDEOGRAPH-#27D54, IRGKangXi=1207.171, RSKangXi=154.5
27D55 CJK UNIFIED IDEOGRAPH-#27D55, IRGKangXi=1207.171, RSKangXi=154.5
27D56 CJK UNIFIED IDEOGRAPH-#27D56, IRGKangXi=1207.171, RSKangXi=154.5
27D57 CJK UNIFIED IDEOGRAPH-#27D57, IRGKangXi=1207.171, RSKangXi=154.5
27D58 CJK UNIFIED IDEOGRAPH-#27D58, IRGKangXi=1207.171, RSKangXi=154.5
27D59 CJK UNIFIED IDEOGRAPH-#27D59, IRGKangXi=1207.171, RSKangXi=154.5
27D5A CJK UNIFIED IDEOGRAPH-#27D5A, IRGKangXi=1207.171, RSKangXi=154.5
27D5B CJK UNIFIED IDEOGRAPH-#27D5B, IRGKangXi=1207.171, RSKangXi=154.5
27D5C CJK UNIFIED IDEOGRAPH-#27D5C, IRGKangXi=1207.171, RSKangXi=154.5
27D5D CJK UNIFIED IDEOGRAPH-#27D5D, IRGKangXi=1207.171, RSKangXi=154.5
27D5E CJK UNIFIED IDEOGRAPH-#27D5E, IRGKangXi=1207.171, RSKangXi=154.5
27D5F CJK UNIFIED IDEOGRAPH-#27D5F, IRGKangXi=1207.171, RSKangXi=154.5
27D60 CJK UNIFIED IDEOGRAPH-#27D60, IRGKangXi=1207.171, RSKangXi=154.5
27D61 CJK UNIFIED IDEOGRAPH-#27D61, IRGKangXi=1207.171, RSKangXi=154.5
27D62 CJK UNIFIED IDEOGRAPH-#27D62, IRGKangXi=1207.171, RSKangXi=154.5
27D63 CJK UNIFIED IDEOGRAPH-#27D63, IRGKangXi=1207.190, RSKangXi=154.6
27D64 CJK UNIFIED IDEOGRAPH-#27D64, IRGKangXi=1207.200, RSKangXi=154.5
27D65 CJK UNIFIED IDEOGRAPH-#27D65, IRGKangXi=1207.210, RSKangXi=154.6
27D66 CJK UNIFIED IDEOGRAPH-#27D66, IRGKangXi=1208.010, RSKangXi=154.6
27D67 CJK UNIFIED IDEOGRAPH-#27D67, IRGKangXi=1208.070, RSKangXi=154.6
27D68 CJK UNIFIED IDEOGRAPH-#27D68, IRGKangXi=1208.080, RSKangXi=154.6
27D69 CJK UNIFIED IDEOGRAPH-#27D69, IRGKangXi=1208.120, RSKangXi=154.6
27D6A CJK UNIFIED IDEOGRAPH-#27D6A, IRGKangXi=1208.130, RSKangXi=154.6
27D6B CJK UNIFIED IDEOGRAPH-#27D6B, IRGKangXi=1208.150, RSKangXi=154.6
27D6C CJK UNIFIED IDEOGRAPH-#27D6C, IRGKangXi=1208.170, RSKangXi=154.6
27D6D CJK UNIFIED IDEOGRAPH-#27D6D, IRGKangXi=1208.180, RSKangXi=154.6
27D6E CJK UNIFIED IDEOGRAPH-#27D6E, IRGKangXi=1208.190, RSKangXi=154.6
27D6F CJK UNIFIED IDEOGRAPH-#27D6F, IRGKangXi=1208.200, RSKangXi=154.6
27D70 CJK UNIFIED IDEOGRAPH-#27D70, IRGKangXi=1208.210, RSKangXi=154.6
27D71 CJK UNIFIED IDEOGRAPH-#27D71, IRGKangXi=1208.230, RSKangXi=154.6
27D72 CJK UNIFIED IDEOGRAPH-#27D72, IRGKangXi=1208.240, RSKangXi=154.6
27D73 CJK UNIFIED IDEOGRAPH-#27D73, IRGKangXi=1208.241, RSKangXi=154.6, Def{a loss; to lose (e.g., money in trade)}
27D74 CJK UNIFIED IDEOGRAPH-#27D74, IRGKangXi=1208.241, RSKangXi=154.6
27D75 CJK UNIFIED IDEOGRAPH-#27D75, IRGKangXi=1208.241, RSKangXi=154.6
27D76 CJK UNIFIED IDEOGRAPH-#27D76, IRGKangXi=1208.241, RSKangXi=154.6
27D77 CJK UNIFIED IDEOGRAPH-#27D77, IRGKangXi=1208.241, RSKangXi=154.6
27D78 CJK UNIFIED IDEOGRAPH-#27D78, IRGKangXi=1208.241, RSKangXi=154.6
27D79 CJK UNIFIED IDEOGRAPH-#27D79, IRGKangXi=1208.241, RSKangXi=154.6
27D7A CJK UNIFIED IDEOGRAPH-#27D7A, IRGKangXi=1208.241, RSKangXi=154.6
27D7B CJK UNIFIED IDEOGRAPH-#27D7B, IRGKangXi=1208.241, RSKangXi=154.6
27D7C CJK UNIFIED IDEOGRAPH-#27D7C, IRGKangXi=1208.241, RSKangXi=154.6
27D7D CJK UNIFIED IDEOGRAPH-#27D7D, IRGKangXi=1208.241, RSKangXi=154.6
27D7E CJK UNIFIED IDEOGRAPH-#27D7E, IRGKangXi=1208.241, RSKangXi=154.6
27D7F CJK UNIFIED IDEOGRAPH-#27D7F, IRGKangXi=1208.241, RSKangXi=154.6
27D80 CJK UNIFIED IDEOGRAPH-#27D80, IRGKangXi=1208.241, RSKangXi=154.6
27D81 CJK UNIFIED IDEOGRAPH-#27D81, IRGKangXi=1208.241, RSKangXi=154.6
27D82 CJK UNIFIED IDEOGRAPH-#27D82, IRGKangXi=1208.241, RSKangXi=154.6
27D83 CJK UNIFIED IDEOGRAPH-#27D83, IRGKangXi=1208.241, RSKangXi=154.6
27D84 CJK UNIFIED IDEOGRAPH-#27D84, IRGKangXi=1208.241, RSKangXi=154.6, Def{(Cant.) to owe}
27D85 CJK UNIFIED IDEOGRAPH-#27D85, IRGKangXi=1208.250, RSKangXi=154.7
27D86 CJK UNIFIED IDEOGRAPH-#27D86, IRGKangXi=1208.310, RSKangXi=154.7
27D87 CJK UNIFIED IDEOGRAPH-#27D87, IRGKangXi=1208.320, RSKangXi=154.7
27D88 CJK UNIFIED IDEOGRAPH-#27D88, IRGKangXi=1208.330, RSKangXi=154.7
27D89 CJK UNIFIED IDEOGRAPH-#27D89, IRGKangXi=1209.010, RSKangXi=154.7
27D8A CJK UNIFIED IDEOGRAPH-#27D8A, IRGKangXi=1209.040, RSKangXi=154.7
27D8B CJK UNIFIED IDEOGRAPH-#27D8B, IRGKangXi=1209.050, RSKangXi=154.7
27D8C CJK UNIFIED IDEOGRAPH-#27D8C, IRGKangXi=1209.060, RSKangXi=154.7
27D8D CJK UNIFIED IDEOGRAPH-#27D8D, IRGKangXi=1209.070, RSKangXi=154.7
27D8E CJK UNIFIED IDEOGRAPH-#27D8E, IRGKangXi=1209.080, RSKangXi=154.7
27D8F CJK UNIFIED IDEOGRAPH-#27D8F, IRGKangXi=1209.081, RSKangXi=154.7
27D90 CJK UNIFIED IDEOGRAPH-#27D90, IRGKangXi=1209.081, RSKangXi=154.7
27D91 CJK UNIFIED IDEOGRAPH-#27D91, IRGKangXi=1209.081, RSKangXi=154.7
27D92 CJK UNIFIED IDEOGRAPH-#27D92, IRGKangXi=1209.081, RSKangXi=154.7
27D93 CJK UNIFIED IDEOGRAPH-#27D93, IRGKangXi=1209.081, RSKangXi=154.7
27D94 CJK UNIFIED IDEOGRAPH-#27D94, IRGKangXi=1209.081, RSKangXi=154.7
27D95 CJK UNIFIED IDEOGRAPH-#27D95, IRGKangXi=1209.081, RSKangXi=154.7
27D96 CJK UNIFIED IDEOGRAPH-#27D96, IRGKangXi=1209.081, RSKangXi=154.7
27D97 CJK UNIFIED IDEOGRAPH-#27D97, IRGKangXi=1209.081, RSKangXi=154.7
27D98 CJK UNIFIED IDEOGRAPH-#27D98, IRGKangXi=1209.081, RSKangXi=154.7
27D99 CJK UNIFIED IDEOGRAPH-#27D99, IRGKangXi=1209.081, RSKangXi=154.7
27D9A CJK UNIFIED IDEOGRAPH-#27D9A, IRGKangXi=1209.081, RSKangXi=154.7
27D9B CJK UNIFIED IDEOGRAPH-#27D9B, IRGKangXi=1209.110, RSKangXi=154.8
27D9C CJK UNIFIED IDEOGRAPH-#27D9C, IRGKangXi=1209.140, RSKangXi=154.8
27D9D CJK UNIFIED IDEOGRAPH-#27D9D, IRGKangXi=1209.210, RSKangXi=154.8
27D9E CJK UNIFIED IDEOGRAPH-#27D9E, IRGKangXi=1209.220, RSKangXi=154.8
27D9F CJK UNIFIED IDEOGRAPH-#27D9F, IRGKangXi=1209.310, RSKangXi=154.8
27DA0 CJK UNIFIED IDEOGRAPH-#27DA0, IRGKangXi=1209.320, RSKangXi=154.8
27DA1 CJK UNIFIED IDEOGRAPH-#27DA1, IRGKangXi=1210.090, RSKangXi=154.8
27DA2 CJK UNIFIED IDEOGRAPH-#27DA2, IRGKangXi=1210.100, RSKangXi=154.8
27DA3 CJK UNIFIED IDEOGRAPH-#27DA3, IRGKangXi=1210.120, RSKangXi=154.8
27DA4 CJK UNIFIED IDEOGRAPH-#27DA4, IRGKangXi=1210.130, RSKangXi=154.8
27DA5 CJK UNIFIED IDEOGRAPH-#27DA5, IRGKangXi=1210.131, RSKangXi=154.8
27DA6 CJK UNIFIED IDEOGRAPH-#27DA6, IRGKangXi=1210.131, RSKangXi=154.8
27DA7 CJK UNIFIED IDEOGRAPH-#27DA7, IRGKangXi=1210.131, RSKangXi=154.8
27DA8 CJK UNIFIED IDEOGRAPH-#27DA8, IRGKangXi=1210.131, RSKangXi=154.8
27DA9 CJK UNIFIED IDEOGRAPH-#27DA9, IRGKangXi=1210.131, RSKangXi=154.8
27DAA CJK UNIFIED IDEOGRAPH-#27DAA, IRGKangXi=1210.131, RSKangXi=154.8
27DAB CJK UNIFIED IDEOGRAPH-#27DAB, IRGKangXi=1210.131, RSKangXi=154.8
27DAC CJK UNIFIED IDEOGRAPH-#27DAC, IRGKangXi=1210.131, RSKangXi=154.8
27DAD CJK UNIFIED IDEOGRAPH-#27DAD, IRGKangXi=1210.131, RSKangXi=154.8
27DAE CJK UNIFIED IDEOGRAPH-#27DAE, IRGKangXi=1210.131, RSKangXi=154.8
27DAF CJK UNIFIED IDEOGRAPH-#27DAF, IRGKangXi=1210.131, RSKangXi=154.8
27DB0 CJK UNIFIED IDEOGRAPH-#27DB0, IRGKangXi=1210.131, RSKangXi=154.8
27DB1 CJK UNIFIED IDEOGRAPH-#27DB1, IRGKangXi=1210.140, RSKangXi=154.9
27DB2 CJK UNIFIED IDEOGRAPH-#27DB2, IRGKangXi=1210.150, RSKangXi=154.9
27DB3 CJK UNIFIED IDEOGRAPH-#27DB3, IRGKangXi=1210.160, RSKangXi=154.9
27DB4 CJK UNIFIED IDEOGRAPH-#27DB4, IRGKangXi=1210.180, RSKangXi=154.9
27DB5 CJK UNIFIED IDEOGRAPH-#27DB5, IRGKangXi=1210.190, RSKangXi=154.9
27DB6 CJK UNIFIED IDEOGRAPH-#27DB6, IRGKangXi=1210.230, RSKangXi=154.9, Def{to peddle, trade, deal in}
27DB7 CJK UNIFIED IDEOGRAPH-#27DB7, IRGKangXi=1210.280, RSKangXi=154.9
27DB8 CJK UNIFIED IDEOGRAPH-#27DB8, IRGKangXi=1211.020, RSKangXi=154.9
27DB9 CJK UNIFIED IDEOGRAPH-#27DB9, IRGKangXi=1211.070, RSKangXi=154.9
27DBA CJK UNIFIED IDEOGRAPH-#27DBA, IRGKangXi=1211.080, RSKangXi=154.9
27DBB CJK UNIFIED IDEOGRAPH-#27DBB, IRGKangXi=1211.090, RSKangXi=154.9
27DBC CJK UNIFIED IDEOGRAPH-#27DBC, IRGKangXi=1211.091, RSKangXi=154.9
27DBD CJK UNIFIED IDEOGRAPH-#27DBD, IRGKangXi=1211.091, RSKangXi=154.9
27DBE CJK UNIFIED IDEOGRAPH-#27DBE, IRGKangXi=1211.091, RSKangXi=154.9
27DBF CJK UNIFIED IDEOGRAPH-#27DBF, IRGKangXi=1211.091, RSKangXi=154.9
27DC0 CJK UNIFIED IDEOGRAPH-#27DC0, IRGKangXi=1211.091, RSKangXi=154.9
27DC1 CJK UNIFIED IDEOGRAPH-#27DC1, IRGKangXi=1211.091, RSKangXi=154.9
27DC2 CJK UNIFIED IDEOGRAPH-#27DC2, IRGKangXi=1211.091, RSKangXi=154.9
27DC3 CJK UNIFIED IDEOGRAPH-#27DC3, IRGKangXi=1211.091, RSKangXi=154.9
27DC4 CJK UNIFIED IDEOGRAPH-#27DC4, IRGKangXi=1211.091, RSKangXi=154.9
27DC5 CJK UNIFIED IDEOGRAPH-#27DC5, IRGKangXi=1211.091, RSKangXi=122.12
27DC6 CJK UNIFIED IDEOGRAPH-#27DC6, IRGKangXi=1211.091, RSKangXi=154.9
27DC7 CJK UNIFIED IDEOGRAPH-#27DC7, IRGKangXi=1211.091, RSKangXi=154.9
27DC8 CJK UNIFIED IDEOGRAPH-#27DC8, IRGKangXi=1211.091, RSKangXi=154.9
27DC9 CJK UNIFIED IDEOGRAPH-#27DC9, IRGKangXi=1211.091, RSKangXi=154.9
27DCA CJK UNIFIED IDEOGRAPH-#27DCA, IRGKangXi=1211.091, RSKangXi=154.9
27DCB CJK UNIFIED IDEOGRAPH-#27DCB, IRGKangXi=1211.091, RSKangXi=154.9
27DCC CJK UNIFIED IDEOGRAPH-#27DCC, IRGKangXi=1211.110, RSKangXi=154.10
27DCD CJK UNIFIED IDEOGRAPH-#27DCD, IRGKangXi=1211.130, RSKangXi=154.10
27DCE CJK UNIFIED IDEOGRAPH-#27DCE, IRGKangXi=1211.140, RSKangXi=154.10
27DCF CJK UNIFIED IDEOGRAPH-#27DCF, IRGKangXi=1211.200, RSKangXi=154.10
27DD0 CJK UNIFIED IDEOGRAPH-#27DD0, IRGKangXi=1211.250, RSKangXi=154.10
27DD1 CJK UNIFIED IDEOGRAPH-#27DD1, IRGKangXi=1211.270, RSKangXi=154.10
27DD2 CJK UNIFIED IDEOGRAPH-#27DD2, IRGKangXi=1211.280, RSKangXi=154.10
27DD3 CJK UNIFIED IDEOGRAPH-#27DD3, IRGKangXi=1211.290, RSKangXi=154.10
27DD4 CJK UNIFIED IDEOGRAPH-#27DD4, IRGKangXi=1211.300, RSKangXi=154.10
27DD5 CJK UNIFIED IDEOGRAPH-#27DD5, IRGKangXi=1211.310, RSKangXi=154.10
27DD6 CJK UNIFIED IDEOGRAPH-#27DD6, IRGKangXi=1211.320, RSKangXi=154.10
27DD7 CJK UNIFIED IDEOGRAPH-#27DD7, IRGKangXi=1211.330, RSKangXi=154.10
27DD8 CJK UNIFIED IDEOGRAPH-#27DD8, IRGKangXi=1211.331, RSKangXi=154.10
27DD9 CJK UNIFIED IDEOGRAPH-#27DD9, IRGKangXi=1211.331, RSKangXi=154.10
27DDA CJK UNIFIED IDEOGRAPH-#27DDA, IRGKangXi=1211.331, RSKangXi=154.10
27DDB CJK UNIFIED IDEOGRAPH-#27DDB, IRGKangXi=1211.331, RSKangXi=154.10
27DDC CJK UNIFIED IDEOGRAPH-#27DDC, IRGKangXi=1211.331, RSKangXi=154.10
27DDD CJK UNIFIED IDEOGRAPH-#27DDD, IRGKangXi=1211.331, RSKangXi=154.10
27DDE CJK UNIFIED IDEOGRAPH-#27DDE, IRGKangXi=1211.350, RSKangXi=154.11
27DDF CJK UNIFIED IDEOGRAPH-#27DDF, IRGKangXi=1211.370, RSKangXi=154.11
27DE0 CJK UNIFIED IDEOGRAPH-#27DE0, IRGKangXi=1211.400, RSKangXi=154.11
27DE1 CJK UNIFIED IDEOGRAPH-#27DE1, IRGKangXi=1211.410, RSKangXi=154.11
27DE2 CJK UNIFIED IDEOGRAPH-#27DE2, IRGKangXi=1211.420, RSKangXi=154.11
27DE3 CJK UNIFIED IDEOGRAPH-#27DE3, IRGKangXi=1211.430, RSKangXi=154.11
27DE4 CJK UNIFIED IDEOGRAPH-#27DE4, IRGKangXi=1211.450, RSKangXi=154.11
27DE5 CJK UNIFIED IDEOGRAPH-#27DE5, IRGKangXi=1212.010, RSKangXi=154.11
27DE6 CJK UNIFIED IDEOGRAPH-#27DE6, IRGKangXi=1212.020, RSKangXi=154.11
27DE7 CJK UNIFIED IDEOGRAPH-#27DE7, IRGKangXi=1212.030, RSKangXi=154.11
27DE8 CJK UNIFIED IDEOGRAPH-#27DE8, IRGKangXi=1212.040, RSKangXi=154.11
27DE9 CJK UNIFIED IDEOGRAPH-#27DE9, IRGKangXi=1212.050, RSKangXi=154.11
27DEA CJK UNIFIED IDEOGRAPH-#27DEA, IRGKangXi=1212.051, RSKangXi=154.11
27DEB CJK UNIFIED IDEOGRAPH-#27DEB, IRGKangXi=1212.051, RSKangXi=154.11
27DEC CJK UNIFIED IDEOGRAPH-#27DEC, IRGKangXi=1212.051, RSKangXi=154.11
27DED CJK UNIFIED IDEOGRAPH-#27DED, IRGKangXi=1212.051, RSKangXi=154.11
27DEE CJK UNIFIED IDEOGRAPH-#27DEE, IRGKangXi=1212.051, RSKangXi=154.11
27DEF CJK UNIFIED IDEOGRAPH-#27DEF, IRGKangXi=1212.051, RSKangXi=154.11
27DF0 CJK UNIFIED IDEOGRAPH-#27DF0, IRGKangXi=1212.051, RSKangXi=154.11
27DF1 CJK UNIFIED IDEOGRAPH-#27DF1, IRGKangXi=1212.051, RSKangXi=154.11
27DF2 CJK UNIFIED IDEOGRAPH-#27DF2, IRGKangXi=1212.051, RSKangXi=154.11
27DF3 CJK UNIFIED IDEOGRAPH-#27DF3, IRGKangXi=1212.051, RSKangXi=154.11
27DF4 CJK UNIFIED IDEOGRAPH-#27DF4, IRGKangXi=1212.051, RSKangXi=154.11
27DF5 CJK UNIFIED IDEOGRAPH-#27DF5, IRGKangXi=1212.051, RSKangXi=154.11
27DF6 CJK UNIFIED IDEOGRAPH-#27DF6, IRGKangXi=1212.051, RSKangXi=154.11
27DF7 CJK UNIFIED IDEOGRAPH-#27DF7, IRGKangXi=1212.051, RSKangXi=154.11
27DF8 CJK UNIFIED IDEOGRAPH-#27DF8, IRGKangXi=1212.051, RSKangXi=154.11
27DF9 CJK UNIFIED IDEOGRAPH-#27DF9, IRGKangXi=1212.051, RSKangXi=154.11
27DFA CJK UNIFIED IDEOGRAPH-#27DFA, IRGKangXi=1212.051, RSKangXi=154.11
27DFB CJK UNIFIED IDEOGRAPH-#27DFB, IRGKangXi=1212.051, RSKangXi=154.11
27DFC CJK UNIFIED IDEOGRAPH-#27DFC, IRGKangXi=1212.070, RSKangXi=154.12
27DFD CJK UNIFIED IDEOGRAPH-#27DFD, IRGKangXi=1212.080, RSKangXi=154.12
27DFE CJK UNIFIED IDEOGRAPH-#27DFE, IRGKangXi=1212.090, RSKangXi=154.12
27DFF CJK UNIFIED IDEOGRAPH-#27DFF, IRGKangXi=1212.120, RSKangXi=154.12
27E00 CJK UNIFIED IDEOGRAPH-#27E00, IRGKangXi=1212.130, RSKangXi=154.12
27E01 CJK UNIFIED IDEOGRAPH-#27E01, IRGKangXi=1212.140, RSKangXi=154.12
27E02 CJK UNIFIED IDEOGRAPH-#27E02, IRGKangXi=1212.160, RSKangXi=154.12
27E03 CJK UNIFIED IDEOGRAPH-#27E03, IRGKangXi=1212.180, RSKangXi=154.12
27E04 CJK UNIFIED IDEOGRAPH-#27E04, IRGKangXi=1212.190, RSKangXi=154.12
27E05 CJK UNIFIED IDEOGRAPH-#27E05, IRGKangXi=1212.200, RSKangXi=154.12
27E06 CJK UNIFIED IDEOGRAPH-#27E06, IRGKangXi=1212.220, RSKangXi=154.12
27E07 CJK UNIFIED IDEOGRAPH-#27E07, IRGKangXi=1212.230, RSKangXi=154.12
27E08 CJK UNIFIED IDEOGRAPH-#27E08, IRGKangXi=1212.240, RSKangXi=154.12
27E09 CJK UNIFIED IDEOGRAPH-#27E09, IRGKangXi=1212.250, RSKangXi=154.12
27E0A CJK UNIFIED IDEOGRAPH-#27E0A, IRGKangXi=1212.260, RSKangXi=154.12
27E0B CJK UNIFIED IDEOGRAPH-#27E0B, IRGKangXi=1212.270, RSKangXi=154.12
27E0C CJK UNIFIED IDEOGRAPH-#27E0C, IRGKangXi=1212.271, RSKangXi=154.12
27E0D CJK UNIFIED IDEOGRAPH-#27E0D, IRGKangXi=1212.271, RSKangXi=154.12
27E0E CJK UNIFIED IDEOGRAPH-#27E0E, IRGKangXi=1212.271, RSKangXi=154.12
27E0F CJK UNIFIED IDEOGRAPH-#27E0F, IRGKangXi=1212.271, RSKangXi=154.12
27E10 CJK UNIFIED IDEOGRAPH-#27E10, IRGKangXi=1212.271, RSKangXi=154.12
27E11 CJK UNIFIED IDEOGRAPH-#27E11, IRGKangXi=1212.271, RSKangXi=154.12
27E12 CJK UNIFIED IDEOGRAPH-#27E12, IRGKangXi=1212.271, RSKangXi=154.12
27E13 CJK UNIFIED IDEOGRAPH-#27E13, IRGKangXi=1212.271, RSKangXi=154.12
27E14 CJK UNIFIED IDEOGRAPH-#27E14, IRGKangXi=1212.271, RSKangXi=154.12
27E15 CJK UNIFIED IDEOGRAPH-#27E15, IRGKangXi=1212.271, RSKangXi=154.12
27E16 CJK UNIFIED IDEOGRAPH-#27E16, IRGKangXi=1212.290, RSKangXi=154.13, Def{to earn, sell at a profit}
27E17 CJK UNIFIED IDEOGRAPH-#27E17, IRGKangXi=1212.310, RSKangXi=154.13
27E18 CJK UNIFIED IDEOGRAPH-#27E18, IRGKangXi=1212.320, RSKangXi=154.13
27E19 CJK UNIFIED IDEOGRAPH-#27E19, IRGKangXi=1212.340, RSKangXi=154.13
27E1A CJK UNIFIED IDEOGRAPH-#27E1A, IRGKangXi=1212.350, RSKangXi=154.13
27E1B CJK UNIFIED IDEOGRAPH-#27E1B, IRGKangXi=1212.351, RSKangXi=154.13
27E1C CJK UNIFIED IDEOGRAPH-#27E1C, IRGKangXi=1212.351, RSKangXi=154.13
27E1D CJK UNIFIED IDEOGRAPH-#27E1D, IRGKangXi=1212.351, RSKangXi=154.13
27E1E CJK UNIFIED IDEOGRAPH-#27E1E, IRGKangXi=1212.351, RSKangXi=154.13
27E1F CJK UNIFIED IDEOGRAPH-#27E1F, IRGKangXi=1212.351, RSKangXi=154.13
27E20 CJK UNIFIED IDEOGRAPH-#27E20, IRGKangXi=1212.351, RSKangXi=154.13
27E21 CJK UNIFIED IDEOGRAPH-#27E21, IRGKangXi=1212.351, RSKangXi=154.13
27E22 CJK UNIFIED IDEOGRAPH-#27E22, IRGKangXi=1212.351, RSKangXi=154.13
27E23 CJK UNIFIED IDEOGRAPH-#27E23, IRGKangXi=1212.351, RSKangXi=154.13
27E24 CJK UNIFIED IDEOGRAPH-#27E24, IRGKangXi=1212.351, RSKangXi=154.13
27E25 CJK UNIFIED IDEOGRAPH-#27E25, IRGKangXi=1212.351, RSKangXi=154.13
27E26 CJK UNIFIED IDEOGRAPH-#27E26, IRGKangXi=1212.370, RSKangXi=154.14
27E27 CJK UNIFIED IDEOGRAPH-#27E27, IRGKangXi=1212.380, RSKangXi=154.14
27E28 CJK UNIFIED IDEOGRAPH-#27E28, IRGKangXi=1212.390, RSKangXi=154.14
27E29 CJK UNIFIED IDEOGRAPH-#27E29, IRGKangXi=1213.040, RSKangXi=154.14
27E2A CJK UNIFIED IDEOGRAPH-#27E2A, IRGKangXi=1213.050, RSKangXi=154.14
27E2B CJK UNIFIED IDEOGRAPH-#27E2B, IRGKangXi=1213.060, RSKangXi=154.14
27E2C CJK UNIFIED IDEOGRAPH-#27E2C, IRGKangXi=1213.061, RSKangXi=154.14
27E2D CJK UNIFIED IDEOGRAPH-#27E2D, IRGKangXi=1213.061, RSKangXi=154.14
27E2E CJK UNIFIED IDEOGRAPH-#27E2E, IRGKangXi=1213.061, RSKangXi=154.14
27E2F CJK UNIFIED IDEOGRAPH-#27E2F, IRGKangXi=1213.061, RSKangXi=154.14
27E30 CJK UNIFIED IDEOGRAPH-#27E30, IRGKangXi=1213.061, RSKangXi=154.14
27E31 CJK UNIFIED IDEOGRAPH-#27E31, IRGKangXi=1213.090, RSKangXi=154.15
27E32 CJK UNIFIED IDEOGRAPH-#27E32, IRGKangXi=1213.110, RSKangXi=154.15
27E33 CJK UNIFIED IDEOGRAPH-#27E33, IRGKangXi=1213.111, RSKangXi=154.15
27E34 CJK UNIFIED IDEOGRAPH-#27E34, IRGKangXi=1213.111, RSKangXi=154.15
27E35 CJK UNIFIED IDEOGRAPH-#27E35, IRGKangXi=1213.111, RSKangXi=154.15
27E36 CJK UNIFIED IDEOGRAPH-#27E36, IRGKangXi=1213.111, RSKangXi=154.15
27E37 CJK UNIFIED IDEOGRAPH-#27E37, IRGKangXi=1213.111, RSKangXi=154.15
27E38 CJK UNIFIED IDEOGRAPH-#27E38, IRGKangXi=1213.111, RSKangXi=154.15
27E39 CJK UNIFIED IDEOGRAPH-#27E39, IRGKangXi=1213.111, RSKangXi=154.15
27E3A CJK UNIFIED IDEOGRAPH-#27E3A, IRGKangXi=1213.111, RSKangXi=154.15
27E3B CJK UNIFIED IDEOGRAPH-#27E3B, IRGKangXi=1213.111, RSKangXi=154.15
27E3C CJK UNIFIED IDEOGRAPH-#27E3C, IRGKangXi=1213.111, RSKangXi=154.15
27E3D CJK UNIFIED IDEOGRAPH-#27E3D, IRGKangXi=1213.120, RSKangXi=154.16
27E3E CJK UNIFIED IDEOGRAPH-#27E3E, IRGKangXi=1213.160, RSKangXi=154.16
27E3F CJK UNIFIED IDEOGRAPH-#27E3F, IRGKangXi=1213.170, RSKangXi=154.15
27E40 CJK UNIFIED IDEOGRAPH-#27E40, IRGKangXi=1213.180, RSKangXi=154.16
27E41 CJK UNIFIED IDEOGRAPH-#27E41, IRGKangXi=1213.181, RSKangXi=154.16
27E42 CJK UNIFIED IDEOGRAPH-#27E42, IRGKangXi=1213.181, RSKangXi=154.16
27E43 CJK UNIFIED IDEOGRAPH-#27E43, IRGKangXi=1213.181, RSKangXi=154.16
27E44 CJK UNIFIED IDEOGRAPH-#27E44, IRGKangXi=1213.181, RSKangXi=154.16
27E45 CJK UNIFIED IDEOGRAPH-#27E45, IRGKangXi=1213.181, RSKangXi=154.16
27E46 CJK UNIFIED IDEOGRAPH-#27E46, IRGKangXi=1213.181, RSKangXi=154.16
27E47 CJK UNIFIED IDEOGRAPH-#27E47, IRGKangXi=1213.181, RSKangXi=154.16
27E48 CJK UNIFIED IDEOGRAPH-#27E48, IRGKangXi=1213.200, RSKangXi=154.17
27E49 CJK UNIFIED IDEOGRAPH-#27E49, IRGKangXi=1213.201, RSKangXi=154.17
27E4A CJK UNIFIED IDEOGRAPH-#27E4A, IRGKangXi=1213.201, RSKangXi=154.17
27E4B CJK UNIFIED IDEOGRAPH-#27E4B, IRGKangXi=1213.201, RSKangXi=154.17
27E4C CJK UNIFIED IDEOGRAPH-#27E4C, IRGKangXi=1213.201, RSKangXi=154.18
27E4D CJK UNIFIED IDEOGRAPH-#27E4D, IRGKangXi=1213.201, RSKangXi=154.18
27E4E CJK UNIFIED IDEOGRAPH-#27E4E, IRGKangXi=1213.210, RSKangXi=154.19
27E4F CJK UNIFIED IDEOGRAPH-#27E4F, IRGKangXi=1213.211, RSKangXi=154.19
27E50 CJK UNIFIED IDEOGRAPH-#27E50, IRGKangXi=1213.211, RSKangXi=154.19
27E51 CJK UNIFIED IDEOGRAPH-#27E51, IRGKangXi=1213.211, RSKangXi=154.4
27E52 CJK UNIFIED IDEOGRAPH-#27E52, IRGKangXi=1213.211, RSKangXi=154.5
27E53 CJK UNIFIED IDEOGRAPH-#27E53, IRGKangXi=1213.211, RSKangXi=154.7
27E54 CJK UNIFIED IDEOGRAPH-#27E54, IRGKangXi=1213.211, RSKangXi=154.8
27E55 CJK UNIFIED IDEOGRAPH-#27E55, IRGKangXi=1213.211, RSKangXi=154.8
27E56 CJK UNIFIED IDEOGRAPH-#27E56, IRGKangXi=1213.211, RSKangXi=154.8
27E57 CJK UNIFIED IDEOGRAPH-#27E57, IRGKangXi=1213.211, RSKangXi=154.11
27E58 CJK UNIFIED IDEOGRAPH-#27E58, IRGKangXi=1213.231, RSKangXi=155.1
27E59 CJK UNIFIED IDEOGRAPH-#27E59, IRGKangXi=1213.240, RSKangXi=155.2
27E5A CJK UNIFIED IDEOGRAPH-#27E5A, IRGKangXi=1213.250, RSKangXi=155.2
27E5B CJK UNIFIED IDEOGRAPH-#27E5B, IRGKangXi=1213.270, RSKangXi=155.4
27E5C CJK UNIFIED IDEOGRAPH-#27E5C, IRGKangXi=1214.011, RSKangXi=155.4
27E5D CJK UNIFIED IDEOGRAPH-#27E5D, IRGKangXi=1214.020, RSKangXi=155.5
27E5E CJK UNIFIED IDEOGRAPH-#27E5E, IRGKangXi=1214.040, RSKangXi=155.5
27E5F CJK UNIFIED IDEOGRAPH-#27E5F, IRGKangXi=1214.041, RSKangXi=155.5
27E60 CJK UNIFIED IDEOGRAPH-#27E60, IRGKangXi=1214.080, RSKangXi=155.6
27E61 CJK UNIFIED IDEOGRAPH-#27E61, IRGKangXi=1214.081, RSKangXi=155.6
27E62 CJK UNIFIED IDEOGRAPH-#27E62, IRGKangXi=1214.081, RSKangXi=155.6
27E63 CJK UNIFIED IDEOGRAPH-#27E63, IRGKangXi=1214.090, RSKangXi=155.7
27E64 CJK UNIFIED IDEOGRAPH-#27E64, IRGKangXi=1214.121, RSKangXi=155.7
27E65 CJK UNIFIED IDEOGRAPH-#27E65, IRGKangXi=1214.121, RSKangXi=155.7
27E66 CJK UNIFIED IDEOGRAPH-#27E66, IRGKangXi=1214.121, RSKangXi=155.7
27E67 CJK UNIFIED IDEOGRAPH-#27E67, IRGKangXi=1214.121, RSKangXi=155.8
27E68 CJK UNIFIED IDEOGRAPH-#27E68, IRGKangXi=1214.121, RSKangXi=155.8
27E69 CJK UNIFIED IDEOGRAPH-#27E69, IRGKangXi=1214.121, RSKangXi=155.8
27E6A CJK UNIFIED IDEOGRAPH-#27E6A, IRGKangXi=1214.121, RSKangXi=155.8
27E6B CJK UNIFIED IDEOGRAPH-#27E6B, IRGKangXi=1214.121, RSKangXi=155.8
27E6C CJK UNIFIED IDEOGRAPH-#27E6C, IRGKangXi=1214.130, RSKangXi=155.9
27E6D CJK UNIFIED IDEOGRAPH-#27E6D, IRGKangXi=1214.140, RSKangXi=155.9
27E6E CJK UNIFIED IDEOGRAPH-#27E6E, IRGKangXi=1214.171, RSKangXi=155.9
27E6F CJK UNIFIED IDEOGRAPH-#27E6F, IRGKangXi=1214.171, RSKangXi=155.9
27E70 CJK UNIFIED IDEOGRAPH-#27E70, IRGKangXi=1214.171, RSKangXi=155.9
27E71 CJK UNIFIED IDEOGRAPH-#27E71, IRGKangXi=1214.171, RSKangXi=155.9
27E72 CJK UNIFIED IDEOGRAPH-#27E72, IRGKangXi=1214.190, RSKangXi=155.10
27E73 CJK UNIFIED IDEOGRAPH-#27E73, IRGKangXi=1214.200, RSKangXi=155.10
27E74 CJK UNIFIED IDEOGRAPH-#27E74, IRGKangXi=1214.210, RSKangXi=155.10
27E75 CJK UNIFIED IDEOGRAPH-#27E75, IRGKangXi=1214.211, RSKangXi=155.10
27E76 CJK UNIFIED IDEOGRAPH-#27E76, IRGKangXi=1214.220, RSKangXi=155.11
27E77 CJK UNIFIED IDEOGRAPH-#27E77, IRGKangXi=1214.221, RSKangXi=155.11
27E78 CJK UNIFIED IDEOGRAPH-#27E78, IRGKangXi=1214.230, RSKangXi=155.12
27E79 CJK UNIFIED IDEOGRAPH-#27E79, IRGKangXi=1214.240, RSKangXi=155.12
27E7A CJK UNIFIED IDEOGRAPH-#27E7A, IRGKangXi=1214.241, RSKangXi=155.12
27E7B CJK UNIFIED IDEOGRAPH-#27E7B, IRGKangXi=1214.241, RSKangXi=155.12
27E7C CJK UNIFIED IDEOGRAPH-#27E7C, IRGKangXi=1214.241, RSKangXi=155.12
27E7D CJK UNIFIED IDEOGRAPH-#27E7D, IRGKangXi=1214.260, RSKangXi=155.14
27E7E CJK UNIFIED IDEOGRAPH-#27E7E, IRGKangXi=1214.261, RSKangXi=155.14
27E7F CJK UNIFIED IDEOGRAPH-#27E7F, IRGKangXi=1214.261, RSKangXi=155.14
27E80 CJK UNIFIED IDEOGRAPH-#27E80, IRGKangXi=1214.261, RSKangXi=155.15
27E81 CJK UNIFIED IDEOGRAPH-#27E81, IRGKangXi=1214.261, RSKangXi=155.15
27E82 CJK UNIFIED IDEOGRAPH-#27E82, IRGKangXi=1214.261, RSKangXi=155.16
27E83 CJK UNIFIED IDEOGRAPH-#27E83, IRGKangXi=1214.261, RSKangXi=155.16
27E84 CJK UNIFIED IDEOGRAPH-#27E84, IRGKangXi=1214.261, RSKangXi=155.16
27E85 CJK UNIFIED IDEOGRAPH-#27E85, IRGKangXi=1214.261, RSKangXi=155.16
27E86 CJK UNIFIED IDEOGRAPH-#27E86, IRGKangXi=1215.030, RSKangXi=156.0
27E87 CJK UNIFIED IDEOGRAPH-#27E87, IRGKangXi=1215.040, RSKangXi=156.1
27E88 CJK UNIFIED IDEOGRAPH-#27E88, IRGKangXi=1215.070, RSKangXi=156.2
27E89 CJK UNIFIED IDEOGRAPH-#27E89, IRGKangXi=1215.081, RSKangXi=156.2
27E8A CJK UNIFIED IDEOGRAPH-#27E8A, IRGKangXi=1215.081, RSKangXi=156.2
27E8B CJK UNIFIED IDEOGRAPH-#27E8B, IRGKangXi=1215.081, RSKangXi=156.2
27E8C CJK UNIFIED IDEOGRAPH-#27E8C, IRGKangXi=1215.081, RSKangXi=156.2
27E8D CJK UNIFIED IDEOGRAPH-#27E8D, IRGKangXi=1215.081, RSKangXi=156.2
27E8E CJK UNIFIED IDEOGRAPH-#27E8E, IRGKangXi=1215.081, RSKangXi=156.2
27E8F CJK UNIFIED IDEOGRAPH-#27E8F, IRGKangXi=1215.090, RSKangXi=156.3
27E90 CJK UNIFIED IDEOGRAPH-#27E90, IRGKangXi=1215.110, RSKangXi=156.3
27E91 CJK UNIFIED IDEOGRAPH-#27E91, IRGKangXi=1215.190, RSKangXi=156.3
27E92 CJK UNIFIED IDEOGRAPH-#27E92, IRGKangXi=1215.200, RSKangXi=156.3
27E93 CJK UNIFIED IDEOGRAPH-#27E93, IRGKangXi=1215.210, RSKangXi=156.3
27E94 CJK UNIFIED IDEOGRAPH-#27E94, IRGKangXi=1215.221, RSKangXi=156.3
27E95 CJK UNIFIED IDEOGRAPH-#27E95, IRGKangXi=1215.221, RSKangXi=156.3
27E96 CJK UNIFIED IDEOGRAPH-#27E96, IRGKangXi=1215.221, RSKangXi=156.3
27E97 CJK UNIFIED IDEOGRAPH-#27E97, IRGKangXi=1215.221, RSKangXi=156.3
27E98 CJK UNIFIED IDEOGRAPH-#27E98, IRGKangXi=1215.221, RSKangXi=156.3
27E99 CJK UNIFIED IDEOGRAPH-#27E99, IRGKangXi=1215.221, RSKangXi=156.3
27E9A CJK UNIFIED IDEOGRAPH-#27E9A, IRGKangXi=1215.221, RSKangXi=156.3
27E9B CJK UNIFIED IDEOGRAPH-#27E9B, IRGKangXi=1215.221, RSKangXi=156.3
27E9C CJK UNIFIED IDEOGRAPH-#27E9C, IRGKangXi=1215.221, RSKangXi=156.3
27E9D CJK UNIFIED IDEOGRAPH-#27E9D, IRGKangXi=1215.240, RSKangXi=156.4
27E9E CJK UNIFIED IDEOGRAPH-#27E9E, IRGKangXi=1215.250, RSKangXi=156.4
27E9F CJK UNIFIED IDEOGRAPH-#27E9F, IRGKangXi=1215.280, RSKangXi=156.4
27EA0 CJK UNIFIED IDEOGRAPH-#27EA0, IRGKangXi=1215.300, RSKangXi=156.4
27EA1 CJK UNIFIED IDEOGRAPH-#27EA1, IRGKangXi=1215.310, RSKangXi=156.4
27EA2 CJK UNIFIED IDEOGRAPH-#27EA2, IRGKangXi=1215.330, RSKangXi=156.4
27EA3 CJK UNIFIED IDEOGRAPH-#27EA3, IRGKangXi=1215.340, RSKangXi=156.4
27EA4 CJK UNIFIED IDEOGRAPH-#27EA4, IRGKangXi=1215.350, RSKangXi=156.4
27EA5 CJK UNIFIED IDEOGRAPH-#27EA5, IRGKangXi=1215.370, RSKangXi=156.4
27EA6 CJK UNIFIED IDEOGRAPH-#27EA6, IRGKangXi=1215.420, RSKangXi=156.4
27EA7 CJK UNIFIED IDEOGRAPH-#27EA7, IRGKangXi=1215.430, RSKangXi=156.4
27EA8 CJK UNIFIED IDEOGRAPH-#27EA8, IRGKangXi=1215.440, RSKangXi=156.4
27EA9 CJK UNIFIED IDEOGRAPH-#27EA9, IRGKangXi=1215.441, RSKangXi=156.4
27EAA CJK UNIFIED IDEOGRAPH-#27EAA, IRGKangXi=1215.441, RSKangXi=156.4
27EAB CJK UNIFIED IDEOGRAPH-#27EAB, IRGKangXi=1215.441, RSKangXi=156.4
27EAC CJK UNIFIED IDEOGRAPH-#27EAC, IRGKangXi=1215.441, RSKangXi=156.4
27EAD CJK UNIFIED IDEOGRAPH-#27EAD, IRGKangXi=1215.441, RSKangXi=156.4
27EAE CJK UNIFIED IDEOGRAPH-#27EAE, IRGKangXi=1215.441, RSKangXi=156.4
27EAF CJK UNIFIED IDEOGRAPH-#27EAF, IRGKangXi=1215.441, RSKangXi=156.4
27EB0 CJK UNIFIED IDEOGRAPH-#27EB0, IRGKangXi=1215.441, RSKangXi=156.4
27EB1 CJK UNIFIED IDEOGRAPH-#27EB1, IRGKangXi=1215.441, RSKangXi=156.4
27EB2 CJK UNIFIED IDEOGRAPH-#27EB2, IRGKangXi=1215.441, RSKangXi=156.4
27EB3 CJK UNIFIED IDEOGRAPH-#27EB3, IRGKangXi=1215.441, RSKangXi=156.4
27EB4 CJK UNIFIED IDEOGRAPH-#27EB4, IRGKangXi=1215.441, RSKangXi=156.4
27EB5 CJK UNIFIED IDEOGRAPH-#27EB5, IRGKangXi=1215.441, RSKangXi=156.4
27EB6 CJK UNIFIED IDEOGRAPH-#27EB6, IRGKangXi=1215.460, RSKangXi=156.5
27EB7 CJK UNIFIED IDEOGRAPH-#27EB7, IRGKangXi=1215.470, RSKangXi=156.5
27EB8 CJK UNIFIED IDEOGRAPH-#27EB8, IRGKangXi=1216.060, RSKangXi=156.5
27EB9 CJK UNIFIED IDEOGRAPH-#27EB9, IRGKangXi=1216.080, RSKangXi=156.5
27EBA CJK UNIFIED IDEOGRAPH-#27EBA, IRGKangXi=1216.090, RSKangXi=156.5
27EBB CJK UNIFIED IDEOGRAPH-#27EBB, IRGKangXi=1216.100, RSKangXi=156.5
27EBC CJK UNIFIED IDEOGRAPH-#27EBC, IRGKangXi=1216.150, RSKangXi=156.5
27EBD CJK UNIFIED IDEOGRAPH-#27EBD, IRGKangXi=1216.170, RSKangXi=156.5
27EBE CJK UNIFIED IDEOGRAPH-#27EBE, IRGKangXi=1216.180, RSKangXi=156.5
27EBF CJK UNIFIED IDEOGRAPH-#27EBF, IRGKangXi=1216.210, RSKangXi=156.5
27EC0 CJK UNIFIED IDEOGRAPH-#27EC0, IRGKangXi=1216.230, RSKangXi=156.5
27EC1 CJK UNIFIED IDEOGRAPH-#27EC1, IRGKangXi=1216.270, RSKangXi=156.5
27EC2 CJK UNIFIED IDEOGRAPH-#27EC2, IRGKangXi=1216.310, RSKangXi=156.5
27EC3 CJK UNIFIED IDEOGRAPH-#27EC3, IRGKangXi=1216.320, RSKangXi=156.5
27EC4 CJK UNIFIED IDEOGRAPH-#27EC4, IRGKangXi=1216.321, RSKangXi=156.5
27EC5 CJK UNIFIED IDEOGRAPH-#27EC5, IRGKangXi=1216.321, RSKangXi=156.5
27EC6 CJK UNIFIED IDEOGRAPH-#27EC6, IRGKangXi=1216.321, RSKangXi=156.5
27EC7 CJK UNIFIED IDEOGRAPH-#27EC7, IRGKangXi=1216.321, RSKangXi=156.5
27EC8 CJK UNIFIED IDEOGRAPH-#27EC8, IRGKangXi=1216.321, RSKangXi=156.5
27EC9 CJK UNIFIED IDEOGRAPH-#27EC9, IRGKangXi=1216.321, RSKangXi=156.5
27ECA CJK UNIFIED IDEOGRAPH-#27ECA, IRGKangXi=1216.321, RSKangXi=156.5
27ECB CJK UNIFIED IDEOGRAPH-#27ECB, IRGKangXi=1216.321, RSKangXi=156.5
27ECC CJK UNIFIED IDEOGRAPH-#27ECC, IRGKangXi=1216.321, RSKangXi=156.5
27ECD CJK UNIFIED IDEOGRAPH-#27ECD, IRGKangXi=1216.321, RSKangXi=156.5
27ECE CJK UNIFIED IDEOGRAPH-#27ECE, IRGKangXi=1216.321, RSKangXi=156.5
27ECF CJK UNIFIED IDEOGRAPH-#27ECF, IRGKangXi=1216.321, RSKangXi=156.5
27ED0 CJK UNIFIED IDEOGRAPH-#27ED0, IRGKangXi=1216.321, RSKangXi=156.6
27ED1 CJK UNIFIED IDEOGRAPH-#27ED1, IRGKangXi=1217.030, RSKangXi=156.6
27ED2 CJK UNIFIED IDEOGRAPH-#27ED2, IRGKangXi=1217.040, RSKangXi=156.6
27ED3 CJK UNIFIED IDEOGRAPH-#27ED3, IRGKangXi=1217.050, RSKangXi=156.6
27ED4 CJK UNIFIED IDEOGRAPH-#27ED4, IRGKangXi=1217.100, RSKangXi=156.6
27ED5 CJK UNIFIED IDEOGRAPH-#27ED5, IRGKangXi=1217.110, RSKangXi=156.6
27ED6 CJK UNIFIED IDEOGRAPH-#27ED6, IRGKangXi=1217.120, RSKangXi=156.6
27ED7 CJK UNIFIED IDEOGRAPH-#27ED7, IRGKangXi=1217.140, RSKangXi=156.6
27ED8 CJK UNIFIED IDEOGRAPH-#27ED8, IRGKangXi=1217.160, RSKangXi=156.6
27ED9 CJK UNIFIED IDEOGRAPH-#27ED9, IRGKangXi=1217.180, RSKangXi=156.6, Def{(Cant.) 轉灣𧻙角, not straightforward}
27EDA CJK UNIFIED IDEOGRAPH-#27EDA, IRGKangXi=1217.200, RSKangXi=156.6
27EDB CJK UNIFIED IDEOGRAPH-#27EDB, IRGKangXi=1217.210, RSKangXi=156.6
27EDC CJK UNIFIED IDEOGRAPH-#27EDC, IRGKangXi=1217.220, RSKangXi=156.6
27EDD CJK UNIFIED IDEOGRAPH-#27EDD, IRGKangXi=1217.260, RSKangXi=156.6
27EDE CJK UNIFIED IDEOGRAPH-#27EDE, IRGKangXi=1217.261, RSKangXi=156.6
27EDF CJK UNIFIED IDEOGRAPH-#27EDF, IRGKangXi=1217.261, RSKangXi=156.6
27EE0 CJK UNIFIED IDEOGRAPH-#27EE0, IRGKangXi=1217.261, RSKangXi=156.6
27EE1 CJK UNIFIED IDEOGRAPH-#27EE1, IRGKangXi=1217.261, RSKangXi=156.6
27EE2 CJK UNIFIED IDEOGRAPH-#27EE2, IRGKangXi=1217.261, RSKangXi=156.6
27EE3 CJK UNIFIED IDEOGRAPH-#27EE3, IRGKangXi=1217.261, RSKangXi=156.6
27EE4 CJK UNIFIED IDEOGRAPH-#27EE4, IRGKangXi=1217.261, RSKangXi=156.6
27EE5 CJK UNIFIED IDEOGRAPH-#27EE5, IRGKangXi=1217.261, RSKangXi=156.6
27EE6 CJK UNIFIED IDEOGRAPH-#27EE6, IRGKangXi=1217.261, RSKangXi=156.6
27EE7 CJK UNIFIED IDEOGRAPH-#27EE7, IRGKangXi=1217.261, RSKangXi=156.6
27EE8 CJK UNIFIED IDEOGRAPH-#27EE8, IRGKangXi=1217.261, RSKangXi=156.6
27EE9 CJK UNIFIED IDEOGRAPH-#27EE9, IRGKangXi=1217.261, RSKangXi=156.6
27EEA CJK UNIFIED IDEOGRAPH-#27EEA, IRGKangXi=1217.261, RSKangXi=156.6
27EEB CJK UNIFIED IDEOGRAPH-#27EEB, IRGKangXi=1217.261, RSKangXi=156.6
27EEC CJK UNIFIED IDEOGRAPH-#27EEC, IRGKangXi=1217.261, RSKangXi=156.6
27EED CJK UNIFIED IDEOGRAPH-#27EED, IRGKangXi=1217.261, RSKangXi=156.6
27EEE CJK UNIFIED IDEOGRAPH-#27EEE, IRGKangXi=1217.261, RSKangXi=156.6
27EEF CJK UNIFIED IDEOGRAPH-#27EEF, IRGKangXi=1217.270, RSKangXi=156.7
27EF0 CJK UNIFIED IDEOGRAPH-#27EF0, IRGKangXi=1217.310, RSKangXi=156.7
27EF1 CJK UNIFIED IDEOGRAPH-#27EF1, IRGKangXi=1217.340, RSKangXi=156.7
27EF2 CJK UNIFIED IDEOGRAPH-#27EF2, IRGKangXi=1217.350, RSKangXi=156.7
27EF3 CJK UNIFIED IDEOGRAPH-#27EF3, IRGKangXi=1217.360, RSKangXi=156.7
27EF4 CJK UNIFIED IDEOGRAPH-#27EF4, IRGKangXi=1217.410, RSKangXi=156.7
27EF5 CJK UNIFIED IDEOGRAPH-#27EF5, IRGKangXi=1217.420, RSKangXi=156.7
27EF6 CJK UNIFIED IDEOGRAPH-#27EF6, IRGKangXi=1217.430, RSKangXi=156.7
27EF7 CJK UNIFIED IDEOGRAPH-#27EF7, IRGKangXi=1217.460, RSKangXi=156.7
27EF8 CJK UNIFIED IDEOGRAPH-#27EF8, IRGKangXi=1217.470, RSKangXi=156.7
27EF9 CJK UNIFIED IDEOGRAPH-#27EF9, IRGKangXi=1217.490, RSKangXi=156.7
27EFA CJK UNIFIED IDEOGRAPH-#27EFA, IRGKangXi=1218.010, RSKangXi=156.7
27EFB CJK UNIFIED IDEOGRAPH-#27EFB, IRGKangXi=1218.030, RSKangXi=156.7
27EFC CJK UNIFIED IDEOGRAPH-#27EFC, IRGKangXi=1218.040, RSKangXi=156.7
27EFD CJK UNIFIED IDEOGRAPH-#27EFD, IRGKangXi=1218.050, RSKangXi=156.7
27EFE CJK UNIFIED IDEOGRAPH-#27EFE, IRGKangXi=1218.060, RSKangXi=156.7
27EFF CJK UNIFIED IDEOGRAPH-#27EFF, IRGKangXi=1218.070, RSKangXi=156.7
27F00 CJK UNIFIED IDEOGRAPH-#27F00, IRGKangXi=1218.071, RSKangXi=156.7
27F01 CJK UNIFIED IDEOGRAPH-#27F01, IRGKangXi=1218.071, RSKangXi=156.7
27F02 CJK UNIFIED IDEOGRAPH-#27F02, IRGKangXi=1218.071, RSKangXi=156.7
27F03 CJK UNIFIED IDEOGRAPH-#27F03, IRGKangXi=1218.071, RSKangXi=156.7
27F04 CJK UNIFIED IDEOGRAPH-#27F04, IRGKangXi=1218.071, RSKangXi=156.7
27F05 CJK UNIFIED IDEOGRAPH-#27F05, IRGKangXi=1218.071, RSKangXi=156.7
27F06 CJK UNIFIED IDEOGRAPH-#27F06, IRGKangXi=1218.071, RSKangXi=156.7
27F07 CJK UNIFIED IDEOGRAPH-#27F07, IRGKangXi=1218.071, RSKangXi=156.7
27F08 CJK UNIFIED IDEOGRAPH-#27F08, IRGKangXi=1218.071, RSKangXi=156.7
27F09 CJK UNIFIED IDEOGRAPH-#27F09, IRGKangXi=1218.071, RSKangXi=156.7
27F0A CJK UNIFIED IDEOGRAPH-#27F0A, IRGKangXi=1218.071, RSKangXi=156.7
27F0B CJK UNIFIED IDEOGRAPH-#27F0B, IRGKangXi=1218.071, RSKangXi=156.7
27F0C CJK UNIFIED IDEOGRAPH-#27F0C, IRGKangXi=1218.071, RSKangXi=156.7
27F0D CJK UNIFIED IDEOGRAPH-#27F0D, IRGKangXi=1218.071, RSKangXi=156.7
27F0E CJK UNIFIED IDEOGRAPH-#27F0E, IRGKangXi=1218.120, RSKangXi=156.8
27F0F CJK UNIFIED IDEOGRAPH-#27F0F, IRGKangXi=1218.130, RSKangXi=156.8
27F10 CJK UNIFIED IDEOGRAPH-#27F10, IRGKangXi=1218.140, RSKangXi=156.8
27F11 CJK UNIFIED IDEOGRAPH-#27F11, IRGKangXi=1218.190, RSKangXi=156.8
27F12 CJK UNIFIED IDEOGRAPH-#27F12, IRGKangXi=1218.210, RSKangXi=156.8
27F13 CJK UNIFIED IDEOGRAPH-#27F13, IRGKangXi=1218.230, RSKangXi=156.8
27F14 CJK UNIFIED IDEOGRAPH-#27F14, IRGKangXi=1218.240, RSKangXi=156.8
27F15 CJK UNIFIED IDEOGRAPH-#27F15, IRGKangXi=1218.260, RSKangXi=156.8
27F16 CJK UNIFIED IDEOGRAPH-#27F16, IRGKangXi=1218.270, RSKangXi=156.8
27F17 CJK UNIFIED IDEOGRAPH-#27F17, IRGKangXi=1218.280, RSKangXi=156.8
27F18 CJK UNIFIED IDEOGRAPH-#27F18, IRGKangXi=1218.300, RSKangXi=156.8
27F19 CJK UNIFIED IDEOGRAPH-#27F19, IRGKangXi=1218.310, RSKangXi=156.8
27F1A CJK UNIFIED IDEOGRAPH-#27F1A, IRGKangXi=1218.320, RSKangXi=156.8
27F1B CJK UNIFIED IDEOGRAPH-#27F1B, IRGKangXi=1218.330, RSKangXi=156.8
27F1C CJK UNIFIED IDEOGRAPH-#27F1C, IRGKangXi=1218.360, RSKangXi=156.8
27F1D CJK UNIFIED IDEOGRAPH-#27F1D, IRGKangXi=1218.370, RSKangXi=156.7
27F1E CJK UNIFIED IDEOGRAPH-#27F1E, IRGKangXi=1218.380, RSKangXi=156.8
27F1F CJK UNIFIED IDEOGRAPH-#27F1F, IRGKangXi=1218.400, RSKangXi=156.9
27F20 CJK UNIFIED IDEOGRAPH-#27F20, IRGKangXi=1218.410, RSKangXi=156.8
27F21 CJK UNIFIED IDEOGRAPH-#27F21, IRGKangXi=1218.420, RSKangXi=156.8
27F22 CJK UNIFIED IDEOGRAPH-#27F22, IRGKangXi=1218.421, RSKangXi=156.8
27F23 CJK UNIFIED IDEOGRAPH-#27F23, IRGKangXi=1218.421, RSKangXi=156.8
27F24 CJK UNIFIED IDEOGRAPH-#27F24, IRGKangXi=1218.421, RSKangXi=156.8
27F25 CJK UNIFIED IDEOGRAPH-#27F25, IRGKangXi=1218.421, RSKangXi=156.8
27F26 CJK UNIFIED IDEOGRAPH-#27F26, IRGKangXi=1218.421, RSKangXi=156.8
27F27 CJK UNIFIED IDEOGRAPH-#27F27, IRGKangXi=1218.421, RSKangXi=156.8
27F28 CJK UNIFIED IDEOGRAPH-#27F28, IRGKangXi=1218.450, RSKangXi=156.9
27F29 CJK UNIFIED IDEOGRAPH-#27F29, IRGKangXi=1218.460, RSKangXi=156.9
27F2A CJK UNIFIED IDEOGRAPH-#27F2A, IRGKangXi=1218.470, RSKangXi=156.9
27F2B CJK UNIFIED IDEOGRAPH-#27F2B, IRGKangXi=1219.010, RSKangXi=156.9
27F2C CJK UNIFIED IDEOGRAPH-#27F2C, IRGKangXi=1219.020, RSKangXi=156.9
27F2D CJK UNIFIED IDEOGRAPH-#27F2D, IRGKangXi=1219.030, RSKangXi=156.9
27F2E CJK UNIFIED IDEOGRAPH-#27F2E, IRGKangXi=1219.060, RSKangXi=156.9, Def{to wade}
27F2F CJK UNIFIED IDEOGRAPH-#27F2F, IRGKangXi=1219.070, RSKangXi=156.9
27F30 CJK UNIFIED IDEOGRAPH-#27F30, IRGKangXi=1219.100, RSKangXi=156.9
27F31 CJK UNIFIED IDEOGRAPH-#27F31, IRGKangXi=1219.110, RSKangXi=156.9
27F32 CJK UNIFIED IDEOGRAPH-#27F32, IRGKangXi=1219.120, RSKangXi=156.9
27F33 CJK UNIFIED IDEOGRAPH-#27F33, IRGKangXi=1219.140, RSKangXi=156.9
27F34 CJK UNIFIED IDEOGRAPH-#27F34, IRGKangXi=1219.160, RSKangXi=156.9
27F35 CJK UNIFIED IDEOGRAPH-#27F35, IRGKangXi=1219.170, RSKangXi=156.9
27F36 CJK UNIFIED IDEOGRAPH-#27F36, IRGKangXi=1219.171, RSKangXi=156.9
27F37 CJK UNIFIED IDEOGRAPH-#27F37, IRGKangXi=1219.171, RSKangXi=156.9
27F38 CJK UNIFIED IDEOGRAPH-#27F38, IRGKangXi=1219.171, RSKangXi=156.9
27F39 CJK UNIFIED IDEOGRAPH-#27F39, IRGKangXi=1219.171, RSKangXi=156.9
27F3A CJK UNIFIED IDEOGRAPH-#27F3A, IRGKangXi=1219.171, RSKangXi=156.9
27F3B CJK UNIFIED IDEOGRAPH-#27F3B, IRGKangXi=1219.171, RSKangXi=156.9
27F3C CJK UNIFIED IDEOGRAPH-#27F3C, IRGKangXi=1219.171, RSKangXi=156.9
27F3D CJK UNIFIED IDEOGRAPH-#27F3D, IRGKangXi=1219.171, RSKangXi=156.9
27F3E CJK UNIFIED IDEOGRAPH-#27F3E, IRGKangXi=1219.171, RSKangXi=156.9
27F3F CJK UNIFIED IDEOGRAPH-#27F3F, IRGKangXi=1219.171, RSKangXi=156.9
27F40 CJK UNIFIED IDEOGRAPH-#27F40, IRGKangXi=1219.171, RSKangXi=156.9
27F41 CJK UNIFIED IDEOGRAPH-#27F41, IRGKangXi=1219.171, RSKangXi=156.9
27F42 CJK UNIFIED IDEOGRAPH-#27F42, IRGKangXi=1219.171, RSKangXi=156.9
27F43 CJK UNIFIED IDEOGRAPH-#27F43, IRGKangXi=1219.171, RSKangXi=156.9
27F44 CJK UNIFIED IDEOGRAPH-#27F44, IRGKangXi=1219.171, RSKangXi=156.9
27F45 CJK UNIFIED IDEOGRAPH-#27F45, IRGKangXi=1219.171, RSKangXi=156.9
27F46 CJK UNIFIED IDEOGRAPH-#27F46, IRGKangXi=1219.171, RSKangXi=156.9
27F47 CJK UNIFIED IDEOGRAPH-#27F47, IRGKangXi=1219.171, RSKangXi=156.9
27F48 CJK UNIFIED IDEOGRAPH-#27F48, IRGKangXi=1219.171, RSKangXi=156.9
27F49 CJK UNIFIED IDEOGRAPH-#27F49, IRGKangXi=1219.180, RSKangXi=156.10
27F4A CJK UNIFIED IDEOGRAPH-#27F4A, IRGKangXi=1219.210, RSKangXi=156.10
27F4B CJK UNIFIED IDEOGRAPH-#27F4B, IRGKangXi=1219.220, RSKangXi=156.10
27F4C CJK UNIFIED IDEOGRAPH-#27F4C, IRGKangXi=1219.230, RSKangXi=156.10
27F4D CJK UNIFIED IDEOGRAPH-#27F4D, IRGKangXi=1219.240, RSKangXi=156.10, Def{to jolt in trotting}
27F4E CJK UNIFIED IDEOGRAPH-#27F4E, IRGKangXi=1219.250, RSKangXi=156.10
27F4F CJK UNIFIED IDEOGRAPH-#27F4F, IRGKangXi=1219.260, RSKangXi=156.10
27F50 CJK UNIFIED IDEOGRAPH-#27F50, IRGKangXi=1219.280, RSKangXi=156.10
27F51 CJK UNIFIED IDEOGRAPH-#27F51, IRGKangXi=1219.290, RSKangXi=156.10
27F52 CJK UNIFIED IDEOGRAPH-#27F52, IRGKangXi=1219.310, RSKangXi=156.10
27F53 CJK UNIFIED IDEOGRAPH-#27F53, IRGKangXi=1219.330, RSKangXi=156.10
27F54 CJK UNIFIED IDEOGRAPH-#27F54, IRGKangXi=1219.340, RSKangXi=156.10
27F55 CJK UNIFIED IDEOGRAPH-#27F55, IRGKangXi=1219.350, RSKangXi=156.10
27F56 CJK UNIFIED IDEOGRAPH-#27F56, IRGKangXi=1219.360, RSKangXi=156.10
27F57 CJK UNIFIED IDEOGRAPH-#27F57, IRGKangXi=1219.361, RSKangXi=156.10
27F58 CJK UNIFIED IDEOGRAPH-#27F58, IRGKangXi=1219.361, RSKangXi=156.10
27F59 CJK UNIFIED IDEOGRAPH-#27F59, IRGKangXi=1219.361, RSKangXi=156.10
27F5A CJK UNIFIED IDEOGRAPH-#27F5A, IRGKangXi=1219.361, RSKangXi=156.10
27F5B CJK UNIFIED IDEOGRAPH-#27F5B, IRGKangXi=1219.361, RSKangXi=156.10
27F5C CJK UNIFIED IDEOGRAPH-#27F5C, IRGKangXi=1219.361, RSKangXi=156.10
27F5D CJK UNIFIED IDEOGRAPH-#27F5D, IRGKangXi=1219.361, RSKangXi=156.10
27F5E CJK UNIFIED IDEOGRAPH-#27F5E, IRGKangXi=1219.370, RSKangXi=156.11
27F5F CJK UNIFIED IDEOGRAPH-#27F5F, IRGKangXi=1219.380, RSKangXi=156.11
27F60 CJK UNIFIED IDEOGRAPH-#27F60, IRGKangXi=1219.390, RSKangXi=156.11
27F61 CJK UNIFIED IDEOGRAPH-#27F61, IRGKangXi=1219.400, RSKangXi=156.11
27F62 CJK UNIFIED IDEOGRAPH-#27F62, IRGKangXi=1219.420, RSKangXi=156.11
27F63 CJK UNIFIED IDEOGRAPH-#27F63, IRGKangXi=1219.430, RSKangXi=156.11
27F64 CJK UNIFIED IDEOGRAPH-#27F64, IRGKangXi=1219.440, RSKangXi=156.11
27F65 CJK UNIFIED IDEOGRAPH-#27F65, IRGKangXi=1219.470, RSKangXi=156.11
27F66 CJK UNIFIED IDEOGRAPH-#27F66, IRGKangXi=1219.480, RSKangXi=156.11
27F67 CJK UNIFIED IDEOGRAPH-#27F67, IRGKangXi=1219.490, RSKangXi=156.11
27F68 CJK UNIFIED IDEOGRAPH-#27F68, IRGKangXi=1219.510, RSKangXi=156.11
27F69 CJK UNIFIED IDEOGRAPH-#27F69, IRGKangXi=1219.520, RSKangXi=156.11
27F6A CJK UNIFIED IDEOGRAPH-#27F6A, IRGKangXi=1220.020, RSKangXi=156.11
27F6B CJK UNIFIED IDEOGRAPH-#27F6B, IRGKangXi=1220.030, RSKangXi=156.11
27F6C CJK UNIFIED IDEOGRAPH-#27F6C, IRGKangXi=1220.031, RSKangXi=156.11
27F6D CJK UNIFIED IDEOGRAPH-#27F6D, IRGKangXi=1220.031, RSKangXi=156.11
27F6E CJK UNIFIED IDEOGRAPH-#27F6E, IRGKangXi=1220.031, RSKangXi=156.11
27F6F CJK UNIFIED IDEOGRAPH-#27F6F, IRGKangXi=1220.031, RSKangXi=156.11
27F70 CJK UNIFIED IDEOGRAPH-#27F70, IRGKangXi=1220.031, RSKangXi=156.11
27F71 CJK UNIFIED IDEOGRAPH-#27F71, IRGKangXi=1220.031, RSKangXi=156.11
27F72 CJK UNIFIED IDEOGRAPH-#27F72, IRGKangXi=1220.031, RSKangXi=156.11
27F73 CJK UNIFIED IDEOGRAPH-#27F73, IRGKangXi=1220.031, RSKangXi=156.11
27F74 CJK UNIFIED IDEOGRAPH-#27F74, IRGKangXi=1220.031, RSKangXi=156.11
27F75 CJK UNIFIED IDEOGRAPH-#27F75, IRGKangXi=1220.031, RSKangXi=156.11
27F76 CJK UNIFIED IDEOGRAPH-#27F76, IRGKangXi=1220.040, RSKangXi=156.12
27F77 CJK UNIFIED IDEOGRAPH-#27F77, IRGKangXi=1220.060, RSKangXi=156.12
27F78 CJK UNIFIED IDEOGRAPH-#27F78, IRGKangXi=1220.070, RSKangXi=156.12, Def{to step, jump}
27F79 CJK UNIFIED IDEOGRAPH-#27F79, IRGKangXi=1220.080, RSKangXi=156.12
27F7A CJK UNIFIED IDEOGRAPH-#27F7A, IRGKangXi=1220.090, RSKangXi=156.12
27F7B CJK UNIFIED IDEOGRAPH-#27F7B, IRGKangXi=1220.110, RSKangXi=156.12
27F7C CJK UNIFIED IDEOGRAPH-#27F7C, IRGKangXi=1220.120, RSKangXi=156.12
27F7D CJK UNIFIED IDEOGRAPH-#27F7D, IRGKangXi=1220.140, RSKangXi=156.12
27F7E CJK UNIFIED IDEOGRAPH-#27F7E, IRGKangXi=1220.160, RSKangXi=156.12
27F7F CJK UNIFIED IDEOGRAPH-#27F7F, IRGKangXi=1220.170, RSKangXi=156.12
27F80 CJK UNIFIED IDEOGRAPH-#27F80, IRGKangXi=1220.180, RSKangXi=156.12
27F81 CJK UNIFIED IDEOGRAPH-#27F81, IRGKangXi=1220.210, RSKangXi=156.12
27F82 CJK UNIFIED IDEOGRAPH-#27F82, IRGKangXi=1220.220, RSKangXi=156.12
27F83 CJK UNIFIED IDEOGRAPH-#27F83, IRGKangXi=1220.221, RSKangXi=156.12
27F84 CJK UNIFIED IDEOGRAPH-#27F84, IRGKangXi=1220.221, RSKangXi=156.12
27F85 CJK UNIFIED IDEOGRAPH-#27F85, IRGKangXi=1220.221, RSKangXi=156.12
27F86 CJK UNIFIED IDEOGRAPH-#27F86, IRGKangXi=1220.221, RSKangXi=156.12
27F87 CJK UNIFIED IDEOGRAPH-#27F87, IRGKangXi=1220.221, RSKangXi=156.12
27F88 CJK UNIFIED IDEOGRAPH-#27F88, IRGKangXi=1220.221, RSKangXi=156.12
27F89 CJK UNIFIED IDEOGRAPH-#27F89, IRGKangXi=1220.221, RSKangXi=156.12
27F8A CJK UNIFIED IDEOGRAPH-#27F8A, IRGKangXi=1220.221, RSKangXi=156.12
27F8B CJK UNIFIED IDEOGRAPH-#27F8B, IRGKangXi=1220.221, RSKangXi=156.12
27F8C CJK UNIFIED IDEOGRAPH-#27F8C, IRGKangXi=1220.221, RSKangXi=156.12
27F8D CJK UNIFIED IDEOGRAPH-#27F8D, IRGKangXi=1220.230, RSKangXi=156.13
27F8E CJK UNIFIED IDEOGRAPH-#27F8E, IRGKangXi=1220.240, RSKangXi=156.13
27F8F CJK UNIFIED IDEOGRAPH-#27F8F, IRGKangXi=1220.260, RSKangXi=156.13
27F90 CJK UNIFIED IDEOGRAPH-#27F90, IRGKangXi=1220.290, RSKangXi=156.13
27F91 CJK UNIFIED IDEOGRAPH-#27F91, IRGKangXi=1220.310, RSKangXi=156.13
27F92 CJK UNIFIED IDEOGRAPH-#27F92, IRGKangXi=1220.320, RSKangXi=156.13
27F93 CJK UNIFIED IDEOGRAPH-#27F93, IRGKangXi=1220.330, RSKangXi=156.13
27F94 CJK UNIFIED IDEOGRAPH-#27F94, IRGKangXi=1220.340, RSKangXi=156.13
27F95 CJK UNIFIED IDEOGRAPH-#27F95, IRGKangXi=1220.360, RSKangXi=156.13
27F96 CJK UNIFIED IDEOGRAPH-#27F96, IRGKangXi=1220.361, RSKangXi=156.13
27F97 CJK UNIFIED IDEOGRAPH-#27F97, IRGKangXi=1220.361, RSKangXi=156.13
27F98 CJK UNIFIED IDEOGRAPH-#27F98, IRGKangXi=1220.361, RSKangXi=156.13
27F99 CJK UNIFIED IDEOGRAPH-#27F99, IRGKangXi=1220.370, RSKangXi=156.14
27F9A CJK UNIFIED IDEOGRAPH-#27F9A, IRGKangXi=1220.380, RSKangXi=156.14
27F9B CJK UNIFIED IDEOGRAPH-#27F9B, IRGKangXi=1220.390, RSKangXi=156.14
27F9C CJK UNIFIED IDEOGRAPH-#27F9C, IRGKangXi=1220.400, RSKangXi=156.14
27F9D CJK UNIFIED IDEOGRAPH-#27F9D, IRGKangXi=1220.410, RSKangXi=156.14
27F9E CJK UNIFIED IDEOGRAPH-#27F9E, IRGKangXi=1220.421, RSKangXi=156.14
27F9F CJK UNIFIED IDEOGRAPH-#27F9F, IRGKangXi=1220.421, RSKangXi=156.14
27FA0 CJK UNIFIED IDEOGRAPH-#27FA0, IRGKangXi=1220.421, RSKangXi=156.14
27FA1 CJK UNIFIED IDEOGRAPH-#27FA1, IRGKangXi=1220.430, RSKangXi=156.15
27FA2 CJK UNIFIED IDEOGRAPH-#27FA2, IRGKangXi=1220.460, RSKangXi=156.15
27FA3 CJK UNIFIED IDEOGRAPH-#27FA3, IRGKangXi=1221.020, RSKangXi=156.15
27FA4 CJK UNIFIED IDEOGRAPH-#27FA4, IRGKangXi=1221.030, RSKangXi=156.15
27FA5 CJK UNIFIED IDEOGRAPH-#27FA5, IRGKangXi=1221.040, RSKangXi=156.15
27FA6 CJK UNIFIED IDEOGRAPH-#27FA6, IRGKangXi=1221.041, RSKangXi=156.15
27FA7 CJK UNIFIED IDEOGRAPH-#27FA7, IRGKangXi=1221.041, RSKangXi=156.15
27FA8 CJK UNIFIED IDEOGRAPH-#27FA8, IRGKangXi=1221.050, RSKangXi=156.16
27FA9 CJK UNIFIED IDEOGRAPH-#27FA9, IRGKangXi=1221.070, RSKangXi=156.16
27FAA CJK UNIFIED IDEOGRAPH-#27FAA, IRGKangXi=1221.071, RSKangXi=156.16
27FAB CJK UNIFIED IDEOGRAPH-#27FAB, IRGKangXi=1221.071, RSKangXi=156.16
27FAC CJK UNIFIED IDEOGRAPH-#27FAC, IRGKangXi=1221.071, RSKangXi=156.16
27FAD CJK UNIFIED IDEOGRAPH-#27FAD, IRGKangXi=1221.071, RSKangXi=156.16
27FAE CJK UNIFIED IDEOGRAPH-#27FAE, IRGKangXi=1221.090, RSKangXi=156.17
27FAF CJK UNIFIED IDEOGRAPH-#27FAF, IRGKangXi=1221.100, RSKangXi=156.17
27FB0 CJK UNIFIED IDEOGRAPH-#27FB0, IRGKangXi=1221.120, RSKangXi=156.18
27FB1 CJK UNIFIED IDEOGRAPH-#27FB1, IRGKangXi=1221.130, RSKangXi=156.18
27FB2 CJK UNIFIED IDEOGRAPH-#27FB2, IRGKangXi=1221.131, RSKangXi=156.18
27FB3 CJK UNIFIED IDEOGRAPH-#27FB3, IRGKangXi=1221.131, RSKangXi=156.18
27FB4 CJK UNIFIED IDEOGRAPH-#27FB4, IRGKangXi=1221.131, RSKangXi=156.18
27FB5 CJK UNIFIED IDEOGRAPH-#27FB5, IRGKangXi=1221.150, RSKangXi=156.20
27FB6 CJK UNIFIED IDEOGRAPH-#27FB6, IRGKangXi=1221.160, RSKangXi=156.21
27FB7 CJK UNIFIED IDEOGRAPH-#27FB7, IRGKangXi=1221.171, RSKangXi=157.0
27FB8 CJK UNIFIED IDEOGRAPH-#27FB8, IRGKangXi=1221.200, RSKangXi=157.1
27FB9 CJK UNIFIED IDEOGRAPH-#27FB9, IRGKangXi=1221.210, RSKangXi=157.1
27FBA CJK UNIFIED IDEOGRAPH-#27FBA, IRGKangXi=1221.230, RSKangXi=157.2
27FBB CJK UNIFIED IDEOGRAPH-#27FBB, IRGKangXi=1221.240, RSKangXi=157.2
27FBC CJK UNIFIED IDEOGRAPH-#27FBC, IRGKangXi=1221.251, RSKangXi=157.2
27FBD CJK UNIFIED IDEOGRAPH-#27FBD, IRGKangXi=1221.251, RSKangXi=157.2
27FBE CJK UNIFIED IDEOGRAPH-#27FBE, IRGKangXi=1221.251, RSKangXi=157.2
27FBF CJK UNIFIED IDEOGRAPH-#27FBF, IRGKangXi=1221.251, RSKangXi=157.2
27FC0 CJK UNIFIED IDEOGRAPH-#27FC0, IRGKangXi=1221.251, RSKangXi=157.2
27FC1 CJK UNIFIED IDEOGRAPH-#27FC1, IRGKangXi=1221.270, RSKangXi=157.3
27FC2 CJK UNIFIED IDEOGRAPH-#27FC2, IRGKangXi=1221.280, RSKangXi=157.3
27FC3 CJK UNIFIED IDEOGRAPH-#27FC3, IRGKangXi=1221.300, RSKangXi=157.3
27FC4 CJK UNIFIED IDEOGRAPH-#27FC4, IRGKangXi=1221.310, RSKangXi=157.3
27FC5 CJK UNIFIED IDEOGRAPH-#27FC5, IRGKangXi=1221.330, RSKangXi=157.3
27FC6 CJK UNIFIED IDEOGRAPH-#27FC6, IRGKangXi=1221.340, RSKangXi=157.3
27FC7 CJK UNIFIED IDEOGRAPH-#27FC7, IRGKangXi=1221.351, RSKangXi=157.3
27FC8 CJK UNIFIED IDEOGRAPH-#27FC8, IRGKangXi=1221.351, RSKangXi=157.3
27FC9 CJK UNIFIED IDEOGRAPH-#27FC9, IRGKangXi=1221.351, RSKangXi=157.3
27FCA CJK UNIFIED IDEOGRAPH-#27FCA, IRGKangXi=1221.351, RSKangXi=157.3
27FCB CJK UNIFIED IDEOGRAPH-#27FCB, IRGKangXi=1221.351, RSKangXi=157.3
27FCC CJK UNIFIED IDEOGRAPH-#27FCC, IRGKangXi=1221.351, RSKangXi=157.3
27FCD CJK UNIFIED IDEOGRAPH-#27FCD, IRGKangXi=1221.351, RSKangXi=157.3
27FCE CJK UNIFIED IDEOGRAPH-#27FCE, IRGKangXi=1221.351, RSKangXi=157.3
27FCF CJK UNIFIED IDEOGRAPH-#27FCF, IRGKangXi=1221.351, RSKangXi=157.3
27FD0 CJK UNIFIED IDEOGRAPH-#27FD0, IRGKangXi=1221.351, RSKangXi=157.3
27FD1 CJK UNIFIED IDEOGRAPH-#27FD1, IRGKangXi=1221.351, RSKangXi=157.3
27FD2 CJK UNIFIED IDEOGRAPH-#27FD2, IRGKangXi=1222.030, RSKangXi=157.4, Def{(Cant.) to stamp (one's foot)}
27FD3 CJK UNIFIED IDEOGRAPH-#27FD3, IRGKangXi=1222.040, RSKangXi=157.4
27FD4 CJK UNIFIED IDEOGRAPH-#27FD4, IRGKangXi=1222.050, RSKangXi=157.4
27FD5 CJK UNIFIED IDEOGRAPH-#27FD5, IRGKangXi=1222.100, RSKangXi=157.4
27FD6 CJK UNIFIED IDEOGRAPH-#27FD6, IRGKangXi=1222.140, RSKangXi=157.4
27FD7 CJK UNIFIED IDEOGRAPH-#27FD7, IRGKangXi=1222.170, RSKangXi=157.4
27FD8 CJK UNIFIED IDEOGRAPH-#27FD8, IRGKangXi=1222.190, RSKangXi=157.4
27FD9 CJK UNIFIED IDEOGRAPH-#27FD9, IRGKangXi=1222.200, RSKangXi=157.4
27FDA CJK UNIFIED IDEOGRAPH-#27FDA, IRGKangXi=1222.230, RSKangXi=157.4
27FDB CJK UNIFIED IDEOGRAPH-#27FDB, IRGKangXi=1222.260, RSKangXi=157.4
27FDC CJK UNIFIED IDEOGRAPH-#27FDC, IRGKangXi=1222.270, RSKangXi=157.4
27FDD CJK UNIFIED IDEOGRAPH-#27FDD, IRGKangXi=1222.280, RSKangXi=157.4
27FDE CJK UNIFIED IDEOGRAPH-#27FDE, IRGKangXi=1222.290, RSKangXi=157.4
27FDF CJK UNIFIED IDEOGRAPH-#27FDF, IRGKangXi=1222.300, RSKangXi=157.4
27FE0 CJK UNIFIED IDEOGRAPH-#27FE0, IRGKangXi=1222.310, RSKangXi=157.4
27FE1 CJK UNIFIED IDEOGRAPH-#27FE1, IRGKangXi=1222.311, RSKangXi=157.4
27FE2 CJK UNIFIED IDEOGRAPH-#27FE2, IRGKangXi=1222.311, RSKangXi=157.4
27FE3 CJK UNIFIED IDEOGRAPH-#27FE3, IRGKangXi=1222.311, RSKangXi=157.4
27FE4 CJK UNIFIED IDEOGRAPH-#27FE4, IRGKangXi=1222.311, RSKangXi=157.4
27FE5 CJK UNIFIED IDEOGRAPH-#27FE5, IRGKangXi=1222.311, RSKangXi=157.4
27FE6 CJK UNIFIED IDEOGRAPH-#27FE6, IRGKangXi=1222.311, RSKangXi=157.4
27FE7 CJK UNIFIED IDEOGRAPH-#27FE7, IRGKangXi=1222.311, RSKangXi=157.4
27FE8 CJK UNIFIED IDEOGRAPH-#27FE8, IRGKangXi=1222.311, RSKangXi=157.4
27FE9 CJK UNIFIED IDEOGRAPH-#27FE9, IRGKangXi=1222.311, RSKangXi=157.4
27FEA CJK UNIFIED IDEOGRAPH-#27FEA, IRGKangXi=1222.311, RSKangXi=157.4
27FEB CJK UNIFIED IDEOGRAPH-#27FEB, IRGKangXi=1222.311, RSKangXi=157.4, Def{(Cant.) to have a rest}
27FEC CJK UNIFIED IDEOGRAPH-#27FEC, IRGKangXi=1222.311, RSKangXi=157.4
27FED CJK UNIFIED IDEOGRAPH-#27FED, IRGKangXi=1222.311, RSKangXi=157.4
27FEE CJK UNIFIED IDEOGRAPH-#27FEE, IRGKangXi=1222.311, RSKangXi=157.4
27FEF CJK UNIFIED IDEOGRAPH-#27FEF, IRGKangXi=1222.311, RSKangXi=157.4
27FF0 CJK UNIFIED IDEOGRAPH-#27FF0, IRGKangXi=1222.311, RSKangXi=157.4
27FF1 CJK UNIFIED IDEOGRAPH-#27FF1, IRGKangXi=1222.311, RSKangXi=157.4
27FF2 CJK UNIFIED IDEOGRAPH-#27FF2, IRGKangXi=1223.030, RSKangXi=157.5
27FF3 CJK UNIFIED IDEOGRAPH-#27FF3, IRGKangXi=1223.040, RSKangXi=157.5
27FF4 CJK UNIFIED IDEOGRAPH-#27FF4, IRGKangXi=1223.080, RSKangXi=157.5
27FF5 CJK UNIFIED IDEOGRAPH-#27FF5, IRGKangXi=1223.120, RSKangXi=157.5
27FF6 CJK UNIFIED IDEOGRAPH-#27FF6, IRGKangXi=1223.160, RSKangXi=157.5
27FF7 CJK UNIFIED IDEOGRAPH-#27FF7, IRGKangXi=1223.180, RSKangXi=157.5
27FF8 CJK UNIFIED IDEOGRAPH-#27FF8, IRGKangXi=1223.240, RSKangXi=157.5
27FF9 CJK UNIFIED IDEOGRAPH-#27FF9, IRGKangXi=1223.260, RSKangXi=157.5, Def{thumb, big toe}
27FFA CJK UNIFIED IDEOGRAPH-#27FFA, IRGKangXi=1223.300, RSKangXi=157.5
27FFB CJK UNIFIED IDEOGRAPH-#27FFB, IRGKangXi=1223.340, RSKangXi=157.5
27FFC CJK UNIFIED IDEOGRAPH-#27FFC, IRGKangXi=1224.030, RSKangXi=157.5
27FFD CJK UNIFIED IDEOGRAPH-#27FFD, IRGKangXi=1224.100, RSKangXi=157.5
27FFE CJK UNIFIED IDEOGRAPH-#27FFE, IRGKangXi=1224.110, RSKangXi=157.5
27FFF CJK UNIFIED IDEOGRAPH-#27FFF, IRGKangXi=1224.120, RSKangXi=157.5
28000 CJK UNIFIED IDEOGRAPH-#28000, IRGKangXi=1224.130, RSKangXi=157.5
28001 CJK UNIFIED IDEOGRAPH-#28001, IRGKangXi=1224.131, RSKangXi=157.5
28002 CJK UNIFIED IDEOGRAPH-#28002, IRGKangXi=1224.131, RSKangXi=157.5
28003 CJK UNIFIED IDEOGRAPH-#28003, IRGKangXi=1224.131, RSKangXi=157.5
28004 CJK UNIFIED IDEOGRAPH-#28004, IRGKangXi=1224.131, RSKangXi=157.5
28005 CJK UNIFIED IDEOGRAPH-#28005, IRGKangXi=1224.131, RSKangXi=157.5
28006 CJK UNIFIED IDEOGRAPH-#28006, IRGKangXi=1224.131, RSKangXi=157.5
28007 CJK UNIFIED IDEOGRAPH-#28007, IRGKangXi=1224.131, RSKangXi=157.5
28008 CJK UNIFIED IDEOGRAPH-#28008, IRGKangXi=1224.131, RSKangXi=157.5
28009 CJK UNIFIED IDEOGRAPH-#28009, IRGKangXi=1224.131, RSKangXi=157.5
2800A CJK UNIFIED IDEOGRAPH-#2800A, IRGKangXi=1224.131, RSKangXi=157.5
2800B CJK UNIFIED IDEOGRAPH-#2800B, IRGKangXi=1224.131, RSKangXi=157.5
2800C CJK UNIFIED IDEOGRAPH-#2800C, IRGKangXi=1224.131, RSKangXi=157.5
2800D CJK UNIFIED IDEOGRAPH-#2800D, IRGKangXi=1224.131, RSKangXi=157.5
2800E CJK UNIFIED IDEOGRAPH-#2800E, IRGKangXi=1224.131, RSKangXi=157.5
2800F CJK UNIFIED IDEOGRAPH-#2800F, IRGKangXi=1224.131, RSKangXi=157.5
28010 CJK UNIFIED IDEOGRAPH-#28010, IRGKangXi=1224.131, RSKangXi=157.5
28011 CJK UNIFIED IDEOGRAPH-#28011, IRGKangXi=1224.131, RSKangXi=157.5
28012 CJK UNIFIED IDEOGRAPH-#28012, IRGKangXi=1224.131, RSKangXi=157.5
28013 CJK UNIFIED IDEOGRAPH-#28013, IRGKangXi=1224.131, RSKangXi=157.5
28014 CJK UNIFIED IDEOGRAPH-#28014, IRGKangXi=1224.131, RSKangXi=157.5
28015 CJK UNIFIED IDEOGRAPH-#28015, IRGKangXi=1224.170, RSKangXi=157.6
28016 CJK UNIFIED IDEOGRAPH-#28016, IRGKangXi=1224.220, RSKangXi=157.6
28017 CJK UNIFIED IDEOGRAPH-#28017, IRGKangXi=1225.020, RSKangXi=157.6
28018 CJK UNIFIED IDEOGRAPH-#28018, IRGKangXi=1225.030, RSKangXi=157.6
28019 CJK UNIFIED IDEOGRAPH-#28019, IRGKangXi=1225.050, RSKangXi=157.6
2801A CJK UNIFIED IDEOGRAPH-#2801A, IRGKangXi=1225.060, RSKangXi=157.6
2801B CJK UNIFIED IDEOGRAPH-#2801B, IRGKangXi=1225.070, RSKangXi=157.6
2801C CJK UNIFIED IDEOGRAPH-#2801C, IRGKangXi=1225.080, RSKangXi=157.6
2801D CJK UNIFIED IDEOGRAPH-#2801D, IRGKangXi=1225.090, RSKangXi=157.6
2801E CJK UNIFIED IDEOGRAPH-#2801E, IRGKangXi=1225.100, RSKangXi=157.6
2801F CJK UNIFIED IDEOGRAPH-#2801F, IRGKangXi=1225.110, RSKangXi=157.6
28020 CJK UNIFIED IDEOGRAPH-#28020, IRGKangXi=1225.140, RSKangXi=157.6
28021 CJK UNIFIED IDEOGRAPH-#28021, IRGKangXi=1225.150, RSKangXi=157.6
28022 CJK UNIFIED IDEOGRAPH-#28022, IRGKangXi=1225.170, RSKangXi=157.6
28023 CJK UNIFIED IDEOGRAPH-#28023, IRGKangXi=1225.210, RSKangXi=157.6, Def{(Cant.) a home, house}
28024 CJK UNIFIED IDEOGRAPH-#28024, IRGKangXi=1225.230, RSKangXi=157.6, Def{(Cant.) to suddenly fall or drop down}
28025 CJK UNIFIED IDEOGRAPH-#28025, IRGKangXi=1225.260, RSKangXi=157.6
28026 CJK UNIFIED IDEOGRAPH-#28026, IRGKangXi=1225.280, RSKangXi=157.6
28027 CJK UNIFIED IDEOGRAPH-#28027, IRGKangXi=1225.290, RSKangXi=157.6
28028 CJK UNIFIED IDEOGRAPH-#28028, IRGKangXi=1226.020, RSKangXi=157.6
28029 CJK UNIFIED IDEOGRAPH-#28029, IRGKangXi=1226.030, RSKangXi=157.6
2802A CJK UNIFIED IDEOGRAPH-#2802A, IRGKangXi=1226.040, RSKangXi=157.6
2802B CJK UNIFIED IDEOGRAPH-#2802B, IRGKangXi=1226.050, RSKangXi=157.6
2802C CJK UNIFIED IDEOGRAPH-#2802C, IRGKangXi=1226.060, RSKangXi=157.6
2802D CJK UNIFIED IDEOGRAPH-#2802D, IRGKangXi=1226.070, RSKangXi=157.6
2802E CJK UNIFIED IDEOGRAPH-#2802E, IRGKangXi=1226.090, RSKangXi=157.6
2802F CJK UNIFIED IDEOGRAPH-#2802F, IRGKangXi=1226.091, RSKangXi=157.6
28030 CJK UNIFIED IDEOGRAPH-#28030, IRGKangXi=1226.091, RSKangXi=157.6
28031 CJK UNIFIED IDEOGRAPH-#28031, IRGKangXi=1226.091, RSKangXi=157.6
28032 CJK UNIFIED IDEOGRAPH-#28032, IRGKangXi=1226.091, RSKangXi=157.6
28033 CJK UNIFIED IDEOGRAPH-#28033, IRGKangXi=1226.091, RSKangXi=157.6
28034 CJK UNIFIED IDEOGRAPH-#28034, IRGKangXi=1226.091, RSKangXi=157.6
28035 CJK UNIFIED IDEOGRAPH-#28035, IRGKangXi=1226.091, RSKangXi=157.6
28036 CJK UNIFIED IDEOGRAPH-#28036, IRGKangXi=1226.091, RSKangXi=157.6
28037 CJK UNIFIED IDEOGRAPH-#28037, IRGKangXi=1226.091, RSKangXi=157.6
28038 CJK UNIFIED IDEOGRAPH-#28038, IRGKangXi=1226.091, RSKangXi=157.6
28039 CJK UNIFIED IDEOGRAPH-#28039, IRGKangXi=1226.091, RSKangXi=157.6
2803A CJK UNIFIED IDEOGRAPH-#2803A, IRGKangXi=1226.091, RSKangXi=157.6
2803B CJK UNIFIED IDEOGRAPH-#2803B, IRGKangXi=1226.091, RSKangXi=157.6
2803C CJK UNIFIED IDEOGRAPH-#2803C, IRGKangXi=1226.091, RSKangXi=157.6
2803D CJK UNIFIED IDEOGRAPH-#2803D, IRGKangXi=1226.091, RSKangXi=157.6
2803E CJK UNIFIED IDEOGRAPH-#2803E, IRGKangXi=1226.091, RSKangXi=157.6
2803F CJK UNIFIED IDEOGRAPH-#2803F, IRGKangXi=1226.091, RSKangXi=157.6
28040 CJK UNIFIED IDEOGRAPH-#28040, IRGKangXi=1226.130, RSKangXi=157.7
28041 CJK UNIFIED IDEOGRAPH-#28041, IRGKangXi=1226.150, RSKangXi=157.7
28042 CJK UNIFIED IDEOGRAPH-#28042, IRGKangXi=1226.170, RSKangXi=157.7
28043 CJK UNIFIED IDEOGRAPH-#28043, IRGKangXi=1226.180, RSKangXi=157.7
28044 CJK UNIFIED IDEOGRAPH-#28044, IRGKangXi=1226.190, RSKangXi=157.7
28045 CJK UNIFIED IDEOGRAPH-#28045, IRGKangXi=1226.210, RSKangXi=157.7
28046 CJK UNIFIED IDEOGRAPH-#28046, IRGKangXi=1226.220, RSKangXi=157.7
28047 CJK UNIFIED IDEOGRAPH-#28047, IRGKangXi=1226.230, RSKangXi=157.7
28048 CJK UNIFIED IDEOGRAPH-#28048, IRGKangXi=1226.270, RSKangXi=157.7, Def{(Cant.) to ford, wade}
28049 CJK UNIFIED IDEOGRAPH-#28049, IRGKangXi=1226.340, RSKangXi=157.7
2804A CJK UNIFIED IDEOGRAPH-#2804A, IRGKangXi=1226.350, RSKangXi=157.7
2804B CJK UNIFIED IDEOGRAPH-#2804B, IRGKangXi=1226.380, RSKangXi=157.7
2804C CJK UNIFIED IDEOGRAPH-#2804C, IRGKangXi=1226.390, RSKangXi=157.7
2804D CJK UNIFIED IDEOGRAPH-#2804D, IRGKangXi=1226.450, RSKangXi=157.7
2804E CJK UNIFIED IDEOGRAPH-#2804E, IRGKangXi=1226.460, RSKangXi=157.7
2804F CJK UNIFIED IDEOGRAPH-#2804F, IRGKangXi=1227.020, RSKangXi=157.7
28050 CJK UNIFIED IDEOGRAPH-#28050, IRGKangXi=1227.040, RSKangXi=157.7
28051 CJK UNIFIED IDEOGRAPH-#28051, IRGKangXi=1227.050, RSKangXi=157.7
28052 CJK UNIFIED IDEOGRAPH-#28052, IRGKangXi=1227.060, RSKangXi=157.7
28053 CJK UNIFIED IDEOGRAPH-#28053, IRGKangXi=1227.070, RSKangXi=157.7
28054 CJK UNIFIED IDEOGRAPH-#28054, IRGKangXi=1227.080, RSKangXi=157.7
28055 CJK UNIFIED IDEOGRAPH-#28055, IRGKangXi=1227.090, RSKangXi=157.7
28056 CJK UNIFIED IDEOGRAPH-#28056, IRGKangXi=1227.091, RSKangXi=157.7
28057 CJK UNIFIED IDEOGRAPH-#28057, IRGKangXi=1227.091, RSKangXi=157.7
28058 CJK UNIFIED IDEOGRAPH-#28058, IRGKangXi=1227.091, RSKangXi=157.7
28059 CJK UNIFIED IDEOGRAPH-#28059, IRGKangXi=1227.091, RSKangXi=157.7
2805A CJK UNIFIED IDEOGRAPH-#2805A, IRGKangXi=1227.091, RSKangXi=157.7
2805B CJK UNIFIED IDEOGRAPH-#2805B, IRGKangXi=1227.091, RSKangXi=157.7
2805C CJK UNIFIED IDEOGRAPH-#2805C, IRGKangXi=1227.091, RSKangXi=157.7
2805D CJK UNIFIED IDEOGRAPH-#2805D, IRGKangXi=1227.091, RSKangXi=157.7
2805E CJK UNIFIED IDEOGRAPH-#2805E, IRGKangXi=1227.091, RSKangXi=157.7
2805F CJK UNIFIED IDEOGRAPH-#2805F, IRGKangXi=1227.091, RSKangXi=157.7
28060 CJK UNIFIED IDEOGRAPH-#28060, IRGKangXi=1227.091, RSKangXi=157.7
28061 CJK UNIFIED IDEOGRAPH-#28061, IRGKangXi=1227.091, RSKangXi=157.7
28062 CJK UNIFIED IDEOGRAPH-#28062, IRGKangXi=1227.091, RSKangXi=157.7
28063 CJK UNIFIED IDEOGRAPH-#28063, IRGKangXi=1227.091, RSKangXi=157.7
28064 CJK UNIFIED IDEOGRAPH-#28064, IRGKangXi=1227.091, RSKangXi=157.7
28065 CJK UNIFIED IDEOGRAPH-#28065, IRGKangXi=1227.091, RSKangXi=157.7
28066 CJK UNIFIED IDEOGRAPH-#28066, IRGKangXi=1227.091, RSKangXi=157.7
28067 CJK UNIFIED IDEOGRAPH-#28067, IRGKangXi=1227.091, RSKangXi=157.7
28068 CJK UNIFIED IDEOGRAPH-#28068, IRGKangXi=1227.091, RSKangXi=157.7
28069 CJK UNIFIED IDEOGRAPH-#28069, IRGKangXi=1227.091, RSKangXi=157.7
2806A CJK UNIFIED IDEOGRAPH-#2806A, IRGKangXi=1227.091, RSKangXi=157.7
2806B CJK UNIFIED IDEOGRAPH-#2806B, IRGKangXi=1227.091, RSKangXi=157.7
2806C CJK UNIFIED IDEOGRAPH-#2806C, IRGKangXi=1227.091, RSKangXi=157.7
2806D CJK UNIFIED IDEOGRAPH-#2806D, IRGKangXi=1227.091, RSKangXi=157.7
2806E CJK UNIFIED IDEOGRAPH-#2806E, IRGKangXi=1227.091, RSKangXi=157.7
2806F CJK UNIFIED IDEOGRAPH-#2806F, IRGKangXi=1227.091, RSKangXi=157.7
28070 CJK UNIFIED IDEOGRAPH-#28070, IRGKangXi=1227.091, RSKangXi=157.7
28071 CJK UNIFIED IDEOGRAPH-#28071, IRGKangXi=1227.091, RSKangXi=157.7
28072 CJK UNIFIED IDEOGRAPH-#28072, IRGKangXi=1227.091, RSKangXi=157.7
28073 CJK UNIFIED IDEOGRAPH-#28073, IRGKangXi=1227.091, RSKangXi=157.7
28074 CJK UNIFIED IDEOGRAPH-#28074, IRGKangXi=1227.091, RSKangXi=157.7
28075 CJK UNIFIED IDEOGRAPH-#28075, IRGKangXi=1227.100, RSKangXi=157.8
28076 CJK UNIFIED IDEOGRAPH-#28076, IRGKangXi=1227.120, RSKangXi=157.8
28077 CJK UNIFIED IDEOGRAPH-#28077, IRGKangXi=1227.160, RSKangXi=157.8
28078 CJK UNIFIED IDEOGRAPH-#28078, IRGKangXi=1227.210, RSKangXi=157.8
28079 CJK UNIFIED IDEOGRAPH-#28079, IRGKangXi=1227.240, RSKangXi=157.8
2807A CJK UNIFIED IDEOGRAPH-#2807A, IRGKangXi=1227.260, RSKangXi=157.8
2807B CJK UNIFIED IDEOGRAPH-#2807B, IRGKangXi=1227.280, RSKangXi=157.8
2807C CJK UNIFIED IDEOGRAPH-#2807C, IRGKangXi=1227.330, RSKangXi=157.8
2807D CJK UNIFIED IDEOGRAPH-#2807D, IRGKangXi=1227.350, RSKangXi=157.8
2807E CJK UNIFIED IDEOGRAPH-#2807E, IRGKangXi=1228.010, RSKangXi=157.8
2807F CJK UNIFIED IDEOGRAPH-#2807F, IRGKangXi=1228.030, RSKangXi=157.8
28080 CJK UNIFIED IDEOGRAPH-#28080, IRGKangXi=1228.040, RSKangXi=157.8
28081 CJK UNIFIED IDEOGRAPH-#28081, IRGKangXi=1228.070, RSKangXi=157.8
28082 CJK UNIFIED IDEOGRAPH-#28082, IRGKangXi=1228.190, RSKangXi=157.8
28083 CJK UNIFIED IDEOGRAPH-#28083, IRGKangXi=1228.270, RSKangXi=157.8
28084 CJK UNIFIED IDEOGRAPH-#28084, IRGKangXi=1228.280, RSKangXi=157.8
28085 CJK UNIFIED IDEOGRAPH-#28085, IRGKangXi=1229.030, RSKangXi=157.8
28086 CJK UNIFIED IDEOGRAPH-#28086, IRGKangXi=1229.040, RSKangXi=157.8
28087 CJK UNIFIED IDEOGRAPH-#28087, IRGKangXi=1229.050, RSKangXi=157.8
28088 CJK UNIFIED IDEOGRAPH-#28088, IRGKangXi=1229.070, RSKangXi=157.8
28089 CJK UNIFIED IDEOGRAPH-#28089, IRGKangXi=1229.071, RSKangXi=157.8
2808A CJK UNIFIED IDEOGRAPH-#2808A, IRGKangXi=1229.071, RSKangXi=157.8
2808B CJK UNIFIED IDEOGRAPH-#2808B, IRGKangXi=1229.071, RSKangXi=157.8
2808C CJK UNIFIED IDEOGRAPH-#2808C, IRGKangXi=1229.071, RSKangXi=157.8
2808D CJK UNIFIED IDEOGRAPH-#2808D, IRGKangXi=1229.071, RSKangXi=157.8
2808E CJK UNIFIED IDEOGRAPH-#2808E, IRGKangXi=1229.071, RSKangXi=157.8
2808F CJK UNIFIED IDEOGRAPH-#2808F, IRGKangXi=1229.071, RSKangXi=157.8
28090 CJK UNIFIED IDEOGRAPH-#28090, IRGKangXi=1229.071, RSKangXi=157.8, Def{(Cant.) to suddenly fall or drop down}
28091 CJK UNIFIED IDEOGRAPH-#28091, IRGKangXi=1229.071, RSKangXi=157.8
28092 CJK UNIFIED IDEOGRAPH-#28092, IRGKangXi=1229.071, RSKangXi=157.8
28093 CJK UNIFIED IDEOGRAPH-#28093, IRGKangXi=1229.071, RSKangXi=157.8
28094 CJK UNIFIED IDEOGRAPH-#28094, IRGKangXi=1229.071, RSKangXi=157.8
28095 CJK UNIFIED IDEOGRAPH-#28095, IRGKangXi=1229.071, RSKangXi=157.8
28096 CJK UNIFIED IDEOGRAPH-#28096, IRGKangXi=1229.071, RSKangXi=157.8
28097 CJK UNIFIED IDEOGRAPH-#28097, IRGKangXi=1229.071, RSKangXi=157.8
28098 CJK UNIFIED IDEOGRAPH-#28098, IRGKangXi=1229.071, RSKangXi=157.8
28099 CJK UNIFIED IDEOGRAPH-#28099, IRGKangXi=1229.071, RSKangXi=157.8
2809A CJK UNIFIED IDEOGRAPH-#2809A, IRGKangXi=1229.071, RSKangXi=157.8
2809B CJK UNIFIED IDEOGRAPH-#2809B, IRGKangXi=1229.071, RSKangXi=157.8
2809C CJK UNIFIED IDEOGRAPH-#2809C, IRGKangXi=1229.071, RSKangXi=157.8
2809D CJK UNIFIED IDEOGRAPH-#2809D, IRGKangXi=1229.080, RSKangXi=157.9
2809E CJK UNIFIED IDEOGRAPH-#2809E, IRGKangXi=1229.090, RSKangXi=157.9
2809F CJK UNIFIED IDEOGRAPH-#2809F, IRGKangXi=1229.091, RSKangXi=157.8
280A0 CJK UNIFIED IDEOGRAPH-#280A0, IRGKangXi=1229.100, RSKangXi=157.9
280A1 CJK UNIFIED IDEOGRAPH-#280A1, IRGKangXi=1229.140, RSKangXi=157.9
280A2 CJK UNIFIED IDEOGRAPH-#280A2, IRGKangXi=1229.150, RSKangXi=157.9
280A3 CJK UNIFIED IDEOGRAPH-#280A3, IRGKangXi=1229.180, RSKangXi=157.9
280A4 CJK UNIFIED IDEOGRAPH-#280A4, IRGKangXi=1229.210, RSKangXi=157.9
280A5 CJK UNIFIED IDEOGRAPH-#280A5, IRGKangXi=1229.260, RSKangXi=157.9
280A6 CJK UNIFIED IDEOGRAPH-#280A6, IRGKangXi=1229.290, RSKangXi=157.9
280A7 CJK UNIFIED IDEOGRAPH-#280A7, IRGKangXi=1229.320, RSKangXi=157.9
280A8 CJK UNIFIED IDEOGRAPH-#280A8, IRGKangXi=1229.330, RSKangXi=157.9
280A9 CJK UNIFIED IDEOGRAPH-#280A9, IRGKangXi=1230.010, RSKangXi=157.9
280AA CJK UNIFIED IDEOGRAPH-#280AA, IRGKangXi=1230.020, RSKangXi=157.9
280AB CJK UNIFIED IDEOGRAPH-#280AB, IRGKangXi=1230.030, RSKangXi=157.9
280AC CJK UNIFIED IDEOGRAPH-#280AC, IRGKangXi=1230.040, RSKangXi=157.9
280AD CJK UNIFIED IDEOGRAPH-#280AD, IRGKangXi=1230.070, RSKangXi=157.9
280AE CJK UNIFIED IDEOGRAPH-#280AE, IRGKangXi=1230.080, RSKangXi=157.9
280AF CJK UNIFIED IDEOGRAPH-#280AF, IRGKangXi=1230.090, RSKangXi=157.9
280B0 CJK UNIFIED IDEOGRAPH-#280B0, IRGKangXi=1230.100, RSKangXi=157.9
280B1 CJK UNIFIED IDEOGRAPH-#280B1, IRGKangXi=1230.110, RSKangXi=157.9
280B2 CJK UNIFIED IDEOGRAPH-#280B2, IRGKangXi=1230.190, RSKangXi=157.9
280B3 CJK UNIFIED IDEOGRAPH-#280B3, IRGKangXi=1230.200, RSKangXi=157.9
280B4 CJK UNIFIED IDEOGRAPH-#280B4, IRGKangXi=1230.210, RSKangXi=157.9
280B5 CJK UNIFIED IDEOGRAPH-#280B5, IRGKangXi=1230.220, RSKangXi=157.9
280B6 CJK UNIFIED IDEOGRAPH-#280B6, IRGKangXi=1230.250, RSKangXi=157.9
280B7 CJK UNIFIED IDEOGRAPH-#280B7, IRGKangXi=1230.260, RSKangXi=157.9
280B8 CJK UNIFIED IDEOGRAPH-#280B8, IRGKangXi=1230.280, RSKangXi=157.9
280B9 CJK UNIFIED IDEOGRAPH-#280B9, IRGKangXi=1230.290, RSKangXi=157.9
280BA CJK UNIFIED IDEOGRAPH-#280BA, IRGKangXi=1230.291, RSKangXi=157.9
280BB CJK UNIFIED IDEOGRAPH-#280BB, IRGKangXi=1230.291, RSKangXi=157.9
280BC CJK UNIFIED IDEOGRAPH-#280BC, IRGKangXi=1230.291, RSKangXi=157.9
280BD CJK UNIFIED IDEOGRAPH-#280BD, IRGKangXi=1230.291, RSKangXi=157.9, Def{(Cant.) to stamp the foot}
280BE CJK UNIFIED IDEOGRAPH-#280BE, IRGKangXi=1230.291, RSKangXi=157.9, Def{(Cant.) to step across}
280BF CJK UNIFIED IDEOGRAPH-#280BF, IRGKangXi=1230.291, RSKangXi=157.9
280C0 CJK UNIFIED IDEOGRAPH-#280C0, IRGKangXi=1230.291, RSKangXi=157.9
280C1 CJK UNIFIED IDEOGRAPH-#280C1, IRGKangXi=1230.291, RSKangXi=157.9
280C2 CJK UNIFIED IDEOGRAPH-#280C2, IRGKangXi=1230.291, RSKangXi=157.9
280C3 CJK UNIFIED IDEOGRAPH-#280C3, IRGKangXi=1230.291, RSKangXi=157.9
280C4 CJK UNIFIED IDEOGRAPH-#280C4, IRGKangXi=1230.291, RSKangXi=157.9
280C5 CJK UNIFIED IDEOGRAPH-#280C5, IRGKangXi=1230.291, RSKangXi=157.9
280C6 CJK UNIFIED IDEOGRAPH-#280C6, IRGKangXi=1230.291, RSKangXi=157.9
280C7 CJK UNIFIED IDEOGRAPH-#280C7, IRGKangXi=1230.291, RSKangXi=157.9
280C8 CJK UNIFIED IDEOGRAPH-#280C8, IRGKangXi=1230.291, RSKangXi=157.9
280C9 CJK UNIFIED IDEOGRAPH-#280C9, IRGKangXi=1230.291, RSKangXi=157.9
280CA CJK UNIFIED IDEOGRAPH-#280CA, IRGKangXi=1230.291, RSKangXi=157.9
280CB CJK UNIFIED IDEOGRAPH-#280CB, IRGKangXi=1230.291, RSKangXi=157.9
280CC CJK UNIFIED IDEOGRAPH-#280CC, IRGKangXi=1230.291, RSKangXi=157.9
280CD CJK UNIFIED IDEOGRAPH-#280CD, IRGKangXi=1230.291, RSKangXi=157.9
280CE CJK UNIFIED IDEOGRAPH-#280CE, IRGKangXi=1230.291, RSKangXi=157.9
280CF CJK UNIFIED IDEOGRAPH-#280CF, IRGKangXi=1230.291, RSKangXi=157.9
280D0 CJK UNIFIED IDEOGRAPH-#280D0, IRGKangXi=1230.291, RSKangXi=157.9
280D1 CJK UNIFIED IDEOGRAPH-#280D1, IRGKangXi=1230.291, RSKangXi=157.9
280D2 CJK UNIFIED IDEOGRAPH-#280D2, IRGKangXi=1230.291, RSKangXi=157.9
280D3 CJK UNIFIED IDEOGRAPH-#280D3, IRGKangXi=1230.300, RSKangXi=157.10
280D4 CJK UNIFIED IDEOGRAPH-#280D4, IRGKangXi=1230.320, RSKangXi=157.10
280D5 CJK UNIFIED IDEOGRAPH-#280D5, IRGKangXi=1230.330, RSKangXi=157.10
280D6 CJK UNIFIED IDEOGRAPH-#280D6, IRGKangXi=1230.340, RSKangXi=157.10
280D7 CJK UNIFIED IDEOGRAPH-#280D7, IRGKangXi=1230.380, RSKangXi=157.10
280D8 CJK UNIFIED IDEOGRAPH-#280D8, IRGKangXi=1230.390, RSKangXi=157.10
280D9 CJK UNIFIED IDEOGRAPH-#280D9, IRGKangXi=1231.010, RSKangXi=157.10
280DA CJK UNIFIED IDEOGRAPH-#280DA, IRGKangXi=1231.020, RSKangXi=157.10
280DB CJK UNIFIED IDEOGRAPH-#280DB, IRGKangXi=1231.090, RSKangXi=157.10
280DC CJK UNIFIED IDEOGRAPH-#280DC, IRGKangXi=1231.100, RSKangXi=157.10
280DD CJK UNIFIED IDEOGRAPH-#280DD, IRGKangXi=1231.120, RSKangXi=157.10
280DE CJK UNIFIED IDEOGRAPH-#280DE, IRGKangXi=1231.130, RSKangXi=157.10, Def{to sit cross-legged}
280DF CJK UNIFIED IDEOGRAPH-#280DF, IRGKangXi=1231.140, RSKangXi=157.10, Def{to sit cross-legged}
280E0 CJK UNIFIED IDEOGRAPH-#280E0, IRGKangXi=1231.150, RSKangXi=157.10
280E1 CJK UNIFIED IDEOGRAPH-#280E1, IRGKangXi=1231.180, RSKangXi=157.10
280E2 CJK UNIFIED IDEOGRAPH-#280E2, IRGKangXi=1231.190, RSKangXi=157.10
280E3 CJK UNIFIED IDEOGRAPH-#280E3, IRGKangXi=1231.210, RSKangXi=157.10
280E4 CJK UNIFIED IDEOGRAPH-#280E4, IRGKangXi=1231.220, RSKangXi=157.10
280E5 CJK UNIFIED IDEOGRAPH-#280E5, IRGKangXi=1231.240, RSKangXi=157.10
280E6 CJK UNIFIED IDEOGRAPH-#280E6, IRGKangXi=1231.270, RSKangXi=157.10
280E7 CJK UNIFIED IDEOGRAPH-#280E7, IRGKangXi=1231.280, RSKangXi=157.10
280E8 CJK UNIFIED IDEOGRAPH-#280E8, IRGKangXi=1231.290, RSKangXi=157.10
280E9 CJK UNIFIED IDEOGRAPH-#280E9, IRGKangXi=1231.301, RSKangXi=157.10, Def{(Cant.) to slip, slide}
280EA CJK UNIFIED IDEOGRAPH-#280EA, IRGKangXi=1231.301, RSKangXi=157.10
280EB CJK UNIFIED IDEOGRAPH-#280EB, IRGKangXi=1231.301, RSKangXi=157.10
280EC CJK UNIFIED IDEOGRAPH-#280EC, IRGKangXi=1231.301, RSKangXi=157.10
280ED CJK UNIFIED IDEOGRAPH-#280ED, IRGKangXi=1231.301, RSKangXi=157.10
280EE CJK UNIFIED IDEOGRAPH-#280EE, IRGKangXi=1231.301, RSKangXi=157.10
280EF CJK UNIFIED IDEOGRAPH-#280EF, IRGKangXi=1231.301, RSKangXi=157.10
280F0 CJK UNIFIED IDEOGRAPH-#280F0, IRGKangXi=1231.301, RSKangXi=157.10
280F1 CJK UNIFIED IDEOGRAPH-#280F1, IRGKangXi=1231.301, RSKangXi=157.10
280F2 CJK UNIFIED IDEOGRAPH-#280F2, IRGKangXi=1231.301, RSKangXi=157.10
280F3 CJK UNIFIED IDEOGRAPH-#280F3, IRGKangXi=1231.301, RSKangXi=157.10
280F4 CJK UNIFIED IDEOGRAPH-#280F4, IRGKangXi=1231.301, RSKangXi=157.10
280F5 CJK UNIFIED IDEOGRAPH-#280F5, IRGKangXi=1231.301, RSKangXi=157.10
280F6 CJK UNIFIED IDEOGRAPH-#280F6, IRGKangXi=1231.301, RSKangXi=157.10
280F7 CJK UNIFIED IDEOGRAPH-#280F7, IRGKangXi=1231.301, RSKangXi=157.10
280F8 CJK UNIFIED IDEOGRAPH-#280F8, IRGKangXi=1231.301, RSKangXi=157.10
280F9 CJK UNIFIED IDEOGRAPH-#280F9, IRGKangXi=1231.301, RSKangXi=157.10
280FA CJK UNIFIED IDEOGRAPH-#280FA, IRGKangXi=1231.301, RSKangXi=157.10
280FB CJK UNIFIED IDEOGRAPH-#280FB, IRGKangXi=1231.301, RSKangXi=157.10
280FC CJK UNIFIED IDEOGRAPH-#280FC, IRGKangXi=1231.301, RSKangXi=157.10
280FD CJK UNIFIED IDEOGRAPH-#280FD, IRGKangXi=1231.301, RSKangXi=157.10
280FE CJK UNIFIED IDEOGRAPH-#280FE, IRGKangXi=1231.301, RSKangXi=157.10
280FF CJK UNIFIED IDEOGRAPH-#280FF, IRGKangXi=1231.301, RSKangXi=157.10
28100 CJK UNIFIED IDEOGRAPH-#28100, IRGKangXi=1231.301, RSKangXi=157.10
28101 CJK UNIFIED IDEOGRAPH-#28101, IRGKangXi=1231.301, RSKangXi=157.10
28102 CJK UNIFIED IDEOGRAPH-#28102, IRGKangXi=1231.301, RSKangXi=157.10
28103 CJK UNIFIED IDEOGRAPH-#28103, IRGKangXi=1231.310, RSKangXi=157.11
28104 CJK UNIFIED IDEOGRAPH-#28104, IRGKangXi=1231.311, RSKangXi=157.10
28105 CJK UNIFIED IDEOGRAPH-#28105, IRGKangXi=1231.320, RSKangXi=157.11
28106 CJK UNIFIED IDEOGRAPH-#28106, IRGKangXi=1232.010, RSKangXi=157.11
28107 CJK UNIFIED IDEOGRAPH-#28107, IRGKangXi=1232.020, RSKangXi=157.11
28108 CJK UNIFIED IDEOGRAPH-#28108, IRGKangXi=1232.040, RSKangXi=157.11
28109 CJK UNIFIED IDEOGRAPH-#28109, IRGKangXi=1232.080, RSKangXi=157.11
2810A CJK UNIFIED IDEOGRAPH-#2810A, IRGKangXi=1232.090, RSKangXi=157.11
2810B CJK UNIFIED IDEOGRAPH-#2810B, IRGKangXi=1232.100, RSKangXi=157.11
2810C CJK UNIFIED IDEOGRAPH-#2810C, IRGKangXi=1232.120, RSKangXi=157.11
2810D CJK UNIFIED IDEOGRAPH-#2810D, IRGKangXi=1232.130, RSKangXi=157.11
2810E CJK UNIFIED IDEOGRAPH-#2810E, IRGKangXi=1232.140, RSKangXi=157.11
2810F CJK UNIFIED IDEOGRAPH-#2810F, IRGKangXi=1232.150, RSKangXi=157.11
28110 CJK UNIFIED IDEOGRAPH-#28110, IRGKangXi=1232.160, RSKangXi=157.11
28111 CJK UNIFIED IDEOGRAPH-#28111, IRGKangXi=1232.170, RSKangXi=157.11
28112 CJK UNIFIED IDEOGRAPH-#28112, IRGKangXi=1232.180, RSKangXi=157.11
28113 CJK UNIFIED IDEOGRAPH-#28113, IRGKangXi=1232.190, RSKangXi=157.11
28114 CJK UNIFIED IDEOGRAPH-#28114, IRGKangXi=1232.230, RSKangXi=157.11
28115 CJK UNIFIED IDEOGRAPH-#28115, IRGKangXi=1232.310, RSKangXi=157.11
28116 CJK UNIFIED IDEOGRAPH-#28116, IRGKangXi=1232.330, RSKangXi=157.11
28117 CJK UNIFIED IDEOGRAPH-#28117, IRGKangXi=1232.400, RSKangXi=157.11
28118 CJK UNIFIED IDEOGRAPH-#28118, IRGKangXi=1232.410, RSKangXi=157.11
28119 CJK UNIFIED IDEOGRAPH-#28119, IRGKangXi=1232.420, RSKangXi=157.11
2811A CJK UNIFIED IDEOGRAPH-#2811A, IRGKangXi=1232.430, RSKangXi=157.11
2811B CJK UNIFIED IDEOGRAPH-#2811B, IRGKangXi=1232.440, RSKangXi=157.11
2811C CJK UNIFIED IDEOGRAPH-#2811C, IRGKangXi=1232.441, RSKangXi=157.11
2811D CJK UNIFIED IDEOGRAPH-#2811D, IRGKangXi=1232.441, RSKangXi=157.11
2811E CJK UNIFIED IDEOGRAPH-#2811E, IRGKangXi=1232.441, RSKangXi=157.11
2811F CJK UNIFIED IDEOGRAPH-#2811F, IRGKangXi=1232.441, RSKangXi=157.11
28120 CJK UNIFIED IDEOGRAPH-#28120, IRGKangXi=1232.441, RSKangXi=157.11
28121 CJK UNIFIED IDEOGRAPH-#28121, IRGKangXi=1232.441, RSKangXi=157.11
28122 CJK UNIFIED IDEOGRAPH-#28122, IRGKangXi=1232.441, RSKangXi=157.11
28123 CJK UNIFIED IDEOGRAPH-#28123, IRGKangXi=1232.441, RSKangXi=157.11
28124 CJK UNIFIED IDEOGRAPH-#28124, IRGKangXi=1232.441, RSKangXi=157.11
28125 CJK UNIFIED IDEOGRAPH-#28125, IRGKangXi=1232.441, RSKangXi=157.11
28126 CJK UNIFIED IDEOGRAPH-#28126, IRGKangXi=1232.441, RSKangXi=157.11
28127 CJK UNIFIED IDEOGRAPH-#28127, IRGKangXi=1232.441, RSKangXi=157.11
28128 CJK UNIFIED IDEOGRAPH-#28128, IRGKangXi=1232.441, RSKangXi=157.11
28129 CJK UNIFIED IDEOGRAPH-#28129, IRGKangXi=1232.441, RSKangXi=157.11
2812A CJK UNIFIED IDEOGRAPH-#2812A, IRGKangXi=1232.441, RSKangXi=157.11
2812B CJK UNIFIED IDEOGRAPH-#2812B, IRGKangXi=1232.441, RSKangXi=157.11
2812C CJK UNIFIED IDEOGRAPH-#2812C, IRGKangXi=1232.441, RSKangXi=157.11
2812D CJK UNIFIED IDEOGRAPH-#2812D, IRGKangXi=1232.441, RSKangXi=157.11
2812E CJK UNIFIED IDEOGRAPH-#2812E, IRGKangXi=1232.441, RSKangXi=157.11
2812F CJK UNIFIED IDEOGRAPH-#2812F, IRGKangXi=1232.441, RSKangXi=157.11
28130 CJK UNIFIED IDEOGRAPH-#28130, IRGKangXi=1232.441, RSKangXi=157.11
28131 CJK UNIFIED IDEOGRAPH-#28131, IRGKangXi=1232.441, RSKangXi=157.11
28132 CJK UNIFIED IDEOGRAPH-#28132, IRGKangXi=1232.441, RSKangXi=157.11
28133 CJK UNIFIED IDEOGRAPH-#28133, IRGKangXi=1232.441, RSKangXi=157.11
28134 CJK UNIFIED IDEOGRAPH-#28134, IRGKangXi=1232.441, RSKangXi=157.11
28135 CJK UNIFIED IDEOGRAPH-#28135, IRGKangXi=1232.441, RSKangXi=157.11
28136 CJK UNIFIED IDEOGRAPH-#28136, IRGKangXi=1232.441, RSKangXi=157.11
28137 CJK UNIFIED IDEOGRAPH-#28137, IRGKangXi=1232.441, RSKangXi=157.11
28138 CJK UNIFIED IDEOGRAPH-#28138, IRGKangXi=1232.441, RSKangXi=157.11
28139 CJK UNIFIED IDEOGRAPH-#28139, IRGKangXi=1232.441, RSKangXi=157.11
2813A CJK UNIFIED IDEOGRAPH-#2813A, IRGKangXi=1232.441, RSKangXi=157.11
2813B CJK UNIFIED IDEOGRAPH-#2813B, IRGKangXi=1232.441, RSKangXi=157.11
2813C CJK UNIFIED IDEOGRAPH-#2813C, IRGKangXi=1232.441, RSKangXi=157.11
2813D CJK UNIFIED IDEOGRAPH-#2813D, IRGKangXi=1232.441, RSKangXi=157.11
2813E CJK UNIFIED IDEOGRAPH-#2813E, IRGKangXi=1232.441, RSKangXi=157.11
2813F CJK UNIFIED IDEOGRAPH-#2813F, IRGKangXi=1232.441, RSKangXi=157.11
28140 CJK UNIFIED IDEOGRAPH-#28140, IRGKangXi=1232.441, RSKangXi=157.11
28141 CJK UNIFIED IDEOGRAPH-#28141, IRGKangXi=1232.441, RSKangXi=157.11
28142 CJK UNIFIED IDEOGRAPH-#28142, IRGKangXi=1232.441, RSKangXi=157.11
28143 CJK UNIFIED IDEOGRAPH-#28143, IRGKangXi=1232.441, RSKangXi=157.11
28144 CJK UNIFIED IDEOGRAPH-#28144, IRGKangXi=1232.441, RSKangXi=157.11
28145 CJK UNIFIED IDEOGRAPH-#28145, IRGKangXi=1232.441, RSKangXi=157.11
28146 CJK UNIFIED IDEOGRAPH-#28146, IRGKangXi=1232.441, RSKangXi=157.11
28147 CJK UNIFIED IDEOGRAPH-#28147, IRGKangXi=1232.441, RSKangXi=157.11
28148 CJK UNIFIED IDEOGRAPH-#28148, IRGKangXi=1232.441, RSKangXi=157.11
28149 CJK UNIFIED IDEOGRAPH-#28149, IRGKangXi=1232.441, RSKangXi=157.11
2814A CJK UNIFIED IDEOGRAPH-#2814A, IRGKangXi=1233.020, RSKangXi=157.12
2814B CJK UNIFIED IDEOGRAPH-#2814B, IRGKangXi=1233.070, RSKangXi=157.12
2814C CJK UNIFIED IDEOGRAPH-#2814C, IRGKangXi=1233.080, RSKangXi=157.12
2814D CJK UNIFIED IDEOGRAPH-#2814D, IRGKangXi=1233.090, RSKangXi=157.12
2814E CJK UNIFIED IDEOGRAPH-#2814E, IRGKangXi=1233.110, RSKangXi=157.12
2814F CJK UNIFIED IDEOGRAPH-#2814F, IRGKangXi=1233.130, RSKangXi=157.12, Def{(Cant.) to step over, step across}
28150 CJK UNIFIED IDEOGRAPH-#28150, IRGKangXi=1233.140, RSKangXi=157.12
28151 CJK UNIFIED IDEOGRAPH-#28151, IRGKangXi=1233.150, RSKangXi=157.12
28152 CJK UNIFIED IDEOGRAPH-#28152, IRGKangXi=1233.170, RSKangXi=157.12
28153 CJK UNIFIED IDEOGRAPH-#28153, IRGKangXi=1233.180, RSKangXi=157.12
28154 CJK UNIFIED IDEOGRAPH-#28154, IRGKangXi=1233.190, RSKangXi=157.12
28155 CJK UNIFIED IDEOGRAPH-#28155, IRGKangXi=1233.200, RSKangXi=157.12
28156 CJK UNIFIED IDEOGRAPH-#28156, IRGKangXi=1233.270, RSKangXi=157.12
28157 CJK UNIFIED IDEOGRAPH-#28157, IRGKangXi=1233.280, RSKangXi=157.12
28158 CJK UNIFIED IDEOGRAPH-#28158, IRGKangXi=1233.300, RSKangXi=157.12
28159 CJK UNIFIED IDEOGRAPH-#28159, IRGKangXi=1233.310, RSKangXi=157.12
2815A CJK UNIFIED IDEOGRAPH-#2815A, IRGKangXi=1233.350, RSKangXi=157.11
2815B CJK UNIFIED IDEOGRAPH-#2815B, IRGKangXi=1233.380, RSKangXi=157.12
2815C CJK UNIFIED IDEOGRAPH-#2815C, IRGKangXi=1233.390, RSKangXi=157.12
2815D CJK UNIFIED IDEOGRAPH-#2815D, IRGKangXi=1233.400, RSKangXi=157.12, Def{(Cant.) to press down or out with the foot; to kick; to tread on}
2815E CJK UNIFIED IDEOGRAPH-#2815E, IRGKangXi=1234.030, RSKangXi=157.12
2815F CJK UNIFIED IDEOGRAPH-#2815F, IRGKangXi=1234.050, RSKangXi=157.12
28160 CJK UNIFIED IDEOGRAPH-#28160, IRGKangXi=1234.080, RSKangXi=157.12
28161 CJK UNIFIED IDEOGRAPH-#28161, IRGKangXi=1234.100, RSKangXi=157.12
28162 CJK UNIFIED IDEOGRAPH-#28162, IRGKangXi=1234.110, RSKangXi=157.12
28163 CJK UNIFIED IDEOGRAPH-#28163, IRGKangXi=1234.120, RSKangXi=157.12
28164 CJK UNIFIED IDEOGRAPH-#28164, IRGKangXi=1234.130, RSKangXi=157.12
28165 CJK UNIFIED IDEOGRAPH-#28165, IRGKangXi=1234.140, RSKangXi=157.12
28166 CJK UNIFIED IDEOGRAPH-#28166, IRGKangXi=1234.150, RSKangXi=157.12
28167 CJK UNIFIED IDEOGRAPH-#28167, IRGKangXi=1234.160, RSKangXi=157.12
28168 CJK UNIFIED IDEOGRAPH-#28168, IRGKangXi=1234.170, RSKangXi=157.12
28169 CJK UNIFIED IDEOGRAPH-#28169, IRGKangXi=1234.180, RSKangXi=157.12
2816A CJK UNIFIED IDEOGRAPH-#2816A, IRGKangXi=1234.190, RSKangXi=157.12
2816B CJK UNIFIED IDEOGRAPH-#2816B, IRGKangXi=1234.200, RSKangXi=157.12
2816C CJK UNIFIED IDEOGRAPH-#2816C, IRGKangXi=1234.201, RSKangXi=157.12
2816D CJK UNIFIED IDEOGRAPH-#2816D, IRGKangXi=1234.201, RSKangXi=157.12
2816E CJK UNIFIED IDEOGRAPH-#2816E, IRGKangXi=1234.201, RSKangXi=157.12
2816F CJK UNIFIED IDEOGRAPH-#2816F, IRGKangXi=1234.201, RSKangXi=157.12
28170 CJK UNIFIED IDEOGRAPH-#28170, IRGKangXi=1234.201, RSKangXi=157.12
28171 CJK UNIFIED IDEOGRAPH-#28171, IRGKangXi=1234.201, RSKangXi=157.12
28172 CJK UNIFIED IDEOGRAPH-#28172, IRGKangXi=1234.201, RSKangXi=157.12
28173 CJK UNIFIED IDEOGRAPH-#28173, IRGKangXi=1234.201, RSKangXi=157.12
28174 CJK UNIFIED IDEOGRAPH-#28174, IRGKangXi=1234.201, RSKangXi=157.12
28175 CJK UNIFIED IDEOGRAPH-#28175, IRGKangXi=1234.201, RSKangXi=157.12
28176 CJK UNIFIED IDEOGRAPH-#28176, IRGKangXi=1234.201, RSKangXi=157.12
28177 CJK UNIFIED IDEOGRAPH-#28177, IRGKangXi=1234.201, RSKangXi=157.12
28178 CJK UNIFIED IDEOGRAPH-#28178, IRGKangXi=1234.201, RSKangXi=157.12
28179 CJK UNIFIED IDEOGRAPH-#28179, IRGKangXi=1234.201, RSKangXi=157.12
2817A CJK UNIFIED IDEOGRAPH-#2817A, IRGKangXi=1234.201, RSKangXi=157.12
2817B CJK UNIFIED IDEOGRAPH-#2817B, IRGKangXi=1234.201, RSKangXi=157.12
2817C CJK UNIFIED IDEOGRAPH-#2817C, IRGKangXi=1234.201, RSKangXi=157.12
2817D CJK UNIFIED IDEOGRAPH-#2817D, IRGKangXi=1234.201, RSKangXi=157.12
2817E CJK UNIFIED IDEOGRAPH-#2817E, IRGKangXi=1234.201, RSKangXi=157.12
2817F CJK UNIFIED IDEOGRAPH-#2817F, IRGKangXi=1234.201, RSKangXi=157.12
28180 CJK UNIFIED IDEOGRAPH-#28180, IRGKangXi=1234.201, RSKangXi=157.12
28181 CJK UNIFIED IDEOGRAPH-#28181, IRGKangXi=1234.220, RSKangXi=157.13
28182 CJK UNIFIED IDEOGRAPH-#28182, IRGKangXi=1234.230, RSKangXi=157.13
28183 CJK UNIFIED IDEOGRAPH-#28183, IRGKangXi=1234.240, RSKangXi=157.13
28184 CJK UNIFIED IDEOGRAPH-#28184, IRGKangXi=1234.260, RSKangXi=157.13
28185 CJK UNIFIED IDEOGRAPH-#28185, IRGKangXi=1234.290, RSKangXi=157.13
28186 CJK UNIFIED IDEOGRAPH-#28186, IRGKangXi=1234.300, RSKangXi=157.13
28187 CJK UNIFIED IDEOGRAPH-#28187, IRGKangXi=1234.310, RSKangXi=157.13
28188 CJK UNIFIED IDEOGRAPH-#28188, IRGKangXi=1234.340, RSKangXi=157.13
28189 CJK UNIFIED IDEOGRAPH-#28189, IRGKangXi=1234.350, RSKangXi=157.13
2818A CJK UNIFIED IDEOGRAPH-#2818A, IRGKangXi=1234.370, RSKangXi=157.13
2818B CJK UNIFIED IDEOGRAPH-#2818B, IRGKangXi=1234.390, RSKangXi=157.13
2818C CJK UNIFIED IDEOGRAPH-#2818C, IRGKangXi=1234.400, RSKangXi=157.13
2818D CJK UNIFIED IDEOGRAPH-#2818D, IRGKangXi=1235.010, RSKangXi=157.13
2818E CJK UNIFIED IDEOGRAPH-#2818E, IRGKangXi=1235.040, RSKangXi=157.13
2818F CJK UNIFIED IDEOGRAPH-#2818F, IRGKangXi=1235.050, RSKangXi=157.13
28190 CJK UNIFIED IDEOGRAPH-#28190, IRGKangXi=1235.070, RSKangXi=157.13
28191 CJK UNIFIED IDEOGRAPH-#28191, IRGKangXi=1235.080, RSKangXi=157.13
28192 CJK UNIFIED IDEOGRAPH-#28192, IRGKangXi=1235.081, RSKangXi=157.13
28193 CJK UNIFIED IDEOGRAPH-#28193, IRGKangXi=1235.081, RSKangXi=157.13
28194 CJK UNIFIED IDEOGRAPH-#28194, IRGKangXi=1235.081, RSKangXi=157.13
28195 CJK UNIFIED IDEOGRAPH-#28195, IRGKangXi=1235.081, RSKangXi=157.13
28196 CJK UNIFIED IDEOGRAPH-#28196, IRGKangXi=1235.081, RSKangXi=157.13
28197 CJK UNIFIED IDEOGRAPH-#28197, IRGKangXi=1235.081, RSKangXi=157.13
28198 CJK UNIFIED IDEOGRAPH-#28198, IRGKangXi=1235.081, RSKangXi=157.13
28199 CJK UNIFIED IDEOGRAPH-#28199, IRGKangXi=1235.081, RSKangXi=157.13
2819A CJK UNIFIED IDEOGRAPH-#2819A, IRGKangXi=1235.081, RSKangXi=157.13
2819B CJK UNIFIED IDEOGRAPH-#2819B, IRGKangXi=1235.081, RSKangXi=157.13
2819C CJK UNIFIED IDEOGRAPH-#2819C, IRGKangXi=1235.081, RSKangXi=157.13
2819D CJK UNIFIED IDEOGRAPH-#2819D, IRGKangXi=1235.081, RSKangXi=157.13
2819E CJK UNIFIED IDEOGRAPH-#2819E, IRGKangXi=1235.081, RSKangXi=157.13
2819F CJK UNIFIED IDEOGRAPH-#2819F, IRGKangXi=1235.081, RSKangXi=157.13
281A0 CJK UNIFIED IDEOGRAPH-#281A0, IRGKangXi=1235.081, RSKangXi=157.13
281A1 CJK UNIFIED IDEOGRAPH-#281A1, IRGKangXi=1235.081, RSKangXi=157.13
281A2 CJK UNIFIED IDEOGRAPH-#281A2, IRGKangXi=1235.081, RSKangXi=157.13
281A3 CJK UNIFIED IDEOGRAPH-#281A3, IRGKangXi=1235.081, RSKangXi=157.13
281A4 CJK UNIFIED IDEOGRAPH-#281A4, IRGKangXi=1235.081, RSKangXi=157.13
281A5 CJK UNIFIED IDEOGRAPH-#281A5, IRGKangXi=1235.081, RSKangXi=157.13
281A6 CJK UNIFIED IDEOGRAPH-#281A6, IRGKangXi=1235.081, RSKangXi=157.13
281A7 CJK UNIFIED IDEOGRAPH-#281A7, IRGKangXi=1235.081, RSKangXi=157.13
281A8 CJK UNIFIED IDEOGRAPH-#281A8, IRGKangXi=1235.081, RSKangXi=157.13
281A9 CJK UNIFIED IDEOGRAPH-#281A9, IRGKangXi=1235.081, RSKangXi=157.13
281AA CJK UNIFIED IDEOGRAPH-#281AA, IRGKangXi=1235.100, RSKangXi=157.14, Def{(Cant.) to press down or push out with the foot}
281AB CJK UNIFIED IDEOGRAPH-#281AB, IRGKangXi=1235.110, RSKangXi=157.14
281AC CJK UNIFIED IDEOGRAPH-#281AC, IRGKangXi=1235.120, RSKangXi=157.14
281AD CJK UNIFIED IDEOGRAPH-#281AD, IRGKangXi=1235.130, RSKangXi=157.14
281AE CJK UNIFIED IDEOGRAPH-#281AE, IRGKangXi=1235.150, RSKangXi=157.14
281AF CJK UNIFIED IDEOGRAPH-#281AF, IRGKangXi=1235.210, RSKangXi=157.14, Def{(Cant.) to lie prone, bend over}
281B0 CJK UNIFIED IDEOGRAPH-#281B0, IRGKangXi=1235.220, RSKangXi=157.14
281B1 CJK UNIFIED IDEOGRAPH-#281B1, IRGKangXi=1235.240, RSKangXi=157.14
281B2 CJK UNIFIED IDEOGRAPH-#281B2, IRGKangXi=1235.250, RSKangXi=157.14
281B3 CJK UNIFIED IDEOGRAPH-#281B3, IRGKangXi=1235.270, RSKangXi=157.14
281B4 CJK UNIFIED IDEOGRAPH-#281B4, IRGKangXi=1235.280, RSKangXi=157.14
281B5 CJK UNIFIED IDEOGRAPH-#281B5, IRGKangXi=1235.300, RSKangXi=157.14
281B6 CJK UNIFIED IDEOGRAPH-#281B6, IRGKangXi=1235.301, RSKangXi=157.14
281B7 CJK UNIFIED IDEOGRAPH-#281B7, IRGKangXi=1235.301, RSKangXi=157.14
281B8 CJK UNIFIED IDEOGRAPH-#281B8, IRGKangXi=1235.301, RSKangXi=157.14
281B9 CJK UNIFIED IDEOGRAPH-#281B9, IRGKangXi=1235.301, RSKangXi=157.14
281BA CJK UNIFIED IDEOGRAPH-#281BA, IRGKangXi=1235.301, RSKangXi=157.14
281BB CJK UNIFIED IDEOGRAPH-#281BB, IRGKangXi=1235.301, RSKangXi=157.14
281BC CJK UNIFIED IDEOGRAPH-#281BC, IRGKangXi=1235.301, RSKangXi=157.14
281BD CJK UNIFIED IDEOGRAPH-#281BD, IRGKangXi=1235.301, RSKangXi=157.14
281BE CJK UNIFIED IDEOGRAPH-#281BE, IRGKangXi=1235.301, RSKangXi=157.14
281BF CJK UNIFIED IDEOGRAPH-#281BF, IRGKangXi=1235.301, RSKangXi=157.14
281C0 CJK UNIFIED IDEOGRAPH-#281C0, IRGKangXi=1235.301, RSKangXi=157.14
281C1 CJK UNIFIED IDEOGRAPH-#281C1, IRGKangXi=1235.310, RSKangXi=157.15
281C2 CJK UNIFIED IDEOGRAPH-#281C2, IRGKangXi=1235.320, RSKangXi=157.15
281C3 CJK UNIFIED IDEOGRAPH-#281C3, IRGKangXi=1235.350, RSKangXi=157.15
281C4 CJK UNIFIED IDEOGRAPH-#281C4, IRGKangXi=1235.370, RSKangXi=157.15
281C5 CJK UNIFIED IDEOGRAPH-#281C5, IRGKangXi=1235.390, RSKangXi=157.15
281C6 CJK UNIFIED IDEOGRAPH-#281C6, IRGKangXi=1235.420, RSKangXi=157.15
281C7 CJK UNIFIED IDEOGRAPH-#281C7, IRGKangXi=1235.450, RSKangXi=157.15
281C8 CJK UNIFIED IDEOGRAPH-#281C8, IRGKangXi=1235.460, RSKangXi=157.15
281C9 CJK UNIFIED IDEOGRAPH-#281C9, IRGKangXi=1235.461, RSKangXi=157.15
281CA CJK UNIFIED IDEOGRAPH-#281CA, IRGKangXi=1235.461, RSKangXi=157.15
281CB CJK UNIFIED IDEOGRAPH-#281CB, IRGKangXi=1235.461, RSKangXi=157.15
281CC CJK UNIFIED IDEOGRAPH-#281CC, IRGKangXi=1235.461, RSKangXi=157.15
281CD CJK UNIFIED IDEOGRAPH-#281CD, IRGKangXi=1235.461, RSKangXi=157.15
281CE CJK UNIFIED IDEOGRAPH-#281CE, IRGKangXi=1235.461, RSKangXi=157.15
281CF CJK UNIFIED IDEOGRAPH-#281CF, IRGKangXi=1235.461, RSKangXi=157.15
281D0 CJK UNIFIED IDEOGRAPH-#281D0, IRGKangXi=1235.461, RSKangXi=157.15
281D1 CJK UNIFIED IDEOGRAPH-#281D1, IRGKangXi=1235.461, RSKangXi=157.15
281D2 CJK UNIFIED IDEOGRAPH-#281D2, IRGKangXi=1235.461, RSKangXi=157.15
281D3 CJK UNIFIED IDEOGRAPH-#281D3, IRGKangXi=1235.461, RSKangXi=157.15
281D4 CJK UNIFIED IDEOGRAPH-#281D4, IRGKangXi=1235.461, RSKangXi=157.15
281D5 CJK UNIFIED IDEOGRAPH-#281D5, IRGKangXi=1235.461, RSKangXi=157.15
281D6 CJK UNIFIED IDEOGRAPH-#281D6, IRGKangXi=1236.050, RSKangXi=157.16
281D7 CJK UNIFIED IDEOGRAPH-#281D7, IRGKangXi=1236.070, RSKangXi=157.16
281D8 CJK UNIFIED IDEOGRAPH-#281D8, IRGKangXi=1236.090, RSKangXi=157.16
281D9 CJK UNIFIED IDEOGRAPH-#281D9, IRGKangXi=1236.100, RSKangXi=157.16
281DA CJK UNIFIED IDEOGRAPH-#281DA, IRGKangXi=1236.110, RSKangXi=157.16
281DB CJK UNIFIED IDEOGRAPH-#281DB, IRGKangXi=1236.111, RSKangXi=157.16
281DC CJK UNIFIED IDEOGRAPH-#281DC, IRGKangXi=1236.111, RSKangXi=157.16
281DD CJK UNIFIED IDEOGRAPH-#281DD, IRGKangXi=1236.111, RSKangXi=157.16
281DE CJK UNIFIED IDEOGRAPH-#281DE, IRGKangXi=1236.111, RSKangXi=157.16
281DF CJK UNIFIED IDEOGRAPH-#281DF, IRGKangXi=1236.111, RSKangXi=157.16
281E0 CJK UNIFIED IDEOGRAPH-#281E0, IRGKangXi=1236.111, RSKangXi=157.16
281E1 CJK UNIFIED IDEOGRAPH-#281E1, IRGKangXi=1236.111, RSKangXi=157.16
281E2 CJK UNIFIED IDEOGRAPH-#281E2, IRGKangXi=1236.111, RSKangXi=157.16
281E3 CJK UNIFIED IDEOGRAPH-#281E3, IRGKangXi=1236.111, RSKangXi=157.16
281E4 CJK UNIFIED IDEOGRAPH-#281E4, IRGKangXi=1236.130, RSKangXi=157.17
281E5 CJK UNIFIED IDEOGRAPH-#281E5, IRGKangXi=1236.140, RSKangXi=157.17
281E6 CJK UNIFIED IDEOGRAPH-#281E6, IRGKangXi=1236.150, RSKangXi=157.17
281E7 CJK UNIFIED IDEOGRAPH-#281E7, IRGKangXi=1236.170, RSKangXi=157.17
281E8 CJK UNIFIED IDEOGRAPH-#281E8, IRGKangXi=1236.210, RSKangXi=157.17
281E9 CJK UNIFIED IDEOGRAPH-#281E9, IRGKangXi=1236.220, RSKangXi=157.17
281EA CJK UNIFIED IDEOGRAPH-#281EA, IRGKangXi=1236.230, RSKangXi=157.17
281EB CJK UNIFIED IDEOGRAPH-#281EB, IRGKangXi=1236.240, RSKangXi=157.17
281EC CJK UNIFIED IDEOGRAPH-#281EC, IRGKangXi=1236.241, RSKangXi=157.17
281ED CJK UNIFIED IDEOGRAPH-#281ED, IRGKangXi=1236.241, RSKangXi=157.17
281EE CJK UNIFIED IDEOGRAPH-#281EE, IRGKangXi=1236.250, RSKangXi=157.18
281EF CJK UNIFIED IDEOGRAPH-#281EF, IRGKangXi=1236.280, RSKangXi=157.18
281F0 CJK UNIFIED IDEOGRAPH-#281F0, IRGKangXi=1236.290, RSKangXi=157.18
281F1 CJK UNIFIED IDEOGRAPH-#281F1, IRGKangXi=1236.310, RSKangXi=157.18
281F2 CJK UNIFIED IDEOGRAPH-#281F2, IRGKangXi=1236.340, RSKangXi=157.18
281F3 CJK UNIFIED IDEOGRAPH-#281F3, IRGKangXi=1236.350, RSKangXi=157.18
281F4 CJK UNIFIED IDEOGRAPH-#281F4, IRGKangXi=1236.351, RSKangXi=157.18
281F5 CJK UNIFIED IDEOGRAPH-#281F5, IRGKangXi=1236.351, RSKangXi=157.18
281F6 CJK UNIFIED IDEOGRAPH-#281F6, IRGKangXi=1236.351, RSKangXi=157.18
281F7 CJK UNIFIED IDEOGRAPH-#281F7, IRGKangXi=1236.351, RSKangXi=157.18
281F8 CJK UNIFIED IDEOGRAPH-#281F8, IRGKangXi=1236.351, RSKangXi=157.18
281F9 CJK UNIFIED IDEOGRAPH-#281F9, IRGKangXi=1236.351, RSKangXi=157.18
281FA CJK UNIFIED IDEOGRAPH-#281FA, IRGKangXi=1236.351, RSKangXi=157.18
281FB CJK UNIFIED IDEOGRAPH-#281FB, IRGKangXi=1236.360, RSKangXi=157.19
281FC CJK UNIFIED IDEOGRAPH-#281FC, IRGKangXi=1236.370, RSKangXi=157.19
281FD CJK UNIFIED IDEOGRAPH-#281FD, IRGKangXi=1236.380, RSKangXi=157.19
281FE CJK UNIFIED IDEOGRAPH-#281FE, IRGKangXi=1236.401, RSKangXi=157.19
281FF CJK UNIFIED IDEOGRAPH-#281FF, IRGKangXi=1236.401, RSKangXi=157.19
28200 CJK UNIFIED IDEOGRAPH-#28200, IRGKangXi=1236.401, RSKangXi=157.19
28201 CJK UNIFIED IDEOGRAPH-#28201, IRGKangXi=1236.431, RSKangXi=157.20
28202 CJK UNIFIED IDEOGRAPH-#28202, IRGKangXi=1236.431, RSKangXi=157.20
28203 CJK UNIFIED IDEOGRAPH-#28203, IRGKangXi=1236.431, RSKangXi=157.20
28204 CJK UNIFIED IDEOGRAPH-#28204, IRGKangXi=1236.450, RSKangXi=157.21
28205 CJK UNIFIED IDEOGRAPH-#28205, IRGKangXi=1236.460, RSKangXi=157.21
28206 CJK UNIFIED IDEOGRAPH-#28206, IRGKangXi=1236.461, RSKangXi=157.21
28207 CJK UNIFIED IDEOGRAPH-#28207, IRGKangXi=1236.461, RSKangXi=157.21, Def{(Cant.) to step over, step across}
28208 CJK UNIFIED IDEOGRAPH-#28208, IRGKangXi=1236.470, RSKangXi=157.22
28209 CJK UNIFIED IDEOGRAPH-#28209, IRGKangXi=1236.480, RSKangXi=157.22
2820A CJK UNIFIED IDEOGRAPH-#2820A, IRGKangXi=1236.481, RSKangXi=157.22
2820B CJK UNIFIED IDEOGRAPH-#2820B, IRGKangXi=1236.490, RSKangXi=157.23
2820C CJK UNIFIED IDEOGRAPH-#2820C, IRGKangXi=1236.491, RSKangXi=157.23
2820D CJK UNIFIED IDEOGRAPH-#2820D, IRGKangXi=1236.491, RSKangXi=157.24
2820E CJK UNIFIED IDEOGRAPH-#2820E, IRGKangXi=1236.491, RSKangXi=157.30
2820F CJK UNIFIED IDEOGRAPH-#2820F, IRGKangXi=1237.011, RSKangXi=158.0
28210 CJK UNIFIED IDEOGRAPH-#28210, IRGKangXi=1237.020, RSKangXi=158.-2
28211 CJK UNIFIED IDEOGRAPH-#28211, IRGKangXi=1237.030, RSKangXi=158.-1
28212 CJK UNIFIED IDEOGRAPH-#28212, IRGKangXi=1237.031, RSKangXi=158.2
28213 CJK UNIFIED IDEOGRAPH-#28213, IRGKangXi=1237.050, RSKangXi=158.3
28214 CJK UNIFIED IDEOGRAPH-#28214, IRGKangXi=1237.060, RSKangXi=158.3
28215 CJK UNIFIED IDEOGRAPH-#28215, IRGKangXi=1237.070, RSKangXi=158.3
28216 CJK UNIFIED IDEOGRAPH-#28216, IRGKangXi=1237.071, RSKangXi=158.3
28217 CJK UNIFIED IDEOGRAPH-#28217, IRGKangXi=1237.071, RSKangXi=158.3
28218 CJK UNIFIED IDEOGRAPH-#28218, IRGKangXi=1237.080, RSKangXi=158.4
28219 CJK UNIFIED IDEOGRAPH-#28219, IRGKangXi=1237.090, RSKangXi=158.4
2821A CJK UNIFIED IDEOGRAPH-#2821A, IRGKangXi=1237.100, RSKangXi=158.4, Def{weak}
2821B CJK UNIFIED IDEOGRAPH-#2821B, IRGKangXi=1237.110, RSKangXi=158.4
2821C CJK UNIFIED IDEOGRAPH-#2821C, IRGKangXi=1237.120, RSKangXi=158.4
2821D CJK UNIFIED IDEOGRAPH-#2821D, IRGKangXi=1237.140, RSKangXi=158.4
2821E CJK UNIFIED IDEOGRAPH-#2821E, IRGKangXi=1237.150, RSKangXi=158.4
2821F CJK UNIFIED IDEOGRAPH-#2821F, IRGKangXi=1237.160, RSKangXi=158.4
28220 CJK UNIFIED IDEOGRAPH-#28220, IRGKangXi=1237.170, RSKangXi=158.4
28221 CJK UNIFIED IDEOGRAPH-#28221, IRGKangXi=1237.180, RSKangXi=158.4
28222 CJK UNIFIED IDEOGRAPH-#28222, IRGKangXi=1237.190, RSKangXi=158.4
28223 CJK UNIFIED IDEOGRAPH-#28223, IRGKangXi=1237.191, RSKangXi=158.4
28224 CJK UNIFIED IDEOGRAPH-#28224, IRGKangXi=1237.191, RSKangXi=158.4
28225 CJK UNIFIED IDEOGRAPH-#28225, IRGKangXi=1237.191, RSKangXi=158.4
28226 CJK UNIFIED IDEOGRAPH-#28226, IRGKangXi=1237.191, RSKangXi=158.4
28227 CJK UNIFIED IDEOGRAPH-#28227, IRGKangXi=1237.191, RSKangXi=158.4
28228 CJK UNIFIED IDEOGRAPH-#28228, IRGKangXi=1237.191, RSKangXi=158.4
28229 CJK UNIFIED IDEOGRAPH-#28229, IRGKangXi=1237.210, RSKangXi=158.5
2822A CJK UNIFIED IDEOGRAPH-#2822A, IRGKangXi=1237.220, RSKangXi=158.5
2822B CJK UNIFIED IDEOGRAPH-#2822B, IRGKangXi=1237.240, RSKangXi=158.5
2822C CJK UNIFIED IDEOGRAPH-#2822C, IRGKangXi=1237.270, RSKangXi=158.5
2822D CJK UNIFIED IDEOGRAPH-#2822D, IRGKangXi=1237.280, RSKangXi=158.5
2822E CJK UNIFIED IDEOGRAPH-#2822E, IRGKangXi=1237.310, RSKangXi=158.5
2822F CJK UNIFIED IDEOGRAPH-#2822F, IRGKangXi=1237.311, RSKangXi=158.5
28230 CJK UNIFIED IDEOGRAPH-#28230, IRGKangXi=1237.311, RSKangXi=158.5
28231 CJK UNIFIED IDEOGRAPH-#28231, IRGKangXi=1237.311, RSKangXi=158.5
28232 CJK UNIFIED IDEOGRAPH-#28232, IRGKangXi=1237.311, RSKangXi=158.5
28233 CJK UNIFIED IDEOGRAPH-#28233, IRGKangXi=1237.311, RSKangXi=158.5
28234 CJK UNIFIED IDEOGRAPH-#28234, IRGKangXi=1237.311, RSKangXi=158.5
28235 CJK UNIFIED IDEOGRAPH-#28235, IRGKangXi=1237.311, RSKangXi=158.5
28236 CJK UNIFIED IDEOGRAPH-#28236, IRGKangXi=1237.311, RSKangXi=158.5
28237 CJK UNIFIED IDEOGRAPH-#28237, IRGKangXi=1237.311, RSKangXi=158.5
28238 CJK UNIFIED IDEOGRAPH-#28238, IRGKangXi=1237.320, RSKangXi=158.6
28239 CJK UNIFIED IDEOGRAPH-#28239, IRGKangXi=1237.340, RSKangXi=158.6
2823A CJK UNIFIED IDEOGRAPH-#2823A, IRGKangXi=1237.390, RSKangXi=158.6
2823B CJK UNIFIED IDEOGRAPH-#2823B, IRGKangXi=1237.400, RSKangXi=158.6
2823C CJK UNIFIED IDEOGRAPH-#2823C, IRGKangXi=1237.410, RSKangXi=158.6
2823D CJK UNIFIED IDEOGRAPH-#2823D, IRGKangXi=1237.411, RSKangXi=158.6
2823E CJK UNIFIED IDEOGRAPH-#2823E, IRGKangXi=1237.411, RSKangXi=158.6
2823F CJK UNIFIED IDEOGRAPH-#2823F, IRGKangXi=1237.411, RSKangXi=158.6
28240 CJK UNIFIED IDEOGRAPH-#28240, IRGKangXi=1237.411, RSKangXi=158.6
28241 CJK UNIFIED IDEOGRAPH-#28241, IRGKangXi=1237.411, RSKangXi=158.6
28242 CJK UNIFIED IDEOGRAPH-#28242, IRGKangXi=1237.411, RSKangXi=158.6
28243 CJK UNIFIED IDEOGRAPH-#28243, IRGKangXi=1237.411, RSKangXi=158.6
28244 CJK UNIFIED IDEOGRAPH-#28244, IRGKangXi=1237.411, RSKangXi=158.6
28245 CJK UNIFIED IDEOGRAPH-#28245, IRGKangXi=1237.411, RSKangXi=158.6
28246 CJK UNIFIED IDEOGRAPH-#28246, IRGKangXi=1237.411, RSKangXi=158.6
28247 CJK UNIFIED IDEOGRAPH-#28247, IRGKangXi=1237.411, RSKangXi=158.6
28248 CJK UNIFIED IDEOGRAPH-#28248, IRGKangXi=1237.420, RSKangXi=158.7
28249 CJK UNIFIED IDEOGRAPH-#28249, IRGKangXi=1237.450, RSKangXi=158.7, Def{weak}
2824A CJK UNIFIED IDEOGRAPH-#2824A, IRGKangXi=1237.460, RSKangXi=158.7
2824B CJK UNIFIED IDEOGRAPH-#2824B, IRGKangXi=1237.470, RSKangXi=158.7
2824C CJK UNIFIED IDEOGRAPH-#2824C, IRGKangXi=1237.480, RSKangXi=158.7
2824D CJK UNIFIED IDEOGRAPH-#2824D, IRGKangXi=1237.490, RSKangXi=158.7
2824E CJK UNIFIED IDEOGRAPH-#2824E, IRGKangXi=1237.491, RSKangXi=158.7
2824F CJK UNIFIED IDEOGRAPH-#2824F, IRGKangXi=1237.491, RSKangXi=158.7
28250 CJK UNIFIED IDEOGRAPH-#28250, IRGKangXi=1237.491, RSKangXi=158.7
28251 CJK UNIFIED IDEOGRAPH-#28251, IRGKangXi=1237.491, RSKangXi=158.7
28252 CJK UNIFIED IDEOGRAPH-#28252, IRGKangXi=1237.491, RSKangXi=158.7
28253 CJK UNIFIED IDEOGRAPH-#28253, IRGKangXi=1237.491, RSKangXi=158.7
28254 CJK UNIFIED IDEOGRAPH-#28254, IRGKangXi=1237.520, RSKangXi=158.8
28255 CJK UNIFIED IDEOGRAPH-#28255, IRGKangXi=1237.560, RSKangXi=158.8
28256 CJK UNIFIED IDEOGRAPH-#28256, IRGKangXi=1237.570, RSKangXi=169.7, Def{(Cant.) to hide oneself}
28257 CJK UNIFIED IDEOGRAPH-#28257, IRGKangXi=1237.580, RSKangXi=158.8
28258 CJK UNIFIED IDEOGRAPH-#28258, IRGKangXi=1237.581, RSKangXi=158.8
28259 CJK UNIFIED IDEOGRAPH-#28259, IRGKangXi=1237.581, RSKangXi=158.8
2825A CJK UNIFIED IDEOGRAPH-#2825A, IRGKangXi=1237.581, RSKangXi=158.8
2825B CJK UNIFIED IDEOGRAPH-#2825B, IRGKangXi=1237.581, RSKangXi=158.8
2825C CJK UNIFIED IDEOGRAPH-#2825C, IRGKangXi=1237.581, RSKangXi=158.8
2825D CJK UNIFIED IDEOGRAPH-#2825D, IRGKangXi=1237.581, RSKangXi=158.8
2825E CJK UNIFIED IDEOGRAPH-#2825E, IRGKangXi=1237.581, RSKangXi=158.8
2825F CJK UNIFIED IDEOGRAPH-#2825F, IRGKangXi=1237.581, RSKangXi=158.8
28260 CJK UNIFIED IDEOGRAPH-#28260, IRGKangXi=1237.581, RSKangXi=158.8
28261 CJK UNIFIED IDEOGRAPH-#28261, IRGKangXi=1237.581, RSKangXi=158.8
28262 CJK UNIFIED IDEOGRAPH-#28262, IRGKangXi=1237.590, RSKangXi=158.9
28263 CJK UNIFIED IDEOGRAPH-#28263, IRGKangXi=1237.620, RSKangXi=158.9
28264 CJK UNIFIED IDEOGRAPH-#28264, IRGKangXi=1237.630, RSKangXi=158.9
28265 CJK UNIFIED IDEOGRAPH-#28265, IRGKangXi=1237.640, RSKangXi=158.9
28266 CJK UNIFIED IDEOGRAPH-#28266, IRGKangXi=1237.650, RSKangXi=158.10
28267 CJK UNIFIED IDEOGRAPH-#28267, IRGKangXi=1237.651, RSKangXi=158.9
28268 CJK UNIFIED IDEOGRAPH-#28268, IRGKangXi=1237.651, RSKangXi=158.9
28269 CJK UNIFIED IDEOGRAPH-#28269, IRGKangXi=1237.651, RSKangXi=158.9
2826A CJK UNIFIED IDEOGRAPH-#2826A, IRGKangXi=1237.651, RSKangXi=158.9
2826B CJK UNIFIED IDEOGRAPH-#2826B, IRGKangXi=1237.651, RSKangXi=158.9
2826C CJK UNIFIED IDEOGRAPH-#2826C, IRGKangXi=1237.651, RSKangXi=158.9
2826D CJK UNIFIED IDEOGRAPH-#2826D, IRGKangXi=1237.651, RSKangXi=158.9
2826E CJK UNIFIED IDEOGRAPH-#2826E, IRGKangXi=1237.670, RSKangXi=158.10
2826F CJK UNIFIED IDEOGRAPH-#2826F, IRGKangXi=1237.680, RSKangXi=158.10
28270 CJK UNIFIED IDEOGRAPH-#28270, IRGKangXi=1238.010, RSKangXi=158.10
28271 CJK UNIFIED IDEOGRAPH-#28271, IRGKangXi=1238.020, RSKangXi=158.10
28272 CJK UNIFIED IDEOGRAPH-#28272, IRGKangXi=1238.021, RSKangXi=158.10
28273 CJK UNIFIED IDEOGRAPH-#28273, IRGKangXi=1238.021, RSKangXi=158.10
28274 CJK UNIFIED IDEOGRAPH-#28274, IRGKangXi=1238.021, RSKangXi=158.10
28275 CJK UNIFIED IDEOGRAPH-#28275, IRGKangXi=1238.021, RSKangXi=158.10
28276 CJK UNIFIED IDEOGRAPH-#28276, IRGKangXi=1238.021, RSKangXi=158.10
28277 CJK UNIFIED IDEOGRAPH-#28277, IRGKangXi=1238.021, RSKangXi=158.10
28278 CJK UNIFIED IDEOGRAPH-#28278, IRGKangXi=1238.021, RSKangXi=158.10
28279 CJK UNIFIED IDEOGRAPH-#28279, IRGKangXi=1238.030, RSKangXi=158.11
2827A CJK UNIFIED IDEOGRAPH-#2827A, IRGKangXi=1238.070, RSKangXi=158.11
2827B CJK UNIFIED IDEOGRAPH-#2827B, IRGKangXi=1238.071, RSKangXi=158.11
2827C CJK UNIFIED IDEOGRAPH-#2827C, IRGKangXi=1238.071, RSKangXi=158.11, Def{(Cant.) to stoop, bow}
2827D CJK UNIFIED IDEOGRAPH-#2827D, IRGKangXi=1238.071, RSKangXi=158.11
2827E CJK UNIFIED IDEOGRAPH-#2827E, IRGKangXi=1238.071, RSKangXi=158.11
2827F CJK UNIFIED IDEOGRAPH-#2827F, IRGKangXi=1238.100, RSKangXi=158.12
28280 CJK UNIFIED IDEOGRAPH-#28280, IRGKangXi=1238.130, RSKangXi=158.12
28281 CJK UNIFIED IDEOGRAPH-#28281, IRGKangXi=1238.140, RSKangXi=158.12
28282 CJK UNIFIED IDEOGRAPH-#28282, IRGKangXi=1238.141, RSKangXi=158.12
28283 CJK UNIFIED IDEOGRAPH-#28283, IRGKangXi=1238.141, RSKangXi=158.12
28284 CJK UNIFIED IDEOGRAPH-#28284, IRGKangXi=1238.141, RSKangXi=158.12
28285 CJK UNIFIED IDEOGRAPH-#28285, IRGKangXi=1238.141, RSKangXi=158.12
28286 CJK UNIFIED IDEOGRAPH-#28286, IRGKangXi=1238.141, RSKangXi=158.12
28287 CJK UNIFIED IDEOGRAPH-#28287, IRGKangXi=1238.141, RSKangXi=158.12
28288 CJK UNIFIED IDEOGRAPH-#28288, IRGKangXi=1238.141, RSKangXi=158.12
28289 CJK UNIFIED IDEOGRAPH-#28289, IRGKangXi=1238.141, RSKangXi=158.12
2828A CJK UNIFIED IDEOGRAPH-#2828A, IRGKangXi=1238.141, RSKangXi=158.12
2828B CJK UNIFIED IDEOGRAPH-#2828B, IRGKangXi=1238.141, RSKangXi=158.12
2828C CJK UNIFIED IDEOGRAPH-#2828C, IRGKangXi=1238.141, RSKangXi=158.12
2828D CJK UNIFIED IDEOGRAPH-#2828D, IRGKangXi=1238.170, RSKangXi=158.13
2828E CJK UNIFIED IDEOGRAPH-#2828E, IRGKangXi=1238.180, RSKangXi=158.13
2828F CJK UNIFIED IDEOGRAPH-#2828F, IRGKangXi=1238.181, RSKangXi=158.13
28290 CJK UNIFIED IDEOGRAPH-#28290, IRGKangXi=1238.181, RSKangXi=158.13
28291 CJK UNIFIED IDEOGRAPH-#28291, IRGKangXi=1238.181, RSKangXi=158.13
28292 CJK UNIFIED IDEOGRAPH-#28292, IRGKangXi=1238.181, RSKangXi=158.13
28293 CJK UNIFIED IDEOGRAPH-#28293, IRGKangXi=1238.190, RSKangXi=158.14
28294 CJK UNIFIED IDEOGRAPH-#28294, IRGKangXi=1238.210, RSKangXi=158.14
28295 CJK UNIFIED IDEOGRAPH-#28295, IRGKangXi=1238.220, RSKangXi=158.14
28296 CJK UNIFIED IDEOGRAPH-#28296, IRGKangXi=1238.230, RSKangXi=158.14
28297 CJK UNIFIED IDEOGRAPH-#28297, IRGKangXi=1238.240, RSKangXi=158.14
28298 CJK UNIFIED IDEOGRAPH-#28298, IRGKangXi=1238.250, RSKangXi=158.15
28299 CJK UNIFIED IDEOGRAPH-#28299, IRGKangXi=1238.251, RSKangXi=158.15
2829A CJK UNIFIED IDEOGRAPH-#2829A, IRGKangXi=1238.251, RSKangXi=158.15
2829B CJK UNIFIED IDEOGRAPH-#2829B, IRGKangXi=1238.260, RSKangXi=158.16, Def{(Cant.) nude, naked}
2829C CJK UNIFIED IDEOGRAPH-#2829C, IRGKangXi=1238.271, RSKangXi=158.16
2829D CJK UNIFIED IDEOGRAPH-#2829D, IRGKangXi=1238.280, RSKangXi=158.18
2829E CJK UNIFIED IDEOGRAPH-#2829E, IRGKangXi=1238.281, RSKangXi=158.18
2829F CJK UNIFIED IDEOGRAPH-#2829F, IRGKangXi=1238.281, RSKangXi=158.19
282A0 CJK UNIFIED IDEOGRAPH-#282A0, IRGKangXi=1239.040, RSKangXi=159.2
282A1 CJK UNIFIED IDEOGRAPH-#282A1, IRGKangXi=1239.050, RSKangXi=159.2
282A2 CJK UNIFIED IDEOGRAPH-#282A2, IRGKangXi=1239.090, RSKangXi=159.2
282A3 CJK UNIFIED IDEOGRAPH-#282A3, IRGKangXi=1239.131, RSKangXi=159.2
282A4 CJK UNIFIED IDEOGRAPH-#282A4, IRGKangXi=1239.131, RSKangXi=159.2
282A5 CJK UNIFIED IDEOGRAPH-#282A5, IRGKangXi=1239.131, RSKangXi=159.2
282A6 CJK UNIFIED IDEOGRAPH-#282A6, IRGKangXi=1239.131, RSKangXi=159.2
282A7 CJK UNIFIED IDEOGRAPH-#282A7, IRGKangXi=1240.010, RSKangXi=159.3
282A8 CJK UNIFIED IDEOGRAPH-#282A8, IRGKangXi=1240.061, RSKangXi=159.3
282A9 CJK UNIFIED IDEOGRAPH-#282A9, IRGKangXi=1240.061, RSKangXi=159.3
282AA CJK UNIFIED IDEOGRAPH-#282AA, IRGKangXi=1240.061, RSKangXi=159.3
282AB CJK UNIFIED IDEOGRAPH-#282AB, IRGKangXi=1240.061, RSKangXi=159.3
282AC CJK UNIFIED IDEOGRAPH-#282AC, IRGKangXi=1240.061, RSKangXi=159.3
282AD CJK UNIFIED IDEOGRAPH-#282AD, IRGKangXi=1240.061, RSKangXi=159.3
282AE CJK UNIFIED IDEOGRAPH-#282AE, IRGKangXi=1240.061, RSKangXi=159.3
282AF CJK UNIFIED IDEOGRAPH-#282AF, IRGKangXi=1240.061, RSKangXi=159.3
282B0 CJK UNIFIED IDEOGRAPH-#282B0, IRGKangXi=1240.061, RSKangXi=159.3
282B1 CJK UNIFIED IDEOGRAPH-#282B1, IRGKangXi=1240.061, RSKangXi=159.3
282B2 CJK UNIFIED IDEOGRAPH-#282B2, IRGKangXi=1240.061, RSKangXi=159.3
282B3 CJK UNIFIED IDEOGRAPH-#282B3, IRGKangXi=1240.090, RSKangXi=159.4
282B4 CJK UNIFIED IDEOGRAPH-#282B4, IRGKangXi=1240.130, RSKangXi=159.4
282B5 CJK UNIFIED IDEOGRAPH-#282B5, IRGKangXi=1240.180, RSKangXi=159.4
282B6 CJK UNIFIED IDEOGRAPH-#282B6, IRGKangXi=1240.190, RSKangXi=159.4
282B7 CJK UNIFIED IDEOGRAPH-#282B7, IRGKangXi=1240.270, RSKangXi=159.4
282B8 CJK UNIFIED IDEOGRAPH-#282B8, IRGKangXi=1240.280, RSKangXi=159.4
282B9 CJK UNIFIED IDEOGRAPH-#282B9, IRGKangXi=1240.290, RSKangXi=159.4
282BA CJK UNIFIED IDEOGRAPH-#282BA, IRGKangXi=1241.030, RSKangXi=159.4
282BB CJK UNIFIED IDEOGRAPH-#282BB, IRGKangXi=1241.050, RSKangXi=159.4
282BC CJK UNIFIED IDEOGRAPH-#282BC, IRGKangXi=1241.060, RSKangXi=159.4
282BD CJK UNIFIED IDEOGRAPH-#282BD, IRGKangXi=1241.070, RSKangXi=159.4
282BE CJK UNIFIED IDEOGRAPH-#282BE, IRGKangXi=1241.080, RSKangXi=159.4
282BF CJK UNIFIED IDEOGRAPH-#282BF, IRGKangXi=1241.090, RSKangXi=159.4
282C0 CJK UNIFIED IDEOGRAPH-#282C0, IRGKangXi=1241.100, RSKangXi=159.4
282C1 CJK UNIFIED IDEOGRAPH-#282C1, IRGKangXi=1241.111, RSKangXi=159.4
282C2 CJK UNIFIED IDEOGRAPH-#282C2, IRGKangXi=1241.111, RSKangXi=159.4
282C3 CJK UNIFIED IDEOGRAPH-#282C3, IRGKangXi=1241.111, RSKangXi=159.4
282C4 CJK UNIFIED IDEOGRAPH-#282C4, IRGKangXi=1241.111, RSKangXi=159.4
282C5 CJK UNIFIED IDEOGRAPH-#282C5, IRGKangXi=1241.111, RSKangXi=159.4
282C6 CJK UNIFIED IDEOGRAPH-#282C6, IRGKangXi=1241.111, RSKangXi=159.4
282C7 CJK UNIFIED IDEOGRAPH-#282C7, IRGKangXi=1241.111, RSKangXi=159.4
282C8 CJK UNIFIED IDEOGRAPH-#282C8, IRGKangXi=1241.111, RSKangXi=159.4
282C9 CJK UNIFIED IDEOGRAPH-#282C9, IRGKangXi=1241.111, RSKangXi=159.4
282CA CJK UNIFIED IDEOGRAPH-#282CA, IRGKangXi=1241.111, RSKangXi=159.4
282CB CJK UNIFIED IDEOGRAPH-#282CB, IRGKangXi=1241.111, RSKangXi=159.4
282CC CJK UNIFIED IDEOGRAPH-#282CC, IRGKangXi=1241.111, RSKangXi=159.4
282CD CJK UNIFIED IDEOGRAPH-#282CD, IRGKangXi=1241.111, RSKangXi=159.4, Def{(Cant.) a van}
282CE CJK UNIFIED IDEOGRAPH-#282CE, IRGKangXi=1241.210, RSKangXi=159.5
282CF CJK UNIFIED IDEOGRAPH-#282CF, IRGKangXi=1241.220, RSKangXi=159.5
282D0 CJK UNIFIED IDEOGRAPH-#282D0, IRGKangXi=1241.250, RSKangXi=159.5
282D1 CJK UNIFIED IDEOGRAPH-#282D1, IRGKangXi=1241.290, RSKangXi=159.5
282D2 CJK UNIFIED IDEOGRAPH-#282D2, IRGKangXi=1241.300, RSKangXi=159.5
282D3 CJK UNIFIED IDEOGRAPH-#282D3, IRGKangXi=1241.340, RSKangXi=159.5
282D4 CJK UNIFIED IDEOGRAPH-#282D4, IRGKangXi=1242.010, RSKangXi=159.5
282D5 CJK UNIFIED IDEOGRAPH-#282D5, IRGKangXi=1242.020, RSKangXi=159.5
282D6 CJK UNIFIED IDEOGRAPH-#282D6, IRGKangXi=1242.030, RSKangXi=159.5
282D7 CJK UNIFIED IDEOGRAPH-#282D7, IRGKangXi=1242.070, RSKangXi=159.5
282D8 CJK UNIFIED IDEOGRAPH-#282D8, IRGKangXi=1242.090, RSKangXi=159.5
282D9 CJK UNIFIED IDEOGRAPH-#282D9, IRGKangXi=1242.110, RSKangXi=159.5
282DA CJK UNIFIED IDEOGRAPH-#282DA, IRGKangXi=1242.140, RSKangXi=159.5
282DB CJK UNIFIED IDEOGRAPH-#282DB, IRGKangXi=1242.170, RSKangXi=159.5
282DC CJK UNIFIED IDEOGRAPH-#282DC, IRGKangXi=1242.191, RSKangXi=159.5
282DD CJK UNIFIED IDEOGRAPH-#282DD, IRGKangXi=1242.191, RSKangXi=159.5
282DE CJK UNIFIED IDEOGRAPH-#282DE, IRGKangXi=1242.191, RSKangXi=159.5
282DF CJK UNIFIED IDEOGRAPH-#282DF, IRGKangXi=1242.191, RSKangXi=159.5
282E0 CJK UNIFIED IDEOGRAPH-#282E0, IRGKangXi=1242.191, RSKangXi=159.5
282E1 CJK UNIFIED IDEOGRAPH-#282E1, IRGKangXi=1242.191, RSKangXi=159.5
282E2 CJK UNIFIED IDEOGRAPH-#282E2, IRGKangXi=1242.191, RSKangXi=159.5, Def{(Cant.) an elevator (from the British 'lift')}
282E3 CJK UNIFIED IDEOGRAPH-#282E3, IRGKangXi=1242.191, RSKangXi=159.5
282E4 CJK UNIFIED IDEOGRAPH-#282E4, IRGKangXi=1242.191, RSKangXi=159.5
282E5 CJK UNIFIED IDEOGRAPH-#282E5, IRGKangXi=1242.191, RSKangXi=159.5
282E6 CJK UNIFIED IDEOGRAPH-#282E6, IRGKangXi=1242.191, RSKangXi=159.5
282E7 CJK UNIFIED IDEOGRAPH-#282E7, IRGKangXi=1242.191, RSKangXi=159.5
282E8 CJK UNIFIED IDEOGRAPH-#282E8, IRGKangXi=1242.260, RSKangXi=159.6
282E9 CJK UNIFIED IDEOGRAPH-#282E9, IRGKangXi=1242.270, RSKangXi=159.6
282EA CJK UNIFIED IDEOGRAPH-#282EA, IRGKangXi=1242.280, RSKangXi=159.6
282EB CJK UNIFIED IDEOGRAPH-#282EB, IRGKangXi=1242.290, RSKangXi=159.6
282EC CJK UNIFIED IDEOGRAPH-#282EC, IRGKangXi=1242.300, RSKangXi=159.6
282ED CJK UNIFIED IDEOGRAPH-#282ED, IRGKangXi=1243.010, RSKangXi=159.6
282EE CJK UNIFIED IDEOGRAPH-#282EE, IRGKangXi=1243.040, RSKangXi=159.6
282EF CJK UNIFIED IDEOGRAPH-#282EF, IRGKangXi=1243.080, RSKangXi=159.6, Def{potholes}
282F0 CJK UNIFIED IDEOGRAPH-#282F0, IRGKangXi=1243.090, RSKangXi=159.6
282F1 CJK UNIFIED IDEOGRAPH-#282F1, IRGKangXi=1243.100, RSKangXi=159.6
282F2 CJK UNIFIED IDEOGRAPH-#282F2, IRGKangXi=1243.140, RSKangXi=159.6
282F3 CJK UNIFIED IDEOGRAPH-#282F3, IRGKangXi=1243.151, RSKangXi=159.6
282F4 CJK UNIFIED IDEOGRAPH-#282F4, IRGKangXi=1243.151, RSKangXi=159.6
282F5 CJK UNIFIED IDEOGRAPH-#282F5, IRGKangXi=1243.151, RSKangXi=159.6
282F6 CJK UNIFIED IDEOGRAPH-#282F6, IRGKangXi=1243.151, RSKangXi=159.6
282F7 CJK UNIFIED IDEOGRAPH-#282F7, IRGKangXi=1243.151, RSKangXi=159.6
282F8 CJK UNIFIED IDEOGRAPH-#282F8, IRGKangXi=1243.151, RSKangXi=159.6
282F9 CJK UNIFIED IDEOGRAPH-#282F9, IRGKangXi=1243.151, RSKangXi=159.6
282FA CJK UNIFIED IDEOGRAPH-#282FA, IRGKangXi=1243.151, RSKangXi=159.6
282FB CJK UNIFIED IDEOGRAPH-#282FB, IRGKangXi=1243.151, RSKangXi=159.6
282FC CJK UNIFIED IDEOGRAPH-#282FC, IRGKangXi=1243.151, RSKangXi=159.6
282FD CJK UNIFIED IDEOGRAPH-#282FD, IRGKangXi=1243.151, RSKangXi=159.6
282FE CJK UNIFIED IDEOGRAPH-#282FE, IRGKangXi=1243.151, RSKangXi=159.6
282FF CJK UNIFIED IDEOGRAPH-#282FF, IRGKangXi=1243.151, RSKangXi=159.6
28300 CJK UNIFIED IDEOGRAPH-#28300, IRGKangXi=1243.151, RSKangXi=159.6
28301 CJK UNIFIED IDEOGRAPH-#28301, IRGKangXi=1243.151, RSKangXi=159.6
28302 CJK UNIFIED IDEOGRAPH-#28302, IRGKangXi=1243.160, RSKangXi=159.7
28303 CJK UNIFIED IDEOGRAPH-#28303, IRGKangXi=1243.170, RSKangXi=159.7
28304 CJK UNIFIED IDEOGRAPH-#28304, IRGKangXi=1243.180, RSKangXi=159.7
28305 CJK UNIFIED IDEOGRAPH-#28305, IRGKangXi=1243.190, RSKangXi=159.7
28306 CJK UNIFIED IDEOGRAPH-#28306, IRGKangXi=1243.210, RSKangXi=159.7
28307 CJK UNIFIED IDEOGRAPH-#28307, IRGKangXi=1243.250, RSKangXi=159.7
28308 CJK UNIFIED IDEOGRAPH-#28308, IRGKangXi=1243.260, RSKangXi=159.7
28309 CJK UNIFIED IDEOGRAPH-#28309, IRGKangXi=1243.270, RSKangXi=159.7
2830A CJK UNIFIED IDEOGRAPH-#2830A, IRGKangXi=1244.010, RSKangXi=159.7
2830B CJK UNIFIED IDEOGRAPH-#2830B, IRGKangXi=1244.030, RSKangXi=159.7
2830C CJK UNIFIED IDEOGRAPH-#2830C, IRGKangXi=1244.040, RSKangXi=159.7
2830D CJK UNIFIED IDEOGRAPH-#2830D, IRGKangXi=1244.070, RSKangXi=159.7
2830E CJK UNIFIED IDEOGRAPH-#2830E, IRGKangXi=1244.080, RSKangXi=159.7
2830F CJK UNIFIED IDEOGRAPH-#2830F, IRGKangXi=1244.111, RSKangXi=159.7
28310 CJK UNIFIED IDEOGRAPH-#28310, IRGKangXi=1244.111, RSKangXi=159.7
28311 CJK UNIFIED IDEOGRAPH-#28311, IRGKangXi=1244.111, RSKangXi=159.7
28312 CJK UNIFIED IDEOGRAPH-#28312, IRGKangXi=1244.111, RSKangXi=159.7
28313 CJK UNIFIED IDEOGRAPH-#28313, IRGKangXi=1244.111, RSKangXi=159.7
28314 CJK UNIFIED IDEOGRAPH-#28314, IRGKangXi=1244.111, RSKangXi=159.7
28315 CJK UNIFIED IDEOGRAPH-#28315, IRGKangXi=1244.111, RSKangXi=159.7
28316 CJK UNIFIED IDEOGRAPH-#28316, IRGKangXi=1244.111, RSKangXi=159.7
28317 CJK UNIFIED IDEOGRAPH-#28317, IRGKangXi=1244.111, RSKangXi=159.7
28318 CJK UNIFIED IDEOGRAPH-#28318, IRGKangXi=1244.111, RSKangXi=159.7
28319 CJK UNIFIED IDEOGRAPH-#28319, IRGKangXi=1244.111, RSKangXi=159.7
2831A CJK UNIFIED IDEOGRAPH-#2831A, IRGKangXi=1244.111, RSKangXi=159.7
2831B CJK UNIFIED IDEOGRAPH-#2831B, IRGKangXi=1244.111, RSKangXi=159.7
2831C CJK UNIFIED IDEOGRAPH-#2831C, IRGKangXi=1244.111, RSKangXi=159.7
2831D CJK UNIFIED IDEOGRAPH-#2831D, IRGKangXi=1244.111, RSKangXi=159.7
2831E CJK UNIFIED IDEOGRAPH-#2831E, IRGKangXi=1244.111, RSKangXi=159.7
2831F CJK UNIFIED IDEOGRAPH-#2831F, IRGKangXi=1244.111, RSKangXi=159.7
28320 CJK UNIFIED IDEOGRAPH-#28320, IRGKangXi=1244.120, RSKangXi=159.8
28321 CJK UNIFIED IDEOGRAPH-#28321, IRGKangXi=1244.180, RSKangXi=159.8
28322 CJK UNIFIED IDEOGRAPH-#28322, IRGKangXi=1244.200, RSKangXi=159.8
28323 CJK UNIFIED IDEOGRAPH-#28323, IRGKangXi=1244.230, RSKangXi=159.8
28324 CJK UNIFIED IDEOGRAPH-#28324, IRGKangXi=1244.240, RSKangXi=159.8
28325 CJK UNIFIED IDEOGRAPH-#28325, IRGKangXi=1244.250, RSKangXi=159.8
28326 CJK UNIFIED IDEOGRAPH-#28326, IRGKangXi=1244.290, RSKangXi=159.8
28327 CJK UNIFIED IDEOGRAPH-#28327, IRGKangXi=1244.340, RSKangXi=159.8
28328 CJK UNIFIED IDEOGRAPH-#28328, IRGKangXi=1244.350, RSKangXi=159.8
28329 CJK UNIFIED IDEOGRAPH-#28329, IRGKangXi=1244.360, RSKangXi=159.8, Def{a time; row}
2832A CJK UNIFIED IDEOGRAPH-#2832A, IRGKangXi=1244.370, RSKangXi=159.8
2832B CJK UNIFIED IDEOGRAPH-#2832B, IRGKangXi=1245.020, RSKangXi=159.8
2832C CJK UNIFIED IDEOGRAPH-#2832C, IRGKangXi=1245.030, RSKangXi=159.8
2832D CJK UNIFIED IDEOGRAPH-#2832D, IRGKangXi=1245.040, RSKangXi=159.8
2832E CJK UNIFIED IDEOGRAPH-#2832E, IRGKangXi=1245.050, RSKangXi=159.8
2832F CJK UNIFIED IDEOGRAPH-#2832F, IRGKangXi=1245.070, RSKangXi=159.8
28330 CJK UNIFIED IDEOGRAPH-#28330, IRGKangXi=1245.080, RSKangXi=159.8
28331 CJK UNIFIED IDEOGRAPH-#28331, IRGKangXi=1245.120, RSKangXi=159.8
28332 CJK UNIFIED IDEOGRAPH-#28332, IRGKangXi=1245.150, RSKangXi=159.8
28333 CJK UNIFIED IDEOGRAPH-#28333, IRGKangXi=1245.160, RSKangXi=159.8
28334 CJK UNIFIED IDEOGRAPH-#28334, IRGKangXi=1245.220, RSKangXi=159.8
28335 CJK UNIFIED IDEOGRAPH-#28335, IRGKangXi=1245.240, RSKangXi=159.8
28336 CJK UNIFIED IDEOGRAPH-#28336, IRGKangXi=1245.250, RSKangXi=159.8
28337 CJK UNIFIED IDEOGRAPH-#28337, IRGKangXi=1245.260, RSKangXi=159.8
28338 CJK UNIFIED IDEOGRAPH-#28338, IRGKangXi=1245.270, RSKangXi=159.8
28339 CJK UNIFIED IDEOGRAPH-#28339, IRGKangXi=1245.271, RSKangXi=159.8
2833A CJK UNIFIED IDEOGRAPH-#2833A, IRGKangXi=1245.271, RSKangXi=159.8
2833B CJK UNIFIED IDEOGRAPH-#2833B, IRGKangXi=1245.271, RSKangXi=159.8
2833C CJK UNIFIED IDEOGRAPH-#2833C, IRGKangXi=1245.271, RSKangXi=159.8
2833D CJK UNIFIED IDEOGRAPH-#2833D, IRGKangXi=1245.271, RSKangXi=159.8
2833E CJK UNIFIED IDEOGRAPH-#2833E, IRGKangXi=1245.271, RSKangXi=159.8
2833F CJK UNIFIED IDEOGRAPH-#2833F, IRGKangXi=1245.271, RSKangXi=159.8
28340 CJK UNIFIED IDEOGRAPH-#28340, IRGKangXi=1245.271, RSKangXi=159.8
28341 CJK UNIFIED IDEOGRAPH-#28341, IRGKangXi=1245.271, RSKangXi=159.8
28342 CJK UNIFIED IDEOGRAPH-#28342, IRGKangXi=1245.271, RSKangXi=159.8
28343 CJK UNIFIED IDEOGRAPH-#28343, IRGKangXi=1245.271, RSKangXi=159.8
28344 CJK UNIFIED IDEOGRAPH-#28344, IRGKangXi=1245.271, RSKangXi=159.8
28345 CJK UNIFIED IDEOGRAPH-#28345, IRGKangXi=1245.271, RSKangXi=159.8
28346 CJK UNIFIED IDEOGRAPH-#28346, IRGKangXi=1245.271, RSKangXi=159.8
28347 CJK UNIFIED IDEOGRAPH-#28347, IRGKangXi=1245.300, RSKangXi=159.9
28348 CJK UNIFIED IDEOGRAPH-#28348, IRGKangXi=1246.020, RSKangXi=159.9
28349 CJK UNIFIED IDEOGRAPH-#28349, IRGKangXi=1246.030, RSKangXi=159.9
2834A CJK UNIFIED IDEOGRAPH-#2834A, IRGKangXi=1246.040, RSKangXi=159.9
2834B CJK UNIFIED IDEOGRAPH-#2834B, IRGKangXi=1246.060, RSKangXi=159.9
2834C CJK UNIFIED IDEOGRAPH-#2834C, IRGKangXi=1246.070, RSKangXi=159.9
2834D CJK UNIFIED IDEOGRAPH-#2834D, IRGKangXi=1246.080, RSKangXi=159.9
2834E CJK UNIFIED IDEOGRAPH-#2834E, IRGKangXi=1246.150, RSKangXi=159.9
2834F CJK UNIFIED IDEOGRAPH-#2834F, IRGKangXi=1246.160, RSKangXi=159.9
28350 CJK UNIFIED IDEOGRAPH-#28350, IRGKangXi=1246.180, RSKangXi=159.9
28351 CJK UNIFIED IDEOGRAPH-#28351, IRGKangXi=1246.190, RSKangXi=159.9
28352 CJK UNIFIED IDEOGRAPH-#28352, IRGKangXi=1246.240, RSKangXi=159.9
28353 CJK UNIFIED IDEOGRAPH-#28353, IRGKangXi=1247.020, RSKangXi=159.9
28354 CJK UNIFIED IDEOGRAPH-#28354, IRGKangXi=1247.030, RSKangXi=159.9
28355 CJK UNIFIED IDEOGRAPH-#28355, IRGKangXi=1247.031, RSKangXi=159.9
28356 CJK UNIFIED IDEOGRAPH-#28356, IRGKangXi=1247.031, RSKangXi=159.9
28357 CJK UNIFIED IDEOGRAPH-#28357, IRGKangXi=1247.031, RSKangXi=159.9
28358 CJK UNIFIED IDEOGRAPH-#28358, IRGKangXi=1247.031, RSKangXi=159.9
28359 CJK UNIFIED IDEOGRAPH-#28359, IRGKangXi=1247.031, RSKangXi=159.9
2835A CJK UNIFIED IDEOGRAPH-#2835A, IRGKangXi=1247.031, RSKangXi=159.9
2835B CJK UNIFIED IDEOGRAPH-#2835B, IRGKangXi=1247.031, RSKangXi=159.9
2835C CJK UNIFIED IDEOGRAPH-#2835C, IRGKangXi=1247.031, RSKangXi=159.9
2835D CJK UNIFIED IDEOGRAPH-#2835D, IRGKangXi=1247.031, RSKangXi=159.9
2835E CJK UNIFIED IDEOGRAPH-#2835E, IRGKangXi=1247.031, RSKangXi=159.9
2835F CJK UNIFIED IDEOGRAPH-#2835F, IRGKangXi=1247.031, RSKangXi=159.9
28360 CJK UNIFIED IDEOGRAPH-#28360, IRGKangXi=1247.031, RSKangXi=159.9
28361 CJK UNIFIED IDEOGRAPH-#28361, IRGKangXi=1247.031, RSKangXi=159.9
28362 CJK UNIFIED IDEOGRAPH-#28362, IRGKangXi=1247.031, RSKangXi=159.9
28363 CJK UNIFIED IDEOGRAPH-#28363, IRGKangXi=1247.031, RSKangXi=159.9
28364 CJK UNIFIED IDEOGRAPH-#28364, IRGKangXi=1247.031, RSKangXi=159.9
28365 CJK UNIFIED IDEOGRAPH-#28365, IRGKangXi=1247.031, RSKangXi=159.9
28366 CJK UNIFIED IDEOGRAPH-#28366, IRGKangXi=1247.031, RSKangXi=159.9
28367 CJK UNIFIED IDEOGRAPH-#28367, IRGKangXi=1247.031, RSKangXi=159.9
28368 CJK UNIFIED IDEOGRAPH-#28368, IRGKangXi=1247.031, RSKangXi=159.9
28369 CJK UNIFIED IDEOGRAPH-#28369, IRGKangXi=1247.050, RSKangXi=159.10
2836A CJK UNIFIED IDEOGRAPH-#2836A, IRGKangXi=1247.060, RSKangXi=159.10
2836B CJK UNIFIED IDEOGRAPH-#2836B, IRGKangXi=1247.070, RSKangXi=159.10
2836C CJK UNIFIED IDEOGRAPH-#2836C, IRGKangXi=1247.090, RSKangXi=159.10
2836D CJK UNIFIED IDEOGRAPH-#2836D, IRGKangXi=1247.100, RSKangXi=159.10
2836E CJK UNIFIED IDEOGRAPH-#2836E, IRGKangXi=1247.110, RSKangXi=159.10
2836F CJK UNIFIED IDEOGRAPH-#2836F, IRGKangXi=1247.120, RSKangXi=159.10
28370 CJK UNIFIED IDEOGRAPH-#28370, IRGKangXi=1247.130, RSKangXi=159.10
28371 CJK UNIFIED IDEOGRAPH-#28371, IRGKangXi=1247.150, RSKangXi=159.10
28372 CJK UNIFIED IDEOGRAPH-#28372, IRGKangXi=1247.180, RSKangXi=159.10
28373 CJK UNIFIED IDEOGRAPH-#28373, IRGKangXi=1247.190, RSKangXi=159.10, Def{distant; an open carriage}
28374 CJK UNIFIED IDEOGRAPH-#28374, IRGKangXi=1247.200, RSKangXi=159.10
28375 CJK UNIFIED IDEOGRAPH-#28375, IRGKangXi=1247.210, RSKangXi=159.10
28376 CJK UNIFIED IDEOGRAPH-#28376, IRGKangXi=1247.230, RSKangXi=159.10
28377 CJK UNIFIED IDEOGRAPH-#28377, IRGKangXi=1247.240, RSKangXi=159.10
28378 CJK UNIFIED IDEOGRAPH-#28378, IRGKangXi=1247.250, RSKangXi=159.10
28379 CJK UNIFIED IDEOGRAPH-#28379, IRGKangXi=1247.270, RSKangXi=159.10
2837A CJK UNIFIED IDEOGRAPH-#2837A, IRGKangXi=1248.020, RSKangXi=159.10
2837B CJK UNIFIED IDEOGRAPH-#2837B, IRGKangXi=1248.040, RSKangXi=159.10
2837C CJK UNIFIED IDEOGRAPH-#2837C, IRGKangXi=1248.041, RSKangXi=159.10
2837D CJK UNIFIED IDEOGRAPH-#2837D, IRGKangXi=1248.041, RSKangXi=159.10
2837E CJK UNIFIED IDEOGRAPH-#2837E, IRGKangXi=1248.041, RSKangXi=159.10
2837F CJK UNIFIED IDEOGRAPH-#2837F, IRGKangXi=1248.041, RSKangXi=159.10
28380 CJK UNIFIED IDEOGRAPH-#28380, IRGKangXi=1248.041, RSKangXi=159.10
28381 CJK UNIFIED IDEOGRAPH-#28381, IRGKangXi=1248.041, RSKangXi=159.10
28382 CJK UNIFIED IDEOGRAPH-#28382, IRGKangXi=1248.041, RSKangXi=159.10
28383 CJK UNIFIED IDEOGRAPH-#28383, IRGKangXi=1248.041, RSKangXi=159.10
28384 CJK UNIFIED IDEOGRAPH-#28384, IRGKangXi=1248.041, RSKangXi=159.10
28385 CJK UNIFIED IDEOGRAPH-#28385, IRGKangXi=1248.041, RSKangXi=159.10
28386 CJK UNIFIED IDEOGRAPH-#28386, IRGKangXi=1248.041, RSKangXi=159.10
28387 CJK UNIFIED IDEOGRAPH-#28387, IRGKangXi=1248.041, RSKangXi=159.10
28388 CJK UNIFIED IDEOGRAPH-#28388, IRGKangXi=1248.041, RSKangXi=159.10
28389 CJK UNIFIED IDEOGRAPH-#28389, IRGKangXi=1248.041, RSKangXi=159.10
2838A CJK UNIFIED IDEOGRAPH-#2838A, IRGKangXi=1248.070, RSKangXi=159.11
2838B CJK UNIFIED IDEOGRAPH-#2838B, IRGKangXi=1248.080, RSKangXi=159.11
2838C CJK UNIFIED IDEOGRAPH-#2838C, IRGKangXi=1248.160, RSKangXi=159.11
2838D CJK UNIFIED IDEOGRAPH-#2838D, IRGKangXi=1248.190, RSKangXi=159.11
2838E CJK UNIFIED IDEOGRAPH-#2838E, IRGKangXi=1248.191, RSKangXi=159.11
2838F CJK UNIFIED IDEOGRAPH-#2838F, IRGKangXi=1248.191, RSKangXi=159.11
28390 CJK UNIFIED IDEOGRAPH-#28390, IRGKangXi=1248.191, RSKangXi=159.11
28391 CJK UNIFIED IDEOGRAPH-#28391, IRGKangXi=1248.191, RSKangXi=159.11
28392 CJK UNIFIED IDEOGRAPH-#28392, IRGKangXi=1248.191, RSKangXi=159.11
28393 CJK UNIFIED IDEOGRAPH-#28393, IRGKangXi=1248.191, RSKangXi=159.11
28394 CJK UNIFIED IDEOGRAPH-#28394, IRGKangXi=1248.191, RSKangXi=159.11
28395 CJK UNIFIED IDEOGRAPH-#28395, IRGKangXi=1248.191, RSKangXi=159.11
28396 CJK UNIFIED IDEOGRAPH-#28396, IRGKangXi=1248.191, RSKangXi=159.11
28397 CJK UNIFIED IDEOGRAPH-#28397, IRGKangXi=1248.191, RSKangXi=159.11
28398 CJK UNIFIED IDEOGRAPH-#28398, IRGKangXi=1248.191, RSKangXi=159.11
28399 CJK UNIFIED IDEOGRAPH-#28399, IRGKangXi=1248.191, RSKangXi=159.11
2839A CJK UNIFIED IDEOGRAPH-#2839A, IRGKangXi=1248.191, RSKangXi=159.11
2839B CJK UNIFIED IDEOGRAPH-#2839B, IRGKangXi=1248.191, RSKangXi=159.11
2839C CJK UNIFIED IDEOGRAPH-#2839C, IRGKangXi=1248.191, RSKangXi=159.11
2839D CJK UNIFIED IDEOGRAPH-#2839D, IRGKangXi=1248.191, RSKangXi=159.11
2839E CJK UNIFIED IDEOGRAPH-#2839E, IRGKangXi=1248.191, RSKangXi=159.11
2839F CJK UNIFIED IDEOGRAPH-#2839F, IRGKangXi=1248.191, RSKangXi=159.11
283A0 CJK UNIFIED IDEOGRAPH-#283A0, IRGKangXi=1248.191, RSKangXi=159.11
283A1 CJK UNIFIED IDEOGRAPH-#283A1, IRGKangXi=1248.191, RSKangXi=159.11
283A2 CJK UNIFIED IDEOGRAPH-#283A2, IRGKangXi=1248.191, RSKangXi=159.11
283A3 CJK UNIFIED IDEOGRAPH-#283A3, IRGKangXi=1248.191, RSKangXi=159.11
283A4 CJK UNIFIED IDEOGRAPH-#283A4, IRGKangXi=1248.200, RSKangXi=159.12
283A5 CJK UNIFIED IDEOGRAPH-#283A5, IRGKangXi=1248.210, RSKangXi=159.12
283A6 CJK UNIFIED IDEOGRAPH-#283A6, IRGKangXi=1248.220, RSKangXi=159.12
283A7 CJK UNIFIED IDEOGRAPH-#283A7, IRGKangXi=1248.240, RSKangXi=159.12
283A8 CJK UNIFIED IDEOGRAPH-#283A8, IRGKangXi=1248.250, RSKangXi=159.12
283A9 CJK UNIFIED IDEOGRAPH-#283A9, IRGKangXi=1248.270, RSKangXi=159.12
283AA CJK UNIFIED IDEOGRAPH-#283AA, IRGKangXi=1248.280, RSKangXi=159.12
283AB CJK UNIFIED IDEOGRAPH-#283AB, IRGKangXi=1248.290, RSKangXi=159.12
283AC CJK UNIFIED IDEOGRAPH-#283AC, IRGKangXi=1248.300, RSKangXi=159.12
283AD CJK UNIFIED IDEOGRAPH-#283AD, IRGKangXi=1248.340, RSKangXi=159.12
283AE CJK UNIFIED IDEOGRAPH-#283AE, IRGKangXi=1248.360, RSKangXi=159.12
283AF CJK UNIFIED IDEOGRAPH-#283AF, IRGKangXi=1249.030, RSKangXi=159.12
283B0 CJK UNIFIED IDEOGRAPH-#283B0, IRGKangXi=1249.031, RSKangXi=159.12
283B1 CJK UNIFIED IDEOGRAPH-#283B1, IRGKangXi=1249.031, RSKangXi=159.12
283B2 CJK UNIFIED IDEOGRAPH-#283B2, IRGKangXi=1249.031, RSKangXi=159.13
283B3 CJK UNIFIED IDEOGRAPH-#283B3, IRGKangXi=1249.040, RSKangXi=159.13
283B4 CJK UNIFIED IDEOGRAPH-#283B4, IRGKangXi=1249.050, RSKangXi=159.13, Def{vertical pegs of wood used to keep the axle-tree of a cart in its place}
283B5 CJK UNIFIED IDEOGRAPH-#283B5, IRGKangXi=1249.060, RSKangXi=159.13
283B6 CJK UNIFIED IDEOGRAPH-#283B6, IRGKangXi=1249.120, RSKangXi=159.13
283B7 CJK UNIFIED IDEOGRAPH-#283B7, IRGKangXi=1249.130, RSKangXi=159.13
283B8 CJK UNIFIED IDEOGRAPH-#283B8, IRGKangXi=1249.150, RSKangXi=159.13
283B9 CJK UNIFIED IDEOGRAPH-#283B9, IRGKangXi=1249.160, RSKangXi=159.13
283BA CJK UNIFIED IDEOGRAPH-#283BA, IRGKangXi=1249.181, RSKangXi=159.13
283BB CJK UNIFIED IDEOGRAPH-#283BB, IRGKangXi=1249.181, RSKangXi=159.13
283BC CJK UNIFIED IDEOGRAPH-#283BC, IRGKangXi=1249.181, RSKangXi=159.13
283BD CJK UNIFIED IDEOGRAPH-#283BD, IRGKangXi=1249.181, RSKangXi=159.13
283BE CJK UNIFIED IDEOGRAPH-#283BE, IRGKangXi=1249.181, RSKangXi=159.13
283BF CJK UNIFIED IDEOGRAPH-#283BF, IRGKangXi=1249.181, RSKangXi=159.13
283C0 CJK UNIFIED IDEOGRAPH-#283C0, IRGKangXi=1249.181, RSKangXi=159.13
283C1 CJK UNIFIED IDEOGRAPH-#283C1, IRGKangXi=1249.181, RSKangXi=159.13
283C2 CJK UNIFIED IDEOGRAPH-#283C2, IRGKangXi=1249.181, RSKangXi=159.13
283C3 CJK UNIFIED IDEOGRAPH-#283C3, IRGKangXi=1249.181, RSKangXi=159.13
283C4 CJK UNIFIED IDEOGRAPH-#283C4, IRGKangXi=1249.181, RSKangXi=159.13
283C5 CJK UNIFIED IDEOGRAPH-#283C5, IRGKangXi=1249.181, RSKangXi=159.13
283C6 CJK UNIFIED IDEOGRAPH-#283C6, IRGKangXi=1249.181, RSKangXi=159.13
283C7 CJK UNIFIED IDEOGRAPH-#283C7, IRGKangXi=1249.181, RSKangXi=159.13
283C8 CJK UNIFIED IDEOGRAPH-#283C8, IRGKangXi=1249.200, RSKangXi=159.14
283C9 CJK UNIFIED IDEOGRAPH-#283C9, IRGKangXi=1249.210, RSKangXi=159.14
283CA CJK UNIFIED IDEOGRAPH-#283CA, IRGKangXi=1249.250, RSKangXi=159.14
283CB CJK UNIFIED IDEOGRAPH-#283CB, IRGKangXi=1249.270, RSKangXi=159.14
283CC CJK UNIFIED IDEOGRAPH-#283CC, IRGKangXi=1249.281, RSKangXi=159.14
283CD CJK UNIFIED IDEOGRAPH-#283CD, IRGKangXi=1249.281, RSKangXi=159.14
283CE CJK UNIFIED IDEOGRAPH-#283CE, IRGKangXi=1249.281, RSKangXi=159.14
283CF CJK UNIFIED IDEOGRAPH-#283CF, IRGKangXi=1249.281, RSKangXi=159.14
283D0 CJK UNIFIED IDEOGRAPH-#283D0, IRGKangXi=1249.281, RSKangXi=159.14
283D1 CJK UNIFIED IDEOGRAPH-#283D1, IRGKangXi=1249.290, RSKangXi=159.15
283D2 CJK UNIFIED IDEOGRAPH-#283D2, IRGKangXi=1249.300, RSKangXi=159.15
283D3 CJK UNIFIED IDEOGRAPH-#283D3, IRGKangXi=1249.320, RSKangXi=159.15
283D4 CJK UNIFIED IDEOGRAPH-#283D4, IRGKangXi=1249.330, RSKangXi=159.15
283D5 CJK UNIFIED IDEOGRAPH-#283D5, IRGKangXi=1249.350, RSKangXi=159.15
283D6 CJK UNIFIED IDEOGRAPH-#283D6, IRGKangXi=1249.360, RSKangXi=159.15
283D7 CJK UNIFIED IDEOGRAPH-#283D7, IRGKangXi=1250.011, RSKangXi=159.15
283D8 CJK UNIFIED IDEOGRAPH-#283D8, IRGKangXi=1250.011, RSKangXi=159.15
283D9 CJK UNIFIED IDEOGRAPH-#283D9, IRGKangXi=1250.011, RSKangXi=159.15
283DA CJK UNIFIED IDEOGRAPH-#283DA, IRGKangXi=1250.011, RSKangXi=159.15
283DB CJK UNIFIED IDEOGRAPH-#283DB, IRGKangXi=1250.011, RSKangXi=159.15
283DC CJK UNIFIED IDEOGRAPH-#283DC, IRGKangXi=1250.011, RSKangXi=159.15
283DD CJK UNIFIED IDEOGRAPH-#283DD, IRGKangXi=1250.011, RSKangXi=159.15
283DE CJK UNIFIED IDEOGRAPH-#283DE, IRGKangXi=1250.030, RSKangXi=159.16
283DF CJK UNIFIED IDEOGRAPH-#283DF, IRGKangXi=1250.040, RSKangXi=159.16
283E0 CJK UNIFIED IDEOGRAPH-#283E0, IRGKangXi=1250.060, RSKangXi=159.16
283E1 CJK UNIFIED IDEOGRAPH-#283E1, IRGKangXi=1250.070, RSKangXi=159.16
283E2 CJK UNIFIED IDEOGRAPH-#283E2, IRGKangXi=1250.080, RSKangXi=159.16
283E3 CJK UNIFIED IDEOGRAPH-#283E3, IRGKangXi=1250.081, RSKangXi=159.16
283E4 CJK UNIFIED IDEOGRAPH-#283E4, IRGKangXi=1250.081, RSKangXi=159.16
283E5 CJK UNIFIED IDEOGRAPH-#283E5, IRGKangXi=1250.081, RSKangXi=159.16
283E6 CJK UNIFIED IDEOGRAPH-#283E6, IRGKangXi=1250.081, RSKangXi=159.16
283E7 CJK UNIFIED IDEOGRAPH-#283E7, IRGKangXi=1250.081, RSKangXi=159.16
283E8 CJK UNIFIED IDEOGRAPH-#283E8, IRGKangXi=1250.081, RSKangXi=159.16
283E9 CJK UNIFIED IDEOGRAPH-#283E9, IRGKangXi=1250.090, RSKangXi=159.17
283EA CJK UNIFIED IDEOGRAPH-#283EA, IRGKangXi=1250.100, RSKangXi=159.17
283EB CJK UNIFIED IDEOGRAPH-#283EB, IRGKangXi=1250.120, RSKangXi=159.17
283EC CJK UNIFIED IDEOGRAPH-#283EC, IRGKangXi=1250.130, RSKangXi=159.17
283ED CJK UNIFIED IDEOGRAPH-#283ED, IRGKangXi=1250.131, RSKangXi=159.17
283EE CJK UNIFIED IDEOGRAPH-#283EE, IRGKangXi=1250.131, RSKangXi=159.17
283EF CJK UNIFIED IDEOGRAPH-#283EF, IRGKangXi=1250.131, RSKangXi=159.17
283F0 CJK UNIFIED IDEOGRAPH-#283F0, IRGKangXi=1250.131, RSKangXi=159.17
283F1 CJK UNIFIED IDEOGRAPH-#283F1, IRGKangXi=1250.131, RSKangXi=159.17
283F2 CJK UNIFIED IDEOGRAPH-#283F2, IRGKangXi=1250.131, RSKangXi=159.17
283F3 CJK UNIFIED IDEOGRAPH-#283F3, IRGKangXi=1250.140, RSKangXi=159.18
283F4 CJK UNIFIED IDEOGRAPH-#283F4, IRGKangXi=1250.150, RSKangXi=159.18
283F5 CJK UNIFIED IDEOGRAPH-#283F5, IRGKangXi=1250.151, RSKangXi=159.19
283F6 CJK UNIFIED IDEOGRAPH-#283F6, IRGKangXi=1250.160, RSKangXi=159.19
283F7 CJK UNIFIED IDEOGRAPH-#283F7, IRGKangXi=1250.171, RSKangXi=159.19
283F8 CJK UNIFIED IDEOGRAPH-#283F8, IRGKangXi=1250.171, RSKangXi=159.19
283F9 CJK UNIFIED IDEOGRAPH-#283F9, IRGKangXi=1250.190, RSKangXi=159.20
283FA CJK UNIFIED IDEOGRAPH-#283FA, IRGKangXi=1250.210, RSKangXi=159.21
283FB CJK UNIFIED IDEOGRAPH-#283FB, IRGKangXi=1250.211, RSKangXi=159.20
283FC CJK UNIFIED IDEOGRAPH-#283FC, IRGKangXi=1250.211, RSKangXi=159.21
283FD CJK UNIFIED IDEOGRAPH-#283FD, IRGKangXi=1250.211, RSKangXi=159.19
283FE CJK UNIFIED IDEOGRAPH-#283FE, IRGKangXi=1250.211, RSKangXi=159.20
283FF CJK UNIFIED IDEOGRAPH-#283FF, IRGKangXi=1250.211, RSKangXi=159.21
28400 CJK UNIFIED IDEOGRAPH-#28400, IRGKangXi=1250.211, RSKangXi=159.21
28401 CJK UNIFIED IDEOGRAPH-#28401, IRGKangXi=1250.220, RSKangXi=159.22
28402 CJK UNIFIED IDEOGRAPH-#28402, IRGKangXi=1250.230, RSKangXi=159.23
28403 CJK UNIFIED IDEOGRAPH-#28403, IRGKangXi=1250.241, RSKangXi=159.24
28404 CJK UNIFIED IDEOGRAPH-#28404, IRGKangXi=1250.241, RSKangXi=159.31
28405 CJK UNIFIED IDEOGRAPH-#28405, IRGKangXi=1250.241, RSKangXi=159.4
28406 CJK UNIFIED IDEOGRAPH-#28406, IRGKangXi=1250.241, RSKangXi=159.4
28407 CJK UNIFIED IDEOGRAPH-#28407, IRGKangXi=1250.241, RSKangXi=159.5
28408 CJK UNIFIED IDEOGRAPH-#28408, IRGKangXi=1250.241, RSKangXi=159.6
28409 CJK UNIFIED IDEOGRAPH-#28409, IRGKangXi=1250.241, RSKangXi=159.12
2840A CJK UNIFIED IDEOGRAPH-#2840A, IRGKangXi=1250.241, RSKangXi=159.16
2840B CJK UNIFIED IDEOGRAPH-#2840B, IRGKangXi=1250.260, RSKangXi=160.0
2840C CJK UNIFIED IDEOGRAPH-#2840C, IRGKangXi=1250.270, RSKangXi=160.1
2840D CJK UNIFIED IDEOGRAPH-#2840D, IRGKangXi=1250.280, RSKangXi=160.3
2840E CJK UNIFIED IDEOGRAPH-#2840E, IRGKangXi=1250.281, RSKangXi=160.3
2840F CJK UNIFIED IDEOGRAPH-#2840F, IRGKangXi=1250.281, RSKangXi=160.4
28410 CJK UNIFIED IDEOGRAPH-#28410, IRGKangXi=1250.281, RSKangXi=160.4
28411 CJK UNIFIED IDEOGRAPH-#28411, IRGKangXi=1250.281, RSKangXi=160.4
28412 CJK UNIFIED IDEOGRAPH-#28412, IRGKangXi=1251.011, RSKangXi=160.5
28413 CJK UNIFIED IDEOGRAPH-#28413, IRGKangXi=1251.011, RSKangXi=160.5
28414 CJK UNIFIED IDEOGRAPH-#28414, IRGKangXi=1251.030, RSKangXi=160.6
28415 CJK UNIFIED IDEOGRAPH-#28415, IRGKangXi=1251.040, RSKangXi=160.6
28416 CJK UNIFIED IDEOGRAPH-#28416, IRGKangXi=1251.050, RSKangXi=160.6
28417 CJK UNIFIED IDEOGRAPH-#28417, IRGKangXi=1251.091, RSKangXi=160.6
28418 CJK UNIFIED IDEOGRAPH-#28418, IRGKangXi=1251.121, RSKangXi=160.7
28419 CJK UNIFIED IDEOGRAPH-#28419, IRGKangXi=1251.121, RSKangXi=160.7
2841A CJK UNIFIED IDEOGRAPH-#2841A, IRGKangXi=1251.121, RSKangXi=160.7
2841B CJK UNIFIED IDEOGRAPH-#2841B, IRGKangXi=1251.121, RSKangXi=160.7
2841C CJK UNIFIED IDEOGRAPH-#2841C, IRGKangXi=1251.140, RSKangXi=160.8
2841D CJK UNIFIED IDEOGRAPH-#2841D, IRGKangXi=1251.160, RSKangXi=160.8
2841E CJK UNIFIED IDEOGRAPH-#2841E, IRGKangXi=1251.161, RSKangXi=160.8
2841F CJK UNIFIED IDEOGRAPH-#2841F, IRGKangXi=1251.161, RSKangXi=160.8
28420 CJK UNIFIED IDEOGRAPH-#28420, IRGKangXi=1251.210, RSKangXi=160.9
28421 CJK UNIFIED IDEOGRAPH-#28421, IRGKangXi=1252.010, RSKangXi=160.9
28422 CJK UNIFIED IDEOGRAPH-#28422, IRGKangXi=1252.020, RSKangXi=160.9
28423 CJK UNIFIED IDEOGRAPH-#28423, IRGKangXi=1252.021, RSKangXi=160.9
28424 CJK UNIFIED IDEOGRAPH-#28424, IRGKangXi=1252.021, RSKangXi=160.9
28425 CJK UNIFIED IDEOGRAPH-#28425, IRGKangXi=1252.021, RSKangXi=160.9
28426 CJK UNIFIED IDEOGRAPH-#28426, IRGKangXi=1252.021, RSKangXi=160.9
28427 CJK UNIFIED IDEOGRAPH-#28427, IRGKangXi=1252.021, RSKangXi=160.9
28428 CJK UNIFIED IDEOGRAPH-#28428, IRGKangXi=1252.030, RSKangXi=160.10
28429 CJK UNIFIED IDEOGRAPH-#28429, IRGKangXi=1252.040, RSKangXi=160.10
2842A CJK UNIFIED IDEOGRAPH-#2842A, IRGKangXi=1252.041, RSKangXi=160.10
2842B CJK UNIFIED IDEOGRAPH-#2842B, IRGKangXi=1252.041, RSKangXi=160.10
2842C CJK UNIFIED IDEOGRAPH-#2842C, IRGKangXi=1252.041, RSKangXi=160.10
2842D CJK UNIFIED IDEOGRAPH-#2842D, IRGKangXi=1252.041, RSKangXi=160.10
2842E CJK UNIFIED IDEOGRAPH-#2842E, IRGKangXi=1252.041, RSKangXi=160.10
2842F CJK UNIFIED IDEOGRAPH-#2842F, IRGKangXi=1252.041, RSKangXi=160.10
28430 CJK UNIFIED IDEOGRAPH-#28430, IRGKangXi=1252.060, RSKangXi=160.11
28431 CJK UNIFIED IDEOGRAPH-#28431, IRGKangXi=1252.070, RSKangXi=160.11
28432 CJK UNIFIED IDEOGRAPH-#28432, IRGKangXi=1252.071, RSKangXi=160.11
28433 CJK UNIFIED IDEOGRAPH-#28433, IRGKangXi=1252.071, RSKangXi=63.14
28434 CJK UNIFIED IDEOGRAPH-#28434, IRGKangXi=1252.071, RSKangXi=102.13
28435 CJK UNIFIED IDEOGRAPH-#28435, IRGKangXi=1252.100, RSKangXi=160.12
28436 CJK UNIFIED IDEOGRAPH-#28436, IRGKangXi=1252.110, RSKangXi=160.12
28437 CJK UNIFIED IDEOGRAPH-#28437, IRGKangXi=1252.111, RSKangXi=160.12
28438 CJK UNIFIED IDEOGRAPH-#28438, IRGKangXi=1252.111, RSKangXi=160.12
28439 CJK UNIFIED IDEOGRAPH-#28439, IRGKangXi=1252.111, RSKangXi=160.12
2843A CJK UNIFIED IDEOGRAPH-#2843A, IRGKangXi=1252.131, RSKangXi=160.13
2843B CJK UNIFIED IDEOGRAPH-#2843B, IRGKangXi=1252.131, RSKangXi=160.13
2843C CJK UNIFIED IDEOGRAPH-#2843C, IRGKangXi=1252.131, RSKangXi=160.13
2843D CJK UNIFIED IDEOGRAPH-#2843D, IRGKangXi=1252.141, RSKangXi=160.14
2843E CJK UNIFIED IDEOGRAPH-#2843E, IRGKangXi=1252.141, RSKangXi=160.15
2843F CJK UNIFIED IDEOGRAPH-#2843F, IRGKangXi=1252.141, RSKangXi=160.15
28440 CJK UNIFIED IDEOGRAPH-#28440, IRGKangXi=1252.141, RSKangXi=160.17
28441 CJK UNIFIED IDEOGRAPH-#28441, IRGKangXi=1252.141, RSKangXi=160.22
28442 CJK UNIFIED IDEOGRAPH-#28442, IRGKangXi=1252.141, RSKangXi=160.23
28443 CJK UNIFIED IDEOGRAPH-#28443, IRGKangXi=1252.190, RSKangXi=161.0
28444 CJK UNIFIED IDEOGRAPH-#28444, IRGKangXi=1252.200, RSKangXi=161.0
28445 CJK UNIFIED IDEOGRAPH-#28445, IRGKangXi=1252.230, RSKangXi=161.6
28446 CJK UNIFIED IDEOGRAPH-#28446, IRGKangXi=1253.010, RSKangXi=161.6
28447 CJK UNIFIED IDEOGRAPH-#28447, IRGKangXi=1253.020, RSKangXi=161.6
28448 CJK UNIFIED IDEOGRAPH-#28448, IRGKangXi=1253.051, RSKangXi=161.8
28449 CJK UNIFIED IDEOGRAPH-#28449, IRGKangXi=1253.051, RSKangXi=161.9
2844A CJK UNIFIED IDEOGRAPH-#2844A, IRGKangXi=1253.070, RSKangXi=161.12
2844B CJK UNIFIED IDEOGRAPH-#2844B, IRGKangXi=1253.100, RSKangXi=161.14
2844C CJK UNIFIED IDEOGRAPH-#2844C, IRGKangXi=1253.101, RSKangXi=161.15
2844D CJK UNIFIED IDEOGRAPH-#2844D, IRGKangXi=1253.120, RSKangXi=162.2
2844E CJK UNIFIED IDEOGRAPH-#2844E, IRGKangXi=1253.131, RSKangXi=162.2
2844F CJK UNIFIED IDEOGRAPH-#2844F, IRGKangXi=1253.131, RSKangXi=162.2
28450 CJK UNIFIED IDEOGRAPH-#28450, IRGKangXi=1253.131, RSKangXi=162.2
28451 CJK UNIFIED IDEOGRAPH-#28451, IRGKangXi=1253.140, RSKangXi=162.3
28452 CJK UNIFIED IDEOGRAPH-#28452, IRGKangXi=1253.150, RSKangXi=162.3, Def{a disciple}
28453 CJK UNIFIED IDEOGRAPH-#28453, IRGKangXi=1253.250, RSKangXi=162.3
28454 CJK UNIFIED IDEOGRAPH-#28454, IRGKangXi=1253.280, RSKangXi=162.3
28455 CJK UNIFIED IDEOGRAPH-#28455, IRGKangXi=1253.281, RSKangXi=162.3
28456 CJK UNIFIED IDEOGRAPH-#28456, IRGKangXi=1253.281, RSKangXi=162.3
28457 CJK UNIFIED IDEOGRAPH-#28457, IRGKangXi=1253.281, RSKangXi=162.3
28458 CJK UNIFIED IDEOGRAPH-#28458, IRGKangXi=1253.281, RSKangXi=162.3
28459 CJK UNIFIED IDEOGRAPH-#28459, IRGKangXi=1253.281, RSKangXi=162.3
2845A CJK UNIFIED IDEOGRAPH-#2845A, IRGKangXi=1253.281, RSKangXi=162.3
2845B CJK UNIFIED IDEOGRAPH-#2845B, IRGKangXi=1253.281, RSKangXi=162.3
2845C CJK UNIFIED IDEOGRAPH-#2845C, IRGKangXi=1253.281, RSKangXi=162.3
2845D CJK UNIFIED IDEOGRAPH-#2845D, IRGKangXi=1253.281, RSKangXi=162.3
2845E CJK UNIFIED IDEOGRAPH-#2845E, IRGKangXi=1253.281, RSKangXi=162.3
2845F CJK UNIFIED IDEOGRAPH-#2845F, IRGKangXi=1253.281, RSKangXi=162.3
28460 CJK UNIFIED IDEOGRAPH-#28460, IRGKangXi=1253.281, RSKangXi=162.3
28461 CJK UNIFIED IDEOGRAPH-#28461, IRGKangXi=1253.281, RSKangXi=162.3
28462 CJK UNIFIED IDEOGRAPH-#28462, IRGKangXi=1253.290, RSKangXi=162.4
28463 CJK UNIFIED IDEOGRAPH-#28463, IRGKangXi=1253.330, RSKangXi=162.4
28464 CJK UNIFIED IDEOGRAPH-#28464, IRGKangXi=1253.340, RSKangXi=162.4
28465 CJK UNIFIED IDEOGRAPH-#28465, IRGKangXi=1253.350, RSKangXi=162.4
28466 CJK UNIFIED IDEOGRAPH-#28466, IRGKangXi=1253.360, RSKangXi=162.4
28467 CJK UNIFIED IDEOGRAPH-#28467, IRGKangXi=1253.370, RSKangXi=162.4
28468 CJK UNIFIED IDEOGRAPH-#28468, IRGKangXi=1253.390, RSKangXi=162.4
28469 CJK UNIFIED IDEOGRAPH-#28469, IRGKangXi=1253.400, RSKangXi=162.4
2846A CJK UNIFIED IDEOGRAPH-#2846A, IRGKangXi=1254.060, RSKangXi=162.4
2846B CJK UNIFIED IDEOGRAPH-#2846B, IRGKangXi=1254.090, RSKangXi=162.4
2846C CJK UNIFIED IDEOGRAPH-#2846C, IRGKangXi=1254.100, RSKangXi=162.4
2846D CJK UNIFIED IDEOGRAPH-#2846D, IRGKangXi=1254.130, RSKangXi=162.4
2846E CJK UNIFIED IDEOGRAPH-#2846E, IRGKangXi=1254.171, RSKangXi=162.4
2846F CJK UNIFIED IDEOGRAPH-#2846F, IRGKangXi=1254.171, RSKangXi=162.4
28470 CJK UNIFIED IDEOGRAPH-#28470, IRGKangXi=1254.171, RSKangXi=162.4
28471 CJK UNIFIED IDEOGRAPH-#28471, IRGKangXi=1254.171, RSKangXi=162.4
28472 CJK UNIFIED IDEOGRAPH-#28472, IRGKangXi=1254.171, RSKangXi=162.4
28473 CJK UNIFIED IDEOGRAPH-#28473, IRGKangXi=1254.171, RSKangXi=162.4
28474 CJK UNIFIED IDEOGRAPH-#28474, IRGKangXi=1254.171, RSKangXi=162.4
28475 CJK UNIFIED IDEOGRAPH-#28475, IRGKangXi=1254.171, RSKangXi=162.4
28476 CJK UNIFIED IDEOGRAPH-#28476, IRGKangXi=1254.171, RSKangXi=162.4
28477 CJK UNIFIED IDEOGRAPH-#28477, IRGKangXi=1254.171, RSKangXi=162.4
28478 CJK UNIFIED IDEOGRAPH-#28478, IRGKangXi=1254.171, RSKangXi=162.4
28479 CJK UNIFIED IDEOGRAPH-#28479, IRGKangXi=1254.171, RSKangXi=162.4
2847A CJK UNIFIED IDEOGRAPH-#2847A, IRGKangXi=1254.171, RSKangXi=162.4
2847B CJK UNIFIED IDEOGRAPH-#2847B, IRGKangXi=1254.171, RSKangXi=162.4
2847C CJK UNIFIED IDEOGRAPH-#2847C, IRGKangXi=1254.171, RSKangXi=162.4
2847D CJK UNIFIED IDEOGRAPH-#2847D, IRGKangXi=1254.171, RSKangXi=162.4
2847E CJK UNIFIED IDEOGRAPH-#2847E, IRGKangXi=1254.171, RSKangXi=162.4
2847F CJK UNIFIED IDEOGRAPH-#2847F, IRGKangXi=1254.171, RSKangXi=162.4
28480 CJK UNIFIED IDEOGRAPH-#28480, IRGKangXi=1254.171, RSKangXi=162.4
28481 CJK UNIFIED IDEOGRAPH-#28481, IRGKangXi=1254.171, RSKangXi=162.4
28482 CJK UNIFIED IDEOGRAPH-#28482, IRGKangXi=1254.171, RSKangXi=162.5
28483 CJK UNIFIED IDEOGRAPH-#28483, IRGKangXi=1254.180, RSKangXi=162.5
28484 CJK UNIFIED IDEOGRAPH-#28484, IRGKangXi=1254.190, RSKangXi=162.5
28485 CJK UNIFIED IDEOGRAPH-#28485, IRGKangXi=1254.230, RSKangXi=162.5
28486 CJK UNIFIED IDEOGRAPH-#28486, IRGKangXi=1254.240, RSKangXi=162.5
28487 CJK UNIFIED IDEOGRAPH-#28487, IRGKangXi=1254.260, RSKangXi=162.5
28488 CJK UNIFIED IDEOGRAPH-#28488, IRGKangXi=1254.280, RSKangXi=162.5
28489 CJK UNIFIED IDEOGRAPH-#28489, IRGKangXi=1254.310, RSKangXi=162.5
2848A CJK UNIFIED IDEOGRAPH-#2848A, IRGKangXi=1254.320, RSKangXi=162.5
2848B CJK UNIFIED IDEOGRAPH-#2848B, IRGKangXi=1254.360, RSKangXi=162.5
2848C CJK UNIFIED IDEOGRAPH-#2848C, IRGKangXi=1255.040, RSKangXi=162.5
2848D CJK UNIFIED IDEOGRAPH-#2848D, IRGKangXi=1255.060, RSKangXi=162.5
2848E CJK UNIFIED IDEOGRAPH-#2848E, IRGKangXi=1255.130, RSKangXi=162.5
2848F CJK UNIFIED IDEOGRAPH-#2848F, IRGKangXi=1255.140, RSKangXi=162.5
28490 CJK UNIFIED IDEOGRAPH-#28490, IRGKangXi=1255.141, RSKangXi=162.5
28491 CJK UNIFIED IDEOGRAPH-#28491, IRGKangXi=1255.141, RSKangXi=162.5
28492 CJK UNIFIED IDEOGRAPH-#28492, IRGKangXi=1255.141, RSKangXi=162.5
28493 CJK UNIFIED IDEOGRAPH-#28493, IRGKangXi=1255.141, RSKangXi=162.5
28494 CJK UNIFIED IDEOGRAPH-#28494, IRGKangXi=1255.141, RSKangXi=162.5
28495 CJK UNIFIED IDEOGRAPH-#28495, IRGKangXi=1255.141, RSKangXi=162.5
28496 CJK UNIFIED IDEOGRAPH-#28496, IRGKangXi=1255.141, RSKangXi=162.5
28497 CJK UNIFIED IDEOGRAPH-#28497, IRGKangXi=1255.141, RSKangXi=162.5
28498 CJK UNIFIED IDEOGRAPH-#28498, IRGKangXi=1255.141, RSKangXi=162.5
28499 CJK UNIFIED IDEOGRAPH-#28499, IRGKangXi=1255.141, RSKangXi=162.5
2849A CJK UNIFIED IDEOGRAPH-#2849A, IRGKangXi=1255.141, RSKangXi=162.5
2849B CJK UNIFIED IDEOGRAPH-#2849B, IRGKangXi=1255.141, RSKangXi=162.5
2849C CJK UNIFIED IDEOGRAPH-#2849C, IRGKangXi=1255.141, RSKangXi=162.5
2849D CJK UNIFIED IDEOGRAPH-#2849D, IRGKangXi=1255.141, RSKangXi=162.5
2849E CJK UNIFIED IDEOGRAPH-#2849E, IRGKangXi=1255.141, RSKangXi=162.5
2849F CJK UNIFIED IDEOGRAPH-#2849F, IRGKangXi=1255.141, RSKangXi=162.5
284A0 CJK UNIFIED IDEOGRAPH-#284A0, IRGKangXi=1255.141, RSKangXi=162.5
284A1 CJK UNIFIED IDEOGRAPH-#284A1, IRGKangXi=1255.141, RSKangXi=162.5
284A2 CJK UNIFIED IDEOGRAPH-#284A2, IRGKangXi=1255.141, RSKangXi=162.5
284A3 CJK UNIFIED IDEOGRAPH-#284A3, IRGKangXi=1255.141, RSKangXi=162.5
284A4 CJK UNIFIED IDEOGRAPH-#284A4, IRGKangXi=1255.141, RSKangXi=162.5
284A5 CJK UNIFIED IDEOGRAPH-#284A5, IRGKangXi=1255.150, RSKangXi=162.6
284A6 CJK UNIFIED IDEOGRAPH-#284A6, IRGKangXi=1255.170, RSKangXi=162.6
284A7 CJK UNIFIED IDEOGRAPH-#284A7, IRGKangXi=1255.220, RSKangXi=162.6
284A8 CJK UNIFIED IDEOGRAPH-#284A8, IRGKangXi=1255.240, RSKangXi=162.6
284A9 CJK UNIFIED IDEOGRAPH-#284A9, IRGKangXi=1256.010, RSKangXi=162.6
284AA CJK UNIFIED IDEOGRAPH-#284AA, IRGKangXi=1256.020, RSKangXi=162.6
284AB CJK UNIFIED IDEOGRAPH-#284AB, IRGKangXi=1256.030, RSKangXi=162.6
284AC CJK UNIFIED IDEOGRAPH-#284AC, IRGKangXi=1256.050, RSKangXi=162.6
284AD CJK UNIFIED IDEOGRAPH-#284AD, IRGKangXi=1257.010, RSKangXi=162.6
284AE CJK UNIFIED IDEOGRAPH-#284AE, IRGKangXi=1257.020, RSKangXi=162.6
284AF CJK UNIFIED IDEOGRAPH-#284AF, IRGKangXi=1257.030, RSKangXi=162.6
284B0 CJK UNIFIED IDEOGRAPH-#284B0, IRGKangXi=1257.040, RSKangXi=162.6
284B1 CJK UNIFIED IDEOGRAPH-#284B1, IRGKangXi=1257.041, RSKangXi=162.6
284B2 CJK UNIFIED IDEOGRAPH-#284B2, IRGKangXi=1257.041, RSKangXi=162.6
284B3 CJK UNIFIED IDEOGRAPH-#284B3, IRGKangXi=1257.041, RSKangXi=162.6
284B4 CJK UNIFIED IDEOGRAPH-#284B4, IRGKangXi=1257.041, RSKangXi=162.6
284B5 CJK UNIFIED IDEOGRAPH-#284B5, IRGKangXi=1257.041, RSKangXi=162.6
284B6 CJK UNIFIED IDEOGRAPH-#284B6, IRGKangXi=1257.041, RSKangXi=162.6
284B7 CJK UNIFIED IDEOGRAPH-#284B7, IRGKangXi=1257.041, RSKangXi=162.6
284B8 CJK UNIFIED IDEOGRAPH-#284B8, IRGKangXi=1257.041, RSKangXi=162.6
284B9 CJK UNIFIED IDEOGRAPH-#284B9, IRGKangXi=1257.041, RSKangXi=162.6
284BA CJK UNIFIED IDEOGRAPH-#284BA, IRGKangXi=1257.041, RSKangXi=162.6
284BB CJK UNIFIED IDEOGRAPH-#284BB, IRGKangXi=1257.041, RSKangXi=162.6
284BC CJK UNIFIED IDEOGRAPH-#284BC, IRGKangXi=1257.041, RSKangXi=162.6
284BD CJK UNIFIED IDEOGRAPH-#284BD, IRGKangXi=1257.041, RSKangXi=162.6
284BE CJK UNIFIED IDEOGRAPH-#284BE, IRGKangXi=1257.041, RSKangXi=162.6
284BF CJK UNIFIED IDEOGRAPH-#284BF, IRGKangXi=1257.041, RSKangXi=162.6
284C0 CJK UNIFIED IDEOGRAPH-#284C0, IRGKangXi=1257.041, RSKangXi=162.6
284C1 CJK UNIFIED IDEOGRAPH-#284C1, IRGKangXi=1257.041, RSKangXi=162.6
284C2 CJK UNIFIED IDEOGRAPH-#284C2, IRGKangXi=1257.041, RSKangXi=162.6
284C3 CJK UNIFIED IDEOGRAPH-#284C3, IRGKangXi=1257.041, RSKangXi=162.6
284C4 CJK UNIFIED IDEOGRAPH-#284C4, IRGKangXi=1257.041, RSKangXi=162.6
284C5 CJK UNIFIED IDEOGRAPH-#284C5, IRGKangXi=1257.050, RSKangXi=162.7
284C6 CJK UNIFIED IDEOGRAPH-#284C6, IRGKangXi=1257.120, RSKangXi=162.7
284C7 CJK UNIFIED IDEOGRAPH-#284C7, IRGKangXi=1257.220, RSKangXi=162.7
284C8 CJK UNIFIED IDEOGRAPH-#284C8, IRGKangXi=1257.230, RSKangXi=162.7
284C9 CJK UNIFIED IDEOGRAPH-#284C9, IRGKangXi=1258.020, RSKangXi=162.7
284CA CJK UNIFIED IDEOGRAPH-#284CA, IRGKangXi=1258.030, RSKangXi=162.7
284CB CJK UNIFIED IDEOGRAPH-#284CB, IRGKangXi=1258.150, RSKangXi=162.7
284CC CJK UNIFIED IDEOGRAPH-#284CC, IRGKangXi=1259.020, RSKangXi=162.7
284CD CJK UNIFIED IDEOGRAPH-#284CD, IRGKangXi=1259.040, RSKangXi=162.7
284CE CJK UNIFIED IDEOGRAPH-#284CE, IRGKangXi=1259.060, RSKangXi=162.7
284CF CJK UNIFIED IDEOGRAPH-#284CF, IRGKangXi=1259.061, RSKangXi=162.7
284D0 CJK UNIFIED IDEOGRAPH-#284D0, IRGKangXi=1259.061, RSKangXi=162.7
284D1 CJK UNIFIED IDEOGRAPH-#284D1, IRGKangXi=1259.061, RSKangXi=162.7
284D2 CJK UNIFIED IDEOGRAPH-#284D2, IRGKangXi=1259.061, RSKangXi=162.7
284D3 CJK UNIFIED IDEOGRAPH-#284D3, IRGKangXi=1259.061, RSKangXi=162.7
284D4 CJK UNIFIED IDEOGRAPH-#284D4, IRGKangXi=1259.061, RSKangXi=162.7
284D5 CJK UNIFIED IDEOGRAPH-#284D5, IRGKangXi=1259.061, RSKangXi=162.7
284D6 CJK UNIFIED IDEOGRAPH-#284D6, IRGKangXi=1259.061, RSKangXi=162.7
284D7 CJK UNIFIED IDEOGRAPH-#284D7, IRGKangXi=1259.061, RSKangXi=162.7
284D8 CJK UNIFIED IDEOGRAPH-#284D8, IRGKangXi=1259.061, RSKangXi=162.7
284D9 CJK UNIFIED IDEOGRAPH-#284D9, IRGKangXi=1259.061, RSKangXi=162.7
284DA CJK UNIFIED IDEOGRAPH-#284DA, IRGKangXi=1259.061, RSKangXi=162.7
284DB CJK UNIFIED IDEOGRAPH-#284DB, IRGKangXi=1259.061, RSKangXi=162.7
284DC CJK UNIFIED IDEOGRAPH-#284DC, IRGKangXi=1259.061, RSKangXi=162.7
284DD CJK UNIFIED IDEOGRAPH-#284DD, IRGKangXi=1259.061, RSKangXi=162.7
284DE CJK UNIFIED IDEOGRAPH-#284DE, IRGKangXi=1259.061, RSKangXi=162.7
284DF CJK UNIFIED IDEOGRAPH-#284DF, IRGKangXi=1259.061, RSKangXi=162.7
284E0 CJK UNIFIED IDEOGRAPH-#284E0, IRGKangXi=1259.061, RSKangXi=162.7
284E1 CJK UNIFIED IDEOGRAPH-#284E1, IRGKangXi=1259.061, RSKangXi=162.7
284E2 CJK UNIFIED IDEOGRAPH-#284E2, IRGKangXi=1259.061, RSKangXi=162.7
284E3 CJK UNIFIED IDEOGRAPH-#284E3, IRGKangXi=1259.061, RSKangXi=162.7
284E4 CJK UNIFIED IDEOGRAPH-#284E4, IRGKangXi=1259.061, RSKangXi=162.7
284E5 CJK UNIFIED IDEOGRAPH-#284E5, IRGKangXi=1259.061, RSKangXi=162.7
284E6 CJK UNIFIED IDEOGRAPH-#284E6, IRGKangXi=1259.061, RSKangXi=162.7
284E7 CJK UNIFIED IDEOGRAPH-#284E7, IRGKangXi=1259.061, RSKangXi=162.7
284E8 CJK UNIFIED IDEOGRAPH-#284E8, IRGKangXi=1259.061, RSKangXi=162.7
284E9 CJK UNIFIED IDEOGRAPH-#284E9, IRGKangXi=1259.061, RSKangXi=162.7
284EA CJK UNIFIED IDEOGRAPH-#284EA, IRGKangXi=1259.061, RSKangXi=162.7
284EB CJK UNIFIED IDEOGRAPH-#284EB, IRGKangXi=1259.070, RSKangXi=162.8
284EC CJK UNIFIED IDEOGRAPH-#284EC, IRGKangXi=1259.130, RSKangXi=162.8
284ED CJK UNIFIED IDEOGRAPH-#284ED, IRGKangXi=1259.140, RSKangXi=162.8
284EE CJK UNIFIED IDEOGRAPH-#284EE, IRGKangXi=1259.210, RSKangXi=162.8
284EF CJK UNIFIED IDEOGRAPH-#284EF, IRGKangXi=1259.220, RSKangXi=162.8
284F0 CJK UNIFIED IDEOGRAPH-#284F0, IRGKangXi=1259.230, RSKangXi=162.8
284F1 CJK UNIFIED IDEOGRAPH-#284F1, IRGKangXi=1259.250, RSKangXi=162.8
284F2 CJK UNIFIED IDEOGRAPH-#284F2, IRGKangXi=1259.260, RSKangXi=162.8
284F3 CJK UNIFIED IDEOGRAPH-#284F3, IRGKangXi=1259.270, RSKangXi=162.8
284F4 CJK UNIFIED IDEOGRAPH-#284F4, IRGKangXi=1259.280, RSKangXi=162.8
284F5 CJK UNIFIED IDEOGRAPH-#284F5, IRGKangXi=1260.010, RSKangXi=162.8
284F6 CJK UNIFIED IDEOGRAPH-#284F6, IRGKangXi=1260.100, RSKangXi=162.8
284F7 CJK UNIFIED IDEOGRAPH-#284F7, IRGKangXi=1260.110, RSKangXi=162.8
284F8 CJK UNIFIED IDEOGRAPH-#284F8, IRGKangXi=1260.120, RSKangXi=162.8
284F9 CJK UNIFIED IDEOGRAPH-#284F9, IRGKangXi=1260.130, RSKangXi=162.8
284FA CJK UNIFIED IDEOGRAPH-#284FA, IRGKangXi=1260.140, RSKangXi=162.8
284FB CJK UNIFIED IDEOGRAPH-#284FB, IRGKangXi=1260.150, RSKangXi=162.8
284FC CJK UNIFIED IDEOGRAPH-#284FC, IRGKangXi=1260.151, RSKangXi=162.8
284FD CJK UNIFIED IDEOGRAPH-#284FD, IRGKangXi=1260.151, RSKangXi=162.8
284FE CJK UNIFIED IDEOGRAPH-#284FE, IRGKangXi=1260.151, RSKangXi=162.8
284FF CJK UNIFIED IDEOGRAPH-#284FF, IRGKangXi=1260.151, RSKangXi=162.8
28500 CJK UNIFIED IDEOGRAPH-#28500, IRGKangXi=1260.151, RSKangXi=162.8
28501 CJK UNIFIED IDEOGRAPH-#28501, IRGKangXi=1260.151, RSKangXi=162.8
28502 CJK UNIFIED IDEOGRAPH-#28502, IRGKangXi=1260.151, RSKangXi=162.8
28503 CJK UNIFIED IDEOGRAPH-#28503, IRGKangXi=1260.151, RSKangXi=162.8
28504 CJK UNIFIED IDEOGRAPH-#28504, IRGKangXi=1260.151, RSKangXi=162.8
28505 CJK UNIFIED IDEOGRAPH-#28505, IRGKangXi=1260.151, RSKangXi=162.8
28506 CJK UNIFIED IDEOGRAPH-#28506, IRGKangXi=1260.151, RSKangXi=162.8
28507 CJK UNIFIED IDEOGRAPH-#28507, IRGKangXi=1260.151, RSKangXi=162.8
28508 CJK UNIFIED IDEOGRAPH-#28508, IRGKangXi=1260.151, RSKangXi=162.8
28509 CJK UNIFIED IDEOGRAPH-#28509, IRGKangXi=1260.151, RSKangXi=162.8
2850A CJK UNIFIED IDEOGRAPH-#2850A, IRGKangXi=1260.151, RSKangXi=162.8
2850B CJK UNIFIED IDEOGRAPH-#2850B, IRGKangXi=1260.151, RSKangXi=162.8
2850C CJK UNIFIED IDEOGRAPH-#2850C, IRGKangXi=1260.151, RSKangXi=162.8
2850D CJK UNIFIED IDEOGRAPH-#2850D, IRGKangXi=1260.151, RSKangXi=162.8
2850E CJK UNIFIED IDEOGRAPH-#2850E, IRGKangXi=1260.151, RSKangXi=162.9
2850F CJK UNIFIED IDEOGRAPH-#2850F, IRGKangXi=1260.151, RSKangXi=162.8
28510 CJK UNIFIED IDEOGRAPH-#28510, IRGKangXi=1260.151, RSKangXi=162.8
28511 CJK UNIFIED IDEOGRAPH-#28511, IRGKangXi=1260.151, RSKangXi=162.8
28512 CJK UNIFIED IDEOGRAPH-#28512, IRGKangXi=1260.151, RSKangXi=162.8
28513 CJK UNIFIED IDEOGRAPH-#28513, IRGKangXi=1260.151, RSKangXi=162.8
28514 CJK UNIFIED IDEOGRAPH-#28514, IRGKangXi=1260.151, RSKangXi=162.8
28515 CJK UNIFIED IDEOGRAPH-#28515, IRGKangXi=1260.151, RSKangXi=162.8
28516 CJK UNIFIED IDEOGRAPH-#28516, IRGKangXi=1260.151, RSKangXi=162.8
28517 CJK UNIFIED IDEOGRAPH-#28517, IRGKangXi=1260.151, RSKangXi=162.8
28518 CJK UNIFIED IDEOGRAPH-#28518, IRGKangXi=1260.151, RSKangXi=162.8
28519 CJK UNIFIED IDEOGRAPH-#28519, IRGKangXi=1260.151, RSKangXi=162.8
2851A CJK UNIFIED IDEOGRAPH-#2851A, IRGKangXi=1260.151, RSKangXi=162.8
2851B CJK UNIFIED IDEOGRAPH-#2851B, IRGKangXi=1260.151, RSKangXi=162.8
2851C CJK UNIFIED IDEOGRAPH-#2851C, IRGKangXi=1260.151, RSKangXi=162.8
2851D CJK UNIFIED IDEOGRAPH-#2851D, IRGKangXi=1260.170, RSKangXi=162.9
2851E CJK UNIFIED IDEOGRAPH-#2851E, IRGKangXi=1260.180, RSKangXi=162.9
2851F CJK UNIFIED IDEOGRAPH-#2851F, IRGKangXi=1260.250, RSKangXi=162.9
28520 CJK UNIFIED IDEOGRAPH-#28520, IRGKangXi=1260.251, RSKangXi=162.8
28521 CJK UNIFIED IDEOGRAPH-#28521, IRGKangXi=1260.300, RSKangXi=162.9
28522 CJK UNIFIED IDEOGRAPH-#28522, IRGKangXi=1260.310, RSKangXi=162.9
28523 CJK UNIFIED IDEOGRAPH-#28523, IRGKangXi=1261.020, RSKangXi=162.9
28524 CJK UNIFIED IDEOGRAPH-#28524, IRGKangXi=1261.150, RSKangXi=162.9
28525 CJK UNIFIED IDEOGRAPH-#28525, IRGKangXi=1261.160, RSKangXi=162.9
28526 CJK UNIFIED IDEOGRAPH-#28526, IRGKangXi=1261.170, RSKangXi=162.9
28527 CJK UNIFIED IDEOGRAPH-#28527, IRGKangXi=1261.230, RSKangXi=162.9
28528 CJK UNIFIED IDEOGRAPH-#28528, IRGKangXi=1262.020, RSKangXi=162.9
28529 CJK UNIFIED IDEOGRAPH-#28529, IRGKangXi=1262.050, RSKangXi=162.9
2852A CJK UNIFIED IDEOGRAPH-#2852A, IRGKangXi=1262.120, RSKangXi=162.9
2852B CJK UNIFIED IDEOGRAPH-#2852B, IRGKangXi=1262.130, RSKangXi=162.9
2852C CJK UNIFIED IDEOGRAPH-#2852C, IRGKangXi=1262.140, RSKangXi=162.9
2852D CJK UNIFIED IDEOGRAPH-#2852D, IRGKangXi=1262.150, RSKangXi=162.9
2852E CJK UNIFIED IDEOGRAPH-#2852E, IRGKangXi=1262.160, RSKangXi=162.9
2852F CJK UNIFIED IDEOGRAPH-#2852F, IRGKangXi=1262.170, RSKangXi=162.9
28530 CJK UNIFIED IDEOGRAPH-#28530, IRGKangXi=1262.180, RSKangXi=162.9
28531 CJK UNIFIED IDEOGRAPH-#28531, IRGKangXi=1262.190, RSKangXi=162.9
28532 CJK UNIFIED IDEOGRAPH-#28532, IRGKangXi=1262.200, RSKangXi=162.9
28533 CJK UNIFIED IDEOGRAPH-#28533, IRGKangXi=1262.201, RSKangXi=162.9
28534 CJK UNIFIED IDEOGRAPH-#28534, IRGKangXi=1262.201, RSKangXi=162.9
28535 CJK UNIFIED IDEOGRAPH-#28535, IRGKangXi=1262.201, RSKangXi=162.9
28536 CJK UNIFIED IDEOGRAPH-#28536, IRGKangXi=1262.201, RSKangXi=162.9
28537 CJK UNIFIED IDEOGRAPH-#28537, IRGKangXi=1262.201, RSKangXi=162.9
28538 CJK UNIFIED IDEOGRAPH-#28538, IRGKangXi=1262.201, RSKangXi=162.9
28539 CJK UNIFIED IDEOGRAPH-#28539, IRGKangXi=1262.201, RSKangXi=162.9
2853A CJK UNIFIED IDEOGRAPH-#2853A, IRGKangXi=1262.201, RSKangXi=162.9
2853B CJK UNIFIED IDEOGRAPH-#2853B, IRGKangXi=1262.201, RSKangXi=162.9
2853C CJK UNIFIED IDEOGRAPH-#2853C, IRGKangXi=1262.201, RSKangXi=162.9
2853D CJK UNIFIED IDEOGRAPH-#2853D, IRGKangXi=1262.201, RSKangXi=162.9
2853E CJK UNIFIED IDEOGRAPH-#2853E, IRGKangXi=1262.201, RSKangXi=162.9
2853F CJK UNIFIED IDEOGRAPH-#2853F, IRGKangXi=1262.201, RSKangXi=162.9
28540 CJK UNIFIED IDEOGRAPH-#28540, IRGKangXi=1262.201, RSKangXi=162.9
28541 CJK UNIFIED IDEOGRAPH-#28541, IRGKangXi=1262.201, RSKangXi=162.9
28542 CJK UNIFIED IDEOGRAPH-#28542, IRGKangXi=1262.201, RSKangXi=162.6
28543 CJK UNIFIED IDEOGRAPH-#28543, IRGKangXi=1262.201, RSKangXi=162.9
28544 CJK UNIFIED IDEOGRAPH-#28544, IRGKangXi=1262.201, RSKangXi=162.9
28545 CJK UNIFIED IDEOGRAPH-#28545, IRGKangXi=1262.201, RSKangXi=162.9
28546 CJK UNIFIED IDEOGRAPH-#28546, IRGKangXi=1262.201, RSKangXi=162.9
28547 CJK UNIFIED IDEOGRAPH-#28547, IRGKangXi=1262.201, RSKangXi=162.9
28548 CJK UNIFIED IDEOGRAPH-#28548, IRGKangXi=1262.201, RSKangXi=162.9
28549 CJK UNIFIED IDEOGRAPH-#28549, IRGKangXi=1262.201, RSKangXi=162.9
2854A CJK UNIFIED IDEOGRAPH-#2854A, IRGKangXi=1262.201, RSKangXi=162.9
2854B CJK UNIFIED IDEOGRAPH-#2854B, IRGKangXi=1262.201, RSKangXi=162.9
2854C CJK UNIFIED IDEOGRAPH-#2854C, IRGKangXi=1262.201, RSKangXi=162.9
2854D CJK UNIFIED IDEOGRAPH-#2854D, IRGKangXi=1262.201, RSKangXi=162.9
2854E CJK UNIFIED IDEOGRAPH-#2854E, IRGKangXi=1262.201, RSKangXi=162.9
2854F CJK UNIFIED IDEOGRAPH-#2854F, IRGKangXi=1262.201, RSKangXi=162.9
28550 CJK UNIFIED IDEOGRAPH-#28550, IRGKangXi=1262.201, RSKangXi=162.9
28551 CJK UNIFIED IDEOGRAPH-#28551, IRGKangXi=1262.201, RSKangXi=162.9
28552 CJK UNIFIED IDEOGRAPH-#28552, IRGKangXi=1262.201, RSKangXi=162.9
28553 CJK UNIFIED IDEOGRAPH-#28553, IRGKangXi=1262.201, RSKangXi=162.9
28554 CJK UNIFIED IDEOGRAPH-#28554, IRGKangXi=1262.201, RSKangXi=162.9
28555 CJK UNIFIED IDEOGRAPH-#28555, IRGKangXi=1262.201, RSKangXi=162.9
28556 CJK UNIFIED IDEOGRAPH-#28556, IRGKangXi=1262.201, RSKangXi=162.9
28557 CJK UNIFIED IDEOGRAPH-#28557, IRGKangXi=1262.201, RSKangXi=162.9
28558 CJK UNIFIED IDEOGRAPH-#28558, IRGKangXi=1262.201, RSKangXi=162.9
28559 CJK UNIFIED IDEOGRAPH-#28559, IRGKangXi=1262.201, RSKangXi=162.9
2855A CJK UNIFIED IDEOGRAPH-#2855A, IRGKangXi=1262.201, RSKangXi=162.9
2855B CJK UNIFIED IDEOGRAPH-#2855B, IRGKangXi=1262.201, RSKangXi=162.9
2855C CJK UNIFIED IDEOGRAPH-#2855C, IRGKangXi=1262.201, RSKangXi=162.9
2855D CJK UNIFIED IDEOGRAPH-#2855D, IRGKangXi=1262.220, RSKangXi=162.10
2855E CJK UNIFIED IDEOGRAPH-#2855E, IRGKangXi=1262.230, RSKangXi=162.10
2855F CJK UNIFIED IDEOGRAPH-#2855F, IRGKangXi=1263.040, RSKangXi=162.10
28560 CJK UNIFIED IDEOGRAPH-#28560, IRGKangXi=1263.050, RSKangXi=162.10
28561 CJK UNIFIED IDEOGRAPH-#28561, IRGKangXi=1263.060, RSKangXi=162.10
28562 CJK UNIFIED IDEOGRAPH-#28562, IRGKangXi=1263.070, RSKangXi=162.10
28563 CJK UNIFIED IDEOGRAPH-#28563, IRGKangXi=1263.080, RSKangXi=162.10
28564 CJK UNIFIED IDEOGRAPH-#28564, IRGKangXi=1263.180, RSKangXi=162.10
28565 CJK UNIFIED IDEOGRAPH-#28565, IRGKangXi=1263.200, RSKangXi=162.10
28566 CJK UNIFIED IDEOGRAPH-#28566, IRGKangXi=1263.210, RSKangXi=162.10
28567 CJK UNIFIED IDEOGRAPH-#28567, IRGKangXi=1263.220, RSKangXi=162.10
28568 CJK UNIFIED IDEOGRAPH-#28568, IRGKangXi=1263.230, RSKangXi=162.10
28569 CJK UNIFIED IDEOGRAPH-#28569, IRGKangXi=1263.240, RSKangXi=162.10
2856A CJK UNIFIED IDEOGRAPH-#2856A, IRGKangXi=1263.250, RSKangXi=162.10
2856B CJK UNIFIED IDEOGRAPH-#2856B, IRGKangXi=1263.251, RSKangXi=162.10
2856C CJK UNIFIED IDEOGRAPH-#2856C, IRGKangXi=1263.251, RSKangXi=162.10
2856D CJK UNIFIED IDEOGRAPH-#2856D, IRGKangXi=1263.251, RSKangXi=162.10
2856E CJK UNIFIED IDEOGRAPH-#2856E, IRGKangXi=1263.251, RSKangXi=162.10
2856F CJK UNIFIED IDEOGRAPH-#2856F, IRGKangXi=1263.251, RSKangXi=162.10
28570 CJK UNIFIED IDEOGRAPH-#28570, IRGKangXi=1263.251, RSKangXi=162.10
28571 CJK UNIFIED IDEOGRAPH-#28571, IRGKangXi=1263.251, RSKangXi=162.10
28572 CJK UNIFIED IDEOGRAPH-#28572, IRGKangXi=1263.251, RSKangXi=162.10
28573 CJK UNIFIED IDEOGRAPH-#28573, IRGKangXi=1263.251, RSKangXi=162.10
28574 CJK UNIFIED IDEOGRAPH-#28574, IRGKangXi=1263.251, RSKangXi=162.10
28575 CJK UNIFIED IDEOGRAPH-#28575, IRGKangXi=1263.251, RSKangXi=162.10
28576 CJK UNIFIED IDEOGRAPH-#28576, IRGKangXi=1263.251, RSKangXi=162.10
28577 CJK UNIFIED IDEOGRAPH-#28577, IRGKangXi=1263.251, RSKangXi=162.10
28578 CJK UNIFIED IDEOGRAPH-#28578, IRGKangXi=1263.251, RSKangXi=162.10
28579 CJK UNIFIED IDEOGRAPH-#28579, IRGKangXi=1263.251, RSKangXi=162.10
2857A CJK UNIFIED IDEOGRAPH-#2857A, IRGKangXi=1263.251, RSKangXi=162.10
2857B CJK UNIFIED IDEOGRAPH-#2857B, IRGKangXi=1263.251, RSKangXi=162.10
2857C CJK UNIFIED IDEOGRAPH-#2857C, IRGKangXi=1263.251, RSKangXi=162.10
2857D CJK UNIFIED IDEOGRAPH-#2857D, IRGKangXi=1263.251, RSKangXi=162.10
2857E CJK UNIFIED IDEOGRAPH-#2857E, IRGKangXi=1263.251, RSKangXi=162.10
2857F CJK UNIFIED IDEOGRAPH-#2857F, IRGKangXi=1263.251, RSKangXi=162.10
28580 CJK UNIFIED IDEOGRAPH-#28580, IRGKangXi=1263.251, RSKangXi=162.10
28581 CJK UNIFIED IDEOGRAPH-#28581, IRGKangXi=1263.251, RSKangXi=162.10
28582 CJK UNIFIED IDEOGRAPH-#28582, IRGKangXi=1263.251, RSKangXi=162.10
28583 CJK UNIFIED IDEOGRAPH-#28583, IRGKangXi=1263.251, RSKangXi=162.10
28584 CJK UNIFIED IDEOGRAPH-#28584, IRGKangXi=1263.251, RSKangXi=162.10
28585 CJK UNIFIED IDEOGRAPH-#28585, IRGKangXi=1263.251, RSKangXi=162.10
28586 CJK UNIFIED IDEOGRAPH-#28586, IRGKangXi=1263.280, RSKangXi=162.11
28587 CJK UNIFIED IDEOGRAPH-#28587, IRGKangXi=1263.290, RSKangXi=162.11
28588 CJK UNIFIED IDEOGRAPH-#28588, IRGKangXi=1263.330, RSKangXi=162.11
28589 CJK UNIFIED IDEOGRAPH-#28589, IRGKangXi=1264.010, RSKangXi=162.11
2858A CJK UNIFIED IDEOGRAPH-#2858A, IRGKangXi=1264.050, RSKangXi=162.11
2858B CJK UNIFIED IDEOGRAPH-#2858B, IRGKangXi=1264.070, RSKangXi=162.11
2858C CJK UNIFIED IDEOGRAPH-#2858C, IRGKangXi=1264.080, RSKangXi=162.11
2858D CJK UNIFIED IDEOGRAPH-#2858D, IRGKangXi=1264.090, RSKangXi=162.11
2858E CJK UNIFIED IDEOGRAPH-#2858E, IRGKangXi=1264.110, RSKangXi=162.11
2858F CJK UNIFIED IDEOGRAPH-#2858F, IRGKangXi=1264.160, RSKangXi=162.11
28590 CJK UNIFIED IDEOGRAPH-#28590, IRGKangXi=1264.190, RSKangXi=162.11
28591 CJK UNIFIED IDEOGRAPH-#28591, IRGKangXi=1264.211, RSKangXi=162.11
28592 CJK UNIFIED IDEOGRAPH-#28592, IRGKangXi=1264.211, RSKangXi=162.11
28593 CJK UNIFIED IDEOGRAPH-#28593, IRGKangXi=1264.211, RSKangXi=162.11
28594 CJK UNIFIED IDEOGRAPH-#28594, IRGKangXi=1264.211, RSKangXi=162.11
28595 CJK UNIFIED IDEOGRAPH-#28595, IRGKangXi=1264.211, RSKangXi=162.11
28596 CJK UNIFIED IDEOGRAPH-#28596, IRGKangXi=1264.211, RSKangXi=162.11
28597 CJK UNIFIED IDEOGRAPH-#28597, IRGKangXi=1264.211, RSKangXi=162.11
28598 CJK UNIFIED IDEOGRAPH-#28598, IRGKangXi=1264.211, RSKangXi=162.11
28599 CJK UNIFIED IDEOGRAPH-#28599, IRGKangXi=1264.211, RSKangXi=162.11
2859A CJK UNIFIED IDEOGRAPH-#2859A, IRGKangXi=1264.211, RSKangXi=162.11
2859B CJK UNIFIED IDEOGRAPH-#2859B, IRGKangXi=1264.211, RSKangXi=162.11
2859C CJK UNIFIED IDEOGRAPH-#2859C, IRGKangXi=1264.211, RSKangXi=162.11
2859D CJK UNIFIED IDEOGRAPH-#2859D, IRGKangXi=1264.211, RSKangXi=162.11
2859E CJK UNIFIED IDEOGRAPH-#2859E, IRGKangXi=1264.211, RSKangXi=162.11
2859F CJK UNIFIED IDEOGRAPH-#2859F, IRGKangXi=1264.211, RSKangXi=162.11
285A0 CJK UNIFIED IDEOGRAPH-#285A0, IRGKangXi=1264.211, RSKangXi=162.11
285A1 CJK UNIFIED IDEOGRAPH-#285A1, IRGKangXi=1264.211, RSKangXi=162.11
285A2 CJK UNIFIED IDEOGRAPH-#285A2, IRGKangXi=1264.211, RSKangXi=162.11
285A3 CJK UNIFIED IDEOGRAPH-#285A3, IRGKangXi=1264.211, RSKangXi=162.11
285A4 CJK UNIFIED IDEOGRAPH-#285A4, IRGKangXi=1264.211, RSKangXi=162.11
285A5 CJK UNIFIED IDEOGRAPH-#285A5, IRGKangXi=1264.211, RSKangXi=162.11
285A6 CJK UNIFIED IDEOGRAPH-#285A6, IRGKangXi=1264.211, RSKangXi=162.11
285A7 CJK UNIFIED IDEOGRAPH-#285A7, IRGKangXi=1264.211, RSKangXi=162.11
285A8 CJK UNIFIED IDEOGRAPH-#285A8, IRGKangXi=1264.211, RSKangXi=162.11
285A9 CJK UNIFIED IDEOGRAPH-#285A9, IRGKangXi=1264.211, RSKangXi=162.11
285AA CJK UNIFIED IDEOGRAPH-#285AA, IRGKangXi=1264.211, RSKangXi=162.11
285AB CJK UNIFIED IDEOGRAPH-#285AB, IRGKangXi=1264.211, RSKangXi=162.11
285AC CJK UNIFIED IDEOGRAPH-#285AC, IRGKangXi=1264.211, RSKangXi=162.11
285AD CJK UNIFIED IDEOGRAPH-#285AD, IRGKangXi=1264.211, RSKangXi=162.11
285AE CJK UNIFIED IDEOGRAPH-#285AE, IRGKangXi=1264.211, RSKangXi=162.11
285AF CJK UNIFIED IDEOGRAPH-#285AF, IRGKangXi=1264.211, RSKangXi=162.11
285B0 CJK UNIFIED IDEOGRAPH-#285B0, IRGKangXi=1264.211, RSKangXi=162.11
285B1 CJK UNIFIED IDEOGRAPH-#285B1, IRGKangXi=1264.211, RSKangXi=162.11
285B2 CJK UNIFIED IDEOGRAPH-#285B2, IRGKangXi=1264.211, RSKangXi=162.11
285B3 CJK UNIFIED IDEOGRAPH-#285B3, IRGKangXi=1264.211, RSKangXi=162.11
285B4 CJK UNIFIED IDEOGRAPH-#285B4, IRGKangXi=1264.220, RSKangXi=162.12
285B5 CJK UNIFIED IDEOGRAPH-#285B5, IRGKangXi=1264.230, RSKangXi=162.12
285B6 CJK UNIFIED IDEOGRAPH-#285B6, IRGKangXi=1264.240, RSKangXi=162.12
285B7 CJK UNIFIED IDEOGRAPH-#285B7, IRGKangXi=1265.010, RSKangXi=162.12
285B8 CJK UNIFIED IDEOGRAPH-#285B8, IRGKangXi=1265.020, RSKangXi=162.12
285B9 CJK UNIFIED IDEOGRAPH-#285B9, IRGKangXi=1265.100, RSKangXi=162.12
285BA CJK UNIFIED IDEOGRAPH-#285BA, IRGKangXi=1265.110, RSKangXi=162.12
285BB CJK UNIFIED IDEOGRAPH-#285BB, IRGKangXi=1265.120, RSKangXi=162.12
285BC CJK UNIFIED IDEOGRAPH-#285BC, IRGKangXi=1265.140, RSKangXi=162.12
285BD CJK UNIFIED IDEOGRAPH-#285BD, IRGKangXi=1265.160, RSKangXi=162.12
285BE CJK UNIFIED IDEOGRAPH-#285BE, IRGKangXi=1265.220, RSKangXi=162.12
285BF CJK UNIFIED IDEOGRAPH-#285BF, IRGKangXi=1266.010, RSKangXi=162.12
285C0 CJK UNIFIED IDEOGRAPH-#285C0, IRGKangXi=1266.020, RSKangXi=162.12
285C1 CJK UNIFIED IDEOGRAPH-#285C1, IRGKangXi=1266.030, RSKangXi=162.12
285C2 CJK UNIFIED IDEOGRAPH-#285C2, IRGKangXi=1266.040, RSKangXi=162.12
285C3 CJK UNIFIED IDEOGRAPH-#285C3, IRGKangXi=1266.050, RSKangXi=162.12
285C4 CJK UNIFIED IDEOGRAPH-#285C4, IRGKangXi=1266.060, RSKangXi=162.12
285C5 CJK UNIFIED IDEOGRAPH-#285C5, IRGKangXi=1266.061, RSKangXi=162.12
285C6 CJK UNIFIED IDEOGRAPH-#285C6, IRGKangXi=1266.061, RSKangXi=162.12
285C7 CJK UNIFIED IDEOGRAPH-#285C7, IRGKangXi=1266.061, RSKangXi=162.12
285C8 CJK UNIFIED IDEOGRAPH-#285C8, IRGKangXi=1266.061, RSKangXi=162.12
285C9 CJK UNIFIED IDEOGRAPH-#285C9, IRGKangXi=1266.061, RSKangXi=162.12
285CA CJK UNIFIED IDEOGRAPH-#285CA, IRGKangXi=1266.061, RSKangXi=162.12
285CB CJK UNIFIED IDEOGRAPH-#285CB, IRGKangXi=1266.061, RSKangXi=162.12
285CC CJK UNIFIED IDEOGRAPH-#285CC, IRGKangXi=1266.061, RSKangXi=162.12
285CD CJK UNIFIED IDEOGRAPH-#285CD, IRGKangXi=1266.061, RSKangXi=162.12
285CE CJK UNIFIED IDEOGRAPH-#285CE, IRGKangXi=1266.061, RSKangXi=162.12
285CF CJK UNIFIED IDEOGRAPH-#285CF, IRGKangXi=1266.061, RSKangXi=162.12
285D0 CJK UNIFIED IDEOGRAPH-#285D0, IRGKangXi=1266.061, RSKangXi=162.12
285D1 CJK UNIFIED IDEOGRAPH-#285D1, IRGKangXi=1266.061, RSKangXi=162.12
285D2 CJK UNIFIED IDEOGRAPH-#285D2, IRGKangXi=1266.061, RSKangXi=162.12
285D3 CJK UNIFIED IDEOGRAPH-#285D3, IRGKangXi=1266.061, RSKangXi=30.13
285D4 CJK UNIFIED IDEOGRAPH-#285D4, IRGKangXi=1266.061, RSKangXi=162.12
285D5 CJK UNIFIED IDEOGRAPH-#285D5, IRGKangXi=1266.061, RSKangXi=162.12
285D6 CJK UNIFIED IDEOGRAPH-#285D6, IRGKangXi=1266.061, RSKangXi=162.12
285D7 CJK UNIFIED IDEOGRAPH-#285D7, IRGKangXi=1266.061, RSKangXi=162.12
285D8 CJK UNIFIED IDEOGRAPH-#285D8, IRGKangXi=1266.061, RSKangXi=162.12
285D9 CJK UNIFIED IDEOGRAPH-#285D9, IRGKangXi=1266.061, RSKangXi=162.12
285DA CJK UNIFIED IDEOGRAPH-#285DA, IRGKangXi=1266.061, RSKangXi=162.12
285DB CJK UNIFIED IDEOGRAPH-#285DB, IRGKangXi=1266.061, RSKangXi=162.12
285DC CJK UNIFIED IDEOGRAPH-#285DC, IRGKangXi=1266.061, RSKangXi=162.12
285DD CJK UNIFIED IDEOGRAPH-#285DD, IRGKangXi=1266.061, RSKangXi=162.12
285DE CJK UNIFIED IDEOGRAPH-#285DE, IRGKangXi=1266.061, RSKangXi=162.12
285DF CJK UNIFIED IDEOGRAPH-#285DF, IRGKangXi=1266.061, RSKangXi=162.12
285E0 CJK UNIFIED IDEOGRAPH-#285E0, IRGKangXi=1266.061, RSKangXi=162.12
285E1 CJK UNIFIED IDEOGRAPH-#285E1, IRGKangXi=1266.061, RSKangXi=162.12
285E2 CJK UNIFIED IDEOGRAPH-#285E2, IRGKangXi=1266.061, RSKangXi=162.12
285E3 CJK UNIFIED IDEOGRAPH-#285E3, IRGKangXi=1266.061, RSKangXi=162.12
285E4 CJK UNIFIED IDEOGRAPH-#285E4, IRGKangXi=1266.061, RSKangXi=162.12
285E5 CJK UNIFIED IDEOGRAPH-#285E5, IRGKangXi=1266.120, RSKangXi=162.13
285E6 CJK UNIFIED IDEOGRAPH-#285E6, IRGKangXi=1266.130, RSKangXi=162.13
285E7 CJK UNIFIED IDEOGRAPH-#285E7, IRGKangXi=1266.140, RSKangXi=162.13
285E8 CJK UNIFIED IDEOGRAPH-#285E8, IRGKangXi=1266.180, RSKangXi=162.13
285E9 CJK UNIFIED IDEOGRAPH-#285E9, IRGKangXi=1266.190, RSKangXi=162.13
285EA CJK UNIFIED IDEOGRAPH-#285EA, IRGKangXi=1266.200, RSKangXi=162.13
285EB CJK UNIFIED IDEOGRAPH-#285EB, IRGKangXi=1266.270, RSKangXi=162.13
285EC CJK UNIFIED IDEOGRAPH-#285EC, IRGKangXi=1266.280, RSKangXi=162.13
285ED CJK UNIFIED IDEOGRAPH-#285ED, IRGKangXi=1266.290, RSKangXi=162.13
285EE CJK UNIFIED IDEOGRAPH-#285EE, IRGKangXi=1266.300, RSKangXi=162.13
285EF CJK UNIFIED IDEOGRAPH-#285EF, IRGKangXi=1267.010, RSKangXi=162.13
285F0 CJK UNIFIED IDEOGRAPH-#285F0, IRGKangXi=1267.020, RSKangXi=162.13
285F1 CJK UNIFIED IDEOGRAPH-#285F1, IRGKangXi=1267.021, RSKangXi=162.13
285F2 CJK UNIFIED IDEOGRAPH-#285F2, IRGKangXi=1267.021, RSKangXi=162.13
285F3 CJK UNIFIED IDEOGRAPH-#285F3, IRGKangXi=1267.021, RSKangXi=162.13
285F4 CJK UNIFIED IDEOGRAPH-#285F4, IRGKangXi=1267.021, RSKangXi=162.13
285F5 CJK UNIFIED IDEOGRAPH-#285F5, IRGKangXi=1267.021, RSKangXi=162.13
285F6 CJK UNIFIED IDEOGRAPH-#285F6, IRGKangXi=1267.021, RSKangXi=162.13
285F7 CJK UNIFIED IDEOGRAPH-#285F7, IRGKangXi=1267.021, RSKangXi=162.13
285F8 CJK UNIFIED IDEOGRAPH-#285F8, IRGKangXi=1267.021, RSKangXi=162.13
285F9 CJK UNIFIED IDEOGRAPH-#285F9, IRGKangXi=1267.021, RSKangXi=162.13
285FA CJK UNIFIED IDEOGRAPH-#285FA, IRGKangXi=1267.021, RSKangXi=162.13
285FB CJK UNIFIED IDEOGRAPH-#285FB, IRGKangXi=1267.021, RSKangXi=162.13
285FC CJK UNIFIED IDEOGRAPH-#285FC, IRGKangXi=1267.021, RSKangXi=162.13
285FD CJK UNIFIED IDEOGRAPH-#285FD, IRGKangXi=1267.021, RSKangXi=162.13
285FE CJK UNIFIED IDEOGRAPH-#285FE, IRGKangXi=1267.021, RSKangXi=162.13
285FF CJK UNIFIED IDEOGRAPH-#285FF, IRGKangXi=1267.021, RSKangXi=162.13
28600 CJK UNIFIED IDEOGRAPH-#28600, IRGKangXi=1267.021, RSKangXi=162.13
28601 CJK UNIFIED IDEOGRAPH-#28601, IRGKangXi=1267.021, RSKangXi=162.13
28602 CJK UNIFIED IDEOGRAPH-#28602, IRGKangXi=1267.021, RSKangXi=162.13
28603 CJK UNIFIED IDEOGRAPH-#28603, IRGKangXi=1267.021, RSKangXi=162.13
28604 CJK UNIFIED IDEOGRAPH-#28604, IRGKangXi=1267.021, RSKangXi=162.13
28605 CJK UNIFIED IDEOGRAPH-#28605, IRGKangXi=1267.021, RSKangXi=162.13
28606 CJK UNIFIED IDEOGRAPH-#28606, IRGKangXi=1267.021, RSKangXi=162.13
28607 CJK UNIFIED IDEOGRAPH-#28607, IRGKangXi=1267.060, RSKangXi=162.14
28608 CJK UNIFIED IDEOGRAPH-#28608, IRGKangXi=1267.070, RSKangXi=162.14
28609 CJK UNIFIED IDEOGRAPH-#28609, IRGKangXi=1267.090, RSKangXi=162.14
2860A CJK UNIFIED IDEOGRAPH-#2860A, IRGKangXi=1267.110, RSKangXi=162.14
2860B CJK UNIFIED IDEOGRAPH-#2860B, IRGKangXi=1267.111, RSKangXi=162.14
2860C CJK UNIFIED IDEOGRAPH-#2860C, IRGKangXi=1267.111, RSKangXi=162.14
2860D CJK UNIFIED IDEOGRAPH-#2860D, IRGKangXi=1267.111, RSKangXi=162.14
2860E CJK UNIFIED IDEOGRAPH-#2860E, IRGKangXi=1267.111, RSKangXi=162.14
2860F CJK UNIFIED IDEOGRAPH-#2860F, IRGKangXi=1267.111, RSKangXi=162.14
28610 CJK UNIFIED IDEOGRAPH-#28610, IRGKangXi=1267.111, RSKangXi=162.14
28611 CJK UNIFIED IDEOGRAPH-#28611, IRGKangXi=1267.111, RSKangXi=162.14
28612 CJK UNIFIED IDEOGRAPH-#28612, IRGKangXi=1267.111, RSKangXi=162.14
28613 CJK UNIFIED IDEOGRAPH-#28613, IRGKangXi=1267.111, RSKangXi=162.14
28614 CJK UNIFIED IDEOGRAPH-#28614, IRGKangXi=1267.111, RSKangXi=162.14
28615 CJK UNIFIED IDEOGRAPH-#28615, IRGKangXi=1267.111, RSKangXi=162.14
28616 CJK UNIFIED IDEOGRAPH-#28616, IRGKangXi=1267.111, RSKangXi=162.14
28617 CJK UNIFIED IDEOGRAPH-#28617, IRGKangXi=1267.111, RSKangXi=162.14
28618 CJK UNIFIED IDEOGRAPH-#28618, IRGKangXi=1267.111, RSKangXi=162.14
28619 CJK UNIFIED IDEOGRAPH-#28619, IRGKangXi=1267.111, RSKangXi=162.14
2861A CJK UNIFIED IDEOGRAPH-#2861A, IRGKangXi=1267.111, RSKangXi=162.14
2861B CJK UNIFIED IDEOGRAPH-#2861B, IRGKangXi=1267.111, RSKangXi=162.14
2861C CJK UNIFIED IDEOGRAPH-#2861C, IRGKangXi=1267.111, RSKangXi=162.14
2861D CJK UNIFIED IDEOGRAPH-#2861D, IRGKangXi=1267.111, RSKangXi=162.14
2861E CJK UNIFIED IDEOGRAPH-#2861E, IRGKangXi=1267.111, RSKangXi=162.14
2861F CJK UNIFIED IDEOGRAPH-#2861F, IRGKangXi=1267.111, RSKangXi=162.14
28620 CJK UNIFIED IDEOGRAPH-#28620, IRGKangXi=1267.111, RSKangXi=162.14
28621 CJK UNIFIED IDEOGRAPH-#28621, IRGKangXi=1267.170, RSKangXi=162.15
28622 CJK UNIFIED IDEOGRAPH-#28622, IRGKangXi=1267.180, RSKangXi=162.15
28623 CJK UNIFIED IDEOGRAPH-#28623, IRGKangXi=1267.190, RSKangXi=162.15
28624 CJK UNIFIED IDEOGRAPH-#28624, IRGKangXi=1267.191, RSKangXi=162.15
28625 CJK UNIFIED IDEOGRAPH-#28625, IRGKangXi=1267.191, RSKangXi=162.15
28626 CJK UNIFIED IDEOGRAPH-#28626, IRGKangXi=1267.191, RSKangXi=162.15
28627 CJK UNIFIED IDEOGRAPH-#28627, IRGKangXi=1267.191, RSKangXi=162.15
28628 CJK UNIFIED IDEOGRAPH-#28628, IRGKangXi=1267.191, RSKangXi=162.15
28629 CJK UNIFIED IDEOGRAPH-#28629, IRGKangXi=1267.191, RSKangXi=162.15
2862A CJK UNIFIED IDEOGRAPH-#2862A, IRGKangXi=1267.191, RSKangXi=162.15
2862B CJK UNIFIED IDEOGRAPH-#2862B, IRGKangXi=1267.191, RSKangXi=162.15
2862C CJK UNIFIED IDEOGRAPH-#2862C, IRGKangXi=1267.191, RSKangXi=162.15
2862D CJK UNIFIED IDEOGRAPH-#2862D, IRGKangXi=1267.191, RSKangXi=162.15
2862E CJK UNIFIED IDEOGRAPH-#2862E, IRGKangXi=1267.191, RSKangXi=162.15
2862F CJK UNIFIED IDEOGRAPH-#2862F, IRGKangXi=1267.191, RSKangXi=162.15
28630 CJK UNIFIED IDEOGRAPH-#28630, IRGKangXi=1267.191, RSKangXi=162.15
28631 CJK UNIFIED IDEOGRAPH-#28631, IRGKangXi=1267.191, RSKangXi=162.15
28632 CJK UNIFIED IDEOGRAPH-#28632, IRGKangXi=1267.191, RSKangXi=162.15
28633 CJK UNIFIED IDEOGRAPH-#28633, IRGKangXi=1267.191, RSKangXi=162.15
28634 CJK UNIFIED IDEOGRAPH-#28634, IRGKangXi=1267.191, RSKangXi=162.15
28635 CJK UNIFIED IDEOGRAPH-#28635, IRGKangXi=1267.191, RSKangXi=162.15
28636 CJK UNIFIED IDEOGRAPH-#28636, IRGKangXi=1267.191, RSKangXi=162.15
28637 CJK UNIFIED IDEOGRAPH-#28637, IRGKangXi=1267.210, RSKangXi=162.16
28638 CJK UNIFIED IDEOGRAPH-#28638, IRGKangXi=1267.220, RSKangXi=162.16
28639 CJK UNIFIED IDEOGRAPH-#28639, IRGKangXi=1267.230, RSKangXi=162.16
2863A CJK UNIFIED IDEOGRAPH-#2863A, IRGKangXi=1267.231, RSKangXi=162.16
2863B CJK UNIFIED IDEOGRAPH-#2863B, IRGKangXi=1267.231, RSKangXi=162.16
2863C CJK UNIFIED IDEOGRAPH-#2863C, IRGKangXi=1267.231, RSKangXi=159.13
2863D CJK UNIFIED IDEOGRAPH-#2863D, IRGKangXi=1267.231, RSKangXi=162.16
2863E CJK UNIFIED IDEOGRAPH-#2863E, IRGKangXi=1267.231, RSKangXi=162.16
2863F CJK UNIFIED IDEOGRAPH-#2863F, IRGKangXi=1267.231, RSKangXi=162.16
28640 CJK UNIFIED IDEOGRAPH-#28640, IRGKangXi=1267.231, RSKangXi=162.16
28641 CJK UNIFIED IDEOGRAPH-#28641, IRGKangXi=1267.231, RSKangXi=162.16
28642 CJK UNIFIED IDEOGRAPH-#28642, IRGKangXi=1267.240, RSKangXi=162.17
28643 CJK UNIFIED IDEOGRAPH-#28643, IRGKangXi=1267.250, RSKangXi=162.17
28644 CJK UNIFIED IDEOGRAPH-#28644, IRGKangXi=1267.260, RSKangXi=162.17
28645 CJK UNIFIED IDEOGRAPH-#28645, IRGKangXi=1267.270, RSKangXi=162.17
28646 CJK UNIFIED IDEOGRAPH-#28646, IRGKangXi=1267.280, RSKangXi=162.17
28647 CJK UNIFIED IDEOGRAPH-#28647, IRGKangXi=1267.281, RSKangXi=162.17
28648 CJK UNIFIED IDEOGRAPH-#28648, IRGKangXi=1267.281, RSKangXi=162.17
28649 CJK UNIFIED IDEOGRAPH-#28649, IRGKangXi=1267.281, RSKangXi=162.17
2864A CJK UNIFIED IDEOGRAPH-#2864A, IRGKangXi=1267.281, RSKangXi=162.17
2864B CJK UNIFIED IDEOGRAPH-#2864B, IRGKangXi=1267.281, RSKangXi=162.17
2864C CJK UNIFIED IDEOGRAPH-#2864C, IRGKangXi=1267.281, RSKangXi=162.17
2864D CJK UNIFIED IDEOGRAPH-#2864D, IRGKangXi=1267.281, RSKangXi=162.17
2864E CJK UNIFIED IDEOGRAPH-#2864E, IRGKangXi=1267.281, RSKangXi=162.17
2864F CJK UNIFIED IDEOGRAPH-#2864F, IRGKangXi=1267.281, RSKangXi=162.17
28650 CJK UNIFIED IDEOGRAPH-#28650, IRGKangXi=1267.281, RSKangXi=162.17
28651 CJK UNIFIED IDEOGRAPH-#28651, IRGKangXi=1267.281, RSKangXi=162.17
28652 CJK UNIFIED IDEOGRAPH-#28652, IRGKangXi=1267.300, RSKangXi=162.18
28653 CJK UNIFIED IDEOGRAPH-#28653, IRGKangXi=1267.310, RSKangXi=162.18
28654 CJK UNIFIED IDEOGRAPH-#28654, IRGKangXi=1267.320, RSKangXi=162.18
28655 CJK UNIFIED IDEOGRAPH-#28655, IRGKangXi=1267.330, RSKangXi=162.18
28656 CJK UNIFIED IDEOGRAPH-#28656, IRGKangXi=1267.331, RSKangXi=162.18
28657 CJK UNIFIED IDEOGRAPH-#28657, IRGKangXi=1267.331, RSKangXi=162.18
28658 CJK UNIFIED IDEOGRAPH-#28658, IRGKangXi=1267.331, RSKangXi=162.18
28659 CJK UNIFIED IDEOGRAPH-#28659, IRGKangXi=1267.340, RSKangXi=162.19
2865A CJK UNIFIED IDEOGRAPH-#2865A, IRGKangXi=1267.350, RSKangXi=162.19
2865B CJK UNIFIED IDEOGRAPH-#2865B, IRGKangXi=1267.371, RSKangXi=162.19
2865C CJK UNIFIED IDEOGRAPH-#2865C, IRGKangXi=1267.371, RSKangXi=162.19
2865D CJK UNIFIED IDEOGRAPH-#2865D, IRGKangXi=1267.371, RSKangXi=162.19
2865E CJK UNIFIED IDEOGRAPH-#2865E, IRGKangXi=1267.371, RSKangXi=162.19
2865F CJK UNIFIED IDEOGRAPH-#2865F, IRGKangXi=1267.390, RSKangXi=162.20
28660 CJK UNIFIED IDEOGRAPH-#28660, IRGKangXi=1267.400, RSKangXi=162.20
28661 CJK UNIFIED IDEOGRAPH-#28661, IRGKangXi=1267.401, RSKangXi=162.20
28662 CJK UNIFIED IDEOGRAPH-#28662, IRGKangXi=1267.401, RSKangXi=162.20
28663 CJK UNIFIED IDEOGRAPH-#28663, IRGKangXi=1267.401, RSKangXi=162.20
28664 CJK UNIFIED IDEOGRAPH-#28664, IRGKangXi=1267.401, RSKangXi=162.21
28665 CJK UNIFIED IDEOGRAPH-#28665, IRGKangXi=1267.401, RSKangXi=162.21
28666 CJK UNIFIED IDEOGRAPH-#28666, IRGKangXi=1267.410, RSKangXi=162.22
28667 CJK UNIFIED IDEOGRAPH-#28667, IRGKangXi=1267.411, RSKangXi=162.23
28668 CJK UNIFIED IDEOGRAPH-#28668, IRGKangXi=1267.421, RSKangXi=163.0
28669 CJK UNIFIED IDEOGRAPH-#28669, IRGKangXi=1268.030, RSKangXi=163.2
2866A CJK UNIFIED IDEOGRAPH-#2866A, IRGKangXi=1268.031, RSKangXi=163.2
2866B CJK UNIFIED IDEOGRAPH-#2866B, IRGKangXi=1268.040, RSKangXi=163.3
2866C CJK UNIFIED IDEOGRAPH-#2866C, IRGKangXi=1268.050, RSKangXi=163.3
2866D CJK UNIFIED IDEOGRAPH-#2866D, IRGKangXi=1268.110, RSKangXi=163.3
2866E CJK UNIFIED IDEOGRAPH-#2866E, IRGKangXi=1268.130, RSKangXi=163.3
2866F CJK UNIFIED IDEOGRAPH-#2866F, IRGKangXi=1268.140, RSKangXi=163.3
28670 CJK UNIFIED IDEOGRAPH-#28670, IRGKangXi=1268.150, RSKangXi=163.3
28671 CJK UNIFIED IDEOGRAPH-#28671, IRGKangXi=1268.170, RSKangXi=163.3
28672 CJK UNIFIED IDEOGRAPH-#28672, IRGKangXi=1268.181, RSKangXi=163.3
28673 CJK UNIFIED IDEOGRAPH-#28673, IRGKangXi=1268.181, RSKangXi=163.3
28674 CJK UNIFIED IDEOGRAPH-#28674, IRGKangXi=1268.181, RSKangXi=163.3
28675 CJK UNIFIED IDEOGRAPH-#28675, IRGKangXi=1268.181, RSKangXi=163.3
28676 CJK UNIFIED IDEOGRAPH-#28676, IRGKangXi=1268.210, RSKangXi=163.4
28677 CJK UNIFIED IDEOGRAPH-#28677, IRGKangXi=1268.230, RSKangXi=163.4
28678 CJK UNIFIED IDEOGRAPH-#28678, IRGKangXi=1268.240, RSKangXi=163.4
28679 CJK UNIFIED IDEOGRAPH-#28679, IRGKangXi=1268.280, RSKangXi=163.4
2867A CJK UNIFIED IDEOGRAPH-#2867A, IRGKangXi=1268.290, RSKangXi=163.4
2867B CJK UNIFIED IDEOGRAPH-#2867B, IRGKangXi=1269.010, RSKangXi=163.4
2867C CJK UNIFIED IDEOGRAPH-#2867C, IRGKangXi=1269.120, RSKangXi=163.4
2867D CJK UNIFIED IDEOGRAPH-#2867D, IRGKangXi=1269.130, RSKangXi=163.4
2867E CJK UNIFIED IDEOGRAPH-#2867E, IRGKangXi=1269.160, RSKangXi=163.4
2867F CJK UNIFIED IDEOGRAPH-#2867F, IRGKangXi=1269.161, RSKangXi=163.4
28680 CJK UNIFIED IDEOGRAPH-#28680, IRGKangXi=1269.161, RSKangXi=163.4
28681 CJK UNIFIED IDEOGRAPH-#28681, IRGKangXi=1269.161, RSKangXi=163.4
28682 CJK UNIFIED IDEOGRAPH-#28682, IRGKangXi=1269.161, RSKangXi=163.4
28683 CJK UNIFIED IDEOGRAPH-#28683, IRGKangXi=1269.161, RSKangXi=163.4
28684 CJK UNIFIED IDEOGRAPH-#28684, IRGKangXi=1269.161, RSKangXi=163.4
28685 CJK UNIFIED IDEOGRAPH-#28685, IRGKangXi=1269.161, RSKangXi=163.4
28686 CJK UNIFIED IDEOGRAPH-#28686, IRGKangXi=1269.161, RSKangXi=163.4
28687 CJK UNIFIED IDEOGRAPH-#28687, IRGKangXi=1269.161, RSKangXi=163.4
28688 CJK UNIFIED IDEOGRAPH-#28688, IRGKangXi=1269.161, RSKangXi=163.4
28689 CJK UNIFIED IDEOGRAPH-#28689, IRGKangXi=1269.161, RSKangXi=163.4
2868A CJK UNIFIED IDEOGRAPH-#2868A, IRGKangXi=1269.161, RSKangXi=163.4
2868B CJK UNIFIED IDEOGRAPH-#2868B, IRGKangXi=1269.161, RSKangXi=163.4
2868C CJK UNIFIED IDEOGRAPH-#2868C, IRGKangXi=1269.161, RSKangXi=163.4
2868D CJK UNIFIED IDEOGRAPH-#2868D, IRGKangXi=1269.161, RSKangXi=163.4
2868E CJK UNIFIED IDEOGRAPH-#2868E, IRGKangXi=1269.161, RSKangXi=163.4
2868F CJK UNIFIED IDEOGRAPH-#2868F, IRGKangXi=1269.161, RSKangXi=163.4
28690 CJK UNIFIED IDEOGRAPH-#28690, IRGKangXi=1269.161, RSKangXi=163.4
28691 CJK UNIFIED IDEOGRAPH-#28691, IRGKangXi=1269.161, RSKangXi=163.4
28692 CJK UNIFIED IDEOGRAPH-#28692, IRGKangXi=1269.161, RSKangXi=163.4
28693 CJK UNIFIED IDEOGRAPH-#28693, IRGKangXi=1269.170, RSKangXi=163.5
28694 CJK UNIFIED IDEOGRAPH-#28694, IRGKangXi=1269.190, RSKangXi=163.5
28695 CJK UNIFIED IDEOGRAPH-#28695, IRGKangXi=1269.210, RSKangXi=163.5
28696 CJK UNIFIED IDEOGRAPH-#28696, IRGKangXi=1269.240, RSKangXi=163.5
28697 CJK UNIFIED IDEOGRAPH-#28697, IRGKangXi=1269.250, RSKangXi=163.5
28698 CJK UNIFIED IDEOGRAPH-#28698, IRGKangXi=1269.270, RSKangXi=163.5
28699 CJK UNIFIED IDEOGRAPH-#28699, IRGKangXi=1270.040, RSKangXi=163.5
2869A CJK UNIFIED IDEOGRAPH-#2869A, IRGKangXi=1270.070, RSKangXi=163.5
2869B CJK UNIFIED IDEOGRAPH-#2869B, IRGKangXi=1270.071, RSKangXi=163.5
2869C CJK UNIFIED IDEOGRAPH-#2869C, IRGKangXi=1270.071, RSKangXi=163.5
2869D CJK UNIFIED IDEOGRAPH-#2869D, IRGKangXi=1270.071, RSKangXi=163.5
2869E CJK UNIFIED IDEOGRAPH-#2869E, IRGKangXi=1270.071, RSKangXi=163.5
2869F CJK UNIFIED IDEOGRAPH-#2869F, IRGKangXi=1270.071, RSKangXi=163.5
286A0 CJK UNIFIED IDEOGRAPH-#286A0, IRGKangXi=1270.071, RSKangXi=163.5
286A1 CJK UNIFIED IDEOGRAPH-#286A1, IRGKangXi=1270.071, RSKangXi=163.5
286A2 CJK UNIFIED IDEOGRAPH-#286A2, IRGKangXi=1270.071, RSKangXi=163.5
286A3 CJK UNIFIED IDEOGRAPH-#286A3, IRGKangXi=1270.071, RSKangXi=163.5
286A4 CJK UNIFIED IDEOGRAPH-#286A4, IRGKangXi=1270.071, RSKangXi=163.5
286A5 CJK UNIFIED IDEOGRAPH-#286A5, IRGKangXi=1270.071, RSKangXi=163.5
286A6 CJK UNIFIED IDEOGRAPH-#286A6, IRGKangXi=1270.071, RSKangXi=163.5
286A7 CJK UNIFIED IDEOGRAPH-#286A7, IRGKangXi=1270.071, RSKangXi=163.5
286A8 CJK UNIFIED IDEOGRAPH-#286A8, IRGKangXi=1270.071, RSKangXi=163.5
286A9 CJK UNIFIED IDEOGRAPH-#286A9, IRGKangXi=1270.071, RSKangXi=163.5
286AA CJK UNIFIED IDEOGRAPH-#286AA, IRGKangXi=1270.071, RSKangXi=163.5
286AB CJK UNIFIED IDEOGRAPH-#286AB, IRGKangXi=1270.071, RSKangXi=163.5
286AC CJK UNIFIED IDEOGRAPH-#286AC, IRGKangXi=1270.071, RSKangXi=163.5
286AD CJK UNIFIED IDEOGRAPH-#286AD, IRGKangXi=1270.071, RSKangXi=163.5
286AE CJK UNIFIED IDEOGRAPH-#286AE, IRGKangXi=1270.071, RSKangXi=163.5
286AF CJK UNIFIED IDEOGRAPH-#286AF, IRGKangXi=1270.110, RSKangXi=163.6
286B0 CJK UNIFIED IDEOGRAPH-#286B0, IRGKangXi=1270.160, RSKangXi=163.6
286B1 CJK UNIFIED IDEOGRAPH-#286B1, IRGKangXi=1270.180, RSKangXi=163.6
286B2 CJK UNIFIED IDEOGRAPH-#286B2, IRGKangXi=1270.210, RSKangXi=163.6
286B3 CJK UNIFIED IDEOGRAPH-#286B3, IRGKangXi=1271.020, RSKangXi=163.6
286B4 CJK UNIFIED IDEOGRAPH-#286B4, IRGKangXi=1271.030, RSKangXi=163.6
286B5 CJK UNIFIED IDEOGRAPH-#286B5, IRGKangXi=1271.040, RSKangXi=163.6
286B6 CJK UNIFIED IDEOGRAPH-#286B6, IRGKangXi=1271.100, RSKangXi=163.6
286B7 CJK UNIFIED IDEOGRAPH-#286B7, IRGKangXi=1271.121, RSKangXi=163.6
286B8 CJK UNIFIED IDEOGRAPH-#286B8, IRGKangXi=1271.121, RSKangXi=163.6
286B9 CJK UNIFIED IDEOGRAPH-#286B9, IRGKangXi=1271.121, RSKangXi=163.6
286BA CJK UNIFIED IDEOGRAPH-#286BA, IRGKangXi=1271.121, RSKangXi=163.6
286BB CJK UNIFIED IDEOGRAPH-#286BB, IRGKangXi=1271.121, RSKangXi=163.6
286BC CJK UNIFIED IDEOGRAPH-#286BC, IRGKangXi=1271.121, RSKangXi=163.6
286BD CJK UNIFIED IDEOGRAPH-#286BD, IRGKangXi=1271.121, RSKangXi=163.6
286BE CJK UNIFIED IDEOGRAPH-#286BE, IRGKangXi=1271.121, RSKangXi=163.6
286BF CJK UNIFIED IDEOGRAPH-#286BF, IRGKangXi=1271.121, RSKangXi=163.6
286C0 CJK UNIFIED IDEOGRAPH-#286C0, IRGKangXi=1271.121, RSKangXi=163.6
286C1 CJK UNIFIED IDEOGRAPH-#286C1, IRGKangXi=1271.121, RSKangXi=163.6
286C2 CJK UNIFIED IDEOGRAPH-#286C2, IRGKangXi=1271.121, RSKangXi=163.6
286C3 CJK UNIFIED IDEOGRAPH-#286C3, IRGKangXi=1271.121, RSKangXi=163.6
286C4 CJK UNIFIED IDEOGRAPH-#286C4, IRGKangXi=1271.121, RSKangXi=163.6
286C5 CJK UNIFIED IDEOGRAPH-#286C5, IRGKangXi=1271.121, RSKangXi=163.6
286C6 CJK UNIFIED IDEOGRAPH-#286C6, IRGKangXi=1271.121, RSKangXi=163.6
286C7 CJK UNIFIED IDEOGRAPH-#286C7, IRGKangXi=1271.121, RSKangXi=163.6
286C8 CJK UNIFIED IDEOGRAPH-#286C8, IRGKangXi=1271.121, RSKangXi=163.6
286C9 CJK UNIFIED IDEOGRAPH-#286C9, IRGKangXi=1271.121, RSKangXi=163.6
286CA CJK UNIFIED IDEOGRAPH-#286CA, IRGKangXi=1271.121, RSKangXi=163.6
286CB CJK UNIFIED IDEOGRAPH-#286CB, IRGKangXi=1271.130, RSKangXi=163.7
286CC CJK UNIFIED IDEOGRAPH-#286CC, IRGKangXi=1271.170, RSKangXi=163.7
286CD CJK UNIFIED IDEOGRAPH-#286CD, IRGKangXi=1271.210, RSKangXi=163.7
286CE CJK UNIFIED IDEOGRAPH-#286CE, IRGKangXi=1271.230, RSKangXi=163.7
286CF CJK UNIFIED IDEOGRAPH-#286CF, IRGKangXi=1271.240, RSKangXi=163.7
286D0 CJK UNIFIED IDEOGRAPH-#286D0, IRGKangXi=1271.270, RSKangXi=163.7
286D1 CJK UNIFIED IDEOGRAPH-#286D1, IRGKangXi=1271.280, RSKangXi=163.7
286D2 CJK UNIFIED IDEOGRAPH-#286D2, IRGKangXi=1271.290, RSKangXi=163.7
286D3 CJK UNIFIED IDEOGRAPH-#286D3, IRGKangXi=1271.300, RSKangXi=163.7
286D4 CJK UNIFIED IDEOGRAPH-#286D4, IRGKangXi=1271.310, RSKangXi=163.7
286D5 CJK UNIFIED IDEOGRAPH-#286D5, IRGKangXi=1271.330, RSKangXi=163.7
286D6 CJK UNIFIED IDEOGRAPH-#286D6, IRGKangXi=1272.030, RSKangXi=163.7
286D7 CJK UNIFIED IDEOGRAPH-#286D7, IRGKangXi=1272.101, RSKangXi=163.7
286D8 CJK UNIFIED IDEOGRAPH-#286D8, IRGKangXi=1272.101, RSKangXi=163.7
286D9 CJK UNIFIED IDEOGRAPH-#286D9, IRGKangXi=1272.101, RSKangXi=163.7
286DA CJK UNIFIED IDEOGRAPH-#286DA, IRGKangXi=1272.101, RSKangXi=163.7
286DB CJK UNIFIED IDEOGRAPH-#286DB, IRGKangXi=1272.101, RSKangXi=163.7
286DC CJK UNIFIED IDEOGRAPH-#286DC, IRGKangXi=1272.101, RSKangXi=163.7
286DD CJK UNIFIED IDEOGRAPH-#286DD, IRGKangXi=1272.101, RSKangXi=163.7
286DE CJK UNIFIED IDEOGRAPH-#286DE, IRGKangXi=1272.101, RSKangXi=163.7
286DF CJK UNIFIED IDEOGRAPH-#286DF, IRGKangXi=1272.101, RSKangXi=163.7
286E0 CJK UNIFIED IDEOGRAPH-#286E0, IRGKangXi=1272.101, RSKangXi=163.7
286E1 CJK UNIFIED IDEOGRAPH-#286E1, IRGKangXi=1272.101, RSKangXi=163.7
286E2 CJK UNIFIED IDEOGRAPH-#286E2, IRGKangXi=1272.101, RSKangXi=163.7
286E3 CJK UNIFIED IDEOGRAPH-#286E3, IRGKangXi=1272.101, RSKangXi=163.7
286E4 CJK UNIFIED IDEOGRAPH-#286E4, IRGKangXi=1272.101, RSKangXi=163.7
286E5 CJK UNIFIED IDEOGRAPH-#286E5, IRGKangXi=1272.101, RSKangXi=163.7
286E6 CJK UNIFIED IDEOGRAPH-#286E6, IRGKangXi=1272.101, RSKangXi=163.7
286E7 CJK UNIFIED IDEOGRAPH-#286E7, IRGKangXi=1272.101, RSKangXi=163.7
286E8 CJK UNIFIED IDEOGRAPH-#286E8, IRGKangXi=1272.101, RSKangXi=163.7
286E9 CJK UNIFIED IDEOGRAPH-#286E9, IRGKangXi=1272.101, RSKangXi=163.7
286EA CJK UNIFIED IDEOGRAPH-#286EA, IRGKangXi=1272.101, RSKangXi=163.7
286EB CJK UNIFIED IDEOGRAPH-#286EB, IRGKangXi=1272.110, RSKangXi=163.8
286EC CJK UNIFIED IDEOGRAPH-#286EC, IRGKangXi=1272.130, RSKangXi=163.8
286ED CJK UNIFIED IDEOGRAPH-#286ED, IRGKangXi=1272.140, RSKangXi=163.8
286EE CJK UNIFIED IDEOGRAPH-#286EE, IRGKangXi=1272.150, RSKangXi=163.8
286EF CJK UNIFIED IDEOGRAPH-#286EF, IRGKangXi=1272.160, RSKangXi=163.8
286F0 CJK UNIFIED IDEOGRAPH-#286F0, IRGKangXi=1273.030, RSKangXi=163.8
286F1 CJK UNIFIED IDEOGRAPH-#286F1, IRGKangXi=1273.060, RSKangXi=163.8
286F2 CJK UNIFIED IDEOGRAPH-#286F2, IRGKangXi=1273.080, RSKangXi=163.8
286F3 CJK UNIFIED IDEOGRAPH-#286F3, IRGKangXi=1273.100, RSKangXi=163.8
286F4 CJK UNIFIED IDEOGRAPH-#286F4, IRGKangXi=1273.120, RSKangXi=163.8
286F5 CJK UNIFIED IDEOGRAPH-#286F5, IRGKangXi=1273.220, RSKangXi=163.8
286F6 CJK UNIFIED IDEOGRAPH-#286F6, IRGKangXi=1273.250, RSKangXi=163.8
286F7 CJK UNIFIED IDEOGRAPH-#286F7, IRGKangXi=1273.260, RSKangXi=163.8
286F8 CJK UNIFIED IDEOGRAPH-#286F8, IRGKangXi=1273.270, RSKangXi=163.8
286F9 CJK UNIFIED IDEOGRAPH-#286F9, IRGKangXi=1273.271, RSKangXi=163.8
286FA CJK UNIFIED IDEOGRAPH-#286FA, IRGKangXi=1273.271, RSKangXi=163.8
286FB CJK UNIFIED IDEOGRAPH-#286FB, IRGKangXi=1273.271, RSKangXi=163.8
286FC CJK UNIFIED IDEOGRAPH-#286FC, IRGKangXi=1273.271, RSKangXi=163.8
286FD CJK UNIFIED IDEOGRAPH-#286FD, IRGKangXi=1273.271, RSKangXi=163.8
286FE CJK UNIFIED IDEOGRAPH-#286FE, IRGKangXi=1273.271, RSKangXi=163.8
286FF CJK UNIFIED IDEOGRAPH-#286FF, IRGKangXi=1273.271, RSKangXi=163.8
28700 CJK UNIFIED IDEOGRAPH-#28700, IRGKangXi=1273.271, RSKangXi=163.8
28701 CJK UNIFIED IDEOGRAPH-#28701, IRGKangXi=1273.271, RSKangXi=163.8
28702 CJK UNIFIED IDEOGRAPH-#28702, IRGKangXi=1273.271, RSKangXi=163.8
28703 CJK UNIFIED IDEOGRAPH-#28703, IRGKangXi=1273.271, RSKangXi=163.8
28704 CJK UNIFIED IDEOGRAPH-#28704, IRGKangXi=1273.271, RSKangXi=163.8
28705 CJK UNIFIED IDEOGRAPH-#28705, IRGKangXi=1273.271, RSKangXi=163.8
28706 CJK UNIFIED IDEOGRAPH-#28706, IRGKangXi=1273.271, RSKangXi=163.8
28707 CJK UNIFIED IDEOGRAPH-#28707, IRGKangXi=1273.271, RSKangXi=163.8
28708 CJK UNIFIED IDEOGRAPH-#28708, IRGKangXi=1273.271, RSKangXi=163.8
28709 CJK UNIFIED IDEOGRAPH-#28709, IRGKangXi=1273.271, RSKangXi=163.8
2870A CJK UNIFIED IDEOGRAPH-#2870A, IRGKangXi=1273.271, RSKangXi=163.8
2870B CJK UNIFIED IDEOGRAPH-#2870B, IRGKangXi=1273.271, RSKangXi=163.8
2870C CJK UNIFIED IDEOGRAPH-#2870C, IRGKangXi=1273.271, RSKangXi=163.8
2870D CJK UNIFIED IDEOGRAPH-#2870D, IRGKangXi=1273.271, RSKangXi=163.8
2870E CJK UNIFIED IDEOGRAPH-#2870E, IRGKangXi=1273.271, RSKangXi=163.8
2870F CJK UNIFIED IDEOGRAPH-#2870F, IRGKangXi=1274.010, RSKangXi=163.9
28710 CJK UNIFIED IDEOGRAPH-#28710, IRGKangXi=1274.030, RSKangXi=163.9
28711 CJK UNIFIED IDEOGRAPH-#28711, IRGKangXi=1274.040, RSKangXi=163.9
28712 CJK UNIFIED IDEOGRAPH-#28712, IRGKangXi=1274.050, RSKangXi=163.9
28713 CJK UNIFIED IDEOGRAPH-#28713, IRGKangXi=1274.110, RSKangXi=163.9
28714 CJK UNIFIED IDEOGRAPH-#28714, IRGKangXi=1274.120, RSKangXi=163.9
28715 CJK UNIFIED IDEOGRAPH-#28715, IRGKangXi=1274.130, RSKangXi=163.9
28716 CJK UNIFIED IDEOGRAPH-#28716, IRGKangXi=1274.160, RSKangXi=163.9
28717 CJK UNIFIED IDEOGRAPH-#28717, IRGKangXi=1274.190, RSKangXi=163.10
28718 CJK UNIFIED IDEOGRAPH-#28718, IRGKangXi=1274.210, RSKangXi=163.9
28719 CJK UNIFIED IDEOGRAPH-#28719, IRGKangXi=1274.230, RSKangXi=163.9
2871A CJK UNIFIED IDEOGRAPH-#2871A, IRGKangXi=1274.260, RSKangXi=163.9
2871B CJK UNIFIED IDEOGRAPH-#2871B, IRGKangXi=1274.280, RSKangXi=163.9
2871C CJK UNIFIED IDEOGRAPH-#2871C, IRGKangXi=1274.290, RSKangXi=163.9
2871D CJK UNIFIED IDEOGRAPH-#2871D, IRGKangXi=1275.021, RSKangXi=163.9
2871E CJK UNIFIED IDEOGRAPH-#2871E, IRGKangXi=1275.021, RSKangXi=163.9
2871F CJK UNIFIED IDEOGRAPH-#2871F, IRGKangXi=1275.021, RSKangXi=163.9
28720 CJK UNIFIED IDEOGRAPH-#28720, IRGKangXi=1275.021, RSKangXi=163.9
28721 CJK UNIFIED IDEOGRAPH-#28721, IRGKangXi=1275.021, RSKangXi=163.9
28722 CJK UNIFIED IDEOGRAPH-#28722, IRGKangXi=1275.021, RSKangXi=163.9
28723 CJK UNIFIED IDEOGRAPH-#28723, IRGKangXi=1275.021, RSKangXi=163.9
28724 CJK UNIFIED IDEOGRAPH-#28724, IRGKangXi=1275.021, RSKangXi=163.9
28725 CJK UNIFIED IDEOGRAPH-#28725, IRGKangXi=1275.021, RSKangXi=163.9
28726 CJK UNIFIED IDEOGRAPH-#28726, IRGKangXi=1275.021, RSKangXi=163.9
28727 CJK UNIFIED IDEOGRAPH-#28727, IRGKangXi=1275.021, RSKangXi=163.9
28728 CJK UNIFIED IDEOGRAPH-#28728, IRGKangXi=1275.021, RSKangXi=163.9
28729 CJK UNIFIED IDEOGRAPH-#28729, IRGKangXi=1275.021, RSKangXi=163.9
2872A CJK UNIFIED IDEOGRAPH-#2872A, IRGKangXi=1275.021, RSKangXi=163.9
2872B CJK UNIFIED IDEOGRAPH-#2872B, IRGKangXi=1275.021, RSKangXi=163.9
2872C CJK UNIFIED IDEOGRAPH-#2872C, IRGKangXi=1275.021, RSKangXi=163.9
2872D CJK UNIFIED IDEOGRAPH-#2872D, IRGKangXi=1275.021, RSKangXi=163.9
2872E CJK UNIFIED IDEOGRAPH-#2872E, IRGKangXi=1275.021, RSKangXi=163.9
2872F CJK UNIFIED IDEOGRAPH-#2872F, IRGKangXi=1275.021, RSKangXi=163.9
28730 CJK UNIFIED IDEOGRAPH-#28730, IRGKangXi=1275.021, RSKangXi=163.9
28731 CJK UNIFIED IDEOGRAPH-#28731, IRGKangXi=1275.021, RSKangXi=163.9
28732 CJK UNIFIED IDEOGRAPH-#28732, IRGKangXi=1275.021, RSKangXi=163.10
28733 CJK UNIFIED IDEOGRAPH-#28733, IRGKangXi=1275.030, RSKangXi=163.10
28734 CJK UNIFIED IDEOGRAPH-#28734, IRGKangXi=1275.040, RSKangXi=163.10
28735 CJK UNIFIED IDEOGRAPH-#28735, IRGKangXi=1275.060, RSKangXi=163.10
28736 CJK UNIFIED IDEOGRAPH-#28736, IRGKangXi=1275.070, RSKangXi=163.10
28737 CJK UNIFIED IDEOGRAPH-#28737, IRGKangXi=1275.080, RSKangXi=163.10
28738 CJK UNIFIED IDEOGRAPH-#28738, IRGKangXi=1275.090, RSKangXi=163.10
28739 CJK UNIFIED IDEOGRAPH-#28739, IRGKangXi=1275.160, RSKangXi=163.10
2873A CJK UNIFIED IDEOGRAPH-#2873A, IRGKangXi=1275.190, RSKangXi=163.10
2873B CJK UNIFIED IDEOGRAPH-#2873B, IRGKangXi=1275.220, RSKangXi=163.10
2873C CJK UNIFIED IDEOGRAPH-#2873C, IRGKangXi=1275.230, RSKangXi=163.10
2873D CJK UNIFIED IDEOGRAPH-#2873D, IRGKangXi=1275.240, RSKangXi=163.10
2873E CJK UNIFIED IDEOGRAPH-#2873E, IRGKangXi=1275.270, RSKangXi=163.10
2873F CJK UNIFIED IDEOGRAPH-#2873F, IRGKangXi=1276.020, RSKangXi=163.10
28740 CJK UNIFIED IDEOGRAPH-#28740, IRGKangXi=1276.030, RSKangXi=163.10
28741 CJK UNIFIED IDEOGRAPH-#28741, IRGKangXi=1276.040, RSKangXi=163.10
28742 CJK UNIFIED IDEOGRAPH-#28742, IRGKangXi=1276.051, RSKangXi=163.10
28743 CJK UNIFIED IDEOGRAPH-#28743, IRGKangXi=1276.051, RSKangXi=163.10
28744 CJK UNIFIED IDEOGRAPH-#28744, IRGKangXi=1276.051, RSKangXi=163.10
28745 CJK UNIFIED IDEOGRAPH-#28745, IRGKangXi=1276.051, RSKangXi=163.10
28746 CJK UNIFIED IDEOGRAPH-#28746, IRGKangXi=1276.051, RSKangXi=163.10
28747 CJK UNIFIED IDEOGRAPH-#28747, IRGKangXi=1276.051, RSKangXi=163.10
28748 CJK UNIFIED IDEOGRAPH-#28748, IRGKangXi=1276.051, RSKangXi=163.10
28749 CJK UNIFIED IDEOGRAPH-#28749, IRGKangXi=1276.051, RSKangXi=163.10
2874A CJK UNIFIED IDEOGRAPH-#2874A, IRGKangXi=1276.051, RSKangXi=163.10
2874B CJK UNIFIED IDEOGRAPH-#2874B, IRGKangXi=1276.060, RSKangXi=163.11
2874C CJK UNIFIED IDEOGRAPH-#2874C, IRGKangXi=1276.070, RSKangXi=163.11
2874D CJK UNIFIED IDEOGRAPH-#2874D, IRGKangXi=1276.080, RSKangXi=163.11
2874E CJK UNIFIED IDEOGRAPH-#2874E, IRGKangXi=1276.100, RSKangXi=163.11
2874F CJK UNIFIED IDEOGRAPH-#2874F, IRGKangXi=1276.110, RSKangXi=163.11
28750 CJK UNIFIED IDEOGRAPH-#28750, IRGKangXi=1276.120, RSKangXi=163.11
28751 CJK UNIFIED IDEOGRAPH-#28751, IRGKangXi=1276.140, RSKangXi=163.11
28752 CJK UNIFIED IDEOGRAPH-#28752, IRGKangXi=1276.150, RSKangXi=163.11
28753 CJK UNIFIED IDEOGRAPH-#28753, IRGKangXi=1276.160, RSKangXi=163.11
28754 CJK UNIFIED IDEOGRAPH-#28754, IRGKangXi=1276.200, RSKangXi=163.11
28755 CJK UNIFIED IDEOGRAPH-#28755, IRGKangXi=1276.240, RSKangXi=163.11
28756 CJK UNIFIED IDEOGRAPH-#28756, IRGKangXi=1277.010, RSKangXi=163.11
28757 CJK UNIFIED IDEOGRAPH-#28757, IRGKangXi=1277.050, RSKangXi=163.11
28758 CJK UNIFIED IDEOGRAPH-#28758, IRGKangXi=1277.060, RSKangXi=163.11
28759 CJK UNIFIED IDEOGRAPH-#28759, IRGKangXi=1277.091, RSKangXi=163.11
2875A CJK UNIFIED IDEOGRAPH-#2875A, IRGKangXi=1277.091, RSKangXi=163.11
2875B CJK UNIFIED IDEOGRAPH-#2875B, IRGKangXi=1277.091, RSKangXi=163.11
2875C CJK UNIFIED IDEOGRAPH-#2875C, IRGKangXi=1277.091, RSKangXi=163.11
2875D CJK UNIFIED IDEOGRAPH-#2875D, IRGKangXi=1277.091, RSKangXi=163.11
2875E CJK UNIFIED IDEOGRAPH-#2875E, IRGKangXi=1277.091, RSKangXi=163.11
2875F CJK UNIFIED IDEOGRAPH-#2875F, IRGKangXi=1277.091, RSKangXi=163.11
28760 CJK UNIFIED IDEOGRAPH-#28760, IRGKangXi=1277.091, RSKangXi=163.11
28761 CJK UNIFIED IDEOGRAPH-#28761, IRGKangXi=1277.091, RSKangXi=163.11
28762 CJK UNIFIED IDEOGRAPH-#28762, IRGKangXi=1277.091, RSKangXi=163.11
28763 CJK UNIFIED IDEOGRAPH-#28763, IRGKangXi=1277.091, RSKangXi=163.11
28764 CJK UNIFIED IDEOGRAPH-#28764, IRGKangXi=1277.091, RSKangXi=163.11
28765 CJK UNIFIED IDEOGRAPH-#28765, IRGKangXi=1277.091, RSKangXi=163.11
28766 CJK UNIFIED IDEOGRAPH-#28766, IRGKangXi=1277.091, RSKangXi=163.11
28767 CJK UNIFIED IDEOGRAPH-#28767, IRGKangXi=1277.091, RSKangXi=163.11
28768 CJK UNIFIED IDEOGRAPH-#28768, IRGKangXi=1277.091, RSKangXi=163.11
28769 CJK UNIFIED IDEOGRAPH-#28769, IRGKangXi=1277.091, RSKangXi=163.11
2876A CJK UNIFIED IDEOGRAPH-#2876A, IRGKangXi=1277.091, RSKangXi=163.11
2876B CJK UNIFIED IDEOGRAPH-#2876B, IRGKangXi=1277.100, RSKangXi=163.12
2876C CJK UNIFIED IDEOGRAPH-#2876C, IRGKangXi=1277.110, RSKangXi=163.12
2876D CJK UNIFIED IDEOGRAPH-#2876D, IRGKangXi=1277.140, RSKangXi=163.12
2876E CJK UNIFIED IDEOGRAPH-#2876E, IRGKangXi=1277.170, RSKangXi=163.12
2876F CJK UNIFIED IDEOGRAPH-#2876F, IRGKangXi=1277.200, RSKangXi=163.12
28770 CJK UNIFIED IDEOGRAPH-#28770, IRGKangXi=1277.210, RSKangXi=163.12
28771 CJK UNIFIED IDEOGRAPH-#28771, IRGKangXi=1277.220, RSKangXi=163.12
28772 CJK UNIFIED IDEOGRAPH-#28772, IRGKangXi=1277.230, RSKangXi=163.12
28773 CJK UNIFIED IDEOGRAPH-#28773, IRGKangXi=1277.240, RSKangXi=163.12
28774 CJK UNIFIED IDEOGRAPH-#28774, IRGKangXi=1277.250, RSKangXi=163.12
28775 CJK UNIFIED IDEOGRAPH-#28775, IRGKangXi=1277.290, RSKangXi=163.12
28776 CJK UNIFIED IDEOGRAPH-#28776, IRGKangXi=1278.010, RSKangXi=163.12
28777 CJK UNIFIED IDEOGRAPH-#28777, IRGKangXi=1278.020, RSKangXi=163.12
28778 CJK UNIFIED IDEOGRAPH-#28778, IRGKangXi=1278.040, RSKangXi=163.12
28779 CJK UNIFIED IDEOGRAPH-#28779, IRGKangXi=1278.111, RSKangXi=163.11
2877A CJK UNIFIED IDEOGRAPH-#2877A, IRGKangXi=1278.111, RSKangXi=163.12
2877B CJK UNIFIED IDEOGRAPH-#2877B, IRGKangXi=1278.111, RSKangXi=163.12
2877C CJK UNIFIED IDEOGRAPH-#2877C, IRGKangXi=1278.111, RSKangXi=163.12
2877D CJK UNIFIED IDEOGRAPH-#2877D, IRGKangXi=1278.111, RSKangXi=163.12
2877E CJK UNIFIED IDEOGRAPH-#2877E, IRGKangXi=1278.111, RSKangXi=163.12
2877F CJK UNIFIED IDEOGRAPH-#2877F, IRGKangXi=1278.111, RSKangXi=163.12
28780 CJK UNIFIED IDEOGRAPH-#28780, IRGKangXi=1278.111, RSKangXi=163.12
28781 CJK UNIFIED IDEOGRAPH-#28781, IRGKangXi=1278.111, RSKangXi=163.12
28782 CJK UNIFIED IDEOGRAPH-#28782, IRGKangXi=1278.111, RSKangXi=163.12
28783 CJK UNIFIED IDEOGRAPH-#28783, IRGKangXi=1278.111, RSKangXi=163.12
28784 CJK UNIFIED IDEOGRAPH-#28784, IRGKangXi=1278.111, RSKangXi=163.12
28785 CJK UNIFIED IDEOGRAPH-#28785, IRGKangXi=1278.111, RSKangXi=163.12
28786 CJK UNIFIED IDEOGRAPH-#28786, IRGKangXi=1278.111, RSKangXi=163.12
28787 CJK UNIFIED IDEOGRAPH-#28787, IRGKangXi=1278.111, RSKangXi=163.12
28788 CJK UNIFIED IDEOGRAPH-#28788, IRGKangXi=1278.111, RSKangXi=163.12
28789 CJK UNIFIED IDEOGRAPH-#28789, IRGKangXi=1278.111, RSKangXi=163.12
2878A CJK UNIFIED IDEOGRAPH-#2878A, IRGKangXi=1278.111, RSKangXi=163.12
2878B CJK UNIFIED IDEOGRAPH-#2878B, IRGKangXi=1278.111, RSKangXi=163.12
2878C CJK UNIFIED IDEOGRAPH-#2878C, IRGKangXi=1278.111, RSKangXi=163.12
2878D CJK UNIFIED IDEOGRAPH-#2878D, IRGKangXi=1278.111, RSKangXi=163.12
2878E CJK UNIFIED IDEOGRAPH-#2878E, IRGKangXi=1278.111, RSKangXi=163.12
2878F CJK UNIFIED IDEOGRAPH-#2878F, IRGKangXi=1278.111, RSKangXi=163.12
28790 CJK UNIFIED IDEOGRAPH-#28790, IRGKangXi=1278.111, RSKangXi=163.12
28791 CJK UNIFIED IDEOGRAPH-#28791, IRGKangXi=1278.120, RSKangXi=163.13
28792 CJK UNIFIED IDEOGRAPH-#28792, IRGKangXi=1278.130, RSKangXi=163.13
28793 CJK UNIFIED IDEOGRAPH-#28793, IRGKangXi=1278.140, RSKangXi=163.13
28794 CJK UNIFIED IDEOGRAPH-#28794, IRGKangXi=1278.150, RSKangXi=163.13
28795 CJK UNIFIED IDEOGRAPH-#28795, IRGKangXi=1278.160, RSKangXi=163.13
28796 CJK UNIFIED IDEOGRAPH-#28796, IRGKangXi=1278.170, RSKangXi=163.13
28797 CJK UNIFIED IDEOGRAPH-#28797, IRGKangXi=1278.200, RSKangXi=163.13
28798 CJK UNIFIED IDEOGRAPH-#28798, IRGKangXi=1278.210, RSKangXi=163.13
28799 CJK UNIFIED IDEOGRAPH-#28799, IRGKangXi=1278.220, RSKangXi=163.13
2879A CJK UNIFIED IDEOGRAPH-#2879A, IRGKangXi=1278.230, RSKangXi=163.13
2879B CJK UNIFIED IDEOGRAPH-#2879B, IRGKangXi=1278.240, RSKangXi=163.13
2879C CJK UNIFIED IDEOGRAPH-#2879C, IRGKangXi=1278.290, RSKangXi=163.13
2879D CJK UNIFIED IDEOGRAPH-#2879D, IRGKangXi=1278.291, RSKangXi=163.13
2879E CJK UNIFIED IDEOGRAPH-#2879E, IRGKangXi=1278.291, RSKangXi=163.13
2879F CJK UNIFIED IDEOGRAPH-#2879F, IRGKangXi=1278.291, RSKangXi=163.13
287A0 CJK UNIFIED IDEOGRAPH-#287A0, IRGKangXi=1278.291, RSKangXi=163.13
287A1 CJK UNIFIED IDEOGRAPH-#287A1, IRGKangXi=1278.291, RSKangXi=163.13
287A2 CJK UNIFIED IDEOGRAPH-#287A2, IRGKangXi=1278.291, RSKangXi=163.13
287A3 CJK UNIFIED IDEOGRAPH-#287A3, IRGKangXi=1278.291, RSKangXi=163.13
287A4 CJK UNIFIED IDEOGRAPH-#287A4, IRGKangXi=1278.291, RSKangXi=163.13
287A5 CJK UNIFIED IDEOGRAPH-#287A5, IRGKangXi=1278.291, RSKangXi=163.13
287A6 CJK UNIFIED IDEOGRAPH-#287A6, IRGKangXi=1278.291, RSKangXi=163.13
287A7 CJK UNIFIED IDEOGRAPH-#287A7, IRGKangXi=1278.300, RSKangXi=163.14
287A8 CJK UNIFIED IDEOGRAPH-#287A8, IRGKangXi=1278.310, RSKangXi=163.14
287A9 CJK UNIFIED IDEOGRAPH-#287A9, IRGKangXi=1278.320, RSKangXi=163.14
287AA CJK UNIFIED IDEOGRAPH-#287AA, IRGKangXi=1278.330, RSKangXi=163.14
287AB CJK UNIFIED IDEOGRAPH-#287AB, IRGKangXi=1278.340, RSKangXi=163.14
287AC CJK UNIFIED IDEOGRAPH-#287AC, IRGKangXi=1278.371, RSKangXi=163.14
287AD CJK UNIFIED IDEOGRAPH-#287AD, IRGKangXi=1278.371, RSKangXi=163.14
287AE CJK UNIFIED IDEOGRAPH-#287AE, IRGKangXi=1278.371, RSKangXi=163.14
287AF CJK UNIFIED IDEOGRAPH-#287AF, IRGKangXi=1278.371, RSKangXi=163.14
287B0 CJK UNIFIED IDEOGRAPH-#287B0, IRGKangXi=1278.371, RSKangXi=163.14
287B1 CJK UNIFIED IDEOGRAPH-#287B1, IRGKangXi=1278.371, RSKangXi=163.14
287B2 CJK UNIFIED IDEOGRAPH-#287B2, IRGKangXi=1278.371, RSKangXi=163.14
287B3 CJK UNIFIED IDEOGRAPH-#287B3, IRGKangXi=1278.371, RSKangXi=163.14
287B4 CJK UNIFIED IDEOGRAPH-#287B4, IRGKangXi=1278.371, RSKangXi=163.14
287B5 CJK UNIFIED IDEOGRAPH-#287B5, IRGKangXi=1278.371, RSKangXi=163.14
287B6 CJK UNIFIED IDEOGRAPH-#287B6, IRGKangXi=1278.371, RSKangXi=163.14
287B7 CJK UNIFIED IDEOGRAPH-#287B7, IRGKangXi=1278.371, RSKangXi=163.14
287B8 CJK UNIFIED IDEOGRAPH-#287B8, IRGKangXi=1278.371, RSKangXi=163.14
287B9 CJK UNIFIED IDEOGRAPH-#287B9, IRGKangXi=1278.371, RSKangXi=163.14
287BA CJK UNIFIED IDEOGRAPH-#287BA, IRGKangXi=1279.010, RSKangXi=163.15
287BB CJK UNIFIED IDEOGRAPH-#287BB, IRGKangXi=1279.020, RSKangXi=163.15
287BC CJK UNIFIED IDEOGRAPH-#287BC, IRGKangXi=1279.040, RSKangXi=163.15
287BD CJK UNIFIED IDEOGRAPH-#287BD, IRGKangXi=1279.060, RSKangXi=163.15
287BE CJK UNIFIED IDEOGRAPH-#287BE, IRGKangXi=1279.080, RSKangXi=163.15
287BF CJK UNIFIED IDEOGRAPH-#287BF, IRGKangXi=1279.090, RSKangXi=163.15
287C0 CJK UNIFIED IDEOGRAPH-#287C0, IRGKangXi=1279.100, RSKangXi=163.15
287C1 CJK UNIFIED IDEOGRAPH-#287C1, IRGKangXi=1279.120, RSKangXi=163.15
287C2 CJK UNIFIED IDEOGRAPH-#287C2, IRGKangXi=1279.130, RSKangXi=163.15
287C3 CJK UNIFIED IDEOGRAPH-#287C3, IRGKangXi=1279.140, RSKangXi=163.15
287C4 CJK UNIFIED IDEOGRAPH-#287C4, IRGKangXi=1279.160, RSKangXi=163.15
287C5 CJK UNIFIED IDEOGRAPH-#287C5, IRGKangXi=1279.170, RSKangXi=163.15
287C6 CJK UNIFIED IDEOGRAPH-#287C6, IRGKangXi=1279.171, RSKangXi=163.15
287C7 CJK UNIFIED IDEOGRAPH-#287C7, IRGKangXi=1279.171, RSKangXi=163.15
287C8 CJK UNIFIED IDEOGRAPH-#287C8, IRGKangXi=1279.171, RSKangXi=163.15
287C9 CJK UNIFIED IDEOGRAPH-#287C9, IRGKangXi=1279.171, RSKangXi=163.15
287CA CJK UNIFIED IDEOGRAPH-#287CA, IRGKangXi=1279.171, RSKangXi=163.15
287CB CJK UNIFIED IDEOGRAPH-#287CB, IRGKangXi=1279.171, RSKangXi=163.15
287CC CJK UNIFIED IDEOGRAPH-#287CC, IRGKangXi=1279.171, RSKangXi=163.15
287CD CJK UNIFIED IDEOGRAPH-#287CD, IRGKangXi=1279.180, RSKangXi=163.16
287CE CJK UNIFIED IDEOGRAPH-#287CE, IRGKangXi=1279.190, RSKangXi=163.16
287CF CJK UNIFIED IDEOGRAPH-#287CF, IRGKangXi=1279.200, RSKangXi=163.16
287D0 CJK UNIFIED IDEOGRAPH-#287D0, IRGKangXi=1279.210, RSKangXi=163.16
287D1 CJK UNIFIED IDEOGRAPH-#287D1, IRGKangXi=1279.250, RSKangXi=163.16
287D2 CJK UNIFIED IDEOGRAPH-#287D2, IRGKangXi=1279.251, RSKangXi=163.16
287D3 CJK UNIFIED IDEOGRAPH-#287D3, IRGKangXi=1279.251, RSKangXi=163.16
287D4 CJK UNIFIED IDEOGRAPH-#287D4, IRGKangXi=1279.251, RSKangXi=163.16
287D5 CJK UNIFIED IDEOGRAPH-#287D5, IRGKangXi=1279.251, RSKangXi=163.16
287D6 CJK UNIFIED IDEOGRAPH-#287D6, IRGKangXi=1279.251, RSKangXi=163.16
287D7 CJK UNIFIED IDEOGRAPH-#287D7, IRGKangXi=1279.251, RSKangXi=163.16
287D8 CJK UNIFIED IDEOGRAPH-#287D8, IRGKangXi=1279.251, RSKangXi=163.16
287D9 CJK UNIFIED IDEOGRAPH-#287D9, IRGKangXi=1279.260, RSKangXi=163.17
287DA CJK UNIFIED IDEOGRAPH-#287DA, IRGKangXi=1279.270, RSKangXi=163.17
287DB CJK UNIFIED IDEOGRAPH-#287DB, IRGKangXi=1279.281, RSKangXi=163.17
287DC CJK UNIFIED IDEOGRAPH-#287DC, IRGKangXi=1279.281, RSKangXi=163.17
287DD CJK UNIFIED IDEOGRAPH-#287DD, IRGKangXi=1279.281, RSKangXi=163.17
287DE CJK UNIFIED IDEOGRAPH-#287DE, IRGKangXi=1279.281, RSKangXi=163.17
287DF CJK UNIFIED IDEOGRAPH-#287DF, IRGKangXi=1279.281, RSKangXi=163.17
287E0 CJK UNIFIED IDEOGRAPH-#287E0, IRGKangXi=1279.320, RSKangXi=163.18
287E1 CJK UNIFIED IDEOGRAPH-#287E1, IRGKangXi=1279.321, RSKangXi=163.18
287E2 CJK UNIFIED IDEOGRAPH-#287E2, IRGKangXi=1279.321, RSKangXi=163.18
287E3 CJK UNIFIED IDEOGRAPH-#287E3, IRGKangXi=1279.321, RSKangXi=163.18
287E4 CJK UNIFIED IDEOGRAPH-#287E4, IRGKangXi=1279.341, RSKangXi=163.19
287E5 CJK UNIFIED IDEOGRAPH-#287E5, IRGKangXi=1279.341, RSKangXi=163.19
287E6 CJK UNIFIED IDEOGRAPH-#287E6, IRGKangXi=1279.341, RSKangXi=163.19
287E7 CJK UNIFIED IDEOGRAPH-#287E7, IRGKangXi=1279.341, RSKangXi=163.19
287E8 CJK UNIFIED IDEOGRAPH-#287E8, IRGKangXi=1280.011, RSKangXi=163.20
287E9 CJK UNIFIED IDEOGRAPH-#287E9, IRGKangXi=1280.011, RSKangXi=163.21
287EA CJK UNIFIED IDEOGRAPH-#287EA, IRGKangXi=1280.011, RSKangXi=163.21
287EB CJK UNIFIED IDEOGRAPH-#287EB, IRGKangXi=1280.011, RSKangXi=163.21
287EC CJK UNIFIED IDEOGRAPH-#287EC, IRGKangXi=1280.011, RSKangXi=163.21
287ED CJK UNIFIED IDEOGRAPH-#287ED, IRGKangXi=1280.011, RSKangXi=163.21
287EE CJK UNIFIED IDEOGRAPH-#287EE, IRGKangXi=1280.011, RSKangXi=163.21
287EF CJK UNIFIED IDEOGRAPH-#287EF, IRGKangXi=1280.011, RSKangXi=163.24
287F0 CJK UNIFIED IDEOGRAPH-#287F0, IRGKangXi=1281.041, RSKangXi=164.3
287F1 CJK UNIFIED IDEOGRAPH-#287F1, IRGKangXi=1281.041, RSKangXi=164.3
287F2 CJK UNIFIED IDEOGRAPH-#287F2, IRGKangXi=1281.041, RSKangXi=164.3
287F3 CJK UNIFIED IDEOGRAPH-#287F3, IRGKangXi=1281.041, RSKangXi=164.3
287F4 CJK UNIFIED IDEOGRAPH-#287F4, IRGKangXi=1281.050, RSKangXi=164.4
287F5 CJK UNIFIED IDEOGRAPH-#287F5, IRGKangXi=1281.060, RSKangXi=164.4
287F6 CJK UNIFIED IDEOGRAPH-#287F6, IRGKangXi=1281.070, RSKangXi=164.4
287F7 CJK UNIFIED IDEOGRAPH-#287F7, IRGKangXi=1281.080, RSKangXi=164.4
287F8 CJK UNIFIED IDEOGRAPH-#287F8, IRGKangXi=1281.100, RSKangXi=164.4
287F9 CJK UNIFIED IDEOGRAPH-#287F9, IRGKangXi=1281.120, RSKangXi=164.4
287FA CJK UNIFIED IDEOGRAPH-#287FA, IRGKangXi=1281.140, RSKangXi=164.4
287FB CJK UNIFIED IDEOGRAPH-#287FB, IRGKangXi=1281.150, RSKangXi=164.4
287FC CJK UNIFIED IDEOGRAPH-#287FC, IRGKangXi=1281.170, RSKangXi=164.4
287FD CJK UNIFIED IDEOGRAPH-#287FD, IRGKangXi=1281.200, RSKangXi=164.4
287FE CJK UNIFIED IDEOGRAPH-#287FE, IRGKangXi=1281.240, RSKangXi=164.4
287FF CJK UNIFIED IDEOGRAPH-#287FF, IRGKangXi=1281.250, RSKangXi=164.4
28800 CJK UNIFIED IDEOGRAPH-#28800, IRGKangXi=1281.260, RSKangXi=164.4
28801 CJK UNIFIED IDEOGRAPH-#28801, IRGKangXi=1281.270, RSKangXi=164.4
28802 CJK UNIFIED IDEOGRAPH-#28802, IRGKangXi=1281.280, RSKangXi=164.4
28803 CJK UNIFIED IDEOGRAPH-#28803, IRGKangXi=1281.281, RSKangXi=164.4
28804 CJK UNIFIED IDEOGRAPH-#28804, IRGKangXi=1281.281, RSKangXi=164.4
28805 CJK UNIFIED IDEOGRAPH-#28805, IRGKangXi=1281.281, RSKangXi=164.4
28806 CJK UNIFIED IDEOGRAPH-#28806, IRGKangXi=1281.281, RSKangXi=164.4
28807 CJK UNIFIED IDEOGRAPH-#28807, IRGKangXi=1281.281, RSKangXi=164.4
28808 CJK UNIFIED IDEOGRAPH-#28808, IRGKangXi=1281.281, RSKangXi=164.4
28809 CJK UNIFIED IDEOGRAPH-#28809, IRGKangXi=1281.281, RSKangXi=164.4
2880A CJK UNIFIED IDEOGRAPH-#2880A, IRGKangXi=1281.281, RSKangXi=164.4
2880B CJK UNIFIED IDEOGRAPH-#2880B, IRGKangXi=1281.300, RSKangXi=164.5
2880C CJK UNIFIED IDEOGRAPH-#2880C, IRGKangXi=1281.310, RSKangXi=164.5
2880D CJK UNIFIED IDEOGRAPH-#2880D, IRGKangXi=1281.330, RSKangXi=164.5
2880E CJK UNIFIED IDEOGRAPH-#2880E, IRGKangXi=1281.370, RSKangXi=164.5
2880F CJK UNIFIED IDEOGRAPH-#2880F, IRGKangXi=1281.380, RSKangXi=164.5
28810 CJK UNIFIED IDEOGRAPH-#28810, IRGKangXi=1281.400, RSKangXi=164.5
28811 CJK UNIFIED IDEOGRAPH-#28811, IRGKangXi=1281.420, RSKangXi=164.5
28812 CJK UNIFIED IDEOGRAPH-#28812, IRGKangXi=1282.040, RSKangXi=164.5
28813 CJK UNIFIED IDEOGRAPH-#28813, IRGKangXi=1282.060, RSKangXi=164.5
28814 CJK UNIFIED IDEOGRAPH-#28814, IRGKangXi=1282.070, RSKangXi=164.5
28815 CJK UNIFIED IDEOGRAPH-#28815, IRGKangXi=1282.080, RSKangXi=164.5
28816 CJK UNIFIED IDEOGRAPH-#28816, IRGKangXi=1282.090, RSKangXi=164.5
28817 CJK UNIFIED IDEOGRAPH-#28817, IRGKangXi=1282.100, RSKangXi=164.5
28818 CJK UNIFIED IDEOGRAPH-#28818, IRGKangXi=1282.130, RSKangXi=164.5
28819 CJK UNIFIED IDEOGRAPH-#28819, IRGKangXi=1282.131, RSKangXi=164.5
2881A CJK UNIFIED IDEOGRAPH-#2881A, IRGKangXi=1282.131, RSKangXi=164.5
2881B CJK UNIFIED IDEOGRAPH-#2881B, IRGKangXi=1282.131, RSKangXi=164.5
2881C CJK UNIFIED IDEOGRAPH-#2881C, IRGKangXi=1282.131, RSKangXi=164.5
2881D CJK UNIFIED IDEOGRAPH-#2881D, IRGKangXi=1282.131, RSKangXi=164.5
2881E CJK UNIFIED IDEOGRAPH-#2881E, IRGKangXi=1282.131, RSKangXi=164.5
2881F CJK UNIFIED IDEOGRAPH-#2881F, IRGKangXi=1282.131, RSKangXi=164.5
28820 CJK UNIFIED IDEOGRAPH-#28820, IRGKangXi=1282.131, RSKangXi=164.5
28821 CJK UNIFIED IDEOGRAPH-#28821, IRGKangXi=1282.131, RSKangXi=164.5
28822 CJK UNIFIED IDEOGRAPH-#28822, IRGKangXi=1282.131, RSKangXi=164.5
28823 CJK UNIFIED IDEOGRAPH-#28823, IRGKangXi=1282.131, RSKangXi=164.5
28824 CJK UNIFIED IDEOGRAPH-#28824, IRGKangXi=1282.180, RSKangXi=164.6
28825 CJK UNIFIED IDEOGRAPH-#28825, IRGKangXi=1283.020, RSKangXi=164.6
28826 CJK UNIFIED IDEOGRAPH-#28826, IRGKangXi=1283.030, RSKangXi=164.6
28827 CJK UNIFIED IDEOGRAPH-#28827, IRGKangXi=1283.040, RSKangXi=164.6
28828 CJK UNIFIED IDEOGRAPH-#28828, IRGKangXi=1283.051, RSKangXi=164.6
28829 CJK UNIFIED IDEOGRAPH-#28829, IRGKangXi=1283.051, RSKangXi=164.6
2882A CJK UNIFIED IDEOGRAPH-#2882A, IRGKangXi=1283.051, RSKangXi=164.6
2882B CJK UNIFIED IDEOGRAPH-#2882B, IRGKangXi=1283.051, RSKangXi=164.6
2882C CJK UNIFIED IDEOGRAPH-#2882C, IRGKangXi=1283.051, RSKangXi=164.6
2882D CJK UNIFIED IDEOGRAPH-#2882D, IRGKangXi=1283.051, RSKangXi=164.6
2882E CJK UNIFIED IDEOGRAPH-#2882E, IRGKangXi=1283.051, RSKangXi=164.6
2882F CJK UNIFIED IDEOGRAPH-#2882F, IRGKangXi=1283.051, RSKangXi=164.6
28830 CJK UNIFIED IDEOGRAPH-#28830, IRGKangXi=1283.051, RSKangXi=164.6
28831 CJK UNIFIED IDEOGRAPH-#28831, IRGKangXi=1283.051, RSKangXi=164.6
28832 CJK UNIFIED IDEOGRAPH-#28832, IRGKangXi=1283.051, RSKangXi=164.6
28833 CJK UNIFIED IDEOGRAPH-#28833, IRGKangXi=1283.051, RSKangXi=164.6
28834 CJK UNIFIED IDEOGRAPH-#28834, IRGKangXi=1283.051, RSKangXi=164.6
28835 CJK UNIFIED IDEOGRAPH-#28835, IRGKangXi=1283.051, RSKangXi=164.6
28836 CJK UNIFIED IDEOGRAPH-#28836, IRGKangXi=1283.051, RSKangXi=164.6
28837 CJK UNIFIED IDEOGRAPH-#28837, IRGKangXi=1283.060, RSKangXi=164.7
28838 CJK UNIFIED IDEOGRAPH-#28838, IRGKangXi=1283.080, RSKangXi=164.7
28839 CJK UNIFIED IDEOGRAPH-#28839, IRGKangXi=1284.020, RSKangXi=164.7
2883A CJK UNIFIED IDEOGRAPH-#2883A, IRGKangXi=1284.021, RSKangXi=164.7
2883B CJK UNIFIED IDEOGRAPH-#2883B, IRGKangXi=1284.021, RSKangXi=164.7
2883C CJK UNIFIED IDEOGRAPH-#2883C, IRGKangXi=1284.021, RSKangXi=164.7
2883D CJK UNIFIED IDEOGRAPH-#2883D, IRGKangXi=1284.021, RSKangXi=164.7
2883E CJK UNIFIED IDEOGRAPH-#2883E, IRGKangXi=1284.021, RSKangXi=164.7
2883F CJK UNIFIED IDEOGRAPH-#2883F, IRGKangXi=1284.021, RSKangXi=164.7
28840 CJK UNIFIED IDEOGRAPH-#28840, IRGKangXi=1284.021
28841 CJK UNIFIED IDEOGRAPH-#28841, IRGKangXi=1284.021, RSKangXi=164.7
28842 CJK UNIFIED IDEOGRAPH-#28842, IRGKangXi=1284.021, RSKangXi=164.7
28843 CJK UNIFIED IDEOGRAPH-#28843, IRGKangXi=1284.021, RSKangXi=164.7
28844 CJK UNIFIED IDEOGRAPH-#28844, IRGKangXi=1284.021, RSKangXi=164.7
28845 CJK UNIFIED IDEOGRAPH-#28845, IRGKangXi=1284.021, RSKangXi=164.7
28846 CJK UNIFIED IDEOGRAPH-#28846, IRGKangXi=1284.021, RSKangXi=164.7
28847 CJK UNIFIED IDEOGRAPH-#28847, IRGKangXi=1284.021, RSKangXi=164.7
28848 CJK UNIFIED IDEOGRAPH-#28848, IRGKangXi=1284.021, RSKangXi=164.7
28849 CJK UNIFIED IDEOGRAPH-#28849, IRGKangXi=1284.021, RSKangXi=164.7
2884A CJK UNIFIED IDEOGRAPH-#2884A, IRGKangXi=1284.021, RSKangXi=164.7
2884B CJK UNIFIED IDEOGRAPH-#2884B, IRGKangXi=1284.021, RSKangXi=164.7
2884C CJK UNIFIED IDEOGRAPH-#2884C, IRGKangXi=1284.060, RSKangXi=164.8
2884D CJK UNIFIED IDEOGRAPH-#2884D, IRGKangXi=1284.070, RSKangXi=164.8
2884E CJK UNIFIED IDEOGRAPH-#2884E, IRGKangXi=1284.080, RSKangXi=164.8
2884F CJK UNIFIED IDEOGRAPH-#2884F, IRGKangXi=1284.100, RSKangXi=164.8
28850 CJK UNIFIED IDEOGRAPH-#28850, IRGKangXi=1284.110, RSKangXi=164.8
28851 CJK UNIFIED IDEOGRAPH-#28851, IRGKangXi=1284.120, RSKangXi=164.8
28852 CJK UNIFIED IDEOGRAPH-#28852, IRGKangXi=1284.150, RSKangXi=164.8
28853 CJK UNIFIED IDEOGRAPH-#28853, IRGKangXi=1284.200, RSKangXi=164.8
28854 CJK UNIFIED IDEOGRAPH-#28854, IRGKangXi=1284.220, RSKangXi=164.8
28855 CJK UNIFIED IDEOGRAPH-#28855, IRGKangXi=1284.260, RSKangXi=164.8
28856 CJK UNIFIED IDEOGRAPH-#28856, IRGKangXi=1285.010, RSKangXi=164.8
28857 CJK UNIFIED IDEOGRAPH-#28857, IRGKangXi=1285.020, RSKangXi=164.8
28858 CJK UNIFIED IDEOGRAPH-#28858, IRGKangXi=1285.030, RSKangXi=164.8
28859 CJK UNIFIED IDEOGRAPH-#28859, IRGKangXi=1285.031, RSKangXi=164.8
2885A CJK UNIFIED IDEOGRAPH-#2885A, IRGKangXi=1285.031, RSKangXi=164.8
2885B CJK UNIFIED IDEOGRAPH-#2885B, IRGKangXi=1285.031, RSKangXi=164.8
2885C CJK UNIFIED IDEOGRAPH-#2885C, IRGKangXi=1285.031, RSKangXi=164.8
2885D CJK UNIFIED IDEOGRAPH-#2885D, IRGKangXi=1285.031, RSKangXi=164.8
2885E CJK UNIFIED IDEOGRAPH-#2885E, IRGKangXi=1285.031, RSKangXi=164.8
2885F CJK UNIFIED IDEOGRAPH-#2885F, IRGKangXi=1285.031, RSKangXi=164.8
28860 CJK UNIFIED IDEOGRAPH-#28860, IRGKangXi=1285.031, RSKangXi=164.8
28861 CJK UNIFIED IDEOGRAPH-#28861, IRGKangXi=1285.031, RSKangXi=164.8
28862 CJK UNIFIED IDEOGRAPH-#28862, IRGKangXi=1285.031, RSKangXi=164.8
28863 CJK UNIFIED IDEOGRAPH-#28863, IRGKangXi=1285.031, RSKangXi=164.8
28864 CJK UNIFIED IDEOGRAPH-#28864, IRGKangXi=1285.031, RSKangXi=164.8
28865 CJK UNIFIED IDEOGRAPH-#28865, IRGKangXi=1285.031, RSKangXi=164.8
28866 CJK UNIFIED IDEOGRAPH-#28866, IRGKangXi=1285.031, RSKangXi=164.8
28867 CJK UNIFIED IDEOGRAPH-#28867, IRGKangXi=1285.031, RSKangXi=164.8
28868 CJK UNIFIED IDEOGRAPH-#28868, IRGKangXi=1285.031, RSKangXi=164.8
28869 CJK UNIFIED IDEOGRAPH-#28869, IRGKangXi=1285.050, RSKangXi=164.9
2886A CJK UNIFIED IDEOGRAPH-#2886A, IRGKangXi=1285.080, RSKangXi=164.9
2886B CJK UNIFIED IDEOGRAPH-#2886B, IRGKangXi=1285.100, RSKangXi=164.9
2886C CJK UNIFIED IDEOGRAPH-#2886C, IRGKangXi=1285.130, RSKangXi=164.9
2886D CJK UNIFIED IDEOGRAPH-#2886D, IRGKangXi=1285.160, RSKangXi=164.9
2886E CJK UNIFIED IDEOGRAPH-#2886E, IRGKangXi=1285.180, RSKangXi=164.9
2886F CJK UNIFIED IDEOGRAPH-#2886F, IRGKangXi=1285.210, RSKangXi=164.9
28870 CJK UNIFIED IDEOGRAPH-#28870, IRGKangXi=1285.230, RSKangXi=164.9
28871 CJK UNIFIED IDEOGRAPH-#28871, IRGKangXi=1285.240, RSKangXi=164.9
28872 CJK UNIFIED IDEOGRAPH-#28872, IRGKangXi=1285.300, RSKangXi=164.9
28873 CJK UNIFIED IDEOGRAPH-#28873, IRGKangXi=1285.310, RSKangXi=164.9
28874 CJK UNIFIED IDEOGRAPH-#28874, IRGKangXi=1285.330, RSKangXi=164.9
28875 CJK UNIFIED IDEOGRAPH-#28875, IRGKangXi=1285.340, RSKangXi=164.9
28876 CJK UNIFIED IDEOGRAPH-#28876, IRGKangXi=1285.350, RSKangXi=164.9
28877 CJK UNIFIED IDEOGRAPH-#28877, IRGKangXi=1285.360, RSKangXi=164.9
28878 CJK UNIFIED IDEOGRAPH-#28878, IRGKangXi=1285.370, RSKangXi=164.9
28879 CJK UNIFIED IDEOGRAPH-#28879, IRGKangXi=1285.371, RSKangXi=164.9
2887A CJK UNIFIED IDEOGRAPH-#2887A, IRGKangXi=1285.371, RSKangXi=164.9
2887B CJK UNIFIED IDEOGRAPH-#2887B, IRGKangXi=1285.371, RSKangXi=164.9
2887C CJK UNIFIED IDEOGRAPH-#2887C, IRGKangXi=1285.371, RSKangXi=164.9
2887D CJK UNIFIED IDEOGRAPH-#2887D, IRGKangXi=1285.371, RSKangXi=164.9
2887E CJK UNIFIED IDEOGRAPH-#2887E, IRGKangXi=1285.371, RSKangXi=164.9
2887F CJK UNIFIED IDEOGRAPH-#2887F, IRGKangXi=1285.371, RSKangXi=164.9
28880 CJK UNIFIED IDEOGRAPH-#28880, IRGKangXi=1285.371, RSKangXi=164.9
28881 CJK UNIFIED IDEOGRAPH-#28881, IRGKangXi=1285.371, RSKangXi=164.9
28882 CJK UNIFIED IDEOGRAPH-#28882, IRGKangXi=1285.371, RSKangXi=164.9
28883 CJK UNIFIED IDEOGRAPH-#28883, IRGKangXi=1285.371, RSKangXi=164.9
28884 CJK UNIFIED IDEOGRAPH-#28884, IRGKangXi=1285.371, RSKangXi=164.9
28885 CJK UNIFIED IDEOGRAPH-#28885, IRGKangXi=1285.380, RSKangXi=164.10
28886 CJK UNIFIED IDEOGRAPH-#28886, IRGKangXi=1285.400, RSKangXi=164.10
28887 CJK UNIFIED IDEOGRAPH-#28887, IRGKangXi=1286.010, RSKangXi=164.10
28888 CJK UNIFIED IDEOGRAPH-#28888, IRGKangXi=1286.020, RSKangXi=164.10
28889 CJK UNIFIED IDEOGRAPH-#28889, IRGKangXi=1286.040, RSKangXi=164.10
2888A CJK UNIFIED IDEOGRAPH-#2888A, IRGKangXi=1286.060, RSKangXi=164.10
2888B CJK UNIFIED IDEOGRAPH-#2888B, IRGKangXi=1286.070, RSKangXi=164.10
2888C CJK UNIFIED IDEOGRAPH-#2888C, IRGKangXi=1286.080, RSKangXi=164.10
2888D CJK UNIFIED IDEOGRAPH-#2888D, IRGKangXi=1286.120, RSKangXi=164.10
2888E CJK UNIFIED IDEOGRAPH-#2888E, IRGKangXi=1286.140, RSKangXi=164.10
2888F CJK UNIFIED IDEOGRAPH-#2888F, IRGKangXi=1286.160, RSKangXi=164.10
28890 CJK UNIFIED IDEOGRAPH-#28890, IRGKangXi=1286.180, RSKangXi=164.10
28891 CJK UNIFIED IDEOGRAPH-#28891, IRGKangXi=1286.220, RSKangXi=164.10
28892 CJK UNIFIED IDEOGRAPH-#28892, IRGKangXi=1286.240, RSKangXi=164.10
28893 CJK UNIFIED IDEOGRAPH-#28893, IRGKangXi=1286.241, RSKangXi=164.10
28894 CJK UNIFIED IDEOGRAPH-#28894, IRGKangXi=1286.241, RSKangXi=164.10
28895 CJK UNIFIED IDEOGRAPH-#28895, IRGKangXi=1286.241, RSKangXi=164.10
28896 CJK UNIFIED IDEOGRAPH-#28896, IRGKangXi=1286.241, RSKangXi=164.10
28897 CJK UNIFIED IDEOGRAPH-#28897, IRGKangXi=1286.241, RSKangXi=164.10
28898 CJK UNIFIED IDEOGRAPH-#28898, IRGKangXi=1286.241, RSKangXi=164.10
28899 CJK UNIFIED IDEOGRAPH-#28899, IRGKangXi=1286.241, RSKangXi=164.10
2889A CJK UNIFIED IDEOGRAPH-#2889A, IRGKangXi=1286.241, RSKangXi=164.10
2889B CJK UNIFIED IDEOGRAPH-#2889B, IRGKangXi=1286.241, RSKangXi=164.10
2889C CJK UNIFIED IDEOGRAPH-#2889C, IRGKangXi=1286.241, RSKangXi=164.10
2889D CJK UNIFIED IDEOGRAPH-#2889D, IRGKangXi=1286.241, RSKangXi=164.10
2889E CJK UNIFIED IDEOGRAPH-#2889E, IRGKangXi=1286.241, RSKangXi=164.10
2889F CJK UNIFIED IDEOGRAPH-#2889F, IRGKangXi=1286.241, RSKangXi=164.10
288A0 CJK UNIFIED IDEOGRAPH-#288A0, IRGKangXi=1286.241, RSKangXi=164.10
288A1 CJK UNIFIED IDEOGRAPH-#288A1, IRGKangXi=1286.250, RSKangXi=164.11
288A2 CJK UNIFIED IDEOGRAPH-#288A2, IRGKangXi=1286.260, RSKangXi=164.11
288A3 CJK UNIFIED IDEOGRAPH-#288A3, IRGKangXi=1286.270, RSKangXi=164.11
288A4 CJK UNIFIED IDEOGRAPH-#288A4, IRGKangXi=1286.280, RSKangXi=164.11
288A5 CJK UNIFIED IDEOGRAPH-#288A5, IRGKangXi=1286.300, RSKangXi=164.11, Def{(same as 䤍) rotten paste or soybean sauce; to grow mildewed}
288A6 CJK UNIFIED IDEOGRAPH-#288A6, IRGKangXi=1287.010, RSKangXi=164.11
288A7 CJK UNIFIED IDEOGRAPH-#288A7, IRGKangXi=1287.020, RSKangXi=164.11
288A8 CJK UNIFIED IDEOGRAPH-#288A8, IRGKangXi=1287.040, RSKangXi=164.11
288A9 CJK UNIFIED IDEOGRAPH-#288A9, IRGKangXi=1287.070, RSKangXi=164.11
288AA CJK UNIFIED IDEOGRAPH-#288AA, IRGKangXi=1287.090, RSKangXi=164.11
288AB CJK UNIFIED IDEOGRAPH-#288AB, IRGKangXi=1287.120, RSKangXi=164.11
288AC CJK UNIFIED IDEOGRAPH-#288AC, IRGKangXi=1287.140, RSKangXi=164.11
288AD CJK UNIFIED IDEOGRAPH-#288AD, IRGKangXi=1287.150, RSKangXi=164.11
288AE CJK UNIFIED IDEOGRAPH-#288AE, IRGKangXi=1287.160, RSKangXi=164.11
288AF CJK UNIFIED IDEOGRAPH-#288AF, IRGKangXi=1287.190, RSKangXi=164.11
288B0 CJK UNIFIED IDEOGRAPH-#288B0, IRGKangXi=1287.200, RSKangXi=164.11
288B1 CJK UNIFIED IDEOGRAPH-#288B1, IRGKangXi=1287.201, RSKangXi=164.11
288B2 CJK UNIFIED IDEOGRAPH-#288B2, IRGKangXi=1287.201, RSKangXi=164.11
288B3 CJK UNIFIED IDEOGRAPH-#288B3, IRGKangXi=1287.201, RSKangXi=164.11
288B4 CJK UNIFIED IDEOGRAPH-#288B4, IRGKangXi=1287.201, RSKangXi=164.11
288B5 CJK UNIFIED IDEOGRAPH-#288B5, IRGKangXi=1287.201, RSKangXi=164.11
288B6 CJK UNIFIED IDEOGRAPH-#288B6, IRGKangXi=1287.201, RSKangXi=164.11
288B7 CJK UNIFIED IDEOGRAPH-#288B7, IRGKangXi=1287.201, RSKangXi=164.11
288B8 CJK UNIFIED IDEOGRAPH-#288B8, IRGKangXi=1287.201, RSKangXi=164.11
288B9 CJK UNIFIED IDEOGRAPH-#288B9, IRGKangXi=1287.201, RSKangXi=164.11
288BA CJK UNIFIED IDEOGRAPH-#288BA, IRGKangXi=1287.201, RSKangXi=164.11
288BB CJK UNIFIED IDEOGRAPH-#288BB, IRGKangXi=1287.201, RSKangXi=164.11
288BC CJK UNIFIED IDEOGRAPH-#288BC, IRGKangXi=1287.201, RSKangXi=164.11
288BD CJK UNIFIED IDEOGRAPH-#288BD, IRGKangXi=1287.210, RSKangXi=164.12
288BE CJK UNIFIED IDEOGRAPH-#288BE, IRGKangXi=1287.220, RSKangXi=164.12
288BF CJK UNIFIED IDEOGRAPH-#288BF, IRGKangXi=1287.280, RSKangXi=164.12
288C0 CJK UNIFIED IDEOGRAPH-#288C0, IRGKangXi=1287.290, RSKangXi=164.12
288C1 CJK UNIFIED IDEOGRAPH-#288C1, IRGKangXi=1287.300, RSKangXi=164.12
288C2 CJK UNIFIED IDEOGRAPH-#288C2, IRGKangXi=1287.320, RSKangXi=164.12
288C3 CJK UNIFIED IDEOGRAPH-#288C3, IRGKangXi=1287.340, RSKangXi=164.12
288C4 CJK UNIFIED IDEOGRAPH-#288C4, IRGKangXi=1287.350, RSKangXi=164.12
288C5 CJK UNIFIED IDEOGRAPH-#288C5, IRGKangXi=1287.360, RSKangXi=164.12
288C6 CJK UNIFIED IDEOGRAPH-#288C6, IRGKangXi=1287.380, RSKangXi=164.12
288C7 CJK UNIFIED IDEOGRAPH-#288C7, IRGKangXi=1288.010, RSKangXi=164.12
288C8 CJK UNIFIED IDEOGRAPH-#288C8, IRGKangXi=1288.040, RSKangXi=164.12
288C9 CJK UNIFIED IDEOGRAPH-#288C9, IRGKangXi=1288.041, RSKangXi=164.12
288CA CJK UNIFIED IDEOGRAPH-#288CA, IRGKangXi=1288.041, RSKangXi=164.12
288CB CJK UNIFIED IDEOGRAPH-#288CB, IRGKangXi=1288.041, RSKangXi=164.12
288CC CJK UNIFIED IDEOGRAPH-#288CC, IRGKangXi=1288.041, RSKangXi=164.12
288CD CJK UNIFIED IDEOGRAPH-#288CD, IRGKangXi=1288.041, RSKangXi=164.12
288CE CJK UNIFIED IDEOGRAPH-#288CE, IRGKangXi=1288.041, RSKangXi=164.12
288CF CJK UNIFIED IDEOGRAPH-#288CF, IRGKangXi=1288.041, RSKangXi=164.12
288D0 CJK UNIFIED IDEOGRAPH-#288D0, IRGKangXi=1288.041, RSKangXi=164.12
288D1 CJK UNIFIED IDEOGRAPH-#288D1, IRGKangXi=1288.041, RSKangXi=164.12
288D2 CJK UNIFIED IDEOGRAPH-#288D2, IRGKangXi=1288.041, RSKangXi=164.12
288D3 CJK UNIFIED IDEOGRAPH-#288D3, IRGKangXi=1288.041, RSKangXi=164.12
288D4 CJK UNIFIED IDEOGRAPH-#288D4, IRGKangXi=1288.041, RSKangXi=164.12
288D5 CJK UNIFIED IDEOGRAPH-#288D5, IRGKangXi=1288.041, RSKangXi=164.12
288D6 CJK UNIFIED IDEOGRAPH-#288D6, IRGKangXi=1288.050, RSKangXi=164.13
288D7 CJK UNIFIED IDEOGRAPH-#288D7, IRGKangXi=1288.060, RSKangXi=164.13
288D8 CJK UNIFIED IDEOGRAPH-#288D8, IRGKangXi=1288.070, RSKangXi=164.13
288D9 CJK UNIFIED IDEOGRAPH-#288D9, IRGKangXi=1288.110, RSKangXi=164.13
288DA CJK UNIFIED IDEOGRAPH-#288DA, IRGKangXi=1288.130, RSKangXi=164.13
288DB CJK UNIFIED IDEOGRAPH-#288DB, IRGKangXi=1288.160, RSKangXi=164.13
288DC CJK UNIFIED IDEOGRAPH-#288DC, IRGKangXi=1288.170, RSKangXi=164.13
288DD CJK UNIFIED IDEOGRAPH-#288DD, IRGKangXi=1288.180, RSKangXi=164.13
288DE CJK UNIFIED IDEOGRAPH-#288DE, IRGKangXi=1288.181, RSKangXi=164.13
288DF CJK UNIFIED IDEOGRAPH-#288DF, IRGKangXi=1288.181, RSKangXi=164.13
288E0 CJK UNIFIED IDEOGRAPH-#288E0, IRGKangXi=1288.181, RSKangXi=164.13
288E1 CJK UNIFIED IDEOGRAPH-#288E1, IRGKangXi=1288.181, RSKangXi=164.13
288E2 CJK UNIFIED IDEOGRAPH-#288E2, IRGKangXi=1288.181, RSKangXi=164.13
288E3 CJK UNIFIED IDEOGRAPH-#288E3, IRGKangXi=1288.181, RSKangXi=164.13
288E4 CJK UNIFIED IDEOGRAPH-#288E4, IRGKangXi=1288.181, RSKangXi=164.13
288E5 CJK UNIFIED IDEOGRAPH-#288E5, IRGKangXi=1288.181, RSKangXi=164.13
288E6 CJK UNIFIED IDEOGRAPH-#288E6, IRGKangXi=1288.190, RSKangXi=164.14, Def{clear; strained}
288E7 CJK UNIFIED IDEOGRAPH-#288E7, IRGKangXi=1288.210, RSKangXi=164.14
288E8 CJK UNIFIED IDEOGRAPH-#288E8, IRGKangXi=1288.250, RSKangXi=164.14
288E9 CJK UNIFIED IDEOGRAPH-#288E9, IRGKangXi=1289.010, RSKangXi=164.14
288EA CJK UNIFIED IDEOGRAPH-#288EA, IRGKangXi=1289.020, RSKangXi=164.14
288EB CJK UNIFIED IDEOGRAPH-#288EB, IRGKangXi=1289.021, RSKangXi=164.14
288EC CJK UNIFIED IDEOGRAPH-#288EC, IRGKangXi=1289.021, RSKangXi=164.14
288ED CJK UNIFIED IDEOGRAPH-#288ED, IRGKangXi=1289.021, RSKangXi=164.14
288EE CJK UNIFIED IDEOGRAPH-#288EE, IRGKangXi=1289.040, RSKangXi=164.15
288EF CJK UNIFIED IDEOGRAPH-#288EF, IRGKangXi=1289.060, RSKangXi=164.15
288F0 CJK UNIFIED IDEOGRAPH-#288F0, IRGKangXi=1289.070, RSKangXi=164.15
288F1 CJK UNIFIED IDEOGRAPH-#288F1, IRGKangXi=1289.080, RSKangXi=164.15
288F2 CJK UNIFIED IDEOGRAPH-#288F2, IRGKangXi=1289.090, RSKangXi=164.15
288F3 CJK UNIFIED IDEOGRAPH-#288F3, IRGKangXi=1289.100, RSKangXi=164.15
288F4 CJK UNIFIED IDEOGRAPH-#288F4, IRGKangXi=1289.101, RSKangXi=164.15
288F5 CJK UNIFIED IDEOGRAPH-#288F5, IRGKangXi=1289.101, RSKangXi=164.15
288F6 CJK UNIFIED IDEOGRAPH-#288F6, IRGKangXi=1289.110, RSKangXi=164.16
288F7 CJK UNIFIED IDEOGRAPH-#288F7, IRGKangXi=1289.130, RSKangXi=164.16
288F8 CJK UNIFIED IDEOGRAPH-#288F8, IRGKangXi=1289.140, RSKangXi=164.16
288F9 CJK UNIFIED IDEOGRAPH-#288F9, IRGKangXi=1289.150, RSKangXi=164.16
288FA CJK UNIFIED IDEOGRAPH-#288FA, IRGKangXi=1289.160, RSKangXi=164.16
288FB CJK UNIFIED IDEOGRAPH-#288FB, IRGKangXi=1289.170, RSKangXi=164.16
288FC CJK UNIFIED IDEOGRAPH-#288FC, IRGKangXi=1289.180, RSKangXi=164.16
288FD CJK UNIFIED IDEOGRAPH-#288FD, IRGKangXi=1289.181, RSKangXi=164.16
288FE CJK UNIFIED IDEOGRAPH-#288FE, IRGKangXi=1289.240, RSKangXi=164.17
288FF CJK UNIFIED IDEOGRAPH-#288FF, IRGKangXi=1289.260, RSKangXi=164.17
28900 CJK UNIFIED IDEOGRAPH-#28900, IRGKangXi=1289.261, RSKangXi=164.17
28901 CJK UNIFIED IDEOGRAPH-#28901, IRGKangXi=1289.261, RSKangXi=164.17
28902 CJK UNIFIED IDEOGRAPH-#28902, IRGKangXi=1289.261, RSKangXi=164.17
28903 CJK UNIFIED IDEOGRAPH-#28903, IRGKangXi=1289.281, RSKangXi=164.18
28904 CJK UNIFIED IDEOGRAPH-#28904, IRGKangXi=1289.281, RSKangXi=164.18
28905 CJK UNIFIED IDEOGRAPH-#28905, IRGKangXi=1289.310, RSKangXi=164.19
28906 CJK UNIFIED IDEOGRAPH-#28906, IRGKangXi=1289.311, RSKangXi=164.19
28907 CJK UNIFIED IDEOGRAPH-#28907, IRGKangXi=1289.330, RSKangXi=164.20
28908 CJK UNIFIED IDEOGRAPH-#28908, IRGKangXi=1289.331, RSKangXi=164.20
28909 CJK UNIFIED IDEOGRAPH-#28909, IRGKangXi=1289.331, RSKangXi=164.20
2890A CJK UNIFIED IDEOGRAPH-#2890A, IRGKangXi=1290.020, RSKangXi=164.21
2890B CJK UNIFIED IDEOGRAPH-#2890B, IRGKangXi=1290.021, RSKangXi=164.21
2890C CJK UNIFIED IDEOGRAPH-#2890C, IRGKangXi=1290.021, RSKangXi=164.21
2890D CJK UNIFIED IDEOGRAPH-#2890D, IRGKangXi=1290.030, RSKangXi=164.24
2890E CJK UNIFIED IDEOGRAPH-#2890E, IRGKangXi=1290.031, RSKangXi=164.24
2890F CJK UNIFIED IDEOGRAPH-#2890F, IRGKangXi=1290.070, RSKangXi=165.3
28910 CJK UNIFIED IDEOGRAPH-#28910, IRGKangXi=1290.080, RSKangXi=165.4
28911 CJK UNIFIED IDEOGRAPH-#28911, IRGKangXi=1290.090, RSKangXi=165.4
28912 CJK UNIFIED IDEOGRAPH-#28912, IRGKangXi=1290.110, RSKangXi=165.7
28913 CJK UNIFIED IDEOGRAPH-#28913, IRGKangXi=1290.120, RSKangXi=165.7
28914 CJK UNIFIED IDEOGRAPH-#28914, IRGKangXi=1290.121, RSKangXi=165.7
28915 CJK UNIFIED IDEOGRAPH-#28915, IRGKangXi=1290.130, RSKangXi=165.8
28916 CJK UNIFIED IDEOGRAPH-#28916, IRGKangXi=1290.140, RSKangXi=165.8
28917 CJK UNIFIED IDEOGRAPH-#28917, IRGKangXi=1290.141, RSKangXi=165.8
28918 CJK UNIFIED IDEOGRAPH-#28918, IRGKangXi=1290.150, RSKangXi=165.9
28919 CJK UNIFIED IDEOGRAPH-#28919, IRGKangXi=1290.151, RSKangXi=165.9
2891A CJK UNIFIED IDEOGRAPH-#2891A, IRGKangXi=1290.160, RSKangXi=165.10
2891B CJK UNIFIED IDEOGRAPH-#2891B, IRGKangXi=1290.161, RSKangXi=165.10
2891C CJK UNIFIED IDEOGRAPH-#2891C, IRGKangXi=1290.161, RSKangXi=165.10
2891D CJK UNIFIED IDEOGRAPH-#2891D, IRGKangXi=1290.161, RSKangXi=165.11
2891E CJK UNIFIED IDEOGRAPH-#2891E, IRGKangXi=1290.171, RSKangXi=165.13
2891F CJK UNIFIED IDEOGRAPH-#2891F, IRGKangXi=1290.171, RSKangXi=165.14
28920 CJK UNIFIED IDEOGRAPH-#28920, IRGKangXi=1290.171, RSKangXi=165.14
28921 CJK UNIFIED IDEOGRAPH-#28921, IRGKangXi=1291.010, RSKangXi=165.15
28922 CJK UNIFIED IDEOGRAPH-#28922, IRGKangXi=1292.010, RSKangXi=166.4
28923 CJK UNIFIED IDEOGRAPH-#28923, IRGKangXi=1292.020, RSKangXi=166.3
28924 CJK UNIFIED IDEOGRAPH-#28924, IRGKangXi=1292.021, RSKangXi=166.3
28925 CJK UNIFIED IDEOGRAPH-#28925, IRGKangXi=1292.040, RSKangXi=166.4
28926 CJK UNIFIED IDEOGRAPH-#28926, IRGKangXi=1292.080, RSKangXi=166.5
28927 CJK UNIFIED IDEOGRAPH-#28927, IRGKangXi=1292.081, RSKangXi=166.5
28928 CJK UNIFIED IDEOGRAPH-#28928, IRGKangXi=1292.081, RSKangXi=166.5
28929 CJK UNIFIED IDEOGRAPH-#28929, IRGKangXi=1292.081, RSKangXi=166.5
2892A CJK UNIFIED IDEOGRAPH-#2892A, IRGKangXi=1292.081, RSKangXi=166.6
2892B CJK UNIFIED IDEOGRAPH-#2892B, IRGKangXi=1292.081, RSKangXi=166.6
2892C CJK UNIFIED IDEOGRAPH-#2892C, IRGKangXi=1292.081, RSKangXi=166.7
2892D CJK UNIFIED IDEOGRAPH-#2892D, IRGKangXi=1292.090, RSKangXi=166.8
2892E CJK UNIFIED IDEOGRAPH-#2892E, IRGKangXi=1292.091, RSKangXi=166.8
2892F CJK UNIFIED IDEOGRAPH-#2892F, IRGKangXi=1292.091, RSKangXi=166.8
28930 CJK UNIFIED IDEOGRAPH-#28930, IRGKangXi=1292.091, RSKangXi=166.9
28931 CJK UNIFIED IDEOGRAPH-#28931, IRGKangXi=1292.091, RSKangXi=166.9
28932 CJK UNIFIED IDEOGRAPH-#28932, IRGKangXi=1292.091, RSKangXi=166.10
28933 CJK UNIFIED IDEOGRAPH-#28933, IRGKangXi=1292.091, RSKangXi=166.10
28934 CJK UNIFIED IDEOGRAPH-#28934, IRGKangXi=1292.120, RSKangXi=166.11
28935 CJK UNIFIED IDEOGRAPH-#28935, IRGKangXi=1292.121, RSKangXi=166.11
28936 CJK UNIFIED IDEOGRAPH-#28936, IRGKangXi=1292.121, RSKangXi=166.11
28937 CJK UNIFIED IDEOGRAPH-#28937, IRGKangXi=1292.121, RSKangXi=166.11
28938 CJK UNIFIED IDEOGRAPH-#28938, IRGKangXi=1292.121, RSKangXi=166.13
28939 CJK UNIFIED IDEOGRAPH-#28939, IRGKangXi=1292.130, RSKangXi=166.14
2893A CJK UNIFIED IDEOGRAPH-#2893A, IRGKangXi=1292.140, RSKangXi=166.14
2893B CJK UNIFIED IDEOGRAPH-#2893B, IRGKangXi=1292.141, RSKangXi=166.18
2893C CJK UNIFIED IDEOGRAPH-#2893C, IRGKangXi=1292.141, RSKangXi=166.23
2893D CJK UNIFIED IDEOGRAPH-#2893D, IRGKangXi=1295.050, RSKangXi=167.2
2893E CJK UNIFIED IDEOGRAPH-#2893E, IRGKangXi=1296.120, RSKangXi=167.2
2893F CJK UNIFIED IDEOGRAPH-#2893F, IRGKangXi=1296.121, RSKangXi=167.2
28940 CJK UNIFIED IDEOGRAPH-#28940, IRGKangXi=1296.121, RSKangXi=167.2
28941 CJK UNIFIED IDEOGRAPH-#28941, IRGKangXi=1296.121, RSKangXi=167.2
28942 CJK UNIFIED IDEOGRAPH-#28942, IRGKangXi=1296.180, RSKangXi=167.3
28943 CJK UNIFIED IDEOGRAPH-#28943, IRGKangXi=1297.130, RSKangXi=167.3
28944 CJK UNIFIED IDEOGRAPH-#28944, IRGKangXi=1297.140, RSKangXi=167.3
28945 CJK UNIFIED IDEOGRAPH-#28945, IRGKangXi=1297.141, RSKangXi=167.3
28946 CJK UNIFIED IDEOGRAPH-#28946, IRGKangXi=1297.141, RSKangXi=167.3
28947 CJK UNIFIED IDEOGRAPH-#28947, IRGKangXi=1297.141, RSKangXi=167.3
28948 CJK UNIFIED IDEOGRAPH-#28948, IRGKangXi=1297.141, RSKangXi=167.3
28949 CJK UNIFIED IDEOGRAPH-#28949, IRGKangXi=1297.141, RSKangXi=167.3
2894A CJK UNIFIED IDEOGRAPH-#2894A, IRGKangXi=1297.170, RSKangXi=167.4
2894B CJK UNIFIED IDEOGRAPH-#2894B, IRGKangXi=1298.030, RSKangXi=167.4
2894C CJK UNIFIED IDEOGRAPH-#2894C, IRGKangXi=1298.150, RSKangXi=167.4
2894D CJK UNIFIED IDEOGRAPH-#2894D, IRGKangXi=1299.130, RSKangXi=167.4
2894E CJK UNIFIED IDEOGRAPH-#2894E, IRGKangXi=1299.140, RSKangXi=167.4
2894F CJK UNIFIED IDEOGRAPH-#2894F, IRGKangXi=1299.150, RSKangXi=167.4
28950 CJK UNIFIED IDEOGRAPH-#28950, IRGKangXi=1299.160, RSKangXi=167.4
28951 CJK UNIFIED IDEOGRAPH-#28951, IRGKangXi=1299.170, RSKangXi=167.4
28952 CJK UNIFIED IDEOGRAPH-#28952, IRGKangXi=1299.190, RSKangXi=167.4
28953 CJK UNIFIED IDEOGRAPH-#28953, IRGKangXi=1299.191, RSKangXi=167.4
28954 CJK UNIFIED IDEOGRAPH-#28954, IRGKangXi=1299.191, RSKangXi=167.4
28955 CJK UNIFIED IDEOGRAPH-#28955, IRGKangXi=1299.191, RSKangXi=167.4
28956 CJK UNIFIED IDEOGRAPH-#28956, IRGKangXi=1299.191, RSKangXi=167.4
28957 CJK UNIFIED IDEOGRAPH-#28957, IRGKangXi=1299.191, RSKangXi=167.4
28958 CJK UNIFIED IDEOGRAPH-#28958, IRGKangXi=1299.191, RSKangXi=167.4
28959 CJK UNIFIED IDEOGRAPH-#28959, IRGKangXi=1299.191, RSKangXi=167.4
2895A CJK UNIFIED IDEOGRAPH-#2895A, IRGKangXi=1299.191, RSKangXi=167.4
2895B CJK UNIFIED IDEOGRAPH-#2895B, IRGKangXi=1299.191, RSKangXi=167.4
2895C CJK UNIFIED IDEOGRAPH-#2895C, IRGKangXi=1299.191, RSKangXi=167.4
2895D CJK UNIFIED IDEOGRAPH-#2895D, IRGKangXi=1299.191, RSKangXi=167.4
2895E CJK UNIFIED IDEOGRAPH-#2895E, IRGKangXi=1299.191, RSKangXi=167.4
2895F CJK UNIFIED IDEOGRAPH-#2895F, IRGKangXi=1299.191, RSKangXi=167.4
28960 CJK UNIFIED IDEOGRAPH-#28960, IRGKangXi=1299.191, RSKangXi=167.4
28961 CJK UNIFIED IDEOGRAPH-#28961, IRGKangXi=1299.191, RSKangXi=167.4
28962 CJK UNIFIED IDEOGRAPH-#28962, IRGKangXi=1299.191, RSKangXi=167.4
28963 CJK UNIFIED IDEOGRAPH-#28963, IRGKangXi=1299.191, RSKangXi=167.4
28964 CJK UNIFIED IDEOGRAPH-#28964, IRGKangXi=1299.191, RSKangXi=167.4
28965 CJK UNIFIED IDEOGRAPH-#28965, IRGKangXi=1299.260, RSKangXi=167.5
28966 CJK UNIFIED IDEOGRAPH-#28966, IRGKangXi=1300.030, RSKangXi=167.5
28967 CJK UNIFIED IDEOGRAPH-#28967, IRGKangXi=1300.100, RSKangXi=167.5
28968 CJK UNIFIED IDEOGRAPH-#28968, IRGKangXi=1301.010, RSKangXi=137.5
28969 CJK UNIFIED IDEOGRAPH-#28969, IRGKangXi=1303.070, RSKangXi=137.5
2896A CJK UNIFIED IDEOGRAPH-#2896A, IRGKangXi=1303.080, RSKangXi=167.5
2896B CJK UNIFIED IDEOGRAPH-#2896B, IRGKangXi=1303.101, RSKangXi=167.5
2896C CJK UNIFIED IDEOGRAPH-#2896C, IRGKangXi=1303.101, RSKangXi=167.5
2896D CJK UNIFIED IDEOGRAPH-#2896D, IRGKangXi=1303.101, RSKangXi=167.5
2896E CJK UNIFIED IDEOGRAPH-#2896E, IRGKangXi=1303.101, RSKangXi=167.5
2896F CJK UNIFIED IDEOGRAPH-#2896F, IRGKangXi=1303.101, RSKangXi=167.5
28970 CJK UNIFIED IDEOGRAPH-#28970, IRGKangXi=1303.101, RSKangXi=167.5
28971 CJK UNIFIED IDEOGRAPH-#28971, IRGKangXi=1303.101, RSKangXi=167.5
28972 CJK UNIFIED IDEOGRAPH-#28972, IRGKangXi=1303.101, RSKangXi=167.5
28973 CJK UNIFIED IDEOGRAPH-#28973, IRGKangXi=1303.101, RSKangXi=167.5
28974 CJK UNIFIED IDEOGRAPH-#28974, IRGKangXi=1303.101, RSKangXi=167.5
28975 CJK UNIFIED IDEOGRAPH-#28975, IRGKangXi=1303.101, RSKangXi=167.5
28976 CJK UNIFIED IDEOGRAPH-#28976, IRGKangXi=1303.101, RSKangXi=167.5
28977 CJK UNIFIED IDEOGRAPH-#28977, IRGKangXi=1303.101, RSKangXi=167.5
28978 CJK UNIFIED IDEOGRAPH-#28978, IRGKangXi=1303.101, RSKangXi=167.5
28979 CJK UNIFIED IDEOGRAPH-#28979, IRGKangXi=1303.101, RSKangXi=167.5
2897A CJK UNIFIED IDEOGRAPH-#2897A, IRGKangXi=1303.101, RSKangXi=167.5
2897B CJK UNIFIED IDEOGRAPH-#2897B, IRGKangXi=1303.101, RSKangXi=167.5
2897C CJK UNIFIED IDEOGRAPH-#2897C, IRGKangXi=1303.101, RSKangXi=167.5
2897D CJK UNIFIED IDEOGRAPH-#2897D, IRGKangXi=1303.101, RSKangXi=167.5
2897E CJK UNIFIED IDEOGRAPH-#2897E, IRGKangXi=1303.101, RSKangXi=167.5
2897F CJK UNIFIED IDEOGRAPH-#2897F, IRGKangXi=1303.101, RSKangXi=167.5
28980 CJK UNIFIED IDEOGRAPH-#28980, IRGKangXi=1303.101, RSKangXi=167.5
28981 CJK UNIFIED IDEOGRAPH-#28981, IRGKangXi=1303.101, RSKangXi=167.5
28982 CJK UNIFIED IDEOGRAPH-#28982, IRGKangXi=1303.110, RSKangXi=167.6
28983 CJK UNIFIED IDEOGRAPH-#28983, IRGKangXi=1303.140, RSKangXi=167.6
28984 CJK UNIFIED IDEOGRAPH-#28984, IRGKangXi=1305.020, RSKangXi=167.6
28985 CJK UNIFIED IDEOGRAPH-#28985, IRGKangXi=1305.160, RSKangXi=167.6
28986 CJK UNIFIED IDEOGRAPH-#28986, IRGKangXi=1305.180, RSKangXi=167.6
28987 CJK UNIFIED IDEOGRAPH-#28987, IRGKangXi=1305.211, RSKangXi=167.6
28988 CJK UNIFIED IDEOGRAPH-#28988, IRGKangXi=1305.211, RSKangXi=167.6
28989 CJK UNIFIED IDEOGRAPH-#28989, IRGKangXi=1305.211, RSKangXi=167.6
2898A CJK UNIFIED IDEOGRAPH-#2898A, IRGKangXi=1305.211, RSKangXi=167.6
2898B CJK UNIFIED IDEOGRAPH-#2898B, IRGKangXi=1305.211, RSKangXi=167.6
2898C CJK UNIFIED IDEOGRAPH-#2898C, IRGKangXi=1305.211, RSKangXi=167.6
2898D CJK UNIFIED IDEOGRAPH-#2898D, IRGKangXi=1305.211, RSKangXi=167.6
2898E CJK UNIFIED IDEOGRAPH-#2898E, IRGKangXi=1305.211, RSKangXi=167.6
2898F CJK UNIFIED IDEOGRAPH-#2898F, IRGKangXi=1305.211, RSKangXi=167.6
28990 CJK UNIFIED IDEOGRAPH-#28990, IRGKangXi=1305.211, RSKangXi=167.6
28991 CJK UNIFIED IDEOGRAPH-#28991, IRGKangXi=1305.211, RSKangXi=167.6
28992 CJK UNIFIED IDEOGRAPH-#28992, IRGKangXi=1305.211, RSKangXi=167.6
28993 CJK UNIFIED IDEOGRAPH-#28993, IRGKangXi=1305.211, RSKangXi=167.6
28994 CJK UNIFIED IDEOGRAPH-#28994, IRGKangXi=1305.211, RSKangXi=167.6
28995 CJK UNIFIED IDEOGRAPH-#28995, IRGKangXi=1305.211, RSKangXi=167.6
28996 CJK UNIFIED IDEOGRAPH-#28996, IRGKangXi=1305.211, RSKangXi=167.6
28997 CJK UNIFIED IDEOGRAPH-#28997, IRGKangXi=1305.211, RSKangXi=167.6
28998 CJK UNIFIED IDEOGRAPH-#28998, IRGKangXi=1305.211, RSKangXi=167.6
28999 CJK UNIFIED IDEOGRAPH-#28999, IRGKangXi=1305.211, RSKangXi=167.6
2899A CJK UNIFIED IDEOGRAPH-#2899A, IRGKangXi=1305.211, RSKangXi=167.6
2899B CJK UNIFIED IDEOGRAPH-#2899B, IRGKangXi=1305.211, RSKangXi=167.6
2899C CJK UNIFIED IDEOGRAPH-#2899C, IRGKangXi=1305.211, RSKangXi=167.6
2899D CJK UNIFIED IDEOGRAPH-#2899D, IRGKangXi=1305.211, RSKangXi=167.6
2899E CJK UNIFIED IDEOGRAPH-#2899E, IRGKangXi=1305.211, RSKangXi=137.8
2899F CJK UNIFIED IDEOGRAPH-#2899F, IRGKangXi=1305.211, RSKangXi=167.6
289A0 CJK UNIFIED IDEOGRAPH-#289A0, IRGKangXi=1305.211, RSKangXi=167.6
289A1 CJK UNIFIED IDEOGRAPH-#289A1, IRGKangXi=1305.211, RSKangXi=167.6
289A2 CJK UNIFIED IDEOGRAPH-#289A2, IRGKangXi=1305.211, RSKangXi=167.6
289A3 CJK UNIFIED IDEOGRAPH-#289A3, IRGKangXi=1305.211, RSKangXi=167.6
289A4 CJK UNIFIED IDEOGRAPH-#289A4, IRGKangXi=1305.211, RSKangXi=167.6
289A5 CJK UNIFIED IDEOGRAPH-#289A5, IRGKangXi=1305.211, RSKangXi=167.6
289A6 CJK UNIFIED IDEOGRAPH-#289A6, IRGKangXi=1305.211, RSKangXi=167.6
289A7 CJK UNIFIED IDEOGRAPH-#289A7, IRGKangXi=1305.211, RSKangXi=167.6
289A8 CJK UNIFIED IDEOGRAPH-#289A8, IRGKangXi=1305.211, RSKangXi=167.6
289A9 CJK UNIFIED IDEOGRAPH-#289A9, IRGKangXi=1305.211, RSKangXi=167.6
289AA CJK UNIFIED IDEOGRAPH-#289AA, IRGKangXi=1305.211, RSKangXi=167.6
289AB CJK UNIFIED IDEOGRAPH-#289AB, IRGKangXi=1305.211, RSKangXi=167.6
289AC CJK UNIFIED IDEOGRAPH-#289AC, IRGKangXi=1306.050, RSKangXi=167.7
289AD CJK UNIFIED IDEOGRAPH-#289AD, IRGKangXi=1306.240, RSKangXi=167.7
289AE CJK UNIFIED IDEOGRAPH-#289AE, IRGKangXi=1307.100, RSKangXi=167.7
289AF CJK UNIFIED IDEOGRAPH-#289AF, IRGKangXi=1307.160, RSKangXi=167.7
289B0 CJK UNIFIED IDEOGRAPH-#289B0, IRGKangXi=1308.010, RSKangXi=167.7
289B1 CJK UNIFIED IDEOGRAPH-#289B1, IRGKangXi=1308.030, RSKangXi=167.7
289B2 CJK UNIFIED IDEOGRAPH-#289B2, IRGKangXi=1308.060, RSKangXi=167.7
289B3 CJK UNIFIED IDEOGRAPH-#289B3, IRGKangXi=1308.110, RSKangXi=167.7
289B4 CJK UNIFIED IDEOGRAPH-#289B4, IRGKangXi=1308.170, RSKangXi=167.7
289B5 CJK UNIFIED IDEOGRAPH-#289B5, IRGKangXi=1308.200, RSKangXi=167.7
289B6 CJK UNIFIED IDEOGRAPH-#289B6, IRGKangXi=1308.220, RSKangXi=167.7
289B7 CJK UNIFIED IDEOGRAPH-#289B7, IRGKangXi=1308.240, RSKangXi=167.7
289B8 CJK UNIFIED IDEOGRAPH-#289B8, IRGKangXi=1308.260, RSKangXi=167.7
289B9 CJK UNIFIED IDEOGRAPH-#289B9, IRGKangXi=1308.261, RSKangXi=167.7
289BA CJK UNIFIED IDEOGRAPH-#289BA, IRGKangXi=1308.261, RSKangXi=167.7
289BB CJK UNIFIED IDEOGRAPH-#289BB, IRGKangXi=1308.261, RSKangXi=167.7
289BC CJK UNIFIED IDEOGRAPH-#289BC, IRGKangXi=1308.261, RSKangXi=167.7
289BD CJK UNIFIED IDEOGRAPH-#289BD, IRGKangXi=1308.261, RSKangXi=167.7
289BE CJK UNIFIED IDEOGRAPH-#289BE, IRGKangXi=1308.261, RSKangXi=167.7
289BF CJK UNIFIED IDEOGRAPH-#289BF, IRGKangXi=1308.261, RSKangXi=167.7
289C0 CJK UNIFIED IDEOGRAPH-#289C0, IRGKangXi=1308.261, RSKangXi=167.7
289C1 CJK UNIFIED IDEOGRAPH-#289C1, IRGKangXi=1308.261, RSKangXi=167.7
289C2 CJK UNIFIED IDEOGRAPH-#289C2, IRGKangXi=1308.261, RSKangXi=167.7
289C3 CJK UNIFIED IDEOGRAPH-#289C3, IRGKangXi=1308.261, RSKangXi=167.7
289C4 CJK UNIFIED IDEOGRAPH-#289C4, IRGKangXi=1308.261, RSKangXi=167.7
289C5 CJK UNIFIED IDEOGRAPH-#289C5, IRGKangXi=1308.261, RSKangXi=167.7
289C6 CJK UNIFIED IDEOGRAPH-#289C6, IRGKangXi=1308.261, RSKangXi=167.7
289C7 CJK UNIFIED IDEOGRAPH-#289C7, IRGKangXi=1308.261, RSKangXi=167.7
289C8 CJK UNIFIED IDEOGRAPH-#289C8, IRGKangXi=1308.261, RSKangXi=167.7
289C9 CJK UNIFIED IDEOGRAPH-#289C9, IRGKangXi=1308.261, RSKangXi=167.7
289CA CJK UNIFIED IDEOGRAPH-#289CA, IRGKangXi=1308.261, RSKangXi=167.7
289CB CJK UNIFIED IDEOGRAPH-#289CB, IRGKangXi=1308.261, RSKangXi=167.7
289CC CJK UNIFIED IDEOGRAPH-#289CC, IRGKangXi=1308.261, RSKangXi=167.7
289CD CJK UNIFIED IDEOGRAPH-#289CD, IRGKangXi=1308.261, RSKangXi=167.7
289CE CJK UNIFIED IDEOGRAPH-#289CE, IRGKangXi=1308.261, RSKangXi=167.7
289CF CJK UNIFIED IDEOGRAPH-#289CF, IRGKangXi=1308.261, RSKangXi=167.7
289D0 CJK UNIFIED IDEOGRAPH-#289D0, IRGKangXi=1308.261, RSKangXi=167.7
289D1 CJK UNIFIED IDEOGRAPH-#289D1, IRGKangXi=1308.261, RSKangXi=167.7
289D2 CJK UNIFIED IDEOGRAPH-#289D2, IRGKangXi=1308.261, RSKangXi=167.7
289D3 CJK UNIFIED IDEOGRAPH-#289D3, IRGKangXi=1308.261, RSKangXi=167.7
289D4 CJK UNIFIED IDEOGRAPH-#289D4, IRGKangXi=1308.261, RSKangXi=167.7
289D5 CJK UNIFIED IDEOGRAPH-#289D5, IRGKangXi=1308.261, RSKangXi=167.7
289D6 CJK UNIFIED IDEOGRAPH-#289D6, IRGKangXi=1308.261, RSKangXi=167.7
289D7 CJK UNIFIED IDEOGRAPH-#289D7, IRGKangXi=1308.261, RSKangXi=167.7
289D8 CJK UNIFIED IDEOGRAPH-#289D8, IRGKangXi=1308.261, RSKangXi=167.7
289D9 CJK UNIFIED IDEOGRAPH-#289D9, IRGKangXi=1308.261, RSKangXi=167.7
289DA CJK UNIFIED IDEOGRAPH-#289DA, IRGKangXi=1308.261, RSKangXi=167.7
289DB CJK UNIFIED IDEOGRAPH-#289DB, IRGKangXi=1308.261, RSKangXi=167.7
289DC CJK UNIFIED IDEOGRAPH-#289DC, IRGKangXi=1308.261, RSKangXi=167.7, Def{a broad hoe, a mattock}
289DD CJK UNIFIED IDEOGRAPH-#289DD, IRGKangXi=1308.261, RSKangXi=167.7
289DE CJK UNIFIED IDEOGRAPH-#289DE, IRGKangXi=1308.261, RSKangXi=167.7
289DF CJK UNIFIED IDEOGRAPH-#289DF, IRGKangXi=1308.261, RSKangXi=167.7
289E0 CJK UNIFIED IDEOGRAPH-#289E0, IRGKangXi=1308.261, RSKangXi=167.7
289E1 CJK UNIFIED IDEOGRAPH-#289E1, IRGKangXi=1308.261, RSKangXi=167.7
289E2 CJK UNIFIED IDEOGRAPH-#289E2, IRGKangXi=1308.261, RSKangXi=167.7
289E3 CJK UNIFIED IDEOGRAPH-#289E3, IRGKangXi=1308.261, RSKangXi=167.7
289E4 CJK UNIFIED IDEOGRAPH-#289E4, IRGKangXi=1308.261, RSKangXi=167.7
289E5 CJK UNIFIED IDEOGRAPH-#289E5, IRGKangXi=1308.261, RSKangXi=167.7
289E6 CJK UNIFIED IDEOGRAPH-#289E6, IRGKangXi=1309.090, RSKangXi=167.8
289E7 CJK UNIFIED IDEOGRAPH-#289E7, IRGKangXi=1309.130, RSKangXi=167.8, Def{to strike, attack}
289E8 CJK UNIFIED IDEOGRAPH-#289E8, IRGKangXi=1309.140, RSKangXi=167.8
289E9 CJK UNIFIED IDEOGRAPH-#289E9, IRGKangXi=1309.190, RSKangXi=167.8
289EA CJK UNIFIED IDEOGRAPH-#289EA, IRGKangXi=1309.240, RSKangXi=167.8
289EB CJK UNIFIED IDEOGRAPH-#289EB, IRGKangXi=1310.030, RSKangXi=167.8
289EC CJK UNIFIED IDEOGRAPH-#289EC, IRGKangXi=1310.090, RSKangXi=167.8
289ED CJK UNIFIED IDEOGRAPH-#289ED, IRGKangXi=1310.130, RSKangXi=167.8
289EE CJK UNIFIED IDEOGRAPH-#289EE, IRGKangXi=1310.140, RSKangXi=167.8
289EF CJK UNIFIED IDEOGRAPH-#289EF, IRGKangXi=1310.150, RSKangXi=167.8
289F0 CJK UNIFIED IDEOGRAPH-#289F0, IRGKangXi=1311.030, RSKangXi=167.8
289F1 CJK UNIFIED IDEOGRAPH-#289F1, IRGKangXi=1311.040, RSKangXi=167.8
289F2 CJK UNIFIED IDEOGRAPH-#289F2, IRGKangXi=1312.070, RSKangXi=167.8
289F3 CJK UNIFIED IDEOGRAPH-#289F3, IRGKangXi=1312.080, RSKangXi=167.8
289F4 CJK UNIFIED IDEOGRAPH-#289F4, IRGKangXi=1313.020, RSKangXi=167.8
289F5 CJK UNIFIED IDEOGRAPH-#289F5, IRGKangXi=1313.030, RSKangXi=167.8
289F6 CJK UNIFIED IDEOGRAPH-#289F6, IRGKangXi=1313.050, RSKangXi=167.8
289F7 CJK UNIFIED IDEOGRAPH-#289F7, IRGKangXi=1313.051, RSKangXi=167.8
289F8 CJK UNIFIED IDEOGRAPH-#289F8, IRGKangXi=1313.051, RSKangXi=167.8
289F9 CJK UNIFIED IDEOGRAPH-#289F9, IRGKangXi=1313.051, RSKangXi=167.8
289FA CJK UNIFIED IDEOGRAPH-#289FA, IRGKangXi=1313.051, RSKangXi=167.8
289FB CJK UNIFIED IDEOGRAPH-#289FB, IRGKangXi=1313.051, RSKangXi=167.8
289FC CJK UNIFIED IDEOGRAPH-#289FC, IRGKangXi=1313.051, RSKangXi=167.8
289FD CJK UNIFIED IDEOGRAPH-#289FD, IRGKangXi=1313.051, RSKangXi=167.8
289FE CJK UNIFIED IDEOGRAPH-#289FE, IRGKangXi=1313.051, RSKangXi=167.8
289FF CJK UNIFIED IDEOGRAPH-#289FF, IRGKangXi=1313.051, RSKangXi=167.8
28A00 CJK UNIFIED IDEOGRAPH-#28A00, IRGKangXi=1313.051, RSKangXi=167.8
28A01 CJK UNIFIED IDEOGRAPH-#28A01, IRGKangXi=1313.051, RSKangXi=167.8
28A02 CJK UNIFIED IDEOGRAPH-#28A02, IRGKangXi=1313.051, RSKangXi=167.8
28A03 CJK UNIFIED IDEOGRAPH-#28A03, IRGKangXi=1313.051, RSKangXi=167.8
28A04 CJK UNIFIED IDEOGRAPH-#28A04, IRGKangXi=1313.051, RSKangXi=167.8
28A05 CJK UNIFIED IDEOGRAPH-#28A05, IRGKangXi=1313.051, RSKangXi=167.8
28A06 CJK UNIFIED IDEOGRAPH-#28A06, IRGKangXi=1313.051, RSKangXi=167.8
28A07 CJK UNIFIED IDEOGRAPH-#28A07, IRGKangXi=1313.051, RSKangXi=167.8
28A08 CJK UNIFIED IDEOGRAPH-#28A08, IRGKangXi=1313.051, RSKangXi=167.8
28A09 CJK UNIFIED IDEOGRAPH-#28A09, IRGKangXi=1313.051, RSKangXi=167.8
28A0A CJK UNIFIED IDEOGRAPH-#28A0A, IRGKangXi=1313.051, RSKangXi=167.8
28A0B CJK UNIFIED IDEOGRAPH-#28A0B, IRGKangXi=1313.051, RSKangXi=167.8
28A0C CJK UNIFIED IDEOGRAPH-#28A0C, IRGKangXi=1313.051, RSKangXi=167.8
28A0D CJK UNIFIED IDEOGRAPH-#28A0D, IRGKangXi=1313.051, RSKangXi=167.8
28A0E CJK UNIFIED IDEOGRAPH-#28A0E, IRGKangXi=1313.051, RSKangXi=167.8
28A0F CJK UNIFIED IDEOGRAPH-#28A0F, IRGKangXi=1313.051, RSKangXi=167.8
28A10 CJK UNIFIED IDEOGRAPH-#28A10, IRGKangXi=1313.051, RSKangXi=167.8
28A11 CJK UNIFIED IDEOGRAPH-#28A11, IRGKangXi=1313.051, RSKangXi=167.8
28A12 CJK UNIFIED IDEOGRAPH-#28A12, IRGKangXi=1313.051, RSKangXi=167.8
28A13 CJK UNIFIED IDEOGRAPH-#28A13, IRGKangXi=1313.051, RSKangXi=167.8
28A14 CJK UNIFIED IDEOGRAPH-#28A14, IRGKangXi=1313.051, RSKangXi=167.8
28A15 CJK UNIFIED IDEOGRAPH-#28A15, IRGKangXi=1313.051, RSKangXi=167.8
28A16 CJK UNIFIED IDEOGRAPH-#28A16, IRGKangXi=1313.051, RSKangXi=167.8
28A17 CJK UNIFIED IDEOGRAPH-#28A17, IRGKangXi=1313.051, RSKangXi=167.8
28A18 CJK UNIFIED IDEOGRAPH-#28A18, IRGKangXi=1313.051, RSKangXi=167.8
28A19 CJK UNIFIED IDEOGRAPH-#28A19, IRGKangXi=1313.051, RSKangXi=167.8
28A1A CJK UNIFIED IDEOGRAPH-#28A1A, IRGKangXi=1313.051, RSKangXi=167.8
28A1B CJK UNIFIED IDEOGRAPH-#28A1B, IRGKangXi=1313.051, RSKangXi=167.8
28A1C CJK UNIFIED IDEOGRAPH-#28A1C, IRGKangXi=1313.051, RSKangXi=167.8
28A1D CJK UNIFIED IDEOGRAPH-#28A1D, IRGKangXi=1313.051, RSKangXi=167.8
28A1E CJK UNIFIED IDEOGRAPH-#28A1E, IRGKangXi=1313.051, RSKangXi=167.8
28A1F CJK UNIFIED IDEOGRAPH-#28A1F, IRGKangXi=1313.051, RSKangXi=167.8
28A20 CJK UNIFIED IDEOGRAPH-#28A20, IRGKangXi=1313.051, RSKangXi=167.8
28A21 CJK UNIFIED IDEOGRAPH-#28A21, IRGKangXi=1313.051, RSKangXi=167.8
28A22 CJK UNIFIED IDEOGRAPH-#28A22, IRGKangXi=1313.051, RSKangXi=167.8
28A23 CJK UNIFIED IDEOGRAPH-#28A23, IRGKangXi=1313.051, RSKangXi=167.8
28A24 CJK UNIFIED IDEOGRAPH-#28A24, IRGKangXi=1313.051, RSKangXi=167.8
28A25 CJK UNIFIED IDEOGRAPH-#28A25, IRGKangXi=1313.051, RSKangXi=167.8
28A26 CJK UNIFIED IDEOGRAPH-#28A26, IRGKangXi=1313.051, RSKangXi=167.8
28A27 CJK UNIFIED IDEOGRAPH-#28A27, IRGKangXi=1313.051, RSKangXi=167.8
28A28 CJK UNIFIED IDEOGRAPH-#28A28, IRGKangXi=1313.051, RSKangXi=167.8
28A29 CJK UNIFIED IDEOGRAPH-#28A29, IRGKangXi=1313.051, RSKangXi=167.8
28A2A CJK UNIFIED IDEOGRAPH-#28A2A, IRGKangXi=1313.051, RSKangXi=167.8
28A2B CJK UNIFIED IDEOGRAPH-#28A2B, IRGKangXi=1313.051, RSKangXi=167.8
28A2C CJK UNIFIED IDEOGRAPH-#28A2C, IRGKangXi=1313.051, RSKangXi=167.8
28A2D CJK UNIFIED IDEOGRAPH-#28A2D, IRGKangXi=1313.051, RSKangXi=167.8
28A2E CJK UNIFIED IDEOGRAPH-#28A2E, IRGKangXi=1313.051, RSKangXi=167.8
28A2F CJK UNIFIED IDEOGRAPH-#28A2F, IRGKangXi=1313.110, RSKangXi=167.9
28A30 CJK UNIFIED IDEOGRAPH-#28A30, IRGKangXi=1313.130, RSKangXi=167.9
28A31 CJK UNIFIED IDEOGRAPH-#28A31, IRGKangXi=1314.020, RSKangXi=167.9
28A32 CJK UNIFIED IDEOGRAPH-#28A32, IRGKangXi=1315.120, RSKangXi=167.9
28A33 CJK UNIFIED IDEOGRAPH-#28A33, IRGKangXi=1315.150, RSKangXi=167.9
28A34 CJK UNIFIED IDEOGRAPH-#28A34, IRGKangXi=1315.200, RSKangXi=167.9
28A35 CJK UNIFIED IDEOGRAPH-#28A35, IRGKangXi=1315.220, RSKangXi=167.9
28A36 CJK UNIFIED IDEOGRAPH-#28A36, IRGKangXi=1315.230, RSKangXi=167.9
28A37 CJK UNIFIED IDEOGRAPH-#28A37, IRGKangXi=1315.240, RSKangXi=167.9
28A38 CJK UNIFIED IDEOGRAPH-#28A38, IRGKangXi=1315.260, RSKangXi=167.9
28A39 CJK UNIFIED IDEOGRAPH-#28A39, IRGKangXi=1316.010, RSKangXi=167.9
28A3A CJK UNIFIED IDEOGRAPH-#28A3A, IRGKangXi=1316.020, RSKangXi=167.9
28A3B CJK UNIFIED IDEOGRAPH-#28A3B, IRGKangXi=1316.030, RSKangXi=167.9
28A3C CJK UNIFIED IDEOGRAPH-#28A3C, IRGKangXi=1316.080, RSKangXi=167.9
28A3D CJK UNIFIED IDEOGRAPH-#28A3D, IRGKangXi=1316.100, RSKangXi=167.9
28A3E CJK UNIFIED IDEOGRAPH-#28A3E, IRGKangXi=1316.110, RSKangXi=167.9
28A3F CJK UNIFIED IDEOGRAPH-#28A3F, IRGKangXi=1316.111, RSKangXi=167.9
28A40 CJK UNIFIED IDEOGRAPH-#28A40, IRGKangXi=1316.111, RSKangXi=167.9
28A41 CJK UNIFIED IDEOGRAPH-#28A41, IRGKangXi=1316.111, RSKangXi=167.9
28A42 CJK UNIFIED IDEOGRAPH-#28A42, IRGKangXi=1316.111, RSKangXi=167.9
28A43 CJK UNIFIED IDEOGRAPH-#28A43, IRGKangXi=1316.111, RSKangXi=167.9
28A44 CJK UNIFIED IDEOGRAPH-#28A44, IRGKangXi=1316.111, RSKangXi=167.9
28A45 CJK UNIFIED IDEOGRAPH-#28A45, IRGKangXi=1316.111, RSKangXi=167.9
28A46 CJK UNIFIED IDEOGRAPH-#28A46, IRGKangXi=1316.111, RSKangXi=167.9
28A47 CJK UNIFIED IDEOGRAPH-#28A47, IRGKangXi=1316.111, RSKangXi=167.9
28A48 CJK UNIFIED IDEOGRAPH-#28A48, IRGKangXi=1316.111, RSKangXi=167.9
28A49 CJK UNIFIED IDEOGRAPH-#28A49, IRGKangXi=1316.111, RSKangXi=167.9
28A4A CJK UNIFIED IDEOGRAPH-#28A4A, IRGKangXi=1316.111, RSKangXi=167.9
28A4B CJK UNIFIED IDEOGRAPH-#28A4B, IRGKangXi=1316.111, RSKangXi=167.9
28A4C CJK UNIFIED IDEOGRAPH-#28A4C, IRGKangXi=1316.111, RSKangXi=167.9
28A4D CJK UNIFIED IDEOGRAPH-#28A4D, IRGKangXi=1316.111, RSKangXi=167.9
28A4E CJK UNIFIED IDEOGRAPH-#28A4E, IRGKangXi=1316.111, RSKangXi=167.9
28A4F CJK UNIFIED IDEOGRAPH-#28A4F, IRGKangXi=1316.111, RSKangXi=167.9
28A50 CJK UNIFIED IDEOGRAPH-#28A50, IRGKangXi=1316.111, RSKangXi=167.9
28A51 CJK UNIFIED IDEOGRAPH-#28A51, IRGKangXi=1316.111, RSKangXi=167.9
28A52 CJK UNIFIED IDEOGRAPH-#28A52, IRGKangXi=1316.111, RSKangXi=167.9
28A53 CJK UNIFIED IDEOGRAPH-#28A53, IRGKangXi=1316.111, RSKangXi=167.9
28A54 CJK UNIFIED IDEOGRAPH-#28A54, IRGKangXi=1316.111, RSKangXi=167.9
28A55 CJK UNIFIED IDEOGRAPH-#28A55, IRGKangXi=1316.111, RSKangXi=167.9
28A56 CJK UNIFIED IDEOGRAPH-#28A56, IRGKangXi=1316.111, RSKangXi=167.9
28A57 CJK UNIFIED IDEOGRAPH-#28A57, IRGKangXi=1316.111, RSKangXi=167.9
28A58 CJK UNIFIED IDEOGRAPH-#28A58, IRGKangXi=1316.111, RSKangXi=167.9
28A59 CJK UNIFIED IDEOGRAPH-#28A59, IRGKangXi=1316.111, RSKangXi=167.9
28A5A CJK UNIFIED IDEOGRAPH-#28A5A, IRGKangXi=1316.111, RSKangXi=167.9
28A5B CJK UNIFIED IDEOGRAPH-#28A5B, IRGKangXi=1316.111, RSKangXi=167.9
28A5C CJK UNIFIED IDEOGRAPH-#28A5C, IRGKangXi=1316.111, RSKangXi=167.9
28A5D CJK UNIFIED IDEOGRAPH-#28A5D, IRGKangXi=1316.111, RSKangXi=167.9
28A5E CJK UNIFIED IDEOGRAPH-#28A5E, IRGKangXi=1316.111, RSKangXi=167.9
28A5F CJK UNIFIED IDEOGRAPH-#28A5F, IRGKangXi=1316.111, RSKangXi=167.9
28A60 CJK UNIFIED IDEOGRAPH-#28A60, IRGKangXi=1316.111, RSKangXi=167.9
28A61 CJK UNIFIED IDEOGRAPH-#28A61, IRGKangXi=1316.111, RSKangXi=167.9
28A62 CJK UNIFIED IDEOGRAPH-#28A62, IRGKangXi=1316.111, RSKangXi=167.9
28A63 CJK UNIFIED IDEOGRAPH-#28A63, IRGKangXi=1316.111, RSKangXi=167.9
28A64 CJK UNIFIED IDEOGRAPH-#28A64, IRGKangXi=1316.111, RSKangXi=167.9
28A65 CJK UNIFIED IDEOGRAPH-#28A65, IRGKangXi=1316.111, RSKangXi=167.9
28A66 CJK UNIFIED IDEOGRAPH-#28A66, IRGKangXi=1316.111, RSKangXi=167.9
28A67 CJK UNIFIED IDEOGRAPH-#28A67, IRGKangXi=1316.111, RSKangXi=167.9
28A68 CJK UNIFIED IDEOGRAPH-#28A68, IRGKangXi=1316.111, RSKangXi=167.9
28A69 CJK UNIFIED IDEOGRAPH-#28A69, IRGKangXi=1316.111, RSKangXi=167.9
28A6A CJK UNIFIED IDEOGRAPH-#28A6A, IRGKangXi=1316.111, RSKangXi=167.9
28A6B CJK UNIFIED IDEOGRAPH-#28A6B, IRGKangXi=1316.111, RSKangXi=167.9
28A6C CJK UNIFIED IDEOGRAPH-#28A6C, IRGKangXi=1316.111, RSKangXi=167.9
28A6D CJK UNIFIED IDEOGRAPH-#28A6D, IRGKangXi=1316.111, RSKangXi=167.9
28A6E CJK UNIFIED IDEOGRAPH-#28A6E, IRGKangXi=1316.111, RSKangXi=167.9
28A6F CJK UNIFIED IDEOGRAPH-#28A6F, IRGKangXi=1316.111, RSKangXi=167.9
28A70 CJK UNIFIED IDEOGRAPH-#28A70, IRGKangXi=1316.111, RSKangXi=167.9
28A71 CJK UNIFIED IDEOGRAPH-#28A71, IRGKangXi=1316.111, RSKangXi=167.9
28A72 CJK UNIFIED IDEOGRAPH-#28A72, IRGKangXi=1316.111, RSKangXi=167.9
28A73 CJK UNIFIED IDEOGRAPH-#28A73, IRGKangXi=1316.111, RSKangXi=167.9
28A74 CJK UNIFIED IDEOGRAPH-#28A74, IRGKangXi=1316.111, RSKangXi=167.9
28A75 CJK UNIFIED IDEOGRAPH-#28A75, IRGKangXi=1316.111, RSKangXi=167.9
28A76 CJK UNIFIED IDEOGRAPH-#28A76, IRGKangXi=1316.111, RSKangXi=167.9
28A77 CJK UNIFIED IDEOGRAPH-#28A77, IRGKangXi=1316.111, RSKangXi=167.9
28A78 CJK UNIFIED IDEOGRAPH-#28A78, IRGKangXi=1316.111, RSKangXi=167.9
28A79 CJK UNIFIED IDEOGRAPH-#28A79, IRGKangXi=1316.111, RSKangXi=167.9
28A7A CJK UNIFIED IDEOGRAPH-#28A7A, IRGKangXi=1316.111, RSKangXi=167.9
28A7B CJK UNIFIED IDEOGRAPH-#28A7B, IRGKangXi=1316.111, RSKangXi=167.9
28A7C CJK UNIFIED IDEOGRAPH-#28A7C, IRGKangXi=1316.111, RSKangXi=167.9
28A7D CJK UNIFIED IDEOGRAPH-#28A7D, IRGKangXi=1316.111, RSKangXi=167.9
28A7E CJK UNIFIED IDEOGRAPH-#28A7E, IRGKangXi=1316.111, RSKangXi=167.9
28A7F CJK UNIFIED IDEOGRAPH-#28A7F, IRGKangXi=1316.111, RSKangXi=167.9
28A80 CJK UNIFIED IDEOGRAPH-#28A80, IRGKangXi=1316.111, RSKangXi=167.9
28A81 CJK UNIFIED IDEOGRAPH-#28A81, IRGKangXi=1316.111, RSKangXi=167.9
28A82 CJK UNIFIED IDEOGRAPH-#28A82, IRGKangXi=1316.111, RSKangXi=167.9
28A83 CJK UNIFIED IDEOGRAPH-#28A83, IRGKangXi=1316.111, RSKangXi=167.9
28A84 CJK UNIFIED IDEOGRAPH-#28A84, IRGKangXi=1316.111, RSKangXi=167.9
28A85 CJK UNIFIED IDEOGRAPH-#28A85, IRGKangXi=1316.111, RSKangXi=167.9
28A86 CJK UNIFIED IDEOGRAPH-#28A86, IRGKangXi=1316.111, RSKangXi=167.9
28A87 CJK UNIFIED IDEOGRAPH-#28A87, IRGKangXi=1316.200, RSKangXi=167.10
28A88 CJK UNIFIED IDEOGRAPH-#28A88, IRGKangXi=1316.250, RSKangXi=167.10
28A89 CJK UNIFIED IDEOGRAPH-#28A89, IRGKangXi=1317.080, RSKangXi=167.10
28A8A CJK UNIFIED IDEOGRAPH-#28A8A, IRGKangXi=1317.110, RSKangXi=167.10
28A8B CJK UNIFIED IDEOGRAPH-#28A8B, IRGKangXi=1317.130, RSKangXi=167.10
28A8C CJK UNIFIED IDEOGRAPH-#28A8C, IRGKangXi=1317.140, RSKangXi=167.10
28A8D CJK UNIFIED IDEOGRAPH-#28A8D, IRGKangXi=1317.220, RSKangXi=167.10
28A8E CJK UNIFIED IDEOGRAPH-#28A8E, IRGKangXi=1317.230, RSKangXi=167.10
28A8F CJK UNIFIED IDEOGRAPH-#28A8F, IRGKangXi=1318.020, RSKangXi=167.10
28A90 CJK UNIFIED IDEOGRAPH-#28A90, IRGKangXi=1318.130, RSKangXi=167.10
28A91 CJK UNIFIED IDEOGRAPH-#28A91, IRGKangXi=1318.140, RSKangXi=167.10
28A92 CJK UNIFIED IDEOGRAPH-#28A92, IRGKangXi=1318.200, RSKangXi=167.10
28A93 CJK UNIFIED IDEOGRAPH-#28A93, IRGKangXi=1318.210, RSKangXi=167.10
28A94 CJK UNIFIED IDEOGRAPH-#28A94, IRGKangXi=1318.240, RSKangXi=167.10
28A95 CJK UNIFIED IDEOGRAPH-#28A95, IRGKangXi=1318.260, RSKangXi=167.10
28A96 CJK UNIFIED IDEOGRAPH-#28A96, IRGKangXi=1318.270, RSKangXi=167.10
28A97 CJK UNIFIED IDEOGRAPH-#28A97, IRGKangXi=1318.280, RSKangXi=167.10
28A98 CJK UNIFIED IDEOGRAPH-#28A98, IRGKangXi=1318.281, RSKangXi=167.10
28A99 CJK UNIFIED IDEOGRAPH-#28A99, IRGKangXi=1318.281, RSKangXi=167.10
28A9A CJK UNIFIED IDEOGRAPH-#28A9A, IRGKangXi=1318.281, RSKangXi=167.10
28A9B CJK UNIFIED IDEOGRAPH-#28A9B, IRGKangXi=1318.281, RSKangXi=167.10
28A9C CJK UNIFIED IDEOGRAPH-#28A9C, IRGKangXi=1318.281, RSKangXi=167.10
28A9D CJK UNIFIED IDEOGRAPH-#28A9D, IRGKangXi=1318.281, RSKangXi=167.10
28A9E CJK UNIFIED IDEOGRAPH-#28A9E, IRGKangXi=1318.281, RSKangXi=167.10
28A9F CJK UNIFIED IDEOGRAPH-#28A9F, IRGKangXi=1318.281, RSKangXi=167.10
28AA0 CJK UNIFIED IDEOGRAPH-#28AA0, IRGKangXi=1318.281, RSKangXi=167.10
28AA1 CJK UNIFIED IDEOGRAPH-#28AA1, IRGKangXi=1318.281, RSKangXi=167.10
28AA2 CJK UNIFIED IDEOGRAPH-#28AA2, IRGKangXi=1318.281, RSKangXi=167.10
28AA3 CJK UNIFIED IDEOGRAPH-#28AA3, IRGKangXi=1318.281, RSKangXi=167.10
28AA4 CJK UNIFIED IDEOGRAPH-#28AA4, IRGKangXi=1318.281, RSKangXi=167.10
28AA5 CJK UNIFIED IDEOGRAPH-#28AA5, IRGKangXi=1318.281, RSKangXi=167.10
28AA6 CJK UNIFIED IDEOGRAPH-#28AA6, IRGKangXi=1318.281, RSKangXi=167.10
28AA7 CJK UNIFIED IDEOGRAPH-#28AA7, IRGKangXi=1318.281, RSKangXi=167.10
28AA8 CJK UNIFIED IDEOGRAPH-#28AA8, IRGKangXi=1318.281, RSKangXi=167.10
28AA9 CJK UNIFIED IDEOGRAPH-#28AA9, IRGKangXi=1318.281, RSKangXi=167.10
28AAA CJK UNIFIED IDEOGRAPH-#28AAA, IRGKangXi=1318.281, RSKangXi=167.10
28AAB CJK UNIFIED IDEOGRAPH-#28AAB, IRGKangXi=1318.281, RSKangXi=167.10
28AAC CJK UNIFIED IDEOGRAPH-#28AAC, IRGKangXi=1318.281, RSKangXi=167.10
28AAD CJK UNIFIED IDEOGRAPH-#28AAD, IRGKangXi=1318.281, RSKangXi=167.10
28AAE CJK UNIFIED IDEOGRAPH-#28AAE, IRGKangXi=1318.281, RSKangXi=167.10
28AAF CJK UNIFIED IDEOGRAPH-#28AAF, IRGKangXi=1318.281, RSKangXi=167.10
28AB0 CJK UNIFIED IDEOGRAPH-#28AB0, IRGKangXi=1318.281, RSKangXi=167.10
28AB1 CJK UNIFIED IDEOGRAPH-#28AB1, IRGKangXi=1318.281, RSKangXi=167.10
28AB2 CJK UNIFIED IDEOGRAPH-#28AB2, IRGKangXi=1318.281, RSKangXi=167.10
28AB3 CJK UNIFIED IDEOGRAPH-#28AB3, IRGKangXi=1318.281, RSKangXi=167.10
28AB4 CJK UNIFIED IDEOGRAPH-#28AB4, IRGKangXi=1318.281, RSKangXi=167.10
28AB5 CJK UNIFIED IDEOGRAPH-#28AB5, IRGKangXi=1318.281, RSKangXi=167.10
28AB6 CJK UNIFIED IDEOGRAPH-#28AB6, IRGKangXi=1318.281, RSKangXi=167.10
28AB7 CJK UNIFIED IDEOGRAPH-#28AB7, IRGKangXi=1318.281, RSKangXi=167.10
28AB8 CJK UNIFIED IDEOGRAPH-#28AB8, IRGKangXi=1318.281, RSKangXi=167.10
28AB9 CJK UNIFIED IDEOGRAPH-#28AB9, IRGKangXi=1318.281, RSKangXi=167.10
28ABA CJK UNIFIED IDEOGRAPH-#28ABA, IRGKangXi=1318.281, RSKangXi=167.10
28ABB CJK UNIFIED IDEOGRAPH-#28ABB, IRGKangXi=1318.281, RSKangXi=167.10
28ABC CJK UNIFIED IDEOGRAPH-#28ABC, IRGKangXi=1318.281, RSKangXi=167.10
28ABD CJK UNIFIED IDEOGRAPH-#28ABD, IRGKangXi=1318.281, RSKangXi=167.10
28ABE CJK UNIFIED IDEOGRAPH-#28ABE, IRGKangXi=1318.281, RSKangXi=167.10
28ABF CJK UNIFIED IDEOGRAPH-#28ABF, IRGKangXi=1318.281, RSKangXi=167.10
28AC0 CJK UNIFIED IDEOGRAPH-#28AC0, IRGKangXi=1318.281, RSKangXi=167.10
28AC1 CJK UNIFIED IDEOGRAPH-#28AC1, IRGKangXi=1318.281, RSKangXi=167.10
28AC2 CJK UNIFIED IDEOGRAPH-#28AC2, IRGKangXi=1318.281, RSKangXi=167.10
28AC3 CJK UNIFIED IDEOGRAPH-#28AC3, IRGKangXi=1318.281, RSKangXi=167.10
28AC4 CJK UNIFIED IDEOGRAPH-#28AC4, IRGKangXi=1318.281, RSKangXi=167.10
28AC5 CJK UNIFIED IDEOGRAPH-#28AC5, IRGKangXi=1318.281, RSKangXi=167.10
28AC6 CJK UNIFIED IDEOGRAPH-#28AC6, IRGKangXi=1318.281, RSKangXi=167.10
28AC7 CJK UNIFIED IDEOGRAPH-#28AC7, IRGKangXi=1318.281, RSKangXi=167.10
28AC8 CJK UNIFIED IDEOGRAPH-#28AC8, IRGKangXi=1318.281, RSKangXi=167.10
28AC9 CJK UNIFIED IDEOGRAPH-#28AC9, IRGKangXi=1318.281, RSKangXi=167.10
28ACA CJK UNIFIED IDEOGRAPH-#28ACA, IRGKangXi=1318.281, RSKangXi=167.10
28ACB CJK UNIFIED IDEOGRAPH-#28ACB, IRGKangXi=1318.281, RSKangXi=167.10
28ACC CJK UNIFIED IDEOGRAPH-#28ACC, IRGKangXi=1318.281, RSKangXi=167.10
28ACD CJK UNIFIED IDEOGRAPH-#28ACD, IRGKangXi=1318.281, RSKangXi=167.10
28ACE CJK UNIFIED IDEOGRAPH-#28ACE, IRGKangXi=1318.281, RSKangXi=167.10
28ACF CJK UNIFIED IDEOGRAPH-#28ACF, IRGKangXi=1319.110, RSKangXi=167.11
28AD0 CJK UNIFIED IDEOGRAPH-#28AD0, IRGKangXi=1319.190, RSKangXi=167.11
28AD1 CJK UNIFIED IDEOGRAPH-#28AD1, IRGKangXi=1319.240, RSKangXi=167.11
28AD2 CJK UNIFIED IDEOGRAPH-#28AD2, IRGKangXi=1319.270, RSKangXi=167.11
28AD3 CJK UNIFIED IDEOGRAPH-#28AD3, IRGKangXi=1320.070, RSKangXi=167.11
28AD4 CJK UNIFIED IDEOGRAPH-#28AD4, IRGKangXi=1320.130, RSKangXi=167.11
28AD5 CJK UNIFIED IDEOGRAPH-#28AD5, IRGKangXi=1320.140, RSKangXi=167.11
28AD6 CJK UNIFIED IDEOGRAPH-#28AD6, IRGKangXi=1320.250, RSKangXi=167.11
28AD7 CJK UNIFIED IDEOGRAPH-#28AD7, IRGKangXi=1321.010, RSKangXi=167.11
28AD8 CJK UNIFIED IDEOGRAPH-#28AD8, IRGKangXi=1321.030, RSKangXi=167.11
28AD9 CJK UNIFIED IDEOGRAPH-#28AD9, IRGKangXi=1321.040, RSKangXi=167.11
28ADA CJK UNIFIED IDEOGRAPH-#28ADA, IRGKangXi=1321.050, RSKangXi=167.11
28ADB CJK UNIFIED IDEOGRAPH-#28ADB, IRGKangXi=1321.071, RSKangXi=167.11
28ADC CJK UNIFIED IDEOGRAPH-#28ADC, IRGKangXi=1321.071, RSKangXi=167.11
28ADD CJK UNIFIED IDEOGRAPH-#28ADD, IRGKangXi=1321.071, RSKangXi=167.11
28ADE CJK UNIFIED IDEOGRAPH-#28ADE, IRGKangXi=1321.071, RSKangXi=167.11
28ADF CJK UNIFIED IDEOGRAPH-#28ADF, IRGKangXi=1321.071, RSKangXi=167.11
28AE0 CJK UNIFIED IDEOGRAPH-#28AE0, IRGKangXi=1321.071, RSKangXi=167.11
28AE1 CJK UNIFIED IDEOGRAPH-#28AE1, IRGKangXi=1321.071, RSKangXi=167.11
28AE2 CJK UNIFIED IDEOGRAPH-#28AE2, IRGKangXi=1321.071, RSKangXi=167.11
28AE3 CJK UNIFIED IDEOGRAPH-#28AE3, IRGKangXi=1321.071, RSKangXi=167.11
28AE4 CJK UNIFIED IDEOGRAPH-#28AE4, IRGKangXi=1321.071, RSKangXi=167.11
28AE5 CJK UNIFIED IDEOGRAPH-#28AE5, IRGKangXi=1321.071, RSKangXi=167.11
28AE6 CJK UNIFIED IDEOGRAPH-#28AE6, IRGKangXi=1321.071, RSKangXi=167.11
28AE7 CJK UNIFIED IDEOGRAPH-#28AE7, IRGKangXi=1321.071, RSKangXi=167.11
28AE8 CJK UNIFIED IDEOGRAPH-#28AE8, IRGKangXi=1321.071, RSKangXi=167.11
28AE9 CJK UNIFIED IDEOGRAPH-#28AE9, IRGKangXi=1321.071, RSKangXi=167.11
28AEA CJK UNIFIED IDEOGRAPH-#28AEA, IRGKangXi=1321.071, RSKangXi=167.11
28AEB CJK UNIFIED IDEOGRAPH-#28AEB, IRGKangXi=1321.071, RSKangXi=167.11
28AEC CJK UNIFIED IDEOGRAPH-#28AEC, IRGKangXi=1321.071, RSKangXi=167.11
28AED CJK UNIFIED IDEOGRAPH-#28AED, IRGKangXi=1321.071, RSKangXi=167.11
28AEE CJK UNIFIED IDEOGRAPH-#28AEE, IRGKangXi=1321.071, RSKangXi=167.11
28AEF CJK UNIFIED IDEOGRAPH-#28AEF, IRGKangXi=1321.071, RSKangXi=167.11
28AF0 CJK UNIFIED IDEOGRAPH-#28AF0, IRGKangXi=1321.071, RSKangXi=167.11
28AF1 CJK UNIFIED IDEOGRAPH-#28AF1, IRGKangXi=1321.071, RSKangXi=167.11
28AF2 CJK UNIFIED IDEOGRAPH-#28AF2, IRGKangXi=1321.071, RSKangXi=167.11
28AF3 CJK UNIFIED IDEOGRAPH-#28AF3, IRGKangXi=1321.071, RSKangXi=167.11
28AF4 CJK UNIFIED IDEOGRAPH-#28AF4, IRGKangXi=1321.071, RSKangXi=167.11
28AF5 CJK UNIFIED IDEOGRAPH-#28AF5, IRGKangXi=1321.071, RSKangXi=167.11
28AF6 CJK UNIFIED IDEOGRAPH-#28AF6, IRGKangXi=1321.071, RSKangXi=167.11
28AF7 CJK UNIFIED IDEOGRAPH-#28AF7, IRGKangXi=1321.071, RSKangXi=167.11
28AF8 CJK UNIFIED IDEOGRAPH-#28AF8, IRGKangXi=1321.071, RSKangXi=167.11
28AF9 CJK UNIFIED IDEOGRAPH-#28AF9, IRGKangXi=1321.071, RSKangXi=167.11
28AFA CJK UNIFIED IDEOGRAPH-#28AFA, IRGKangXi=1321.071, RSKangXi=167.11
28AFB CJK UNIFIED IDEOGRAPH-#28AFB, IRGKangXi=1321.071, RSKangXi=167.11
28AFC CJK UNIFIED IDEOGRAPH-#28AFC, IRGKangXi=1321.071, RSKangXi=167.11
28AFD CJK UNIFIED IDEOGRAPH-#28AFD, IRGKangXi=1321.071, RSKangXi=167.11
28AFE CJK UNIFIED IDEOGRAPH-#28AFE, IRGKangXi=1321.071, RSKangXi=167.11
28AFF CJK UNIFIED IDEOGRAPH-#28AFF, IRGKangXi=1321.071, RSKangXi=167.11
28B00 CJK UNIFIED IDEOGRAPH-#28B00, IRGKangXi=1321.071, RSKangXi=167.11
28B01 CJK UNIFIED IDEOGRAPH-#28B01, IRGKangXi=1321.071, RSKangXi=167.11
28B02 CJK UNIFIED IDEOGRAPH-#28B02, IRGKangXi=1321.071, RSKangXi=167.11
28B03 CJK UNIFIED IDEOGRAPH-#28B03, IRGKangXi=1321.071, RSKangXi=167.11
28B04 CJK UNIFIED IDEOGRAPH-#28B04, IRGKangXi=1321.071, RSKangXi=167.11
28B05 CJK UNIFIED IDEOGRAPH-#28B05, IRGKangXi=1321.071, RSKangXi=167.11
28B06 CJK UNIFIED IDEOGRAPH-#28B06, IRGKangXi=1321.071, RSKangXi=167.11
28B07 CJK UNIFIED IDEOGRAPH-#28B07, IRGKangXi=1321.071, RSKangXi=167.11
28B08 CJK UNIFIED IDEOGRAPH-#28B08, IRGKangXi=1321.071, RSKangXi=167.11
28B09 CJK UNIFIED IDEOGRAPH-#28B09, IRGKangXi=1321.071, RSKangXi=167.11
28B0A CJK UNIFIED IDEOGRAPH-#28B0A, IRGKangXi=1321.071, RSKangXi=167.11
28B0B CJK UNIFIED IDEOGRAPH-#28B0B, IRGKangXi=1321.071, RSKangXi=167.11
28B0C CJK UNIFIED IDEOGRAPH-#28B0C, IRGKangXi=1321.071, RSKangXi=167.11
28B0D CJK UNIFIED IDEOGRAPH-#28B0D, IRGKangXi=1321.110, RSKangXi=167.12
28B0E CJK UNIFIED IDEOGRAPH-#28B0E, IRGKangXi=1321.150, RSKangXi=167.12
28B0F CJK UNIFIED IDEOGRAPH-#28B0F, IRGKangXi=1321.200, RSKangXi=167.12
28B10 CJK UNIFIED IDEOGRAPH-#28B10, IRGKangXi=1321.250, RSKangXi=167.12
28B11 CJK UNIFIED IDEOGRAPH-#28B11, IRGKangXi=1321.270, RSKangXi=167.12
28B12 CJK UNIFIED IDEOGRAPH-#28B12, IRGKangXi=1321.340, RSKangXi=167.12
28B13 CJK UNIFIED IDEOGRAPH-#28B13, IRGKangXi=1321.390, RSKangXi=167.12
28B14 CJK UNIFIED IDEOGRAPH-#28B14, IRGKangXi=1322.020, RSKangXi=167.12
28B15 CJK UNIFIED IDEOGRAPH-#28B15, IRGKangXi=1322.040, RSKangXi=167.13
28B16 CJK UNIFIED IDEOGRAPH-#28B16, IRGKangXi=1322.140, RSKangXi=167.12
28B17 CJK UNIFIED IDEOGRAPH-#28B17, IRGKangXi=1322.150, RSKangXi=167.12
28B18 CJK UNIFIED IDEOGRAPH-#28B18, IRGKangXi=1322.180, RSKangXi=167.12
28B19 CJK UNIFIED IDEOGRAPH-#28B19, IRGKangXi=1323.010, RSKangXi=167.12
28B1A CJK UNIFIED IDEOGRAPH-#28B1A, IRGKangXi=1323.030, RSKangXi=167.12
28B1B CJK UNIFIED IDEOGRAPH-#28B1B, IRGKangXi=1323.050, RSKangXi=167.12
28B1C CJK UNIFIED IDEOGRAPH-#28B1C, IRGKangXi=1323.070, RSKangXi=167.12
28B1D CJK UNIFIED IDEOGRAPH-#28B1D, IRGKangXi=1323.110, RSKangXi=167.12
28B1E CJK UNIFIED IDEOGRAPH-#28B1E, IRGKangXi=1323.121, RSKangXi=167.12
28B1F CJK UNIFIED IDEOGRAPH-#28B1F, IRGKangXi=1323.121, RSKangXi=167.12
28B20 CJK UNIFIED IDEOGRAPH-#28B20, IRGKangXi=1323.121, RSKangXi=167.12
28B21 CJK UNIFIED IDEOGRAPH-#28B21, IRGKangXi=1323.121, RSKangXi=167.12
28B22 CJK UNIFIED IDEOGRAPH-#28B22, IRGKangXi=1323.121, RSKangXi=167.12
28B23 CJK UNIFIED IDEOGRAPH-#28B23, IRGKangXi=1323.121, RSKangXi=167.12
28B24 CJK UNIFIED IDEOGRAPH-#28B24, IRGKangXi=1323.121, RSKangXi=167.12
28B25 CJK UNIFIED IDEOGRAPH-#28B25, IRGKangXi=1323.121, RSKangXi=167.12
28B26 CJK UNIFIED IDEOGRAPH-#28B26, IRGKangXi=1323.121, RSKangXi=167.12
28B27 CJK UNIFIED IDEOGRAPH-#28B27, IRGKangXi=1323.121, RSKangXi=167.12
28B28 CJK UNIFIED IDEOGRAPH-#28B28, IRGKangXi=1323.121, RSKangXi=167.12
28B29 CJK UNIFIED IDEOGRAPH-#28B29, IRGKangXi=1323.121, RSKangXi=167.12
28B2A CJK UNIFIED IDEOGRAPH-#28B2A, IRGKangXi=1323.121, RSKangXi=167.12
28B2B CJK UNIFIED IDEOGRAPH-#28B2B, IRGKangXi=1323.121, RSKangXi=167.12
28B2C CJK UNIFIED IDEOGRAPH-#28B2C, IRGKangXi=1323.121, RSKangXi=167.12
28B2D CJK UNIFIED IDEOGRAPH-#28B2D, IRGKangXi=1323.121, RSKangXi=167.12
28B2E CJK UNIFIED IDEOGRAPH-#28B2E, IRGKangXi=1323.121, RSKangXi=167.12
28B2F CJK UNIFIED IDEOGRAPH-#28B2F, IRGKangXi=1323.121, RSKangXi=167.12
28B30 CJK UNIFIED IDEOGRAPH-#28B30, IRGKangXi=1323.121, RSKangXi=167.12
28B31 CJK UNIFIED IDEOGRAPH-#28B31, IRGKangXi=1323.121, RSKangXi=167.12
28B32 CJK UNIFIED IDEOGRAPH-#28B32, IRGKangXi=1323.121, RSKangXi=167.12
28B33 CJK UNIFIED IDEOGRAPH-#28B33, IRGKangXi=1323.121, RSKangXi=167.12
28B34 CJK UNIFIED IDEOGRAPH-#28B34, IRGKangXi=1323.121, RSKangXi=167.12
28B35 CJK UNIFIED IDEOGRAPH-#28B35, IRGKangXi=1323.121, RSKangXi=167.12
28B36 CJK UNIFIED IDEOGRAPH-#28B36, IRGKangXi=1323.121, RSKangXi=167.12
28B37 CJK UNIFIED IDEOGRAPH-#28B37, IRGKangXi=1323.121, RSKangXi=167.12
28B38 CJK UNIFIED IDEOGRAPH-#28B38, IRGKangXi=1323.121, RSKangXi=167.12
28B39 CJK UNIFIED IDEOGRAPH-#28B39, IRGKangXi=1323.121, RSKangXi=167.12
28B3A CJK UNIFIED IDEOGRAPH-#28B3A, IRGKangXi=1323.121, RSKangXi=167.12
28B3B CJK UNIFIED IDEOGRAPH-#28B3B, IRGKangXi=1323.121, RSKangXi=167.12
28B3C CJK UNIFIED IDEOGRAPH-#28B3C, IRGKangXi=1323.121, RSKangXi=167.12
28B3D CJK UNIFIED IDEOGRAPH-#28B3D, IRGKangXi=1323.121, RSKangXi=167.12
28B3E CJK UNIFIED IDEOGRAPH-#28B3E, IRGKangXi=1323.121, RSKangXi=167.12
28B3F CJK UNIFIED IDEOGRAPH-#28B3F, IRGKangXi=1323.121, RSKangXi=167.12
28B40 CJK UNIFIED IDEOGRAPH-#28B40, IRGKangXi=1323.121, RSKangXi=167.12
28B41 CJK UNIFIED IDEOGRAPH-#28B41, IRGKangXi=1323.121, RSKangXi=167.12
28B42 CJK UNIFIED IDEOGRAPH-#28B42, IRGKangXi=1323.121, RSKangXi=167.12
28B43 CJK UNIFIED IDEOGRAPH-#28B43, IRGKangXi=1323.121, RSKangXi=167.12
28B44 CJK UNIFIED IDEOGRAPH-#28B44, IRGKangXi=1323.121, RSKangXi=167.12
28B45 CJK UNIFIED IDEOGRAPH-#28B45, IRGKangXi=1323.121, RSKangXi=167.12
28B46 CJK UNIFIED IDEOGRAPH-#28B46, IRGKangXi=1323.121, RSKangXi=167.12
28B47 CJK UNIFIED IDEOGRAPH-#28B47, IRGKangXi=1323.121, RSKangXi=167.12
28B48 CJK UNIFIED IDEOGRAPH-#28B48, IRGKangXi=1323.121, RSKangXi=167.12
28B49 CJK UNIFIED IDEOGRAPH-#28B49, IRGKangXi=1323.121, RSKangXi=167.12
28B4A CJK UNIFIED IDEOGRAPH-#28B4A, IRGKangXi=1323.121, RSKangXi=167.12
28B4B CJK UNIFIED IDEOGRAPH-#28B4B, IRGKangXi=1323.121, RSKangXi=167.12
28B4C CJK UNIFIED IDEOGRAPH-#28B4C, IRGKangXi=1323.121, RSKangXi=167.12, Def{(Cant.) bang; pan (Eng. loanwords)}
28B4D CJK UNIFIED IDEOGRAPH-#28B4D, IRGKangXi=1323.121, RSKangXi=167.12
28B4E CJK UNIFIED IDEOGRAPH-#28B4E, IRGKangXi=1323.121, RSKangXi=167.12
28B4F CJK UNIFIED IDEOGRAPH-#28B4F, IRGKangXi=1323.121, RSKangXi=167.12
28B50 CJK UNIFIED IDEOGRAPH-#28B50, IRGKangXi=1323.121, RSKangXi=167.12
28B51 CJK UNIFIED IDEOGRAPH-#28B51, IRGKangXi=1323.121, RSKangXi=167.12
28B52 CJK UNIFIED IDEOGRAPH-#28B52, IRGKangXi=1323.121, RSKangXi=167.12
28B53 CJK UNIFIED IDEOGRAPH-#28B53, IRGKangXi=1323.121, RSKangXi=167.12
28B54 CJK UNIFIED IDEOGRAPH-#28B54, IRGKangXi=1323.121, RSKangXi=167.12
28B55 CJK UNIFIED IDEOGRAPH-#28B55, IRGKangXi=1323.220, RSKangXi=167.13
28B56 CJK UNIFIED IDEOGRAPH-#28B56, IRGKangXi=1323.230, RSKangXi=167.13
28B57 CJK UNIFIED IDEOGRAPH-#28B57, IRGKangXi=1323.240, RSKangXi=167.13
28B58 CJK UNIFIED IDEOGRAPH-#28B58, IRGKangXi=1323.250, RSKangXi=167.13
28B59 CJK UNIFIED IDEOGRAPH-#28B59, IRGKangXi=1323.280, RSKangXi=167.13
28B5A CJK UNIFIED IDEOGRAPH-#28B5A, IRGKangXi=1323.300, RSKangXi=167.13
28B5B CJK UNIFIED IDEOGRAPH-#28B5B, IRGKangXi=1323.310, RSKangXi=167.13
28B5C CJK UNIFIED IDEOGRAPH-#28B5C, IRGKangXi=1323.360, RSKangXi=167.13
28B5D CJK UNIFIED IDEOGRAPH-#28B5D, IRGKangXi=1324.040, RSKangXi=167.13
28B5E CJK UNIFIED IDEOGRAPH-#28B5E, IRGKangXi=1324.100, RSKangXi=167.13
28B5F CJK UNIFIED IDEOGRAPH-#28B5F, IRGKangXi=1324.160, RSKangXi=167.13
28B60 CJK UNIFIED IDEOGRAPH-#28B60, IRGKangXi=1324.161, RSKangXi=167.13
28B61 CJK UNIFIED IDEOGRAPH-#28B61, IRGKangXi=1324.161, RSKangXi=167.13
28B62 CJK UNIFIED IDEOGRAPH-#28B62, IRGKangXi=1324.161, RSKangXi=167.13
28B63 CJK UNIFIED IDEOGRAPH-#28B63, IRGKangXi=1324.161, RSKangXi=167.13
28B64 CJK UNIFIED IDEOGRAPH-#28B64, IRGKangXi=1324.161, RSKangXi=167.13
28B65 CJK UNIFIED IDEOGRAPH-#28B65, IRGKangXi=1324.161, RSKangXi=167.13
28B66 CJK UNIFIED IDEOGRAPH-#28B66, IRGKangXi=1324.161, RSKangXi=167.13
28B67 CJK UNIFIED IDEOGRAPH-#28B67, IRGKangXi=1324.161, RSKangXi=167.13
28B68 CJK UNIFIED IDEOGRAPH-#28B68, IRGKangXi=1324.161, RSKangXi=167.13
28B69 CJK UNIFIED IDEOGRAPH-#28B69, IRGKangXi=1324.161, RSKangXi=167.13
28B6A CJK UNIFIED IDEOGRAPH-#28B6A, IRGKangXi=1324.161, RSKangXi=167.13
28B6B CJK UNIFIED IDEOGRAPH-#28B6B, IRGKangXi=1324.161, RSKangXi=167.13
28B6C CJK UNIFIED IDEOGRAPH-#28B6C, IRGKangXi=1324.161, RSKangXi=167.13
28B6D CJK UNIFIED IDEOGRAPH-#28B6D, IRGKangXi=1324.161, RSKangXi=167.13
28B6E CJK UNIFIED IDEOGRAPH-#28B6E, IRGKangXi=1324.161, RSKangXi=167.13
28B6F CJK UNIFIED IDEOGRAPH-#28B6F, IRGKangXi=1324.161, RSKangXi=167.13
28B70 CJK UNIFIED IDEOGRAPH-#28B70, IRGKangXi=1324.161, RSKangXi=167.13
28B71 CJK UNIFIED IDEOGRAPH-#28B71, IRGKangXi=1324.161, RSKangXi=167.13
28B72 CJK UNIFIED IDEOGRAPH-#28B72, IRGKangXi=1324.161, RSKangXi=167.13
28B73 CJK UNIFIED IDEOGRAPH-#28B73, IRGKangXi=1324.161, RSKangXi=167.13
28B74 CJK UNIFIED IDEOGRAPH-#28B74, IRGKangXi=1324.161, RSKangXi=167.13
28B75 CJK UNIFIED IDEOGRAPH-#28B75, IRGKangXi=1324.161, RSKangXi=167.13
28B76 CJK UNIFIED IDEOGRAPH-#28B76, IRGKangXi=1324.161, RSKangXi=167.13
28B77 CJK UNIFIED IDEOGRAPH-#28B77, IRGKangXi=1324.161, RSKangXi=167.13
28B78 CJK UNIFIED IDEOGRAPH-#28B78, IRGKangXi=1324.161, RSKangXi=167.13
28B79 CJK UNIFIED IDEOGRAPH-#28B79, IRGKangXi=1324.161, RSKangXi=167.13
28B7A CJK UNIFIED IDEOGRAPH-#28B7A, IRGKangXi=1324.161, RSKangXi=167.13
28B7B CJK UNIFIED IDEOGRAPH-#28B7B, IRGKangXi=1324.161, RSKangXi=167.13
28B7C CJK UNIFIED IDEOGRAPH-#28B7C, IRGKangXi=1324.161, RSKangXi=167.13
28B7D CJK UNIFIED IDEOGRAPH-#28B7D, IRGKangXi=1324.161, RSKangXi=167.13
28B7E CJK UNIFIED IDEOGRAPH-#28B7E, IRGKangXi=1324.161, RSKangXi=167.13
28B7F CJK UNIFIED IDEOGRAPH-#28B7F, IRGKangXi=1324.161, RSKangXi=167.13
28B80 CJK UNIFIED IDEOGRAPH-#28B80, IRGKangXi=1324.161, RSKangXi=167.13
28B81 CJK UNIFIED IDEOGRAPH-#28B81, IRGKangXi=1324.161, RSKangXi=167.13
28B82 CJK UNIFIED IDEOGRAPH-#28B82, IRGKangXi=1324.161, RSKangXi=167.13
28B83 CJK UNIFIED IDEOGRAPH-#28B83, IRGKangXi=1324.161, RSKangXi=167.13
28B84 CJK UNIFIED IDEOGRAPH-#28B84, IRGKangXi=1324.161, RSKangXi=167.13
28B85 CJK UNIFIED IDEOGRAPH-#28B85, IRGKangXi=1324.161, RSKangXi=167.13
28B86 CJK UNIFIED IDEOGRAPH-#28B86, IRGKangXi=1324.161, RSKangXi=167.13
28B87 CJK UNIFIED IDEOGRAPH-#28B87, IRGKangXi=1324.161, RSKangXi=167.13
28B88 CJK UNIFIED IDEOGRAPH-#28B88, IRGKangXi=1324.161, RSKangXi=167.13
28B89 CJK UNIFIED IDEOGRAPH-#28B89, IRGKangXi=1324.161, RSKangXi=167.13
28B8A CJK UNIFIED IDEOGRAPH-#28B8A, IRGKangXi=1324.161, RSKangXi=167.13
28B8B CJK UNIFIED IDEOGRAPH-#28B8B, IRGKangXi=1324.161, RSKangXi=167.13
28B8C CJK UNIFIED IDEOGRAPH-#28B8C, IRGKangXi=1324.161, RSKangXi=167.13
28B8D CJK UNIFIED IDEOGRAPH-#28B8D, IRGKangXi=1324.161, RSKangXi=167.13
28B8E CJK UNIFIED IDEOGRAPH-#28B8E, IRGKangXi=1324.161, RSKangXi=167.13
28B8F CJK UNIFIED IDEOGRAPH-#28B8F, IRGKangXi=1324.161, RSKangXi=167.13
28B90 CJK UNIFIED IDEOGRAPH-#28B90, IRGKangXi=1324.161, RSKangXi=167.13
28B91 CJK UNIFIED IDEOGRAPH-#28B91, IRGKangXi=1324.161, RSKangXi=167.13
28B92 CJK UNIFIED IDEOGRAPH-#28B92, IRGKangXi=1324.170, RSKangXi=167.14
28B93 CJK UNIFIED IDEOGRAPH-#28B93, IRGKangXi=1324.220, RSKangXi=167.14
28B94 CJK UNIFIED IDEOGRAPH-#28B94, IRGKangXi=1324.260, RSKangXi=167.14
28B95 CJK UNIFIED IDEOGRAPH-#28B95, IRGKangXi=1325.120, RSKangXi=167.14
28B96 CJK UNIFIED IDEOGRAPH-#28B96, IRGKangXi=1325.160, RSKangXi=167.14
28B97 CJK UNIFIED IDEOGRAPH-#28B97, IRGKangXi=1325.170, RSKangXi=167.14
28B98 CJK UNIFIED IDEOGRAPH-#28B98, IRGKangXi=1325.181, RSKangXi=167.14, Def{a fine grade of steel}
28B99 CJK UNIFIED IDEOGRAPH-#28B99, IRGKangXi=1325.181, RSKangXi=167.14
28B9A CJK UNIFIED IDEOGRAPH-#28B9A, IRGKangXi=1325.181, RSKangXi=167.14
28B9B CJK UNIFIED IDEOGRAPH-#28B9B, IRGKangXi=1325.181, RSKangXi=167.14
28B9C CJK UNIFIED IDEOGRAPH-#28B9C, IRGKangXi=1325.181, RSKangXi=167.14
28B9D CJK UNIFIED IDEOGRAPH-#28B9D, IRGKangXi=1325.181, RSKangXi=167.14
28B9E CJK UNIFIED IDEOGRAPH-#28B9E, IRGKangXi=1325.181, RSKangXi=167.14
28B9F CJK UNIFIED IDEOGRAPH-#28B9F, IRGKangXi=1325.181, RSKangXi=167.14
28BA0 CJK UNIFIED IDEOGRAPH-#28BA0, IRGKangXi=1325.181, RSKangXi=167.14
28BA1 CJK UNIFIED IDEOGRAPH-#28BA1, IRGKangXi=1325.181, RSKangXi=167.14
28BA2 CJK UNIFIED IDEOGRAPH-#28BA2, IRGKangXi=1325.181, RSKangXi=167.14
28BA3 CJK UNIFIED IDEOGRAPH-#28BA3, IRGKangXi=1325.181, RSKangXi=167.14
28BA4 CJK UNIFIED IDEOGRAPH-#28BA4, IRGKangXi=1325.181, RSKangXi=167.14
28BA5 CJK UNIFIED IDEOGRAPH-#28BA5, IRGKangXi=1325.181, RSKangXi=167.14
28BA6 CJK UNIFIED IDEOGRAPH-#28BA6, IRGKangXi=1325.181, RSKangXi=167.14
28BA7 CJK UNIFIED IDEOGRAPH-#28BA7, IRGKangXi=1325.181, RSKangXi=167.14
28BA8 CJK UNIFIED IDEOGRAPH-#28BA8, IRGKangXi=1325.181, RSKangXi=167.14
28BA9 CJK UNIFIED IDEOGRAPH-#28BA9, IRGKangXi=1325.181, RSKangXi=167.14
28BAA CJK UNIFIED IDEOGRAPH-#28BAA, IRGKangXi=1325.181, RSKangXi=167.14
28BAB CJK UNIFIED IDEOGRAPH-#28BAB, IRGKangXi=1325.181, RSKangXi=167.14
28BAC CJK UNIFIED IDEOGRAPH-#28BAC, IRGKangXi=1325.181, RSKangXi=167.14
28BAD CJK UNIFIED IDEOGRAPH-#28BAD, IRGKangXi=1325.181, RSKangXi=167.14
28BAE CJK UNIFIED IDEOGRAPH-#28BAE, IRGKangXi=1325.181, RSKangXi=167.14
28BAF CJK UNIFIED IDEOGRAPH-#28BAF, IRGKangXi=1325.181, RSKangXi=167.14
28BB0 CJK UNIFIED IDEOGRAPH-#28BB0, IRGKangXi=1325.181, RSKangXi=167.14
28BB1 CJK UNIFIED IDEOGRAPH-#28BB1, IRGKangXi=1325.181, RSKangXi=167.14
28BB2 CJK UNIFIED IDEOGRAPH-#28BB2, IRGKangXi=1325.181, RSKangXi=167.14
28BB3 CJK UNIFIED IDEOGRAPH-#28BB3, IRGKangXi=1325.181, RSKangXi=167.14
28BB4 CJK UNIFIED IDEOGRAPH-#28BB4, IRGKangXi=1325.181, RSKangXi=167.14
28BB5 CJK UNIFIED IDEOGRAPH-#28BB5, IRGKangXi=1325.181, RSKangXi=167.14
28BB6 CJK UNIFIED IDEOGRAPH-#28BB6, IRGKangXi=1325.181, RSKangXi=167.14
28BB7 CJK UNIFIED IDEOGRAPH-#28BB7, IRGKangXi=1325.181, RSKangXi=167.14
28BB8 CJK UNIFIED IDEOGRAPH-#28BB8, IRGKangXi=1325.220, RSKangXi=167.15
28BB9 CJK UNIFIED IDEOGRAPH-#28BB9, IRGKangXi=1325.250, RSKangXi=167.15
28BBA CJK UNIFIED IDEOGRAPH-#28BBA, IRGKangXi=1325.260, RSKangXi=167.15
28BBB CJK UNIFIED IDEOGRAPH-#28BBB, IRGKangXi=1325.300, RSKangXi=167.15
28BBC CJK UNIFIED IDEOGRAPH-#28BBC, IRGKangXi=1326.020, RSKangXi=167.15
28BBD CJK UNIFIED IDEOGRAPH-#28BBD, IRGKangXi=1326.100, RSKangXi=167.15
28BBE CJK UNIFIED IDEOGRAPH-#28BBE, IRGKangXi=1326.110, RSKangXi=167.15
28BBF CJK UNIFIED IDEOGRAPH-#28BBF, IRGKangXi=1326.120, RSKangXi=167.15
28BC0 CJK UNIFIED IDEOGRAPH-#28BC0, IRGKangXi=1326.121, RSKangXi=167.15
28BC1 CJK UNIFIED IDEOGRAPH-#28BC1, IRGKangXi=1326.121, RSKangXi=167.15
28BC2 CJK UNIFIED IDEOGRAPH-#28BC2, IRGKangXi=1326.121, RSKangXi=167.15
28BC3 CJK UNIFIED IDEOGRAPH-#28BC3, IRGKangXi=1326.121, RSKangXi=167.15
28BC4 CJK UNIFIED IDEOGRAPH-#28BC4, IRGKangXi=1326.121, RSKangXi=167.15
28BC5 CJK UNIFIED IDEOGRAPH-#28BC5, IRGKangXi=1326.121, RSKangXi=167.15
28BC6 CJK UNIFIED IDEOGRAPH-#28BC6, IRGKangXi=1326.121, RSKangXi=167.15
28BC7 CJK UNIFIED IDEOGRAPH-#28BC7, IRGKangXi=1326.121, RSKangXi=167.15
28BC8 CJK UNIFIED IDEOGRAPH-#28BC8, IRGKangXi=1326.121, RSKangXi=167.15
28BC9 CJK UNIFIED IDEOGRAPH-#28BC9, IRGKangXi=1326.121, RSKangXi=167.15
28BCA CJK UNIFIED IDEOGRAPH-#28BCA, IRGKangXi=1326.121, RSKangXi=167.15
28BCB CJK UNIFIED IDEOGRAPH-#28BCB, IRGKangXi=1326.121, RSKangXi=167.15
28BCC CJK UNIFIED IDEOGRAPH-#28BCC, IRGKangXi=1326.121, RSKangXi=167.15
28BCD CJK UNIFIED IDEOGRAPH-#28BCD, IRGKangXi=1326.121, RSKangXi=167.15
28BCE CJK UNIFIED IDEOGRAPH-#28BCE, IRGKangXi=1326.121, RSKangXi=167.15
28BCF CJK UNIFIED IDEOGRAPH-#28BCF, IRGKangXi=1326.121, RSKangXi=167.15
28BD0 CJK UNIFIED IDEOGRAPH-#28BD0, IRGKangXi=1326.121, RSKangXi=167.15
28BD1 CJK UNIFIED IDEOGRAPH-#28BD1, IRGKangXi=1326.121, RSKangXi=167.15
28BD2 CJK UNIFIED IDEOGRAPH-#28BD2, IRGKangXi=1326.121, RSKangXi=167.15
28BD3 CJK UNIFIED IDEOGRAPH-#28BD3, IRGKangXi=1326.121, RSKangXi=167.15
28BD4 CJK UNIFIED IDEOGRAPH-#28BD4, IRGKangXi=1326.121, RSKangXi=167.15
28BD5 CJK UNIFIED IDEOGRAPH-#28BD5, IRGKangXi=1326.121, RSKangXi=167.15
28BD6 CJK UNIFIED IDEOGRAPH-#28BD6, IRGKangXi=1326.121, RSKangXi=167.15
28BD7 CJK UNIFIED IDEOGRAPH-#28BD7, IRGKangXi=1326.121, RSKangXi=167.15
28BD8 CJK UNIFIED IDEOGRAPH-#28BD8, IRGKangXi=1326.121, RSKangXi=167.15
28BD9 CJK UNIFIED IDEOGRAPH-#28BD9, IRGKangXi=1326.121, RSKangXi=167.15
28BDA CJK UNIFIED IDEOGRAPH-#28BDA, IRGKangXi=1326.121, RSKangXi=167.15
28BDB CJK UNIFIED IDEOGRAPH-#28BDB, IRGKangXi=1326.121, RSKangXi=167.15
28BDC CJK UNIFIED IDEOGRAPH-#28BDC, IRGKangXi=1326.121, RSKangXi=167.15
28BDD CJK UNIFIED IDEOGRAPH-#28BDD, IRGKangXi=1326.140, RSKangXi=167.16
28BDE CJK UNIFIED IDEOGRAPH-#28BDE, IRGKangXi=1326.170, RSKangXi=167.16
28BDF CJK UNIFIED IDEOGRAPH-#28BDF, IRGKangXi=1326.180, RSKangXi=167.16
28BE0 CJK UNIFIED IDEOGRAPH-#28BE0, IRGKangXi=1326.210, RSKangXi=167.16
28BE1 CJK UNIFIED IDEOGRAPH-#28BE1, IRGKangXi=1326.230, RSKangXi=167.16
28BE2 CJK UNIFIED IDEOGRAPH-#28BE2, IRGKangXi=1326.240, RSKangXi=167.16
28BE3 CJK UNIFIED IDEOGRAPH-#28BE3, IRGKangXi=1326.250, RSKangXi=167.16
28BE4 CJK UNIFIED IDEOGRAPH-#28BE4, IRGKangXi=1326.261, RSKangXi=167.16
28BE5 CJK UNIFIED IDEOGRAPH-#28BE5, IRGKangXi=1326.261, RSKangXi=167.16
28BE6 CJK UNIFIED IDEOGRAPH-#28BE6, IRGKangXi=1326.261, RSKangXi=167.16
28BE7 CJK UNIFIED IDEOGRAPH-#28BE7, IRGKangXi=1326.261, RSKangXi=167.16
28BE8 CJK UNIFIED IDEOGRAPH-#28BE8, IRGKangXi=1326.261, RSKangXi=167.16
28BE9 CJK UNIFIED IDEOGRAPH-#28BE9, IRGKangXi=1326.261, RSKangXi=167.16
28BEA CJK UNIFIED IDEOGRAPH-#28BEA, IRGKangXi=1326.261, RSKangXi=167.16
28BEB CJK UNIFIED IDEOGRAPH-#28BEB, IRGKangXi=1326.261, RSKangXi=167.16
28BEC CJK UNIFIED IDEOGRAPH-#28BEC, IRGKangXi=1326.261, RSKangXi=167.16
28BED CJK UNIFIED IDEOGRAPH-#28BED, IRGKangXi=1326.261, RSKangXi=167.16
28BEE CJK UNIFIED IDEOGRAPH-#28BEE, IRGKangXi=1326.261, RSKangXi=167.16
28BEF CJK UNIFIED IDEOGRAPH-#28BEF, IRGKangXi=1326.261, RSKangXi=167.16
28BF0 CJK UNIFIED IDEOGRAPH-#28BF0, IRGKangXi=1326.261, RSKangXi=167.16
28BF1 CJK UNIFIED IDEOGRAPH-#28BF1, IRGKangXi=1326.261, RSKangXi=167.16
28BF2 CJK UNIFIED IDEOGRAPH-#28BF2, IRGKangXi=1326.261, RSKangXi=167.16
28BF3 CJK UNIFIED IDEOGRAPH-#28BF3, IRGKangXi=1326.261, RSKangXi=167.16
28BF4 CJK UNIFIED IDEOGRAPH-#28BF4, IRGKangXi=1326.261, RSKangXi=167.16
28BF5 CJK UNIFIED IDEOGRAPH-#28BF5, IRGKangXi=1326.261, RSKangXi=167.16
28BF6 CJK UNIFIED IDEOGRAPH-#28BF6, IRGKangXi=1326.261, RSKangXi=167.16
28BF7 CJK UNIFIED IDEOGRAPH-#28BF7, IRGKangXi=1326.261, RSKangXi=167.16
28BF8 CJK UNIFIED IDEOGRAPH-#28BF8, IRGKangXi=1326.261, RSKangXi=167.16
28BF9 CJK UNIFIED IDEOGRAPH-#28BF9, IRGKangXi=1326.261, RSKangXi=167.16
28BFA CJK UNIFIED IDEOGRAPH-#28BFA, IRGKangXi=1326.280, RSKangXi=167.17
28BFB CJK UNIFIED IDEOGRAPH-#28BFB, IRGKangXi=1327.040, RSKangXi=167.17
28BFC CJK UNIFIED IDEOGRAPH-#28BFC, IRGKangXi=1327.050, RSKangXi=167.17
28BFD CJK UNIFIED IDEOGRAPH-#28BFD, IRGKangXi=1327.051, RSKangXi=167.17
28BFE CJK UNIFIED IDEOGRAPH-#28BFE, IRGKangXi=1327.051, RSKangXi=167.17
28BFF CJK UNIFIED IDEOGRAPH-#28BFF, IRGKangXi=1327.051, RSKangXi=167.17
28C00 CJK UNIFIED IDEOGRAPH-#28C00, IRGKangXi=1327.051, RSKangXi=167.17
28C01 CJK UNIFIED IDEOGRAPH-#28C01, IRGKangXi=1327.051, RSKangXi=167.17
28C02 CJK UNIFIED IDEOGRAPH-#28C02, IRGKangXi=1327.051, RSKangXi=167.17
28C03 CJK UNIFIED IDEOGRAPH-#28C03, IRGKangXi=1327.051, RSKangXi=167.17
28C04 CJK UNIFIED IDEOGRAPH-#28C04, IRGKangXi=1327.051, RSKangXi=167.17
28C05 CJK UNIFIED IDEOGRAPH-#28C05, IRGKangXi=1327.051, RSKangXi=167.17
28C06 CJK UNIFIED IDEOGRAPH-#28C06, IRGKangXi=1327.051, RSKangXi=167.17
28C07 CJK UNIFIED IDEOGRAPH-#28C07, IRGKangXi=1327.051, RSKangXi=167.17
28C08 CJK UNIFIED IDEOGRAPH-#28C08, IRGKangXi=1327.051, RSKangXi=167.17
28C09 CJK UNIFIED IDEOGRAPH-#28C09, IRGKangXi=1327.060, RSKangXi=167.18
28C0A CJK UNIFIED IDEOGRAPH-#28C0A, IRGKangXi=1327.080, RSKangXi=167.18
28C0B CJK UNIFIED IDEOGRAPH-#28C0B, IRGKangXi=1327.090, RSKangXi=167.18
28C0C CJK UNIFIED IDEOGRAPH-#28C0C, IRGKangXi=1327.110, RSKangXi=167.18
28C0D CJK UNIFIED IDEOGRAPH-#28C0D, IRGKangXi=1327.120, RSKangXi=167.18
28C0E CJK UNIFIED IDEOGRAPH-#28C0E, IRGKangXi=1327.140, RSKangXi=167.18
28C0F CJK UNIFIED IDEOGRAPH-#28C0F, IRGKangXi=1327.170, RSKangXi=167.18
28C10 CJK UNIFIED IDEOGRAPH-#28C10, IRGKangXi=1327.200, RSKangXi=167.18
28C11 CJK UNIFIED IDEOGRAPH-#28C11, IRGKangXi=1327.210, RSKangXi=167.18
28C12 CJK UNIFIED IDEOGRAPH-#28C12, IRGKangXi=1327.220, RSKangXi=167.18
28C13 CJK UNIFIED IDEOGRAPH-#28C13, IRGKangXi=1327.230, RSKangXi=167.18
28C14 CJK UNIFIED IDEOGRAPH-#28C14, IRGKangXi=1327.231, RSKangXi=167.18
28C15 CJK UNIFIED IDEOGRAPH-#28C15, IRGKangXi=1327.231, RSKangXi=167.18
28C16 CJK UNIFIED IDEOGRAPH-#28C16, IRGKangXi=1327.231, RSKangXi=167.18
28C17 CJK UNIFIED IDEOGRAPH-#28C17, IRGKangXi=1327.231, RSKangXi=167.18
28C18 CJK UNIFIED IDEOGRAPH-#28C18, IRGKangXi=1327.231, RSKangXi=167.18
28C19 CJK UNIFIED IDEOGRAPH-#28C19, IRGKangXi=1327.231, RSKangXi=167.18
28C1A CJK UNIFIED IDEOGRAPH-#28C1A, IRGKangXi=1327.231, RSKangXi=167.18
28C1B CJK UNIFIED IDEOGRAPH-#28C1B, IRGKangXi=1327.231, RSKangXi=167.18
28C1C CJK UNIFIED IDEOGRAPH-#28C1C, IRGKangXi=1327.231, RSKangXi=167.18
28C1D CJK UNIFIED IDEOGRAPH-#28C1D, IRGKangXi=1327.231, RSKangXi=167.18
28C1E CJK UNIFIED IDEOGRAPH-#28C1E, IRGKangXi=1327.240, RSKangXi=167.19
28C1F CJK UNIFIED IDEOGRAPH-#28C1F, IRGKangXi=1328.010, RSKangXi=167.19
28C20 CJK UNIFIED IDEOGRAPH-#28C20, IRGKangXi=1328.020, RSKangXi=167.19
28C21 CJK UNIFIED IDEOGRAPH-#28C21, IRGKangXi=1328.021, RSKangXi=167.19
28C22 CJK UNIFIED IDEOGRAPH-#28C22, IRGKangXi=1328.021, RSKangXi=167.19
28C23 CJK UNIFIED IDEOGRAPH-#28C23, IRGKangXi=1328.021, RSKangXi=167.19
28C24 CJK UNIFIED IDEOGRAPH-#28C24, IRGKangXi=1328.021, RSKangXi=167.19
28C25 CJK UNIFIED IDEOGRAPH-#28C25, IRGKangXi=1328.021, RSKangXi=167.19
28C26 CJK UNIFIED IDEOGRAPH-#28C26, IRGKangXi=1328.021, RSKangXi=167.19
28C27 CJK UNIFIED IDEOGRAPH-#28C27, IRGKangXi=1328.021, RSKangXi=167.19
28C28 CJK UNIFIED IDEOGRAPH-#28C28, IRGKangXi=1328.021, RSKangXi=167.19
28C29 CJK UNIFIED IDEOGRAPH-#28C29, IRGKangXi=1328.030, RSKangXi=167.20
28C2A CJK UNIFIED IDEOGRAPH-#28C2A, IRGKangXi=1328.051, RSKangXi=167.20
28C2B CJK UNIFIED IDEOGRAPH-#28C2B, IRGKangXi=1328.051, RSKangXi=167.20
28C2C CJK UNIFIED IDEOGRAPH-#28C2C, IRGKangXi=1328.051, RSKangXi=167.20
28C2D CJK UNIFIED IDEOGRAPH-#28C2D, IRGKangXi=1328.051, RSKangXi=167.20
28C2E CJK UNIFIED IDEOGRAPH-#28C2E, IRGKangXi=1328.051, RSKangXi=167.20
28C2F CJK UNIFIED IDEOGRAPH-#28C2F, IRGKangXi=1328.051, RSKangXi=167.20
28C30 CJK UNIFIED IDEOGRAPH-#28C30, IRGKangXi=1328.051, RSKangXi=167.20
28C31 CJK UNIFIED IDEOGRAPH-#28C31, IRGKangXi=1328.051, RSKangXi=167.17
28C32 CJK UNIFIED IDEOGRAPH-#28C32, IRGKangXi=1328.061, RSKangXi=167.21
28C33 CJK UNIFIED IDEOGRAPH-#28C33, IRGKangXi=1328.061, RSKangXi=167.21
28C34 CJK UNIFIED IDEOGRAPH-#28C34, IRGKangXi=1328.061, RSKangXi=167.21
28C35 CJK UNIFIED IDEOGRAPH-#28C35, IRGKangXi=1328.061, RSKangXi=167.21
28C36 CJK UNIFIED IDEOGRAPH-#28C36, IRGKangXi=1328.061, RSKangXi=167.21
28C37 CJK UNIFIED IDEOGRAPH-#28C37, IRGKangXi=1328.061, RSKangXi=167.22
28C38 CJK UNIFIED IDEOGRAPH-#28C38, IRGKangXi=1328.061, RSKangXi=167.22
28C39 CJK UNIFIED IDEOGRAPH-#28C39, IRGKangXi=1328.061, RSKangXi=167.22
28C3A CJK UNIFIED IDEOGRAPH-#28C3A, IRGKangXi=1328.061, RSKangXi=167.23
28C3B CJK UNIFIED IDEOGRAPH-#28C3B, IRGKangXi=1328.061, RSKangXi=167.24
28C3C CJK UNIFIED IDEOGRAPH-#28C3C, IRGKangXi=1328.061, RSKangXi=167.27
28C3D CJK UNIFIED IDEOGRAPH-#28C3D, IRGKangXi=1328.061, RSKangXi=167.30
28C3E CJK UNIFIED IDEOGRAPH-#28C3E, IRGKangXi=1328.061, RSKangXi=167.3
28C3F CJK UNIFIED IDEOGRAPH-#28C3F, IRGKangXi=1328.061, RSKangXi=167.3
28C40 CJK UNIFIED IDEOGRAPH-#28C40, IRGKangXi=1328.061, RSKangXi=167.4
28C41 CJK UNIFIED IDEOGRAPH-#28C41, IRGKangXi=1328.061, RSKangXi=167.4
28C42 CJK UNIFIED IDEOGRAPH-#28C42, IRGKangXi=1328.061, RSKangXi=167.4
28C43 CJK UNIFIED IDEOGRAPH-#28C43, IRGKangXi=1328.061, RSKangXi=167.5
28C44 CJK UNIFIED IDEOGRAPH-#28C44, IRGKangXi=1328.061, RSKangXi=167.5
28C45 CJK UNIFIED IDEOGRAPH-#28C45, IRGKangXi=1328.061, RSKangXi=167.5
28C46 CJK UNIFIED IDEOGRAPH-#28C46, IRGKangXi=1328.061, RSKangXi=167.5
28C47 CJK UNIFIED IDEOGRAPH-#28C47, IRGKangXi=1328.061, RSKangXi=167.7
28C48 CJK UNIFIED IDEOGRAPH-#28C48, IRGKangXi=1328.061, RSKangXi=167.7
28C49 CJK UNIFIED IDEOGRAPH-#28C49, IRGKangXi=1328.061, RSKangXi=167.8
28C4A CJK UNIFIED IDEOGRAPH-#28C4A, IRGKangXi=1328.061, RSKangXi=167.8
28C4B CJK UNIFIED IDEOGRAPH-#28C4B, IRGKangXi=1328.061, RSKangXi=167.8
28C4C CJK UNIFIED IDEOGRAPH-#28C4C, IRGKangXi=1328.061, RSKangXi=167.8
28C4D CJK UNIFIED IDEOGRAPH-#28C4D, IRGKangXi=1328.061, RSKangXi=167.10
28C4E CJK UNIFIED IDEOGRAPH-#28C4E, IRGKangXi=1328.061, RSKangXi=167.9
28C4F CJK UNIFIED IDEOGRAPH-#28C4F, IRGKangXi=1328.061, RSKangXi=167.10, Def{technetium}
28C50 CJK UNIFIED IDEOGRAPH-#28C50, IRGKangXi=1328.061, RSKangXi=167.11
28C51 CJK UNIFIED IDEOGRAPH-#28C51, IRGKangXi=1328.061, RSKangXi=167.12
28C52 CJK UNIFIED IDEOGRAPH-#28C52, IRGKangXi=1328.061, RSKangXi=167.11
28C53 CJK UNIFIED IDEOGRAPH-#28C53, IRGKangXi=1328.061, RSKangXi=167.12
28C54 CJK UNIFIED IDEOGRAPH-#28C54, IRGKangXi=1328.061, RSKangXi=167.12
28C55 CJK UNIFIED IDEOGRAPH-#28C55, IRGKangXi=1328.061, RSKangXi=167.13
28C56 CJK UNIFIED IDEOGRAPH-#28C56, IRGKangXi=1328.061, RSKangXi=167.13
28C57 CJK UNIFIED IDEOGRAPH-#28C57, IRGKangXi=1328.170, RSKangXi=168.0
28C58 CJK UNIFIED IDEOGRAPH-#28C58, IRGKangXi=1328.171, RSKangXi=168.0
28C59 CJK UNIFIED IDEOGRAPH-#28C59, IRGKangXi=1328.180, RSKangXi=168.2
28C5A CJK UNIFIED IDEOGRAPH-#28C5A, IRGKangXi=1329.020, RSKangXi=168.4
28C5B CJK UNIFIED IDEOGRAPH-#28C5B, IRGKangXi=1329.030, RSKangXi=168.4
28C5C CJK UNIFIED IDEOGRAPH-#28C5C, IRGKangXi=1329.040, RSKangXi=168.4
28C5D CJK UNIFIED IDEOGRAPH-#28C5D, IRGKangXi=1329.050, RSKangXi=168.4
28C5E CJK UNIFIED IDEOGRAPH-#28C5E, IRGKangXi=1329.070, RSKangXi=168.4
28C5F CJK UNIFIED IDEOGRAPH-#28C5F, IRGKangXi=1329.071, RSKangXi=168.4
28C60 CJK UNIFIED IDEOGRAPH-#28C60, IRGKangXi=1329.071, RSKangXi=168.4
28C61 CJK UNIFIED IDEOGRAPH-#28C61, IRGKangXi=1329.071, RSKangXi=168.4
28C62 CJK UNIFIED IDEOGRAPH-#28C62, IRGKangXi=1329.071, RSKangXi=168.4
28C63 CJK UNIFIED IDEOGRAPH-#28C63, IRGKangXi=1329.071, RSKangXi=168.4
28C64 CJK UNIFIED IDEOGRAPH-#28C64, IRGKangXi=1329.071, RSKangXi=168.4
28C65 CJK UNIFIED IDEOGRAPH-#28C65, IRGKangXi=1329.071, RSKangXi=168.4
28C66 CJK UNIFIED IDEOGRAPH-#28C66, IRGKangXi=1329.080, RSKangXi=168.5
28C67 CJK UNIFIED IDEOGRAPH-#28C67, IRGKangXi=1329.090, RSKangXi=168.5
28C68 CJK UNIFIED IDEOGRAPH-#28C68, IRGKangXi=1329.100, RSKangXi=168.5
28C69 CJK UNIFIED IDEOGRAPH-#28C69, IRGKangXi=1329.130, RSKangXi=168.5
28C6A CJK UNIFIED IDEOGRAPH-#28C6A, IRGKangXi=1329.131, RSKangXi=168.5
28C6B CJK UNIFIED IDEOGRAPH-#28C6B, IRGKangXi=1329.131, RSKangXi=168.5
28C6C CJK UNIFIED IDEOGRAPH-#28C6C, IRGKangXi=1329.131, RSKangXi=168.5
28C6D CJK UNIFIED IDEOGRAPH-#28C6D, IRGKangXi=1329.131, RSKangXi=168.5
28C6E CJK UNIFIED IDEOGRAPH-#28C6E, IRGKangXi=1329.131, RSKangXi=168.5
28C6F CJK UNIFIED IDEOGRAPH-#28C6F, IRGKangXi=1329.131, RSKangXi=168.5
28C70 CJK UNIFIED IDEOGRAPH-#28C70, IRGKangXi=1329.131, RSKangXi=168.5
28C71 CJK UNIFIED IDEOGRAPH-#28C71, IRGKangXi=1329.131, RSKangXi=168.5
28C72 CJK UNIFIED IDEOGRAPH-#28C72, IRGKangXi=1329.131, RSKangXi=168.6
28C73 CJK UNIFIED IDEOGRAPH-#28C73, IRGKangXi=1329.140, RSKangXi=168.6
28C74 CJK UNIFIED IDEOGRAPH-#28C74, IRGKangXi=1329.150, RSKangXi=168.6
28C75 CJK UNIFIED IDEOGRAPH-#28C75, IRGKangXi=1329.170, RSKangXi=168.6
28C76 CJK UNIFIED IDEOGRAPH-#28C76, IRGKangXi=1329.180, RSKangXi=168.6
28C77 CJK UNIFIED IDEOGRAPH-#28C77, IRGKangXi=1329.190, RSKangXi=168.6
28C78 CJK UNIFIED IDEOGRAPH-#28C78, IRGKangXi=1329.191, RSKangXi=168.6
28C79 CJK UNIFIED IDEOGRAPH-#28C79, IRGKangXi=1329.191, RSKangXi=168.6
28C7A CJK UNIFIED IDEOGRAPH-#28C7A, IRGKangXi=1329.191, RSKangXi=168.6
28C7B CJK UNIFIED IDEOGRAPH-#28C7B, IRGKangXi=1329.191, RSKangXi=168.6
28C7C CJK UNIFIED IDEOGRAPH-#28C7C, IRGKangXi=1329.191, RSKangXi=168.6
28C7D CJK UNIFIED IDEOGRAPH-#28C7D, IRGKangXi=1329.191, RSKangXi=168.6
28C7E CJK UNIFIED IDEOGRAPH-#28C7E, IRGKangXi=1329.191, RSKangXi=168.6
28C7F CJK UNIFIED IDEOGRAPH-#28C7F, IRGKangXi=1329.191, RSKangXi=168.6
28C80 CJK UNIFIED IDEOGRAPH-#28C80, IRGKangXi=1329.200, RSKangXi=168.7
28C81 CJK UNIFIED IDEOGRAPH-#28C81, IRGKangXi=1329.210, RSKangXi=168.7
28C82 CJK UNIFIED IDEOGRAPH-#28C82, IRGKangXi=1329.220, RSKangXi=168.7
28C83 CJK UNIFIED IDEOGRAPH-#28C83, IRGKangXi=1329.221, RSKangXi=168.7
28C84 CJK UNIFIED IDEOGRAPH-#28C84, IRGKangXi=1329.221, RSKangXi=168.7
28C85 CJK UNIFIED IDEOGRAPH-#28C85, IRGKangXi=1329.221, RSKangXi=168.7
28C86 CJK UNIFIED IDEOGRAPH-#28C86, IRGKangXi=1329.221, RSKangXi=168.7
28C87 CJK UNIFIED IDEOGRAPH-#28C87, IRGKangXi=1329.230, RSKangXi=168.8
28C88 CJK UNIFIED IDEOGRAPH-#28C88, IRGKangXi=1329.240, RSKangXi=168.8
28C89 CJK UNIFIED IDEOGRAPH-#28C89, IRGKangXi=1329.250, RSKangXi=168.8
28C8A CJK UNIFIED IDEOGRAPH-#28C8A, IRGKangXi=1329.260, RSKangXi=168.8
28C8B CJK UNIFIED IDEOGRAPH-#28C8B, IRGKangXi=1329.270, RSKangXi=168.8
28C8C CJK UNIFIED IDEOGRAPH-#28C8C, IRGKangXi=1329.280, RSKangXi=168.8
28C8D CJK UNIFIED IDEOGRAPH-#28C8D, IRGKangXi=1329.291, RSKangXi=168.8
28C8E CJK UNIFIED IDEOGRAPH-#28C8E, IRGKangXi=1329.291, RSKangXi=168.8
28C8F CJK UNIFIED IDEOGRAPH-#28C8F, IRGKangXi=1329.291, RSKangXi=168.8
28C90 CJK UNIFIED IDEOGRAPH-#28C90, IRGKangXi=1329.291, RSKangXi=168.8
28C91 CJK UNIFIED IDEOGRAPH-#28C91, IRGKangXi=1329.291, RSKangXi=168.8
28C92 CJK UNIFIED IDEOGRAPH-#28C92, IRGKangXi=1329.291, RSKangXi=168.8
28C93 CJK UNIFIED IDEOGRAPH-#28C93, IRGKangXi=1329.300, RSKangXi=168.9
28C94 CJK UNIFIED IDEOGRAPH-#28C94, IRGKangXi=1329.310, RSKangXi=168.9
28C95 CJK UNIFIED IDEOGRAPH-#28C95, IRGKangXi=1329.320, RSKangXi=168.9
28C96 CJK UNIFIED IDEOGRAPH-#28C96, IRGKangXi=1329.321, RSKangXi=168.9
28C97 CJK UNIFIED IDEOGRAPH-#28C97, IRGKangXi=1329.321, RSKangXi=168.9
28C98 CJK UNIFIED IDEOGRAPH-#28C98, IRGKangXi=1329.321, RSKangXi=168.9
28C99 CJK UNIFIED IDEOGRAPH-#28C99, IRGKangXi=1329.321, RSKangXi=168.9
28C9A CJK UNIFIED IDEOGRAPH-#28C9A, IRGKangXi=1329.321, RSKangXi=168.9
28C9B CJK UNIFIED IDEOGRAPH-#28C9B, IRGKangXi=1329.321, RSKangXi=168.9
28C9C CJK UNIFIED IDEOGRAPH-#28C9C, IRGKangXi=1329.321, RSKangXi=168.9
28C9D CJK UNIFIED IDEOGRAPH-#28C9D, IRGKangXi=1329.321, RSKangXi=168.9
28C9E CJK UNIFIED IDEOGRAPH-#28C9E, IRGKangXi=1329.330, RSKangXi=168.10
28C9F CJK UNIFIED IDEOGRAPH-#28C9F, IRGKangXi=1329.340, RSKangXi=168.10
28CA0 CJK UNIFIED IDEOGRAPH-#28CA0, IRGKangXi=1329.350, RSKangXi=168.10
28CA1 CJK UNIFIED IDEOGRAPH-#28CA1, IRGKangXi=1329.360, RSKangXi=168.10
28CA2 CJK UNIFIED IDEOGRAPH-#28CA2, IRGKangXi=1329.370, RSKangXi=168.10
28CA3 CJK UNIFIED IDEOGRAPH-#28CA3, IRGKangXi=1329.371, RSKangXi=168.10
28CA4 CJK UNIFIED IDEOGRAPH-#28CA4, IRGKangXi=1329.371, RSKangXi=168.10
28CA5 CJK UNIFIED IDEOGRAPH-#28CA5, IRGKangXi=1329.371, RSKangXi=168.11
28CA6 CJK UNIFIED IDEOGRAPH-#28CA6, IRGKangXi=1329.371, RSKangXi=168.11
28CA7 CJK UNIFIED IDEOGRAPH-#28CA7, IRGKangXi=1329.390, RSKangXi=168.11
28CA8 CJK UNIFIED IDEOGRAPH-#28CA8, IRGKangXi=1329.400, RSKangXi=168.11
28CA9 CJK UNIFIED IDEOGRAPH-#28CA9, IRGKangXi=1329.410, RSKangXi=168.11
28CAA CJK UNIFIED IDEOGRAPH-#28CAA, IRGKangXi=1329.411, RSKangXi=168.11
28CAB CJK UNIFIED IDEOGRAPH-#28CAB, IRGKangXi=1329.411, RSKangXi=168.11
28CAC CJK UNIFIED IDEOGRAPH-#28CAC, IRGKangXi=1329.411, RSKangXi=168.11
28CAD CJK UNIFIED IDEOGRAPH-#28CAD, IRGKangXi=1329.430, RSKangXi=168.12
28CAE CJK UNIFIED IDEOGRAPH-#28CAE, IRGKangXi=1329.440, RSKangXi=168.12
28CAF CJK UNIFIED IDEOGRAPH-#28CAF, IRGKangXi=1329.450, RSKangXi=168.12
28CB0 CJK UNIFIED IDEOGRAPH-#28CB0, IRGKangXi=1329.451, RSKangXi=168.12
28CB1 CJK UNIFIED IDEOGRAPH-#28CB1, IRGKangXi=1329.451, RSKangXi=168.12
28CB2 CJK UNIFIED IDEOGRAPH-#28CB2, IRGKangXi=1329.451, RSKangXi=168.12
28CB3 CJK UNIFIED IDEOGRAPH-#28CB3, IRGKangXi=1329.460, RSKangXi=168.13
28CB4 CJK UNIFIED IDEOGRAPH-#28CB4, IRGKangXi=1329.461, RSKangXi=168.13
28CB5 CJK UNIFIED IDEOGRAPH-#28CB5, IRGKangXi=1329.461, RSKangXi=168.13
28CB6 CJK UNIFIED IDEOGRAPH-#28CB6, IRGKangXi=1329.461, RSKangXi=168.13
28CB7 CJK UNIFIED IDEOGRAPH-#28CB7, IRGKangXi=1329.461, RSKangXi=168.13
28CB8 CJK UNIFIED IDEOGRAPH-#28CB8, IRGKangXi=1329.470, RSKangXi=168.14
28CB9 CJK UNIFIED IDEOGRAPH-#28CB9, IRGKangXi=1329.481, RSKangXi=168.14
28CBA CJK UNIFIED IDEOGRAPH-#28CBA, IRGKangXi=1329.481, RSKangXi=168.14
28CBB CJK UNIFIED IDEOGRAPH-#28CBB, IRGKangXi=1329.490, RSKangXi=168.15
28CBC CJK UNIFIED IDEOGRAPH-#28CBC, IRGKangXi=1329.500, RSKangXi=168.15
28CBD CJK UNIFIED IDEOGRAPH-#28CBD, IRGKangXi=1329.501, RSKangXi=168.15
28CBE CJK UNIFIED IDEOGRAPH-#28CBE, IRGKangXi=1329.501, RSKangXi=168.15
28CBF CJK UNIFIED IDEOGRAPH-#28CBF, IRGKangXi=1329.501, RSKangXi=168.15
28CC0 CJK UNIFIED IDEOGRAPH-#28CC0, IRGKangXi=1329.510, RSKangXi=168.16
28CC1 CJK UNIFIED IDEOGRAPH-#28CC1, IRGKangXi=1329.520, RSKangXi=168.16
28CC2 CJK UNIFIED IDEOGRAPH-#28CC2, IRGKangXi=1329.521, RSKangXi=168.17
28CC3 CJK UNIFIED IDEOGRAPH-#28CC3, IRGKangXi=1329.521, RSKangXi=168.17
28CC4 CJK UNIFIED IDEOGRAPH-#28CC4, IRGKangXi=1329.521, RSKangXi=168.19
28CC5 CJK UNIFIED IDEOGRAPH-#28CC5, IRGKangXi=1329.521, RSKangXi=168.21
28CC6 CJK UNIFIED IDEOGRAPH-#28CC6, IRGKangXi=1329.521, RSKangXi=168.22
28CC7 CJK UNIFIED IDEOGRAPH-#28CC7, IRGKangXi=1329.531, RSKangXi=169.0
28CC8 CJK UNIFIED IDEOGRAPH-#28CC8, IRGKangXi=1329.531, RSKangXi=169.0
28CC9 CJK UNIFIED IDEOGRAPH-#28CC9, IRGKangXi=1330.020, RSKangXi=169.1
28CCA CJK UNIFIED IDEOGRAPH-#28CCA, IRGKangXi=1330.040, RSKangXi=169.2, Def{(Cant.) penis (vulg.)}
28CCB CJK UNIFIED IDEOGRAPH-#28CCB, IRGKangXi=1330.050, RSKangXi=169.2
28CCC CJK UNIFIED IDEOGRAPH-#28CCC, IRGKangXi=1330.070, RSKangXi=169.2
28CCD CJK UNIFIED IDEOGRAPH-#28CCD, IRGKangXi=1330.091, RSKangXi=169.2, Def{(Cant.) penis (vulg.)}
28CCE CJK UNIFIED IDEOGRAPH-#28CCE, IRGKangXi=1330.091, RSKangXi=169.2
28CCF CJK UNIFIED IDEOGRAPH-#28CCF, IRGKangXi=1330.091, RSKangXi=169.2
28CD0 CJK UNIFIED IDEOGRAPH-#28CD0, IRGKangXi=1330.150, RSKangXi=169.3
28CD1 CJK UNIFIED IDEOGRAPH-#28CD1, IRGKangXi=1331.010, RSKangXi=169.3
28CD2 CJK UNIFIED IDEOGRAPH-#28CD2, IRGKangXi=1331.011, RSKangXi=169.3, Def{(Cant.) sexual intercourse (vulg.)}
28CD3 CJK UNIFIED IDEOGRAPH-#28CD3, IRGKangXi=1331.011, RSKangXi=169.3
28CD4 CJK UNIFIED IDEOGRAPH-#28CD4, IRGKangXi=1331.011, RSKangXi=169.3
28CD5 CJK UNIFIED IDEOGRAPH-#28CD5, IRGKangXi=1331.011, RSKangXi=169.3
28CD6 CJK UNIFIED IDEOGRAPH-#28CD6, IRGKangXi=1331.011, RSKangXi=169.3
28CD7 CJK UNIFIED IDEOGRAPH-#28CD7, IRGKangXi=1331.030, RSKangXi=169.4
28CD8 CJK UNIFIED IDEOGRAPH-#28CD8, IRGKangXi=1331.040, RSKangXi=169.4
28CD9 CJK UNIFIED IDEOGRAPH-#28CD9, IRGKangXi=1331.080, RSKangXi=169.4
28CDA CJK UNIFIED IDEOGRAPH-#28CDA, IRGKangXi=1331.090, RSKangXi=169.4
28CDB CJK UNIFIED IDEOGRAPH-#28CDB, IRGKangXi=1331.100, RSKangXi=169.4
28CDC CJK UNIFIED IDEOGRAPH-#28CDC, IRGKangXi=1331.120, RSKangXi=169.4
28CDD CJK UNIFIED IDEOGRAPH-#28CDD, IRGKangXi=1331.170, RSKangXi=169.4
28CDE CJK UNIFIED IDEOGRAPH-#28CDE, IRGKangXi=1331.200, RSKangXi=169.4
28CDF CJK UNIFIED IDEOGRAPH-#28CDF, IRGKangXi=1333.050, RSKangXi=169.4
28CE0 CJK UNIFIED IDEOGRAPH-#28CE0, IRGKangXi=1333.060, RSKangXi=169.4
28CE1 CJK UNIFIED IDEOGRAPH-#28CE1, IRGKangXi=1333.070, RSKangXi=169.4
28CE2 CJK UNIFIED IDEOGRAPH-#28CE2, IRGKangXi=1333.080, RSKangXi=169.4
28CE3 CJK UNIFIED IDEOGRAPH-#28CE3, IRGKangXi=1333.090, RSKangXi=169.4
28CE4 CJK UNIFIED IDEOGRAPH-#28CE4, IRGKangXi=1333.091, RSKangXi=169.4
28CE5 CJK UNIFIED IDEOGRAPH-#28CE5, IRGKangXi=1333.091, RSKangXi=169.4
28CE6 CJK UNIFIED IDEOGRAPH-#28CE6, IRGKangXi=1333.091, RSKangXi=169.4
28CE7 CJK UNIFIED IDEOGRAPH-#28CE7, IRGKangXi=1333.091, RSKangXi=169.4
28CE8 CJK UNIFIED IDEOGRAPH-#28CE8, IRGKangXi=1333.091, RSKangXi=169.4
28CE9 CJK UNIFIED IDEOGRAPH-#28CE9, IRGKangXi=1333.091, RSKangXi=169.4
28CEA CJK UNIFIED IDEOGRAPH-#28CEA, IRGKangXi=1333.091, RSKangXi=169.4
28CEB CJK UNIFIED IDEOGRAPH-#28CEB, IRGKangXi=1333.091, RSKangXi=169.4
28CEC CJK UNIFIED IDEOGRAPH-#28CEC, IRGKangXi=1333.091, RSKangXi=169.4
28CED CJK UNIFIED IDEOGRAPH-#28CED, IRGKangXi=1333.091, RSKangXi=169.4
28CEE CJK UNIFIED IDEOGRAPH-#28CEE, IRGKangXi=1333.091, RSKangXi=169.4
28CEF CJK UNIFIED IDEOGRAPH-#28CEF, IRGKangXi=1333.091, RSKangXi=169.4
28CF0 CJK UNIFIED IDEOGRAPH-#28CF0, IRGKangXi=1333.091, RSKangXi=169.4
28CF1 CJK UNIFIED IDEOGRAPH-#28CF1, IRGKangXi=1333.091, RSKangXi=169.4
28CF2 CJK UNIFIED IDEOGRAPH-#28CF2, IRGKangXi=1333.091, RSKangXi=169.4
28CF3 CJK UNIFIED IDEOGRAPH-#28CF3, IRGKangXi=1333.100, RSKangXi=169.5
28CF4 CJK UNIFIED IDEOGRAPH-#28CF4, IRGKangXi=1333.150, RSKangXi=169.5
28CF5 CJK UNIFIED IDEOGRAPH-#28CF5, IRGKangXi=1333.170, RSKangXi=169.5
28CF6 CJK UNIFIED IDEOGRAPH-#28CF6, IRGKangXi=1333.180, RSKangXi=169.5
28CF7 CJK UNIFIED IDEOGRAPH-#28CF7, IRGKangXi=1333.190, RSKangXi=169.5
28CF8 CJK UNIFIED IDEOGRAPH-#28CF8, IRGKangXi=1333.210, RSKangXi=169.5
28CF9 CJK UNIFIED IDEOGRAPH-#28CF9, IRGKangXi=1333.230, RSKangXi=169.5
28CFA CJK UNIFIED IDEOGRAPH-#28CFA, IRGKangXi=1333.240, RSKangXi=169.5
28CFB CJK UNIFIED IDEOGRAPH-#28CFB, IRGKangXi=1333.250, RSKangXi=169.5
28CFC CJK UNIFIED IDEOGRAPH-#28CFC, IRGKangXi=1333.260, RSKangXi=169.5
28CFD CJK UNIFIED IDEOGRAPH-#28CFD, IRGKangXi=1333.270, RSKangXi=169.5
28CFE CJK UNIFIED IDEOGRAPH-#28CFE, IRGKangXi=1333.290, RSKangXi=169.5
28CFF CJK UNIFIED IDEOGRAPH-#28CFF, IRGKangXi=1333.330, RSKangXi=169.5
28D00 CJK UNIFIED IDEOGRAPH-#28D00, IRGKangXi=1333.340, RSKangXi=169.5
28D01 CJK UNIFIED IDEOGRAPH-#28D01, IRGKangXi=1333.350, RSKangXi=169.5
28D02 CJK UNIFIED IDEOGRAPH-#28D02, IRGKangXi=1333.360, RSKangXi=169.5
28D03 CJK UNIFIED IDEOGRAPH-#28D03, IRGKangXi=1333.361, RSKangXi=169.5
28D04 CJK UNIFIED IDEOGRAPH-#28D04, IRGKangXi=1333.361, RSKangXi=169.5
28D05 CJK UNIFIED IDEOGRAPH-#28D05, IRGKangXi=1333.361, RSKangXi=169.5
28D06 CJK UNIFIED IDEOGRAPH-#28D06, IRGKangXi=1333.361, RSKangXi=169.5
28D07 CJK UNIFIED IDEOGRAPH-#28D07, IRGKangXi=1333.361, RSKangXi=169.5
28D08 CJK UNIFIED IDEOGRAPH-#28D08, IRGKangXi=1333.361, RSKangXi=169.5
28D09 CJK UNIFIED IDEOGRAPH-#28D09, IRGKangXi=1333.361, RSKangXi=169.5
28D0A CJK UNIFIED IDEOGRAPH-#28D0A, IRGKangXi=1333.361, RSKangXi=169.5
28D0B CJK UNIFIED IDEOGRAPH-#28D0B, IRGKangXi=1333.361, RSKangXi=169.5
28D0C CJK UNIFIED IDEOGRAPH-#28D0C, IRGKangXi=1333.361, RSKangXi=169.5
28D0D CJK UNIFIED IDEOGRAPH-#28D0D, IRGKangXi=1334.030, RSKangXi=169.6
28D0E CJK UNIFIED IDEOGRAPH-#28D0E, IRGKangXi=1334.040, RSKangXi=169.6
28D0F CJK UNIFIED IDEOGRAPH-#28D0F, IRGKangXi=1334.050, RSKangXi=169.6
28D10 CJK UNIFIED IDEOGRAPH-#28D10, IRGKangXi=1334.060, RSKangXi=169.6
28D11 CJK UNIFIED IDEOGRAPH-#28D11, IRGKangXi=1334.070, RSKangXi=169.6, Def{the frame of a door or window fixed in a wall}
28D12 CJK UNIFIED IDEOGRAPH-#28D12, IRGKangXi=1334.130, RSKangXi=169.6
28D13 CJK UNIFIED IDEOGRAPH-#28D13, IRGKangXi=1334.140, RSKangXi=169.6
28D14 CJK UNIFIED IDEOGRAPH-#28D14, IRGKangXi=1334.150, RSKangXi=169.6
28D15 CJK UNIFIED IDEOGRAPH-#28D15, IRGKangXi=1334.160, RSKangXi=169.6
28D16 CJK UNIFIED IDEOGRAPH-#28D16, IRGKangXi=1335.020, RSKangXi=169.6
28D17 CJK UNIFIED IDEOGRAPH-#28D17, IRGKangXi=1335.060, RSKangXi=169.6
28D18 CJK UNIFIED IDEOGRAPH-#28D18, IRGKangXi=1335.080, RSKangXi=169.6
28D19 CJK UNIFIED IDEOGRAPH-#28D19, IRGKangXi=1335.090, RSKangXi=169.6
28D1A CJK UNIFIED IDEOGRAPH-#28D1A, IRGKangXi=1335.091, RSKangXi=169.6
28D1B CJK UNIFIED IDEOGRAPH-#28D1B, IRGKangXi=1335.091, RSKangXi=169.6
28D1C CJK UNIFIED IDEOGRAPH-#28D1C, IRGKangXi=1335.091, RSKangXi=169.6
28D1D CJK UNIFIED IDEOGRAPH-#28D1D, IRGKangXi=1335.091, RSKangXi=169.6
28D1E CJK UNIFIED IDEOGRAPH-#28D1E, IRGKangXi=1335.091, RSKangXi=169.6
28D1F CJK UNIFIED IDEOGRAPH-#28D1F, IRGKangXi=1335.091, RSKangXi=169.6
28D20 CJK UNIFIED IDEOGRAPH-#28D20, IRGKangXi=1335.091, RSKangXi=169.6
28D21 CJK UNIFIED IDEOGRAPH-#28D21, IRGKangXi=1335.091, RSKangXi=169.6
28D22 CJK UNIFIED IDEOGRAPH-#28D22, IRGKangXi=1335.091, RSKangXi=169.6
28D23 CJK UNIFIED IDEOGRAPH-#28D23, IRGKangXi=1335.091, RSKangXi=169.6
28D24 CJK UNIFIED IDEOGRAPH-#28D24, IRGKangXi=1335.091, RSKangXi=169.6
28D25 CJK UNIFIED IDEOGRAPH-#28D25, IRGKangXi=1335.091, RSKangXi=169.6
28D26 CJK UNIFIED IDEOGRAPH-#28D26, IRGKangXi=1335.091, RSKangXi=169.6
28D27 CJK UNIFIED IDEOGRAPH-#28D27, IRGKangXi=1335.091, RSKangXi=169.7
28D28 CJK UNIFIED IDEOGRAPH-#28D28, IRGKangXi=1335.100, RSKangXi=169.7
28D29 CJK UNIFIED IDEOGRAPH-#28D29, IRGKangXi=1335.110, RSKangXi=169.7
28D2A CJK UNIFIED IDEOGRAPH-#28D2A, IRGKangXi=1335.140, RSKangXi=169.7
28D2B CJK UNIFIED IDEOGRAPH-#28D2B, IRGKangXi=1335.160, RSKangXi=169.7
28D2C CJK UNIFIED IDEOGRAPH-#28D2C, IRGKangXi=1336.010, RSKangXi=169.7
28D2D CJK UNIFIED IDEOGRAPH-#28D2D, IRGKangXi=1336.020, RSKangXi=169.7
28D2E CJK UNIFIED IDEOGRAPH-#28D2E, IRGKangXi=1336.080, RSKangXi=169.7
28D2F CJK UNIFIED IDEOGRAPH-#28D2F, IRGKangXi=1336.090, RSKangXi=169.7
28D30 CJK UNIFIED IDEOGRAPH-#28D30, IRGKangXi=1336.100, RSKangXi=169.7
28D31 CJK UNIFIED IDEOGRAPH-#28D31, IRGKangXi=1336.110, RSKangXi=169.7
28D32 CJK UNIFIED IDEOGRAPH-#28D32, IRGKangXi=1336.111, RSKangXi=169.7
28D33 CJK UNIFIED IDEOGRAPH-#28D33, IRGKangXi=1336.111, RSKangXi=169.7
28D34 CJK UNIFIED IDEOGRAPH-#28D34, IRGKangXi=1336.111, RSKangXi=169.7
28D35 CJK UNIFIED IDEOGRAPH-#28D35, IRGKangXi=1336.111, RSKangXi=169.7
28D36 CJK UNIFIED IDEOGRAPH-#28D36, IRGKangXi=1336.111, RSKangXi=169.7
28D37 CJK UNIFIED IDEOGRAPH-#28D37, IRGKangXi=1336.111, RSKangXi=169.7
28D38 CJK UNIFIED IDEOGRAPH-#28D38, IRGKangXi=1336.111, RSKangXi=169.7
28D39 CJK UNIFIED IDEOGRAPH-#28D39, IRGKangXi=1336.111, RSKangXi=169.7
28D3A CJK UNIFIED IDEOGRAPH-#28D3A, IRGKangXi=1336.111, RSKangXi=169.7
28D3B CJK UNIFIED IDEOGRAPH-#28D3B, IRGKangXi=1336.111, RSKangXi=169.7
28D3C CJK UNIFIED IDEOGRAPH-#28D3C, IRGKangXi=1336.111, RSKangXi=169.7
28D3D CJK UNIFIED IDEOGRAPH-#28D3D, IRGKangXi=1336.111, RSKangXi=169.7
28D3E CJK UNIFIED IDEOGRAPH-#28D3E, IRGKangXi=1336.111, RSKangXi=169.7
28D3F CJK UNIFIED IDEOGRAPH-#28D3F, IRGKangXi=1336.111, RSKangXi=169.7
28D40 CJK UNIFIED IDEOGRAPH-#28D40, IRGKangXi=1336.111, RSKangXi=169.7
28D41 CJK UNIFIED IDEOGRAPH-#28D41, IRGKangXi=1336.111, RSKangXi=169.7
28D42 CJK UNIFIED IDEOGRAPH-#28D42, IRGKangXi=1336.111, RSKangXi=169.7
28D43 CJK UNIFIED IDEOGRAPH-#28D43, IRGKangXi=1336.111, RSKangXi=169.7
28D44 CJK UNIFIED IDEOGRAPH-#28D44, IRGKangXi=1336.111, RSKangXi=169.7
28D45 CJK UNIFIED IDEOGRAPH-#28D45, IRGKangXi=1336.111, RSKangXi=169.7
28D46 CJK UNIFIED IDEOGRAPH-#28D46, IRGKangXi=1336.111, RSKangXi=169.7
28D47 CJK UNIFIED IDEOGRAPH-#28D47, IRGKangXi=1336.111, RSKangXi=169.7
28D48 CJK UNIFIED IDEOGRAPH-#28D48, IRGKangXi=1336.140, RSKangXi=169.8
28D49 CJK UNIFIED IDEOGRAPH-#28D49, IRGKangXi=1337.020, RSKangXi=169.8
28D4A CJK UNIFIED IDEOGRAPH-#28D4A, IRGKangXi=1337.040, RSKangXi=169.8
28D4B CJK UNIFIED IDEOGRAPH-#28D4B, IRGKangXi=1337.060, RSKangXi=169.8
28D4C CJK UNIFIED IDEOGRAPH-#28D4C, IRGKangXi=1337.070, RSKangXi=169.8
28D4D CJK UNIFIED IDEOGRAPH-#28D4D, IRGKangXi=1337.100, RSKangXi=169.8
28D4E CJK UNIFIED IDEOGRAPH-#28D4E, IRGKangXi=1337.110, RSKangXi=169.8
28D4F CJK UNIFIED IDEOGRAPH-#28D4F, IRGKangXi=1337.150, RSKangXi=169.8
28D50 CJK UNIFIED IDEOGRAPH-#28D50, IRGKangXi=1338.050, RSKangXi=169.8
28D51 CJK UNIFIED IDEOGRAPH-#28D51, IRGKangXi=1338.060, RSKangXi=169.8
28D52 CJK UNIFIED IDEOGRAPH-#28D52, IRGKangXi=1338.070, RSKangXi=169.8
28D53 CJK UNIFIED IDEOGRAPH-#28D53, IRGKangXi=1338.080, RSKangXi=169.8
28D54 CJK UNIFIED IDEOGRAPH-#28D54, IRGKangXi=1338.081, RSKangXi=169.8
28D55 CJK UNIFIED IDEOGRAPH-#28D55, IRGKangXi=1338.081, RSKangXi=169.8
28D56 CJK UNIFIED IDEOGRAPH-#28D56, IRGKangXi=1338.081, RSKangXi=169.8
28D57 CJK UNIFIED IDEOGRAPH-#28D57, IRGKangXi=1338.081, RSKangXi=169.8
28D58 CJK UNIFIED IDEOGRAPH-#28D58, IRGKangXi=1338.081, RSKangXi=169.8
28D59 CJK UNIFIED IDEOGRAPH-#28D59, IRGKangXi=1338.081, RSKangXi=169.8
28D5A CJK UNIFIED IDEOGRAPH-#28D5A, IRGKangXi=1338.081, RSKangXi=169.8
28D5B CJK UNIFIED IDEOGRAPH-#28D5B, IRGKangXi=1338.081, RSKangXi=169.8
28D5C CJK UNIFIED IDEOGRAPH-#28D5C, IRGKangXi=1338.081, RSKangXi=169.8
28D5D CJK UNIFIED IDEOGRAPH-#28D5D, IRGKangXi=1338.081, RSKangXi=169.8
28D5E CJK UNIFIED IDEOGRAPH-#28D5E, IRGKangXi=1338.081, RSKangXi=169.8
28D5F CJK UNIFIED IDEOGRAPH-#28D5F, IRGKangXi=1338.081, RSKangXi=169.8
28D60 CJK UNIFIED IDEOGRAPH-#28D60, IRGKangXi=1338.081, RSKangXi=169.8
28D61 CJK UNIFIED IDEOGRAPH-#28D61, IRGKangXi=1338.081, RSKangXi=169.8
28D62 CJK UNIFIED IDEOGRAPH-#28D62, IRGKangXi=1338.081, RSKangXi=169.8
28D63 CJK UNIFIED IDEOGRAPH-#28D63, IRGKangXi=1338.081, RSKangXi=169.8
28D64 CJK UNIFIED IDEOGRAPH-#28D64, IRGKangXi=1338.081, RSKangXi=169.8
28D65 CJK UNIFIED IDEOGRAPH-#28D65, IRGKangXi=1338.110, RSKangXi=169.9
28D66 CJK UNIFIED IDEOGRAPH-#28D66, IRGKangXi=1338.170, RSKangXi=169.9
28D67 CJK UNIFIED IDEOGRAPH-#28D67, IRGKangXi=1338.180, RSKangXi=169.9
28D68 CJK UNIFIED IDEOGRAPH-#28D68, IRGKangXi=1338.190, RSKangXi=169.9
28D69 CJK UNIFIED IDEOGRAPH-#28D69, IRGKangXi=1338.230, RSKangXi=169.9
28D6A CJK UNIFIED IDEOGRAPH-#28D6A, IRGKangXi=1338.240, RSKangXi=169.9
28D6B CJK UNIFIED IDEOGRAPH-#28D6B, IRGKangXi=1338.250, RSKangXi=169.9
28D6C CJK UNIFIED IDEOGRAPH-#28D6C, IRGKangXi=1338.280, RSKangXi=169.9
28D6D CJK UNIFIED IDEOGRAPH-#28D6D, IRGKangXi=1339.020, RSKangXi=169.9
28D6E CJK UNIFIED IDEOGRAPH-#28D6E, IRGKangXi=1339.030, RSKangXi=169.9
28D6F CJK UNIFIED IDEOGRAPH-#28D6F, IRGKangXi=1339.060, RSKangXi=169.9
28D70 CJK UNIFIED IDEOGRAPH-#28D70, IRGKangXi=1339.070, RSKangXi=169.9
28D71 CJK UNIFIED IDEOGRAPH-#28D71, IRGKangXi=1339.071, RSKangXi=169.9
28D72 CJK UNIFIED IDEOGRAPH-#28D72, IRGKangXi=1339.071, RSKangXi=169.9
28D73 CJK UNIFIED IDEOGRAPH-#28D73, IRGKangXi=1339.071, RSKangXi=169.9
28D74 CJK UNIFIED IDEOGRAPH-#28D74, IRGKangXi=1339.071, RSKangXi=169.9
28D75 CJK UNIFIED IDEOGRAPH-#28D75, IRGKangXi=1339.071, RSKangXi=169.9
28D76 CJK UNIFIED IDEOGRAPH-#28D76, IRGKangXi=1339.071, RSKangXi=169.9
28D77 CJK UNIFIED IDEOGRAPH-#28D77, IRGKangXi=1339.071, RSKangXi=169.9
28D78 CJK UNIFIED IDEOGRAPH-#28D78, IRGKangXi=1339.071, RSKangXi=169.9
28D79 CJK UNIFIED IDEOGRAPH-#28D79, IRGKangXi=1339.071, RSKangXi=169.9
28D7A CJK UNIFIED IDEOGRAPH-#28D7A, IRGKangXi=1339.071, RSKangXi=169.9
28D7B CJK UNIFIED IDEOGRAPH-#28D7B, IRGKangXi=1339.071, RSKangXi=169.9
28D7C CJK UNIFIED IDEOGRAPH-#28D7C, IRGKangXi=1339.071, RSKangXi=169.9
28D7D CJK UNIFIED IDEOGRAPH-#28D7D, IRGKangXi=1339.071, RSKangXi=169.9
28D7E CJK UNIFIED IDEOGRAPH-#28D7E, IRGKangXi=1339.071, RSKangXi=169.9
28D7F CJK UNIFIED IDEOGRAPH-#28D7F, IRGKangXi=1339.071, RSKangXi=169.9
28D80 CJK UNIFIED IDEOGRAPH-#28D80, IRGKangXi=1339.080, RSKangXi=169.10
28D81 CJK UNIFIED IDEOGRAPH-#28D81, IRGKangXi=1339.090, RSKangXi=169.10
28D82 CJK UNIFIED IDEOGRAPH-#28D82, IRGKangXi=1339.100, RSKangXi=169.10
28D83 CJK UNIFIED IDEOGRAPH-#28D83, IRGKangXi=1339.120, RSKangXi=169.10
28D84 CJK UNIFIED IDEOGRAPH-#28D84, IRGKangXi=1339.130, RSKangXi=169.10
28D85 CJK UNIFIED IDEOGRAPH-#28D85, IRGKangXi=1340.030, RSKangXi=169.10
28D86 CJK UNIFIED IDEOGRAPH-#28D86, IRGKangXi=1340.040, RSKangXi=169.10
28D87 CJK UNIFIED IDEOGRAPH-#28D87, IRGKangXi=1340.050, RSKangXi=169.10
28D88 CJK UNIFIED IDEOGRAPH-#28D88, IRGKangXi=1340.070, RSKangXi=169.10
28D89 CJK UNIFIED IDEOGRAPH-#28D89, IRGKangXi=1341.010, RSKangXi=169.10
28D8A CJK UNIFIED IDEOGRAPH-#28D8A, IRGKangXi=1341.020, RSKangXi=169.10
28D8B CJK UNIFIED IDEOGRAPH-#28D8B, IRGKangXi=1341.030, RSKangXi=169.10
28D8C CJK UNIFIED IDEOGRAPH-#28D8C, IRGKangXi=1341.031, RSKangXi=169.10
28D8D CJK UNIFIED IDEOGRAPH-#28D8D, IRGKangXi=1341.031, RSKangXi=169.10
28D8E CJK UNIFIED IDEOGRAPH-#28D8E, IRGKangXi=1341.031, RSKangXi=169.10
28D8F CJK UNIFIED IDEOGRAPH-#28D8F, IRGKangXi=1341.031, RSKangXi=169.10
28D90 CJK UNIFIED IDEOGRAPH-#28D90, IRGKangXi=1341.031, RSKangXi=169.10
28D91 CJK UNIFIED IDEOGRAPH-#28D91, IRGKangXi=1341.031, RSKangXi=169.10
28D92 CJK UNIFIED IDEOGRAPH-#28D92, IRGKangXi=1341.031, RSKangXi=169.10
28D93 CJK UNIFIED IDEOGRAPH-#28D93, IRGKangXi=1341.031, RSKangXi=169.10
28D94 CJK UNIFIED IDEOGRAPH-#28D94, IRGKangXi=1341.031, RSKangXi=169.10
28D95 CJK UNIFIED IDEOGRAPH-#28D95, IRGKangXi=1341.031, RSKangXi=169.10
28D96 CJK UNIFIED IDEOGRAPH-#28D96, IRGKangXi=1341.031, RSKangXi=169.10
28D97 CJK UNIFIED IDEOGRAPH-#28D97, IRGKangXi=1341.031, RSKangXi=169.10
28D98 CJK UNIFIED IDEOGRAPH-#28D98, IRGKangXi=1341.031, RSKangXi=169.10
28D99 CJK UNIFIED IDEOGRAPH-#28D99, IRGKangXi=1341.031, RSKangXi=169.10, Def{(Cant., vulg.) penis}
28D9A CJK UNIFIED IDEOGRAPH-#28D9A, IRGKangXi=1341.031, RSKangXi=169.10
28D9B CJK UNIFIED IDEOGRAPH-#28D9B, IRGKangXi=1341.031, RSKangXi=169.10
28D9C CJK UNIFIED IDEOGRAPH-#28D9C, IRGKangXi=1341.050, RSKangXi=169.11
28D9D CJK UNIFIED IDEOGRAPH-#28D9D, IRGKangXi=1341.080, RSKangXi=169.11
28D9E CJK UNIFIED IDEOGRAPH-#28D9E, IRGKangXi=1341.100, RSKangXi=169.11
28D9F CJK UNIFIED IDEOGRAPH-#28D9F, IRGKangXi=1341.110, RSKangXi=169.11
28DA0 CJK UNIFIED IDEOGRAPH-#28DA0, IRGKangXi=1341.120, RSKangXi=169.11
28DA1 CJK UNIFIED IDEOGRAPH-#28DA1, IRGKangXi=1341.130, RSKangXi=169.11
28DA2 CJK UNIFIED IDEOGRAPH-#28DA2, IRGKangXi=1341.140, RSKangXi=169.11
28DA3 CJK UNIFIED IDEOGRAPH-#28DA3, IRGKangXi=1341.141, RSKangXi=169.11
28DA4 CJK UNIFIED IDEOGRAPH-#28DA4, IRGKangXi=1341.141, RSKangXi=169.11
28DA5 CJK UNIFIED IDEOGRAPH-#28DA5, IRGKangXi=1341.141, RSKangXi=169.11
28DA6 CJK UNIFIED IDEOGRAPH-#28DA6, IRGKangXi=1341.141, RSKangXi=169.11
28DA7 CJK UNIFIED IDEOGRAPH-#28DA7, IRGKangXi=1341.141, RSKangXi=169.11
28DA8 CJK UNIFIED IDEOGRAPH-#28DA8, IRGKangXi=1341.141, RSKangXi=169.11
28DA9 CJK UNIFIED IDEOGRAPH-#28DA9, IRGKangXi=1341.141, RSKangXi=169.11
28DAA CJK UNIFIED IDEOGRAPH-#28DAA, IRGKangXi=1341.141, RSKangXi=169.11
28DAB CJK UNIFIED IDEOGRAPH-#28DAB, IRGKangXi=1341.141, RSKangXi=169.11
28DAC CJK UNIFIED IDEOGRAPH-#28DAC, IRGKangXi=1341.150, RSKangXi=169.12
28DAD CJK UNIFIED IDEOGRAPH-#28DAD, IRGKangXi=1341.160, RSKangXi=169.12
28DAE CJK UNIFIED IDEOGRAPH-#28DAE, IRGKangXi=1341.170, RSKangXi=169.12
28DAF CJK UNIFIED IDEOGRAPH-#28DAF, IRGKangXi=1341.190, RSKangXi=169.12
28DB0 CJK UNIFIED IDEOGRAPH-#28DB0, IRGKangXi=1341.200, RSKangXi=169.12
28DB1 CJK UNIFIED IDEOGRAPH-#28DB1, IRGKangXi=1342.010, RSKangXi=169.12
28DB2 CJK UNIFIED IDEOGRAPH-#28DB2, IRGKangXi=1342.020, RSKangXi=169.12
28DB3 CJK UNIFIED IDEOGRAPH-#28DB3, IRGKangXi=1342.060, RSKangXi=169.12
28DB4 CJK UNIFIED IDEOGRAPH-#28DB4, IRGKangXi=1342.070, RSKangXi=169.12
28DB5 CJK UNIFIED IDEOGRAPH-#28DB5, IRGKangXi=1342.071, RSKangXi=169.12
28DB6 CJK UNIFIED IDEOGRAPH-#28DB6, IRGKangXi=1342.071, RSKangXi=169.12
28DB7 CJK UNIFIED IDEOGRAPH-#28DB7, IRGKangXi=1342.071, RSKangXi=169.12
28DB8 CJK UNIFIED IDEOGRAPH-#28DB8, IRGKangXi=1342.071, RSKangXi=169.12
28DB9 CJK UNIFIED IDEOGRAPH-#28DB9, IRGKangXi=1342.071, RSKangXi=169.12, Def{to close, shut}
28DBA CJK UNIFIED IDEOGRAPH-#28DBA, IRGKangXi=1342.071, RSKangXi=169.12
28DBB CJK UNIFIED IDEOGRAPH-#28DBB, IRGKangXi=1342.071, RSKangXi=169.12
28DBC CJK UNIFIED IDEOGRAPH-#28DBC, IRGKangXi=1342.071, RSKangXi=169.12
28DBD CJK UNIFIED IDEOGRAPH-#28DBD, IRGKangXi=1342.071, RSKangXi=169.12
28DBE CJK UNIFIED IDEOGRAPH-#28DBE, IRGKangXi=1342.071, RSKangXi=169.12
28DBF CJK UNIFIED IDEOGRAPH-#28DBF, IRGKangXi=1342.071, RSKangXi=169.12
28DC0 CJK UNIFIED IDEOGRAPH-#28DC0, IRGKangXi=1342.071, RSKangXi=169.12
28DC1 CJK UNIFIED IDEOGRAPH-#28DC1, IRGKangXi=1342.071, RSKangXi=169.12
28DC2 CJK UNIFIED IDEOGRAPH-#28DC2, IRGKangXi=1342.071, RSKangXi=169.12
28DC3 CJK UNIFIED IDEOGRAPH-#28DC3, IRGKangXi=1342.080, RSKangXi=169.13
28DC4 CJK UNIFIED IDEOGRAPH-#28DC4, IRGKangXi=1342.090, RSKangXi=169.13
28DC5 CJK UNIFIED IDEOGRAPH-#28DC5, IRGKangXi=1342.130, RSKangXi=169.13
28DC6 CJK UNIFIED IDEOGRAPH-#28DC6, IRGKangXi=1342.140, RSKangXi=169.13
28DC7 CJK UNIFIED IDEOGRAPH-#28DC7, IRGKangXi=1342.190, RSKangXi=169.13
28DC8 CJK UNIFIED IDEOGRAPH-#28DC8, IRGKangXi=1343.011, RSKangXi=169.13
28DC9 CJK UNIFIED IDEOGRAPH-#28DC9, IRGKangXi=1343.011, RSKangXi=169.13
28DCA CJK UNIFIED IDEOGRAPH-#28DCA, IRGKangXi=1343.011, RSKangXi=169.13
28DCB CJK UNIFIED IDEOGRAPH-#28DCB, IRGKangXi=1343.011, RSKangXi=169.13
28DCC CJK UNIFIED IDEOGRAPH-#28DCC, IRGKangXi=1343.011, RSKangXi=169.13
28DCD CJK UNIFIED IDEOGRAPH-#28DCD, IRGKangXi=1343.011, RSKangXi=169.13
28DCE CJK UNIFIED IDEOGRAPH-#28DCE, IRGKangXi=1343.011, RSKangXi=169.13
28DCF CJK UNIFIED IDEOGRAPH-#28DCF, IRGKangXi=1343.011, RSKangXi=169.13
28DD0 CJK UNIFIED IDEOGRAPH-#28DD0, IRGKangXi=1343.011, RSKangXi=169.13
28DD1 CJK UNIFIED IDEOGRAPH-#28DD1, IRGKangXi=1343.011, RSKangXi=169.13
28DD2 CJK UNIFIED IDEOGRAPH-#28DD2, IRGKangXi=1343.011, RSKangXi=169.13
28DD3 CJK UNIFIED IDEOGRAPH-#28DD3, IRGKangXi=1343.020, RSKangXi=169.13
28DD4 CJK UNIFIED IDEOGRAPH-#28DD4, IRGKangXi=1343.040, RSKangXi=169.14
28DD5 CJK UNIFIED IDEOGRAPH-#28DD5, IRGKangXi=1343.050, RSKangXi=169.13
28DD6 CJK UNIFIED IDEOGRAPH-#28DD6, IRGKangXi=1343.051, RSKangXi=169.13
28DD7 CJK UNIFIED IDEOGRAPH-#28DD7, IRGKangXi=1343.051, RSKangXi=169.13
28DD8 CJK UNIFIED IDEOGRAPH-#28DD8, IRGKangXi=1343.051, RSKangXi=169.14
28DD9 CJK UNIFIED IDEOGRAPH-#28DD9, IRGKangXi=1343.051, RSKangXi=169.14
28DDA CJK UNIFIED IDEOGRAPH-#28DDA, IRGKangXi=1343.051, RSKangXi=169.14
28DDB CJK UNIFIED IDEOGRAPH-#28DDB, IRGKangXi=1343.051, RSKangXi=169.14
28DDC CJK UNIFIED IDEOGRAPH-#28DDC, IRGKangXi=1343.051, RSKangXi=169.14
28DDD CJK UNIFIED IDEOGRAPH-#28DDD, IRGKangXi=1343.051, RSKangXi=169.14
28DDE CJK UNIFIED IDEOGRAPH-#28DDE, IRGKangXi=1343.051, RSKangXi=169.14
28DDF CJK UNIFIED IDEOGRAPH-#28DDF, IRGKangXi=1343.051, RSKangXi=169.15
28DE0 CJK UNIFIED IDEOGRAPH-#28DE0, IRGKangXi=1343.051, RSKangXi=169.15
28DE1 CJK UNIFIED IDEOGRAPH-#28DE1, IRGKangXi=1343.051, RSKangXi=169.15
28DE2 CJK UNIFIED IDEOGRAPH-#28DE2, IRGKangXi=1343.051, RSKangXi=169.15
28DE3 CJK UNIFIED IDEOGRAPH-#28DE3, IRGKangXi=1343.051, RSKangXi=169.15
28DE4 CJK UNIFIED IDEOGRAPH-#28DE4, IRGKangXi=1343.051, RSKangXi=169.15
28DE5 CJK UNIFIED IDEOGRAPH-#28DE5, IRGKangXi=1343.051, RSKangXi=169.15
28DE6 CJK UNIFIED IDEOGRAPH-#28DE6, IRGKangXi=1343.060, RSKangXi=169.16
28DE7 CJK UNIFIED IDEOGRAPH-#28DE7, IRGKangXi=1343.061, RSKangXi=169.16
28DE8 CJK UNIFIED IDEOGRAPH-#28DE8, IRGKangXi=1343.061, RSKangXi=169.16
28DE9 CJK UNIFIED IDEOGRAPH-#28DE9, IRGKangXi=1343.061, RSKangXi=169.16
28DEA CJK UNIFIED IDEOGRAPH-#28DEA, IRGKangXi=1343.061, RSKangXi=169.16
28DEB CJK UNIFIED IDEOGRAPH-#28DEB, IRGKangXi=1343.061, RSKangXi=169.16
28DEC CJK UNIFIED IDEOGRAPH-#28DEC, IRGKangXi=1343.061, RSKangXi=169.16
28DED CJK UNIFIED IDEOGRAPH-#28DED, IRGKangXi=1343.061, RSKangXi=169.16
28DEE CJK UNIFIED IDEOGRAPH-#28DEE, IRGKangXi=1343.061, RSKangXi=169.16
28DEF CJK UNIFIED IDEOGRAPH-#28DEF, IRGKangXi=1343.061, RSKangXi=169.17
28DF0 CJK UNIFIED IDEOGRAPH-#28DF0, IRGKangXi=1343.070, RSKangXi=169.17
28DF1 CJK UNIFIED IDEOGRAPH-#28DF1, IRGKangXi=1343.080, RSKangXi=169.17
28DF2 CJK UNIFIED IDEOGRAPH-#28DF2, IRGKangXi=1343.090, RSKangXi=169.17
28DF3 CJK UNIFIED IDEOGRAPH-#28DF3, IRGKangXi=1343.091, RSKangXi=169.17
28DF4 CJK UNIFIED IDEOGRAPH-#28DF4, IRGKangXi=1343.091, RSKangXi=169.17
28DF5 CJK UNIFIED IDEOGRAPH-#28DF5, IRGKangXi=1343.091, RSKangXi=169.17
28DF6 CJK UNIFIED IDEOGRAPH-#28DF6, IRGKangXi=1343.091, RSKangXi=169.16
28DF7 CJK UNIFIED IDEOGRAPH-#28DF7, IRGKangXi=1343.100, RSKangXi=169.18
28DF8 CJK UNIFIED IDEOGRAPH-#28DF8, IRGKangXi=1343.101, RSKangXi=169.17
28DF9 CJK UNIFIED IDEOGRAPH-#28DF9, IRGKangXi=1343.101, RSKangXi=169.18
28DFA CJK UNIFIED IDEOGRAPH-#28DFA, IRGKangXi=1343.101, RSKangXi=169.18
28DFB CJK UNIFIED IDEOGRAPH-#28DFB, IRGKangXi=1343.110, RSKangXi=169.19
28DFC CJK UNIFIED IDEOGRAPH-#28DFC, IRGKangXi=1343.111, RSKangXi=169.21
28DFD CJK UNIFIED IDEOGRAPH-#28DFD, IRGKangXi=1343.120, RSKangXi=169.24
28DFE CJK UNIFIED IDEOGRAPH-#28DFE, IRGKangXi=1343.121, RSKangXi=169.24
28DFF CJK UNIFIED IDEOGRAPH-#28DFF, IRGKangXi=1343.121, RSKangXi=169.3
28E00 CJK UNIFIED IDEOGRAPH-#28E00, IRGKangXi=1343.121, RSKangXi=169.3
28E01 CJK UNIFIED IDEOGRAPH-#28E01, IRGKangXi=1343.121, RSKangXi=169.3
28E02 CJK UNIFIED IDEOGRAPH-#28E02, IRGKangXi=1343.121, RSKangXi=169.4
28E03 CJK UNIFIED IDEOGRAPH-#28E03, IRGKangXi=1343.121, RSKangXi=169.4
28E04 CJK UNIFIED IDEOGRAPH-#28E04, IRGKangXi=1343.121, RSKangXi=169.6
28E05 CJK UNIFIED IDEOGRAPH-#28E05, IRGKangXi=1343.121, RSKangXi=169.6
28E06 CJK UNIFIED IDEOGRAPH-#28E06, IRGKangXi=1343.121, RSKangXi=169.9
28E07 CJK UNIFIED IDEOGRAPH-#28E07, IRGKangXi=1343.121, RSKangXi=169.9
28E08 CJK UNIFIED IDEOGRAPH-#28E08, IRGKangXi=1343.121, RSKangXi=169.9
28E09 CJK UNIFIED IDEOGRAPH-#28E09, IRGKangXi=1343.121, RSKangXi=169.10
28E0A CJK UNIFIED IDEOGRAPH-#28E0A, IRGKangXi=1343.121, RSKangXi=169.10
28E0B CJK UNIFIED IDEOGRAPH-#28E0B, IRGKangXi=1343.121, RSKangXi=169.12
28E0C CJK UNIFIED IDEOGRAPH-#28E0C, IRGKangXi=1343.121, RSKangXi=169.12
28E0D CJK UNIFIED IDEOGRAPH-#28E0D, IRGKangXi=1343.121, RSKangXi=169.14
28E0E CJK UNIFIED IDEOGRAPH-#28E0E, IRGKangXi=1343.121, RSKangXi=169.17
28E0F CJK UNIFIED IDEOGRAPH-#28E0F, IRGKangXi=1345.030, RSKangXi=170.0
28E10 CJK UNIFIED IDEOGRAPH-#28E10, IRGKangXi=1345.050, RSKangXi=170.2
28E11 CJK UNIFIED IDEOGRAPH-#28E11, IRGKangXi=1345.070, RSKangXi=170.2
28E12 CJK UNIFIED IDEOGRAPH-#28E12, IRGKangXi=1345.090, RSKangXi=170.2
28E13 CJK UNIFIED IDEOGRAPH-#28E13, IRGKangXi=1345.100, RSKangXi=170.2
28E14 CJK UNIFIED IDEOGRAPH-#28E14, IRGKangXi=1345.120, RSKangXi=170.2
28E15 CJK UNIFIED IDEOGRAPH-#28E15, IRGKangXi=1345.121, RSKangXi=170.2
28E16 CJK UNIFIED IDEOGRAPH-#28E16, IRGKangXi=1345.130, RSKangXi=170.3
28E17 CJK UNIFIED IDEOGRAPH-#28E17, IRGKangXi=1345.170, RSKangXi=170.3
28E18 CJK UNIFIED IDEOGRAPH-#28E18, IRGKangXi=1346.030, RSKangXi=170.3
28E19 CJK UNIFIED IDEOGRAPH-#28E19, IRGKangXi=1346.031, RSKangXi=170.3
28E1A CJK UNIFIED IDEOGRAPH-#28E1A, IRGKangXi=1346.040, RSKangXi=170.4, Def{series, rank, grade}
28E1B CJK UNIFIED IDEOGRAPH-#28E1B, IRGKangXi=1346.090, RSKangXi=170.4
28E1C CJK UNIFIED IDEOGRAPH-#28E1C, IRGKangXi=1346.120, RSKangXi=170.4
28E1D CJK UNIFIED IDEOGRAPH-#28E1D, IRGKangXi=1347.020, RSKangXi=170.4
28E1E CJK UNIFIED IDEOGRAPH-#28E1E, IRGKangXi=1347.060, RSKangXi=170.4
28E1F CJK UNIFIED IDEOGRAPH-#28E1F, IRGKangXi=1347.081, RSKangXi=170.4
28E20 CJK UNIFIED IDEOGRAPH-#28E20, IRGKangXi=1347.081, RSKangXi=170.4
28E21 CJK UNIFIED IDEOGRAPH-#28E21, IRGKangXi=1347.081, RSKangXi=170.4
28E22 CJK UNIFIED IDEOGRAPH-#28E22, IRGKangXi=1347.081, RSKangXi=170.4
28E23 CJK UNIFIED IDEOGRAPH-#28E23, IRGKangXi=1347.081, RSKangXi=170.4
28E24 CJK UNIFIED IDEOGRAPH-#28E24, IRGKangXi=1347.081, RSKangXi=170.4
28E25 CJK UNIFIED IDEOGRAPH-#28E25, IRGKangXi=1347.081, RSKangXi=170.4
28E26 CJK UNIFIED IDEOGRAPH-#28E26, IRGKangXi=1347.081, RSKangXi=170.4
28E27 CJK UNIFIED IDEOGRAPH-#28E27, IRGKangXi=1347.081, RSKangXi=170.4
28E28 CJK UNIFIED IDEOGRAPH-#28E28, IRGKangXi=1347.081, RSKangXi=170.4
28E29 CJK UNIFIED IDEOGRAPH-#28E29, IRGKangXi=1347.081, RSKangXi=170.4
28E2A CJK UNIFIED IDEOGRAPH-#28E2A, IRGKangXi=1347.100, RSKangXi=170.5
28E2B CJK UNIFIED IDEOGRAPH-#28E2B, IRGKangXi=1347.110, RSKangXi=170.5
28E2C CJK UNIFIED IDEOGRAPH-#28E2C, IRGKangXi=1347.140, RSKangXi=170.5, Def{battle-field, battle array}
28E2D CJK UNIFIED IDEOGRAPH-#28E2D, IRGKangXi=1347.150, RSKangXi=170.5
28E2E CJK UNIFIED IDEOGRAPH-#28E2E, IRGKangXi=1348.030, RSKangXi=170.5
28E2F CJK UNIFIED IDEOGRAPH-#28E2F, IRGKangXi=1348.050, RSKangXi=170.5
28E30 CJK UNIFIED IDEOGRAPH-#28E30, IRGKangXi=1348.090, RSKangXi=170.5
28E31 CJK UNIFIED IDEOGRAPH-#28E31, IRGKangXi=1349.020, RSKangXi=170.5
28E32 CJK UNIFIED IDEOGRAPH-#28E32, IRGKangXi=1349.040, RSKangXi=170.5
28E33 CJK UNIFIED IDEOGRAPH-#28E33, IRGKangXi=1349.050, RSKangXi=170.5
28E34 CJK UNIFIED IDEOGRAPH-#28E34, IRGKangXi=1349.051, RSKangXi=170.5
28E35 CJK UNIFIED IDEOGRAPH-#28E35, IRGKangXi=1349.051, RSKangXi=170.5
28E36 CJK UNIFIED IDEOGRAPH-#28E36, IRGKangXi=1349.051, RSKangXi=170.5
28E37 CJK UNIFIED IDEOGRAPH-#28E37, IRGKangXi=1349.051, RSKangXi=170.5
28E38 CJK UNIFIED IDEOGRAPH-#28E38, IRGKangXi=1349.051, RSKangXi=170.5
28E39 CJK UNIFIED IDEOGRAPH-#28E39, IRGKangXi=1349.051, RSKangXi=170.5
28E3A CJK UNIFIED IDEOGRAPH-#28E3A, IRGKangXi=1349.051, RSKangXi=170.5
28E3B CJK UNIFIED IDEOGRAPH-#28E3B, IRGKangXi=1349.051, RSKangXi=170.5
28E3C CJK UNIFIED IDEOGRAPH-#28E3C, IRGKangXi=1349.051, RSKangXi=170.5
28E3D CJK UNIFIED IDEOGRAPH-#28E3D, IRGKangXi=1349.051, RSKangXi=170.5
28E3E CJK UNIFIED IDEOGRAPH-#28E3E, IRGKangXi=1349.051, RSKangXi=170.5
28E3F CJK UNIFIED IDEOGRAPH-#28E3F, IRGKangXi=1349.051, RSKangXi=170.5
28E40 CJK UNIFIED IDEOGRAPH-#28E40, IRGKangXi=1349.051, RSKangXi=170.5
28E41 CJK UNIFIED IDEOGRAPH-#28E41, IRGKangXi=1349.100, RSKangXi=170.6
28E42 CJK UNIFIED IDEOGRAPH-#28E42, IRGKangXi=1349.110, RSKangXi=170.6
28E43 CJK UNIFIED IDEOGRAPH-#28E43, IRGKangXi=1350.040, RSKangXi=170.6
28E44 CJK UNIFIED IDEOGRAPH-#28E44, IRGKangXi=1350.050, RSKangXi=170.6
28E45 CJK UNIFIED IDEOGRAPH-#28E45, IRGKangXi=1350.060, RSKangXi=170.6
28E46 CJK UNIFIED IDEOGRAPH-#28E46, IRGKangXi=1350.140, RSKangXi=170.6
28E47 CJK UNIFIED IDEOGRAPH-#28E47, IRGKangXi=1350.150, RSKangXi=170.6
28E48 CJK UNIFIED IDEOGRAPH-#28E48, IRGKangXi=1350.160, RSKangXi=170.6
28E49 CJK UNIFIED IDEOGRAPH-#28E49, IRGKangXi=1350.170, RSKangXi=170.6
28E4A CJK UNIFIED IDEOGRAPH-#28E4A, IRGKangXi=1350.180, RSKangXi=170.6
28E4B CJK UNIFIED IDEOGRAPH-#28E4B, IRGKangXi=1350.190, RSKangXi=170.6
28E4C CJK UNIFIED IDEOGRAPH-#28E4C, IRGKangXi=1350.200, RSKangXi=170.6
28E4D CJK UNIFIED IDEOGRAPH-#28E4D, IRGKangXi=1350.201, RSKangXi=170.6
28E4E CJK UNIFIED IDEOGRAPH-#28E4E, IRGKangXi=1350.201, RSKangXi=170.6
28E4F CJK UNIFIED IDEOGRAPH-#28E4F, IRGKangXi=1350.201, RSKangXi=170.6
28E50 CJK UNIFIED IDEOGRAPH-#28E50, IRGKangXi=1350.201, RSKangXi=170.6
28E51 CJK UNIFIED IDEOGRAPH-#28E51, IRGKangXi=1350.201, RSKangXi=170.6
28E52 CJK UNIFIED IDEOGRAPH-#28E52, IRGKangXi=1350.201, RSKangXi=170.6
28E53 CJK UNIFIED IDEOGRAPH-#28E53, IRGKangXi=1350.201, RSKangXi=170.6
28E54 CJK UNIFIED IDEOGRAPH-#28E54, IRGKangXi=1350.201, RSKangXi=170.6
28E55 CJK UNIFIED IDEOGRAPH-#28E55, IRGKangXi=1350.201, RSKangXi=170.6
28E56 CJK UNIFIED IDEOGRAPH-#28E56, IRGKangXi=1350.201, RSKangXi=170.6
28E57 CJK UNIFIED IDEOGRAPH-#28E57, IRGKangXi=1350.201, RSKangXi=170.6
28E58 CJK UNIFIED IDEOGRAPH-#28E58, IRGKangXi=1350.210, RSKangXi=170.7
28E59 CJK UNIFIED IDEOGRAPH-#28E59, IRGKangXi=1351.030, RSKangXi=170.7
28E5A CJK UNIFIED IDEOGRAPH-#28E5A, IRGKangXi=1351.040, RSKangXi=170.7
28E5B CJK UNIFIED IDEOGRAPH-#28E5B, IRGKangXi=1351.080, RSKangXi=170.7
28E5C CJK UNIFIED IDEOGRAPH-#28E5C, IRGKangXi=1352.010, RSKangXi=170.7
28E5D CJK UNIFIED IDEOGRAPH-#28E5D, IRGKangXi=1352.070, RSKangXi=170.7
28E5E CJK UNIFIED IDEOGRAPH-#28E5E, IRGKangXi=1352.090, RSKangXi=170.7
28E5F CJK UNIFIED IDEOGRAPH-#28E5F, IRGKangXi=1352.100, RSKangXi=170.7
28E60 CJK UNIFIED IDEOGRAPH-#28E60, IRGKangXi=1352.110, RSKangXi=170.7
28E61 CJK UNIFIED IDEOGRAPH-#28E61, IRGKangXi=1352.120, RSKangXi=170.7
28E62 CJK UNIFIED IDEOGRAPH-#28E62, IRGKangXi=1352.130, RSKangXi=170.7
28E63 CJK UNIFIED IDEOGRAPH-#28E63, IRGKangXi=1352.140, RSKangXi=170.7
28E64 CJK UNIFIED IDEOGRAPH-#28E64, IRGKangXi=1352.141, RSKangXi=170.7
28E65 CJK UNIFIED IDEOGRAPH-#28E65, IRGKangXi=1352.141, RSKangXi=170.7
28E66 CJK UNIFIED IDEOGRAPH-#28E66, IRGKangXi=1352.141, RSKangXi=170.7
28E67 CJK UNIFIED IDEOGRAPH-#28E67, IRGKangXi=1352.141, RSKangXi=170.7
28E68 CJK UNIFIED IDEOGRAPH-#28E68, IRGKangXi=1352.141, RSKangXi=170.7
28E69 CJK UNIFIED IDEOGRAPH-#28E69, IRGKangXi=1352.141, RSKangXi=170.7
28E6A CJK UNIFIED IDEOGRAPH-#28E6A, IRGKangXi=1352.141, RSKangXi=170.7
28E6B CJK UNIFIED IDEOGRAPH-#28E6B, IRGKangXi=1352.141, RSKangXi=170.7
28E6C CJK UNIFIED IDEOGRAPH-#28E6C, IRGKangXi=1352.141, RSKangXi=170.7
28E6D CJK UNIFIED IDEOGRAPH-#28E6D, IRGKangXi=1352.141, RSKangXi=170.7
28E6E CJK UNIFIED IDEOGRAPH-#28E6E, IRGKangXi=1352.141, RSKangXi=170.7
28E6F CJK UNIFIED IDEOGRAPH-#28E6F, IRGKangXi=1352.141, RSKangXi=170.7
28E70 CJK UNIFIED IDEOGRAPH-#28E70, IRGKangXi=1352.141, RSKangXi=170.7
28E71 CJK UNIFIED IDEOGRAPH-#28E71, IRGKangXi=1352.141, RSKangXi=170.7
28E72 CJK UNIFIED IDEOGRAPH-#28E72, IRGKangXi=1352.141, RSKangXi=170.7
28E73 CJK UNIFIED IDEOGRAPH-#28E73, IRGKangXi=1352.141, RSKangXi=170.7
28E74 CJK UNIFIED IDEOGRAPH-#28E74, IRGKangXi=1352.141, RSKangXi=39.7
28E75 CJK UNIFIED IDEOGRAPH-#28E75, IRGKangXi=1352.170, RSKangXi=170.8
28E76 CJK UNIFIED IDEOGRAPH-#28E76, IRGKangXi=1352.200, RSKangXi=170.8
28E77 CJK UNIFIED IDEOGRAPH-#28E77, IRGKangXi=1352.210, RSKangXi=170.8
28E78 CJK UNIFIED IDEOGRAPH-#28E78, IRGKangXi=1352.220, RSKangXi=170.8
28E79 CJK UNIFIED IDEOGRAPH-#28E79, IRGKangXi=1353.040, RSKangXi=170.8
28E7A CJK UNIFIED IDEOGRAPH-#28E7A, IRGKangXi=1353.130, RSKangXi=170.8
28E7B CJK UNIFIED IDEOGRAPH-#28E7B, IRGKangXi=1353.180, RSKangXi=170.8
28E7C CJK UNIFIED IDEOGRAPH-#28E7C, IRGKangXi=1354.010, RSKangXi=170.8
28E7D CJK UNIFIED IDEOGRAPH-#28E7D, IRGKangXi=1354.050, RSKangXi=170.8
28E7E CJK UNIFIED IDEOGRAPH-#28E7E, IRGKangXi=1354.110, RSKangXi=170.8
28E7F CJK UNIFIED IDEOGRAPH-#28E7F, IRGKangXi=1355.030, RSKangXi=170.8
28E80 CJK UNIFIED IDEOGRAPH-#28E80, IRGKangXi=1355.040, RSKangXi=170.8
28E81 CJK UNIFIED IDEOGRAPH-#28E81, IRGKangXi=1355.050, RSKangXi=170.8
28E82 CJK UNIFIED IDEOGRAPH-#28E82, IRGKangXi=1355.060, RSKangXi=170.8
28E83 CJK UNIFIED IDEOGRAPH-#28E83, IRGKangXi=1355.070, RSKangXi=170.8
28E84 CJK UNIFIED IDEOGRAPH-#28E84, IRGKangXi=1355.080, RSKangXi=170.8
28E85 CJK UNIFIED IDEOGRAPH-#28E85, IRGKangXi=1355.090, RSKangXi=170.8
28E86 CJK UNIFIED IDEOGRAPH-#28E86, IRGKangXi=1355.110, RSKangXi=170.8
28E87 CJK UNIFIED IDEOGRAPH-#28E87, IRGKangXi=1355.111, RSKangXi=170.8
28E88 CJK UNIFIED IDEOGRAPH-#28E88, IRGKangXi=1355.111, RSKangXi=170.8
28E89 CJK UNIFIED IDEOGRAPH-#28E89, IRGKangXi=1355.111, RSKangXi=170.8
28E8A CJK UNIFIED IDEOGRAPH-#28E8A, IRGKangXi=1355.111, RSKangXi=170.8
28E8B CJK UNIFIED IDEOGRAPH-#28E8B, IRGKangXi=1355.111, RSKangXi=170.8
28E8C CJK UNIFIED IDEOGRAPH-#28E8C, IRGKangXi=1355.111, RSKangXi=170.8
28E8D CJK UNIFIED IDEOGRAPH-#28E8D, IRGKangXi=1355.111, RSKangXi=170.8
28E8E CJK UNIFIED IDEOGRAPH-#28E8E, IRGKangXi=1355.111, RSKangXi=170.8
28E8F CJK UNIFIED IDEOGRAPH-#28E8F, IRGKangXi=1355.111, RSKangXi=170.8
28E90 CJK UNIFIED IDEOGRAPH-#28E90, IRGKangXi=1355.111, RSKangXi=170.8
28E91 CJK UNIFIED IDEOGRAPH-#28E91, IRGKangXi=1355.111, RSKangXi=170.8
28E92 CJK UNIFIED IDEOGRAPH-#28E92, IRGKangXi=1355.111, RSKangXi=170.8
28E93 CJK UNIFIED IDEOGRAPH-#28E93, IRGKangXi=1355.111, RSKangXi=170.8
28E94 CJK UNIFIED IDEOGRAPH-#28E94, IRGKangXi=1355.111, RSKangXi=170.8
28E95 CJK UNIFIED IDEOGRAPH-#28E95, IRGKangXi=1355.111, RSKangXi=170.8
28E96 CJK UNIFIED IDEOGRAPH-#28E96, IRGKangXi=1355.111, RSKangXi=170.8
28E97 CJK UNIFIED IDEOGRAPH-#28E97, IRGKangXi=1355.111, RSKangXi=170.8
28E98 CJK UNIFIED IDEOGRAPH-#28E98, IRGKangXi=1355.111, RSKangXi=170.8
28E99 CJK UNIFIED IDEOGRAPH-#28E99, IRGKangXi=1355.111, RSKangXi=170.8
28E9A CJK UNIFIED IDEOGRAPH-#28E9A, IRGKangXi=1355.111, RSKangXi=170.8
28E9B CJK UNIFIED IDEOGRAPH-#28E9B, IRGKangXi=1355.111, RSKangXi=170.8
28E9C CJK UNIFIED IDEOGRAPH-#28E9C, IRGKangXi=1355.111, RSKangXi=170.8
28E9D CJK UNIFIED IDEOGRAPH-#28E9D, IRGKangXi=1355.111, RSKangXi=170.8
28E9E CJK UNIFIED IDEOGRAPH-#28E9E, IRGKangXi=1355.111, RSKangXi=170.9
28E9F CJK UNIFIED IDEOGRAPH-#28E9F, IRGKangXi=1355.120, RSKangXi=170.9
28EA0 CJK UNIFIED IDEOGRAPH-#28EA0, IRGKangXi=1356.040, RSKangXi=170.9
28EA1 CJK UNIFIED IDEOGRAPH-#28EA1, IRGKangXi=1356.050, RSKangXi=170.9
28EA2 CJK UNIFIED IDEOGRAPH-#28EA2, IRGKangXi=1356.080, RSKangXi=170.9
28EA3 CJK UNIFIED IDEOGRAPH-#28EA3, IRGKangXi=1356.090, RSKangXi=170.9
28EA4 CJK UNIFIED IDEOGRAPH-#28EA4, IRGKangXi=1356.110, RSKangXi=170.9
28EA5 CJK UNIFIED IDEOGRAPH-#28EA5, IRGKangXi=1356.120, RSKangXi=170.9
28EA6 CJK UNIFIED IDEOGRAPH-#28EA6, IRGKangXi=1356.140, RSKangXi=170.9
28EA7 CJK UNIFIED IDEOGRAPH-#28EA7, IRGKangXi=1356.180, RSKangXi=170.9
28EA8 CJK UNIFIED IDEOGRAPH-#28EA8, IRGKangXi=1356.200, RSKangXi=170.9
28EA9 CJK UNIFIED IDEOGRAPH-#28EA9, IRGKangXi=1356.210, RSKangXi=170.9
28EAA CJK UNIFIED IDEOGRAPH-#28EAA, IRGKangXi=1357.070, RSKangXi=170.9
28EAB CJK UNIFIED IDEOGRAPH-#28EAB, IRGKangXi=1357.110, RSKangXi=170.9
28EAC CJK UNIFIED IDEOGRAPH-#28EAC, IRGKangXi=1357.120, RSKangXi=170.9
28EAD CJK UNIFIED IDEOGRAPH-#28EAD, IRGKangXi=1357.130, RSKangXi=170.9
28EAE CJK UNIFIED IDEOGRAPH-#28EAE, IRGKangXi=1357.140, RSKangXi=170.9
28EAF CJK UNIFIED IDEOGRAPH-#28EAF, IRGKangXi=1357.150, RSKangXi=170.9
28EB0 CJK UNIFIED IDEOGRAPH-#28EB0, IRGKangXi=1357.151, RSKangXi=170.9
28EB1 CJK UNIFIED IDEOGRAPH-#28EB1, IRGKangXi=1357.151, RSKangXi=170.9
28EB2 CJK UNIFIED IDEOGRAPH-#28EB2, IRGKangXi=1357.151, RSKangXi=170.9
28EB3 CJK UNIFIED IDEOGRAPH-#28EB3, IRGKangXi=1357.151, RSKangXi=170.9
28EB4 CJK UNIFIED IDEOGRAPH-#28EB4, IRGKangXi=1357.151, RSKangXi=170.9
28EB5 CJK UNIFIED IDEOGRAPH-#28EB5, IRGKangXi=1357.151, RSKangXi=170.9
28EB6 CJK UNIFIED IDEOGRAPH-#28EB6, IRGKangXi=1357.151, RSKangXi=170.9
28EB7 CJK UNIFIED IDEOGRAPH-#28EB7, IRGKangXi=1357.151, RSKangXi=170.9
28EB8 CJK UNIFIED IDEOGRAPH-#28EB8, IRGKangXi=1357.151, RSKangXi=170.9
28EB9 CJK UNIFIED IDEOGRAPH-#28EB9, IRGKangXi=1357.151, RSKangXi=170.9, Def{mournful, narrow; used for U+6E6B 湫}
28EBA CJK UNIFIED IDEOGRAPH-#28EBA, IRGKangXi=1357.151, RSKangXi=170.9
28EBB CJK UNIFIED IDEOGRAPH-#28EBB, IRGKangXi=1357.151, RSKangXi=170.9
28EBC CJK UNIFIED IDEOGRAPH-#28EBC, IRGKangXi=1357.151, RSKangXi=170.9
28EBD CJK UNIFIED IDEOGRAPH-#28EBD, IRGKangXi=1357.151, RSKangXi=170.9
28EBE CJK UNIFIED IDEOGRAPH-#28EBE, IRGKangXi=1357.151, RSKangXi=170.9
28EBF CJK UNIFIED IDEOGRAPH-#28EBF, IRGKangXi=1357.151, RSKangXi=170.9
28EC0 CJK UNIFIED IDEOGRAPH-#28EC0, IRGKangXi=1357.160, RSKangXi=170.10
28EC1 CJK UNIFIED IDEOGRAPH-#28EC1, IRGKangXi=1358.020, RSKangXi=170.10
28EC2 CJK UNIFIED IDEOGRAPH-#28EC2, IRGKangXi=1358.040, RSKangXi=170.10
28EC3 CJK UNIFIED IDEOGRAPH-#28EC3, IRGKangXi=1358.080, RSKangXi=170.10
28EC4 CJK UNIFIED IDEOGRAPH-#28EC4, IRGKangXi=1358.090, RSKangXi=170.10
28EC5 CJK UNIFIED IDEOGRAPH-#28EC5, IRGKangXi=1358.120, RSKangXi=170.10
28EC6 CJK UNIFIED IDEOGRAPH-#28EC6, IRGKangXi=1358.130, RSKangXi=170.10
28EC7 CJK UNIFIED IDEOGRAPH-#28EC7, IRGKangXi=1358.140, RSKangXi=170.10
28EC8 CJK UNIFIED IDEOGRAPH-#28EC8, IRGKangXi=1358.150, RSKangXi=170.10
28EC9 CJK UNIFIED IDEOGRAPH-#28EC9, IRGKangXi=1358.180, RSKangXi=170.10
28ECA CJK UNIFIED IDEOGRAPH-#28ECA, IRGKangXi=1358.230, RSKangXi=170.10
28ECB CJK UNIFIED IDEOGRAPH-#28ECB, IRGKangXi=1359.030, RSKangXi=170.10
28ECC CJK UNIFIED IDEOGRAPH-#28ECC, IRGKangXi=1359.040, RSKangXi=170.10
28ECD CJK UNIFIED IDEOGRAPH-#28ECD, IRGKangXi=1359.050, RSKangXi=170.10
28ECE CJK UNIFIED IDEOGRAPH-#28ECE, IRGKangXi=1359.060, RSKangXi=170.10
28ECF CJK UNIFIED IDEOGRAPH-#28ECF, IRGKangXi=1359.070, RSKangXi=170.10
28ED0 CJK UNIFIED IDEOGRAPH-#28ED0, IRGKangXi=1359.080, RSKangXi=170.10
28ED1 CJK UNIFIED IDEOGRAPH-#28ED1, IRGKangXi=1359.090, RSKangXi=170.10
28ED2 CJK UNIFIED IDEOGRAPH-#28ED2, IRGKangXi=1359.100, RSKangXi=170.10
28ED3 CJK UNIFIED IDEOGRAPH-#28ED3, IRGKangXi=1359.110, RSKangXi=170.10
28ED4 CJK UNIFIED IDEOGRAPH-#28ED4, IRGKangXi=1359.120, RSKangXi=170.10
28ED5 CJK UNIFIED IDEOGRAPH-#28ED5, IRGKangXi=1359.130, RSKangXi=170.10
28ED6 CJK UNIFIED IDEOGRAPH-#28ED6, IRGKangXi=1359.140, RSKangXi=170.10
28ED7 CJK UNIFIED IDEOGRAPH-#28ED7, IRGKangXi=1359.150, RSKangXi=170.10
28ED8 CJK UNIFIED IDEOGRAPH-#28ED8, IRGKangXi=1359.160, RSKangXi=170.10
28ED9 CJK UNIFIED IDEOGRAPH-#28ED9, IRGKangXi=1359.161, RSKangXi=170.10
28EDA CJK UNIFIED IDEOGRAPH-#28EDA, IRGKangXi=1359.161, RSKangXi=170.10
28EDB CJK UNIFIED IDEOGRAPH-#28EDB, IRGKangXi=1359.161, RSKangXi=170.10
28EDC CJK UNIFIED IDEOGRAPH-#28EDC, IRGKangXi=1359.161, RSKangXi=170.10
28EDD CJK UNIFIED IDEOGRAPH-#28EDD, IRGKangXi=1359.161, RSKangXi=170.10
28EDE CJK UNIFIED IDEOGRAPH-#28EDE, IRGKangXi=1359.161, RSKangXi=170.10
28EDF CJK UNIFIED IDEOGRAPH-#28EDF, IRGKangXi=1359.161, RSKangXi=170.10
28EE0 CJK UNIFIED IDEOGRAPH-#28EE0, IRGKangXi=1359.161, RSKangXi=170.10
28EE1 CJK UNIFIED IDEOGRAPH-#28EE1, IRGKangXi=1359.161, RSKangXi=170.10
28EE2 CJK UNIFIED IDEOGRAPH-#28EE2, IRGKangXi=1359.161, RSKangXi=170.10
28EE3 CJK UNIFIED IDEOGRAPH-#28EE3, IRGKangXi=1359.161, RSKangXi=170.10
28EE4 CJK UNIFIED IDEOGRAPH-#28EE4, IRGKangXi=1359.161, RSKangXi=170.10
28EE5 CJK UNIFIED IDEOGRAPH-#28EE5, IRGKangXi=1359.161, RSKangXi=170.10
28EE6 CJK UNIFIED IDEOGRAPH-#28EE6, IRGKangXi=1359.161, RSKangXi=170.10
28EE7 CJK UNIFIED IDEOGRAPH-#28EE7, IRGKangXi=1359.161, RSKangXi=170.10
28EE8 CJK UNIFIED IDEOGRAPH-#28EE8, IRGKangXi=1359.161, RSKangXi=170.10
28EE9 CJK UNIFIED IDEOGRAPH-#28EE9, IRGKangXi=1359.161, RSKangXi=170.10
28EEA CJK UNIFIED IDEOGRAPH-#28EEA, IRGKangXi=1359.161, RSKangXi=170.10
28EEB CJK UNIFIED IDEOGRAPH-#28EEB, IRGKangXi=1359.161, RSKangXi=170.10
28EEC CJK UNIFIED IDEOGRAPH-#28EEC, IRGKangXi=1359.161, RSKangXi=170.10
28EED CJK UNIFIED IDEOGRAPH-#28EED, IRGKangXi=1359.161, RSKangXi=170.10
28EEE CJK UNIFIED IDEOGRAPH-#28EEE, IRGKangXi=1359.161, RSKangXi=170.11
28EEF CJK UNIFIED IDEOGRAPH-#28EEF, IRGKangXi=1359.161, RSKangXi=170.11
28EF0 CJK UNIFIED IDEOGRAPH-#28EF0, IRGKangXi=1359.161, RSKangXi=170.11
28EF1 CJK UNIFIED IDEOGRAPH-#28EF1, IRGKangXi=1359.170, RSKangXi=170.11
28EF2 CJK UNIFIED IDEOGRAPH-#28EF2, IRGKangXi=1359.180, RSKangXi=170.11, Def{a crack, fissure}
28EF3 CJK UNIFIED IDEOGRAPH-#28EF3, IRGKangXi=1359.190, RSKangXi=170.11
28EF4 CJK UNIFIED IDEOGRAPH-#28EF4, IRGKangXi=1359.200, RSKangXi=170.11
28EF5 CJK UNIFIED IDEOGRAPH-#28EF5, IRGKangXi=1359.210, RSKangXi=170.11
28EF6 CJK UNIFIED IDEOGRAPH-#28EF6, IRGKangXi=1359.220, RSKangXi=170.11, Def{a crevise, fissure; time, leisure; unpreparedness}
28EF7 CJK UNIFIED IDEOGRAPH-#28EF7, IRGKangXi=1359.230, RSKangXi=170.11
28EF8 CJK UNIFIED IDEOGRAPH-#28EF8, IRGKangXi=1359.240, RSKangXi=170.11
28EF9 CJK UNIFIED IDEOGRAPH-#28EF9, IRGKangXi=1359.260, RSKangXi=170.11
28EFA CJK UNIFIED IDEOGRAPH-#28EFA, IRGKangXi=1359.300, RSKangXi=170.11
28EFB CJK UNIFIED IDEOGRAPH-#28EFB, IRGKangXi=1360.010, RSKangXi=170.11
28EFC CJK UNIFIED IDEOGRAPH-#28EFC, IRGKangXi=1360.050, RSKangXi=170.11
28EFD CJK UNIFIED IDEOGRAPH-#28EFD, IRGKangXi=1360.080, RSKangXi=170.11
28EFE CJK UNIFIED IDEOGRAPH-#28EFE, IRGKangXi=1360.100, RSKangXi=170.11
28EFF CJK UNIFIED IDEOGRAPH-#28EFF, IRGKangXi=1360.110, RSKangXi=170.11
28F00 CJK UNIFIED IDEOGRAPH-#28F00, IRGKangXi=1360.111, RSKangXi=170.11
28F01 CJK UNIFIED IDEOGRAPH-#28F01, IRGKangXi=1360.111, RSKangXi=170.11
28F02 CJK UNIFIED IDEOGRAPH-#28F02, IRGKangXi=1360.111, RSKangXi=170.11
28F03 CJK UNIFIED IDEOGRAPH-#28F03, IRGKangXi=1360.111, RSKangXi=170.11
28F04 CJK UNIFIED IDEOGRAPH-#28F04, IRGKangXi=1360.111, RSKangXi=170.11
28F05 CJK UNIFIED IDEOGRAPH-#28F05, IRGKangXi=1360.111, RSKangXi=170.11
28F06 CJK UNIFIED IDEOGRAPH-#28F06, IRGKangXi=1360.111, RSKangXi=170.11
28F07 CJK UNIFIED IDEOGRAPH-#28F07, IRGKangXi=1360.111, RSKangXi=170.11
28F08 CJK UNIFIED IDEOGRAPH-#28F08, IRGKangXi=1360.111, RSKangXi=170.11
28F09 CJK UNIFIED IDEOGRAPH-#28F09, IRGKangXi=1360.111, RSKangXi=170.11
28F0A CJK UNIFIED IDEOGRAPH-#28F0A, IRGKangXi=1360.120, RSKangXi=170.12
28F0B CJK UNIFIED IDEOGRAPH-#28F0B, IRGKangXi=1360.150, RSKangXi=170.12
28F0C CJK UNIFIED IDEOGRAPH-#28F0C, IRGKangXi=1360.160, RSKangXi=170.12
28F0D CJK UNIFIED IDEOGRAPH-#28F0D, IRGKangXi=1360.170, RSKangXi=170.12
28F0E CJK UNIFIED IDEOGRAPH-#28F0E, IRGKangXi=1360.200, RSKangXi=170.12
28F0F CJK UNIFIED IDEOGRAPH-#28F0F, IRGKangXi=1360.210, RSKangXi=170.12
28F10 CJK UNIFIED IDEOGRAPH-#28F10, IRGKangXi=1360.230, RSKangXi=170.12
28F11 CJK UNIFIED IDEOGRAPH-#28F11, IRGKangXi=1360.260, RSKangXi=170.12
28F12 CJK UNIFIED IDEOGRAPH-#28F12, IRGKangXi=1360.270, RSKangXi=170.12
28F13 CJK UNIFIED IDEOGRAPH-#28F13, IRGKangXi=1360.280, RSKangXi=170.12
28F14 CJK UNIFIED IDEOGRAPH-#28F14, IRGKangXi=1360.290, RSKangXi=170.12
28F15 CJK UNIFIED IDEOGRAPH-#28F15, IRGKangXi=1360.300, RSKangXi=170.12
28F16 CJK UNIFIED IDEOGRAPH-#28F16, IRGKangXi=1360.310, RSKangXi=170.12
28F17 CJK UNIFIED IDEOGRAPH-#28F17, IRGKangXi=1360.320, RSKangXi=170.12
28F18 CJK UNIFIED IDEOGRAPH-#28F18, IRGKangXi=1360.330, RSKangXi=170.12
28F19 CJK UNIFIED IDEOGRAPH-#28F19, IRGKangXi=1360.340, RSKangXi=170.12
28F1A CJK UNIFIED IDEOGRAPH-#28F1A, IRGKangXi=1360.341, RSKangXi=170.12
28F1B CJK UNIFIED IDEOGRAPH-#28F1B, IRGKangXi=1360.341, RSKangXi=170.12
28F1C CJK UNIFIED IDEOGRAPH-#28F1C, IRGKangXi=1360.341, RSKangXi=170.12
28F1D CJK UNIFIED IDEOGRAPH-#28F1D, IRGKangXi=1360.341, RSKangXi=170.12
28F1E CJK UNIFIED IDEOGRAPH-#28F1E, IRGKangXi=1360.341, RSKangXi=170.12
28F1F CJK UNIFIED IDEOGRAPH-#28F1F, IRGKangXi=1360.341, RSKangXi=170.12
28F20 CJK UNIFIED IDEOGRAPH-#28F20, IRGKangXi=1360.341, RSKangXi=170.12
28F21 CJK UNIFIED IDEOGRAPH-#28F21, IRGKangXi=1360.341, RSKangXi=170.12
28F22 CJK UNIFIED IDEOGRAPH-#28F22, IRGKangXi=1360.341, RSKangXi=170.12
28F23 CJK UNIFIED IDEOGRAPH-#28F23, IRGKangXi=1360.341, RSKangXi=170.12
28F24 CJK UNIFIED IDEOGRAPH-#28F24, IRGKangXi=1360.341, RSKangXi=170.12
28F25 CJK UNIFIED IDEOGRAPH-#28F25, IRGKangXi=1360.341, RSKangXi=170.12
28F26 CJK UNIFIED IDEOGRAPH-#28F26, IRGKangXi=1360.341, RSKangXi=170.12
28F27 CJK UNIFIED IDEOGRAPH-#28F27, IRGKangXi=1360.341, RSKangXi=170.12
28F28 CJK UNIFIED IDEOGRAPH-#28F28, IRGKangXi=1360.341, RSKangXi=170.12
28F29 CJK UNIFIED IDEOGRAPH-#28F29, IRGKangXi=1360.341, RSKangXi=170.12
28F2A CJK UNIFIED IDEOGRAPH-#28F2A, IRGKangXi=1360.350, RSKangXi=170.13
28F2B CJK UNIFIED IDEOGRAPH-#28F2B, IRGKangXi=1360.360, RSKangXi=170.13
28F2C CJK UNIFIED IDEOGRAPH-#28F2C, IRGKangXi=1360.390, RSKangXi=170.13
28F2D CJK UNIFIED IDEOGRAPH-#28F2D, IRGKangXi=1360.410, RSKangXi=170.13
28F2E CJK UNIFIED IDEOGRAPH-#28F2E, IRGKangXi=1361.010, RSKangXi=170.13
28F2F CJK UNIFIED IDEOGRAPH-#28F2F, IRGKangXi=1361.090, RSKangXi=170.13
28F30 CJK UNIFIED IDEOGRAPH-#28F30, IRGKangXi=1362.010, RSKangXi=170.13
28F31 CJK UNIFIED IDEOGRAPH-#28F31, IRGKangXi=1362.030, RSKangXi=170.13
28F32 CJK UNIFIED IDEOGRAPH-#28F32, IRGKangXi=1362.031, RSKangXi=170.13
28F33 CJK UNIFIED IDEOGRAPH-#28F33, IRGKangXi=1362.031, RSKangXi=170.13
28F34 CJK UNIFIED IDEOGRAPH-#28F34, IRGKangXi=1362.031, RSKangXi=170.13
28F35 CJK UNIFIED IDEOGRAPH-#28F35, IRGKangXi=1362.031, RSKangXi=170.13
28F36 CJK UNIFIED IDEOGRAPH-#28F36, IRGKangXi=1362.031, RSKangXi=170.13
28F37 CJK UNIFIED IDEOGRAPH-#28F37, IRGKangXi=1362.031, RSKangXi=170.13
28F38 CJK UNIFIED IDEOGRAPH-#28F38, IRGKangXi=1362.031, RSKangXi=170.13
28F39 CJK UNIFIED IDEOGRAPH-#28F39, IRGKangXi=1362.031, RSKangXi=170.13
28F3A CJK UNIFIED IDEOGRAPH-#28F3A, IRGKangXi=1362.031, RSKangXi=170.13
28F3B CJK UNIFIED IDEOGRAPH-#28F3B, IRGKangXi=1362.031, RSKangXi=170.13
28F3C CJK UNIFIED IDEOGRAPH-#28F3C, IRGKangXi=1362.031, RSKangXi=170.13
28F3D CJK UNIFIED IDEOGRAPH-#28F3D, IRGKangXi=1362.031, RSKangXi=170.13
28F3E CJK UNIFIED IDEOGRAPH-#28F3E, IRGKangXi=1362.031, RSKangXi=170.13
28F3F CJK UNIFIED IDEOGRAPH-#28F3F, IRGKangXi=1362.040, RSKangXi=170.14
28F40 CJK UNIFIED IDEOGRAPH-#28F40, IRGKangXi=1362.070, RSKangXi=170.14
28F41 CJK UNIFIED IDEOGRAPH-#28F41, IRGKangXi=1362.090, RSKangXi=170.14
28F42 CJK UNIFIED IDEOGRAPH-#28F42, IRGKangXi=1362.140, RSKangXi=170.14
28F43 CJK UNIFIED IDEOGRAPH-#28F43, IRGKangXi=1362.180, RSKangXi=170.14
28F44 CJK UNIFIED IDEOGRAPH-#28F44, IRGKangXi=1362.190, RSKangXi=170.14
28F45 CJK UNIFIED IDEOGRAPH-#28F45, IRGKangXi=1362.191, RSKangXi=170.14
28F46 CJK UNIFIED IDEOGRAPH-#28F46, IRGKangXi=1362.191, RSKangXi=170.14
28F47 CJK UNIFIED IDEOGRAPH-#28F47, IRGKangXi=1362.191, RSKangXi=170.14
28F48 CJK UNIFIED IDEOGRAPH-#28F48, IRGKangXi=1362.191, RSKangXi=170.14
28F49 CJK UNIFIED IDEOGRAPH-#28F49, IRGKangXi=1362.191, RSKangXi=170.14
28F4A CJK UNIFIED IDEOGRAPH-#28F4A, IRGKangXi=1362.191, RSKangXi=170.14
28F4B CJK UNIFIED IDEOGRAPH-#28F4B, IRGKangXi=1362.191, RSKangXi=170.14
28F4C CJK UNIFIED IDEOGRAPH-#28F4C, IRGKangXi=1362.191, RSKangXi=170.14
28F4D CJK UNIFIED IDEOGRAPH-#28F4D, IRGKangXi=1362.200, RSKangXi=170.15
28F4E CJK UNIFIED IDEOGRAPH-#28F4E, IRGKangXi=1363.010, RSKangXi=170.15
28F4F CJK UNIFIED IDEOGRAPH-#28F4F, IRGKangXi=1363.020, RSKangXi=170.15
28F50 CJK UNIFIED IDEOGRAPH-#28F50, IRGKangXi=1363.030, RSKangXi=170.15
28F51 CJK UNIFIED IDEOGRAPH-#28F51, IRGKangXi=1363.040, RSKangXi=170.15
28F52 CJK UNIFIED IDEOGRAPH-#28F52, IRGKangXi=1363.041, RSKangXi=170.15
28F53 CJK UNIFIED IDEOGRAPH-#28F53, IRGKangXi=1363.041, RSKangXi=170.15
28F54 CJK UNIFIED IDEOGRAPH-#28F54, IRGKangXi=1363.041, RSKangXi=170.15
28F55 CJK UNIFIED IDEOGRAPH-#28F55, IRGKangXi=1363.041, RSKangXi=170.15
28F56 CJK UNIFIED IDEOGRAPH-#28F56, IRGKangXi=1363.050, RSKangXi=170.16
28F57 CJK UNIFIED IDEOGRAPH-#28F57, IRGKangXi=1363.060, RSKangXi=170.16
28F58 CJK UNIFIED IDEOGRAPH-#28F58, IRGKangXi=1363.090, RSKangXi=170.16
28F59 CJK UNIFIED IDEOGRAPH-#28F59, IRGKangXi=1363.100, RSKangXi=170.16
28F5A CJK UNIFIED IDEOGRAPH-#28F5A, IRGKangXi=1363.101, RSKangXi=170.16
28F5B CJK UNIFIED IDEOGRAPH-#28F5B, IRGKangXi=1363.101, RSKangXi=170.16
28F5C CJK UNIFIED IDEOGRAPH-#28F5C, IRGKangXi=1363.101, RSKangXi=170.16
28F5D CJK UNIFIED IDEOGRAPH-#28F5D, IRGKangXi=1363.101, RSKangXi=170.16
28F5E CJK UNIFIED IDEOGRAPH-#28F5E, IRGKangXi=1363.101, RSKangXi=170.16
28F5F CJK UNIFIED IDEOGRAPH-#28F5F, IRGKangXi=1363.101, RSKangXi=170.16
28F60 CJK UNIFIED IDEOGRAPH-#28F60, IRGKangXi=1363.101, RSKangXi=170.16
28F61 CJK UNIFIED IDEOGRAPH-#28F61, IRGKangXi=1363.130, RSKangXi=170.16
28F62 CJK UNIFIED IDEOGRAPH-#28F62, IRGKangXi=1363.131, RSKangXi=170.17
28F63 CJK UNIFIED IDEOGRAPH-#28F63, IRGKangXi=1363.131, RSKangXi=170.17
28F64 CJK UNIFIED IDEOGRAPH-#28F64, IRGKangXi=1363.131, RSKangXi=170.17
28F65 CJK UNIFIED IDEOGRAPH-#28F65, IRGKangXi=1363.131, RSKangXi=170.17
28F66 CJK UNIFIED IDEOGRAPH-#28F66, IRGKangXi=1363.140, RSKangXi=170.18
28F67 CJK UNIFIED IDEOGRAPH-#28F67, IRGKangXi=1363.160, RSKangXi=170.18
28F68 CJK UNIFIED IDEOGRAPH-#28F68, IRGKangXi=1363.170, RSKangXi=170.18
28F69 CJK UNIFIED IDEOGRAPH-#28F69, IRGKangXi=1363.180, RSKangXi=170.18
28F6A CJK UNIFIED IDEOGRAPH-#28F6A, IRGKangXi=1363.181, RSKangXi=170.18
28F6B CJK UNIFIED IDEOGRAPH-#28F6B, IRGKangXi=1363.181, RSKangXi=170.18
28F6C CJK UNIFIED IDEOGRAPH-#28F6C, IRGKangXi=1363.181, RSKangXi=170.19
28F6D CJK UNIFIED IDEOGRAPH-#28F6D, IRGKangXi=1363.181, RSKangXi=170.19
28F6E CJK UNIFIED IDEOGRAPH-#28F6E, IRGKangXi=1363.181, RSKangXi=170.20
28F6F CJK UNIFIED IDEOGRAPH-#28F6F, IRGKangXi=1363.181, RSKangXi=170.20
28F70 CJK UNIFIED IDEOGRAPH-#28F70, IRGKangXi=1363.190, RSKangXi=170.21
28F71 CJK UNIFIED IDEOGRAPH-#28F71, IRGKangXi=1363.191, RSKangXi=170.21
28F72 CJK UNIFIED IDEOGRAPH-#28F72, IRGKangXi=1363.200, RSKangXi=170.24
28F73 CJK UNIFIED IDEOGRAPH-#28F73, IRGKangXi=1363.201, RSKangXi=170.24
28F74 CJK UNIFIED IDEOGRAPH-#28F74, IRGKangXi=1363.210, RSKangXi=170.25
28F75 CJK UNIFIED IDEOGRAPH-#28F75, IRGKangXi=1363.211, RSKangXi=170.25
28F76 CJK UNIFIED IDEOGRAPH-#28F76, IRGKangXi=1363.230, RSKangXi=171.5
28F77 CJK UNIFIED IDEOGRAPH-#28F77, IRGKangXi=1363.231, RSKangXi=171.6
28F78 CJK UNIFIED IDEOGRAPH-#28F78, IRGKangXi=1363.240, RSKangXi=171.7
28F79 CJK UNIFIED IDEOGRAPH-#28F79, IRGKangXi=1363.250, RSKangXi=171.7
28F7A CJK UNIFIED IDEOGRAPH-#28F7A, IRGKangXi=1363.251, RSKangXi=171.7
28F7B CJK UNIFIED IDEOGRAPH-#28F7B, IRGKangXi=1363.251, RSKangXi=171.7
28F7C CJK UNIFIED IDEOGRAPH-#28F7C, IRGKangXi=1363.270, RSKangXi=171.8
28F7D CJK UNIFIED IDEOGRAPH-#28F7D, IRGKangXi=1363.280, RSKangXi=171.8
28F7E CJK UNIFIED IDEOGRAPH-#28F7E, IRGKangXi=1363.281, RSKangXi=171.8
28F7F CJK UNIFIED IDEOGRAPH-#28F7F, IRGKangXi=1363.290, RSKangXi=171.9
28F80 CJK UNIFIED IDEOGRAPH-#28F80, IRGKangXi=1364.010, RSKangXi=171.10
28F81 CJK UNIFIED IDEOGRAPH-#28F81, IRGKangXi=1364.020, RSKangXi=171.10
28F82 CJK UNIFIED IDEOGRAPH-#28F82, IRGKangXi=1364.030, RSKangXi=171.12
28F83 CJK UNIFIED IDEOGRAPH-#28F83, IRGKangXi=1364.040, RSKangXi=171.12
28F84 CJK UNIFIED IDEOGRAPH-#28F84, IRGKangXi=1364.041, RSKangXi=171.14
28F85 CJK UNIFIED IDEOGRAPH-#28F85, IRGKangXi=1364.070, RSKangXi=172.2
28F86 CJK UNIFIED IDEOGRAPH-#28F86, IRGKangXi=1364.100, RSKangXi=172.2
28F87 CJK UNIFIED IDEOGRAPH-#28F87, IRGKangXi=1364.120, RSKangXi=172.2
28F88 CJK UNIFIED IDEOGRAPH-#28F88, IRGKangXi=1364.140, RSKangXi=172.3
28F89 CJK UNIFIED IDEOGRAPH-#28F89, IRGKangXi=1364.150, RSKangXi=172.3
28F8A CJK UNIFIED IDEOGRAPH-#28F8A, IRGKangXi=1364.180, RSKangXi=172.3
28F8B CJK UNIFIED IDEOGRAPH-#28F8B, IRGKangXi=1364.210, RSKangXi=172.3
28F8C CJK UNIFIED IDEOGRAPH-#28F8C, IRGKangXi=1364.211, RSKangXi=172.3
28F8D CJK UNIFIED IDEOGRAPH-#28F8D, IRGKangXi=1364.211, RSKangXi=172.3
28F8E CJK UNIFIED IDEOGRAPH-#28F8E, IRGKangXi=1364.211, RSKangXi=172.3
28F8F CJK UNIFIED IDEOGRAPH-#28F8F, IRGKangXi=1364.211, RSKangXi=172.3
28F90 CJK UNIFIED IDEOGRAPH-#28F90, IRGKangXi=1364.211, RSKangXi=172.3
28F91 CJK UNIFIED IDEOGRAPH-#28F91, IRGKangXi=1364.211, RSKangXi=172.3
28F92 CJK UNIFIED IDEOGRAPH-#28F92, IRGKangXi=1364.220, RSKangXi=172.4
28F93 CJK UNIFIED IDEOGRAPH-#28F93, IRGKangXi=1364.230, RSKangXi=172.4
28F94 CJK UNIFIED IDEOGRAPH-#28F94, IRGKangXi=1365.010, RSKangXi=172.4
28F95 CJK UNIFIED IDEOGRAPH-#28F95, IRGKangXi=1365.040, RSKangXi=172.4
28F96 CJK UNIFIED IDEOGRAPH-#28F96, IRGKangXi=1365.050, RSKangXi=172.4
28F97 CJK UNIFIED IDEOGRAPH-#28F97, IRGKangXi=1365.060, RSKangXi=172.4
28F98 CJK UNIFIED IDEOGRAPH-#28F98, IRGKangXi=1365.070, RSKangXi=172.4
28F99 CJK UNIFIED IDEOGRAPH-#28F99, IRGKangXi=1365.080, RSKangXi=172.4
28F9A CJK UNIFIED IDEOGRAPH-#28F9A, IRGKangXi=1365.090, RSKangXi=172.4
28F9B CJK UNIFIED IDEOGRAPH-#28F9B, IRGKangXi=1365.170, RSKangXi=172.4
28F9C CJK UNIFIED IDEOGRAPH-#28F9C, IRGKangXi=1365.181, RSKangXi=172.4
28F9D CJK UNIFIED IDEOGRAPH-#28F9D, IRGKangXi=1365.181, RSKangXi=172.4
28F9E CJK UNIFIED IDEOGRAPH-#28F9E, IRGKangXi=1365.181, RSKangXi=172.4
28F9F CJK UNIFIED IDEOGRAPH-#28F9F, IRGKangXi=1365.181, RSKangXi=172.4
28FA0 CJK UNIFIED IDEOGRAPH-#28FA0, IRGKangXi=1365.200, RSKangXi=172.5
28FA1 CJK UNIFIED IDEOGRAPH-#28FA1, IRGKangXi=1365.210, RSKangXi=172.5
28FA2 CJK UNIFIED IDEOGRAPH-#28FA2, IRGKangXi=1365.220, RSKangXi=172.5
28FA3 CJK UNIFIED IDEOGRAPH-#28FA3, IRGKangXi=1365.230, RSKangXi=172.5
28FA4 CJK UNIFIED IDEOGRAPH-#28FA4, IRGKangXi=1366.010, RSKangXi=172.5
28FA5 CJK UNIFIED IDEOGRAPH-#28FA5, IRGKangXi=1366.030, RSKangXi=172.5
28FA6 CJK UNIFIED IDEOGRAPH-#28FA6, IRGKangXi=1366.040, RSKangXi=172.5
28FA7 CJK UNIFIED IDEOGRAPH-#28FA7, IRGKangXi=1366.060, RSKangXi=172.5
28FA8 CJK UNIFIED IDEOGRAPH-#28FA8, IRGKangXi=1366.070, RSKangXi=172.5
28FA9 CJK UNIFIED IDEOGRAPH-#28FA9, IRGKangXi=1366.080, RSKangXi=172.5
28FAA CJK UNIFIED IDEOGRAPH-#28FAA, IRGKangXi=1366.130, RSKangXi=172.5
28FAB CJK UNIFIED IDEOGRAPH-#28FAB, IRGKangXi=1366.170, RSKangXi=172.5
28FAC CJK UNIFIED IDEOGRAPH-#28FAC, IRGKangXi=1366.181, RSKangXi=172.5
28FAD CJK UNIFIED IDEOGRAPH-#28FAD, IRGKangXi=1366.181, RSKangXi=172.5
28FAE CJK UNIFIED IDEOGRAPH-#28FAE, IRGKangXi=1366.181, RSKangXi=172.5
28FAF CJK UNIFIED IDEOGRAPH-#28FAF, IRGKangXi=1366.181, RSKangXi=172.5
28FB0 CJK UNIFIED IDEOGRAPH-#28FB0, IRGKangXi=1366.181, RSKangXi=172.5
28FB1 CJK UNIFIED IDEOGRAPH-#28FB1, IRGKangXi=1366.181, RSKangXi=172.5
28FB2 CJK UNIFIED IDEOGRAPH-#28FB2, IRGKangXi=1366.200, RSKangXi=172.6
28FB3 CJK UNIFIED IDEOGRAPH-#28FB3, IRGKangXi=1366.210, RSKangXi=172.6
28FB4 CJK UNIFIED IDEOGRAPH-#28FB4, IRGKangXi=1366.220, RSKangXi=172.6
28FB5 CJK UNIFIED IDEOGRAPH-#28FB5, IRGKangXi=1366.230, RSKangXi=172.6
28FB6 CJK UNIFIED IDEOGRAPH-#28FB6, IRGKangXi=1367.020, RSKangXi=172.6
28FB7 CJK UNIFIED IDEOGRAPH-#28FB7, IRGKangXi=1367.030, RSKangXi=172.6
28FB8 CJK UNIFIED IDEOGRAPH-#28FB8, IRGKangXi=1367.040, RSKangXi=172.6
28FB9 CJK UNIFIED IDEOGRAPH-#28FB9, IRGKangXi=1367.050, RSKangXi=172.6
28FBA CJK UNIFIED IDEOGRAPH-#28FBA, IRGKangXi=1367.060, RSKangXi=172.6
28FBB CJK UNIFIED IDEOGRAPH-#28FBB, IRGKangXi=1367.080, RSKangXi=172.6
28FBC CJK UNIFIED IDEOGRAPH-#28FBC, IRGKangXi=1367.090, RSKangXi=172.6
28FBD CJK UNIFIED IDEOGRAPH-#28FBD, IRGKangXi=1367.100, RSKangXi=172.6
28FBE CJK UNIFIED IDEOGRAPH-#28FBE, IRGKangXi=1367.120, RSKangXi=172.6
28FBF CJK UNIFIED IDEOGRAPH-#28FBF, IRGKangXi=1367.130, RSKangXi=172.6
28FC0 CJK UNIFIED IDEOGRAPH-#28FC0, IRGKangXi=1367.140, RSKangXi=172.6
28FC1 CJK UNIFIED IDEOGRAPH-#28FC1, IRGKangXi=1367.150, RSKangXi=172.6
28FC2 CJK UNIFIED IDEOGRAPH-#28FC2, IRGKangXi=1367.160, RSKangXi=172.6
28FC3 CJK UNIFIED IDEOGRAPH-#28FC3, IRGKangXi=1367.161, RSKangXi=172.6
28FC4 CJK UNIFIED IDEOGRAPH-#28FC4, IRGKangXi=1367.161, RSKangXi=172.6
28FC5 CJK UNIFIED IDEOGRAPH-#28FC5, IRGKangXi=1367.161, RSKangXi=172.6
28FC6 CJK UNIFIED IDEOGRAPH-#28FC6, IRGKangXi=1367.161, RSKangXi=172.6
28FC7 CJK UNIFIED IDEOGRAPH-#28FC7, IRGKangXi=1367.161, RSKangXi=172.6
28FC8 CJK UNIFIED IDEOGRAPH-#28FC8, IRGKangXi=1367.161, RSKangXi=172.6
28FC9 CJK UNIFIED IDEOGRAPH-#28FC9, IRGKangXi=1367.161, RSKangXi=172.6
28FCA CJK UNIFIED IDEOGRAPH-#28FCA, IRGKangXi=1367.161, RSKangXi=172.6
28FCB CJK UNIFIED IDEOGRAPH-#28FCB, IRGKangXi=1367.170, RSKangXi=172.7
28FCC CJK UNIFIED IDEOGRAPH-#28FCC, IRGKangXi=1367.180, RSKangXi=172.7
28FCD CJK UNIFIED IDEOGRAPH-#28FCD, IRGKangXi=1367.190, RSKangXi=172.7
28FCE CJK UNIFIED IDEOGRAPH-#28FCE, IRGKangXi=1367.210, RSKangXi=172.7
28FCF CJK UNIFIED IDEOGRAPH-#28FCF, IRGKangXi=1367.220, RSKangXi=172.7
28FD0 CJK UNIFIED IDEOGRAPH-#28FD0, IRGKangXi=1367.230, RSKangXi=172.7
28FD1 CJK UNIFIED IDEOGRAPH-#28FD1, IRGKangXi=1367.240, RSKangXi=172.7
28FD2 CJK UNIFIED IDEOGRAPH-#28FD2, IRGKangXi=1367.250, RSKangXi=172.7
28FD3 CJK UNIFIED IDEOGRAPH-#28FD3, IRGKangXi=1367.260, RSKangXi=172.7
28FD4 CJK UNIFIED IDEOGRAPH-#28FD4, IRGKangXi=1367.270, RSKangXi=172.7
28FD5 CJK UNIFIED IDEOGRAPH-#28FD5, IRGKangXi=1367.290, RSKangXi=172.7
28FD6 CJK UNIFIED IDEOGRAPH-#28FD6, IRGKangXi=1367.300, RSKangXi=172.7
28FD7 CJK UNIFIED IDEOGRAPH-#28FD7, IRGKangXi=1367.310, RSKangXi=172.7
28FD8 CJK UNIFIED IDEOGRAPH-#28FD8, IRGKangXi=1367.320, RSKangXi=172.7
28FD9 CJK UNIFIED IDEOGRAPH-#28FD9, IRGKangXi=1367.340, RSKangXi=172.7
28FDA CJK UNIFIED IDEOGRAPH-#28FDA, IRGKangXi=1367.341, RSKangXi=172.7
28FDB CJK UNIFIED IDEOGRAPH-#28FDB, IRGKangXi=1367.341, RSKangXi=172.7
28FDC CJK UNIFIED IDEOGRAPH-#28FDC, IRGKangXi=1367.341, RSKangXi=172.7
28FDD CJK UNIFIED IDEOGRAPH-#28FDD, IRGKangXi=1367.341, RSKangXi=172.7
28FDE CJK UNIFIED IDEOGRAPH-#28FDE, IRGKangXi=1367.341, RSKangXi=172.7
28FDF CJK UNIFIED IDEOGRAPH-#28FDF, IRGKangXi=1367.341, RSKangXi=172.7
28FE0 CJK UNIFIED IDEOGRAPH-#28FE0, IRGKangXi=1367.350, RSKangXi=172.8
28FE1 CJK UNIFIED IDEOGRAPH-#28FE1, IRGKangXi=1367.360, RSKangXi=172.8
28FE2 CJK UNIFIED IDEOGRAPH-#28FE2, IRGKangXi=1367.370, RSKangXi=172.8
28FE3 CJK UNIFIED IDEOGRAPH-#28FE3, IRGKangXi=1367.380, RSKangXi=172.8
28FE4 CJK UNIFIED IDEOGRAPH-#28FE4, IRGKangXi=1367.390, RSKangXi=172.8
28FE5 CJK UNIFIED IDEOGRAPH-#28FE5, IRGKangXi=1367.400, RSKangXi=172.8
28FE6 CJK UNIFIED IDEOGRAPH-#28FE6, IRGKangXi=1367.410, RSKangXi=172.8
28FE7 CJK UNIFIED IDEOGRAPH-#28FE7, IRGKangXi=1367.420, RSKangXi=172.8
28FE8 CJK UNIFIED IDEOGRAPH-#28FE8, IRGKangXi=1367.430, RSKangXi=172.8
28FE9 CJK UNIFIED IDEOGRAPH-#28FE9, IRGKangXi=1367.450, RSKangXi=172.8
28FEA CJK UNIFIED IDEOGRAPH-#28FEA, IRGKangXi=1367.460, RSKangXi=172.8
28FEB CJK UNIFIED IDEOGRAPH-#28FEB, IRGKangXi=1367.470, RSKangXi=172.8
28FEC CJK UNIFIED IDEOGRAPH-#28FEC, IRGKangXi=1367.500, RSKangXi=172.8
28FED CJK UNIFIED IDEOGRAPH-#28FED, IRGKangXi=1367.510, RSKangXi=172.8
28FEE CJK UNIFIED IDEOGRAPH-#28FEE, IRGKangXi=1367.520, RSKangXi=172.8
28FEF CJK UNIFIED IDEOGRAPH-#28FEF, IRGKangXi=1367.540, RSKangXi=172.8
28FF0 CJK UNIFIED IDEOGRAPH-#28FF0, IRGKangXi=1367.550, RSKangXi=172.8
28FF1 CJK UNIFIED IDEOGRAPH-#28FF1, IRGKangXi=1367.560, RSKangXi=172.8
28FF2 CJK UNIFIED IDEOGRAPH-#28FF2, IRGKangXi=1367.570, RSKangXi=172.8
28FF3 CJK UNIFIED IDEOGRAPH-#28FF3, IRGKangXi=1368.010, RSKangXi=172.8
28FF4 CJK UNIFIED IDEOGRAPH-#28FF4, IRGKangXi=1368.020, RSKangXi=172.8
28FF5 CJK UNIFIED IDEOGRAPH-#28FF5, IRGKangXi=1368.030, RSKangXi=172.8
28FF6 CJK UNIFIED IDEOGRAPH-#28FF6, IRGKangXi=1368.040, RSKangXi=172.8
28FF7 CJK UNIFIED IDEOGRAPH-#28FF7, IRGKangXi=1368.041, RSKangXi=172.8
28FF8 CJK UNIFIED IDEOGRAPH-#28FF8, IRGKangXi=1368.041, RSKangXi=172.8
28FF9 CJK UNIFIED IDEOGRAPH-#28FF9, IRGKangXi=1368.041, RSKangXi=172.8
28FFA CJK UNIFIED IDEOGRAPH-#28FFA, IRGKangXi=1368.041, RSKangXi=172.8
28FFB CJK UNIFIED IDEOGRAPH-#28FFB, IRGKangXi=1368.041, RSKangXi=172.8
28FFC CJK UNIFIED IDEOGRAPH-#28FFC, IRGKangXi=1368.041, RSKangXi=172.8
28FFD CJK UNIFIED IDEOGRAPH-#28FFD, IRGKangXi=1368.041, RSKangXi=172.8
28FFE CJK UNIFIED IDEOGRAPH-#28FFE, IRGKangXi=1368.041, RSKangXi=172.8
28FFF CJK UNIFIED IDEOGRAPH-#28FFF, IRGKangXi=1368.050, RSKangXi=172.9
29000 CJK UNIFIED IDEOGRAPH-#29000, IRGKangXi=1368.060, RSKangXi=172.9
29001 CJK UNIFIED IDEOGRAPH-#29001, IRGKangXi=1368.070, RSKangXi=172.9
29002 CJK UNIFIED IDEOGRAPH-#29002, IRGKangXi=1368.080, RSKangXi=172.9
29003 CJK UNIFIED IDEOGRAPH-#29003, IRGKangXi=1368.100, RSKangXi=172.9
29004 CJK UNIFIED IDEOGRAPH-#29004, IRGKangXi=1368.110, RSKangXi=172.9
29005 CJK UNIFIED IDEOGRAPH-#29005, IRGKangXi=1368.120, RSKangXi=172.9
29006 CJK UNIFIED IDEOGRAPH-#29006, IRGKangXi=1368.130, RSKangXi=172.9
29007 CJK UNIFIED IDEOGRAPH-#29007, IRGKangXi=1368.140, RSKangXi=172.9
29008 CJK UNIFIED IDEOGRAPH-#29008, IRGKangXi=1368.150, RSKangXi=172.9
29009 CJK UNIFIED IDEOGRAPH-#29009, IRGKangXi=1368.160, RSKangXi=172.9
2900A CJK UNIFIED IDEOGRAPH-#2900A, IRGKangXi=1368.170, RSKangXi=172.9
2900B CJK UNIFIED IDEOGRAPH-#2900B, IRGKangXi=1368.190, RSKangXi=172.9
2900C CJK UNIFIED IDEOGRAPH-#2900C, IRGKangXi=1368.200, RSKangXi=172.9
2900D CJK UNIFIED IDEOGRAPH-#2900D, IRGKangXi=1368.210, RSKangXi=172.9
2900E CJK UNIFIED IDEOGRAPH-#2900E, IRGKangXi=1368.240, RSKangXi=172.9
2900F CJK UNIFIED IDEOGRAPH-#2900F, IRGKangXi=1368.250, RSKangXi=172.9
29010 CJK UNIFIED IDEOGRAPH-#29010, IRGKangXi=1368.260, RSKangXi=172.9
29011 CJK UNIFIED IDEOGRAPH-#29011, IRGKangXi=1368.261, RSKangXi=172.9
29012 CJK UNIFIED IDEOGRAPH-#29012, IRGKangXi=1368.261, RSKangXi=172.9
29013 CJK UNIFIED IDEOGRAPH-#29013, IRGKangXi=1368.261, RSKangXi=172.9
29014 CJK UNIFIED IDEOGRAPH-#29014, IRGKangXi=1368.261, RSKangXi=172.9
29015 CJK UNIFIED IDEOGRAPH-#29015, IRGKangXi=1368.261, RSKangXi=172.9
29016 CJK UNIFIED IDEOGRAPH-#29016, IRGKangXi=1368.261, RSKangXi=172.9
29017 CJK UNIFIED IDEOGRAPH-#29017, IRGKangXi=1368.270, RSKangXi=172.10
29018 CJK UNIFIED IDEOGRAPH-#29018, IRGKangXi=1368.280, RSKangXi=172.10
29019 CJK UNIFIED IDEOGRAPH-#29019, IRGKangXi=1368.310, RSKangXi=172.10
2901A CJK UNIFIED IDEOGRAPH-#2901A, IRGKangXi=1368.320, RSKangXi=172.10
2901B CJK UNIFIED IDEOGRAPH-#2901B, IRGKangXi=1368.330, RSKangXi=172.10
2901C CJK UNIFIED IDEOGRAPH-#2901C, IRGKangXi=1368.350, RSKangXi=172.10
2901D CJK UNIFIED IDEOGRAPH-#2901D, IRGKangXi=1368.360, RSKangXi=172.10
2901E CJK UNIFIED IDEOGRAPH-#2901E, IRGKangXi=1368.370, RSKangXi=172.10
2901F CJK UNIFIED IDEOGRAPH-#2901F, IRGKangXi=1369.040, RSKangXi=172.10
29020 CJK UNIFIED IDEOGRAPH-#29020, IRGKangXi=1369.041, RSKangXi=172.10
29021 CJK UNIFIED IDEOGRAPH-#29021, IRGKangXi=1369.041, RSKangXi=172.10
29022 CJK UNIFIED IDEOGRAPH-#29022, IRGKangXi=1369.041, RSKangXi=172.10
29023 CJK UNIFIED IDEOGRAPH-#29023, IRGKangXi=1369.041, RSKangXi=172.10
29024 CJK UNIFIED IDEOGRAPH-#29024, IRGKangXi=1369.060, RSKangXi=172.11
29025 CJK UNIFIED IDEOGRAPH-#29025, IRGKangXi=1369.070, RSKangXi=172.11
29026 CJK UNIFIED IDEOGRAPH-#29026, IRGKangXi=1369.080, RSKangXi=172.11
29027 CJK UNIFIED IDEOGRAPH-#29027, IRGKangXi=1369.090, RSKangXi=172.11
29028 CJK UNIFIED IDEOGRAPH-#29028, IRGKangXi=1369.110, RSKangXi=172.11
29029 CJK UNIFIED IDEOGRAPH-#29029, IRGKangXi=1369.120, RSKangXi=172.11
2902A CJK UNIFIED IDEOGRAPH-#2902A, IRGKangXi=1369.130, RSKangXi=172.11
2902B CJK UNIFIED IDEOGRAPH-#2902B, IRGKangXi=1369.140, RSKangXi=172.11
2902C CJK UNIFIED IDEOGRAPH-#2902C, IRGKangXi=1369.150, RSKangXi=172.11
2902D CJK UNIFIED IDEOGRAPH-#2902D, IRGKangXi=1370.010, RSKangXi=172.11
2902E CJK UNIFIED IDEOGRAPH-#2902E, IRGKangXi=1370.020, RSKangXi=172.11
2902F CJK UNIFIED IDEOGRAPH-#2902F, IRGKangXi=1370.030, RSKangXi=172.11
29030 CJK UNIFIED IDEOGRAPH-#29030, IRGKangXi=1370.140, RSKangXi=172.11
29031 CJK UNIFIED IDEOGRAPH-#29031, IRGKangXi=1370.141, RSKangXi=172.11
29032 CJK UNIFIED IDEOGRAPH-#29032, IRGKangXi=1370.141, RSKangXi=172.11
29033 CJK UNIFIED IDEOGRAPH-#29033, IRGKangXi=1370.141, RSKangXi=172.11
29034 CJK UNIFIED IDEOGRAPH-#29034, IRGKangXi=1370.150, RSKangXi=172.12
29035 CJK UNIFIED IDEOGRAPH-#29035, IRGKangXi=1370.170, RSKangXi=172.12
29036 CJK UNIFIED IDEOGRAPH-#29036, IRGKangXi=1370.180, RSKangXi=172.12
29037 CJK UNIFIED IDEOGRAPH-#29037, IRGKangXi=1370.190, RSKangXi=172.12
29038 CJK UNIFIED IDEOGRAPH-#29038, IRGKangXi=1370.200, RSKangXi=172.12
29039 CJK UNIFIED IDEOGRAPH-#29039, IRGKangXi=1370.210, RSKangXi=172.12
2903A CJK UNIFIED IDEOGRAPH-#2903A, IRGKangXi=1370.220, RSKangXi=172.12
2903B CJK UNIFIED IDEOGRAPH-#2903B, IRGKangXi=1370.230, RSKangXi=172.12
2903C CJK UNIFIED IDEOGRAPH-#2903C, IRGKangXi=1370.240, RSKangXi=172.12
2903D CJK UNIFIED IDEOGRAPH-#2903D, IRGKangXi=1370.250, RSKangXi=172.12
2903E CJK UNIFIED IDEOGRAPH-#2903E, IRGKangXi=1370.260, RSKangXi=172.12
2903F CJK UNIFIED IDEOGRAPH-#2903F, IRGKangXi=1370.270, RSKangXi=172.12
29040 CJK UNIFIED IDEOGRAPH-#29040, IRGKangXi=1370.280, RSKangXi=172.12
29041 CJK UNIFIED IDEOGRAPH-#29041, IRGKangXi=1370.291, RSKangXi=172.12
29042 CJK UNIFIED IDEOGRAPH-#29042, IRGKangXi=1370.291, RSKangXi=172.12
29043 CJK UNIFIED IDEOGRAPH-#29043, IRGKangXi=1370.291, RSKangXi=172.12
29044 CJK UNIFIED IDEOGRAPH-#29044, IRGKangXi=1370.291, RSKangXi=172.12
29045 CJK UNIFIED IDEOGRAPH-#29045, IRGKangXi=1370.291, RSKangXi=172.12
29046 CJK UNIFIED IDEOGRAPH-#29046, IRGKangXi=1370.291, RSKangXi=172.12
29047 CJK UNIFIED IDEOGRAPH-#29047, IRGKangXi=1370.300, RSKangXi=172.13
29048 CJK UNIFIED IDEOGRAPH-#29048, IRGKangXi=1370.310, RSKangXi=172.13
29049 CJK UNIFIED IDEOGRAPH-#29049, IRGKangXi=1370.320, RSKangXi=172.13
2904A CJK UNIFIED IDEOGRAPH-#2904A, IRGKangXi=1370.330, RSKangXi=172.13
2904B CJK UNIFIED IDEOGRAPH-#2904B, IRGKangXi=1370.340, RSKangXi=172.13
2904C CJK UNIFIED IDEOGRAPH-#2904C, IRGKangXi=1370.360, RSKangXi=172.13
2904D CJK UNIFIED IDEOGRAPH-#2904D, IRGKangXi=1370.370, RSKangXi=172.13
2904E CJK UNIFIED IDEOGRAPH-#2904E, IRGKangXi=1370.380, RSKangXi=172.13
2904F CJK UNIFIED IDEOGRAPH-#2904F, IRGKangXi=1370.390, RSKangXi=172.13
29050 CJK UNIFIED IDEOGRAPH-#29050, IRGKangXi=1370.400, RSKangXi=172.13
29051 CJK UNIFIED IDEOGRAPH-#29051, IRGKangXi=1370.401, RSKangXi=172.13
29052 CJK UNIFIED IDEOGRAPH-#29052, IRGKangXi=1370.401, RSKangXi=172.13
29053 CJK UNIFIED IDEOGRAPH-#29053, IRGKangXi=1370.410, RSKangXi=172.14
29054 CJK UNIFIED IDEOGRAPH-#29054, IRGKangXi=1370.420, RSKangXi=172.14
29055 CJK UNIFIED IDEOGRAPH-#29055, IRGKangXi=1370.450, RSKangXi=172.14
29056 CJK UNIFIED IDEOGRAPH-#29056, IRGKangXi=1370.460, RSKangXi=172.14
29057 CJK UNIFIED IDEOGRAPH-#29057, IRGKangXi=1370.470, RSKangXi=172.14
29058 CJK UNIFIED IDEOGRAPH-#29058, IRGKangXi=1370.471, RSKangXi=172.14
29059 CJK UNIFIED IDEOGRAPH-#29059, IRGKangXi=1370.471, RSKangXi=172.14
2905A CJK UNIFIED IDEOGRAPH-#2905A, IRGKangXi=1370.471, RSKangXi=172.14
2905B CJK UNIFIED IDEOGRAPH-#2905B, IRGKangXi=1370.471, RSKangXi=172.14
2905C CJK UNIFIED IDEOGRAPH-#2905C, IRGKangXi=1370.480, RSKangXi=172.15
2905D CJK UNIFIED IDEOGRAPH-#2905D, IRGKangXi=1370.490, RSKangXi=172.15
2905E CJK UNIFIED IDEOGRAPH-#2905E, IRGKangXi=1371.010, RSKangXi=172.15
2905F CJK UNIFIED IDEOGRAPH-#2905F, IRGKangXi=1371.020, RSKangXi=172.15
29060 CJK UNIFIED IDEOGRAPH-#29060, IRGKangXi=1371.030, RSKangXi=172.15
29061 CJK UNIFIED IDEOGRAPH-#29061, IRGKangXi=1371.040, RSKangXi=172.15
29062 CJK UNIFIED IDEOGRAPH-#29062, IRGKangXi=1371.050, RSKangXi=172.15
29063 CJK UNIFIED IDEOGRAPH-#29063, IRGKangXi=1371.060, RSKangXi=172.15
29064 CJK UNIFIED IDEOGRAPH-#29064, IRGKangXi=1371.070, RSKangXi=172.15
29065 CJK UNIFIED IDEOGRAPH-#29065, IRGKangXi=1371.071, RSKangXi=172.15
29066 CJK UNIFIED IDEOGRAPH-#29066, IRGKangXi=1371.071, RSKangXi=172.15
29067 CJK UNIFIED IDEOGRAPH-#29067, IRGKangXi=1371.080, RSKangXi=172.16
29068 CJK UNIFIED IDEOGRAPH-#29068, IRGKangXi=1371.100, RSKangXi=172.16
29069 CJK UNIFIED IDEOGRAPH-#29069, IRGKangXi=1371.120, RSKangXi=172.16
2906A CJK UNIFIED IDEOGRAPH-#2906A, IRGKangXi=1371.121, RSKangXi=172.16
2906B CJK UNIFIED IDEOGRAPH-#2906B, IRGKangXi=1371.121, RSKangXi=172.16
2906C CJK UNIFIED IDEOGRAPH-#2906C, IRGKangXi=1371.130, RSKangXi=172.17
2906D CJK UNIFIED IDEOGRAPH-#2906D, IRGKangXi=1371.141, RSKangXi=172.17
2906E CJK UNIFIED IDEOGRAPH-#2906E, IRGKangXi=1371.141, RSKangXi=172.17
2906F CJK UNIFIED IDEOGRAPH-#2906F, IRGKangXi=1371.141, RSKangXi=172.18
29070 CJK UNIFIED IDEOGRAPH-#29070, IRGKangXi=1371.141, RSKangXi=172.18
29071 CJK UNIFIED IDEOGRAPH-#29071, IRGKangXi=1371.141, RSKangXi=172.18
29072 CJK UNIFIED IDEOGRAPH-#29072, IRGKangXi=1371.160, RSKangXi=172.20
29073 CJK UNIFIED IDEOGRAPH-#29073, IRGKangXi=1371.161, RSKangXi=172.20
29074 CJK UNIFIED IDEOGRAPH-#29074, IRGKangXi=1371.171, RSKangXi=172.24
29075 CJK UNIFIED IDEOGRAPH-#29075, IRGKangXi=1371.171, RSKangXi=172.28
29076 CJK UNIFIED IDEOGRAPH-#29076, IRGKangXi=1371.181, RSKangXi=173.1
29077 CJK UNIFIED IDEOGRAPH-#29077, IRGKangXi=1371.240, RSKangXi=173.2
29078 CJK UNIFIED IDEOGRAPH-#29078, IRGKangXi=1371.241, RSKangXi=173.2
29079 CJK UNIFIED IDEOGRAPH-#29079, IRGKangXi=1371.260, RSKangXi=173.3
2907A CJK UNIFIED IDEOGRAPH-#2907A, IRGKangXi=1371.270, RSKangXi=173.3
2907B CJK UNIFIED IDEOGRAPH-#2907B, IRGKangXi=1371.280, RSKangXi=173.3
2907C CJK UNIFIED IDEOGRAPH-#2907C, IRGKangXi=1371.300, RSKangXi=173.3
2907D CJK UNIFIED IDEOGRAPH-#2907D, IRGKangXi=1371.301, RSKangXi=173.3
2907E CJK UNIFIED IDEOGRAPH-#2907E, IRGKangXi=1371.301, RSKangXi=173.3
2907F CJK UNIFIED IDEOGRAPH-#2907F, IRGKangXi=1371.301, RSKangXi=173.3
29080 CJK UNIFIED IDEOGRAPH-#29080, IRGKangXi=1371.301, RSKangXi=173.3
29081 CJK UNIFIED IDEOGRAPH-#29081, IRGKangXi=1371.301, RSKangXi=173.3
29082 CJK UNIFIED IDEOGRAPH-#29082, IRGKangXi=1371.320, RSKangXi=173.4
29083 CJK UNIFIED IDEOGRAPH-#29083, IRGKangXi=1371.330, RSKangXi=173.4
29084 CJK UNIFIED IDEOGRAPH-#29084, IRGKangXi=1371.360, RSKangXi=173.4
29085 CJK UNIFIED IDEOGRAPH-#29085, IRGKangXi=1371.370, RSKangXi=173.4
29086 CJK UNIFIED IDEOGRAPH-#29086, IRGKangXi=1371.390, RSKangXi=173.4
29087 CJK UNIFIED IDEOGRAPH-#29087, IRGKangXi=1371.400, RSKangXi=173.4
29088 CJK UNIFIED IDEOGRAPH-#29088, IRGKangXi=1372.040, RSKangXi=173.4
29089 CJK UNIFIED IDEOGRAPH-#29089, IRGKangXi=1372.060, RSKangXi=173.4
2908A CJK UNIFIED IDEOGRAPH-#2908A, IRGKangXi=1372.061, RSKangXi=173.4
2908B CJK UNIFIED IDEOGRAPH-#2908B, IRGKangXi=1372.061, RSKangXi=173.4
2908C CJK UNIFIED IDEOGRAPH-#2908C, IRGKangXi=1372.061, RSKangXi=173.4
2908D CJK UNIFIED IDEOGRAPH-#2908D, IRGKangXi=1372.061, RSKangXi=173.4
2908E CJK UNIFIED IDEOGRAPH-#2908E, IRGKangXi=1372.061, RSKangXi=173.4
2908F CJK UNIFIED IDEOGRAPH-#2908F, IRGKangXi=1372.061, RSKangXi=173.4
29090 CJK UNIFIED IDEOGRAPH-#29090, IRGKangXi=1372.061, RSKangXi=173.4
29091 CJK UNIFIED IDEOGRAPH-#29091, IRGKangXi=1372.061, RSKangXi=173.4
29092 CJK UNIFIED IDEOGRAPH-#29092, IRGKangXi=1372.120, RSKangXi=173.5
29093 CJK UNIFIED IDEOGRAPH-#29093, IRGKangXi=1372.130, RSKangXi=173.5
29094 CJK UNIFIED IDEOGRAPH-#29094, IRGKangXi=1372.250, RSKangXi=173.5
29095 CJK UNIFIED IDEOGRAPH-#29095, IRGKangXi=1373.010, RSKangXi=173.5
29096 CJK UNIFIED IDEOGRAPH-#29096, IRGKangXi=1373.030, RSKangXi=173.5
29097 CJK UNIFIED IDEOGRAPH-#29097, IRGKangXi=1373.040, RSKangXi=173.5
29098 CJK UNIFIED IDEOGRAPH-#29098, IRGKangXi=1373.070, RSKangXi=173.5
29099 CJK UNIFIED IDEOGRAPH-#29099, IRGKangXi=1373.080, RSKangXi=173.5
2909A CJK UNIFIED IDEOGRAPH-#2909A, IRGKangXi=1373.091, RSKangXi=173.5
2909B CJK UNIFIED IDEOGRAPH-#2909B, IRGKangXi=1373.091, RSKangXi=173.5
2909C CJK UNIFIED IDEOGRAPH-#2909C, IRGKangXi=1373.091, RSKangXi=173.5
2909D CJK UNIFIED IDEOGRAPH-#2909D, IRGKangXi=1373.091, RSKangXi=173.5
2909E CJK UNIFIED IDEOGRAPH-#2909E, IRGKangXi=1373.091, RSKangXi=173.5
2909F CJK UNIFIED IDEOGRAPH-#2909F, IRGKangXi=1373.091, RSKangXi=173.5
290A0 CJK UNIFIED IDEOGRAPH-#290A0, IRGKangXi=1373.091, RSKangXi=173.5
290A1 CJK UNIFIED IDEOGRAPH-#290A1, IRGKangXi=1373.091, RSKangXi=173.5
290A2 CJK UNIFIED IDEOGRAPH-#290A2, IRGKangXi=1373.100, RSKangXi=173.6
290A3 CJK UNIFIED IDEOGRAPH-#290A3, IRGKangXi=1373.130, RSKangXi=173.6
290A4 CJK UNIFIED IDEOGRAPH-#290A4, IRGKangXi=1373.140, RSKangXi=173.6
290A5 CJK UNIFIED IDEOGRAPH-#290A5, IRGKangXi=1373.160, RSKangXi=173.6
290A6 CJK UNIFIED IDEOGRAPH-#290A6, IRGKangXi=1373.180, RSKangXi=173.6
290A7 CJK UNIFIED IDEOGRAPH-#290A7, IRGKangXi=1373.200, RSKangXi=173.6
290A8 CJK UNIFIED IDEOGRAPH-#290A8, IRGKangXi=1373.210, RSKangXi=173.6
290A9 CJK UNIFIED IDEOGRAPH-#290A9, IRGKangXi=1373.220, RSKangXi=173.6
290AA CJK UNIFIED IDEOGRAPH-#290AA, IRGKangXi=1373.260, RSKangXi=173.6
290AB CJK UNIFIED IDEOGRAPH-#290AB, IRGKangXi=1373.280, RSKangXi=173.6
290AC CJK UNIFIED IDEOGRAPH-#290AC, IRGKangXi=1374.010, RSKangXi=173.6
290AD CJK UNIFIED IDEOGRAPH-#290AD, IRGKangXi=1374.021, RSKangXi=173.6
290AE CJK UNIFIED IDEOGRAPH-#290AE, IRGKangXi=1374.021, RSKangXi=173.6
290AF CJK UNIFIED IDEOGRAPH-#290AF, IRGKangXi=1374.021, RSKangXi=173.6
290B0 CJK UNIFIED IDEOGRAPH-#290B0, IRGKangXi=1374.021, RSKangXi=173.6
290B1 CJK UNIFIED IDEOGRAPH-#290B1, IRGKangXi=1374.021, RSKangXi=173.6
290B2 CJK UNIFIED IDEOGRAPH-#290B2, IRGKangXi=1374.021, RSKangXi=173.6
290B3 CJK UNIFIED IDEOGRAPH-#290B3, IRGKangXi=1374.021, RSKangXi=173.6, Def{non-standard variant of 靈 U+9748, a spirit, soul; the spiritual world}
290B4 CJK UNIFIED IDEOGRAPH-#290B4, IRGKangXi=1374.021, RSKangXi=173.6
290B5 CJK UNIFIED IDEOGRAPH-#290B5, IRGKangXi=1374.021, RSKangXi=173.6
290B6 CJK UNIFIED IDEOGRAPH-#290B6, IRGKangXi=1374.021, RSKangXi=173.6
290B7 CJK UNIFIED IDEOGRAPH-#290B7, IRGKangXi=1374.060, RSKangXi=173.7
290B8 CJK UNIFIED IDEOGRAPH-#290B8, IRGKangXi=1374.070, RSKangXi=173.7
290B9 CJK UNIFIED IDEOGRAPH-#290B9, IRGKangXi=1374.080, RSKangXi=173.7
290BA CJK UNIFIED IDEOGRAPH-#290BA, IRGKangXi=1374.090, RSKangXi=173.7
290BB CJK UNIFIED IDEOGRAPH-#290BB, IRGKangXi=1374.120, RSKangXi=173.7
290BC CJK UNIFIED IDEOGRAPH-#290BC, IRGKangXi=1374.130, RSKangXi=173.7
290BD CJK UNIFIED IDEOGRAPH-#290BD, IRGKangXi=1374.140, RSKangXi=173.7
290BE CJK UNIFIED IDEOGRAPH-#290BE, IRGKangXi=1374.160, RSKangXi=173.7
290BF CJK UNIFIED IDEOGRAPH-#290BF, IRGKangXi=1374.180, RSKangXi=173.7
290C0 CJK UNIFIED IDEOGRAPH-#290C0, IRGKangXi=1374.190, RSKangXi=173.7
290C1 CJK UNIFIED IDEOGRAPH-#290C1, IRGKangXi=1375.030, RSKangXi=173.7
290C2 CJK UNIFIED IDEOGRAPH-#290C2, IRGKangXi=1375.040, RSKangXi=173.7
290C3 CJK UNIFIED IDEOGRAPH-#290C3, IRGKangXi=1375.050, RSKangXi=173.7
290C4 CJK UNIFIED IDEOGRAPH-#290C4, IRGKangXi=1375.051, RSKangXi=173.7
290C5 CJK UNIFIED IDEOGRAPH-#290C5, IRGKangXi=1375.051, RSKangXi=173.7
290C6 CJK UNIFIED IDEOGRAPH-#290C6, IRGKangXi=1375.051, RSKangXi=173.7
290C7 CJK UNIFIED IDEOGRAPH-#290C7, IRGKangXi=1375.051, RSKangXi=173.7
290C8 CJK UNIFIED IDEOGRAPH-#290C8, IRGKangXi=1375.051, RSKangXi=173.7
290C9 CJK UNIFIED IDEOGRAPH-#290C9, IRGKangXi=1375.051, RSKangXi=173.7
290CA CJK UNIFIED IDEOGRAPH-#290CA, IRGKangXi=1375.051, RSKangXi=173.7
290CB CJK UNIFIED IDEOGRAPH-#290CB, IRGKangXi=1375.051, RSKangXi=173.7
290CC CJK UNIFIED IDEOGRAPH-#290CC, IRGKangXi=1375.051, RSKangXi=173.7
290CD CJK UNIFIED IDEOGRAPH-#290CD, IRGKangXi=1375.051, RSKangXi=173.7
290CE CJK UNIFIED IDEOGRAPH-#290CE, IRGKangXi=1375.051, RSKangXi=173.7
290CF CJK UNIFIED IDEOGRAPH-#290CF, IRGKangXi=1375.051, RSKangXi=173.7
290D0 CJK UNIFIED IDEOGRAPH-#290D0, IRGKangXi=1375.051, RSKangXi=173.7
290D1 CJK UNIFIED IDEOGRAPH-#290D1, IRGKangXi=1375.051, RSKangXi=173.7
290D2 CJK UNIFIED IDEOGRAPH-#290D2, IRGKangXi=1375.060, RSKangXi=173.8
290D3 CJK UNIFIED IDEOGRAPH-#290D3, IRGKangXi=1375.070, RSKangXi=173.8
290D4 CJK UNIFIED IDEOGRAPH-#290D4, IRGKangXi=1375.080, RSKangXi=173.8
290D5 CJK UNIFIED IDEOGRAPH-#290D5, IRGKangXi=1375.110, RSKangXi=173.8
290D6 CJK UNIFIED IDEOGRAPH-#290D6, IRGKangXi=1375.120, RSKangXi=173.8
290D7 CJK UNIFIED IDEOGRAPH-#290D7, IRGKangXi=1375.140, RSKangXi=173.8
290D8 CJK UNIFIED IDEOGRAPH-#290D8, IRGKangXi=1375.160, RSKangXi=173.8
290D9 CJK UNIFIED IDEOGRAPH-#290D9, IRGKangXi=1375.210, RSKangXi=173.8
290DA CJK UNIFIED IDEOGRAPH-#290DA, IRGKangXi=1375.240, RSKangXi=173.8
290DB CJK UNIFIED IDEOGRAPH-#290DB, IRGKangXi=1375.280, RSKangXi=173.8
290DC CJK UNIFIED IDEOGRAPH-#290DC, IRGKangXi=1376.040, RSKangXi=173.8
290DD CJK UNIFIED IDEOGRAPH-#290DD, IRGKangXi=1376.050, RSKangXi=173.8
290DE CJK UNIFIED IDEOGRAPH-#290DE, IRGKangXi=1376.060, RSKangXi=173.8
290DF CJK UNIFIED IDEOGRAPH-#290DF, IRGKangXi=1376.070, RSKangXi=173.8
290E0 CJK UNIFIED IDEOGRAPH-#290E0, IRGKangXi=1376.080, RSKangXi=173.8
290E1 CJK UNIFIED IDEOGRAPH-#290E1, IRGKangXi=1376.090, RSKangXi=173.8
290E2 CJK UNIFIED IDEOGRAPH-#290E2, IRGKangXi=1376.091, RSKangXi=173.8
290E3 CJK UNIFIED IDEOGRAPH-#290E3, IRGKangXi=1376.091, RSKangXi=173.8
290E4 CJK UNIFIED IDEOGRAPH-#290E4, IRGKangXi=1376.091, RSKangXi=173.8
290E5 CJK UNIFIED IDEOGRAPH-#290E5, IRGKangXi=1376.091, RSKangXi=173.8
290E6 CJK UNIFIED IDEOGRAPH-#290E6, IRGKangXi=1376.091, RSKangXi=173.8
290E7 CJK UNIFIED IDEOGRAPH-#290E7, IRGKangXi=1376.091, RSKangXi=173.8
290E8 CJK UNIFIED IDEOGRAPH-#290E8, IRGKangXi=1376.091, RSKangXi=173.8
290E9 CJK UNIFIED IDEOGRAPH-#290E9, IRGKangXi=1376.091, RSKangXi=173.8
290EA CJK UNIFIED IDEOGRAPH-#290EA, IRGKangXi=1376.091, RSKangXi=173.8
290EB CJK UNIFIED IDEOGRAPH-#290EB, IRGKangXi=1376.091, RSKangXi=173.8
290EC CJK UNIFIED IDEOGRAPH-#290EC, IRGKangXi=1376.091, RSKangXi=173.8
290ED CJK UNIFIED IDEOGRAPH-#290ED, IRGKangXi=1376.091, RSKangXi=173.8
290EE CJK UNIFIED IDEOGRAPH-#290EE, IRGKangXi=1376.091, RSKangXi=173.8
290EF CJK UNIFIED IDEOGRAPH-#290EF, IRGKangXi=1376.091, RSKangXi=173.8
290F0 CJK UNIFIED IDEOGRAPH-#290F0, IRGKangXi=1376.091, RSKangXi=173.8
290F1 CJK UNIFIED IDEOGRAPH-#290F1, IRGKangXi=1376.091, RSKangXi=173.8
290F2 CJK UNIFIED IDEOGRAPH-#290F2, IRGKangXi=1376.091, RSKangXi=173.8
290F3 CJK UNIFIED IDEOGRAPH-#290F3, IRGKangXi=1376.091, RSKangXi=173.8
290F4 CJK UNIFIED IDEOGRAPH-#290F4, IRGKangXi=1376.091, RSKangXi=173.8
290F5 CJK UNIFIED IDEOGRAPH-#290F5, IRGKangXi=1376.110, RSKangXi=173.9
290F6 CJK UNIFIED IDEOGRAPH-#290F6, IRGKangXi=1376.130, RSKangXi=173.9
290F7 CJK UNIFIED IDEOGRAPH-#290F7, IRGKangXi=1376.140, RSKangXi=173.9
290F8 CJK UNIFIED IDEOGRAPH-#290F8, IRGKangXi=1376.210, RSKangXi=173.9
290F9 CJK UNIFIED IDEOGRAPH-#290F9, IRGKangXi=1376.220, RSKangXi=173.9
290FA CJK UNIFIED IDEOGRAPH-#290FA, IRGKangXi=1376.230, RSKangXi=173.9
290FB CJK UNIFIED IDEOGRAPH-#290FB, IRGKangXi=1376.250, RSKangXi=173.9
290FC CJK UNIFIED IDEOGRAPH-#290FC, IRGKangXi=1376.270, RSKangXi=173.9
290FD CJK UNIFIED IDEOGRAPH-#290FD, IRGKangXi=1376.280, RSKangXi=173.9
290FE CJK UNIFIED IDEOGRAPH-#290FE, IRGKangXi=1376.330, RSKangXi=173.9
290FF CJK UNIFIED IDEOGRAPH-#290FF, IRGKangXi=1377.020, RSKangXi=173.9
29100 CJK UNIFIED IDEOGRAPH-#29100, IRGKangXi=1377.030, RSKangXi=173.9
29101 CJK UNIFIED IDEOGRAPH-#29101, IRGKangXi=1377.031, RSKangXi=173.9
29102 CJK UNIFIED IDEOGRAPH-#29102, IRGKangXi=1377.031, RSKangXi=173.9
29103 CJK UNIFIED IDEOGRAPH-#29103, IRGKangXi=1377.031, RSKangXi=173.9
29104 CJK UNIFIED IDEOGRAPH-#29104, IRGKangXi=1377.031, RSKangXi=173.9
29105 CJK UNIFIED IDEOGRAPH-#29105, IRGKangXi=1377.031, RSKangXi=173.9
29106 CJK UNIFIED IDEOGRAPH-#29106, IRGKangXi=1377.031, RSKangXi=173.9
29107 CJK UNIFIED IDEOGRAPH-#29107, IRGKangXi=1377.031, RSKangXi=173.9
29108 CJK UNIFIED IDEOGRAPH-#29108, IRGKangXi=1377.031, RSKangXi=173.9
29109 CJK UNIFIED IDEOGRAPH-#29109, IRGKangXi=1377.031, RSKangXi=173.9
2910A CJK UNIFIED IDEOGRAPH-#2910A, IRGKangXi=1377.031, RSKangXi=173.9
2910B CJK UNIFIED IDEOGRAPH-#2910B, IRGKangXi=1377.031, RSKangXi=173.9
2910C CJK UNIFIED IDEOGRAPH-#2910C, IRGKangXi=1377.031, RSKangXi=173.9
2910D CJK UNIFIED IDEOGRAPH-#2910D, IRGKangXi=1377.031, RSKangXi=173.9
2910E CJK UNIFIED IDEOGRAPH-#2910E, IRGKangXi=1377.031, RSKangXi=173.9
2910F CJK UNIFIED IDEOGRAPH-#2910F, IRGKangXi=1377.031, RSKangXi=173.9
29110 CJK UNIFIED IDEOGRAPH-#29110, IRGKangXi=1377.031, RSKangXi=173.9
29111 CJK UNIFIED IDEOGRAPH-#29111, IRGKangXi=1377.031, RSKangXi=173.9
29112 CJK UNIFIED IDEOGRAPH-#29112, IRGKangXi=1377.031, RSKangXi=173.9
29113 CJK UNIFIED IDEOGRAPH-#29113, IRGKangXi=1377.031, RSKangXi=173.9
29114 CJK UNIFIED IDEOGRAPH-#29114, IRGKangXi=1377.031, RSKangXi=173.9
29115 CJK UNIFIED IDEOGRAPH-#29115, IRGKangXi=1377.031, RSKangXi=173.9
29116 CJK UNIFIED IDEOGRAPH-#29116, IRGKangXi=1377.031, RSKangXi=173.9
29117 CJK UNIFIED IDEOGRAPH-#29117, IRGKangXi=1377.031, RSKangXi=173.10
29118 CJK UNIFIED IDEOGRAPH-#29118, IRGKangXi=1377.040, RSKangXi=173.10
29119 CJK UNIFIED IDEOGRAPH-#29119, IRGKangXi=1377.050, RSKangXi=173.10
2911A CJK UNIFIED IDEOGRAPH-#2911A, IRGKangXi=1377.060, RSKangXi=173.10
2911B CJK UNIFIED IDEOGRAPH-#2911B, IRGKangXi=1377.070, RSKangXi=173.10
2911C CJK UNIFIED IDEOGRAPH-#2911C, IRGKangXi=1377.100, RSKangXi=173.10
2911D CJK UNIFIED IDEOGRAPH-#2911D, IRGKangXi=1377.120, RSKangXi=173.10
2911E CJK UNIFIED IDEOGRAPH-#2911E, IRGKangXi=1377.140, RSKangXi=173.10
2911F CJK UNIFIED IDEOGRAPH-#2911F, IRGKangXi=1377.150, RSKangXi=173.10
29120 CJK UNIFIED IDEOGRAPH-#29120, IRGKangXi=1377.210, RSKangXi=173.10
29121 CJK UNIFIED IDEOGRAPH-#29121, IRGKangXi=1377.230, RSKangXi=173.10
29122 CJK UNIFIED IDEOGRAPH-#29122, IRGKangXi=1377.240, RSKangXi=173.10
29123 CJK UNIFIED IDEOGRAPH-#29123, IRGKangXi=1377.260, RSKangXi=173.10
29124 CJK UNIFIED IDEOGRAPH-#29124, IRGKangXi=1377.270, RSKangXi=173.10
29125 CJK UNIFIED IDEOGRAPH-#29125, IRGKangXi=1377.280, RSKangXi=173.10
29126 CJK UNIFIED IDEOGRAPH-#29126, IRGKangXi=1377.310, RSKangXi=173.10
29127 CJK UNIFIED IDEOGRAPH-#29127, IRGKangXi=1377.320, RSKangXi=173.10
29128 CJK UNIFIED IDEOGRAPH-#29128, IRGKangXi=1377.321, RSKangXi=173.10
29129 CJK UNIFIED IDEOGRAPH-#29129, IRGKangXi=1377.321, RSKangXi=173.10
2912A CJK UNIFIED IDEOGRAPH-#2912A, IRGKangXi=1377.321, RSKangXi=173.10
2912B CJK UNIFIED IDEOGRAPH-#2912B, IRGKangXi=1377.321, RSKangXi=173.10
2912C CJK UNIFIED IDEOGRAPH-#2912C, IRGKangXi=1377.321, RSKangXi=173.10
2912D CJK UNIFIED IDEOGRAPH-#2912D, IRGKangXi=1377.321, RSKangXi=173.10
2912E CJK UNIFIED IDEOGRAPH-#2912E, IRGKangXi=1377.321, RSKangXi=162.14
2912F CJK UNIFIED IDEOGRAPH-#2912F, IRGKangXi=1377.321, RSKangXi=173.10
29130 CJK UNIFIED IDEOGRAPH-#29130, IRGKangXi=1377.321, RSKangXi=173.10
29131 CJK UNIFIED IDEOGRAPH-#29131, IRGKangXi=1377.321, RSKangXi=173.10
29132 CJK UNIFIED IDEOGRAPH-#29132, IRGKangXi=1377.321, RSKangXi=173.10
29133 CJK UNIFIED IDEOGRAPH-#29133, IRGKangXi=1377.321, RSKangXi=173.10
29134 CJK UNIFIED IDEOGRAPH-#29134, IRGKangXi=1377.321, RSKangXi=173.10
29135 CJK UNIFIED IDEOGRAPH-#29135, IRGKangXi=1377.321, RSKangXi=173.10
29136 CJK UNIFIED IDEOGRAPH-#29136, IRGKangXi=1377.321, RSKangXi=173.10
29137 CJK UNIFIED IDEOGRAPH-#29137, IRGKangXi=1377.321, RSKangXi=173.10
29138 CJK UNIFIED IDEOGRAPH-#29138, IRGKangXi=1377.321, RSKangXi=173.10
29139 CJK UNIFIED IDEOGRAPH-#29139, IRGKangXi=1377.321, RSKangXi=173.10
2913A CJK UNIFIED IDEOGRAPH-#2913A, IRGKangXi=1377.321, RSKangXi=173.10
2913B CJK UNIFIED IDEOGRAPH-#2913B, IRGKangXi=1377.340, RSKangXi=173.11
2913C CJK UNIFIED IDEOGRAPH-#2913C, IRGKangXi=1377.390, RSKangXi=173.11
2913D CJK UNIFIED IDEOGRAPH-#2913D, IRGKangXi=1377.400, RSKangXi=173.11
2913E CJK UNIFIED IDEOGRAPH-#2913E, IRGKangXi=1377.410, RSKangXi=173.11
2913F CJK UNIFIED IDEOGRAPH-#2913F, IRGKangXi=1377.420, RSKangXi=173.11
29140 CJK UNIFIED IDEOGRAPH-#29140, IRGKangXi=1377.440, RSKangXi=173.11
29141 CJK UNIFIED IDEOGRAPH-#29141, IRGKangXi=1377.470, RSKangXi=173.11
29142 CJK UNIFIED IDEOGRAPH-#29142, IRGKangXi=1377.490, RSKangXi=173.11
29143 CJK UNIFIED IDEOGRAPH-#29143, IRGKangXi=1377.500, RSKangXi=173.11
29144 CJK UNIFIED IDEOGRAPH-#29144, IRGKangXi=1377.510, RSKangXi=173.11
29145 CJK UNIFIED IDEOGRAPH-#29145, IRGKangXi=1378.010, RSKangXi=173.11
29146 CJK UNIFIED IDEOGRAPH-#29146, IRGKangXi=1378.020, RSKangXi=173.11
29147 CJK UNIFIED IDEOGRAPH-#29147, IRGKangXi=1378.030, RSKangXi=173.11
29148 CJK UNIFIED IDEOGRAPH-#29148, IRGKangXi=1378.040, RSKangXi=173.11
29149 CJK UNIFIED IDEOGRAPH-#29149, IRGKangXi=1378.041, RSKangXi=173.11
2914A CJK UNIFIED IDEOGRAPH-#2914A, IRGKangXi=1378.041, RSKangXi=173.11
2914B CJK UNIFIED IDEOGRAPH-#2914B, IRGKangXi=1378.041, RSKangXi=173.11
2914C CJK UNIFIED IDEOGRAPH-#2914C, IRGKangXi=1378.041, RSKangXi=173.11
2914D CJK UNIFIED IDEOGRAPH-#2914D, IRGKangXi=1378.041, RSKangXi=173.11
2914E CJK UNIFIED IDEOGRAPH-#2914E, IRGKangXi=1378.041, RSKangXi=173.11
2914F CJK UNIFIED IDEOGRAPH-#2914F, IRGKangXi=1378.041, RSKangXi=173.11
29150 CJK UNIFIED IDEOGRAPH-#29150, IRGKangXi=1378.041, RSKangXi=173.11
29151 CJK UNIFIED IDEOGRAPH-#29151, IRGKangXi=1378.041, RSKangXi=173.11
29152 CJK UNIFIED IDEOGRAPH-#29152, IRGKangXi=1378.041, RSKangXi=173.11
29153 CJK UNIFIED IDEOGRAPH-#29153, IRGKangXi=1378.041, RSKangXi=173.11
29154 CJK UNIFIED IDEOGRAPH-#29154, IRGKangXi=1378.041, RSKangXi=173.11
29155 CJK UNIFIED IDEOGRAPH-#29155, IRGKangXi=1378.041, RSKangXi=173.11
29156 CJK UNIFIED IDEOGRAPH-#29156, IRGKangXi=1378.041, RSKangXi=173.11
29157 CJK UNIFIED IDEOGRAPH-#29157, IRGKangXi=1378.041, RSKangXi=173.11
29158 CJK UNIFIED IDEOGRAPH-#29158, IRGKangXi=1378.041, RSKangXi=173.11
29159 CJK UNIFIED IDEOGRAPH-#29159, IRGKangXi=1378.041, RSKangXi=173.11
2915A CJK UNIFIED IDEOGRAPH-#2915A, IRGKangXi=1378.041, RSKangXi=173.11
2915B CJK UNIFIED IDEOGRAPH-#2915B, IRGKangXi=1378.041, RSKangXi=173.11
2915C CJK UNIFIED IDEOGRAPH-#2915C, IRGKangXi=1378.041, RSKangXi=173.11
2915D CJK UNIFIED IDEOGRAPH-#2915D, IRGKangXi=1378.050, RSKangXi=173.12
2915E CJK UNIFIED IDEOGRAPH-#2915E, IRGKangXi=1378.060, RSKangXi=173.12
2915F CJK UNIFIED IDEOGRAPH-#2915F, IRGKangXi=1378.070, RSKangXi=173.12
29160 CJK UNIFIED IDEOGRAPH-#29160, IRGKangXi=1378.080, RSKangXi=173.12
29161 CJK UNIFIED IDEOGRAPH-#29161, IRGKangXi=1378.110, RSKangXi=173.12
29162 CJK UNIFIED IDEOGRAPH-#29162, IRGKangXi=1378.130, RSKangXi=173.12
29163 CJK UNIFIED IDEOGRAPH-#29163, IRGKangXi=1378.140, RSKangXi=173.12
29164 CJK UNIFIED IDEOGRAPH-#29164, IRGKangXi=1378.150, RSKangXi=173.12
29165 CJK UNIFIED IDEOGRAPH-#29165, IRGKangXi=1378.180, RSKangXi=173.12
29166 CJK UNIFIED IDEOGRAPH-#29166, IRGKangXi=1378.190, RSKangXi=173.12
29167 CJK UNIFIED IDEOGRAPH-#29167, IRGKangXi=1378.200, RSKangXi=173.12
29168 CJK UNIFIED IDEOGRAPH-#29168, IRGKangXi=1378.240, RSKangXi=173.12
29169 CJK UNIFIED IDEOGRAPH-#29169, IRGKangXi=1378.270, RSKangXi=173.12
2916A CJK UNIFIED IDEOGRAPH-#2916A, IRGKangXi=1378.280, RSKangXi=173.12
2916B CJK UNIFIED IDEOGRAPH-#2916B, IRGKangXi=1378.281, RSKangXi=173.12
2916C CJK UNIFIED IDEOGRAPH-#2916C, IRGKangXi=1378.281, RSKangXi=173.12
2916D CJK UNIFIED IDEOGRAPH-#2916D, IRGKangXi=1378.281, RSKangXi=173.12
2916E CJK UNIFIED IDEOGRAPH-#2916E, IRGKangXi=1378.281, RSKangXi=173.12
2916F CJK UNIFIED IDEOGRAPH-#2916F, IRGKangXi=1378.281, RSKangXi=173.12
29170 CJK UNIFIED IDEOGRAPH-#29170, IRGKangXi=1378.281, RSKangXi=173.12
29171 CJK UNIFIED IDEOGRAPH-#29171, IRGKangXi=1378.281, RSKangXi=173.12
29172 CJK UNIFIED IDEOGRAPH-#29172, IRGKangXi=1378.281, RSKangXi=173.12
29173 CJK UNIFIED IDEOGRAPH-#29173, IRGKangXi=1378.281, RSKangXi=173.12
29174 CJK UNIFIED IDEOGRAPH-#29174, IRGKangXi=1378.281, RSKangXi=173.12
29175 CJK UNIFIED IDEOGRAPH-#29175, IRGKangXi=1378.281, RSKangXi=173.12
29176 CJK UNIFIED IDEOGRAPH-#29176, IRGKangXi=1378.281, RSKangXi=173.12
29177 CJK UNIFIED IDEOGRAPH-#29177, IRGKangXi=1378.281, RSKangXi=173.12
29178 CJK UNIFIED IDEOGRAPH-#29178, IRGKangXi=1378.281, RSKangXi=173.12
29179 CJK UNIFIED IDEOGRAPH-#29179, IRGKangXi=1378.281, RSKangXi=173.12
2917A CJK UNIFIED IDEOGRAPH-#2917A, IRGKangXi=1378.281, RSKangXi=173.12
2917B CJK UNIFIED IDEOGRAPH-#2917B, IRGKangXi=1378.281, RSKangXi=173.12, Def{pelting rain}
2917C CJK UNIFIED IDEOGRAPH-#2917C, IRGKangXi=1379.010, RSKangXi=173.13
2917D CJK UNIFIED IDEOGRAPH-#2917D, IRGKangXi=1379.020, RSKangXi=173.13
2917E CJK UNIFIED IDEOGRAPH-#2917E, IRGKangXi=1379.030, RSKangXi=173.13
2917F CJK UNIFIED IDEOGRAPH-#2917F, IRGKangXi=1379.040, RSKangXi=173.13
29180 CJK UNIFIED IDEOGRAPH-#29180, IRGKangXi=1379.050, RSKangXi=173.13
29181 CJK UNIFIED IDEOGRAPH-#29181, IRGKangXi=1379.060, RSKangXi=173.13
29182 CJK UNIFIED IDEOGRAPH-#29182, IRGKangXi=1379.070, RSKangXi=173.13
29183 CJK UNIFIED IDEOGRAPH-#29183, IRGKangXi=1379.080, RSKangXi=173.13
29184 CJK UNIFIED IDEOGRAPH-#29184, IRGKangXi=1379.090, RSKangXi=173.13
29185 CJK UNIFIED IDEOGRAPH-#29185, IRGKangXi=1379.110, RSKangXi=173.13
29186 CJK UNIFIED IDEOGRAPH-#29186, IRGKangXi=1379.170, RSKangXi=173.13
29187 CJK UNIFIED IDEOGRAPH-#29187, IRGKangXi=1379.180, RSKangXi=173.13
29188 CJK UNIFIED IDEOGRAPH-#29188, IRGKangXi=1379.190, RSKangXi=173.13
29189 CJK UNIFIED IDEOGRAPH-#29189, IRGKangXi=1379.200, RSKangXi=173.13
2918A CJK UNIFIED IDEOGRAPH-#2918A, IRGKangXi=1379.201, RSKangXi=173.13
2918B CJK UNIFIED IDEOGRAPH-#2918B, IRGKangXi=1379.201, RSKangXi=173.13
2918C CJK UNIFIED IDEOGRAPH-#2918C, IRGKangXi=1379.201, RSKangXi=173.13
2918D CJK UNIFIED IDEOGRAPH-#2918D, IRGKangXi=1379.201, RSKangXi=173.13
2918E CJK UNIFIED IDEOGRAPH-#2918E, IRGKangXi=1379.201, RSKangXi=173.13
2918F CJK UNIFIED IDEOGRAPH-#2918F, IRGKangXi=1379.201, RSKangXi=173.13
29190 CJK UNIFIED IDEOGRAPH-#29190, IRGKangXi=1379.201, RSKangXi=173.13
29191 CJK UNIFIED IDEOGRAPH-#29191, IRGKangXi=1379.230, RSKangXi=173.14
29192 CJK UNIFIED IDEOGRAPH-#29192, IRGKangXi=1379.240, RSKangXi=173.14
29193 CJK UNIFIED IDEOGRAPH-#29193, IRGKangXi=1379.280, RSKangXi=173.14
29194 CJK UNIFIED IDEOGRAPH-#29194, IRGKangXi=1379.290, RSKangXi=173.14
29195 CJK UNIFIED IDEOGRAPH-#29195, IRGKangXi=1380.030, RSKangXi=173.14
29196 CJK UNIFIED IDEOGRAPH-#29196, IRGKangXi=1380.040, RSKangXi=173.14
29197 CJK UNIFIED IDEOGRAPH-#29197, IRGKangXi=1380.050, RSKangXi=173.14
29198 CJK UNIFIED IDEOGRAPH-#29198, IRGKangXi=1380.060, RSKangXi=173.14
29199 CJK UNIFIED IDEOGRAPH-#29199, IRGKangXi=1380.070, RSKangXi=173.14
2919A CJK UNIFIED IDEOGRAPH-#2919A, IRGKangXi=1380.080, RSKangXi=173.14
2919B CJK UNIFIED IDEOGRAPH-#2919B, IRGKangXi=1380.081, RSKangXi=173.14
2919C CJK UNIFIED IDEOGRAPH-#2919C, IRGKangXi=1380.081, RSKangXi=173.14
2919D CJK UNIFIED IDEOGRAPH-#2919D, IRGKangXi=1380.081, RSKangXi=173.14
2919E CJK UNIFIED IDEOGRAPH-#2919E, IRGKangXi=1380.081, RSKangXi=173.14
2919F CJK UNIFIED IDEOGRAPH-#2919F, IRGKangXi=1380.081, RSKangXi=173.14
291A0 CJK UNIFIED IDEOGRAPH-#291A0, IRGKangXi=1380.081, RSKangXi=173.14
291A1 CJK UNIFIED IDEOGRAPH-#291A1, IRGKangXi=1380.081, RSKangXi=173.14
291A2 CJK UNIFIED IDEOGRAPH-#291A2, IRGKangXi=1380.081, RSKangXi=173.14
291A3 CJK UNIFIED IDEOGRAPH-#291A3, IRGKangXi=1380.081, RSKangXi=173.14
291A4 CJK UNIFIED IDEOGRAPH-#291A4, IRGKangXi=1380.100, RSKangXi=173.15
291A5 CJK UNIFIED IDEOGRAPH-#291A5, IRGKangXi=1380.120, RSKangXi=173.15
291A6 CJK UNIFIED IDEOGRAPH-#291A6, IRGKangXi=1380.130, RSKangXi=173.15
291A7 CJK UNIFIED IDEOGRAPH-#291A7, IRGKangXi=1380.131, RSKangXi=173.15
291A8 CJK UNIFIED IDEOGRAPH-#291A8, IRGKangXi=1380.131, RSKangXi=173.15
291A9 CJK UNIFIED IDEOGRAPH-#291A9, IRGKangXi=1380.131, RSKangXi=173.15
291AA CJK UNIFIED IDEOGRAPH-#291AA, IRGKangXi=1380.131, RSKangXi=173.15
291AB CJK UNIFIED IDEOGRAPH-#291AB, IRGKangXi=1380.131, RSKangXi=173.15
291AC CJK UNIFIED IDEOGRAPH-#291AC, IRGKangXi=1380.131, RSKangXi=173.15
291AD CJK UNIFIED IDEOGRAPH-#291AD, IRGKangXi=1380.140, RSKangXi=173.16
291AE CJK UNIFIED IDEOGRAPH-#291AE, IRGKangXi=1380.160, RSKangXi=173.16
291AF CJK UNIFIED IDEOGRAPH-#291AF, IRGKangXi=1380.200, RSKangXi=173.16
291B0 CJK UNIFIED IDEOGRAPH-#291B0, IRGKangXi=1380.210, RSKangXi=173.16
291B1 CJK UNIFIED IDEOGRAPH-#291B1, IRGKangXi=1380.300, RSKangXi=173.16
291B2 CJK UNIFIED IDEOGRAPH-#291B2, IRGKangXi=1380.310, RSKangXi=173.16
291B3 CJK UNIFIED IDEOGRAPH-#291B3, IRGKangXi=1380.311, RSKangXi=173.16
291B4 CJK UNIFIED IDEOGRAPH-#291B4, IRGKangXi=1380.311, RSKangXi=173.16
291B5 CJK UNIFIED IDEOGRAPH-#291B5, IRGKangXi=1380.320, RSKangXi=173.17
291B6 CJK UNIFIED IDEOGRAPH-#291B6, IRGKangXi=1380.330, RSKangXi=173.17
291B7 CJK UNIFIED IDEOGRAPH-#291B7, IRGKangXi=1380.340, RSKangXi=173.17
291B8 CJK UNIFIED IDEOGRAPH-#291B8, IRGKangXi=1381.030, RSKangXi=173.17
291B9 CJK UNIFIED IDEOGRAPH-#291B9, IRGKangXi=1381.040, RSKangXi=173.17
291BA CJK UNIFIED IDEOGRAPH-#291BA, IRGKangXi=1381.050, RSKangXi=173.17
291BB CJK UNIFIED IDEOGRAPH-#291BB, IRGKangXi=1381.051, RSKangXi=173.17
291BC CJK UNIFIED IDEOGRAPH-#291BC, IRGKangXi=1381.051, RSKangXi=173.17
291BD CJK UNIFIED IDEOGRAPH-#291BD, IRGKangXi=1381.051, RSKangXi=173.17
291BE CJK UNIFIED IDEOGRAPH-#291BE, IRGKangXi=1381.051, RSKangXi=173.17
291BF CJK UNIFIED IDEOGRAPH-#291BF, IRGKangXi=1381.060, RSKangXi=173.18
291C0 CJK UNIFIED IDEOGRAPH-#291C0, IRGKangXi=1381.080, RSKangXi=173.18
291C1 CJK UNIFIED IDEOGRAPH-#291C1, IRGKangXi=1381.090, RSKangXi=173.18
291C2 CJK UNIFIED IDEOGRAPH-#291C2, IRGKangXi=1381.091, RSKangXi=173.18
291C3 CJK UNIFIED IDEOGRAPH-#291C3, IRGKangXi=1381.091, RSKangXi=173.18
291C4 CJK UNIFIED IDEOGRAPH-#291C4, IRGKangXi=1381.091, RSKangXi=173.18
291C5 CJK UNIFIED IDEOGRAPH-#291C5, IRGKangXi=1381.091, RSKangXi=173.18
291C6 CJK UNIFIED IDEOGRAPH-#291C6, IRGKangXi=1381.091, RSKangXi=173.18
291C7 CJK UNIFIED IDEOGRAPH-#291C7, IRGKangXi=1381.091, RSKangXi=173.18
291C8 CJK UNIFIED IDEOGRAPH-#291C8, IRGKangXi=1381.111, RSKangXi=173.20
291C9 CJK UNIFIED IDEOGRAPH-#291C9, IRGKangXi=1381.111, RSKangXi=173.20
291CA CJK UNIFIED IDEOGRAPH-#291CA, IRGKangXi=1381.120, RSKangXi=173.21
291CB CJK UNIFIED IDEOGRAPH-#291CB, IRGKangXi=1381.130, RSKangXi=173.21
291CC CJK UNIFIED IDEOGRAPH-#291CC, IRGKangXi=1381.140, RSKangXi=173.21
291CD CJK UNIFIED IDEOGRAPH-#291CD, IRGKangXi=1381.141, RSKangXi=173.21
291CE CJK UNIFIED IDEOGRAPH-#291CE, IRGKangXi=1381.141, RSKangXi=173.21
291CF CJK UNIFIED IDEOGRAPH-#291CF, IRGKangXi=1381.141, RSKangXi=173.23
291D0 CJK UNIFIED IDEOGRAPH-#291D0, IRGKangXi=1381.141, RSKangXi=173.24
291D1 CJK UNIFIED IDEOGRAPH-#291D1, IRGKangXi=1381.141, RSKangXi=173.24
291D2 CJK UNIFIED IDEOGRAPH-#291D2, IRGKangXi=1381.151, RSKangXi=173.30
291D3 CJK UNIFIED IDEOGRAPH-#291D3, IRGKangXi=1381.170, RSKangXi=173.32
291D4 CJK UNIFIED IDEOGRAPH-#291D4, IRGKangXi=1381.171, RSKangXi=173.40
291D5 CJK UNIFIED IDEOGRAPH-#291D5, IRGKangXi=1381.250, RSKangXi=174.3
291D6 CJK UNIFIED IDEOGRAPH-#291D6, IRGKangXi=1381.261, RSKangXi=174.4
291D7 CJK UNIFIED IDEOGRAPH-#291D7, IRGKangXi=1381.261, RSKangXi=174.4
291D8 CJK UNIFIED IDEOGRAPH-#291D8, IRGKangXi=1381.281, RSKangXi=174.5
291D9 CJK UNIFIED IDEOGRAPH-#291D9, IRGKangXi=1381.281, RSKangXi=174.5
291DA CJK UNIFIED IDEOGRAPH-#291DA, IRGKangXi=1381.281, RSKangXi=174.5
291DB CJK UNIFIED IDEOGRAPH-#291DB, IRGKangXi=1381.281, RSKangXi=174.5
291DC CJK UNIFIED IDEOGRAPH-#291DC, IRGKangXi=1381.290, RSKangXi=174.6
291DD CJK UNIFIED IDEOGRAPH-#291DD, IRGKangXi=1382.010, RSKangXi=174.8
291DE CJK UNIFIED IDEOGRAPH-#291DE, IRGKangXi=1382.050, RSKangXi=174.8
291DF CJK UNIFIED IDEOGRAPH-#291DF, IRGKangXi=1382.060, RSKangXi=174.9
291E0 CJK UNIFIED IDEOGRAPH-#291E0, IRGKangXi=1382.080, RSKangXi=174.10
291E1 CJK UNIFIED IDEOGRAPH-#291E1, IRGKangXi=1382.081, RSKangXi=174.11
291E2 CJK UNIFIED IDEOGRAPH-#291E2, IRGKangXi=1382.081, RSKangXi=174.12
291E3 CJK UNIFIED IDEOGRAPH-#291E3, IRGKangXi=1382.090, RSKangXi=174.13
291E4 CJK UNIFIED IDEOGRAPH-#291E4, IRGKangXi=1382.101, RSKangXi=174.16
291E5 CJK UNIFIED IDEOGRAPH-#291E5, IRGKangXi=1382.101, RSKangXi=174.17
291E6 CJK UNIFIED IDEOGRAPH-#291E6, IRGKangXi=1382.111, RSKangXi=175.2
291E7 CJK UNIFIED IDEOGRAPH-#291E7, IRGKangXi=1382.120, RSKangXi=175.2
291E8 CJK UNIFIED IDEOGRAPH-#291E8, IRGKangXi=1382.130, RSKangXi=175.2
291E9 CJK UNIFIED IDEOGRAPH-#291E9, IRGKangXi=1382.140, RSKangXi=175.3
291EA CJK UNIFIED IDEOGRAPH-#291EA, IRGKangXi=1382.160, RSKangXi=175.3
291EB CJK UNIFIED IDEOGRAPH-#291EB, IRGKangXi=1382.190, RSKangXi=175.3
291EC CJK UNIFIED IDEOGRAPH-#291EC, IRGKangXi=1382.191, RSKangXi=175.3
291ED CJK UNIFIED IDEOGRAPH-#291ED, IRGKangXi=1382.200, RSKangXi=175.4
291EE CJK UNIFIED IDEOGRAPH-#291EE, IRGKangXi=1382.210, RSKangXi=175.4
291EF CJK UNIFIED IDEOGRAPH-#291EF, IRGKangXi=1382.230, RSKangXi=175.4
291F0 CJK UNIFIED IDEOGRAPH-#291F0, IRGKangXi=1382.250, RSKangXi=175.4
291F1 CJK UNIFIED IDEOGRAPH-#291F1, IRGKangXi=1382.260, RSKangXi=175.4
291F2 CJK UNIFIED IDEOGRAPH-#291F2, IRGKangXi=1382.261, RSKangXi=175.4
291F3 CJK UNIFIED IDEOGRAPH-#291F3, IRGKangXi=1382.261, RSKangXi=175.4
291F4 CJK UNIFIED IDEOGRAPH-#291F4, IRGKangXi=1382.261, RSKangXi=175.4
291F5 CJK UNIFIED IDEOGRAPH-#291F5, IRGKangXi=1382.270, RSKangXi=175.5
291F6 CJK UNIFIED IDEOGRAPH-#291F6, IRGKangXi=1382.280, RSKangXi=175.5
291F7 CJK UNIFIED IDEOGRAPH-#291F7, IRGKangXi=1382.281, RSKangXi=175.6
291F8 CJK UNIFIED IDEOGRAPH-#291F8, IRGKangXi=1382.300, RSKangXi=175.7
291F9 CJK UNIFIED IDEOGRAPH-#291F9, IRGKangXi=1382.310, RSKangXi=175.7
291FA CJK UNIFIED IDEOGRAPH-#291FA, IRGKangXi=1383.011, RSKangXi=175.7
291FB CJK UNIFIED IDEOGRAPH-#291FB, IRGKangXi=1383.011, RSKangXi=175.7
291FC CJK UNIFIED IDEOGRAPH-#291FC, IRGKangXi=1383.011, RSKangXi=175.8
291FD CJK UNIFIED IDEOGRAPH-#291FD, IRGKangXi=1383.011, RSKangXi=175.10
291FE CJK UNIFIED IDEOGRAPH-#291FE, IRGKangXi=1383.040, RSKangXi=175.12
291FF CJK UNIFIED IDEOGRAPH-#291FF, IRGKangXi=1383.060, RSKangXi=175.12
29200 CJK UNIFIED IDEOGRAPH-#29200, IRGKangXi=1383.061, RSKangXi=175.12
29201 CJK UNIFIED IDEOGRAPH-#29201, IRGKangXi=1383.061, RSKangXi=175.12
29202 CJK UNIFIED IDEOGRAPH-#29202, IRGKangXi=1383.061, RSKangXi=175.18
29203 CJK UNIFIED IDEOGRAPH-#29203, IRGKangXi=1383.080, RSKangXi=176.3
29204 CJK UNIFIED IDEOGRAPH-#29204, IRGKangXi=1383.090, RSKangXi=176.3
29205 CJK UNIFIED IDEOGRAPH-#29205, IRGKangXi=1383.100, RSKangXi=176.3
29206 CJK UNIFIED IDEOGRAPH-#29206, IRGKangXi=1383.110, RSKangXi=176.4
29207 CJK UNIFIED IDEOGRAPH-#29207, IRGKangXi=1383.130, RSKangXi=176.4
29208 CJK UNIFIED IDEOGRAPH-#29208, IRGKangXi=1383.140, RSKangXi=176.4
29209 CJK UNIFIED IDEOGRAPH-#29209, IRGKangXi=1383.150, RSKangXi=176.4
2920A CJK UNIFIED IDEOGRAPH-#2920A, IRGKangXi=1383.161, RSKangXi=176.4
2920B CJK UNIFIED IDEOGRAPH-#2920B, IRGKangXi=1383.161, RSKangXi=176.4
2920C CJK UNIFIED IDEOGRAPH-#2920C, IRGKangXi=1383.161, RSKangXi=176.4
2920D CJK UNIFIED IDEOGRAPH-#2920D, IRGKangXi=1383.170, RSKangXi=176.5
2920E CJK UNIFIED IDEOGRAPH-#2920E, IRGKangXi=1383.180, RSKangXi=176.5
2920F CJK UNIFIED IDEOGRAPH-#2920F, IRGKangXi=1383.190, RSKangXi=176.5
29210 CJK UNIFIED IDEOGRAPH-#29210, IRGKangXi=1383.210, RSKangXi=176.5
29211 CJK UNIFIED IDEOGRAPH-#29211, IRGKangXi=1383.220, RSKangXi=176.5
29212 CJK UNIFIED IDEOGRAPH-#29212, IRGKangXi=1384.021, RSKangXi=176.5
29213 CJK UNIFIED IDEOGRAPH-#29213, IRGKangXi=1384.021, RSKangXi=176.5
29214 CJK UNIFIED IDEOGRAPH-#29214, IRGKangXi=1384.021, RSKangXi=176.5
29215 CJK UNIFIED IDEOGRAPH-#29215, IRGKangXi=1384.021, RSKangXi=176.5
29216 CJK UNIFIED IDEOGRAPH-#29216, IRGKangXi=1384.021, RSKangXi=176.5
29217 CJK UNIFIED IDEOGRAPH-#29217, IRGKangXi=1384.021, RSKangXi=176.5
29218 CJK UNIFIED IDEOGRAPH-#29218, IRGKangXi=1384.021, RSKangXi=176.5
29219 CJK UNIFIED IDEOGRAPH-#29219, IRGKangXi=1384.030, RSKangXi=176.6
2921A CJK UNIFIED IDEOGRAPH-#2921A, IRGKangXi=1384.040, RSKangXi=176.6
2921B CJK UNIFIED IDEOGRAPH-#2921B, IRGKangXi=1384.050, RSKangXi=176.6
2921C CJK UNIFIED IDEOGRAPH-#2921C, IRGKangXi=1384.060, RSKangXi=176.6
2921D CJK UNIFIED IDEOGRAPH-#2921D, IRGKangXi=1384.070, RSKangXi=176.6
2921E CJK UNIFIED IDEOGRAPH-#2921E, IRGKangXi=1384.071, RSKangXi=176.6
2921F CJK UNIFIED IDEOGRAPH-#2921F, IRGKangXi=1384.071, RSKangXi=176.6
29220 CJK UNIFIED IDEOGRAPH-#29220, IRGKangXi=1384.071, RSKangXi=176.6
29221 CJK UNIFIED IDEOGRAPH-#29221, IRGKangXi=1384.090, RSKangXi=176.7
29222 CJK UNIFIED IDEOGRAPH-#29222, IRGKangXi=1384.100, RSKangXi=176.7
29223 CJK UNIFIED IDEOGRAPH-#29223, IRGKangXi=1384.110, RSKangXi=176.7
29224 CJK UNIFIED IDEOGRAPH-#29224, IRGKangXi=1384.120, RSKangXi=176.7
29225 CJK UNIFIED IDEOGRAPH-#29225, IRGKangXi=1384.130, RSKangXi=176.7
29226 CJK UNIFIED IDEOGRAPH-#29226, IRGKangXi=1384.160, RSKangXi=176.7
29227 CJK UNIFIED IDEOGRAPH-#29227, IRGKangXi=1384.161, RSKangXi=176.7
29228 CJK UNIFIED IDEOGRAPH-#29228, IRGKangXi=1384.161, RSKangXi=176.7
29229 CJK UNIFIED IDEOGRAPH-#29229, IRGKangXi=1384.161, RSKangXi=176.7
2922A CJK UNIFIED IDEOGRAPH-#2922A, IRGKangXi=1384.161, RSKangXi=176.7
2922B CJK UNIFIED IDEOGRAPH-#2922B, IRGKangXi=1384.170, RSKangXi=176.8
2922C CJK UNIFIED IDEOGRAPH-#2922C, IRGKangXi=1384.180, RSKangXi=176.8
2922D CJK UNIFIED IDEOGRAPH-#2922D, IRGKangXi=1384.200, RSKangXi=176.8
2922E CJK UNIFIED IDEOGRAPH-#2922E, IRGKangXi=1384.210, RSKangXi=176.8
2922F CJK UNIFIED IDEOGRAPH-#2922F, IRGKangXi=1384.220, RSKangXi=176.8
29230 CJK UNIFIED IDEOGRAPH-#29230, IRGKangXi=1384.221, RSKangXi=176.8
29231 CJK UNIFIED IDEOGRAPH-#29231, IRGKangXi=1384.221, RSKangXi=176.8
29232 CJK UNIFIED IDEOGRAPH-#29232, IRGKangXi=1384.230, RSKangXi=176.9
29233 CJK UNIFIED IDEOGRAPH-#29233, IRGKangXi=1384.240, RSKangXi=176.9
29234 CJK UNIFIED IDEOGRAPH-#29234, IRGKangXi=1384.250, RSKangXi=176.9
29235 CJK UNIFIED IDEOGRAPH-#29235, IRGKangXi=1384.260, RSKangXi=176.9
29236 CJK UNIFIED IDEOGRAPH-#29236, IRGKangXi=1384.270, RSKangXi=176.9
29237 CJK UNIFIED IDEOGRAPH-#29237, IRGKangXi=1384.271, RSKangXi=176.9
29238 CJK UNIFIED IDEOGRAPH-#29238, IRGKangXi=1384.280, RSKangXi=176.10
29239 CJK UNIFIED IDEOGRAPH-#29239, IRGKangXi=1384.290, RSKangXi=176.10
2923A CJK UNIFIED IDEOGRAPH-#2923A, IRGKangXi=1384.291, RSKangXi=176.10
2923B CJK UNIFIED IDEOGRAPH-#2923B, IRGKangXi=1384.300, RSKangXi=176.11
2923C CJK UNIFIED IDEOGRAPH-#2923C, IRGKangXi=1384.320, RSKangXi=176.11
2923D CJK UNIFIED IDEOGRAPH-#2923D, IRGKangXi=1384.330, RSKangXi=176.11
2923E CJK UNIFIED IDEOGRAPH-#2923E, IRGKangXi=1384.331, RSKangXi=176.11
2923F CJK UNIFIED IDEOGRAPH-#2923F, IRGKangXi=1384.331, RSKangXi=176.11
29240 CJK UNIFIED IDEOGRAPH-#29240, IRGKangXi=1384.331, RSKangXi=176.11
29241 CJK UNIFIED IDEOGRAPH-#29241, IRGKangXi=1384.340, RSKangXi=176.12
29242 CJK UNIFIED IDEOGRAPH-#29242, IRGKangXi=1384.350, RSKangXi=176.12
29243 CJK UNIFIED IDEOGRAPH-#29243, IRGKangXi=1384.380, RSKangXi=176.12
29244 CJK UNIFIED IDEOGRAPH-#29244, IRGKangXi=1384.400, RSKangXi=176.12
29245 CJK UNIFIED IDEOGRAPH-#29245, IRGKangXi=1384.401, RSKangXi=176.12
29246 CJK UNIFIED IDEOGRAPH-#29246, IRGKangXi=1384.401, RSKangXi=176.12
29247 CJK UNIFIED IDEOGRAPH-#29247, IRGKangXi=1384.401, RSKangXi=176.12
29248 CJK UNIFIED IDEOGRAPH-#29248, IRGKangXi=1384.401, RSKangXi=176.12
29249 CJK UNIFIED IDEOGRAPH-#29249, IRGKangXi=1384.401, RSKangXi=176.12
2924A CJK UNIFIED IDEOGRAPH-#2924A, IRGKangXi=1384.410, RSKangXi=176.13
2924B CJK UNIFIED IDEOGRAPH-#2924B, IRGKangXi=1384.411, RSKangXi=176.13
2924C CJK UNIFIED IDEOGRAPH-#2924C, IRGKangXi=1384.420, RSKangXi=176.14
2924D CJK UNIFIED IDEOGRAPH-#2924D, IRGKangXi=1384.430, RSKangXi=176.14
2924E CJK UNIFIED IDEOGRAPH-#2924E, IRGKangXi=1384.441, RSKangXi=176.14
2924F CJK UNIFIED IDEOGRAPH-#2924F, IRGKangXi=1384.441, RSKangXi=176.14
29250 CJK UNIFIED IDEOGRAPH-#29250, IRGKangXi=1384.441, RSKangXi=176.14
29251 CJK UNIFIED IDEOGRAPH-#29251, IRGKangXi=1384.460, RSKangXi=176.15
29252 CJK UNIFIED IDEOGRAPH-#29252, IRGKangXi=1384.461, RSKangXi=176.15
29253 CJK UNIFIED IDEOGRAPH-#29253, IRGKangXi=1384.461, RSKangXi=176.16
29254 CJK UNIFIED IDEOGRAPH-#29254, IRGKangXi=1384.470, RSKangXi=176.17
29255 CJK UNIFIED IDEOGRAPH-#29255, IRGKangXi=1384.471, RSKangXi=176.17
29256 CJK UNIFIED IDEOGRAPH-#29256, IRGKangXi=1384.480, RSKangXi=176.18
29257 CJK UNIFIED IDEOGRAPH-#29257, IRGKangXi=1384.481, RSKangXi=176.18
29258 CJK UNIFIED IDEOGRAPH-#29258, IRGKangXi=1384.481, RSKangXi=176.18
29259 CJK UNIFIED IDEOGRAPH-#29259, IRGKangXi=1384.490, RSKangXi=176.19
2925A CJK UNIFIED IDEOGRAPH-#2925A, IRGKangXi=1384.500, RSKangXi=176.19
2925B CJK UNIFIED IDEOGRAPH-#2925B, IRGKangXi=1385.031, RSKangXi=177.2
2925C CJK UNIFIED IDEOGRAPH-#2925C, IRGKangXi=1385.031, RSKangXi=177.2
2925D CJK UNIFIED IDEOGRAPH-#2925D, IRGKangXi=1385.080, RSKangXi=177.3
2925E CJK UNIFIED IDEOGRAPH-#2925E, IRGKangXi=1385.130, RSKangXi=177.3
2925F CJK UNIFIED IDEOGRAPH-#2925F, IRGKangXi=1385.131, RSKangXi=177.3
29260 CJK UNIFIED IDEOGRAPH-#29260, IRGKangXi=1385.131, RSKangXi=177.3
29261 CJK UNIFIED IDEOGRAPH-#29261, IRGKangXi=1385.150, RSKangXi=177.4
29262 CJK UNIFIED IDEOGRAPH-#29262, IRGKangXi=1385.160, RSKangXi=177.4
29263 CJK UNIFIED IDEOGRAPH-#29263, IRGKangXi=1385.170, RSKangXi=177.4
29264 CJK UNIFIED IDEOGRAPH-#29264, IRGKangXi=1385.210, RSKangXi=177.4
29265 CJK UNIFIED IDEOGRAPH-#29265, IRGKangXi=1385.230, RSKangXi=177.4
29266 CJK UNIFIED IDEOGRAPH-#29266, IRGKangXi=1386.010, RSKangXi=177.4
29267 CJK UNIFIED IDEOGRAPH-#29267, IRGKangXi=1386.020, RSKangXi=177.4
29268 CJK UNIFIED IDEOGRAPH-#29268, IRGKangXi=1386.030, RSKangXi=177.4
29269 CJK UNIFIED IDEOGRAPH-#29269, IRGKangXi=1386.040, RSKangXi=177.4
2926A CJK UNIFIED IDEOGRAPH-#2926A, IRGKangXi=1386.050, RSKangXi=177.4
2926B CJK UNIFIED IDEOGRAPH-#2926B, IRGKangXi=1386.060, RSKangXi=177.4
2926C CJK UNIFIED IDEOGRAPH-#2926C, IRGKangXi=1386.090, RSKangXi=177.4
2926D CJK UNIFIED IDEOGRAPH-#2926D, IRGKangXi=1386.101, RSKangXi=177.4
2926E CJK UNIFIED IDEOGRAPH-#2926E, IRGKangXi=1386.101, RSKangXi=177.4
2926F CJK UNIFIED IDEOGRAPH-#2926F, IRGKangXi=1386.101, RSKangXi=177.4
29270 CJK UNIFIED IDEOGRAPH-#29270, IRGKangXi=1386.101, RSKangXi=177.4
29271 CJK UNIFIED IDEOGRAPH-#29271, IRGKangXi=1386.101, RSKangXi=177.4
29272 CJK UNIFIED IDEOGRAPH-#29272, IRGKangXi=1386.101, RSKangXi=177.4
29273 CJK UNIFIED IDEOGRAPH-#29273, IRGKangXi=1386.101, RSKangXi=177.4
29274 CJK UNIFIED IDEOGRAPH-#29274, IRGKangXi=1386.101, RSKangXi=177.4
29275 CJK UNIFIED IDEOGRAPH-#29275, IRGKangXi=1386.101, RSKangXi=177.4
29276 CJK UNIFIED IDEOGRAPH-#29276, IRGKangXi=1386.101, RSKangXi=177.4
29277 CJK UNIFIED IDEOGRAPH-#29277, IRGKangXi=1386.101, RSKangXi=177.4
29278 CJK UNIFIED IDEOGRAPH-#29278, IRGKangXi=1386.130, RSKangXi=177.5
29279 CJK UNIFIED IDEOGRAPH-#29279, IRGKangXi=1386.140, RSKangXi=177.5
2927A CJK UNIFIED IDEOGRAPH-#2927A, IRGKangXi=1386.150, RSKangXi=177.5
2927B CJK UNIFIED IDEOGRAPH-#2927B, IRGKangXi=1386.160, RSKangXi=177.5
2927C CJK UNIFIED IDEOGRAPH-#2927C, IRGKangXi=1386.190, RSKangXi=177.5
2927D CJK UNIFIED IDEOGRAPH-#2927D, IRGKangXi=1386.250, RSKangXi=177.5
2927E CJK UNIFIED IDEOGRAPH-#2927E, IRGKangXi=1386.290, RSKangXi=177.5
2927F CJK UNIFIED IDEOGRAPH-#2927F, IRGKangXi=1386.320, RSKangXi=177.5
29280 CJK UNIFIED IDEOGRAPH-#29280, IRGKangXi=1386.340, RSKangXi=177.5
29281 CJK UNIFIED IDEOGRAPH-#29281, IRGKangXi=1386.350, RSKangXi=177.5
29282 CJK UNIFIED IDEOGRAPH-#29282, IRGKangXi=1386.390, RSKangXi=177.5
29283 CJK UNIFIED IDEOGRAPH-#29283, IRGKangXi=1386.400, RSKangXi=177.5
29284 CJK UNIFIED IDEOGRAPH-#29284, IRGKangXi=1387.010, RSKangXi=177.5
29285 CJK UNIFIED IDEOGRAPH-#29285, IRGKangXi=1387.020, RSKangXi=177.5
29286 CJK UNIFIED IDEOGRAPH-#29286, IRGKangXi=1387.030, RSKangXi=177.5
29287 CJK UNIFIED IDEOGRAPH-#29287, IRGKangXi=1387.031, RSKangXi=177.5
29288 CJK UNIFIED IDEOGRAPH-#29288, IRGKangXi=1387.031, RSKangXi=177.5
29289 CJK UNIFIED IDEOGRAPH-#29289, IRGKangXi=1387.031, RSKangXi=177.5
2928A CJK UNIFIED IDEOGRAPH-#2928A, IRGKangXi=1387.031, RSKangXi=177.5
2928B CJK UNIFIED IDEOGRAPH-#2928B, IRGKangXi=1387.031, RSKangXi=177.5
2928C CJK UNIFIED IDEOGRAPH-#2928C, IRGKangXi=1387.031, RSKangXi=177.5
2928D CJK UNIFIED IDEOGRAPH-#2928D, IRGKangXi=1387.031, RSKangXi=177.5
2928E CJK UNIFIED IDEOGRAPH-#2928E, IRGKangXi=1387.031, RSKangXi=177.5
2928F CJK UNIFIED IDEOGRAPH-#2928F, IRGKangXi=1387.031, RSKangXi=177.5
29290 CJK UNIFIED IDEOGRAPH-#29290, IRGKangXi=1387.040, RSKangXi=177.6
29291 CJK UNIFIED IDEOGRAPH-#29291, IRGKangXi=1387.050, RSKangXi=177.6
29292 CJK UNIFIED IDEOGRAPH-#29292, IRGKangXi=1387.060, RSKangXi=177.6
29293 CJK UNIFIED IDEOGRAPH-#29293, IRGKangXi=1387.070, RSKangXi=177.6
29294 CJK UNIFIED IDEOGRAPH-#29294, IRGKangXi=1387.080, RSKangXi=177.6
29295 CJK UNIFIED IDEOGRAPH-#29295, IRGKangXi=1387.090, RSKangXi=177.6
29296 CJK UNIFIED IDEOGRAPH-#29296, IRGKangXi=1387.100, RSKangXi=177.6
29297 CJK UNIFIED IDEOGRAPH-#29297, IRGKangXi=1387.130, RSKangXi=177.6
29298 CJK UNIFIED IDEOGRAPH-#29298, IRGKangXi=1387.150, RSKangXi=177.6
29299 CJK UNIFIED IDEOGRAPH-#29299, IRGKangXi=1387.170, RSKangXi=177.6
2929A CJK UNIFIED IDEOGRAPH-#2929A, IRGKangXi=1387.180, RSKangXi=177.6
2929B CJK UNIFIED IDEOGRAPH-#2929B, IRGKangXi=1387.200, RSKangXi=177.6
2929C CJK UNIFIED IDEOGRAPH-#2929C, IRGKangXi=1387.210, RSKangXi=177.6
2929D CJK UNIFIED IDEOGRAPH-#2929D, IRGKangXi=1387.250, RSKangXi=177.6
2929E CJK UNIFIED IDEOGRAPH-#2929E, IRGKangXi=1387.270, RSKangXi=177.6
2929F CJK UNIFIED IDEOGRAPH-#2929F, IRGKangXi=1387.290, RSKangXi=177.6
292A0 CJK UNIFIED IDEOGRAPH-#292A0, IRGKangXi=1387.291, RSKangXi=177.6
292A1 CJK UNIFIED IDEOGRAPH-#292A1, IRGKangXi=1387.291, RSKangXi=177.6
292A2 CJK UNIFIED IDEOGRAPH-#292A2, IRGKangXi=1387.291, RSKangXi=177.6
292A3 CJK UNIFIED IDEOGRAPH-#292A3, IRGKangXi=1387.291, RSKangXi=177.6
292A4 CJK UNIFIED IDEOGRAPH-#292A4, IRGKangXi=1387.291, RSKangXi=177.6
292A5 CJK UNIFIED IDEOGRAPH-#292A5, IRGKangXi=1387.291, RSKangXi=177.6
292A6 CJK UNIFIED IDEOGRAPH-#292A6, IRGKangXi=1387.291, RSKangXi=177.6
292A7 CJK UNIFIED IDEOGRAPH-#292A7, IRGKangXi=1387.291, RSKangXi=177.6
292A8 CJK UNIFIED IDEOGRAPH-#292A8, IRGKangXi=1387.291, RSKangXi=177.6
292A9 CJK UNIFIED IDEOGRAPH-#292A9, IRGKangXi=1387.300, RSKangXi=177.7
292AA CJK UNIFIED IDEOGRAPH-#292AA, IRGKangXi=1387.340, RSKangXi=177.7
292AB CJK UNIFIED IDEOGRAPH-#292AB, IRGKangXi=1388.030, RSKangXi=177.7
292AC CJK UNIFIED IDEOGRAPH-#292AC, IRGKangXi=1388.050, RSKangXi=177.7
292AD CJK UNIFIED IDEOGRAPH-#292AD, IRGKangXi=1388.060, RSKangXi=177.7
292AE CJK UNIFIED IDEOGRAPH-#292AE, IRGKangXi=1388.070, RSKangXi=177.7
292AF CJK UNIFIED IDEOGRAPH-#292AF, IRGKangXi=1388.090, RSKangXi=177.7
292B0 CJK UNIFIED IDEOGRAPH-#292B0, IRGKangXi=1388.100, RSKangXi=177.7
292B1 CJK UNIFIED IDEOGRAPH-#292B1, IRGKangXi=1388.151, RSKangXi=177.7
292B2 CJK UNIFIED IDEOGRAPH-#292B2, IRGKangXi=1388.151, RSKangXi=177.7
292B3 CJK UNIFIED IDEOGRAPH-#292B3, IRGKangXi=1388.151, RSKangXi=177.7
292B4 CJK UNIFIED IDEOGRAPH-#292B4, IRGKangXi=1388.151, RSKangXi=177.7
292B5 CJK UNIFIED IDEOGRAPH-#292B5, IRGKangXi=1388.151, RSKangXi=177.7
292B6 CJK UNIFIED IDEOGRAPH-#292B6, IRGKangXi=1388.151, RSKangXi=177.7
292B7 CJK UNIFIED IDEOGRAPH-#292B7, IRGKangXi=1388.151, RSKangXi=177.7
292B8 CJK UNIFIED IDEOGRAPH-#292B8, IRGKangXi=1388.151, RSKangXi=177.7
292B9 CJK UNIFIED IDEOGRAPH-#292B9, IRGKangXi=1388.151, RSKangXi=177.7
292BA CJK UNIFIED IDEOGRAPH-#292BA, IRGKangXi=1388.151, RSKangXi=177.7
292BB CJK UNIFIED IDEOGRAPH-#292BB, IRGKangXi=1388.151, RSKangXi=177.7
292BC CJK UNIFIED IDEOGRAPH-#292BC, IRGKangXi=1388.151, RSKangXi=177.7
292BD CJK UNIFIED IDEOGRAPH-#292BD, IRGKangXi=1388.151, RSKangXi=177.7
292BE CJK UNIFIED IDEOGRAPH-#292BE, IRGKangXi=1388.151, RSKangXi=177.7
292BF CJK UNIFIED IDEOGRAPH-#292BF, IRGKangXi=1388.160, RSKangXi=177.8
292C0 CJK UNIFIED IDEOGRAPH-#292C0, IRGKangXi=1388.170, RSKangXi=177.8
292C1 CJK UNIFIED IDEOGRAPH-#292C1, IRGKangXi=1388.200, RSKangXi=177.8
292C2 CJK UNIFIED IDEOGRAPH-#292C2, IRGKangXi=1388.220, RSKangXi=177.8
292C3 CJK UNIFIED IDEOGRAPH-#292C3, IRGKangXi=1388.230, RSKangXi=177.8
292C4 CJK UNIFIED IDEOGRAPH-#292C4, IRGKangXi=1388.250, RSKangXi=177.8
292C5 CJK UNIFIED IDEOGRAPH-#292C5, IRGKangXi=1388.260, RSKangXi=177.8
292C6 CJK UNIFIED IDEOGRAPH-#292C6, IRGKangXi=1388.280, RSKangXi=177.8
292C7 CJK UNIFIED IDEOGRAPH-#292C7, IRGKangXi=1388.290, RSKangXi=177.8
292C8 CJK UNIFIED IDEOGRAPH-#292C8, IRGKangXi=1388.300, RSKangXi=177.8
292C9 CJK UNIFIED IDEOGRAPH-#292C9, IRGKangXi=1388.310, RSKangXi=177.8
292CA CJK UNIFIED IDEOGRAPH-#292CA, IRGKangXi=1388.320, RSKangXi=177.8
292CB CJK UNIFIED IDEOGRAPH-#292CB, IRGKangXi=1388.340, RSKangXi=177.8
292CC CJK UNIFIED IDEOGRAPH-#292CC, IRGKangXi=1388.350, RSKangXi=177.8
292CD CJK UNIFIED IDEOGRAPH-#292CD, IRGKangXi=1388.390, RSKangXi=177.8
292CE CJK UNIFIED IDEOGRAPH-#292CE, IRGKangXi=1388.410, RSKangXi=177.8
292CF CJK UNIFIED IDEOGRAPH-#292CF, IRGKangXi=1388.430, RSKangXi=177.8
292D0 CJK UNIFIED IDEOGRAPH-#292D0, IRGKangXi=1389.010, RSKangXi=177.8
292D1 CJK UNIFIED IDEOGRAPH-#292D1, IRGKangXi=1389.020, RSKangXi=177.8
292D2 CJK UNIFIED IDEOGRAPH-#292D2, IRGKangXi=1389.030, RSKangXi=177.8
292D3 CJK UNIFIED IDEOGRAPH-#292D3, IRGKangXi=1389.070, RSKangXi=177.8
292D4 CJK UNIFIED IDEOGRAPH-#292D4, IRGKangXi=1389.071, RSKangXi=177.8
292D5 CJK UNIFIED IDEOGRAPH-#292D5, IRGKangXi=1389.071, RSKangXi=177.8
292D6 CJK UNIFIED IDEOGRAPH-#292D6, IRGKangXi=1389.071, RSKangXi=177.8
292D7 CJK UNIFIED IDEOGRAPH-#292D7, IRGKangXi=1389.071, RSKangXi=177.8
292D8 CJK UNIFIED IDEOGRAPH-#292D8, IRGKangXi=1389.071, RSKangXi=177.8, Def{shoes}
292D9 CJK UNIFIED IDEOGRAPH-#292D9, IRGKangXi=1389.071, RSKangXi=177.8
292DA CJK UNIFIED IDEOGRAPH-#292DA, IRGKangXi=1389.071, RSKangXi=177.8
292DB CJK UNIFIED IDEOGRAPH-#292DB, IRGKangXi=1389.071, RSKangXi=177.8
292DC CJK UNIFIED IDEOGRAPH-#292DC, IRGKangXi=1389.071, RSKangXi=177.8
292DD CJK UNIFIED IDEOGRAPH-#292DD, IRGKangXi=1389.071, RSKangXi=177.8
292DE CJK UNIFIED IDEOGRAPH-#292DE, IRGKangXi=1389.071, RSKangXi=177.8
292DF CJK UNIFIED IDEOGRAPH-#292DF, IRGKangXi=1389.090, RSKangXi=177.9
292E0 CJK UNIFIED IDEOGRAPH-#292E0, IRGKangXi=1389.100, RSKangXi=177.9
292E1 CJK UNIFIED IDEOGRAPH-#292E1, IRGKangXi=1389.140, RSKangXi=177.9
292E2 CJK UNIFIED IDEOGRAPH-#292E2, IRGKangXi=1389.160, RSKangXi=177.9
292E3 CJK UNIFIED IDEOGRAPH-#292E3, IRGKangXi=1389.170, RSKangXi=177.9
292E4 CJK UNIFIED IDEOGRAPH-#292E4, IRGKangXi=1389.180, RSKangXi=177.9
292E5 CJK UNIFIED IDEOGRAPH-#292E5, IRGKangXi=1389.190, RSKangXi=177.9
292E6 CJK UNIFIED IDEOGRAPH-#292E6, IRGKangXi=1389.200, RSKangXi=177.9
292E7 CJK UNIFIED IDEOGRAPH-#292E7, IRGKangXi=1389.210, RSKangXi=177.9, Def{shoes; the name of a drum}
292E8 CJK UNIFIED IDEOGRAPH-#292E8, IRGKangXi=1389.220, RSKangXi=177.9
292E9 CJK UNIFIED IDEOGRAPH-#292E9, IRGKangXi=1389.230, RSKangXi=177.9
292EA CJK UNIFIED IDEOGRAPH-#292EA, IRGKangXi=1389.280, RSKangXi=177.9
292EB CJK UNIFIED IDEOGRAPH-#292EB, IRGKangXi=1389.320, RSKangXi=177.9
292EC CJK UNIFIED IDEOGRAPH-#292EC, IRGKangXi=1390.010, RSKangXi=177.9
292ED CJK UNIFIED IDEOGRAPH-#292ED, IRGKangXi=1390.030, RSKangXi=177.9
292EE CJK UNIFIED IDEOGRAPH-#292EE, IRGKangXi=1390.050, RSKangXi=177.9
292EF CJK UNIFIED IDEOGRAPH-#292EF, IRGKangXi=1390.080, RSKangXi=177.9
292F0 CJK UNIFIED IDEOGRAPH-#292F0, IRGKangXi=1390.110, RSKangXi=177.9
292F1 CJK UNIFIED IDEOGRAPH-#292F1, IRGKangXi=1390.140, RSKangXi=177.9
292F2 CJK UNIFIED IDEOGRAPH-#292F2, IRGKangXi=1390.150, RSKangXi=177.9
292F3 CJK UNIFIED IDEOGRAPH-#292F3, IRGKangXi=1390.151, RSKangXi=177.9
292F4 CJK UNIFIED IDEOGRAPH-#292F4, IRGKangXi=1390.151, RSKangXi=177.9
292F5 CJK UNIFIED IDEOGRAPH-#292F5, IRGKangXi=1390.151, RSKangXi=177.9
292F6 CJK UNIFIED IDEOGRAPH-#292F6, IRGKangXi=1390.151, RSKangXi=177.9
292F7 CJK UNIFIED IDEOGRAPH-#292F7, IRGKangXi=1390.151, RSKangXi=177.9
292F8 CJK UNIFIED IDEOGRAPH-#292F8, IRGKangXi=1390.151, RSKangXi=177.9
292F9 CJK UNIFIED IDEOGRAPH-#292F9, IRGKangXi=1390.151, RSKangXi=177.9
292FA CJK UNIFIED IDEOGRAPH-#292FA, IRGKangXi=1390.151, RSKangXi=177.9
292FB CJK UNIFIED IDEOGRAPH-#292FB, IRGKangXi=1390.151, RSKangXi=177.9
292FC CJK UNIFIED IDEOGRAPH-#292FC, IRGKangXi=1390.151, RSKangXi=177.9
292FD CJK UNIFIED IDEOGRAPH-#292FD, IRGKangXi=1390.151, RSKangXi=177.9
292FE CJK UNIFIED IDEOGRAPH-#292FE, IRGKangXi=1390.151, RSKangXi=177.9
292FF CJK UNIFIED IDEOGRAPH-#292FF, IRGKangXi=1390.151, RSKangXi=177.9
29300 CJK UNIFIED IDEOGRAPH-#29300, IRGKangXi=1390.151, RSKangXi=177.9
29301 CJK UNIFIED IDEOGRAPH-#29301, IRGKangXi=1390.151, RSKangXi=177.9
29302 CJK UNIFIED IDEOGRAPH-#29302, IRGKangXi=1390.151, RSKangXi=177.9
29303 CJK UNIFIED IDEOGRAPH-#29303, IRGKangXi=1390.170, RSKangXi=177.10
29304 CJK UNIFIED IDEOGRAPH-#29304, IRGKangXi=1390.190, RSKangXi=177.10
29305 CJK UNIFIED IDEOGRAPH-#29305, IRGKangXi=1390.200, RSKangXi=177.10
29306 CJK UNIFIED IDEOGRAPH-#29306, IRGKangXi=1390.210, RSKangXi=177.10
29307 CJK UNIFIED IDEOGRAPH-#29307, IRGKangXi=1390.220, RSKangXi=177.10
29308 CJK UNIFIED IDEOGRAPH-#29308, IRGKangXi=1390.230, RSKangXi=177.10
29309 CJK UNIFIED IDEOGRAPH-#29309, IRGKangXi=1390.260, RSKangXi=177.10
2930A CJK UNIFIED IDEOGRAPH-#2930A, IRGKangXi=1390.300, RSKangXi=177.10
2930B CJK UNIFIED IDEOGRAPH-#2930B, IRGKangXi=1390.310, RSKangXi=177.10
2930C CJK UNIFIED IDEOGRAPH-#2930C, IRGKangXi=1390.320, RSKangXi=177.10
2930D CJK UNIFIED IDEOGRAPH-#2930D, IRGKangXi=1390.330, RSKangXi=177.10
2930E CJK UNIFIED IDEOGRAPH-#2930E, IRGKangXi=1390.350, RSKangXi=177.10
2930F CJK UNIFIED IDEOGRAPH-#2930F, IRGKangXi=1391.020, RSKangXi=177.10
29310 CJK UNIFIED IDEOGRAPH-#29310, IRGKangXi=1391.050, RSKangXi=177.10
29311 CJK UNIFIED IDEOGRAPH-#29311, IRGKangXi=1391.060, RSKangXi=177.10
29312 CJK UNIFIED IDEOGRAPH-#29312, IRGKangXi=1391.070, RSKangXi=177.10
29313 CJK UNIFIED IDEOGRAPH-#29313, IRGKangXi=1391.071, RSKangXi=177.10
29314 CJK UNIFIED IDEOGRAPH-#29314, IRGKangXi=1391.071, RSKangXi=177.10
29315 CJK UNIFIED IDEOGRAPH-#29315, IRGKangXi=1391.071, RSKangXi=177.10
29316 CJK UNIFIED IDEOGRAPH-#29316, IRGKangXi=1391.071, RSKangXi=177.10
29317 CJK UNIFIED IDEOGRAPH-#29317, IRGKangXi=1391.071, RSKangXi=177.10
29318 CJK UNIFIED IDEOGRAPH-#29318, IRGKangXi=1391.071, RSKangXi=177.10
29319 CJK UNIFIED IDEOGRAPH-#29319, IRGKangXi=1391.071, RSKangXi=177.10
2931A CJK UNIFIED IDEOGRAPH-#2931A, IRGKangXi=1391.071, RSKangXi=177.10
2931B CJK UNIFIED IDEOGRAPH-#2931B, IRGKangXi=1391.071, RSKangXi=177.10
2931C CJK UNIFIED IDEOGRAPH-#2931C, IRGKangXi=1391.071, RSKangXi=177.10
2931D CJK UNIFIED IDEOGRAPH-#2931D, IRGKangXi=1391.071, RSKangXi=177.10
2931E CJK UNIFIED IDEOGRAPH-#2931E, IRGKangXi=1391.071, RSKangXi=177.10
2931F CJK UNIFIED IDEOGRAPH-#2931F, IRGKangXi=1391.071, RSKangXi=177.10
29320 CJK UNIFIED IDEOGRAPH-#29320, IRGKangXi=1391.071, RSKangXi=177.10
29321 CJK UNIFIED IDEOGRAPH-#29321, IRGKangXi=1391.071, RSKangXi=177.10
29322 CJK UNIFIED IDEOGRAPH-#29322, IRGKangXi=1391.071, RSKangXi=177.10
29323 CJK UNIFIED IDEOGRAPH-#29323, IRGKangXi=1391.071, RSKangXi=177.10
29324 CJK UNIFIED IDEOGRAPH-#29324, IRGKangXi=1391.071, RSKangXi=177.10
29325 CJK UNIFIED IDEOGRAPH-#29325, IRGKangXi=1391.071, RSKangXi=177.10
29326 CJK UNIFIED IDEOGRAPH-#29326, IRGKangXi=1391.080, RSKangXi=177.11
29327 CJK UNIFIED IDEOGRAPH-#29327, IRGKangXi=1391.120, RSKangXi=177.11
29328 CJK UNIFIED IDEOGRAPH-#29328, IRGKangXi=1391.130, RSKangXi=177.11
29329 CJK UNIFIED IDEOGRAPH-#29329, IRGKangXi=1391.140, RSKangXi=177.11
2932A CJK UNIFIED IDEOGRAPH-#2932A, IRGKangXi=1391.160, RSKangXi=177.11
2932B CJK UNIFIED IDEOGRAPH-#2932B, IRGKangXi=1391.180, RSKangXi=177.11
2932C CJK UNIFIED IDEOGRAPH-#2932C, IRGKangXi=1391.190, RSKangXi=177.11
2932D CJK UNIFIED IDEOGRAPH-#2932D, IRGKangXi=1391.200, RSKangXi=177.11
2932E CJK UNIFIED IDEOGRAPH-#2932E, IRGKangXi=1391.230, RSKangXi=177.11
2932F CJK UNIFIED IDEOGRAPH-#2932F, IRGKangXi=1391.240, RSKangXi=177.11
29330 CJK UNIFIED IDEOGRAPH-#29330, IRGKangXi=1391.250, RSKangXi=177.11
29331 CJK UNIFIED IDEOGRAPH-#29331, IRGKangXi=1391.270, RSKangXi=177.11
29332 CJK UNIFIED IDEOGRAPH-#29332, IRGKangXi=1391.280, RSKangXi=177.11
29333 CJK UNIFIED IDEOGRAPH-#29333, IRGKangXi=1391.290, RSKangXi=177.11
29334 CJK UNIFIED IDEOGRAPH-#29334, IRGKangXi=1391.291, RSKangXi=177.11
29335 CJK UNIFIED IDEOGRAPH-#29335, IRGKangXi=1391.291, RSKangXi=177.11
29336 CJK UNIFIED IDEOGRAPH-#29336, IRGKangXi=1391.291, RSKangXi=177.11
29337 CJK UNIFIED IDEOGRAPH-#29337, IRGKangXi=1391.291, RSKangXi=177.11
29338 CJK UNIFIED IDEOGRAPH-#29338, IRGKangXi=1391.291, RSKangXi=177.11
29339 CJK UNIFIED IDEOGRAPH-#29339, IRGKangXi=1391.291, RSKangXi=177.11
2933A CJK UNIFIED IDEOGRAPH-#2933A, IRGKangXi=1391.291, RSKangXi=177.11
2933B CJK UNIFIED IDEOGRAPH-#2933B, IRGKangXi=1391.291, RSKangXi=177.11
2933C CJK UNIFIED IDEOGRAPH-#2933C, IRGKangXi=1391.291, RSKangXi=177.11
2933D CJK UNIFIED IDEOGRAPH-#2933D, IRGKangXi=1391.291, RSKangXi=177.11
2933E CJK UNIFIED IDEOGRAPH-#2933E, IRGKangXi=1391.291, RSKangXi=177.11
2933F CJK UNIFIED IDEOGRAPH-#2933F, IRGKangXi=1391.291, RSKangXi=177.11
29340 CJK UNIFIED IDEOGRAPH-#29340, IRGKangXi=1391.291, RSKangXi=177.11
29341 CJK UNIFIED IDEOGRAPH-#29341, IRGKangXi=1391.291, RSKangXi=177.11
29342 CJK UNIFIED IDEOGRAPH-#29342, IRGKangXi=1391.291, RSKangXi=177.11
29343 CJK UNIFIED IDEOGRAPH-#29343, IRGKangXi=1391.320, RSKangXi=177.12
29344 CJK UNIFIED IDEOGRAPH-#29344, IRGKangXi=1391.350, RSKangXi=177.12
29345 CJK UNIFIED IDEOGRAPH-#29345, IRGKangXi=1391.370, RSKangXi=177.12
29346 CJK UNIFIED IDEOGRAPH-#29346, IRGKangXi=1391.390, RSKangXi=177.12
29347 CJK UNIFIED IDEOGRAPH-#29347, IRGKangXi=1391.420, RSKangXi=177.12
29348 CJK UNIFIED IDEOGRAPH-#29348, IRGKangXi=1391.431, RSKangXi=177.12
29349 CJK UNIFIED IDEOGRAPH-#29349, IRGKangXi=1391.431, RSKangXi=177.12
2934A CJK UNIFIED IDEOGRAPH-#2934A, IRGKangXi=1391.431, RSKangXi=177.12
2934B CJK UNIFIED IDEOGRAPH-#2934B, IRGKangXi=1391.431, RSKangXi=177.12
2934C CJK UNIFIED IDEOGRAPH-#2934C, IRGKangXi=1391.431
2934D CJK UNIFIED IDEOGRAPH-#2934D, IRGKangXi=1391.431, RSKangXi=177.12
2934E CJK UNIFIED IDEOGRAPH-#2934E, IRGKangXi=1391.431, RSKangXi=177.12
2934F CJK UNIFIED IDEOGRAPH-#2934F, IRGKangXi=1391.431, RSKangXi=177.12
29350 CJK UNIFIED IDEOGRAPH-#29350, IRGKangXi=1391.431, RSKangXi=177.12
29351 CJK UNIFIED IDEOGRAPH-#29351, IRGKangXi=1391.431, RSKangXi=177.12
29352 CJK UNIFIED IDEOGRAPH-#29352, IRGKangXi=1391.431, RSKangXi=177.12
29353 CJK UNIFIED IDEOGRAPH-#29353, IRGKangXi=1392.010, RSKangXi=177.13
29354 CJK UNIFIED IDEOGRAPH-#29354, IRGKangXi=1392.020, RSKangXi=177.13
29355 CJK UNIFIED IDEOGRAPH-#29355, IRGKangXi=1392.030, RSKangXi=177.13
29356 CJK UNIFIED IDEOGRAPH-#29356, IRGKangXi=1392.040, RSKangXi=177.13
29357 CJK UNIFIED IDEOGRAPH-#29357, IRGKangXi=1392.050, RSKangXi=177.13, Def{the lining of a shoe; the vamp or upper part of a shoe or boot}
29358 CJK UNIFIED IDEOGRAPH-#29358, IRGKangXi=1392.080, RSKangXi=177.13
29359 CJK UNIFIED IDEOGRAPH-#29359, IRGKangXi=1392.110, RSKangXi=177.13
2935A CJK UNIFIED IDEOGRAPH-#2935A, IRGKangXi=1392.140, RSKangXi=177.13
2935B CJK UNIFIED IDEOGRAPH-#2935B, IRGKangXi=1392.150, RSKangXi=177.13
2935C CJK UNIFIED IDEOGRAPH-#2935C, IRGKangXi=1392.160, RSKangXi=177.13
2935D CJK UNIFIED IDEOGRAPH-#2935D, IRGKangXi=1392.170, RSKangXi=177.13
2935E CJK UNIFIED IDEOGRAPH-#2935E, IRGKangXi=1392.171, RSKangXi=177.13
2935F CJK UNIFIED IDEOGRAPH-#2935F, IRGKangXi=1392.171, RSKangXi=177.13
29360 CJK UNIFIED IDEOGRAPH-#29360, IRGKangXi=1392.171, RSKangXi=177.13
29361 CJK UNIFIED IDEOGRAPH-#29361, IRGKangXi=1392.171, RSKangXi=177.13
29362 CJK UNIFIED IDEOGRAPH-#29362, IRGKangXi=1392.171, RSKangXi=177.13
29363 CJK UNIFIED IDEOGRAPH-#29363, IRGKangXi=1392.171, RSKangXi=177.13
29364 CJK UNIFIED IDEOGRAPH-#29364, IRGKangXi=1392.171, RSKangXi=177.13
29365 CJK UNIFIED IDEOGRAPH-#29365, IRGKangXi=1392.180, RSKangXi=177.14
29366 CJK UNIFIED IDEOGRAPH-#29366, IRGKangXi=1392.190, RSKangXi=177.14
29367 CJK UNIFIED IDEOGRAPH-#29367, IRGKangXi=1392.200, RSKangXi=177.14
29368 CJK UNIFIED IDEOGRAPH-#29368, IRGKangXi=1392.220, RSKangXi=177.14
29369 CJK UNIFIED IDEOGRAPH-#29369, IRGKangXi=1392.240, RSKangXi=177.14
2936A CJK UNIFIED IDEOGRAPH-#2936A, IRGKangXi=1392.270, RSKangXi=177.14
2936B CJK UNIFIED IDEOGRAPH-#2936B, IRGKangXi=1392.280, RSKangXi=177.14
2936C CJK UNIFIED IDEOGRAPH-#2936C, IRGKangXi=1392.281, RSKangXi=177.14
2936D CJK UNIFIED IDEOGRAPH-#2936D, IRGKangXi=1392.281, RSKangXi=177.14
2936E CJK UNIFIED IDEOGRAPH-#2936E, IRGKangXi=1392.281, RSKangXi=177.14
2936F CJK UNIFIED IDEOGRAPH-#2936F, IRGKangXi=1392.281, RSKangXi=177.14
29370 CJK UNIFIED IDEOGRAPH-#29370, IRGKangXi=1392.281, RSKangXi=177.14
29371 CJK UNIFIED IDEOGRAPH-#29371, IRGKangXi=1392.281, RSKangXi=177.14
29372 CJK UNIFIED IDEOGRAPH-#29372, IRGKangXi=1392.300, RSKangXi=177.15
29373 CJK UNIFIED IDEOGRAPH-#29373, IRGKangXi=1392.340, RSKangXi=177.15
29374 CJK UNIFIED IDEOGRAPH-#29374, IRGKangXi=1392.350, RSKangXi=177.15
29375 CJK UNIFIED IDEOGRAPH-#29375, IRGKangXi=1392.351, RSKangXi=177.15
29376 CJK UNIFIED IDEOGRAPH-#29376, IRGKangXi=1392.351, RSKangXi=177.15
29377 CJK UNIFIED IDEOGRAPH-#29377, IRGKangXi=1392.351, RSKangXi=177.15
29378 CJK UNIFIED IDEOGRAPH-#29378, IRGKangXi=1392.360, RSKangXi=177.16
29379 CJK UNIFIED IDEOGRAPH-#29379, IRGKangXi=1392.370, RSKangXi=177.16
2937A CJK UNIFIED IDEOGRAPH-#2937A, IRGKangXi=1392.391, RSKangXi=177.16
2937B CJK UNIFIED IDEOGRAPH-#2937B, IRGKangXi=1392.391, RSKangXi=193.15
2937C CJK UNIFIED IDEOGRAPH-#2937C, IRGKangXi=1392.391, RSKangXi=177.16
2937D CJK UNIFIED IDEOGRAPH-#2937D, IRGKangXi=1392.391, RSKangXi=177.16
2937E CJK UNIFIED IDEOGRAPH-#2937E, IRGKangXi=1392.391, RSKangXi=177.16
2937F CJK UNIFIED IDEOGRAPH-#2937F, IRGKangXi=1392.410, RSKangXi=177.17
29380 CJK UNIFIED IDEOGRAPH-#29380, IRGKangXi=1392.420, RSKangXi=177.17
29381 CJK UNIFIED IDEOGRAPH-#29381, IRGKangXi=1392.441, RSKangXi=177.17
29382 CJK UNIFIED IDEOGRAPH-#29382, IRGKangXi=1392.441, RSKangXi=177.17
29383 CJK UNIFIED IDEOGRAPH-#29383, IRGKangXi=1392.441, RSKangXi=177.17
29384 CJK UNIFIED IDEOGRAPH-#29384, IRGKangXi=1392.441, RSKangXi=177.17
29385 CJK UNIFIED IDEOGRAPH-#29385, IRGKangXi=1392.441, RSKangXi=177.17
29386 CJK UNIFIED IDEOGRAPH-#29386, IRGKangXi=1392.441, RSKangXi=177.17
29387 CJK UNIFIED IDEOGRAPH-#29387, IRGKangXi=1392.460, RSKangXi=177.18
29388 CJK UNIFIED IDEOGRAPH-#29388, IRGKangXi=1392.470, RSKangXi=177.19
29389 CJK UNIFIED IDEOGRAPH-#29389, IRGKangXi=1392.480, RSKangXi=177.19
2938A CJK UNIFIED IDEOGRAPH-#2938A, IRGKangXi=1392.481, RSKangXi=177.19
2938B CJK UNIFIED IDEOGRAPH-#2938B, IRGKangXi=1393.020, RSKangXi=177.21
2938C CJK UNIFIED IDEOGRAPH-#2938C, IRGKangXi=1393.030, RSKangXi=177.23
2938D CJK UNIFIED IDEOGRAPH-#2938D, IRGKangXi=1393.031, RSKangXi=177.23
2938E CJK UNIFIED IDEOGRAPH-#2938E, IRGKangXi=1393.040, RSKangXi=177.24
2938F CJK UNIFIED IDEOGRAPH-#2938F, IRGKangXi=1393.041, RSKangXi=177.24
29390 CJK UNIFIED IDEOGRAPH-#29390, IRGKangXi=1393.041, RSKangXi=177.25
29391 CJK UNIFIED IDEOGRAPH-#29391, IRGKangXi=1393.050, RSKangXi=177.29
29392 CJK UNIFIED IDEOGRAPH-#29392, IRGKangXi=1393.101, RSKangXi=178.3
29393 CJK UNIFIED IDEOGRAPH-#29393, IRGKangXi=1393.110, RSKangXi=178.4
29394 CJK UNIFIED IDEOGRAPH-#29394, IRGKangXi=1393.140, RSKangXi=178.4
29395 CJK UNIFIED IDEOGRAPH-#29395, IRGKangXi=1393.150, RSKangXi=178.4
29396 CJK UNIFIED IDEOGRAPH-#29396, IRGKangXi=1393.151, RSKangXi=178.4
29397 CJK UNIFIED IDEOGRAPH-#29397, IRGKangXi=1393.151, RSKangXi=178.4
29398 CJK UNIFIED IDEOGRAPH-#29398, IRGKangXi=1393.170, RSKangXi=178.5
29399 CJK UNIFIED IDEOGRAPH-#29399, IRGKangXi=1393.180, RSKangXi=178.5
2939A CJK UNIFIED IDEOGRAPH-#2939A, IRGKangXi=1393.190, RSKangXi=178.5
2939B CJK UNIFIED IDEOGRAPH-#2939B, IRGKangXi=1393.220, RSKangXi=178.5
2939C CJK UNIFIED IDEOGRAPH-#2939C, IRGKangXi=1393.230, RSKangXi=178.5
2939D CJK UNIFIED IDEOGRAPH-#2939D, IRGKangXi=1394.010, RSKangXi=178.5
2939E CJK UNIFIED IDEOGRAPH-#2939E, IRGKangXi=1394.011, RSKangXi=178.5
2939F CJK UNIFIED IDEOGRAPH-#2939F, IRGKangXi=1394.011, RSKangXi=178.5
293A0 CJK UNIFIED IDEOGRAPH-#293A0, IRGKangXi=1394.011, RSKangXi=178.5
293A1 CJK UNIFIED IDEOGRAPH-#293A1, IRGKangXi=1394.011, RSKangXi=178.5
293A2 CJK UNIFIED IDEOGRAPH-#293A2, IRGKangXi=1394.011, RSKangXi=178.5
293A3 CJK UNIFIED IDEOGRAPH-#293A3, IRGKangXi=1394.011, RSKangXi=178.5
293A4 CJK UNIFIED IDEOGRAPH-#293A4, IRGKangXi=1394.020, RSKangXi=178.6
293A5 CJK UNIFIED IDEOGRAPH-#293A5, IRGKangXi=1394.030, RSKangXi=178.6
293A6 CJK UNIFIED IDEOGRAPH-#293A6, IRGKangXi=1394.040, RSKangXi=178.6
293A7 CJK UNIFIED IDEOGRAPH-#293A7, IRGKangXi=1394.060, RSKangXi=178.6
293A8 CJK UNIFIED IDEOGRAPH-#293A8, IRGKangXi=1394.070, RSKangXi=178.6
293A9 CJK UNIFIED IDEOGRAPH-#293A9, IRGKangXi=1394.081, RSKangXi=178.6
293AA CJK UNIFIED IDEOGRAPH-#293AA, IRGKangXi=1394.081, RSKangXi=178.6
293AB CJK UNIFIED IDEOGRAPH-#293AB, IRGKangXi=1394.081, RSKangXi=178.6
293AC CJK UNIFIED IDEOGRAPH-#293AC, IRGKangXi=1394.081, RSKangXi=178.6
293AD CJK UNIFIED IDEOGRAPH-#293AD, IRGKangXi=1394.081, RSKangXi=178.6
293AE CJK UNIFIED IDEOGRAPH-#293AE, IRGKangXi=1394.081, RSKangXi=178.6
293AF CJK UNIFIED IDEOGRAPH-#293AF, IRGKangXi=1394.090, RSKangXi=178.7
293B0 CJK UNIFIED IDEOGRAPH-#293B0, IRGKangXi=1394.110, RSKangXi=178.7
293B1 CJK UNIFIED IDEOGRAPH-#293B1, IRGKangXi=1394.130, RSKangXi=178.7
293B2 CJK UNIFIED IDEOGRAPH-#293B2, IRGKangXi=1394.131, RSKangXi=178.7
293B3 CJK UNIFIED IDEOGRAPH-#293B3, IRGKangXi=1394.131, RSKangXi=178.7
293B4 CJK UNIFIED IDEOGRAPH-#293B4, IRGKangXi=1394.131, RSKangXi=178.7
293B5 CJK UNIFIED IDEOGRAPH-#293B5, IRGKangXi=1394.131, RSKangXi=178.7
293B6 CJK UNIFIED IDEOGRAPH-#293B6, IRGKangXi=1394.131, RSKangXi=178.7
293B7 CJK UNIFIED IDEOGRAPH-#293B7, IRGKangXi=1394.131, RSKangXi=178.7
293B8 CJK UNIFIED IDEOGRAPH-#293B8, IRGKangXi=1394.140, RSKangXi=178.8
293B9 CJK UNIFIED IDEOGRAPH-#293B9, IRGKangXi=1394.150, RSKangXi=178.8
293BA CJK UNIFIED IDEOGRAPH-#293BA, IRGKangXi=1394.160, RSKangXi=178.8
293BB CJK UNIFIED IDEOGRAPH-#293BB, IRGKangXi=1394.170, RSKangXi=178.8
293BC CJK UNIFIED IDEOGRAPH-#293BC, IRGKangXi=1394.180, RSKangXi=178.8
293BD CJK UNIFIED IDEOGRAPH-#293BD, IRGKangXi=1394.220, RSKangXi=178.8
293BE CJK UNIFIED IDEOGRAPH-#293BE, IRGKangXi=1394.230, RSKangXi=178.8
293BF CJK UNIFIED IDEOGRAPH-#293BF, IRGKangXi=1394.241, RSKangXi=178.8
293C0 CJK UNIFIED IDEOGRAPH-#293C0, IRGKangXi=1394.241, RSKangXi=178.8
293C1 CJK UNIFIED IDEOGRAPH-#293C1, IRGKangXi=1394.241, RSKangXi=178.8
293C2 CJK UNIFIED IDEOGRAPH-#293C2, IRGKangXi=1394.241, RSKangXi=178.8
293C3 CJK UNIFIED IDEOGRAPH-#293C3, IRGKangXi=1394.241, RSKangXi=178.8
293C4 CJK UNIFIED IDEOGRAPH-#293C4, IRGKangXi=1394.241, RSKangXi=178.8
293C5 CJK UNIFIED IDEOGRAPH-#293C5, IRGKangXi=1394.260, RSKangXi=178.9
293C6 CJK UNIFIED IDEOGRAPH-#293C6, IRGKangXi=1394.270, RSKangXi=178.9
293C7 CJK UNIFIED IDEOGRAPH-#293C7, IRGKangXi=1394.300, RSKangXi=178.9
293C8 CJK UNIFIED IDEOGRAPH-#293C8, IRGKangXi=1394.310, RSKangXi=178.9
293C9 CJK UNIFIED IDEOGRAPH-#293C9, IRGKangXi=1394.360, RSKangXi=178.9
293CA CJK UNIFIED IDEOGRAPH-#293CA, IRGKangXi=1394.370, RSKangXi=178.9
293CB CJK UNIFIED IDEOGRAPH-#293CB, IRGKangXi=1394.380, RSKangXi=178.9
293CC CJK UNIFIED IDEOGRAPH-#293CC, IRGKangXi=1394.381, RSKangXi=178.9
293CD CJK UNIFIED IDEOGRAPH-#293CD, IRGKangXi=1394.381, RSKangXi=178.9
293CE CJK UNIFIED IDEOGRAPH-#293CE, IRGKangXi=1394.381, RSKangXi=178.9
293CF CJK UNIFIED IDEOGRAPH-#293CF, IRGKangXi=1394.400, RSKangXi=178.10
293D0 CJK UNIFIED IDEOGRAPH-#293D0, IRGKangXi=1394.410, RSKangXi=178.10
293D1 CJK UNIFIED IDEOGRAPH-#293D1, IRGKangXi=1394.420, RSKangXi=178.10
293D2 CJK UNIFIED IDEOGRAPH-#293D2, IRGKangXi=1395.010, RSKangXi=178.10
293D3 CJK UNIFIED IDEOGRAPH-#293D3, IRGKangXi=1395.020, RSKangXi=178.10
293D4 CJK UNIFIED IDEOGRAPH-#293D4, IRGKangXi=1395.060, RSKangXi=178.10
293D5 CJK UNIFIED IDEOGRAPH-#293D5, IRGKangXi=1395.070, RSKangXi=178.10
293D6 CJK UNIFIED IDEOGRAPH-#293D6, IRGKangXi=1395.071, RSKangXi=178.10
293D7 CJK UNIFIED IDEOGRAPH-#293D7, IRGKangXi=1395.071, RSKangXi=178.10
293D8 CJK UNIFIED IDEOGRAPH-#293D8, IRGKangXi=1395.080, RSKangXi=178.11
293D9 CJK UNIFIED IDEOGRAPH-#293D9, IRGKangXi=1395.090, RSKangXi=178.11
293DA CJK UNIFIED IDEOGRAPH-#293DA, IRGKangXi=1395.110, RSKangXi=178.11
293DB CJK UNIFIED IDEOGRAPH-#293DB, IRGKangXi=1395.111, RSKangXi=178.11
293DC CJK UNIFIED IDEOGRAPH-#293DC, IRGKangXi=1395.111, RSKangXi=178.11
293DD CJK UNIFIED IDEOGRAPH-#293DD, IRGKangXi=1395.111, RSKangXi=178.11
293DE CJK UNIFIED IDEOGRAPH-#293DE, IRGKangXi=1395.111, RSKangXi=178.11
293DF CJK UNIFIED IDEOGRAPH-#293DF, IRGKangXi=1395.111, RSKangXi=178.11
293E0 CJK UNIFIED IDEOGRAPH-#293E0, IRGKangXi=1395.120, RSKangXi=178.12
293E1 CJK UNIFIED IDEOGRAPH-#293E1, IRGKangXi=1395.130, RSKangXi=178.12
293E2 CJK UNIFIED IDEOGRAPH-#293E2, IRGKangXi=1395.140, RSKangXi=178.12
293E3 CJK UNIFIED IDEOGRAPH-#293E3, IRGKangXi=1395.160, RSKangXi=178.12
293E4 CJK UNIFIED IDEOGRAPH-#293E4, IRGKangXi=1395.170, RSKangXi=178.12
293E5 CJK UNIFIED IDEOGRAPH-#293E5, IRGKangXi=1395.191, RSKangXi=178.12
293E6 CJK UNIFIED IDEOGRAPH-#293E6, IRGKangXi=1395.191, RSKangXi=178.12
293E7 CJK UNIFIED IDEOGRAPH-#293E7, IRGKangXi=1395.191, RSKangXi=178.12
293E8 CJK UNIFIED IDEOGRAPH-#293E8, IRGKangXi=1395.200, RSKangXi=178.13
293E9 CJK UNIFIED IDEOGRAPH-#293E9, IRGKangXi=1395.210, RSKangXi=178.13
293EA CJK UNIFIED IDEOGRAPH-#293EA, IRGKangXi=1395.240, RSKangXi=178.13
293EB CJK UNIFIED IDEOGRAPH-#293EB, IRGKangXi=1395.250, RSKangXi=178.13
293EC CJK UNIFIED IDEOGRAPH-#293EC, IRGKangXi=1395.260, RSKangXi=178.13
293ED CJK UNIFIED IDEOGRAPH-#293ED, IRGKangXi=1395.261, RSKangXi=178.13
293EE CJK UNIFIED IDEOGRAPH-#293EE, IRGKangXi=1395.280, RSKangXi=178.14
293EF CJK UNIFIED IDEOGRAPH-#293EF, IRGKangXi=1395.290, RSKangXi=178.14
293F0 CJK UNIFIED IDEOGRAPH-#293F0, IRGKangXi=1395.300, RSKangXi=178.14
293F1 CJK UNIFIED IDEOGRAPH-#293F1, IRGKangXi=1395.310, RSKangXi=178.14
293F2 CJK UNIFIED IDEOGRAPH-#293F2, IRGKangXi=1395.340, RSKangXi=178.15
293F3 CJK UNIFIED IDEOGRAPH-#293F3, IRGKangXi=1395.341, RSKangXi=178.15
293F4 CJK UNIFIED IDEOGRAPH-#293F4, IRGKangXi=1395.350, RSKangXi=178.16
293F5 CJK UNIFIED IDEOGRAPH-#293F5, IRGKangXi=1395.360, RSKangXi=178.17
293F6 CJK UNIFIED IDEOGRAPH-#293F6, IRGKangXi=1396.010, RSKangXi=178.18
293F7 CJK UNIFIED IDEOGRAPH-#293F7, IRGKangXi=1396.011, RSKangXi=178.18
293F8 CJK UNIFIED IDEOGRAPH-#293F8, IRGKangXi=1396.011, RSKangXi=178.18
293F9 CJK UNIFIED IDEOGRAPH-#293F9, IRGKangXi=1396.020, RSKangXi=178.19
293FA CJK UNIFIED IDEOGRAPH-#293FA, IRGKangXi=1396.030, RSKangXi=178.20
293FB CJK UNIFIED IDEOGRAPH-#293FB, IRGKangXi=1396.031, RSKangXi=178.20
293FC CJK UNIFIED IDEOGRAPH-#293FC, IRGKangXi=1396.031, RSKangXi=178.4
293FD CJK UNIFIED IDEOGRAPH-#293FD, IRGKangXi=1396.031, RSKangXi=178.5
293FE CJK UNIFIED IDEOGRAPH-#293FE, IRGKangXi=1396.031, RSKangXi=178.5
293FF CJK UNIFIED IDEOGRAPH-#293FF, IRGKangXi=1396.031, RSKangXi=178.9
29400 CJK UNIFIED IDEOGRAPH-#29400, IRGKangXi=1396.031, RSKangXi=178.9
29401 CJK UNIFIED IDEOGRAPH-#29401, IRGKangXi=1396.070, RSKangXi=179.4
29402 CJK UNIFIED IDEOGRAPH-#29402, IRGKangXi=1396.071, RSKangXi=179.4
29403 CJK UNIFIED IDEOGRAPH-#29403, IRGKangXi=1396.081, RSKangXi=179.6
29404 CJK UNIFIED IDEOGRAPH-#29404, IRGKangXi=1396.100, RSKangXi=179.7
29405 CJK UNIFIED IDEOGRAPH-#29405, IRGKangXi=1396.110, RSKangXi=179.8
29406 CJK UNIFIED IDEOGRAPH-#29406, IRGKangXi=1396.121, RSKangXi=179.8
29407 CJK UNIFIED IDEOGRAPH-#29407, IRGKangXi=1396.121, RSKangXi=179.8
29408 CJK UNIFIED IDEOGRAPH-#29408, IRGKangXi=1396.121, RSKangXi=179.9
29409 CJK UNIFIED IDEOGRAPH-#29409, IRGKangXi=1396.150, RSKangXi=179.10
2940A CJK UNIFIED IDEOGRAPH-#2940A, IRGKangXi=1396.160, RSKangXi=179.10
2940B CJK UNIFIED IDEOGRAPH-#2940B, IRGKangXi=1396.180, RSKangXi=179.11
2940C CJK UNIFIED IDEOGRAPH-#2940C, IRGKangXi=1396.190, RSKangXi=179.12
2940D CJK UNIFIED IDEOGRAPH-#2940D, IRGKangXi=1396.191, RSKangXi=179.11
2940E CJK UNIFIED IDEOGRAPH-#2940E, IRGKangXi=1396.191, RSKangXi=179.11
2940F CJK UNIFIED IDEOGRAPH-#2940F, IRGKangXi=1396.210, RSKangXi=179.12
29410 CJK UNIFIED IDEOGRAPH-#29410, IRGKangXi=1396.211, RSKangXi=179.12
29411 CJK UNIFIED IDEOGRAPH-#29411, IRGKangXi=1396.211, RSKangXi=179.13
29412 CJK UNIFIED IDEOGRAPH-#29412, IRGKangXi=1396.211, RSKangXi=179.13
29413 CJK UNIFIED IDEOGRAPH-#29413, IRGKangXi=1396.211, RSKangXi=179.13
29414 CJK UNIFIED IDEOGRAPH-#29414, IRGKangXi=1396.230, RSKangXi=179.14
29415 CJK UNIFIED IDEOGRAPH-#29415, IRGKangXi=1396.231, RSKangXi=179.14
29416 CJK UNIFIED IDEOGRAPH-#29416, IRGKangXi=1396.240, RSKangXi=179.16
29417 CJK UNIFIED IDEOGRAPH-#29417, IRGKangXi=1397.021, RSKangXi=180.3
29418 CJK UNIFIED IDEOGRAPH-#29418, IRGKangXi=1397.060, RSKangXi=180.4
29419 CJK UNIFIED IDEOGRAPH-#29419, IRGKangXi=1397.061, RSKangXi=180.4
2941A CJK UNIFIED IDEOGRAPH-#2941A, IRGKangXi=1397.070, RSKangXi=180.5
2941B CJK UNIFIED IDEOGRAPH-#2941B, IRGKangXi=1397.080, RSKangXi=180.5
2941C CJK UNIFIED IDEOGRAPH-#2941C, IRGKangXi=1397.111, RSKangXi=180.5
2941D CJK UNIFIED IDEOGRAPH-#2941D, IRGKangXi=1397.111, RSKangXi=180.5
2941E CJK UNIFIED IDEOGRAPH-#2941E, IRGKangXi=1397.120, RSKangXi=180.6
2941F CJK UNIFIED IDEOGRAPH-#2941F, IRGKangXi=1397.130, RSKangXi=180.6
29420 CJK UNIFIED IDEOGRAPH-#29420, IRGKangXi=1397.140, RSKangXi=180.6
29421 CJK UNIFIED IDEOGRAPH-#29421, IRGKangXi=1397.150, RSKangXi=180.6
29422 CJK UNIFIED IDEOGRAPH-#29422, IRGKangXi=1397.160, RSKangXi=180.6
29423 CJK UNIFIED IDEOGRAPH-#29423, IRGKangXi=1397.161, RSKangXi=180.6
29424 CJK UNIFIED IDEOGRAPH-#29424, IRGKangXi=1397.161, RSKangXi=180.6
29425 CJK UNIFIED IDEOGRAPH-#29425, IRGKangXi=1397.161, RSKangXi=180.6
29426 CJK UNIFIED IDEOGRAPH-#29426, IRGKangXi=1397.161, RSKangXi=180.6
29427 CJK UNIFIED IDEOGRAPH-#29427, IRGKangXi=1397.170, RSKangXi=180.7
29428 CJK UNIFIED IDEOGRAPH-#29428, IRGKangXi=1397.210, RSKangXi=180.7
29429 CJK UNIFIED IDEOGRAPH-#29429, IRGKangXi=1397.211, RSKangXi=180.7
2942A CJK UNIFIED IDEOGRAPH-#2942A, IRGKangXi=1397.211, RSKangXi=180.7
2942B CJK UNIFIED IDEOGRAPH-#2942B, IRGKangXi=1397.211, RSKangXi=180.7
2942C CJK UNIFIED IDEOGRAPH-#2942C, IRGKangXi=1397.211, RSKangXi=180.7
2942D CJK UNIFIED IDEOGRAPH-#2942D, IRGKangXi=1397.220, RSKangXi=180.8
2942E CJK UNIFIED IDEOGRAPH-#2942E, IRGKangXi=1397.221, RSKangXi=180.8
2942F CJK UNIFIED IDEOGRAPH-#2942F, IRGKangXi=1397.221, RSKangXi=180.8
29430 CJK UNIFIED IDEOGRAPH-#29430, IRGKangXi=1397.221, RSKangXi=180.8
29431 CJK UNIFIED IDEOGRAPH-#29431, IRGKangXi=1397.250, RSKangXi=180.9
29432 CJK UNIFIED IDEOGRAPH-#29432, IRGKangXi=1397.251, RSKangXi=180.9
29433 CJK UNIFIED IDEOGRAPH-#29433, IRGKangXi=1397.251, RSKangXi=180.9
29434 CJK UNIFIED IDEOGRAPH-#29434, IRGKangXi=1397.251, RSKangXi=180.9
29435 CJK UNIFIED IDEOGRAPH-#29435, IRGKangXi=1397.270, RSKangXi=180.10
29436 CJK UNIFIED IDEOGRAPH-#29436, IRGKangXi=1397.310, RSKangXi=180.10
29437 CJK UNIFIED IDEOGRAPH-#29437, IRGKangXi=1397.311, RSKangXi=180.10
29438 CJK UNIFIED IDEOGRAPH-#29438, IRGKangXi=1397.311, RSKangXi=180.10
29439 CJK UNIFIED IDEOGRAPH-#29439, IRGKangXi=1397.350, RSKangXi=180.11
2943A CJK UNIFIED IDEOGRAPH-#2943A, IRGKangXi=1397.351, RSKangXi=180.11
2943B CJK UNIFIED IDEOGRAPH-#2943B, IRGKangXi=1397.351, RSKangXi=180.11
2943C CJK UNIFIED IDEOGRAPH-#2943C, IRGKangXi=1397.351, RSKangXi=180.11
2943D CJK UNIFIED IDEOGRAPH-#2943D, IRGKangXi=1397.351, RSKangXi=180.11
2943E CJK UNIFIED IDEOGRAPH-#2943E, IRGKangXi=1397.351, RSKangXi=180.11
2943F CJK UNIFIED IDEOGRAPH-#2943F, IRGKangXi=1397.360, RSKangXi=180.12
29440 CJK UNIFIED IDEOGRAPH-#29440, IRGKangXi=1397.361, RSKangXi=180.12
29441 CJK UNIFIED IDEOGRAPH-#29441, IRGKangXi=1397.361, RSKangXi=180.12
29442 CJK UNIFIED IDEOGRAPH-#29442, IRGKangXi=1397.370, RSKangXi=180.13
29443 CJK UNIFIED IDEOGRAPH-#29443, IRGKangXi=1397.380, RSKangXi=180.13
29444 CJK UNIFIED IDEOGRAPH-#29444, IRGKangXi=1398.050, RSKangXi=180.13
29445 CJK UNIFIED IDEOGRAPH-#29445, IRGKangXi=1398.060, RSKangXi=180.13
29446 CJK UNIFIED IDEOGRAPH-#29446, IRGKangXi=1398.061, RSKangXi=180.13
29447 CJK UNIFIED IDEOGRAPH-#29447, IRGKangXi=1398.080, RSKangXi=180.14
29448 CJK UNIFIED IDEOGRAPH-#29448, IRGKangXi=1398.081, RSKangXi=180.15
29449 CJK UNIFIED IDEOGRAPH-#29449, IRGKangXi=1398.081, RSKangXi=180.18
2944A CJK UNIFIED IDEOGRAPH-#2944A, IRGKangXi=1398.090, RSKangXi=180.24
2944B CJK UNIFIED IDEOGRAPH-#2944B, IRGKangXi=1399.011, RSKangXi=181.0
2944C CJK UNIFIED IDEOGRAPH-#2944C, IRGKangXi=1399.030, RSKangXi=181.2
2944D CJK UNIFIED IDEOGRAPH-#2944D, IRGKangXi=1399.040, RSKangXi=181.2
2944E CJK UNIFIED IDEOGRAPH-#2944E, IRGKangXi=1399.071, RSKangXi=181.2
2944F CJK UNIFIED IDEOGRAPH-#2944F, IRGKangXi=1399.071, RSKangXi=181.2
29450 CJK UNIFIED IDEOGRAPH-#29450, IRGKangXi=1399.080, RSKangXi=181.3
29451 CJK UNIFIED IDEOGRAPH-#29451, IRGKangXi=1399.090, RSKangXi=181.3
29452 CJK UNIFIED IDEOGRAPH-#29452, IRGKangXi=1399.120, RSKangXi=181.3
29453 CJK UNIFIED IDEOGRAPH-#29453, IRGKangXi=1399.140, RSKangXi=181.3
29454 CJK UNIFIED IDEOGRAPH-#29454, IRGKangXi=1399.150, RSKangXi=181.3
29455 CJK UNIFIED IDEOGRAPH-#29455, IRGKangXi=1399.160, RSKangXi=181.3
29456 CJK UNIFIED IDEOGRAPH-#29456, IRGKangXi=1399.210, RSKangXi=181.3
29457 CJK UNIFIED IDEOGRAPH-#29457, IRGKangXi=1400.010, RSKangXi=181.3
29458 CJK UNIFIED IDEOGRAPH-#29458, IRGKangXi=1400.021, RSKangXi=181.3
29459 CJK UNIFIED IDEOGRAPH-#29459, IRGKangXi=1400.030, RSKangXi=181.4
2945A CJK UNIFIED IDEOGRAPH-#2945A, IRGKangXi=1400.050, RSKangXi=181.4
2945B CJK UNIFIED IDEOGRAPH-#2945B, IRGKangXi=1400.070, RSKangXi=181.4
2945C CJK UNIFIED IDEOGRAPH-#2945C, IRGKangXi=1400.080, RSKangXi=181.4
2945D CJK UNIFIED IDEOGRAPH-#2945D, IRGKangXi=1400.090, RSKangXi=181.4
2945E CJK UNIFIED IDEOGRAPH-#2945E, IRGKangXi=1400.100, RSKangXi=181.4
2945F CJK UNIFIED IDEOGRAPH-#2945F, IRGKangXi=1400.110, RSKangXi=181.4
29460 CJK UNIFIED IDEOGRAPH-#29460, IRGKangXi=1400.130, RSKangXi=181.4
29461 CJK UNIFIED IDEOGRAPH-#29461, IRGKangXi=1400.140, RSKangXi=181.4
29462 CJK UNIFIED IDEOGRAPH-#29462, IRGKangXi=1400.150, RSKangXi=181.4
29463 CJK UNIFIED IDEOGRAPH-#29463, IRGKangXi=1401.050, RSKangXi=181.4
29464 CJK UNIFIED IDEOGRAPH-#29464, IRGKangXi=1401.070, RSKangXi=181.4
29465 CJK UNIFIED IDEOGRAPH-#29465, IRGKangXi=1401.090, RSKangXi=181.4
29466 CJK UNIFIED IDEOGRAPH-#29466, IRGKangXi=1401.100, RSKangXi=181.4
29467 CJK UNIFIED IDEOGRAPH-#29467, IRGKangXi=1401.120, RSKangXi=181.4
29468 CJK UNIFIED IDEOGRAPH-#29468, IRGKangXi=1401.130, RSKangXi=181.4
29469 CJK UNIFIED IDEOGRAPH-#29469, IRGKangXi=1401.140, RSKangXi=181.4
2946A CJK UNIFIED IDEOGRAPH-#2946A, IRGKangXi=1401.150, RSKangXi=181.4
2946B CJK UNIFIED IDEOGRAPH-#2946B, IRGKangXi=1401.151, RSKangXi=181.4
2946C CJK UNIFIED IDEOGRAPH-#2946C, IRGKangXi=1401.151, RSKangXi=181.4
2946D CJK UNIFIED IDEOGRAPH-#2946D, IRGKangXi=1401.151, RSKangXi=181.4
2946E CJK UNIFIED IDEOGRAPH-#2946E, IRGKangXi=1401.151, RSKangXi=181.4
2946F CJK UNIFIED IDEOGRAPH-#2946F, IRGKangXi=1401.151, RSKangXi=181.4
29470 CJK UNIFIED IDEOGRAPH-#29470, IRGKangXi=1401.180, RSKangXi=181.5
29471 CJK UNIFIED IDEOGRAPH-#29471, IRGKangXi=1401.190, RSKangXi=181.5
29472 CJK UNIFIED IDEOGRAPH-#29472, IRGKangXi=1402.020, RSKangXi=181.5
29473 CJK UNIFIED IDEOGRAPH-#29473, IRGKangXi=1402.040, RSKangXi=181.5
29474 CJK UNIFIED IDEOGRAPH-#29474, IRGKangXi=1402.050, RSKangXi=181.5
29475 CJK UNIFIED IDEOGRAPH-#29475, IRGKangXi=1402.060, RSKangXi=181.5
29476 CJK UNIFIED IDEOGRAPH-#29476, IRGKangXi=1402.070, RSKangXi=181.5
29477 CJK UNIFIED IDEOGRAPH-#29477, IRGKangXi=1402.080, RSKangXi=181.5
29478 CJK UNIFIED IDEOGRAPH-#29478, IRGKangXi=1402.090, RSKangXi=181.5
29479 CJK UNIFIED IDEOGRAPH-#29479, IRGKangXi=1402.100, RSKangXi=181.5
2947A CJK UNIFIED IDEOGRAPH-#2947A, IRGKangXi=1402.120, RSKangXi=181.5
2947B CJK UNIFIED IDEOGRAPH-#2947B, IRGKangXi=1402.130, RSKangXi=181.5
2947C CJK UNIFIED IDEOGRAPH-#2947C, IRGKangXi=1402.150, RSKangXi=181.5
2947D CJK UNIFIED IDEOGRAPH-#2947D, IRGKangXi=1402.160, RSKangXi=181.5
2947E CJK UNIFIED IDEOGRAPH-#2947E, IRGKangXi=1402.200, RSKangXi=181.5
2947F CJK UNIFIED IDEOGRAPH-#2947F, IRGKangXi=1402.240, RSKangXi=181.5
29480 CJK UNIFIED IDEOGRAPH-#29480, IRGKangXi=1402.260, RSKangXi=181.5
29481 CJK UNIFIED IDEOGRAPH-#29481, IRGKangXi=1402.270, RSKangXi=181.5
29482 CJK UNIFIED IDEOGRAPH-#29482, IRGKangXi=1402.280, RSKangXi=181.5
29483 CJK UNIFIED IDEOGRAPH-#29483, IRGKangXi=1402.290, RSKangXi=181.5
29484 CJK UNIFIED IDEOGRAPH-#29484, IRGKangXi=1402.300, RSKangXi=181.5
29485 CJK UNIFIED IDEOGRAPH-#29485, IRGKangXi=1402.301, RSKangXi=181.5
29486 CJK UNIFIED IDEOGRAPH-#29486, IRGKangXi=1402.301, RSKangXi=181.5
29487 CJK UNIFIED IDEOGRAPH-#29487, IRGKangXi=1402.301, RSKangXi=181.5
29488 CJK UNIFIED IDEOGRAPH-#29488, IRGKangXi=1402.301, RSKangXi=181.5
29489 CJK UNIFIED IDEOGRAPH-#29489, IRGKangXi=1402.301, RSKangXi=181.5
2948A CJK UNIFIED IDEOGRAPH-#2948A, IRGKangXi=1402.301, RSKangXi=181.5
2948B CJK UNIFIED IDEOGRAPH-#2948B, IRGKangXi=1402.301, RSKangXi=181.5
2948C CJK UNIFIED IDEOGRAPH-#2948C, IRGKangXi=1402.301, RSKangXi=181.5
2948D CJK UNIFIED IDEOGRAPH-#2948D, IRGKangXi=1402.301, RSKangXi=181.5
2948E CJK UNIFIED IDEOGRAPH-#2948E, IRGKangXi=1402.301, RSKangXi=181.5
2948F CJK UNIFIED IDEOGRAPH-#2948F, IRGKangXi=1402.310, RSKangXi=181.6
29490 CJK UNIFIED IDEOGRAPH-#29490, IRGKangXi=1402.340, RSKangXi=181.6
29491 CJK UNIFIED IDEOGRAPH-#29491, IRGKangXi=1402.370, RSKangXi=181.6
29492 CJK UNIFIED IDEOGRAPH-#29492, IRGKangXi=1403.010, RSKangXi=181.6
29493 CJK UNIFIED IDEOGRAPH-#29493, IRGKangXi=1403.020, RSKangXi=181.6
29494 CJK UNIFIED IDEOGRAPH-#29494, IRGKangXi=1403.070, RSKangXi=181.6
29495 CJK UNIFIED IDEOGRAPH-#29495, IRGKangXi=1403.080, RSKangXi=181.6
29496 CJK UNIFIED IDEOGRAPH-#29496, IRGKangXi=1403.160, RSKangXi=181.6
29497 CJK UNIFIED IDEOGRAPH-#29497, IRGKangXi=1403.190, RSKangXi=181.6
29498 CJK UNIFIED IDEOGRAPH-#29498, IRGKangXi=1404.010, RSKangXi=181.6
29499 CJK UNIFIED IDEOGRAPH-#29499, IRGKangXi=1404.020, RSKangXi=181.6
2949A CJK UNIFIED IDEOGRAPH-#2949A, IRGKangXi=1404.030, RSKangXi=181.6
2949B CJK UNIFIED IDEOGRAPH-#2949B, IRGKangXi=1404.040, RSKangXi=181.6
2949C CJK UNIFIED IDEOGRAPH-#2949C, IRGKangXi=1404.050, RSKangXi=181.6
2949D CJK UNIFIED IDEOGRAPH-#2949D, IRGKangXi=1404.060, RSKangXi=181.6
2949E CJK UNIFIED IDEOGRAPH-#2949E, IRGKangXi=1404.070, RSKangXi=181.6
2949F CJK UNIFIED IDEOGRAPH-#2949F, IRGKangXi=1404.071, RSKangXi=181.6
294A0 CJK UNIFIED IDEOGRAPH-#294A0, IRGKangXi=1404.071, RSKangXi=181.6
294A1 CJK UNIFIED IDEOGRAPH-#294A1, IRGKangXi=1404.071, RSKangXi=181.6
294A2 CJK UNIFIED IDEOGRAPH-#294A2, IRGKangXi=1404.071, RSKangXi=181.6
294A3 CJK UNIFIED IDEOGRAPH-#294A3, IRGKangXi=1404.071, RSKangXi=181.6
294A4 CJK UNIFIED IDEOGRAPH-#294A4, IRGKangXi=1404.071, RSKangXi=181.6
294A5 CJK UNIFIED IDEOGRAPH-#294A5, IRGKangXi=1404.071, RSKangXi=181.6
294A6 CJK UNIFIED IDEOGRAPH-#294A6, IRGKangXi=1404.071, RSKangXi=181.6
294A7 CJK UNIFIED IDEOGRAPH-#294A7, IRGKangXi=1404.071, RSKangXi=181.6
294A8 CJK UNIFIED IDEOGRAPH-#294A8, IRGKangXi=1404.071, RSKangXi=181.6
294A9 CJK UNIFIED IDEOGRAPH-#294A9, IRGKangXi=1404.071, RSKangXi=181.6
294AA CJK UNIFIED IDEOGRAPH-#294AA, IRGKangXi=1404.071, RSKangXi=181.6
294AB CJK UNIFIED IDEOGRAPH-#294AB, IRGKangXi=1404.071, RSKangXi=181.6
294AC CJK UNIFIED IDEOGRAPH-#294AC, IRGKangXi=1404.071, RSKangXi=181.6
294AD CJK UNIFIED IDEOGRAPH-#294AD, IRGKangXi=1404.071, RSKangXi=181.6
294AE CJK UNIFIED IDEOGRAPH-#294AE, IRGKangXi=1404.090, RSKangXi=181.7
294AF CJK UNIFIED IDEOGRAPH-#294AF, IRGKangXi=1404.110, RSKangXi=181.7
294B0 CJK UNIFIED IDEOGRAPH-#294B0, IRGKangXi=1404.120, RSKangXi=181.7
294B1 CJK UNIFIED IDEOGRAPH-#294B1, IRGKangXi=1404.130, RSKangXi=181.7
294B2 CJK UNIFIED IDEOGRAPH-#294B2, IRGKangXi=1404.150, RSKangXi=181.7
294B3 CJK UNIFIED IDEOGRAPH-#294B3, IRGKangXi=1404.160, RSKangXi=181.7
294B4 CJK UNIFIED IDEOGRAPH-#294B4, IRGKangXi=1404.170, RSKangXi=181.7
294B5 CJK UNIFIED IDEOGRAPH-#294B5, IRGKangXi=1404.180, RSKangXi=181.7
294B6 CJK UNIFIED IDEOGRAPH-#294B6, IRGKangXi=1404.240, RSKangXi=181.7
294B7 CJK UNIFIED IDEOGRAPH-#294B7, IRGKangXi=1404.250, RSKangXi=181.7
294B8 CJK UNIFIED IDEOGRAPH-#294B8, IRGKangXi=1404.260, RSKangXi=181.7
294B9 CJK UNIFIED IDEOGRAPH-#294B9, IRGKangXi=1404.300, RSKangXi=181.7
294BA CJK UNIFIED IDEOGRAPH-#294BA, IRGKangXi=1404.320, RSKangXi=181.7
294BB CJK UNIFIED IDEOGRAPH-#294BB, IRGKangXi=1404.330, RSKangXi=181.7
294BC CJK UNIFIED IDEOGRAPH-#294BC, IRGKangXi=1405.010, RSKangXi=181.7
294BD CJK UNIFIED IDEOGRAPH-#294BD, IRGKangXi=1405.030, RSKangXi=181.7
294BE CJK UNIFIED IDEOGRAPH-#294BE, IRGKangXi=1405.060, RSKangXi=181.7
294BF CJK UNIFIED IDEOGRAPH-#294BF, IRGKangXi=1405.070, RSKangXi=181.7
294C0 CJK UNIFIED IDEOGRAPH-#294C0, IRGKangXi=1405.110, RSKangXi=181.7
294C1 CJK UNIFIED IDEOGRAPH-#294C1, IRGKangXi=1405.120, RSKangXi=181.7
294C2 CJK UNIFIED IDEOGRAPH-#294C2, IRGKangXi=1405.130, RSKangXi=181.7
294C3 CJK UNIFIED IDEOGRAPH-#294C3, IRGKangXi=1405.210, RSKangXi=181.7
294C4 CJK UNIFIED IDEOGRAPH-#294C4, IRGKangXi=1405.220, RSKangXi=181.7
294C5 CJK UNIFIED IDEOGRAPH-#294C5, IRGKangXi=1405.230, RSKangXi=181.7
294C6 CJK UNIFIED IDEOGRAPH-#294C6, IRGKangXi=1405.240, RSKangXi=181.7
294C7 CJK UNIFIED IDEOGRAPH-#294C7, IRGKangXi=1405.241, RSKangXi=181.7
294C8 CJK UNIFIED IDEOGRAPH-#294C8, IRGKangXi=1405.241, RSKangXi=181.7
294C9 CJK UNIFIED IDEOGRAPH-#294C9, IRGKangXi=1405.241, RSKangXi=181.7
294CA CJK UNIFIED IDEOGRAPH-#294CA, IRGKangXi=1405.241, RSKangXi=181.7
294CB CJK UNIFIED IDEOGRAPH-#294CB, IRGKangXi=1405.241, RSKangXi=181.7
294CC CJK UNIFIED IDEOGRAPH-#294CC, IRGKangXi=1405.241, RSKangXi=181.7
294CD CJK UNIFIED IDEOGRAPH-#294CD, IRGKangXi=1405.241, RSKangXi=181.7
294CE CJK UNIFIED IDEOGRAPH-#294CE, IRGKangXi=1405.241, RSKangXi=181.7
294CF CJK UNIFIED IDEOGRAPH-#294CF, IRGKangXi=1405.241, RSKangXi=181.7
294D0 CJK UNIFIED IDEOGRAPH-#294D0, IRGKangXi=1405.241, RSKangXi=181.7
294D1 CJK UNIFIED IDEOGRAPH-#294D1, IRGKangXi=1405.241, RSKangXi=181.7
294D2 CJK UNIFIED IDEOGRAPH-#294D2, IRGKangXi=1405.241, RSKangXi=181.7
294D3 CJK UNIFIED IDEOGRAPH-#294D3, IRGKangXi=1405.241, RSKangXi=181.7
294D4 CJK UNIFIED IDEOGRAPH-#294D4, IRGKangXi=1405.241, RSKangXi=181.7
294D5 CJK UNIFIED IDEOGRAPH-#294D5, IRGKangXi=1405.241, RSKangXi=181.7
294D6 CJK UNIFIED IDEOGRAPH-#294D6, IRGKangXi=1405.241, RSKangXi=181.7
294D7 CJK UNIFIED IDEOGRAPH-#294D7, IRGKangXi=1405.241, RSKangXi=181.7
294D8 CJK UNIFIED IDEOGRAPH-#294D8, IRGKangXi=1405.241, RSKangXi=181.7
294D9 CJK UNIFIED IDEOGRAPH-#294D9, IRGKangXi=1405.241, RSKangXi=181.7
294DA CJK UNIFIED IDEOGRAPH-#294DA, IRGKangXi=1405.241, RSKangXi=181.7
294DB CJK UNIFIED IDEOGRAPH-#294DB, IRGKangXi=1405.241, RSKangXi=181.7
294DC CJK UNIFIED IDEOGRAPH-#294DC, IRGKangXi=1405.241, RSKangXi=181.7
294DD CJK UNIFIED IDEOGRAPH-#294DD, IRGKangXi=1405.320, RSKangXi=181.8
294DE CJK UNIFIED IDEOGRAPH-#294DE, IRGKangXi=1405.340, RSKangXi=181.8
294DF CJK UNIFIED IDEOGRAPH-#294DF, IRGKangXi=1405.380, RSKangXi=181.8
294E0 CJK UNIFIED IDEOGRAPH-#294E0, IRGKangXi=1405.400, RSKangXi=181.8
294E1 CJK UNIFIED IDEOGRAPH-#294E1, IRGKangXi=1406.010, RSKangXi=181.8
294E2 CJK UNIFIED IDEOGRAPH-#294E2, IRGKangXi=1406.030, RSKangXi=181.8
294E3 CJK UNIFIED IDEOGRAPH-#294E3, IRGKangXi=1406.050, RSKangXi=181.8
294E4 CJK UNIFIED IDEOGRAPH-#294E4, IRGKangXi=1406.070, RSKangXi=181.8
294E5 CJK UNIFIED IDEOGRAPH-#294E5, IRGKangXi=1406.080, RSKangXi=181.8, Def{(Cant.) to raise the head}
294E6 CJK UNIFIED IDEOGRAPH-#294E6, IRGKangXi=1406.100, RSKangXi=181.8
294E7 CJK UNIFIED IDEOGRAPH-#294E7, IRGKangXi=1406.110, RSKangXi=181.8
294E8 CJK UNIFIED IDEOGRAPH-#294E8, IRGKangXi=1406.130, RSKangXi=181.8
294E9 CJK UNIFIED IDEOGRAPH-#294E9, IRGKangXi=1406.140, RSKangXi=181.8
294EA CJK UNIFIED IDEOGRAPH-#294EA, IRGKangXi=1406.150, RSKangXi=181.8
294EB CJK UNIFIED IDEOGRAPH-#294EB, IRGKangXi=1406.200, RSKangXi=181.8
294EC CJK UNIFIED IDEOGRAPH-#294EC, IRGKangXi=1406.210, RSKangXi=181.8
294ED CJK UNIFIED IDEOGRAPH-#294ED, IRGKangXi=1406.220, RSKangXi=181.8
294EE CJK UNIFIED IDEOGRAPH-#294EE, IRGKangXi=1406.230, RSKangXi=181.8
294EF CJK UNIFIED IDEOGRAPH-#294EF, IRGKangXi=1406.260, RSKangXi=181.8
294F0 CJK UNIFIED IDEOGRAPH-#294F0, IRGKangXi=1406.261, RSKangXi=181.8
294F1 CJK UNIFIED IDEOGRAPH-#294F1, IRGKangXi=1406.261, RSKangXi=181.8
294F2 CJK UNIFIED IDEOGRAPH-#294F2, IRGKangXi=1406.261, RSKangXi=181.8
294F3 CJK UNIFIED IDEOGRAPH-#294F3, IRGKangXi=1406.261, RSKangXi=181.8
294F4 CJK UNIFIED IDEOGRAPH-#294F4, IRGKangXi=1406.261, RSKangXi=181.8
294F5 CJK UNIFIED IDEOGRAPH-#294F5, IRGKangXi=1406.261, RSKangXi=181.8
294F6 CJK UNIFIED IDEOGRAPH-#294F6, IRGKangXi=1406.261, RSKangXi=181.8
294F7 CJK UNIFIED IDEOGRAPH-#294F7, IRGKangXi=1406.261, RSKangXi=181.8
294F8 CJK UNIFIED IDEOGRAPH-#294F8, IRGKangXi=1406.261, RSKangXi=181.8
294F9 CJK UNIFIED IDEOGRAPH-#294F9, IRGKangXi=1406.261, RSKangXi=181.8
294FA CJK UNIFIED IDEOGRAPH-#294FA, IRGKangXi=1406.261, RSKangXi=181.8
294FB CJK UNIFIED IDEOGRAPH-#294FB, IRGKangXi=1406.261, RSKangXi=181.8
294FC CJK UNIFIED IDEOGRAPH-#294FC, IRGKangXi=1406.261, RSKangXi=181.8
294FD CJK UNIFIED IDEOGRAPH-#294FD, IRGKangXi=1406.261, RSKangXi=181.8
294FE CJK UNIFIED IDEOGRAPH-#294FE, IRGKangXi=1406.261, RSKangXi=181.8
294FF CJK UNIFIED IDEOGRAPH-#294FF, IRGKangXi=1406.261, RSKangXi=181.8
29500 CJK UNIFIED IDEOGRAPH-#29500, IRGKangXi=1406.270, RSKangXi=181.9
29501 CJK UNIFIED IDEOGRAPH-#29501, IRGKangXi=1406.280, RSKangXi=181.9
29502 CJK UNIFIED IDEOGRAPH-#29502, IRGKangXi=1406.310, RSKangXi=181.9
29503 CJK UNIFIED IDEOGRAPH-#29503, IRGKangXi=1406.320, RSKangXi=181.9
29504 CJK UNIFIED IDEOGRAPH-#29504, IRGKangXi=1406.370, RSKangXi=181.9
29505 CJK UNIFIED IDEOGRAPH-#29505, IRGKangXi=1406.390, RSKangXi=181.9
29506 CJK UNIFIED IDEOGRAPH-#29506, IRGKangXi=1407.010, RSKangXi=181.9
29507 CJK UNIFIED IDEOGRAPH-#29507, IRGKangXi=1407.030, RSKangXi=181.9
29508 CJK UNIFIED IDEOGRAPH-#29508, IRGKangXi=1407.060, RSKangXi=181.9
29509 CJK UNIFIED IDEOGRAPH-#29509, IRGKangXi=1407.070, RSKangXi=181.9
2950A CJK UNIFIED IDEOGRAPH-#2950A, IRGKangXi=1407.080, RSKangXi=181.9
2950B CJK UNIFIED IDEOGRAPH-#2950B, IRGKangXi=1407.150, RSKangXi=181.9
2950C CJK UNIFIED IDEOGRAPH-#2950C, IRGKangXi=1407.160, RSKangXi=181.9
2950D CJK UNIFIED IDEOGRAPH-#2950D, IRGKangXi=1407.171, RSKangXi=181.9
2950E CJK UNIFIED IDEOGRAPH-#2950E, IRGKangXi=1407.171, RSKangXi=181.9
2950F CJK UNIFIED IDEOGRAPH-#2950F, IRGKangXi=1407.171, RSKangXi=181.9
29510 CJK UNIFIED IDEOGRAPH-#29510, IRGKangXi=1407.171, RSKangXi=181.9
29511 CJK UNIFIED IDEOGRAPH-#29511, IRGKangXi=1407.171, RSKangXi=181.9
29512 CJK UNIFIED IDEOGRAPH-#29512, IRGKangXi=1407.171, RSKangXi=181.9
29513 CJK UNIFIED IDEOGRAPH-#29513, IRGKangXi=1407.171, RSKangXi=181.9
29514 CJK UNIFIED IDEOGRAPH-#29514, IRGKangXi=1407.171, RSKangXi=181.9
29515 CJK UNIFIED IDEOGRAPH-#29515, IRGKangXi=1407.171, RSKangXi=181.9
29516 CJK UNIFIED IDEOGRAPH-#29516, IRGKangXi=1407.171, RSKangXi=181.9
29517 CJK UNIFIED IDEOGRAPH-#29517, IRGKangXi=1407.171, RSKangXi=181.9, Def{kind, species; to be similar to}
29518 CJK UNIFIED IDEOGRAPH-#29518, IRGKangXi=1407.171, RSKangXi=181.9
29519 CJK UNIFIED IDEOGRAPH-#29519, IRGKangXi=1407.190, RSKangXi=181.10
2951A CJK UNIFIED IDEOGRAPH-#2951A, IRGKangXi=1407.240, RSKangXi=181.10
2951B CJK UNIFIED IDEOGRAPH-#2951B, IRGKangXi=1407.250, RSKangXi=181.10
2951C CJK UNIFIED IDEOGRAPH-#2951C, IRGKangXi=1407.280, RSKangXi=181.10
2951D CJK UNIFIED IDEOGRAPH-#2951D, IRGKangXi=1407.290, RSKangXi=181.10
2951E CJK UNIFIED IDEOGRAPH-#2951E, IRGKangXi=1407.300, RSKangXi=181.10
2951F CJK UNIFIED IDEOGRAPH-#2951F, IRGKangXi=1408.030, RSKangXi=181.10
29520 CJK UNIFIED IDEOGRAPH-#29520, IRGKangXi=1408.070, RSKangXi=181.10
29521 CJK UNIFIED IDEOGRAPH-#29521, IRGKangXi=1408.120, RSKangXi=181.10
29522 CJK UNIFIED IDEOGRAPH-#29522, IRGKangXi=1408.140, RSKangXi=181.10
29523 CJK UNIFIED IDEOGRAPH-#29523, IRGKangXi=1408.150, RSKangXi=181.10
29524 CJK UNIFIED IDEOGRAPH-#29524, IRGKangXi=1408.160, RSKangXi=181.10
29525 CJK UNIFIED IDEOGRAPH-#29525, IRGKangXi=1408.170, RSKangXi=181.10
29526 CJK UNIFIED IDEOGRAPH-#29526, IRGKangXi=1408.180, RSKangXi=181.10
29527 CJK UNIFIED IDEOGRAPH-#29527, IRGKangXi=1408.190, RSKangXi=181.10
29528 CJK UNIFIED IDEOGRAPH-#29528, IRGKangXi=1408.200, RSKangXi=181.10
29529 CJK UNIFIED IDEOGRAPH-#29529, IRGKangXi=1408.210, RSKangXi=181.10
2952A CJK UNIFIED IDEOGRAPH-#2952A, IRGKangXi=1408.211, RSKangXi=181.10
2952B CJK UNIFIED IDEOGRAPH-#2952B, IRGKangXi=1408.211, RSKangXi=181.10
2952C CJK UNIFIED IDEOGRAPH-#2952C, IRGKangXi=1408.211, RSKangXi=181.10
2952D CJK UNIFIED IDEOGRAPH-#2952D, IRGKangXi=1408.211, RSKangXi=181.10
2952E CJK UNIFIED IDEOGRAPH-#2952E, IRGKangXi=1408.211, RSKangXi=181.10
2952F CJK UNIFIED IDEOGRAPH-#2952F, IRGKangXi=1408.211, RSKangXi=181.10
29530 CJK UNIFIED IDEOGRAPH-#29530, IRGKangXi=1408.211, RSKangXi=181.10
29531 CJK UNIFIED IDEOGRAPH-#29531, IRGKangXi=1408.211, RSKangXi=181.10
29532 CJK UNIFIED IDEOGRAPH-#29532, IRGKangXi=1408.211, RSKangXi=181.10
29533 CJK UNIFIED IDEOGRAPH-#29533, IRGKangXi=1408.220, RSKangXi=181.11
29534 CJK UNIFIED IDEOGRAPH-#29534, IRGKangXi=1408.240, RSKangXi=181.11
29535 CJK UNIFIED IDEOGRAPH-#29535, IRGKangXi=1409.010, RSKangXi=181.11
29536 CJK UNIFIED IDEOGRAPH-#29536, IRGKangXi=1409.030, RSKangXi=181.11
29537 CJK UNIFIED IDEOGRAPH-#29537, IRGKangXi=1409.040, RSKangXi=181.11
29538 CJK UNIFIED IDEOGRAPH-#29538, IRGKangXi=1409.100, RSKangXi=181.11
29539 CJK UNIFIED IDEOGRAPH-#29539, IRGKangXi=1409.110, RSKangXi=181.11
2953A CJK UNIFIED IDEOGRAPH-#2953A, IRGKangXi=1409.140, RSKangXi=181.11
2953B CJK UNIFIED IDEOGRAPH-#2953B, IRGKangXi=1409.150, RSKangXi=181.11
2953C CJK UNIFIED IDEOGRAPH-#2953C, IRGKangXi=1409.160, RSKangXi=181.11
2953D CJK UNIFIED IDEOGRAPH-#2953D, IRGKangXi=1409.170, RSKangXi=181.11
2953E CJK UNIFIED IDEOGRAPH-#2953E, IRGKangXi=1409.171, RSKangXi=181.11
2953F CJK UNIFIED IDEOGRAPH-#2953F, IRGKangXi=1409.171, RSKangXi=181.11
29540 CJK UNIFIED IDEOGRAPH-#29540, IRGKangXi=1409.171, RSKangXi=181.11
29541 CJK UNIFIED IDEOGRAPH-#29541, IRGKangXi=1409.171, RSKangXi=181.11
29542 CJK UNIFIED IDEOGRAPH-#29542, IRGKangXi=1409.171, RSKangXi=181.11
29543 CJK UNIFIED IDEOGRAPH-#29543, IRGKangXi=1409.171, RSKangXi=181.11
29544 CJK UNIFIED IDEOGRAPH-#29544, IRGKangXi=1409.171, RSKangXi=181.11
29545 CJK UNIFIED IDEOGRAPH-#29545, IRGKangXi=1409.171, RSKangXi=181.11
29546 CJK UNIFIED IDEOGRAPH-#29546, IRGKangXi=1409.171, RSKangXi=181.11
29547 CJK UNIFIED IDEOGRAPH-#29547, IRGKangXi=1409.171, RSKangXi=181.11
29548 CJK UNIFIED IDEOGRAPH-#29548, IRGKangXi=1409.171, RSKangXi=181.11
29549 CJK UNIFIED IDEOGRAPH-#29549, IRGKangXi=1409.180, RSKangXi=181.12
2954A CJK UNIFIED IDEOGRAPH-#2954A, IRGKangXi=1409.190, RSKangXi=181.12
2954B CJK UNIFIED IDEOGRAPH-#2954B, IRGKangXi=1409.200, RSKangXi=181.12
2954C CJK UNIFIED IDEOGRAPH-#2954C, IRGKangXi=1409.210, RSKangXi=181.12
2954D CJK UNIFIED IDEOGRAPH-#2954D, IRGKangXi=1409.220, RSKangXi=181.12
2954E CJK UNIFIED IDEOGRAPH-#2954E, IRGKangXi=1409.240, RSKangXi=181.12
2954F CJK UNIFIED IDEOGRAPH-#2954F, IRGKangXi=1409.250, RSKangXi=181.12
29550 CJK UNIFIED IDEOGRAPH-#29550, IRGKangXi=1409.290, RSKangXi=181.12
29551 CJK UNIFIED IDEOGRAPH-#29551, IRGKangXi=1409.310, RSKangXi=181.12
29552 CJK UNIFIED IDEOGRAPH-#29552, IRGKangXi=1409.320, RSKangXi=181.12
29553 CJK UNIFIED IDEOGRAPH-#29553, IRGKangXi=1409.330, RSKangXi=181.12
29554 CJK UNIFIED IDEOGRAPH-#29554, IRGKangXi=1409.340, RSKangXi=181.12
29555 CJK UNIFIED IDEOGRAPH-#29555, IRGKangXi=1409.350, RSKangXi=181.12
29556 CJK UNIFIED IDEOGRAPH-#29556, IRGKangXi=1409.360, RSKangXi=181.12
29557 CJK UNIFIED IDEOGRAPH-#29557, IRGKangXi=1409.420, RSKangXi=181.12
29558 CJK UNIFIED IDEOGRAPH-#29558, IRGKangXi=1409.421, RSKangXi=181.12
29559 CJK UNIFIED IDEOGRAPH-#29559, IRGKangXi=1409.421, RSKangXi=181.12
2955A CJK UNIFIED IDEOGRAPH-#2955A, IRGKangXi=1409.421, RSKangXi=181.12
2955B CJK UNIFIED IDEOGRAPH-#2955B, IRGKangXi=1409.421, RSKangXi=181.12
2955C CJK UNIFIED IDEOGRAPH-#2955C, IRGKangXi=1409.421, RSKangXi=181.12
2955D CJK UNIFIED IDEOGRAPH-#2955D, IRGKangXi=1409.421, RSKangXi=181.12
2955E CJK UNIFIED IDEOGRAPH-#2955E, IRGKangXi=1409.421, RSKangXi=181.12
2955F CJK UNIFIED IDEOGRAPH-#2955F, IRGKangXi=1409.430, RSKangXi=181.13
29560 CJK UNIFIED IDEOGRAPH-#29560, IRGKangXi=1410.010, RSKangXi=181.13
29561 CJK UNIFIED IDEOGRAPH-#29561, IRGKangXi=1410.060, RSKangXi=181.13
29562 CJK UNIFIED IDEOGRAPH-#29562, IRGKangXi=1410.070, RSKangXi=181.13
29563 CJK UNIFIED IDEOGRAPH-#29563, IRGKangXi=1410.080, RSKangXi=181.13
29564 CJK UNIFIED IDEOGRAPH-#29564, IRGKangXi=1410.090, RSKangXi=181.13
29565 CJK UNIFIED IDEOGRAPH-#29565, IRGKangXi=1410.091, RSKangXi=181.13
29566 CJK UNIFIED IDEOGRAPH-#29566, IRGKangXi=1410.091, RSKangXi=181.13
29567 CJK UNIFIED IDEOGRAPH-#29567, IRGKangXi=1410.091, RSKangXi=181.13
29568 CJK UNIFIED IDEOGRAPH-#29568, IRGKangXi=1410.091, RSKangXi=181.13
29569 CJK UNIFIED IDEOGRAPH-#29569, IRGKangXi=1410.091, RSKangXi=181.13
2956A CJK UNIFIED IDEOGRAPH-#2956A, IRGKangXi=1410.091, RSKangXi=181.13
2956B CJK UNIFIED IDEOGRAPH-#2956B, IRGKangXi=1410.091, RSKangXi=181.13
2956C CJK UNIFIED IDEOGRAPH-#2956C, IRGKangXi=1410.100, RSKangXi=181.14
2956D CJK UNIFIED IDEOGRAPH-#2956D, IRGKangXi=1410.120, RSKangXi=181.14, Def{the top of a skull}
2956E CJK UNIFIED IDEOGRAPH-#2956E, IRGKangXi=1410.130, RSKangXi=181.14
2956F CJK UNIFIED IDEOGRAPH-#2956F, IRGKangXi=1410.140, RSKangXi=181.14
29570 CJK UNIFIED IDEOGRAPH-#29570, IRGKangXi=1410.160, RSKangXi=181.14
29571 CJK UNIFIED IDEOGRAPH-#29571, IRGKangXi=1410.170, RSKangXi=181.14
29572 CJK UNIFIED IDEOGRAPH-#29572, IRGKangXi=1410.180, RSKangXi=181.14
29573 CJK UNIFIED IDEOGRAPH-#29573, IRGKangXi=1410.190, RSKangXi=181.14
29574 CJK UNIFIED IDEOGRAPH-#29574, IRGKangXi=1410.230, RSKangXi=181.14
29575 CJK UNIFIED IDEOGRAPH-#29575, IRGKangXi=1410.240, RSKangXi=181.14
29576 CJK UNIFIED IDEOGRAPH-#29576, IRGKangXi=1410.250, RSKangXi=181.14
29577 CJK UNIFIED IDEOGRAPH-#29577, IRGKangXi=1410.251, RSKangXi=181.14
29578 CJK UNIFIED IDEOGRAPH-#29578, IRGKangXi=1410.251, RSKangXi=181.14
29579 CJK UNIFIED IDEOGRAPH-#29579, IRGKangXi=1410.251, RSKangXi=181.14
2957A CJK UNIFIED IDEOGRAPH-#2957A, IRGKangXi=1410.251, RSKangXi=181.14
2957B CJK UNIFIED IDEOGRAPH-#2957B, IRGKangXi=1410.251, RSKangXi=181.14
2957C CJK UNIFIED IDEOGRAPH-#2957C, IRGKangXi=1410.251, RSKangXi=181.14
2957D CJK UNIFIED IDEOGRAPH-#2957D, IRGKangXi=1410.251, RSKangXi=181.14
2957E CJK UNIFIED IDEOGRAPH-#2957E, IRGKangXi=1410.260, RSKangXi=181.15
2957F CJK UNIFIED IDEOGRAPH-#2957F, IRGKangXi=1410.270, RSKangXi=181.15
29580 CJK UNIFIED IDEOGRAPH-#29580, IRGKangXi=1410.300, RSKangXi=181.15
29581 CJK UNIFIED IDEOGRAPH-#29581, IRGKangXi=1410.310, RSKangXi=181.15
29582 CJK UNIFIED IDEOGRAPH-#29582, IRGKangXi=1410.311, RSKangXi=181.15
29583 CJK UNIFIED IDEOGRAPH-#29583, IRGKangXi=1410.311, RSKangXi=181.15
29584 CJK UNIFIED IDEOGRAPH-#29584, IRGKangXi=1410.311, RSKangXi=181.15
29585 CJK UNIFIED IDEOGRAPH-#29585, IRGKangXi=1410.311, RSKangXi=181.15
29586 CJK UNIFIED IDEOGRAPH-#29586, IRGKangXi=1410.330, RSKangXi=181.16
29587 CJK UNIFIED IDEOGRAPH-#29587, IRGKangXi=1410.360, RSKangXi=181.16
29588 CJK UNIFIED IDEOGRAPH-#29588, IRGKangXi=1410.361, RSKangXi=181.16
29589 CJK UNIFIED IDEOGRAPH-#29589, IRGKangXi=1410.370, RSKangXi=181.17
2958A CJK UNIFIED IDEOGRAPH-#2958A, IRGKangXi=1410.380, RSKangXi=181.17
2958B CJK UNIFIED IDEOGRAPH-#2958B, IRGKangXi=1410.390, RSKangXi=181.17
2958C CJK UNIFIED IDEOGRAPH-#2958C, IRGKangXi=1410.400, RSKangXi=181.17
2958D CJK UNIFIED IDEOGRAPH-#2958D, IRGKangXi=1410.410, RSKangXi=181.17
2958E CJK UNIFIED IDEOGRAPH-#2958E, IRGKangXi=1410.411, RSKangXi=181.17
2958F CJK UNIFIED IDEOGRAPH-#2958F, IRGKangXi=1410.440, RSKangXi=181.18
29590 CJK UNIFIED IDEOGRAPH-#29590, IRGKangXi=1410.450, RSKangXi=181.18
29591 CJK UNIFIED IDEOGRAPH-#29591, IRGKangXi=1410.451, RSKangXi=181.18
29592 CJK UNIFIED IDEOGRAPH-#29592, IRGKangXi=1410.451, RSKangXi=181.20
29593 CJK UNIFIED IDEOGRAPH-#29593, IRGKangXi=1410.451, RSKangXi=181.20
29594 CJK UNIFIED IDEOGRAPH-#29594, IRGKangXi=1410.451, RSKangXi=196.20
29595 CJK UNIFIED IDEOGRAPH-#29595, IRGKangXi=1410.451, RSKangXi=181.8
29596 CJK UNIFIED IDEOGRAPH-#29596, IRGKangXi=1410.451, RSKangXi=181.8
29597 CJK UNIFIED IDEOGRAPH-#29597, IRGKangXi=1410.451, RSKangXi=181.13
29598 CJK UNIFIED IDEOGRAPH-#29598, IRGKangXi=1411.081, RSKangXi=182.2
29599 CJK UNIFIED IDEOGRAPH-#29599, IRGKangXi=1411.081, RSKangXi=182.2
2959A CJK UNIFIED IDEOGRAPH-#2959A, IRGKangXi=1411.090, RSKangXi=185.3
2959B CJK UNIFIED IDEOGRAPH-#2959B, IRGKangXi=1411.100, RSKangXi=182.3
2959C CJK UNIFIED IDEOGRAPH-#2959C, IRGKangXi=1411.110, RSKangXi=182.3
2959D CJK UNIFIED IDEOGRAPH-#2959D, IRGKangXi=1411.130, RSKangXi=182.3
2959E CJK UNIFIED IDEOGRAPH-#2959E, IRGKangXi=1411.141, RSKangXi=182.3
2959F CJK UNIFIED IDEOGRAPH-#2959F, IRGKangXi=1411.141, RSKangXi=182.3
295A0 CJK UNIFIED IDEOGRAPH-#295A0, IRGKangXi=1411.141, RSKangXi=182.3
295A1 CJK UNIFIED IDEOGRAPH-#295A1, IRGKangXi=1411.141, RSKangXi=182.3
295A2 CJK UNIFIED IDEOGRAPH-#295A2, IRGKangXi=1411.160, RSKangXi=182.4
295A3 CJK UNIFIED IDEOGRAPH-#295A3, IRGKangXi=1411.190, RSKangXi=182.4
295A4 CJK UNIFIED IDEOGRAPH-#295A4, IRGKangXi=1411.200, RSKangXi=182.4
295A5 CJK UNIFIED IDEOGRAPH-#295A5, IRGKangXi=1411.210, RSKangXi=182.4
295A6 CJK UNIFIED IDEOGRAPH-#295A6, IRGKangXi=1411.230, RSKangXi=182.4
295A7 CJK UNIFIED IDEOGRAPH-#295A7, IRGKangXi=1411.260, RSKangXi=182.4
295A8 CJK UNIFIED IDEOGRAPH-#295A8, IRGKangXi=1411.270, RSKangXi=182.4
295A9 CJK UNIFIED IDEOGRAPH-#295A9, IRGKangXi=1412.010, RSKangXi=182.4
295AA CJK UNIFIED IDEOGRAPH-#295AA, IRGKangXi=1412.011, RSKangXi=182.4
295AB CJK UNIFIED IDEOGRAPH-#295AB, IRGKangXi=1412.011, RSKangXi=182.4
295AC CJK UNIFIED IDEOGRAPH-#295AC, IRGKangXi=1412.011, RSKangXi=182.4
295AD CJK UNIFIED IDEOGRAPH-#295AD, IRGKangXi=1412.011, RSKangXi=182.4
295AE CJK UNIFIED IDEOGRAPH-#295AE, IRGKangXi=1412.011, RSKangXi=182.4
295AF CJK UNIFIED IDEOGRAPH-#295AF, IRGKangXi=1412.011, RSKangXi=182.4
295B0 CJK UNIFIED IDEOGRAPH-#295B0, IRGKangXi=1412.011, RSKangXi=67.9
295B1 CJK UNIFIED IDEOGRAPH-#295B1, IRGKangXi=1412.011, RSKangXi=182.4
295B2 CJK UNIFIED IDEOGRAPH-#295B2, IRGKangXi=1412.011, RSKangXi=182.4
295B3 CJK UNIFIED IDEOGRAPH-#295B3, IRGKangXi=1412.011, RSKangXi=182.4
295B4 CJK UNIFIED IDEOGRAPH-#295B4, IRGKangXi=1412.030, RSKangXi=182.5
295B5 CJK UNIFIED IDEOGRAPH-#295B5, IRGKangXi=1412.040, RSKangXi=182.5
295B6 CJK UNIFIED IDEOGRAPH-#295B6, IRGKangXi=1412.080, RSKangXi=182.5
295B7 CJK UNIFIED IDEOGRAPH-#295B7, IRGKangXi=1412.100, RSKangXi=182.5
295B8 CJK UNIFIED IDEOGRAPH-#295B8, IRGKangXi=1412.110, RSKangXi=182.5
295B9 CJK UNIFIED IDEOGRAPH-#295B9, IRGKangXi=1412.130, RSKangXi=182.5
295BA CJK UNIFIED IDEOGRAPH-#295BA, IRGKangXi=1412.150, RSKangXi=182.5
295BB CJK UNIFIED IDEOGRAPH-#295BB, IRGKangXi=1412.160, RSKangXi=182.5
295BC CJK UNIFIED IDEOGRAPH-#295BC, IRGKangXi=1412.180, RSKangXi=182.5
295BD CJK UNIFIED IDEOGRAPH-#295BD, IRGKangXi=1412.200, RSKangXi=182.5
295BE CJK UNIFIED IDEOGRAPH-#295BE, IRGKangXi=1412.220, RSKangXi=182.5
295BF CJK UNIFIED IDEOGRAPH-#295BF, IRGKangXi=1412.230, RSKangXi=182.5
295C0 CJK UNIFIED IDEOGRAPH-#295C0, IRGKangXi=1412.231, RSKangXi=182.5
295C1 CJK UNIFIED IDEOGRAPH-#295C1, IRGKangXi=1412.231, RSKangXi=182.5
295C2 CJK UNIFIED IDEOGRAPH-#295C2, IRGKangXi=1412.231, RSKangXi=182.5
295C3 CJK UNIFIED IDEOGRAPH-#295C3, IRGKangXi=1412.231, RSKangXi=182.5
295C4 CJK UNIFIED IDEOGRAPH-#295C4, IRGKangXi=1412.240, RSKangXi=182.6
295C5 CJK UNIFIED IDEOGRAPH-#295C5, IRGKangXi=1412.260, RSKangXi=182.6
295C6 CJK UNIFIED IDEOGRAPH-#295C6, IRGKangXi=1412.280, RSKangXi=182.6
295C7 CJK UNIFIED IDEOGRAPH-#295C7, IRGKangXi=1412.290, RSKangXi=182.6
295C8 CJK UNIFIED IDEOGRAPH-#295C8, IRGKangXi=1412.300, RSKangXi=182.6
295C9 CJK UNIFIED IDEOGRAPH-#295C9, IRGKangXi=1412.310, RSKangXi=182.6
295CA CJK UNIFIED IDEOGRAPH-#295CA, IRGKangXi=1412.330, RSKangXi=182.6
295CB CJK UNIFIED IDEOGRAPH-#295CB, IRGKangXi=1412.340, RSKangXi=182.6
295CC CJK UNIFIED IDEOGRAPH-#295CC, IRGKangXi=1412.351, RSKangXi=182.6
295CD CJK UNIFIED IDEOGRAPH-#295CD, IRGKangXi=1412.351, RSKangXi=182.6
295CE CJK UNIFIED IDEOGRAPH-#295CE, IRGKangXi=1412.351, RSKangXi=182.6
295CF CJK UNIFIED IDEOGRAPH-#295CF, IRGKangXi=1412.351, RSKangXi=182.6
295D0 CJK UNIFIED IDEOGRAPH-#295D0, IRGKangXi=1412.351, RSKangXi=182.6
295D1 CJK UNIFIED IDEOGRAPH-#295D1, IRGKangXi=1412.351, RSKangXi=182.6
295D2 CJK UNIFIED IDEOGRAPH-#295D2, IRGKangXi=1412.351, RSKangXi=182.6
295D3 CJK UNIFIED IDEOGRAPH-#295D3, IRGKangXi=1412.360, RSKangXi=182.7
295D4 CJK UNIFIED IDEOGRAPH-#295D4, IRGKangXi=1412.380, RSKangXi=182.7
295D5 CJK UNIFIED IDEOGRAPH-#295D5, IRGKangXi=1412.410, RSKangXi=182.7
295D6 CJK UNIFIED IDEOGRAPH-#295D6, IRGKangXi=1412.440, RSKangXi=182.7
295D7 CJK UNIFIED IDEOGRAPH-#295D7, IRGKangXi=1412.450, RSKangXi=182.7
295D8 CJK UNIFIED IDEOGRAPH-#295D8, IRGKangXi=1412.460, RSKangXi=182.7
295D9 CJK UNIFIED IDEOGRAPH-#295D9, IRGKangXi=1412.480, RSKangXi=182.7
295DA CJK UNIFIED IDEOGRAPH-#295DA, IRGKangXi=1412.490, RSKangXi=182.7
295DB CJK UNIFIED IDEOGRAPH-#295DB, IRGKangXi=1412.500, RSKangXi=182.7
295DC CJK UNIFIED IDEOGRAPH-#295DC, IRGKangXi=1412.520, RSKangXi=182.7
295DD CJK UNIFIED IDEOGRAPH-#295DD, IRGKangXi=1412.530, RSKangXi=182.7
295DE CJK UNIFIED IDEOGRAPH-#295DE, IRGKangXi=1412.540, RSKangXi=182.7
295DF CJK UNIFIED IDEOGRAPH-#295DF, IRGKangXi=1412.541, RSKangXi=182.7
295E0 CJK UNIFIED IDEOGRAPH-#295E0, IRGKangXi=1412.541, RSKangXi=182.7
295E1 CJK UNIFIED IDEOGRAPH-#295E1, IRGKangXi=1412.541, RSKangXi=182.7
295E2 CJK UNIFIED IDEOGRAPH-#295E2, IRGKangXi=1412.541, RSKangXi=182.7
295E3 CJK UNIFIED IDEOGRAPH-#295E3, IRGKangXi=1412.541, RSKangXi=182.7
295E4 CJK UNIFIED IDEOGRAPH-#295E4, IRGKangXi=1412.541, RSKangXi=182.7
295E5 CJK UNIFIED IDEOGRAPH-#295E5, IRGKangXi=1412.541, RSKangXi=182.7
295E6 CJK UNIFIED IDEOGRAPH-#295E6, IRGKangXi=1412.541, RSKangXi=182.7
295E7 CJK UNIFIED IDEOGRAPH-#295E7, IRGKangXi=1412.541, RSKangXi=182.7
295E8 CJK UNIFIED IDEOGRAPH-#295E8, IRGKangXi=1413.020, RSKangXi=182.8
295E9 CJK UNIFIED IDEOGRAPH-#295E9, IRGKangXi=1413.030, RSKangXi=182.8
295EA CJK UNIFIED IDEOGRAPH-#295EA, IRGKangXi=1413.060, RSKangXi=182.8
295EB CJK UNIFIED IDEOGRAPH-#295EB, IRGKangXi=1413.070, RSKangXi=182.8
295EC CJK UNIFIED IDEOGRAPH-#295EC, IRGKangXi=1413.080, RSKangXi=182.8
295ED CJK UNIFIED IDEOGRAPH-#295ED, IRGKangXi=1413.090, RSKangXi=182.8
295EE CJK UNIFIED IDEOGRAPH-#295EE, IRGKangXi=1413.110, RSKangXi=182.8
295EF CJK UNIFIED IDEOGRAPH-#295EF, IRGKangXi=1413.120, RSKangXi=182.8
295F0 CJK UNIFIED IDEOGRAPH-#295F0, IRGKangXi=1413.130, RSKangXi=182.8
295F1 CJK UNIFIED IDEOGRAPH-#295F1, IRGKangXi=1413.140, RSKangXi=182.8
295F2 CJK UNIFIED IDEOGRAPH-#295F2, IRGKangXi=1413.150, RSKangXi=182.8
295F3 CJK UNIFIED IDEOGRAPH-#295F3, IRGKangXi=1413.160, RSKangXi=182.8
295F4 CJK UNIFIED IDEOGRAPH-#295F4, IRGKangXi=1413.170, RSKangXi=182.8, Def{(Cant.) classifier for odors}
295F5 CJK UNIFIED IDEOGRAPH-#295F5, IRGKangXi=1413.180, RSKangXi=182.8
295F6 CJK UNIFIED IDEOGRAPH-#295F6, IRGKangXi=1413.190, RSKangXi=182.8
295F7 CJK UNIFIED IDEOGRAPH-#295F7, IRGKangXi=1413.230, RSKangXi=182.8
295F8 CJK UNIFIED IDEOGRAPH-#295F8, IRGKangXi=1413.250, RSKangXi=182.8
295F9 CJK UNIFIED IDEOGRAPH-#295F9, IRGKangXi=1413.251, RSKangXi=182.8
295FA CJK UNIFIED IDEOGRAPH-#295FA, IRGKangXi=1413.251, RSKangXi=182.8
295FB CJK UNIFIED IDEOGRAPH-#295FB, IRGKangXi=1413.251, RSKangXi=182.8
295FC CJK UNIFIED IDEOGRAPH-#295FC, IRGKangXi=1413.251, RSKangXi=182.8
295FD CJK UNIFIED IDEOGRAPH-#295FD, IRGKangXi=1413.251, RSKangXi=182.8
295FE CJK UNIFIED IDEOGRAPH-#295FE, IRGKangXi=1413.251, RSKangXi=182.8
295FF CJK UNIFIED IDEOGRAPH-#295FF, IRGKangXi=1413.251, RSKangXi=182.8
29600 CJK UNIFIED IDEOGRAPH-#29600, IRGKangXi=1413.251, RSKangXi=182.8
29601 CJK UNIFIED IDEOGRAPH-#29601, IRGKangXi=1413.251, RSKangXi=182.8
29602 CJK UNIFIED IDEOGRAPH-#29602, IRGKangXi=1413.251, RSKangXi=182.8
29603 CJK UNIFIED IDEOGRAPH-#29603, IRGKangXi=1413.251, RSKangXi=182.8
29604 CJK UNIFIED IDEOGRAPH-#29604, IRGKangXi=1413.251, RSKangXi=182.8
29605 CJK UNIFIED IDEOGRAPH-#29605, IRGKangXi=1413.260, RSKangXi=182.9
29606 CJK UNIFIED IDEOGRAPH-#29606, IRGKangXi=1413.280, RSKangXi=182.9
29607 CJK UNIFIED IDEOGRAPH-#29607, IRGKangXi=1413.290, RSKangXi=182.9
29608 CJK UNIFIED IDEOGRAPH-#29608, IRGKangXi=1413.300, RSKangXi=182.9
29609 CJK UNIFIED IDEOGRAPH-#29609, IRGKangXi=1413.310, RSKangXi=182.9
2960A CJK UNIFIED IDEOGRAPH-#2960A, IRGKangXi=1413.320, RSKangXi=182.9
2960B CJK UNIFIED IDEOGRAPH-#2960B, IRGKangXi=1413.340, RSKangXi=182.9
2960C CJK UNIFIED IDEOGRAPH-#2960C, IRGKangXi=1413.350, RSKangXi=182.9
2960D CJK UNIFIED IDEOGRAPH-#2960D, IRGKangXi=1413.360, RSKangXi=182.9
2960E CJK UNIFIED IDEOGRAPH-#2960E, IRGKangXi=1413.380, RSKangXi=182.10
2960F CJK UNIFIED IDEOGRAPH-#2960F, IRGKangXi=1413.390, RSKangXi=182.9
29610 CJK UNIFIED IDEOGRAPH-#29610, IRGKangXi=1413.400, RSKangXi=182.9
29611 CJK UNIFIED IDEOGRAPH-#29611, IRGKangXi=1413.440, RSKangXi=182.9
29612 CJK UNIFIED IDEOGRAPH-#29612, IRGKangXi=1413.480, RSKangXi=182.9
29613 CJK UNIFIED IDEOGRAPH-#29613, IRGKangXi=1413.490, RSKangXi=182.9
29614 CJK UNIFIED IDEOGRAPH-#29614, IRGKangXi=1413.491, RSKangXi=182.9
29615 CJK UNIFIED IDEOGRAPH-#29615, IRGKangXi=1413.491, RSKangXi=182.9
29616 CJK UNIFIED IDEOGRAPH-#29616, IRGKangXi=1413.491, RSKangXi=182.9
29617 CJK UNIFIED IDEOGRAPH-#29617, IRGKangXi=1413.491, RSKangXi=182.9
29618 CJK UNIFIED IDEOGRAPH-#29618, IRGKangXi=1413.491, RSKangXi=182.9
29619 CJK UNIFIED IDEOGRAPH-#29619, IRGKangXi=1413.491, RSKangXi=182.9
2961A CJK UNIFIED IDEOGRAPH-#2961A, IRGKangXi=1413.491, RSKangXi=182.9
2961B CJK UNIFIED IDEOGRAPH-#2961B, IRGKangXi=1413.491, RSKangXi=182.9
2961C CJK UNIFIED IDEOGRAPH-#2961C, IRGKangXi=1414.010, RSKangXi=182.10
2961D CJK UNIFIED IDEOGRAPH-#2961D, IRGKangXi=1414.040, RSKangXi=182.10
2961E CJK UNIFIED IDEOGRAPH-#2961E, IRGKangXi=1414.050, RSKangXi=182.10
2961F CJK UNIFIED IDEOGRAPH-#2961F, IRGKangXi=1414.060, RSKangXi=182.10
29620 CJK UNIFIED IDEOGRAPH-#29620, IRGKangXi=1414.100, RSKangXi=182.10
29621 CJK UNIFIED IDEOGRAPH-#29621, IRGKangXi=1414.110, RSKangXi=182.10
29622 CJK UNIFIED IDEOGRAPH-#29622, IRGKangXi=1414.111, RSKangXi=182.10
29623 CJK UNIFIED IDEOGRAPH-#29623, IRGKangXi=1414.111, RSKangXi=182.10
29624 CJK UNIFIED IDEOGRAPH-#29624, IRGKangXi=1414.111, RSKangXi=182.10
29625 CJK UNIFIED IDEOGRAPH-#29625, IRGKangXi=1414.111, RSKangXi=182.10
29626 CJK UNIFIED IDEOGRAPH-#29626, IRGKangXi=1414.111, RSKangXi=182.10
29627 CJK UNIFIED IDEOGRAPH-#29627, IRGKangXi=1414.111, RSKangXi=182.10
29628 CJK UNIFIED IDEOGRAPH-#29628, IRGKangXi=1414.111, RSKangXi=182.10
29629 CJK UNIFIED IDEOGRAPH-#29629, IRGKangXi=1414.111, RSKangXi=182.10
2962A CJK UNIFIED IDEOGRAPH-#2962A, IRGKangXi=1414.111, RSKangXi=182.10
2962B CJK UNIFIED IDEOGRAPH-#2962B, IRGKangXi=1414.111, RSKangXi=182.10
2962C CJK UNIFIED IDEOGRAPH-#2962C, IRGKangXi=1414.111, RSKangXi=182.10
2962D CJK UNIFIED IDEOGRAPH-#2962D, IRGKangXi=1414.120, RSKangXi=182.11
2962E CJK UNIFIED IDEOGRAPH-#2962E, IRGKangXi=1414.130, RSKangXi=182.11
2962F CJK UNIFIED IDEOGRAPH-#2962F, IRGKangXi=1414.140, RSKangXi=182.11
29630 CJK UNIFIED IDEOGRAPH-#29630, IRGKangXi=1414.170, RSKangXi=182.11
29631 CJK UNIFIED IDEOGRAPH-#29631, IRGKangXi=1414.180, RSKangXi=182.11
29632 CJK UNIFIED IDEOGRAPH-#29632, IRGKangXi=1414.230, RSKangXi=182.11
29633 CJK UNIFIED IDEOGRAPH-#29633, IRGKangXi=1414.240, RSKangXi=182.11
29634 CJK UNIFIED IDEOGRAPH-#29634, IRGKangXi=1414.241, RSKangXi=182.11
29635 CJK UNIFIED IDEOGRAPH-#29635, IRGKangXi=1414.241, RSKangXi=182.11
29636 CJK UNIFIED IDEOGRAPH-#29636, IRGKangXi=1414.241, RSKangXi=182.11
29637 CJK UNIFIED IDEOGRAPH-#29637, IRGKangXi=1414.241, RSKangXi=182.11
29638 CJK UNIFIED IDEOGRAPH-#29638, IRGKangXi=1414.250, RSKangXi=182.12
29639 CJK UNIFIED IDEOGRAPH-#29639, IRGKangXi=1414.260, RSKangXi=182.12
2963A CJK UNIFIED IDEOGRAPH-#2963A, IRGKangXi=1414.270, RSKangXi=182.12
2963B CJK UNIFIED IDEOGRAPH-#2963B, IRGKangXi=1414.280, RSKangXi=182.12
2963C CJK UNIFIED IDEOGRAPH-#2963C, IRGKangXi=1414.300, RSKangXi=182.12
2963D CJK UNIFIED IDEOGRAPH-#2963D, IRGKangXi=1414.320, RSKangXi=182.12
2963E CJK UNIFIED IDEOGRAPH-#2963E, IRGKangXi=1414.330, RSKangXi=182.12
2963F CJK UNIFIED IDEOGRAPH-#2963F, IRGKangXi=1414.380, RSKangXi=182.12
29640 CJK UNIFIED IDEOGRAPH-#29640, IRGKangXi=1414.381, RSKangXi=182.12
29641 CJK UNIFIED IDEOGRAPH-#29641, IRGKangXi=1414.381, RSKangXi=182.12
29642 CJK UNIFIED IDEOGRAPH-#29642, IRGKangXi=1414.381, RSKangXi=182.12
29643 CJK UNIFIED IDEOGRAPH-#29643, IRGKangXi=1414.381, RSKangXi=182.12
29644 CJK UNIFIED IDEOGRAPH-#29644, IRGKangXi=1414.381, RSKangXi=182.12
29645 CJK UNIFIED IDEOGRAPH-#29645, IRGKangXi=1414.381, RSKangXi=182.12
29646 CJK UNIFIED IDEOGRAPH-#29646, IRGKangXi=1414.381, RSKangXi=182.12
29647 CJK UNIFIED IDEOGRAPH-#29647, IRGKangXi=1414.381, RSKangXi=182.12
29648 CJK UNIFIED IDEOGRAPH-#29648, IRGKangXi=1414.390, RSKangXi=182.13
29649 CJK UNIFIED IDEOGRAPH-#29649, IRGKangXi=1414.401, RSKangXi=182.13
2964A CJK UNIFIED IDEOGRAPH-#2964A, IRGKangXi=1414.401, RSKangXi=182.13
2964B CJK UNIFIED IDEOGRAPH-#2964B, IRGKangXi=1414.401, RSKangXi=182.13
2964C CJK UNIFIED IDEOGRAPH-#2964C, IRGKangXi=1414.401, RSKangXi=182.13
2964D CJK UNIFIED IDEOGRAPH-#2964D, IRGKangXi=1414.401, RSKangXi=182.13
2964E CJK UNIFIED IDEOGRAPH-#2964E, IRGKangXi=1414.420, RSKangXi=182.14
2964F CJK UNIFIED IDEOGRAPH-#2964F, IRGKangXi=1414.421, RSKangXi=182.14
29650 CJK UNIFIED IDEOGRAPH-#29650, IRGKangXi=1414.421, RSKangXi=182.14
29651 CJK UNIFIED IDEOGRAPH-#29651, IRGKangXi=1414.430, RSKangXi=182.15
29652 CJK UNIFIED IDEOGRAPH-#29652, IRGKangXi=1414.440, RSKangXi=182.15
29653 CJK UNIFIED IDEOGRAPH-#29653, IRGKangXi=1415.020, RSKangXi=182.15
29654 CJK UNIFIED IDEOGRAPH-#29654, IRGKangXi=1415.021, RSKangXi=182.15
29655 CJK UNIFIED IDEOGRAPH-#29655, IRGKangXi=1415.021, RSKangXi=182.15
29656 CJK UNIFIED IDEOGRAPH-#29656, IRGKangXi=1415.030, RSKangXi=182.16
29657 CJK UNIFIED IDEOGRAPH-#29657, IRGKangXi=1415.040, RSKangXi=182.16
29658 CJK UNIFIED IDEOGRAPH-#29658, IRGKangXi=1415.041, RSKangXi=182.16
29659 CJK UNIFIED IDEOGRAPH-#29659, IRGKangXi=1415.041, RSKangXi=182.16
2965A CJK UNIFIED IDEOGRAPH-#2965A, IRGKangXi=1415.050, RSKangXi=182.16
2965B CJK UNIFIED IDEOGRAPH-#2965B, IRGKangXi=1415.060, RSKangXi=182.17
2965C CJK UNIFIED IDEOGRAPH-#2965C, IRGKangXi=1415.070, RSKangXi=182.17
2965D CJK UNIFIED IDEOGRAPH-#2965D, IRGKangXi=1415.090, RSKangXi=182.18
2965E CJK UNIFIED IDEOGRAPH-#2965E, IRGKangXi=1415.110, RSKangXi=182.18
2965F CJK UNIFIED IDEOGRAPH-#2965F, IRGKangXi=1415.111, RSKangXi=182.19
29660 CJK UNIFIED IDEOGRAPH-#29660, IRGKangXi=1415.111, RSKangXi=182.26
29661 CJK UNIFIED IDEOGRAPH-#29661, IRGKangXi=1415.120, RSKangXi=182.27
29662 CJK UNIFIED IDEOGRAPH-#29662, IRGKangXi=1415.121, RSKangXi=182.28
29663 CJK UNIFIED IDEOGRAPH-#29663, IRGKangXi=1415.121, RSKangXi=182.37
29664 CJK UNIFIED IDEOGRAPH-#29664, IRGKangXi=1415.130, RSKangXi=182.39
29665 CJK UNIFIED IDEOGRAPH-#29665, IRGKangXi=1415.131, RSKangXi=182.5
29666 CJK UNIFIED IDEOGRAPH-#29666, IRGKangXi=1415.131, RSKangXi=182.5
29667 CJK UNIFIED IDEOGRAPH-#29667, IRGKangXi=1415.131, RSKangXi=182.7
29668 CJK UNIFIED IDEOGRAPH-#29668, IRGKangXi=1415.131, RSKangXi=182.8
29669 CJK UNIFIED IDEOGRAPH-#29669, IRGKangXi=1415.131, RSKangXi=182.8
2966A CJK UNIFIED IDEOGRAPH-#2966A, IRGKangXi=1415.131, RSKangXi=182.8
2966B CJK UNIFIED IDEOGRAPH-#2966B, IRGKangXi=1415.131, RSKangXi=182.9
2966C CJK UNIFIED IDEOGRAPH-#2966C, IRGKangXi=1415.131, RSKangXi=182.9
2966D CJK UNIFIED IDEOGRAPH-#2966D, IRGKangXi=1415.131, RSKangXi=182.10
2966E CJK UNIFIED IDEOGRAPH-#2966E, IRGKangXi=1415.131, RSKangXi=182.10
2966F CJK UNIFIED IDEOGRAPH-#2966F, IRGKangXi=1415.131, RSKangXi=182.12
29670 CJK UNIFIED IDEOGRAPH-#29670, IRGKangXi=1415.131, RSKangXi=182.13
29671 CJK UNIFIED IDEOGRAPH-#29671, IRGKangXi=1415.170, RSKangXi=183.0
29672 CJK UNIFIED IDEOGRAPH-#29672, IRGKangXi=1415.180, RSKangXi=183.4
29673 CJK UNIFIED IDEOGRAPH-#29673, IRGKangXi=1415.181, RSKangXi=183.5
29674 CJK UNIFIED IDEOGRAPH-#29674, IRGKangXi=1415.190, RSKangXi=183.6
29675 CJK UNIFIED IDEOGRAPH-#29675, IRGKangXi=1415.211, RSKangXi=183.9
29676 CJK UNIFIED IDEOGRAPH-#29676, IRGKangXi=1415.220, RSKangXi=183.10
29677 CJK UNIFIED IDEOGRAPH-#29677, IRGKangXi=1415.230, RSKangXi=183.10
29678 CJK UNIFIED IDEOGRAPH-#29678, IRGKangXi=1415.231, RSKangXi=183.10
29679 CJK UNIFIED IDEOGRAPH-#29679, IRGKangXi=1415.231, RSKangXi=183.11
2967A CJK UNIFIED IDEOGRAPH-#2967A, IRGKangXi=1415.240, RSKangXi=183.12
2967B CJK UNIFIED IDEOGRAPH-#2967B, IRGKangXi=1415.251, RSKangXi=183.12
2967C CJK UNIFIED IDEOGRAPH-#2967C, IRGKangXi=1415.260, RSKangXi=183.13
2967D CJK UNIFIED IDEOGRAPH-#2967D, IRGKangXi=1415.270, RSKangXi=183.13
2967E CJK UNIFIED IDEOGRAPH-#2967E, IRGKangXi=1415.281, RSKangXi=183.22
2967F CJK UNIFIED IDEOGRAPH-#2967F, IRGKangXi=1415.291, RSKangXi=184.0
29680 CJK UNIFIED IDEOGRAPH-#29680, IRGKangXi=1416.010, RSKangXi=184.0
29681 CJK UNIFIED IDEOGRAPH-#29681, IRGKangXi=1416.020, RSKangXi=184.0
29682 CJK UNIFIED IDEOGRAPH-#29682, IRGKangXi=1416.030, RSKangXi=184.1
29683 CJK UNIFIED IDEOGRAPH-#29683, IRGKangXi=1416.040, RSKangXi=184.0
29684 CJK UNIFIED IDEOGRAPH-#29684, IRGKangXi=1416.060, RSKangXi=184.2
29685 CJK UNIFIED IDEOGRAPH-#29685, IRGKangXi=1416.110, RSKangXi=184.2
29686 CJK UNIFIED IDEOGRAPH-#29686, IRGKangXi=1416.111, RSKangXi=184.2
29687 CJK UNIFIED IDEOGRAPH-#29687, IRGKangXi=1416.130, RSKangXi=184.3
29688 CJK UNIFIED IDEOGRAPH-#29688, IRGKangXi=1416.140, RSKangXi=184.3
29689 CJK UNIFIED IDEOGRAPH-#29689, IRGKangXi=1416.170, RSKangXi=184.3
2968A CJK UNIFIED IDEOGRAPH-#2968A, IRGKangXi=1416.210, RSKangXi=184.3
2968B CJK UNIFIED IDEOGRAPH-#2968B, IRGKangXi=1417.010, RSKangXi=184.3
2968C CJK UNIFIED IDEOGRAPH-#2968C, IRGKangXi=1417.011, RSKangXi=184.3
2968D CJK UNIFIED IDEOGRAPH-#2968D, IRGKangXi=1417.011, RSKangXi=184.3
2968E CJK UNIFIED IDEOGRAPH-#2968E, IRGKangXi=1417.011, RSKangXi=184.3
2968F CJK UNIFIED IDEOGRAPH-#2968F, IRGKangXi=1417.011, RSKangXi=184.3
29690 CJK UNIFIED IDEOGRAPH-#29690, IRGKangXi=1417.011, RSKangXi=184.3
29691 CJK UNIFIED IDEOGRAPH-#29691, IRGKangXi=1417.011, RSKangXi=184.3
29692 CJK UNIFIED IDEOGRAPH-#29692, IRGKangXi=1417.011, RSKangXi=184.3
29693 CJK UNIFIED IDEOGRAPH-#29693, IRGKangXi=1417.011, RSKangXi=184.3
29694 CJK UNIFIED IDEOGRAPH-#29694, IRGKangXi=1417.011, RSKangXi=184.3
29695 CJK UNIFIED IDEOGRAPH-#29695, IRGKangXi=1417.030, RSKangXi=184.4
29696 CJK UNIFIED IDEOGRAPH-#29696, IRGKangXi=1417.040, RSKangXi=184.4
29697 CJK UNIFIED IDEOGRAPH-#29697, IRGKangXi=1417.090, RSKangXi=184.4
29698 CJK UNIFIED IDEOGRAPH-#29698, IRGKangXi=1417.130, RSKangXi=184.4
29699 CJK UNIFIED IDEOGRAPH-#29699, IRGKangXi=1417.160, RSKangXi=184.4
2969A CJK UNIFIED IDEOGRAPH-#2969A, IRGKangXi=1417.170, RSKangXi=184.4
2969B CJK UNIFIED IDEOGRAPH-#2969B, IRGKangXi=1417.180, RSKangXi=184.4
2969C CJK UNIFIED IDEOGRAPH-#2969C, IRGKangXi=1417.300, RSKangXi=184.4
2969D CJK UNIFIED IDEOGRAPH-#2969D, IRGKangXi=1417.310, RSKangXi=184.4
2969E CJK UNIFIED IDEOGRAPH-#2969E, IRGKangXi=1417.320, RSKangXi=184.4
2969F CJK UNIFIED IDEOGRAPH-#2969F, IRGKangXi=1417.331, RSKangXi=184.4
296A0 CJK UNIFIED IDEOGRAPH-#296A0, IRGKangXi=1417.331, RSKangXi=184.4
296A1 CJK UNIFIED IDEOGRAPH-#296A1, IRGKangXi=1417.331, RSKangXi=184.4
296A2 CJK UNIFIED IDEOGRAPH-#296A2, IRGKangXi=1417.331, RSKangXi=184.4
296A3 CJK UNIFIED IDEOGRAPH-#296A3, IRGKangXi=1417.331, RSKangXi=184.4
296A4 CJK UNIFIED IDEOGRAPH-#296A4, IRGKangXi=1417.331, RSKangXi=184.4
296A5 CJK UNIFIED IDEOGRAPH-#296A5, IRGKangXi=1417.331, RSKangXi=184.4
296A6 CJK UNIFIED IDEOGRAPH-#296A6, IRGKangXi=1417.331, RSKangXi=184.4
296A7 CJK UNIFIED IDEOGRAPH-#296A7, IRGKangXi=1417.331, RSKangXi=184.4
296A8 CJK UNIFIED IDEOGRAPH-#296A8, IRGKangXi=1418.010, RSKangXi=184.5
296A9 CJK UNIFIED IDEOGRAPH-#296A9, IRGKangXi=1418.020, RSKangXi=184.5
296AA CJK UNIFIED IDEOGRAPH-#296AA, IRGKangXi=1418.040, RSKangXi=184.5
296AB CJK UNIFIED IDEOGRAPH-#296AB, IRGKangXi=1418.100, RSKangXi=184.5
296AC CJK UNIFIED IDEOGRAPH-#296AC, IRGKangXi=1418.110, RSKangXi=184.5
296AD CJK UNIFIED IDEOGRAPH-#296AD, IRGKangXi=1418.130, RSKangXi=184.5
296AE CJK UNIFIED IDEOGRAPH-#296AE, IRGKangXi=1418.170, RSKangXi=184.5
296AF CJK UNIFIED IDEOGRAPH-#296AF, IRGKangXi=1418.180, RSKangXi=184.5
296B0 CJK UNIFIED IDEOGRAPH-#296B0, IRGKangXi=1418.190, RSKangXi=184.5
296B1 CJK UNIFIED IDEOGRAPH-#296B1, IRGKangXi=1418.200, RSKangXi=184.5
296B2 CJK UNIFIED IDEOGRAPH-#296B2, IRGKangXi=1418.240, RSKangXi=184.5
296B3 CJK UNIFIED IDEOGRAPH-#296B3, IRGKangXi=1418.250, RSKangXi=184.5
296B4 CJK UNIFIED IDEOGRAPH-#296B4, IRGKangXi=1418.260, RSKangXi=184.5
296B5 CJK UNIFIED IDEOGRAPH-#296B5, IRGKangXi=1418.280, RSKangXi=184.5
296B6 CJK UNIFIED IDEOGRAPH-#296B6, IRGKangXi=1418.300, RSKangXi=184.5
296B7 CJK UNIFIED IDEOGRAPH-#296B7, IRGKangXi=1418.320, RSKangXi=184.5
296B8 CJK UNIFIED IDEOGRAPH-#296B8, IRGKangXi=1418.350, RSKangXi=184.5
296B9 CJK UNIFIED IDEOGRAPH-#296B9, IRGKangXi=1418.430, RSKangXi=184.5
296BA CJK UNIFIED IDEOGRAPH-#296BA, IRGKangXi=1419.010, RSKangXi=184.5
296BB CJK UNIFIED IDEOGRAPH-#296BB, IRGKangXi=1419.020, RSKangXi=184.5
296BC CJK UNIFIED IDEOGRAPH-#296BC, IRGKangXi=1419.021, RSKangXi=184.5
296BD CJK UNIFIED IDEOGRAPH-#296BD, IRGKangXi=1419.021, RSKangXi=184.5
296BE CJK UNIFIED IDEOGRAPH-#296BE, IRGKangXi=1419.021, RSKangXi=184.5
296BF CJK UNIFIED IDEOGRAPH-#296BF, IRGKangXi=1419.021, RSKangXi=184.5
296C0 CJK UNIFIED IDEOGRAPH-#296C0, IRGKangXi=1419.021, RSKangXi=184.5
296C1 CJK UNIFIED IDEOGRAPH-#296C1, IRGKangXi=1419.021, RSKangXi=184.5
296C2 CJK UNIFIED IDEOGRAPH-#296C2, IRGKangXi=1419.021, RSKangXi=184.5
296C3 CJK UNIFIED IDEOGRAPH-#296C3, IRGKangXi=1419.021, RSKangXi=184.5
296C4 CJK UNIFIED IDEOGRAPH-#296C4, IRGKangXi=1419.021, RSKangXi=184.5
296C5 CJK UNIFIED IDEOGRAPH-#296C5, IRGKangXi=1419.021, RSKangXi=184.5
296C6 CJK UNIFIED IDEOGRAPH-#296C6, IRGKangXi=1419.021, RSKangXi=184.5
296C7 CJK UNIFIED IDEOGRAPH-#296C7, IRGKangXi=1419.021, RSKangXi=184.5
296C8 CJK UNIFIED IDEOGRAPH-#296C8, IRGKangXi=1419.021, RSKangXi=184.5
296C9 CJK UNIFIED IDEOGRAPH-#296C9, IRGKangXi=1419.040, RSKangXi=184.6
296CA CJK UNIFIED IDEOGRAPH-#296CA, IRGKangXi=1419.050, RSKangXi=184.6
296CB CJK UNIFIED IDEOGRAPH-#296CB, IRGKangXi=1419.060, RSKangXi=184.6
296CC CJK UNIFIED IDEOGRAPH-#296CC, IRGKangXi=1419.100, RSKangXi=184.6
296CD CJK UNIFIED IDEOGRAPH-#296CD, IRGKangXi=1419.190, RSKangXi=184.6
296CE CJK UNIFIED IDEOGRAPH-#296CE, IRGKangXi=1419.240, RSKangXi=184.6
296CF CJK UNIFIED IDEOGRAPH-#296CF, IRGKangXi=1419.310, RSKangXi=184.6
296D0 CJK UNIFIED IDEOGRAPH-#296D0, IRGKangXi=1419.320, RSKangXi=184.6
296D1 CJK UNIFIED IDEOGRAPH-#296D1, IRGKangXi=1419.330, RSKangXi=184.6
296D2 CJK UNIFIED IDEOGRAPH-#296D2, IRGKangXi=1419.340, RSKangXi=184.6
296D3 CJK UNIFIED IDEOGRAPH-#296D3, IRGKangXi=1419.350, RSKangXi=184.6
296D4 CJK UNIFIED IDEOGRAPH-#296D4, IRGKangXi=1419.351, RSKangXi=184.6
296D5 CJK UNIFIED IDEOGRAPH-#296D5, IRGKangXi=1419.351, RSKangXi=184.6
296D6 CJK UNIFIED IDEOGRAPH-#296D6, IRGKangXi=1419.351, RSKangXi=184.6
296D7 CJK UNIFIED IDEOGRAPH-#296D7, IRGKangXi=1419.351, RSKangXi=184.6
296D8 CJK UNIFIED IDEOGRAPH-#296D8, IRGKangXi=1419.351, RSKangXi=184.6
296D9 CJK UNIFIED IDEOGRAPH-#296D9, IRGKangXi=1419.351, RSKangXi=184.6
296DA CJK UNIFIED IDEOGRAPH-#296DA, IRGKangXi=1419.351, RSKangXi=184.6
296DB CJK UNIFIED IDEOGRAPH-#296DB, IRGKangXi=1419.351, RSKangXi=184.6
296DC CJK UNIFIED IDEOGRAPH-#296DC, IRGKangXi=1419.351, RSKangXi=184.6
296DD CJK UNIFIED IDEOGRAPH-#296DD, IRGKangXi=1419.370, RSKangXi=184.7
296DE CJK UNIFIED IDEOGRAPH-#296DE, IRGKangXi=1419.380, RSKangXi=184.7
296DF CJK UNIFIED IDEOGRAPH-#296DF, IRGKangXi=1420.050, RSKangXi=184.7
296E0 CJK UNIFIED IDEOGRAPH-#296E0, IRGKangXi=1420.070, RSKangXi=184.7
296E1 CJK UNIFIED IDEOGRAPH-#296E1, IRGKangXi=1420.100, RSKangXi=184.7
296E2 CJK UNIFIED IDEOGRAPH-#296E2, IRGKangXi=1420.120, RSKangXi=184.7
296E3 CJK UNIFIED IDEOGRAPH-#296E3, IRGKangXi=1420.150, RSKangXi=184.7
296E4 CJK UNIFIED IDEOGRAPH-#296E4, IRGKangXi=1420.160, RSKangXi=184.7
296E5 CJK UNIFIED IDEOGRAPH-#296E5, IRGKangXi=1420.180, RSKangXi=184.7
296E6 CJK UNIFIED IDEOGRAPH-#296E6, IRGKangXi=1420.210, RSKangXi=184.7
296E7 CJK UNIFIED IDEOGRAPH-#296E7, IRGKangXi=1420.220, RSKangXi=184.7
296E8 CJK UNIFIED IDEOGRAPH-#296E8, IRGKangXi=1420.230, RSKangXi=184.7
296E9 CJK UNIFIED IDEOGRAPH-#296E9, IRGKangXi=1420.240, RSKangXi=184.7
296EA CJK UNIFIED IDEOGRAPH-#296EA, IRGKangXi=1421.010, RSKangXi=184.7
296EB CJK UNIFIED IDEOGRAPH-#296EB, IRGKangXi=1421.020, RSKangXi=184.7
296EC CJK UNIFIED IDEOGRAPH-#296EC, IRGKangXi=1421.030, RSKangXi=184.7
296ED CJK UNIFIED IDEOGRAPH-#296ED, IRGKangXi=1421.040, RSKangXi=184.7
296EE CJK UNIFIED IDEOGRAPH-#296EE, IRGKangXi=1421.050, RSKangXi=184.7
296EF CJK UNIFIED IDEOGRAPH-#296EF, IRGKangXi=1421.060, RSKangXi=184.7
296F0 CJK UNIFIED IDEOGRAPH-#296F0, IRGKangXi=1421.061, RSKangXi=184.7
296F1 CJK UNIFIED IDEOGRAPH-#296F1, IRGKangXi=1421.061, RSKangXi=184.7
296F2 CJK UNIFIED IDEOGRAPH-#296F2, IRGKangXi=1421.061, RSKangXi=184.7
296F3 CJK UNIFIED IDEOGRAPH-#296F3, IRGKangXi=1421.061, RSKangXi=184.7
296F4 CJK UNIFIED IDEOGRAPH-#296F4, IRGKangXi=1421.061, RSKangXi=184.7
296F5 CJK UNIFIED IDEOGRAPH-#296F5, IRGKangXi=1421.061, RSKangXi=184.7
296F6 CJK UNIFIED IDEOGRAPH-#296F6, IRGKangXi=1421.061, RSKangXi=184.7
296F7 CJK UNIFIED IDEOGRAPH-#296F7, IRGKangXi=1421.061, RSKangXi=184.7
296F8 CJK UNIFIED IDEOGRAPH-#296F8, IRGKangXi=1421.061, RSKangXi=184.7
296F9 CJK UNIFIED IDEOGRAPH-#296F9, IRGKangXi=1421.061, RSKangXi=184.7
296FA CJK UNIFIED IDEOGRAPH-#296FA, IRGKangXi=1421.070, RSKangXi=184.8
296FB CJK UNIFIED IDEOGRAPH-#296FB, IRGKangXi=1421.080, RSKangXi=184.8
296FC CJK UNIFIED IDEOGRAPH-#296FC, IRGKangXi=1421.100, RSKangXi=184.8
296FD CJK UNIFIED IDEOGRAPH-#296FD, IRGKangXi=1421.110, RSKangXi=184.8
296FE CJK UNIFIED IDEOGRAPH-#296FE, IRGKangXi=1421.130, RSKangXi=184.8
296FF CJK UNIFIED IDEOGRAPH-#296FF, IRGKangXi=1421.140, RSKangXi=184.8
29700 CJK UNIFIED IDEOGRAPH-#29700, IRGKangXi=1421.180, RSKangXi=184.8
29701 CJK UNIFIED IDEOGRAPH-#29701, IRGKangXi=1421.190, RSKangXi=184.8
29702 CJK UNIFIED IDEOGRAPH-#29702, IRGKangXi=1421.210, RSKangXi=184.8
29703 CJK UNIFIED IDEOGRAPH-#29703, IRGKangXi=1421.230, RSKangXi=184.8
29704 CJK UNIFIED IDEOGRAPH-#29704, IRGKangXi=1421.260, RSKangXi=184.8
29705 CJK UNIFIED IDEOGRAPH-#29705, IRGKangXi=1421.270, RSKangXi=184.8
29706 CJK UNIFIED IDEOGRAPH-#29706, IRGKangXi=1421.280, RSKangXi=184.8
29707 CJK UNIFIED IDEOGRAPH-#29707, IRGKangXi=1421.290, RSKangXi=184.8, Def{thin wafers in which meat and other foods are rolled and eaten}
29708 CJK UNIFIED IDEOGRAPH-#29708, IRGKangXi=1421.310, RSKangXi=184.8
29709 CJK UNIFIED IDEOGRAPH-#29709, IRGKangXi=1421.330, RSKangXi=184.8
2970A CJK UNIFIED IDEOGRAPH-#2970A, IRGKangXi=1422.010, RSKangXi=184.8
2970B CJK UNIFIED IDEOGRAPH-#2970B, IRGKangXi=1422.020, RSKangXi=184.8
2970C CJK UNIFIED IDEOGRAPH-#2970C, IRGKangXi=1422.060, RSKangXi=184.8
2970D CJK UNIFIED IDEOGRAPH-#2970D, IRGKangXi=1422.090, RSKangXi=184.8
2970E CJK UNIFIED IDEOGRAPH-#2970E, IRGKangXi=1422.120, RSKangXi=184.8
2970F CJK UNIFIED IDEOGRAPH-#2970F, IRGKangXi=1422.150, RSKangXi=184.8
29710 CJK UNIFIED IDEOGRAPH-#29710, IRGKangXi=1422.170, RSKangXi=184.8
29711 CJK UNIFIED IDEOGRAPH-#29711, IRGKangXi=1422.180, RSKangXi=184.8
29712 CJK UNIFIED IDEOGRAPH-#29712, IRGKangXi=1422.190, RSKangXi=184.8
29713 CJK UNIFIED IDEOGRAPH-#29713, IRGKangXi=1422.200, RSKangXi=184.8
29714 CJK UNIFIED IDEOGRAPH-#29714, IRGKangXi=1422.210, RSKangXi=184.8
29715 CJK UNIFIED IDEOGRAPH-#29715, IRGKangXi=1422.220, RSKangXi=184.8
29716 CJK UNIFIED IDEOGRAPH-#29716, IRGKangXi=1422.230, RSKangXi=184.8
29717 CJK UNIFIED IDEOGRAPH-#29717, IRGKangXi=1422.240, RSKangXi=184.8
29718 CJK UNIFIED IDEOGRAPH-#29718, IRGKangXi=1422.241, RSKangXi=184.8
29719 CJK UNIFIED IDEOGRAPH-#29719, IRGKangXi=1422.241, RSKangXi=184.8
2971A CJK UNIFIED IDEOGRAPH-#2971A, IRGKangXi=1422.241, RSKangXi=184.8
2971B CJK UNIFIED IDEOGRAPH-#2971B, IRGKangXi=1422.241, RSKangXi=184.8
2971C CJK UNIFIED IDEOGRAPH-#2971C, IRGKangXi=1422.241, RSKangXi=184.8
2971D CJK UNIFIED IDEOGRAPH-#2971D, IRGKangXi=1422.241, RSKangXi=184.8
2971E CJK UNIFIED IDEOGRAPH-#2971E, IRGKangXi=1422.241, RSKangXi=184.8
2971F CJK UNIFIED IDEOGRAPH-#2971F, IRGKangXi=1422.241, RSKangXi=184.8
29720 CJK UNIFIED IDEOGRAPH-#29720, IRGKangXi=1422.241, RSKangXi=184.8, Def{(Cant.) soft rice for a small child}
29721 CJK UNIFIED IDEOGRAPH-#29721, IRGKangXi=1422.241, RSKangXi=184.8
29722 CJK UNIFIED IDEOGRAPH-#29722, IRGKangXi=1422.241, RSKangXi=184.8
29723 CJK UNIFIED IDEOGRAPH-#29723, IRGKangXi=1422.241, RSKangXi=184.9
29724 CJK UNIFIED IDEOGRAPH-#29724, IRGKangXi=1422.241, RSKangXi=184.8
29725 CJK UNIFIED IDEOGRAPH-#29725, IRGKangXi=1422.241, RSKangXi=184.8
29726 CJK UNIFIED IDEOGRAPH-#29726, IRGKangXi=1422.241, RSKangXi=184.8
29727 CJK UNIFIED IDEOGRAPH-#29727, IRGKangXi=1422.241, RSKangXi=184.8
29728 CJK UNIFIED IDEOGRAPH-#29728, IRGKangXi=1422.241, RSKangXi=184.8
29729 CJK UNIFIED IDEOGRAPH-#29729, IRGKangXi=1422.241, RSKangXi=184.8
2972A CJK UNIFIED IDEOGRAPH-#2972A, IRGKangXi=1422.241, RSKangXi=184.8
2972B CJK UNIFIED IDEOGRAPH-#2972B, IRGKangXi=1422.241, RSKangXi=184.8
2972C CJK UNIFIED IDEOGRAPH-#2972C, IRGKangXi=1422.241, RSKangXi=184.8
2972D CJK UNIFIED IDEOGRAPH-#2972D, IRGKangXi=1422.280, RSKangXi=184.9
2972E CJK UNIFIED IDEOGRAPH-#2972E, IRGKangXi=1422.300, RSKangXi=184.9
2972F CJK UNIFIED IDEOGRAPH-#2972F, IRGKangXi=1422.310, RSKangXi=184.9
29730 CJK UNIFIED IDEOGRAPH-#29730, IRGKangXi=1422.330, RSKangXi=184.9
29731 CJK UNIFIED IDEOGRAPH-#29731, IRGKangXi=1422.350, RSKangXi=184.9
29732 CJK UNIFIED IDEOGRAPH-#29732, IRGKangXi=1422.360, RSKangXi=184.9
29733 CJK UNIFIED IDEOGRAPH-#29733, IRGKangXi=1422.370, RSKangXi=184.9
29734 CJK UNIFIED IDEOGRAPH-#29734, IRGKangXi=1422.380, RSKangXi=184.9
29735 CJK UNIFIED IDEOGRAPH-#29735, IRGKangXi=1423.010, RSKangXi=184.9
29736 CJK UNIFIED IDEOGRAPH-#29736, IRGKangXi=1423.030, RSKangXi=184.9
29737 CJK UNIFIED IDEOGRAPH-#29737, IRGKangXi=1423.040, RSKangXi=184.9
29738 CJK UNIFIED IDEOGRAPH-#29738, IRGKangXi=1423.060, RSKangXi=184.9
29739 CJK UNIFIED IDEOGRAPH-#29739, IRGKangXi=1423.100, RSKangXi=184.9
2973A CJK UNIFIED IDEOGRAPH-#2973A, IRGKangXi=1423.110, RSKangXi=184.9
2973B CJK UNIFIED IDEOGRAPH-#2973B, IRGKangXi=1423.120, RSKangXi=184.9
2973C CJK UNIFIED IDEOGRAPH-#2973C, IRGKangXi=1423.170, RSKangXi=184.9
2973D CJK UNIFIED IDEOGRAPH-#2973D, IRGKangXi=1423.180, RSKangXi=184.9
2973E CJK UNIFIED IDEOGRAPH-#2973E, IRGKangXi=1423.190, RSKangXi=184.9
2973F CJK UNIFIED IDEOGRAPH-#2973F, IRGKangXi=1423.200, RSKangXi=184.9
29740 CJK UNIFIED IDEOGRAPH-#29740, IRGKangXi=1423.210, RSKangXi=184.9
29741 CJK UNIFIED IDEOGRAPH-#29741, IRGKangXi=1423.220, RSKangXi=184.9
29742 CJK UNIFIED IDEOGRAPH-#29742, IRGKangXi=1423.230, RSKangXi=184.9
29743 CJK UNIFIED IDEOGRAPH-#29743, IRGKangXi=1423.241, RSKangXi=184.9
29744 CJK UNIFIED IDEOGRAPH-#29744, IRGKangXi=1423.241, RSKangXi=184.9
29745 CJK UNIFIED IDEOGRAPH-#29745, IRGKangXi=1423.241, RSKangXi=184.9
29746 CJK UNIFIED IDEOGRAPH-#29746, IRGKangXi=1423.241, RSKangXi=184.9
29747 CJK UNIFIED IDEOGRAPH-#29747, IRGKangXi=1423.241, RSKangXi=184.9
29748 CJK UNIFIED IDEOGRAPH-#29748, IRGKangXi=1423.241, RSKangXi=184.9
29749 CJK UNIFIED IDEOGRAPH-#29749, IRGKangXi=1423.241, RSKangXi=184.9
2974A CJK UNIFIED IDEOGRAPH-#2974A, IRGKangXi=1423.241, RSKangXi=184.9
2974B CJK UNIFIED IDEOGRAPH-#2974B, IRGKangXi=1423.241, RSKangXi=184.9
2974C CJK UNIFIED IDEOGRAPH-#2974C, IRGKangXi=1423.241, RSKangXi=184.9
2974D CJK UNIFIED IDEOGRAPH-#2974D, IRGKangXi=1423.241, RSKangXi=184.9
2974E CJK UNIFIED IDEOGRAPH-#2974E, IRGKangXi=1423.241, RSKangXi=184.9
2974F CJK UNIFIED IDEOGRAPH-#2974F, IRGKangXi=1423.241, RSKangXi=184.9
29750 CJK UNIFIED IDEOGRAPH-#29750, IRGKangXi=1423.241, RSKangXi=184.9
29751 CJK UNIFIED IDEOGRAPH-#29751, IRGKangXi=1423.241, RSKangXi=184.9
29752 CJK UNIFIED IDEOGRAPH-#29752, IRGKangXi=1423.241, RSKangXi=184.9
29753 CJK UNIFIED IDEOGRAPH-#29753, IRGKangXi=1423.241, RSKangXi=184.9
29754 CJK UNIFIED IDEOGRAPH-#29754, IRGKangXi=1423.241, RSKangXi=184.9
29755 CJK UNIFIED IDEOGRAPH-#29755, IRGKangXi=1423.241, RSKangXi=184.9
29756 CJK UNIFIED IDEOGRAPH-#29756, IRGKangXi=1423.241, RSKangXi=184.9
29757 CJK UNIFIED IDEOGRAPH-#29757, IRGKangXi=1423.241, RSKangXi=184.9
29758 CJK UNIFIED IDEOGRAPH-#29758, IRGKangXi=1423.241, RSKangXi=184.9
29759 CJK UNIFIED IDEOGRAPH-#29759, IRGKangXi=1423.260, RSKangXi=184.10
2975A CJK UNIFIED IDEOGRAPH-#2975A, IRGKangXi=1423.270, RSKangXi=184.10
2975B CJK UNIFIED IDEOGRAPH-#2975B, IRGKangXi=1423.280, RSKangXi=184.10
2975C CJK UNIFIED IDEOGRAPH-#2975C, IRGKangXi=1423.320, RSKangXi=184.10
2975D CJK UNIFIED IDEOGRAPH-#2975D, IRGKangXi=1423.340, RSKangXi=184.10
2975E CJK UNIFIED IDEOGRAPH-#2975E, IRGKangXi=1423.350, RSKangXi=184.10
2975F CJK UNIFIED IDEOGRAPH-#2975F, IRGKangXi=1423.360, RSKangXi=184.10
29760 CJK UNIFIED IDEOGRAPH-#29760, IRGKangXi=1423.370, RSKangXi=184.10, Def{spoiled provisions}
29761 CJK UNIFIED IDEOGRAPH-#29761, IRGKangXi=1423.390, RSKangXi=184.10
29762 CJK UNIFIED IDEOGRAPH-#29762, IRGKangXi=1423.400, RSKangXi=184.10
29763 CJK UNIFIED IDEOGRAPH-#29763, IRGKangXi=1424.010, RSKangXi=184.10
29764 CJK UNIFIED IDEOGRAPH-#29764, IRGKangXi=1424.020, RSKangXi=184.10
29765 CJK UNIFIED IDEOGRAPH-#29765, IRGKangXi=1424.030, RSKangXi=184.10
29766 CJK UNIFIED IDEOGRAPH-#29766, IRGKangXi=1424.100, RSKangXi=184.10
29767 CJK UNIFIED IDEOGRAPH-#29767, IRGKangXi=1424.110, RSKangXi=184.10
29768 CJK UNIFIED IDEOGRAPH-#29768, IRGKangXi=1424.130, RSKangXi=184.10
29769 CJK UNIFIED IDEOGRAPH-#29769, IRGKangXi=1424.140, RSKangXi=184.10
2976A CJK UNIFIED IDEOGRAPH-#2976A, IRGKangXi=1424.150, RSKangXi=184.10
2976B CJK UNIFIED IDEOGRAPH-#2976B, IRGKangXi=1424.160, RSKangXi=184.10
2976C CJK UNIFIED IDEOGRAPH-#2976C, IRGKangXi=1424.170, RSKangXi=184.10
2976D CJK UNIFIED IDEOGRAPH-#2976D, IRGKangXi=1424.171, RSKangXi=184.10
2976E CJK UNIFIED IDEOGRAPH-#2976E, IRGKangXi=1424.171, RSKangXi=184.10
2976F CJK UNIFIED IDEOGRAPH-#2976F, IRGKangXi=1424.171, RSKangXi=184.10
29770 CJK UNIFIED IDEOGRAPH-#29770, IRGKangXi=1424.171, RSKangXi=184.10
29771 CJK UNIFIED IDEOGRAPH-#29771, IRGKangXi=1424.171, RSKangXi=184.10
29772 CJK UNIFIED IDEOGRAPH-#29772, IRGKangXi=1424.171, RSKangXi=184.10
29773 CJK UNIFIED IDEOGRAPH-#29773, IRGKangXi=1424.171, RSKangXi=184.10
29774 CJK UNIFIED IDEOGRAPH-#29774, IRGKangXi=1424.171, RSKangXi=184.11
29775 CJK UNIFIED IDEOGRAPH-#29775, IRGKangXi=1424.171, RSKangXi=184.10
29776 CJK UNIFIED IDEOGRAPH-#29776, IRGKangXi=1424.171, RSKangXi=184.10
29777 CJK UNIFIED IDEOGRAPH-#29777, IRGKangXi=1424.171, RSKangXi=184.10
29778 CJK UNIFIED IDEOGRAPH-#29778, IRGKangXi=1424.171, RSKangXi=184.10
29779 CJK UNIFIED IDEOGRAPH-#29779, IRGKangXi=1424.171, RSKangXi=184.10
2977A CJK UNIFIED IDEOGRAPH-#2977A, IRGKangXi=1424.171, RSKangXi=184.10
2977B CJK UNIFIED IDEOGRAPH-#2977B, IRGKangXi=1424.171, RSKangXi=184.10
2977C CJK UNIFIED IDEOGRAPH-#2977C, IRGKangXi=1424.171, RSKangXi=184.10
2977D CJK UNIFIED IDEOGRAPH-#2977D, IRGKangXi=1424.180, RSKangXi=184.11
2977E CJK UNIFIED IDEOGRAPH-#2977E, IRGKangXi=1424.200, RSKangXi=184.11
2977F CJK UNIFIED IDEOGRAPH-#2977F, IRGKangXi=1424.210, RSKangXi=184.11
29780 CJK UNIFIED IDEOGRAPH-#29780, IRGKangXi=1424.220, RSKangXi=184.11
29781 CJK UNIFIED IDEOGRAPH-#29781, IRGKangXi=1424.230, RSKangXi=184.11
29782 CJK UNIFIED IDEOGRAPH-#29782, IRGKangXi=1424.250, RSKangXi=184.11
29783 CJK UNIFIED IDEOGRAPH-#29783, IRGKangXi=1424.260, RSKangXi=184.11
29784 CJK UNIFIED IDEOGRAPH-#29784, IRGKangXi=1424.280, RSKangXi=184.11
29785 CJK UNIFIED IDEOGRAPH-#29785, IRGKangXi=1424.290, RSKangXi=184.11
29786 CJK UNIFIED IDEOGRAPH-#29786, IRGKangXi=1424.300, RSKangXi=184.11
29787 CJK UNIFIED IDEOGRAPH-#29787, IRGKangXi=1424.320, RSKangXi=184.11
29788 CJK UNIFIED IDEOGRAPH-#29788, IRGKangXi=1424.340, RSKangXi=184.11
29789 CJK UNIFIED IDEOGRAPH-#29789, IRGKangXi=1424.360, RSKangXi=184.11
2978A CJK UNIFIED IDEOGRAPH-#2978A, IRGKangXi=1425.020, RSKangXi=184.11
2978B CJK UNIFIED IDEOGRAPH-#2978B, IRGKangXi=1425.030, RSKangXi=184.11
2978C CJK UNIFIED IDEOGRAPH-#2978C, IRGKangXi=1425.060, RSKangXi=184.11
2978D CJK UNIFIED IDEOGRAPH-#2978D, IRGKangXi=1425.070, RSKangXi=184.11
2978E CJK UNIFIED IDEOGRAPH-#2978E, IRGKangXi=1425.080, RSKangXi=184.11
2978F CJK UNIFIED IDEOGRAPH-#2978F, IRGKangXi=1425.090, RSKangXi=184.11
29790 CJK UNIFIED IDEOGRAPH-#29790, IRGKangXi=1425.100, RSKangXi=184.11
29791 CJK UNIFIED IDEOGRAPH-#29791, IRGKangXi=1425.110, RSKangXi=184.11
29792 CJK UNIFIED IDEOGRAPH-#29792, IRGKangXi=1425.111, RSKangXi=184.11
29793 CJK UNIFIED IDEOGRAPH-#29793, IRGKangXi=1425.111, RSKangXi=184.11
29794 CJK UNIFIED IDEOGRAPH-#29794, IRGKangXi=1425.111, RSKangXi=184.11
29795 CJK UNIFIED IDEOGRAPH-#29795, IRGKangXi=1425.111, RSKangXi=184.11
29796 CJK UNIFIED IDEOGRAPH-#29796, IRGKangXi=1425.111, RSKangXi=184.11
29797 CJK UNIFIED IDEOGRAPH-#29797, IRGKangXi=1425.111, RSKangXi=184.11
29798 CJK UNIFIED IDEOGRAPH-#29798, IRGKangXi=1425.111, RSKangXi=184.11
29799 CJK UNIFIED IDEOGRAPH-#29799, IRGKangXi=1425.111, RSKangXi=184.11
2979A CJK UNIFIED IDEOGRAPH-#2979A, IRGKangXi=1425.111, RSKangXi=184.11
2979B CJK UNIFIED IDEOGRAPH-#2979B, IRGKangXi=1425.111, RSKangXi=184.11
2979C CJK UNIFIED IDEOGRAPH-#2979C, IRGKangXi=1425.111, RSKangXi=184.11
2979D CJK UNIFIED IDEOGRAPH-#2979D, IRGKangXi=1425.111, RSKangXi=184.11
2979E CJK UNIFIED IDEOGRAPH-#2979E, IRGKangXi=1425.111, RSKangXi=184.11
2979F CJK UNIFIED IDEOGRAPH-#2979F, IRGKangXi=1425.111, RSKangXi=184.11
297A0 CJK UNIFIED IDEOGRAPH-#297A0, IRGKangXi=1425.111, RSKangXi=184.11
297A1 CJK UNIFIED IDEOGRAPH-#297A1, IRGKangXi=1425.120, RSKangXi=184.12
297A2 CJK UNIFIED IDEOGRAPH-#297A2, IRGKangXi=1425.130, RSKangXi=184.12
297A3 CJK UNIFIED IDEOGRAPH-#297A3, IRGKangXi=1425.150, RSKangXi=184.12
297A4 CJK UNIFIED IDEOGRAPH-#297A4, IRGKangXi=1425.170, RSKangXi=184.12
297A5 CJK UNIFIED IDEOGRAPH-#297A5, IRGKangXi=1425.180, RSKangXi=184.12
297A6 CJK UNIFIED IDEOGRAPH-#297A6, IRGKangXi=1425.210, RSKangXi=184.12
297A7 CJK UNIFIED IDEOGRAPH-#297A7, IRGKangXi=1425.230, RSKangXi=184.12
297A8 CJK UNIFIED IDEOGRAPH-#297A8, IRGKangXi=1425.260, RSKangXi=184.12
297A9 CJK UNIFIED IDEOGRAPH-#297A9, IRGKangXi=1425.270, RSKangXi=184.12
297AA CJK UNIFIED IDEOGRAPH-#297AA, IRGKangXi=1425.320, RSKangXi=184.12
297AB CJK UNIFIED IDEOGRAPH-#297AB, IRGKangXi=1425.380, RSKangXi=184.12
297AC CJK UNIFIED IDEOGRAPH-#297AC, IRGKangXi=1425.390, RSKangXi=184.12
297AD CJK UNIFIED IDEOGRAPH-#297AD, IRGKangXi=1425.410, RSKangXi=184.12
297AE CJK UNIFIED IDEOGRAPH-#297AE, IRGKangXi=1425.420, RSKangXi=184.12
297AF CJK UNIFIED IDEOGRAPH-#297AF, IRGKangXi=1425.431, RSKangXi=184.12
297B0 CJK UNIFIED IDEOGRAPH-#297B0, IRGKangXi=1425.431, RSKangXi=184.12
297B1 CJK UNIFIED IDEOGRAPH-#297B1, IRGKangXi=1425.431, RSKangXi=184.12
297B2 CJK UNIFIED IDEOGRAPH-#297B2, IRGKangXi=1425.431, RSKangXi=184.12
297B3 CJK UNIFIED IDEOGRAPH-#297B3, IRGKangXi=1425.431, RSKangXi=184.12
297B4 CJK UNIFIED IDEOGRAPH-#297B4, IRGKangXi=1425.431, RSKangXi=184.12
297B5 CJK UNIFIED IDEOGRAPH-#297B5, IRGKangXi=1425.431, RSKangXi=184.12
297B6 CJK UNIFIED IDEOGRAPH-#297B6, IRGKangXi=1425.431, RSKangXi=184.13
297B7 CJK UNIFIED IDEOGRAPH-#297B7, IRGKangXi=1425.431, RSKangXi=184.12
297B8 CJK UNIFIED IDEOGRAPH-#297B8, IRGKangXi=1425.431, RSKangXi=184.12
297B9 CJK UNIFIED IDEOGRAPH-#297B9, IRGKangXi=1425.431, RSKangXi=184.12
297BA CJK UNIFIED IDEOGRAPH-#297BA, IRGKangXi=1425.431, RSKangXi=184.12
297BB CJK UNIFIED IDEOGRAPH-#297BB, IRGKangXi=1425.431, RSKangXi=184.12
297BC CJK UNIFIED IDEOGRAPH-#297BC, IRGKangXi=1425.431, RSKangXi=184.12
297BD CJK UNIFIED IDEOGRAPH-#297BD, IRGKangXi=1425.431, RSKangXi=184.12
297BE CJK UNIFIED IDEOGRAPH-#297BE, IRGKangXi=1425.450, RSKangXi=184.13
297BF CJK UNIFIED IDEOGRAPH-#297BF, IRGKangXi=1425.460, RSKangXi=184.13
297C0 CJK UNIFIED IDEOGRAPH-#297C0, IRGKangXi=1425.470, RSKangXi=184.13
297C1 CJK UNIFIED IDEOGRAPH-#297C1, IRGKangXi=1426.010, RSKangXi=184.13
297C2 CJK UNIFIED IDEOGRAPH-#297C2, IRGKangXi=1426.020, RSKangXi=184.13
297C3 CJK UNIFIED IDEOGRAPH-#297C3, IRGKangXi=1426.030, RSKangXi=184.13
297C4 CJK UNIFIED IDEOGRAPH-#297C4, IRGKangXi=1426.040, RSKangXi=184.13
297C5 CJK UNIFIED IDEOGRAPH-#297C5, IRGKangXi=1426.060, RSKangXi=184.13
297C6 CJK UNIFIED IDEOGRAPH-#297C6, IRGKangXi=1426.070, RSKangXi=184.13
297C7 CJK UNIFIED IDEOGRAPH-#297C7, IRGKangXi=1426.080, RSKangXi=184.13
297C8 CJK UNIFIED IDEOGRAPH-#297C8, IRGKangXi=1426.090, RSKangXi=184.13
297C9 CJK UNIFIED IDEOGRAPH-#297C9, IRGKangXi=1426.130, RSKangXi=184.13
297CA CJK UNIFIED IDEOGRAPH-#297CA, IRGKangXi=1426.160, RSKangXi=184.13
297CB CJK UNIFIED IDEOGRAPH-#297CB, IRGKangXi=1426.180, RSKangXi=184.13
297CC CJK UNIFIED IDEOGRAPH-#297CC, IRGKangXi=1426.200, RSKangXi=184.13
297CD CJK UNIFIED IDEOGRAPH-#297CD, IRGKangXi=1426.210, RSKangXi=184.13
297CE CJK UNIFIED IDEOGRAPH-#297CE, IRGKangXi=1426.211, RSKangXi=184.13
297CF CJK UNIFIED IDEOGRAPH-#297CF, IRGKangXi=1426.211, RSKangXi=184.13
297D0 CJK UNIFIED IDEOGRAPH-#297D0, IRGKangXi=1426.211, RSKangXi=184.13
297D1 CJK UNIFIED IDEOGRAPH-#297D1, IRGKangXi=1426.211, RSKangXi=184.13
297D2 CJK UNIFIED IDEOGRAPH-#297D2, IRGKangXi=1426.211, RSKangXi=184.13
297D3 CJK UNIFIED IDEOGRAPH-#297D3, IRGKangXi=1426.230, RSKangXi=184.14
297D4 CJK UNIFIED IDEOGRAPH-#297D4, IRGKangXi=1426.250, RSKangXi=184.14, Def{(Cant., vulg.) to eat}
297D5 CJK UNIFIED IDEOGRAPH-#297D5, IRGKangXi=1426.260, RSKangXi=184.14
297D6 CJK UNIFIED IDEOGRAPH-#297D6, IRGKangXi=1426.270, RSKangXi=184.14
297D7 CJK UNIFIED IDEOGRAPH-#297D7, IRGKangXi=1426.300, RSKangXi=184.14
297D8 CJK UNIFIED IDEOGRAPH-#297D8, IRGKangXi=1426.330, RSKangXi=184.14
297D9 CJK UNIFIED IDEOGRAPH-#297D9, IRGKangXi=1427.010, RSKangXi=184.14
297DA CJK UNIFIED IDEOGRAPH-#297DA, IRGKangXi=1427.030, RSKangXi=184.14
297DB CJK UNIFIED IDEOGRAPH-#297DB, IRGKangXi=1427.040, RSKangXi=184.14
297DC CJK UNIFIED IDEOGRAPH-#297DC, IRGKangXi=1427.050, RSKangXi=184.14
297DD CJK UNIFIED IDEOGRAPH-#297DD, IRGKangXi=1427.051, RSKangXi=184.14
297DE CJK UNIFIED IDEOGRAPH-#297DE, IRGKangXi=1427.051, RSKangXi=184.14
297DF CJK UNIFIED IDEOGRAPH-#297DF, IRGKangXi=1427.051, RSKangXi=184.14
297E0 CJK UNIFIED IDEOGRAPH-#297E0, IRGKangXi=1427.051, RSKangXi=184.14
297E1 CJK UNIFIED IDEOGRAPH-#297E1, IRGKangXi=1427.051, RSKangXi=184.14
297E2 CJK UNIFIED IDEOGRAPH-#297E2, IRGKangXi=1427.051, RSKangXi=184.14
297E3 CJK UNIFIED IDEOGRAPH-#297E3, IRGKangXi=1427.051, RSKangXi=184.14
297E4 CJK UNIFIED IDEOGRAPH-#297E4, IRGKangXi=1427.060, RSKangXi=184.15
297E5 CJK UNIFIED IDEOGRAPH-#297E5, IRGKangXi=1427.080, RSKangXi=184.15
297E6 CJK UNIFIED IDEOGRAPH-#297E6, IRGKangXi=1427.090, RSKangXi=184.15
297E7 CJK UNIFIED IDEOGRAPH-#297E7, IRGKangXi=1427.100, RSKangXi=184.15
297E8 CJK UNIFIED IDEOGRAPH-#297E8, IRGKangXi=1427.110, RSKangXi=184.15
297E9 CJK UNIFIED IDEOGRAPH-#297E9, IRGKangXi=1427.120, RSKangXi=184.15
297EA CJK UNIFIED IDEOGRAPH-#297EA, IRGKangXi=1427.121, RSKangXi=184.15
297EB CJK UNIFIED IDEOGRAPH-#297EB, IRGKangXi=1427.121, RSKangXi=184.15
297EC CJK UNIFIED IDEOGRAPH-#297EC, IRGKangXi=1427.121, RSKangXi=184.15
297ED CJK UNIFIED IDEOGRAPH-#297ED, IRGKangXi=1427.130, RSKangXi=184.16
297EE CJK UNIFIED IDEOGRAPH-#297EE, IRGKangXi=1427.140, RSKangXi=184.16
297EF CJK UNIFIED IDEOGRAPH-#297EF, IRGKangXi=1427.150, RSKangXi=184.16
297F0 CJK UNIFIED IDEOGRAPH-#297F0, IRGKangXi=1427.160, RSKangXi=184.16
297F1 CJK UNIFIED IDEOGRAPH-#297F1, IRGKangXi=1427.170, RSKangXi=184.16
297F2 CJK UNIFIED IDEOGRAPH-#297F2, IRGKangXi=1427.181, RSKangXi=184.16
297F3 CJK UNIFIED IDEOGRAPH-#297F3, IRGKangXi=1427.181, RSKangXi=184.16
297F4 CJK UNIFIED IDEOGRAPH-#297F4, IRGKangXi=1427.181, RSKangXi=184.16
297F5 CJK UNIFIED IDEOGRAPH-#297F5, IRGKangXi=1427.181, RSKangXi=184.16
297F6 CJK UNIFIED IDEOGRAPH-#297F6, IRGKangXi=1427.200, RSKangXi=184.17
297F7 CJK UNIFIED IDEOGRAPH-#297F7, IRGKangXi=1427.250, RSKangXi=184.18
297F8 CJK UNIFIED IDEOGRAPH-#297F8, IRGKangXi=1427.260, RSKangXi=184.18
297F9 CJK UNIFIED IDEOGRAPH-#297F9, IRGKangXi=1427.261, RSKangXi=184.18
297FA CJK UNIFIED IDEOGRAPH-#297FA, IRGKangXi=1427.261, RSKangXi=184.18
297FB CJK UNIFIED IDEOGRAPH-#297FB, IRGKangXi=1427.311, RSKangXi=184.21
297FC CJK UNIFIED IDEOGRAPH-#297FC, IRGKangXi=1427.311, RSKangXi=184.22
297FD CJK UNIFIED IDEOGRAPH-#297FD, IRGKangXi=1427.311, RSKangXi=184.24
297FE CJK UNIFIED IDEOGRAPH-#297FE, IRGKangXi=1427.311, RSKangXi=184.4
297FF CJK UNIFIED IDEOGRAPH-#297FF, IRGKangXi=1427.311, RSKangXi=184.4
29800 CJK UNIFIED IDEOGRAPH-#29800, IRGKangXi=1427.311, RSKangXi=184.4
29801 CJK UNIFIED IDEOGRAPH-#29801, IRGKangXi=1427.311, RSKangXi=184.5
29802 CJK UNIFIED IDEOGRAPH-#29802, IRGKangXi=1427.311, RSKangXi=184.5
29803 CJK UNIFIED IDEOGRAPH-#29803, IRGKangXi=1427.311, RSKangXi=184.6
29804 CJK UNIFIED IDEOGRAPH-#29804, IRGKangXi=1427.311, RSKangXi=184.7
29805 CJK UNIFIED IDEOGRAPH-#29805, IRGKangXi=1427.311, RSKangXi=184.7
29806 CJK UNIFIED IDEOGRAPH-#29806, IRGKangXi=1427.311, RSKangXi=184.8
29807 CJK UNIFIED IDEOGRAPH-#29807, IRGKangXi=1427.311, RSKangXi=184.7
29808 CJK UNIFIED IDEOGRAPH-#29808, IRGKangXi=1427.311, RSKangXi=184.8
29809 CJK UNIFIED IDEOGRAPH-#29809, IRGKangXi=1427.311, RSKangXi=184.8
2980A CJK UNIFIED IDEOGRAPH-#2980A, IRGKangXi=1427.311, RSKangXi=184.9
2980B CJK UNIFIED IDEOGRAPH-#2980B, IRGKangXi=1427.311, RSKangXi=184.9
2980C CJK UNIFIED IDEOGRAPH-#2980C, IRGKangXi=1427.311, RSKangXi=184.10
2980D CJK UNIFIED IDEOGRAPH-#2980D, IRGKangXi=1427.311, RSKangXi=184.11
2980E CJK UNIFIED IDEOGRAPH-#2980E, IRGKangXi=1427.311, RSKangXi=184.11
2980F CJK UNIFIED IDEOGRAPH-#2980F, IRGKangXi=1427.311, RSKangXi=184.12
29810 CJK UNIFIED IDEOGRAPH-#29810, IRGKangXi=1428.010, RSKangXi=185.0
29811 CJK UNIFIED IDEOGRAPH-#29811, IRGKangXi=1428.020, RSKangXi=184.2, Def{top, head, summit}
29812 CJK UNIFIED IDEOGRAPH-#29812, IRGKangXi=1428.031, RSKangXi=185.2
29813 CJK UNIFIED IDEOGRAPH-#29813, IRGKangXi=1428.031, RSKangXi=185.3
29814 CJK UNIFIED IDEOGRAPH-#29814, IRGKangXi=1428.031, RSKangXi=185.4
29815 CJK UNIFIED IDEOGRAPH-#29815, IRGKangXi=1428.040, RSKangXi=185.5
29816 CJK UNIFIED IDEOGRAPH-#29816, IRGKangXi=1428.050, RSKangXi=185.5
29817 CJK UNIFIED IDEOGRAPH-#29817, IRGKangXi=1428.060, RSKangXi=185.5
29818 CJK UNIFIED IDEOGRAPH-#29818, IRGKangXi=1428.061, RSKangXi=185.5
29819 CJK UNIFIED IDEOGRAPH-#29819, IRGKangXi=1428.061, RSKangXi=185.5
2981A CJK UNIFIED IDEOGRAPH-#2981A, IRGKangXi=1428.070, RSKangXi=185.6
2981B CJK UNIFIED IDEOGRAPH-#2981B, IRGKangXi=1428.080, RSKangXi=185.6
2981C CJK UNIFIED IDEOGRAPH-#2981C, IRGKangXi=1428.090, RSKangXi=185.6
2981D CJK UNIFIED IDEOGRAPH-#2981D, IRGKangXi=1428.101, RSKangXi=185.6
2981E CJK UNIFIED IDEOGRAPH-#2981E, IRGKangXi=1428.101, RSKangXi=185.6
2981F CJK UNIFIED IDEOGRAPH-#2981F, IRGKangXi=1428.101, RSKangXi=185.6
29820 CJK UNIFIED IDEOGRAPH-#29820, IRGKangXi=1428.101, RSKangXi=185.6
29821 CJK UNIFIED IDEOGRAPH-#29821, IRGKangXi=1428.101, RSKangXi=185.7
29822 CJK UNIFIED IDEOGRAPH-#29822, IRGKangXi=1428.101, RSKangXi=185.7
29823 CJK UNIFIED IDEOGRAPH-#29823, IRGKangXi=1428.110, RSKangXi=185.7
29824 CJK UNIFIED IDEOGRAPH-#29824, IRGKangXi=1428.120, RSKangXi=185.7
29825 CJK UNIFIED IDEOGRAPH-#29825, IRGKangXi=1428.121, RSKangXi=185.7
29826 CJK UNIFIED IDEOGRAPH-#29826, IRGKangXi=1428.121, RSKangXi=185.7
29827 CJK UNIFIED IDEOGRAPH-#29827, IRGKangXi=1428.121, RSKangXi=185.7
29828 CJK UNIFIED IDEOGRAPH-#29828, IRGKangXi=1428.131, RSKangXi=185.8
29829 CJK UNIFIED IDEOGRAPH-#29829, IRGKangXi=1428.131, RSKangXi=185.8
2982A CJK UNIFIED IDEOGRAPH-#2982A, IRGKangXi=1428.150, RSKangXi=185.9
2982B CJK UNIFIED IDEOGRAPH-#2982B, IRGKangXi=1428.160, RSKangXi=185.9
2982C CJK UNIFIED IDEOGRAPH-#2982C, IRGKangXi=1428.161, RSKangXi=185.9
2982D CJK UNIFIED IDEOGRAPH-#2982D, IRGKangXi=1428.161, RSKangXi=185.9
2982E CJK UNIFIED IDEOGRAPH-#2982E, IRGKangXi=1428.161, RSKangXi=66.15
2982F CJK UNIFIED IDEOGRAPH-#2982F, IRGKangXi=1428.161, RSKangXi=185.10
29830 CJK UNIFIED IDEOGRAPH-#29830, IRGKangXi=1428.161, RSKangXi=66.16
29831 CJK UNIFIED IDEOGRAPH-#29831, IRGKangXi=1428.171, RSKangXi=185.10
29832 CJK UNIFIED IDEOGRAPH-#29832, IRGKangXi=1428.180, RSKangXi=185.11
29833 CJK UNIFIED IDEOGRAPH-#29833, IRGKangXi=1428.181, RSKangXi=185.12
29834 CJK UNIFIED IDEOGRAPH-#29834, IRGKangXi=1428.181, RSKangXi=185.13
29835 CJK UNIFIED IDEOGRAPH-#29835, IRGKangXi=1428.181, RSKangXi=185.14
29836 CJK UNIFIED IDEOGRAPH-#29836, IRGKangXi=1428.181, RSKangXi=185.14
29837 CJK UNIFIED IDEOGRAPH-#29837, IRGKangXi=1428.190, RSKangXi=185.15
29838 CJK UNIFIED IDEOGRAPH-#29838, IRGKangXi=1428.191, RSKangXi=185.16
29839 CJK UNIFIED IDEOGRAPH-#29839, IRGKangXi=1428.200, RSKangXi=185.18
2983A CJK UNIFIED IDEOGRAPH-#2983A, IRGKangXi=1428.211, RSKangXi=186.1
2983B CJK UNIFIED IDEOGRAPH-#2983B, IRGKangXi=1429.010, RSKangXi=186.4
2983C CJK UNIFIED IDEOGRAPH-#2983C, IRGKangXi=1429.030, RSKangXi=186.4
2983D CJK UNIFIED IDEOGRAPH-#2983D, IRGKangXi=1429.031, RSKangXi=186.4
2983E CJK UNIFIED IDEOGRAPH-#2983E, IRGKangXi=1429.040, RSKangXi=186.5
2983F CJK UNIFIED IDEOGRAPH-#2983F, IRGKangXi=1429.050, RSKangXi=186.5
29840 CJK UNIFIED IDEOGRAPH-#29840, IRGKangXi=1429.100, RSKangXi=186.5
29841 CJK UNIFIED IDEOGRAPH-#29841, IRGKangXi=1429.101, RSKangXi=186.5
29842 CJK UNIFIED IDEOGRAPH-#29842, IRGKangXi=1429.101, RSKangXi=186.6
29843 CJK UNIFIED IDEOGRAPH-#29843, IRGKangXi=1429.101, RSKangXi=186.5
29844 CJK UNIFIED IDEOGRAPH-#29844, IRGKangXi=1429.101, RSKangXi=186.5
29845 CJK UNIFIED IDEOGRAPH-#29845, IRGKangXi=1429.101, RSKangXi=186.6
29846 CJK UNIFIED IDEOGRAPH-#29846, IRGKangXi=1429.101, RSKangXi=186.6
29847 CJK UNIFIED IDEOGRAPH-#29847, IRGKangXi=1429.131, RSKangXi=186.7
29848 CJK UNIFIED IDEOGRAPH-#29848, IRGKangXi=1429.131, RSKangXi=186.7
29849 CJK UNIFIED IDEOGRAPH-#29849, IRGKangXi=1429.191, RSKangXi=186.8
2984A CJK UNIFIED IDEOGRAPH-#2984A, IRGKangXi=1429.191, RSKangXi=186.8
2984B CJK UNIFIED IDEOGRAPH-#2984B, IRGKangXi=1429.191, RSKangXi=186.8
2984C CJK UNIFIED IDEOGRAPH-#2984C, IRGKangXi=1429.220, RSKangXi=186.9
2984D CJK UNIFIED IDEOGRAPH-#2984D, IRGKangXi=1429.230, RSKangXi=186.9
2984E CJK UNIFIED IDEOGRAPH-#2984E, IRGKangXi=1429.240, RSKangXi=186.9
2984F CJK UNIFIED IDEOGRAPH-#2984F, IRGKangXi=1429.241, RSKangXi=186.9
29850 CJK UNIFIED IDEOGRAPH-#29850, IRGKangXi=1429.241, RSKangXi=186.9
29851 CJK UNIFIED IDEOGRAPH-#29851, IRGKangXi=1429.241, RSKangXi=186.9
29852 CJK UNIFIED IDEOGRAPH-#29852, IRGKangXi=1429.241, RSKangXi=186.9
29853 CJK UNIFIED IDEOGRAPH-#29853, IRGKangXi=1429.250, RSKangXi=186.10
29854 CJK UNIFIED IDEOGRAPH-#29854, IRGKangXi=1429.270, RSKangXi=186.10
29855 CJK UNIFIED IDEOGRAPH-#29855, IRGKangXi=1429.290, RSKangXi=186.10
29856 CJK UNIFIED IDEOGRAPH-#29856, IRGKangXi=1429.291, RSKangXi=186.10
29857 CJK UNIFIED IDEOGRAPH-#29857, IRGKangXi=1429.291, RSKangXi=186.10
29858 CJK UNIFIED IDEOGRAPH-#29858, IRGKangXi=1429.291, RSKangXi=186.10
29859 CJK UNIFIED IDEOGRAPH-#29859, IRGKangXi=1429.301, RSKangXi=186.11
2985A CJK UNIFIED IDEOGRAPH-#2985A, IRGKangXi=1429.301, RSKangXi=186.11
2985B CJK UNIFIED IDEOGRAPH-#2985B, IRGKangXi=1429.301, RSKangXi=186.11
2985C CJK UNIFIED IDEOGRAPH-#2985C, IRGKangXi=1429.301, RSKangXi=186.11
2985D CJK UNIFIED IDEOGRAPH-#2985D, IRGKangXi=1429.320, RSKangXi=186.12
2985E CJK UNIFIED IDEOGRAPH-#2985E, IRGKangXi=1429.321, RSKangXi=186.12
2985F CJK UNIFIED IDEOGRAPH-#2985F, IRGKangXi=1429.321, RSKangXi=186.12
29860 CJK UNIFIED IDEOGRAPH-#29860, IRGKangXi=1429.321, RSKangXi=186.12
29861 CJK UNIFIED IDEOGRAPH-#29861, IRGKangXi=1429.321, RSKangXi=186.12
29862 CJK UNIFIED IDEOGRAPH-#29862, IRGKangXi=1429.321, RSKangXi=186.13
29863 CJK UNIFIED IDEOGRAPH-#29863, IRGKangXi=1429.321, RSKangXi=186.13
29864 CJK UNIFIED IDEOGRAPH-#29864, IRGKangXi=1429.330, RSKangXi=186.14
29865 CJK UNIFIED IDEOGRAPH-#29865, IRGKangXi=1429.350, RSKangXi=186.17
29866 CJK UNIFIED IDEOGRAPH-#29866, IRGKangXi=1430.011, RSKangXi=186.19
29867 CJK UNIFIED IDEOGRAPH-#29867, IRGKangXi=1433.050, RSKangXi=187.0
29868 CJK UNIFIED IDEOGRAPH-#29868, IRGKangXi=1433.060, RSKangXi=187.1
29869 CJK UNIFIED IDEOGRAPH-#29869, IRGKangXi=1433.070, RSKangXi=187.2
2986A CJK UNIFIED IDEOGRAPH-#2986A, IRGKangXi=1433.100, RSKangXi=187.2
2986B CJK UNIFIED IDEOGRAPH-#2986B, IRGKangXi=1434.010, RSKangXi=187.2
2986C CJK UNIFIED IDEOGRAPH-#2986C, IRGKangXi=1434.020, RSKangXi=187.2
2986D CJK UNIFIED IDEOGRAPH-#2986D, IRGKangXi=1434.021, RSKangXi=187.2
2986E CJK UNIFIED IDEOGRAPH-#2986E, IRGKangXi=1434.021, RSKangXi=187.2
2986F CJK UNIFIED IDEOGRAPH-#2986F, IRGKangXi=1434.021, RSKangXi=187.2
29870 CJK UNIFIED IDEOGRAPH-#29870, IRGKangXi=1434.040, RSKangXi=187.3
29871 CJK UNIFIED IDEOGRAPH-#29871, IRGKangXi=1434.050, RSKangXi=187.3
29872 CJK UNIFIED IDEOGRAPH-#29872, IRGKangXi=1434.130, RSKangXi=187.3
29873 CJK UNIFIED IDEOGRAPH-#29873, IRGKangXi=1434.150, RSKangXi=187.3
29874 CJK UNIFIED IDEOGRAPH-#29874, IRGKangXi=1434.161, RSKangXi=187.3
29875 CJK UNIFIED IDEOGRAPH-#29875, IRGKangXi=1434.161, RSKangXi=187.3
29876 CJK UNIFIED IDEOGRAPH-#29876, IRGKangXi=1434.161, RSKangXi=187.3
29877 CJK UNIFIED IDEOGRAPH-#29877, IRGKangXi=1434.180, RSKangXi=187.4
29878 CJK UNIFIED IDEOGRAPH-#29878, IRGKangXi=1434.200, RSKangXi=187.4
29879 CJK UNIFIED IDEOGRAPH-#29879, IRGKangXi=1434.220, RSKangXi=187.4
2987A CJK UNIFIED IDEOGRAPH-#2987A, IRGKangXi=1435.010, RSKangXi=187.4
2987B CJK UNIFIED IDEOGRAPH-#2987B, IRGKangXi=1435.030, RSKangXi=187.4
2987C CJK UNIFIED IDEOGRAPH-#2987C, IRGKangXi=1435.080, RSKangXi=187.4
2987D CJK UNIFIED IDEOGRAPH-#2987D, IRGKangXi=1435.140, RSKangXi=187.4
2987E CJK UNIFIED IDEOGRAPH-#2987E, IRGKangXi=1435.190, RSKangXi=187.4
2987F CJK UNIFIED IDEOGRAPH-#2987F, IRGKangXi=1435.200, RSKangXi=187.5
29880 CJK UNIFIED IDEOGRAPH-#29880, IRGKangXi=1435.211, RSKangXi=187.4
29881 CJK UNIFIED IDEOGRAPH-#29881, IRGKangXi=1435.211, RSKangXi=187.4
29882 CJK UNIFIED IDEOGRAPH-#29882, IRGKangXi=1435.211, RSKangXi=187.4
29883 CJK UNIFIED IDEOGRAPH-#29883, IRGKangXi=1435.211, RSKangXi=187.4
29884 CJK UNIFIED IDEOGRAPH-#29884, IRGKangXi=1435.211, RSKangXi=187.4
29885 CJK UNIFIED IDEOGRAPH-#29885, IRGKangXi=1435.211, RSKangXi=187.4
29886 CJK UNIFIED IDEOGRAPH-#29886, IRGKangXi=1435.211, RSKangXi=187.5
29887 CJK UNIFIED IDEOGRAPH-#29887, IRGKangXi=1435.211, RSKangXi=187.4
29888 CJK UNIFIED IDEOGRAPH-#29888, IRGKangXi=1435.211, RSKangXi=187.4
29889 CJK UNIFIED IDEOGRAPH-#29889, IRGKangXi=1435.211, RSKangXi=187.4
2988A CJK UNIFIED IDEOGRAPH-#2988A, IRGKangXi=1435.211, RSKangXi=187.4
2988B CJK UNIFIED IDEOGRAPH-#2988B, IRGKangXi=1435.211, RSKangXi=187.4
2988C CJK UNIFIED IDEOGRAPH-#2988C, IRGKangXi=1435.211, RSKangXi=187.4
2988D CJK UNIFIED IDEOGRAPH-#2988D, IRGKangXi=1435.220, RSKangXi=187.5
2988E CJK UNIFIED IDEOGRAPH-#2988E, IRGKangXi=1435.260, RSKangXi=187.5
2988F CJK UNIFIED IDEOGRAPH-#2988F, IRGKangXi=1435.270, RSKangXi=187.5
29890 CJK UNIFIED IDEOGRAPH-#29890, IRGKangXi=1435.300, RSKangXi=187.5
29891 CJK UNIFIED IDEOGRAPH-#29891, IRGKangXi=1435.310, RSKangXi=187.5
29892 CJK UNIFIED IDEOGRAPH-#29892, IRGKangXi=1435.320, RSKangXi=187.5
29893 CJK UNIFIED IDEOGRAPH-#29893, IRGKangXi=1435.350, RSKangXi=187.5
29894 CJK UNIFIED IDEOGRAPH-#29894, IRGKangXi=1435.360, RSKangXi=187.5
29895 CJK UNIFIED IDEOGRAPH-#29895, IRGKangXi=1435.390, RSKangXi=187.5
29896 CJK UNIFIED IDEOGRAPH-#29896, IRGKangXi=1435.410, RSKangXi=187.5
29897 CJK UNIFIED IDEOGRAPH-#29897, IRGKangXi=1435.420, RSKangXi=187.5
29898 CJK UNIFIED IDEOGRAPH-#29898, IRGKangXi=1435.430, RSKangXi=187.5
29899 CJK UNIFIED IDEOGRAPH-#29899, IRGKangXi=1436.010, RSKangXi=187.5
2989A CJK UNIFIED IDEOGRAPH-#2989A, IRGKangXi=1436.040, RSKangXi=187.5
2989B CJK UNIFIED IDEOGRAPH-#2989B, IRGKangXi=1436.080, RSKangXi=187.5
2989C CJK UNIFIED IDEOGRAPH-#2989C, IRGKangXi=1436.150, RSKangXi=187.5
2989D CJK UNIFIED IDEOGRAPH-#2989D, IRGKangXi=1437.070, RSKangXi=187.5
2989E CJK UNIFIED IDEOGRAPH-#2989E, IRGKangXi=1437.080, RSKangXi=187.5
2989F CJK UNIFIED IDEOGRAPH-#2989F, IRGKangXi=1437.090, RSKangXi=187.5
298A0 CJK UNIFIED IDEOGRAPH-#298A0, IRGKangXi=1437.100, RSKangXi=187.5
298A1 CJK UNIFIED IDEOGRAPH-#298A1, IRGKangXi=1437.120, RSKangXi=187.5
298A2 CJK UNIFIED IDEOGRAPH-#298A2, IRGKangXi=1437.121, RSKangXi=187.5
298A3 CJK UNIFIED IDEOGRAPH-#298A3, IRGKangXi=1437.121, RSKangXi=187.5
298A4 CJK UNIFIED IDEOGRAPH-#298A4, IRGKangXi=1437.121, RSKangXi=187.5
298A5 CJK UNIFIED IDEOGRAPH-#298A5, IRGKangXi=1437.121, RSKangXi=187.5
298A6 CJK UNIFIED IDEOGRAPH-#298A6, IRGKangXi=1437.121, RSKangXi=187.5
298A7 CJK UNIFIED IDEOGRAPH-#298A7, IRGKangXi=1437.121, RSKangXi=187.5
298A8 CJK UNIFIED IDEOGRAPH-#298A8, IRGKangXi=1437.121, RSKangXi=187.5
298A9 CJK UNIFIED IDEOGRAPH-#298A9, IRGKangXi=1437.121, RSKangXi=187.5
298AA CJK UNIFIED IDEOGRAPH-#298AA, IRGKangXi=1437.121, RSKangXi=187.5
298AB CJK UNIFIED IDEOGRAPH-#298AB, IRGKangXi=1437.121, RSKangXi=187.5
298AC CJK UNIFIED IDEOGRAPH-#298AC, IRGKangXi=1437.121, RSKangXi=187.5
298AD CJK UNIFIED IDEOGRAPH-#298AD, IRGKangXi=1437.121, RSKangXi=187.5
298AE CJK UNIFIED IDEOGRAPH-#298AE, IRGKangXi=1437.140, RSKangXi=187.6
298AF CJK UNIFIED IDEOGRAPH-#298AF, IRGKangXi=1437.160, RSKangXi=187.6
298B0 CJK UNIFIED IDEOGRAPH-#298B0, IRGKangXi=1437.190, RSKangXi=187.6
298B1 CJK UNIFIED IDEOGRAPH-#298B1, IRGKangXi=1437.200, RSKangXi=187.6
298B2 CJK UNIFIED IDEOGRAPH-#298B2, IRGKangXi=1437.210, RSKangXi=187.6
298B3 CJK UNIFIED IDEOGRAPH-#298B3, IRGKangXi=1437.220, RSKangXi=187.6
298B4 CJK UNIFIED IDEOGRAPH-#298B4, IRGKangXi=1437.230, RSKangXi=187.6
298B5 CJK UNIFIED IDEOGRAPH-#298B5, IRGKangXi=1437.240, RSKangXi=187.6
298B6 CJK UNIFIED IDEOGRAPH-#298B6, IRGKangXi=1437.260, RSKangXi=187.6
298B7 CJK UNIFIED IDEOGRAPH-#298B7, IRGKangXi=1437.300, RSKangXi=187.6
298B8 CJK UNIFIED IDEOGRAPH-#298B8, IRGKangXi=1438.020, RSKangXi=187.6
298B9 CJK UNIFIED IDEOGRAPH-#298B9, IRGKangXi=1438.050, RSKangXi=187.6
298BA CJK UNIFIED IDEOGRAPH-#298BA, IRGKangXi=1438.060, RSKangXi=187.6
298BB CJK UNIFIED IDEOGRAPH-#298BB, IRGKangXi=1438.120, RSKangXi=187.6
298BC CJK UNIFIED IDEOGRAPH-#298BC, IRGKangXi=1438.140, RSKangXi=187.6
298BD CJK UNIFIED IDEOGRAPH-#298BD, IRGKangXi=1438.160, RSKangXi=187.6
298BE CJK UNIFIED IDEOGRAPH-#298BE, IRGKangXi=1438.180, RSKangXi=187.6
298BF CJK UNIFIED IDEOGRAPH-#298BF, IRGKangXi=1438.200, RSKangXi=187.6
298C0 CJK UNIFIED IDEOGRAPH-#298C0, IRGKangXi=1438.210, RSKangXi=187.6
298C1 CJK UNIFIED IDEOGRAPH-#298C1, IRGKangXi=1438.220, RSKangXi=187.6
298C2 CJK UNIFIED IDEOGRAPH-#298C2, IRGKangXi=1438.230, RSKangXi=187.6
298C3 CJK UNIFIED IDEOGRAPH-#298C3, IRGKangXi=1438.240, RSKangXi=187.6
298C4 CJK UNIFIED IDEOGRAPH-#298C4, IRGKangXi=1438.250, RSKangXi=187.6
298C5 CJK UNIFIED IDEOGRAPH-#298C5, IRGKangXi=1438.260, RSKangXi=187.6
298C6 CJK UNIFIED IDEOGRAPH-#298C6, IRGKangXi=1438.261, RSKangXi=187.6
298C7 CJK UNIFIED IDEOGRAPH-#298C7, IRGKangXi=1438.261, RSKangXi=187.6
298C8 CJK UNIFIED IDEOGRAPH-#298C8, IRGKangXi=1438.261, RSKangXi=187.6
298C9 CJK UNIFIED IDEOGRAPH-#298C9, IRGKangXi=1438.261, RSKangXi=187.6
298CA CJK UNIFIED IDEOGRAPH-#298CA, IRGKangXi=1438.261, RSKangXi=187.6
298CB CJK UNIFIED IDEOGRAPH-#298CB, IRGKangXi=1438.261, RSKangXi=187.6
298CC CJK UNIFIED IDEOGRAPH-#298CC, IRGKangXi=1438.261, RSKangXi=187.6
298CD CJK UNIFIED IDEOGRAPH-#298CD, IRGKangXi=1438.261, RSKangXi=187.6
298CE CJK UNIFIED IDEOGRAPH-#298CE, IRGKangXi=1438.261, RSKangXi=187.6
298CF CJK UNIFIED IDEOGRAPH-#298CF, IRGKangXi=1438.261, RSKangXi=187.6
298D0 CJK UNIFIED IDEOGRAPH-#298D0, IRGKangXi=1438.261, RSKangXi=187.6
298D1 CJK UNIFIED IDEOGRAPH-#298D1, IRGKangXi=1438.261, RSKangXi=187.6, Def{(same as U+978D 鞍) saddle; a saddle-like terrain or thing}
298D2 CJK UNIFIED IDEOGRAPH-#298D2, IRGKangXi=1438.261, RSKangXi=187.6
298D3 CJK UNIFIED IDEOGRAPH-#298D3, IRGKangXi=1438.261, RSKangXi=187.6
298D4 CJK UNIFIED IDEOGRAPH-#298D4, IRGKangXi=1438.261, RSKangXi=187.6
298D5 CJK UNIFIED IDEOGRAPH-#298D5, IRGKangXi=1438.261, RSKangXi=187.6
298D6 CJK UNIFIED IDEOGRAPH-#298D6, IRGKangXi=1438.270, RSKangXi=187.7
298D7 CJK UNIFIED IDEOGRAPH-#298D7, IRGKangXi=1438.290, RSKangXi=187.7
298D8 CJK UNIFIED IDEOGRAPH-#298D8, IRGKangXi=1439.040, RSKangXi=187.7
298D9 CJK UNIFIED IDEOGRAPH-#298D9, IRGKangXi=1439.050, RSKangXi=187.7
298DA CJK UNIFIED IDEOGRAPH-#298DA, IRGKangXi=1439.060, RSKangXi=187.7
298DB CJK UNIFIED IDEOGRAPH-#298DB, IRGKangXi=1439.130, RSKangXi=187.7
298DC CJK UNIFIED IDEOGRAPH-#298DC, IRGKangXi=1439.160, RSKangXi=187.7
298DD CJK UNIFIED IDEOGRAPH-#298DD, IRGKangXi=1439.170, RSKangXi=187.7
298DE CJK UNIFIED IDEOGRAPH-#298DE, IRGKangXi=1439.190, RSKangXi=187.7
298DF CJK UNIFIED IDEOGRAPH-#298DF, IRGKangXi=1439.200, RSKangXi=187.7
298E0 CJK UNIFIED IDEOGRAPH-#298E0, IRGKangXi=1439.210, RSKangXi=187.7
298E1 CJK UNIFIED IDEOGRAPH-#298E1, IRGKangXi=1439.220, RSKangXi=187.7
298E2 CJK UNIFIED IDEOGRAPH-#298E2, IRGKangXi=1440.020, RSKangXi=187.7
298E3 CJK UNIFIED IDEOGRAPH-#298E3, IRGKangXi=1440.030, RSKangXi=187.7
298E4 CJK UNIFIED IDEOGRAPH-#298E4, IRGKangXi=1440.040, RSKangXi=187.7
298E5 CJK UNIFIED IDEOGRAPH-#298E5, IRGKangXi=1440.041, RSKangXi=187.7
298E6 CJK UNIFIED IDEOGRAPH-#298E6, IRGKangXi=1440.041, RSKangXi=187.7
298E7 CJK UNIFIED IDEOGRAPH-#298E7, IRGKangXi=1440.041, RSKangXi=187.7
298E8 CJK UNIFIED IDEOGRAPH-#298E8, IRGKangXi=1440.041, RSKangXi=187.7
298E9 CJK UNIFIED IDEOGRAPH-#298E9, IRGKangXi=1440.041, RSKangXi=187.7
298EA CJK UNIFIED IDEOGRAPH-#298EA, IRGKangXi=1440.041, RSKangXi=187.7
298EB CJK UNIFIED IDEOGRAPH-#298EB, IRGKangXi=1440.041, RSKangXi=187.7
298EC CJK UNIFIED IDEOGRAPH-#298EC, IRGKangXi=1440.041, RSKangXi=187.7
298ED CJK UNIFIED IDEOGRAPH-#298ED, IRGKangXi=1440.050, RSKangXi=187.8
298EE CJK UNIFIED IDEOGRAPH-#298EE, IRGKangXi=1440.060, RSKangXi=187.8
298EF CJK UNIFIED IDEOGRAPH-#298EF, IRGKangXi=1440.120, RSKangXi=187.8
298F0 CJK UNIFIED IDEOGRAPH-#298F0, IRGKangXi=1440.130, RSKangXi=187.8
298F1 CJK UNIFIED IDEOGRAPH-#298F1, IRGKangXi=1440.140, RSKangXi=187.8
298F2 CJK UNIFIED IDEOGRAPH-#298F2, IRGKangXi=1440.160, RSKangXi=187.8
298F3 CJK UNIFIED IDEOGRAPH-#298F3, IRGKangXi=1440.170, RSKangXi=187.8
298F4 CJK UNIFIED IDEOGRAPH-#298F4, IRGKangXi=1440.180, RSKangXi=187.8
298F5 CJK UNIFIED IDEOGRAPH-#298F5, IRGKangXi=1440.190, RSKangXi=187.8
298F6 CJK UNIFIED IDEOGRAPH-#298F6, IRGKangXi=1440.200, RSKangXi=187.8
298F7 CJK UNIFIED IDEOGRAPH-#298F7, IRGKangXi=1440.220, RSKangXi=187.8
298F8 CJK UNIFIED IDEOGRAPH-#298F8, IRGKangXi=1440.240, RSKangXi=187.8
298F9 CJK UNIFIED IDEOGRAPH-#298F9, IRGKangXi=1440.250, RSKangXi=187.8
298FA CJK UNIFIED IDEOGRAPH-#298FA, IRGKangXi=1440.290, RSKangXi=187.8
298FB CJK UNIFIED IDEOGRAPH-#298FB, IRGKangXi=1440.300, RSKangXi=187.8
298FC CJK UNIFIED IDEOGRAPH-#298FC, IRGKangXi=1440.330, RSKangXi=187.8
298FD CJK UNIFIED IDEOGRAPH-#298FD, IRGKangXi=1440.410, RSKangXi=187.8
298FE CJK UNIFIED IDEOGRAPH-#298FE, IRGKangXi=1441.040, RSKangXi=187.8
298FF CJK UNIFIED IDEOGRAPH-#298FF, IRGKangXi=1441.050, RSKangXi=187.8
29900 CJK UNIFIED IDEOGRAPH-#29900, IRGKangXi=1441.060, RSKangXi=187.8
29901 CJK UNIFIED IDEOGRAPH-#29901, IRGKangXi=1441.070, RSKangXi=187.8
29902 CJK UNIFIED IDEOGRAPH-#29902, IRGKangXi=1441.071, RSKangXi=187.8
29903 CJK UNIFIED IDEOGRAPH-#29903, IRGKangXi=1441.071, RSKangXi=187.8
29904 CJK UNIFIED IDEOGRAPH-#29904, IRGKangXi=1441.071, RSKangXi=187.8
29905 CJK UNIFIED IDEOGRAPH-#29905, IRGKangXi=1441.071, RSKangXi=187.8
29906 CJK UNIFIED IDEOGRAPH-#29906, IRGKangXi=1441.071, RSKangXi=187.8
29907 CJK UNIFIED IDEOGRAPH-#29907, IRGKangXi=1441.071, RSKangXi=187.8
29908 CJK UNIFIED IDEOGRAPH-#29908, IRGKangXi=1441.071, RSKangXi=187.8
29909 CJK UNIFIED IDEOGRAPH-#29909, IRGKangXi=1441.071, RSKangXi=187.8
2990A CJK UNIFIED IDEOGRAPH-#2990A, IRGKangXi=1441.071, RSKangXi=187.8
2990B CJK UNIFIED IDEOGRAPH-#2990B, IRGKangXi=1441.071, RSKangXi=187.8
2990C CJK UNIFIED IDEOGRAPH-#2990C, IRGKangXi=1441.071, RSKangXi=187.8
2990D CJK UNIFIED IDEOGRAPH-#2990D, IRGKangXi=1441.071, RSKangXi=187.8
2990E CJK UNIFIED IDEOGRAPH-#2990E, IRGKangXi=1441.071, RSKangXi=187.8
2990F CJK UNIFIED IDEOGRAPH-#2990F, IRGKangXi=1441.071, RSKangXi=187.8
29910 CJK UNIFIED IDEOGRAPH-#29910, IRGKangXi=1441.071, RSKangXi=187.8
29911 CJK UNIFIED IDEOGRAPH-#29911, IRGKangXi=1441.071, RSKangXi=187.8
29912 CJK UNIFIED IDEOGRAPH-#29912, IRGKangXi=1441.071, RSKangXi=187.8
29913 CJK UNIFIED IDEOGRAPH-#29913, IRGKangXi=1441.071, RSKangXi=187.8
29914 CJK UNIFIED IDEOGRAPH-#29914, IRGKangXi=1441.071, RSKangXi=187.8
29915 CJK UNIFIED IDEOGRAPH-#29915, IRGKangXi=1441.071, RSKangXi=187.8
29916 CJK UNIFIED IDEOGRAPH-#29916, IRGKangXi=1441.071, RSKangXi=187.8
29917 CJK UNIFIED IDEOGRAPH-#29917, IRGKangXi=1441.071, RSKangXi=187.9
29918 CJK UNIFIED IDEOGRAPH-#29918, IRGKangXi=1441.080, RSKangXi=187.9
29919 CJK UNIFIED IDEOGRAPH-#29919, IRGKangXi=1441.090, RSKangXi=187.9
2991A CJK UNIFIED IDEOGRAPH-#2991A, IRGKangXi=1441.110, RSKangXi=187.9
2991B CJK UNIFIED IDEOGRAPH-#2991B, IRGKangXi=1441.140, RSKangXi=187.9
2991C CJK UNIFIED IDEOGRAPH-#2991C, IRGKangXi=1441.150, RSKangXi=187.9
2991D CJK UNIFIED IDEOGRAPH-#2991D, IRGKangXi=1441.180, RSKangXi=187.9
2991E CJK UNIFIED IDEOGRAPH-#2991E, IRGKangXi=1441.220, RSKangXi=187.8
2991F CJK UNIFIED IDEOGRAPH-#2991F, IRGKangXi=1441.240, RSKangXi=187.9
29920 CJK UNIFIED IDEOGRAPH-#29920, IRGKangXi=1441.260, RSKangXi=187.9
29921 CJK UNIFIED IDEOGRAPH-#29921, IRGKangXi=1441.280, RSKangXi=187.9
29922 CJK UNIFIED IDEOGRAPH-#29922, IRGKangXi=1441.360, RSKangXi=187.9
29923 CJK UNIFIED IDEOGRAPH-#29923, IRGKangXi=1441.380, RSKangXi=187.9
29924 CJK UNIFIED IDEOGRAPH-#29924, IRGKangXi=1442.010, RSKangXi=187.9
29925 CJK UNIFIED IDEOGRAPH-#29925, IRGKangXi=1442.020, RSKangXi=187.9
29926 CJK UNIFIED IDEOGRAPH-#29926, IRGKangXi=1442.030, RSKangXi=187.9
29927 CJK UNIFIED IDEOGRAPH-#29927, IRGKangXi=1442.050, RSKangXi=187.9
29928 CJK UNIFIED IDEOGRAPH-#29928, IRGKangXi=1442.070, RSKangXi=187.9
29929 CJK UNIFIED IDEOGRAPH-#29929, IRGKangXi=1442.080, RSKangXi=187.9
2992A CJK UNIFIED IDEOGRAPH-#2992A, IRGKangXi=1442.090, RSKangXi=187.9
2992B CJK UNIFIED IDEOGRAPH-#2992B, IRGKangXi=1442.100, RSKangXi=187.9
2992C CJK UNIFIED IDEOGRAPH-#2992C, IRGKangXi=1442.110, RSKangXi=187.9
2992D CJK UNIFIED IDEOGRAPH-#2992D, IRGKangXi=1442.120, RSKangXi=187.9
2992E CJK UNIFIED IDEOGRAPH-#2992E, IRGKangXi=1442.121, RSKangXi=187.9
2992F CJK UNIFIED IDEOGRAPH-#2992F, IRGKangXi=1442.121, RSKangXi=187.9
29930 CJK UNIFIED IDEOGRAPH-#29930, IRGKangXi=1442.121, RSKangXi=187.9
29931 CJK UNIFIED IDEOGRAPH-#29931, IRGKangXi=1442.121, RSKangXi=187.9
29932 CJK UNIFIED IDEOGRAPH-#29932, IRGKangXi=1442.121, RSKangXi=187.9
29933 CJK UNIFIED IDEOGRAPH-#29933, IRGKangXi=1442.121, RSKangXi=187.9
29934 CJK UNIFIED IDEOGRAPH-#29934, IRGKangXi=1442.121, RSKangXi=187.9
29935 CJK UNIFIED IDEOGRAPH-#29935, IRGKangXi=1442.121, RSKangXi=187.9
29936 CJK UNIFIED IDEOGRAPH-#29936, IRGKangXi=1442.121, RSKangXi=187.9
29937 CJK UNIFIED IDEOGRAPH-#29937, IRGKangXi=1442.121, RSKangXi=187.7
29938 CJK UNIFIED IDEOGRAPH-#29938, IRGKangXi=1442.121, RSKangXi=187.9
29939 CJK UNIFIED IDEOGRAPH-#29939, IRGKangXi=1442.121, RSKangXi=187.9
2993A CJK UNIFIED IDEOGRAPH-#2993A, IRGKangXi=1442.121, RSKangXi=187.9
2993B CJK UNIFIED IDEOGRAPH-#2993B, IRGKangXi=1442.121, RSKangXi=187.9
2993C CJK UNIFIED IDEOGRAPH-#2993C, IRGKangXi=1442.121, RSKangXi=187.9
2993D CJK UNIFIED IDEOGRAPH-#2993D, IRGKangXi=1442.150, RSKangXi=187.10
2993E CJK UNIFIED IDEOGRAPH-#2993E, IRGKangXi=1442.160, RSKangXi=187.10
2993F CJK UNIFIED IDEOGRAPH-#2993F, IRGKangXi=1442.190, RSKangXi=187.10
29940 CJK UNIFIED IDEOGRAPH-#29940, IRGKangXi=1442.210, RSKangXi=187.10
29941 CJK UNIFIED IDEOGRAPH-#29941, IRGKangXi=1442.220, RSKangXi=187.10
29942 CJK UNIFIED IDEOGRAPH-#29942, IRGKangXi=1442.230, RSKangXi=187.10
29943 CJK UNIFIED IDEOGRAPH-#29943, IRGKangXi=1442.250, RSKangXi=187.10
29944 CJK UNIFIED IDEOGRAPH-#29944, IRGKangXi=1442.260, RSKangXi=187.10
29945 CJK UNIFIED IDEOGRAPH-#29945, IRGKangXi=1442.290, RSKangXi=187.10
29946 CJK UNIFIED IDEOGRAPH-#29946, IRGKangXi=1442.300, RSKangXi=187.10
29947 CJK UNIFIED IDEOGRAPH-#29947, IRGKangXi=1442.310, RSKangXi=187.10
29948 CJK UNIFIED IDEOGRAPH-#29948, IRGKangXi=1442.320, RSKangXi=187.10
29949 CJK UNIFIED IDEOGRAPH-#29949, IRGKangXi=1443.020, RSKangXi=187.10
2994A CJK UNIFIED IDEOGRAPH-#2994A, IRGKangXi=1443.040, RSKangXi=187.10
2994B CJK UNIFIED IDEOGRAPH-#2994B, IRGKangXi=1443.060, RSKangXi=187.10, Def{to gallop wildly; (Cant.) stupid}
2994C CJK UNIFIED IDEOGRAPH-#2994C, IRGKangXi=1443.070, RSKangXi=187.10
2994D CJK UNIFIED IDEOGRAPH-#2994D, IRGKangXi=1443.100, RSKangXi=187.10
2994E CJK UNIFIED IDEOGRAPH-#2994E, IRGKangXi=1443.140, RSKangXi=187.10
2994F CJK UNIFIED IDEOGRAPH-#2994F, IRGKangXi=1443.150, RSKangXi=187.10
29950 CJK UNIFIED IDEOGRAPH-#29950, IRGKangXi=1443.170, RSKangXi=187.10
29951 CJK UNIFIED IDEOGRAPH-#29951, IRGKangXi=1443.180, RSKangXi=187.10
29952 CJK UNIFIED IDEOGRAPH-#29952, IRGKangXi=1443.200, RSKangXi=187.10
29953 CJK UNIFIED IDEOGRAPH-#29953, IRGKangXi=1443.220, RSKangXi=187.10
29954 CJK UNIFIED IDEOGRAPH-#29954, IRGKangXi=1443.230, RSKangXi=187.10
29955 CJK UNIFIED IDEOGRAPH-#29955, IRGKangXi=1443.240, RSKangXi=187.10
29956 CJK UNIFIED IDEOGRAPH-#29956, IRGKangXi=1443.250, RSKangXi=187.10
29957 CJK UNIFIED IDEOGRAPH-#29957, IRGKangXi=1443.260, RSKangXi=187.10
29958 CJK UNIFIED IDEOGRAPH-#29958, IRGKangXi=1443.270, RSKangXi=187.10
29959 CJK UNIFIED IDEOGRAPH-#29959, IRGKangXi=1443.281, RSKangXi=187.10
2995A CJK UNIFIED IDEOGRAPH-#2995A, IRGKangXi=1443.281, RSKangXi=187.10
2995B CJK UNIFIED IDEOGRAPH-#2995B, IRGKangXi=1443.281, RSKangXi=187.10
2995C CJK UNIFIED IDEOGRAPH-#2995C, IRGKangXi=1443.281, RSKangXi=187.10
2995D CJK UNIFIED IDEOGRAPH-#2995D, IRGKangXi=1443.281, RSKangXi=187.10
2995E CJK UNIFIED IDEOGRAPH-#2995E, IRGKangXi=1443.281, RSKangXi=187.10
2995F CJK UNIFIED IDEOGRAPH-#2995F, IRGKangXi=1443.281, RSKangXi=187.10
29960 CJK UNIFIED IDEOGRAPH-#29960, IRGKangXi=1443.281, RSKangXi=187.10
29961 CJK UNIFIED IDEOGRAPH-#29961, IRGKangXi=1443.281, RSKangXi=187.10
29962 CJK UNIFIED IDEOGRAPH-#29962, IRGKangXi=1443.281, RSKangXi=187.10
29963 CJK UNIFIED IDEOGRAPH-#29963, IRGKangXi=1443.281, RSKangXi=187.10
29964 CJK UNIFIED IDEOGRAPH-#29964, IRGKangXi=1443.281, RSKangXi=187.10
29965 CJK UNIFIED IDEOGRAPH-#29965, IRGKangXi=1443.281, RSKangXi=187.10
29966 CJK UNIFIED IDEOGRAPH-#29966, IRGKangXi=1443.281, RSKangXi=187.10
29967 CJK UNIFIED IDEOGRAPH-#29967, IRGKangXi=1443.281, RSKangXi=187.10
29968 CJK UNIFIED IDEOGRAPH-#29968, IRGKangXi=1443.281, RSKangXi=187.10
29969 CJK UNIFIED IDEOGRAPH-#29969, IRGKangXi=1443.281, RSKangXi=187.10
2996A CJK UNIFIED IDEOGRAPH-#2996A, IRGKangXi=1443.281, RSKangXi=187.10
2996B CJK UNIFIED IDEOGRAPH-#2996B, IRGKangXi=1444.020, RSKangXi=187.11
2996C CJK UNIFIED IDEOGRAPH-#2996C, IRGKangXi=1444.050, RSKangXi=187.11
2996D CJK UNIFIED IDEOGRAPH-#2996D, IRGKangXi=1444.060, RSKangXi=187.11
2996E CJK UNIFIED IDEOGRAPH-#2996E, IRGKangXi=1444.070, RSKangXi=187.11
2996F CJK UNIFIED IDEOGRAPH-#2996F, IRGKangXi=1444.100, RSKangXi=187.11
29970 CJK UNIFIED IDEOGRAPH-#29970, IRGKangXi=1444.130, RSKangXi=187.11
29971 CJK UNIFIED IDEOGRAPH-#29971, IRGKangXi=1444.170, RSKangXi=187.11
29972 CJK UNIFIED IDEOGRAPH-#29972, IRGKangXi=1444.200, RSKangXi=187.11
29973 CJK UNIFIED IDEOGRAPH-#29973, IRGKangXi=1444.290, RSKangXi=187.11
29974 CJK UNIFIED IDEOGRAPH-#29974, IRGKangXi=1444.300, RSKangXi=187.11
29975 CJK UNIFIED IDEOGRAPH-#29975, IRGKangXi=1444.301, RSKangXi=187.11
29976 CJK UNIFIED IDEOGRAPH-#29976, IRGKangXi=1444.301, RSKangXi=187.11
29977 CJK UNIFIED IDEOGRAPH-#29977, IRGKangXi=1444.301, RSKangXi=187.11
29978 CJK UNIFIED IDEOGRAPH-#29978, IRGKangXi=1444.301, RSKangXi=187.11
29979 CJK UNIFIED IDEOGRAPH-#29979, IRGKangXi=1444.301, RSKangXi=187.11
2997A CJK UNIFIED IDEOGRAPH-#2997A, IRGKangXi=1444.301, RSKangXi=187.11
2997B CJK UNIFIED IDEOGRAPH-#2997B, IRGKangXi=1444.301, RSKangXi=187.11
2997C CJK UNIFIED IDEOGRAPH-#2997C, IRGKangXi=1444.301, RSKangXi=187.11
2997D CJK UNIFIED IDEOGRAPH-#2997D, IRGKangXi=1444.301, RSKangXi=187.11
2997E CJK UNIFIED IDEOGRAPH-#2997E, IRGKangXi=1444.301, RSKangXi=187.11
2997F CJK UNIFIED IDEOGRAPH-#2997F, IRGKangXi=1444.301, RSKangXi=187.11
29980 CJK UNIFIED IDEOGRAPH-#29980, IRGKangXi=1444.301, RSKangXi=187.11
29981 CJK UNIFIED IDEOGRAPH-#29981, IRGKangXi=1444.301, RSKangXi=187.11
29982 CJK UNIFIED IDEOGRAPH-#29982, IRGKangXi=1444.320, RSKangXi=187.12
29983 CJK UNIFIED IDEOGRAPH-#29983, IRGKangXi=1444.330, RSKangXi=187.12
29984 CJK UNIFIED IDEOGRAPH-#29984, IRGKangXi=1445.050, RSKangXi=187.12
29985 CJK UNIFIED IDEOGRAPH-#29985, IRGKangXi=1445.060, RSKangXi=187.12
29986 CJK UNIFIED IDEOGRAPH-#29986, IRGKangXi=1445.070, RSKangXi=187.12
29987 CJK UNIFIED IDEOGRAPH-#29987, IRGKangXi=1445.140, RSKangXi=187.12
29988 CJK UNIFIED IDEOGRAPH-#29988, IRGKangXi=1445.150, RSKangXi=187.12
29989 CJK UNIFIED IDEOGRAPH-#29989, IRGKangXi=1445.160, RSKangXi=187.12
2998A CJK UNIFIED IDEOGRAPH-#2998A, IRGKangXi=1445.170, RSKangXi=187.12
2998B CJK UNIFIED IDEOGRAPH-#2998B, IRGKangXi=1445.220, RSKangXi=187.12
2998C CJK UNIFIED IDEOGRAPH-#2998C, IRGKangXi=1445.230, RSKangXi=187.12
2998D CJK UNIFIED IDEOGRAPH-#2998D, IRGKangXi=1445.260, RSKangXi=187.12
2998E CJK UNIFIED IDEOGRAPH-#2998E, IRGKangXi=1445.270, RSKangXi=187.12
2998F CJK UNIFIED IDEOGRAPH-#2998F, IRGKangXi=1445.280, RSKangXi=187.12
29990 CJK UNIFIED IDEOGRAPH-#29990, IRGKangXi=1445.290, RSKangXi=187.12
29991 CJK UNIFIED IDEOGRAPH-#29991, IRGKangXi=1445.300, RSKangXi=187.12
29992 CJK UNIFIED IDEOGRAPH-#29992, IRGKangXi=1445.301, RSKangXi=187.12
29993 CJK UNIFIED IDEOGRAPH-#29993, IRGKangXi=1445.301, RSKangXi=187.12
29994 CJK UNIFIED IDEOGRAPH-#29994, IRGKangXi=1445.301, RSKangXi=187.12
29995 CJK UNIFIED IDEOGRAPH-#29995, IRGKangXi=1445.301, RSKangXi=187.12
29996 CJK UNIFIED IDEOGRAPH-#29996, IRGKangXi=1445.301, RSKangXi=187.12
29997 CJK UNIFIED IDEOGRAPH-#29997, IRGKangXi=1445.301, RSKangXi=187.12
29998 CJK UNIFIED IDEOGRAPH-#29998, IRGKangXi=1445.301, RSKangXi=187.12
29999 CJK UNIFIED IDEOGRAPH-#29999, IRGKangXi=1445.301, RSKangXi=187.12
2999A CJK UNIFIED IDEOGRAPH-#2999A, IRGKangXi=1445.301, RSKangXi=187.12
2999B CJK UNIFIED IDEOGRAPH-#2999B, IRGKangXi=1445.301, RSKangXi=187.12
2999C CJK UNIFIED IDEOGRAPH-#2999C, IRGKangXi=1445.301, RSKangXi=187.12
2999D CJK UNIFIED IDEOGRAPH-#2999D, IRGKangXi=1445.301, RSKangXi=187.12
2999E CJK UNIFIED IDEOGRAPH-#2999E, IRGKangXi=1445.310, RSKangXi=187.13
2999F CJK UNIFIED IDEOGRAPH-#2999F, IRGKangXi=1445.320, RSKangXi=187.13
299A0 CJK UNIFIED IDEOGRAPH-#299A0, IRGKangXi=1445.330, RSKangXi=187.13
299A1 CJK UNIFIED IDEOGRAPH-#299A1, IRGKangXi=1445.340, RSKangXi=187.13
299A2 CJK UNIFIED IDEOGRAPH-#299A2, IRGKangXi=1445.370, RSKangXi=187.13, Def{to provide for; anxious; danger}
299A3 CJK UNIFIED IDEOGRAPH-#299A3, IRGKangXi=1445.390, RSKangXi=187.13
299A4 CJK UNIFIED IDEOGRAPH-#299A4, IRGKangXi=1446.030, RSKangXi=187.13
299A5 CJK UNIFIED IDEOGRAPH-#299A5, IRGKangXi=1446.070, RSKangXi=187.13
299A6 CJK UNIFIED IDEOGRAPH-#299A6, IRGKangXi=1446.080, RSKangXi=187.13
299A7 CJK UNIFIED IDEOGRAPH-#299A7, IRGKangXi=1446.090, RSKangXi=187.13
299A8 CJK UNIFIED IDEOGRAPH-#299A8, IRGKangXi=1446.100, RSKangXi=187.13
299A9 CJK UNIFIED IDEOGRAPH-#299A9, IRGKangXi=1446.101, RSKangXi=187.13
299AA CJK UNIFIED IDEOGRAPH-#299AA, IRGKangXi=1446.101, RSKangXi=187.13
299AB CJK UNIFIED IDEOGRAPH-#299AB, IRGKangXi=1446.101, RSKangXi=187.13
299AC CJK UNIFIED IDEOGRAPH-#299AC, IRGKangXi=1446.101, RSKangXi=187.13
299AD CJK UNIFIED IDEOGRAPH-#299AD, IRGKangXi=1446.101, RSKangXi=187.13
299AE CJK UNIFIED IDEOGRAPH-#299AE, IRGKangXi=1446.101, RSKangXi=187.13
299AF CJK UNIFIED IDEOGRAPH-#299AF, IRGKangXi=1446.101, RSKangXi=187.13
299B0 CJK UNIFIED IDEOGRAPH-#299B0, IRGKangXi=1446.101, RSKangXi=187.13
299B1 CJK UNIFIED IDEOGRAPH-#299B1, IRGKangXi=1446.101, RSKangXi=187.13
299B2 CJK UNIFIED IDEOGRAPH-#299B2, IRGKangXi=1446.101, RSKangXi=187.13
299B3 CJK UNIFIED IDEOGRAPH-#299B3, IRGKangXi=1446.101, RSKangXi=187.13
299B4 CJK UNIFIED IDEOGRAPH-#299B4, IRGKangXi=1446.101, RSKangXi=187.13
299B5 CJK UNIFIED IDEOGRAPH-#299B5, IRGKangXi=1446.101, RSKangXi=187.13
299B6 CJK UNIFIED IDEOGRAPH-#299B6, IRGKangXi=1446.140, RSKangXi=187.14
299B7 CJK UNIFIED IDEOGRAPH-#299B7, IRGKangXi=1446.150, RSKangXi=187.14
299B8 CJK UNIFIED IDEOGRAPH-#299B8, IRGKangXi=1446.160, RSKangXi=187.14
299B9 CJK UNIFIED IDEOGRAPH-#299B9, IRGKangXi=1446.170, RSKangXi=187.14
299BA CJK UNIFIED IDEOGRAPH-#299BA, IRGKangXi=1446.180, RSKangXi=187.14
299BB CJK UNIFIED IDEOGRAPH-#299BB, IRGKangXi=1446.220, RSKangXi=187.14
299BC CJK UNIFIED IDEOGRAPH-#299BC, IRGKangXi=1446.230, RSKangXi=187.14
299BD CJK UNIFIED IDEOGRAPH-#299BD, IRGKangXi=1446.240, RSKangXi=187.14
299BE CJK UNIFIED IDEOGRAPH-#299BE, IRGKangXi=1446.250, RSKangXi=187.14
299BF CJK UNIFIED IDEOGRAPH-#299BF, IRGKangXi=1446.251, RSKangXi=187.14
299C0 CJK UNIFIED IDEOGRAPH-#299C0, IRGKangXi=1446.251, RSKangXi=187.14
299C1 CJK UNIFIED IDEOGRAPH-#299C1, IRGKangXi=1446.251, RSKangXi=187.14
299C2 CJK UNIFIED IDEOGRAPH-#299C2, IRGKangXi=1446.260, RSKangXi=187.15
299C3 CJK UNIFIED IDEOGRAPH-#299C3, IRGKangXi=1446.270, RSKangXi=187.15
299C4 CJK UNIFIED IDEOGRAPH-#299C4, IRGKangXi=1446.280, RSKangXi=187.15
299C5 CJK UNIFIED IDEOGRAPH-#299C5, IRGKangXi=1446.290, RSKangXi=187.15
299C6 CJK UNIFIED IDEOGRAPH-#299C6, IRGKangXi=1446.300, RSKangXi=187.15
299C7 CJK UNIFIED IDEOGRAPH-#299C7, IRGKangXi=1446.310, RSKangXi=187.15
299C8 CJK UNIFIED IDEOGRAPH-#299C8, IRGKangXi=1446.320, RSKangXi=187.15
299C9 CJK UNIFIED IDEOGRAPH-#299C9, IRGKangXi=1446.330, RSKangXi=187.15
299CA CJK UNIFIED IDEOGRAPH-#299CA, IRGKangXi=1446.340, RSKangXi=187.15
299CB CJK UNIFIED IDEOGRAPH-#299CB, IRGKangXi=1446.360, RSKangXi=187.15
299CC CJK UNIFIED IDEOGRAPH-#299CC, IRGKangXi=1446.361, RSKangXi=187.15
299CD CJK UNIFIED IDEOGRAPH-#299CD, IRGKangXi=1446.361, RSKangXi=187.15
299CE CJK UNIFIED IDEOGRAPH-#299CE, IRGKangXi=1446.410, RSKangXi=187.15
299CF CJK UNIFIED IDEOGRAPH-#299CF, IRGKangXi=1446.420, RSKangXi=187.16
299D0 CJK UNIFIED IDEOGRAPH-#299D0, IRGKangXi=1447.020, RSKangXi=187.16
299D1 CJK UNIFIED IDEOGRAPH-#299D1, IRGKangXi=1447.021, RSKangXi=187.16
299D2 CJK UNIFIED IDEOGRAPH-#299D2, IRGKangXi=1447.021, RSKangXi=187.16
299D3 CJK UNIFIED IDEOGRAPH-#299D3, IRGKangXi=1447.021, RSKangXi=187.16
299D4 CJK UNIFIED IDEOGRAPH-#299D4, IRGKangXi=1447.090, RSKangXi=187.17
299D5 CJK UNIFIED IDEOGRAPH-#299D5, IRGKangXi=1447.100, RSKangXi=187.17
299D6 CJK UNIFIED IDEOGRAPH-#299D6, IRGKangXi=1447.110, RSKangXi=187.17
299D7 CJK UNIFIED IDEOGRAPH-#299D7, IRGKangXi=1447.111, RSKangXi=187.17
299D8 CJK UNIFIED IDEOGRAPH-#299D8, IRGKangXi=1447.140, RSKangXi=187.18
299D9 CJK UNIFIED IDEOGRAPH-#299D9, IRGKangXi=1447.160, RSKangXi=187.18
299DA CJK UNIFIED IDEOGRAPH-#299DA, IRGKangXi=1447.170, RSKangXi=187.18
299DB CJK UNIFIED IDEOGRAPH-#299DB, IRGKangXi=1447.171, RSKangXi=187.18
299DC CJK UNIFIED IDEOGRAPH-#299DC, IRGKangXi=1447.171, RSKangXi=187.18
299DD CJK UNIFIED IDEOGRAPH-#299DD, IRGKangXi=1447.171, RSKangXi=187.18
299DE CJK UNIFIED IDEOGRAPH-#299DE, IRGKangXi=1447.190, RSKangXi=187.18
299DF CJK UNIFIED IDEOGRAPH-#299DF, IRGKangXi=1447.191, RSKangXi=187.19
299E0 CJK UNIFIED IDEOGRAPH-#299E0, IRGKangXi=1447.191, RSKangXi=187.19
299E1 CJK UNIFIED IDEOGRAPH-#299E1, IRGKangXi=1447.200, RSKangXi=187.20
299E2 CJK UNIFIED IDEOGRAPH-#299E2, IRGKangXi=1447.210, RSKangXi=187.20
299E3 CJK UNIFIED IDEOGRAPH-#299E3, IRGKangXi=1447.230, RSKangXi=187.21
299E4 CJK UNIFIED IDEOGRAPH-#299E4, IRGKangXi=1447.231, RSKangXi=187.21
299E5 CJK UNIFIED IDEOGRAPH-#299E5, IRGKangXi=1447.241, RSKangXi=187.26
299E6 CJK UNIFIED IDEOGRAPH-#299E6, IRGKangXi=1447.241, RSKangXi=187.4
299E7 CJK UNIFIED IDEOGRAPH-#299E7, IRGKangXi=1447.241, RSKangXi=187.5
299E8 CJK UNIFIED IDEOGRAPH-#299E8, IRGKangXi=1447.241, RSKangXi=187.5
299E9 CJK UNIFIED IDEOGRAPH-#299E9, IRGKangXi=1447.241, RSKangXi=187.5
299EA CJK UNIFIED IDEOGRAPH-#299EA, IRGKangXi=1447.241, RSKangXi=187.5
299EB CJK UNIFIED IDEOGRAPH-#299EB, IRGKangXi=1447.241, RSKangXi=187.5
299EC CJK UNIFIED IDEOGRAPH-#299EC, IRGKangXi=1447.241, RSKangXi=187.5
299ED CJK UNIFIED IDEOGRAPH-#299ED, IRGKangXi=1447.241, RSKangXi=187.5
299EE CJK UNIFIED IDEOGRAPH-#299EE, IRGKangXi=1447.241, RSKangXi=187.6
299EF CJK UNIFIED IDEOGRAPH-#299EF, IRGKangXi=1447.241, RSKangXi=187.5
299F0 CJK UNIFIED IDEOGRAPH-#299F0, IRGKangXi=1447.241, RSKangXi=187.6
299F1 CJK UNIFIED IDEOGRAPH-#299F1, IRGKangXi=1447.241, RSKangXi=187.6
299F2 CJK UNIFIED IDEOGRAPH-#299F2, IRGKangXi=1447.241, RSKangXi=187.6
299F3 CJK UNIFIED IDEOGRAPH-#299F3, IRGKangXi=1447.241, RSKangXi=187.6
299F4 CJK UNIFIED IDEOGRAPH-#299F4, IRGKangXi=1447.241, RSKangXi=187.6
299F5 CJK UNIFIED IDEOGRAPH-#299F5, IRGKangXi=1447.241, RSKangXi=187.6
299F6 CJK UNIFIED IDEOGRAPH-#299F6, IRGKangXi=1447.241, RSKangXi=187.6
299F7 CJK UNIFIED IDEOGRAPH-#299F7, IRGKangXi=1447.241, RSKangXi=187.7
299F8 CJK UNIFIED IDEOGRAPH-#299F8, IRGKangXi=1447.241, RSKangXi=187.7
299F9 CJK UNIFIED IDEOGRAPH-#299F9, IRGKangXi=1447.241, RSKangXi=187.7
299FA CJK UNIFIED IDEOGRAPH-#299FA, IRGKangXi=1447.241, RSKangXi=187.7
299FB CJK UNIFIED IDEOGRAPH-#299FB, IRGKangXi=1447.241, RSKangXi=187.8
299FC CJK UNIFIED IDEOGRAPH-#299FC, IRGKangXi=1447.241, RSKangXi=187.8
299FD CJK UNIFIED IDEOGRAPH-#299FD, IRGKangXi=1447.241, RSKangXi=187.8
299FE CJK UNIFIED IDEOGRAPH-#299FE, IRGKangXi=1447.241, RSKangXi=187.9
299FF CJK UNIFIED IDEOGRAPH-#299FF, IRGKangXi=1447.241, RSKangXi=187.9
29A00 CJK UNIFIED IDEOGRAPH-#29A00, IRGKangXi=1447.241, RSKangXi=187.9
29A01 CJK UNIFIED IDEOGRAPH-#29A01, IRGKangXi=1447.241, RSKangXi=187.9
29A02 CJK UNIFIED IDEOGRAPH-#29A02, IRGKangXi=1447.241, RSKangXi=187.9
29A03 CJK UNIFIED IDEOGRAPH-#29A03, IRGKangXi=1447.241, RSKangXi=187.9
29A04 CJK UNIFIED IDEOGRAPH-#29A04, IRGKangXi=1447.241, RSKangXi=187.10
29A05 CJK UNIFIED IDEOGRAPH-#29A05, IRGKangXi=1447.241, RSKangXi=187.9
29A06 CJK UNIFIED IDEOGRAPH-#29A06, IRGKangXi=1447.241, RSKangXi=187.9
29A07 CJK UNIFIED IDEOGRAPH-#29A07, IRGKangXi=1447.241, RSKangXi=187.9
29A08 CJK UNIFIED IDEOGRAPH-#29A08, IRGKangXi=1447.241, RSKangXi=187.9
29A09 CJK UNIFIED IDEOGRAPH-#29A09, IRGKangXi=1447.241, RSKangXi=187.9
29A0A CJK UNIFIED IDEOGRAPH-#29A0A, IRGKangXi=1447.241, RSKangXi=187.9
29A0B CJK UNIFIED IDEOGRAPH-#29A0B, IRGKangXi=1447.241, RSKangXi=187.10
29A0C CJK UNIFIED IDEOGRAPH-#29A0C, IRGKangXi=1447.241, RSKangXi=187.10
29A0D CJK UNIFIED IDEOGRAPH-#29A0D, IRGKangXi=1447.241, RSKangXi=187.10
29A0E CJK UNIFIED IDEOGRAPH-#29A0E, IRGKangXi=1447.241, RSKangXi=187.12
29A0F CJK UNIFIED IDEOGRAPH-#29A0F, IRGKangXi=1447.241, RSKangXi=187.12
29A10 CJK UNIFIED IDEOGRAPH-#29A10, IRGKangXi=1447.241, RSKangXi=187.15
29A11 CJK UNIFIED IDEOGRAPH-#29A11, IRGKangXi=1447.270, RSKangXi=188.2
29A12 CJK UNIFIED IDEOGRAPH-#29A12, IRGKangXi=1447.280, RSKangXi=188.2
29A13 CJK UNIFIED IDEOGRAPH-#29A13, IRGKangXi=1448.011, RSKangXi=188.2
29A14 CJK UNIFIED IDEOGRAPH-#29A14, IRGKangXi=1448.040, RSKangXi=188.3
29A15 CJK UNIFIED IDEOGRAPH-#29A15, IRGKangXi=1448.070, RSKangXi=188.3
29A16 CJK UNIFIED IDEOGRAPH-#29A16, IRGKangXi=1448.090, RSKangXi=188.3
29A17 CJK UNIFIED IDEOGRAPH-#29A17, IRGKangXi=1448.100, RSKangXi=188.3
29A18 CJK UNIFIED IDEOGRAPH-#29A18, IRGKangXi=1448.101, RSKangXi=188.3, Def{arm, side}
29A19 CJK UNIFIED IDEOGRAPH-#29A19, IRGKangXi=1448.101, RSKangXi=188.3
29A1A CJK UNIFIED IDEOGRAPH-#29A1A, IRGKangXi=1448.101, RSKangXi=188.3
29A1B CJK UNIFIED IDEOGRAPH-#29A1B, IRGKangXi=1448.101, RSKangXi=188.3
29A1C CJK UNIFIED IDEOGRAPH-#29A1C, IRGKangXi=1448.110, RSKangXi=188.4
29A1D CJK UNIFIED IDEOGRAPH-#29A1D, IRGKangXi=1448.120, RSKangXi=188.4
29A1E CJK UNIFIED IDEOGRAPH-#29A1E, IRGKangXi=1448.130, RSKangXi=188.4
29A1F CJK UNIFIED IDEOGRAPH-#29A1F, IRGKangXi=1448.140, RSKangXi=188.4
29A20 CJK UNIFIED IDEOGRAPH-#29A20, IRGKangXi=1448.150, RSKangXi=188.4
29A21 CJK UNIFIED IDEOGRAPH-#29A21, IRGKangXi=1448.190, RSKangXi=188.4
29A22 CJK UNIFIED IDEOGRAPH-#29A22, IRGKangXi=1448.220, RSKangXi=188.4
29A23 CJK UNIFIED IDEOGRAPH-#29A23, IRGKangXi=1448.230, RSKangXi=188.4
29A24 CJK UNIFIED IDEOGRAPH-#29A24, IRGKangXi=1448.240, RSKangXi=188.4
29A25 CJK UNIFIED IDEOGRAPH-#29A25, IRGKangXi=1448.241, RSKangXi=188.4
29A26 CJK UNIFIED IDEOGRAPH-#29A26, IRGKangXi=1448.241, RSKangXi=188.4
29A27 CJK UNIFIED IDEOGRAPH-#29A27, IRGKangXi=1448.241, RSKangXi=188.4
29A28 CJK UNIFIED IDEOGRAPH-#29A28, IRGKangXi=1448.241, RSKangXi=188.4
29A29 CJK UNIFIED IDEOGRAPH-#29A29, IRGKangXi=1448.241, RSKangXi=188.4
29A2A CJK UNIFIED IDEOGRAPH-#29A2A, IRGKangXi=1448.241, RSKangXi=188.4
29A2B CJK UNIFIED IDEOGRAPH-#29A2B, IRGKangXi=1448.241, RSKangXi=188.4
29A2C CJK UNIFIED IDEOGRAPH-#29A2C, IRGKangXi=1448.250, RSKangXi=188.5
29A2D CJK UNIFIED IDEOGRAPH-#29A2D, IRGKangXi=1448.260, RSKangXi=188.5, Def{stiffness in the joints}
29A2E CJK UNIFIED IDEOGRAPH-#29A2E, IRGKangXi=1448.270, RSKangXi=188.5
29A2F CJK UNIFIED IDEOGRAPH-#29A2F, IRGKangXi=1448.280, RSKangXi=188.5
29A30 CJK UNIFIED IDEOGRAPH-#29A30, IRGKangXi=1448.290, RSKangXi=188.5
29A31 CJK UNIFIED IDEOGRAPH-#29A31, IRGKangXi=1448.360, RSKangXi=188.5
29A32 CJK UNIFIED IDEOGRAPH-#29A32, IRGKangXi=1448.370, RSKangXi=188.5
29A33 CJK UNIFIED IDEOGRAPH-#29A33, IRGKangXi=1448.400, RSKangXi=188.5
29A34 CJK UNIFIED IDEOGRAPH-#29A34, IRGKangXi=1448.410, RSKangXi=188.5
29A35 CJK UNIFIED IDEOGRAPH-#29A35, IRGKangXi=1448.450, RSKangXi=188.5
29A36 CJK UNIFIED IDEOGRAPH-#29A36, IRGKangXi=1448.460, RSKangXi=188.5
29A37 CJK UNIFIED IDEOGRAPH-#29A37, IRGKangXi=1448.470, RSKangXi=188.5
29A38 CJK UNIFIED IDEOGRAPH-#29A38, IRGKangXi=1448.480, RSKangXi=188.5
29A39 CJK UNIFIED IDEOGRAPH-#29A39, IRGKangXi=1448.481, RSKangXi=188.5
29A3A CJK UNIFIED IDEOGRAPH-#29A3A, IRGKangXi=1448.481, RSKangXi=188.5
29A3B CJK UNIFIED IDEOGRAPH-#29A3B, IRGKangXi=1448.481, RSKangXi=188.5
29A3C CJK UNIFIED IDEOGRAPH-#29A3C, IRGKangXi=1448.481, RSKangXi=188.5
29A3D CJK UNIFIED IDEOGRAPH-#29A3D, IRGKangXi=1449.040, RSKangXi=188.6
29A3E CJK UNIFIED IDEOGRAPH-#29A3E, IRGKangXi=1449.050, RSKangXi=188.6
29A3F CJK UNIFIED IDEOGRAPH-#29A3F, IRGKangXi=1449.090, RSKangXi=188.6
29A40 CJK UNIFIED IDEOGRAPH-#29A40, IRGKangXi=1449.120, RSKangXi=188.6
29A41 CJK UNIFIED IDEOGRAPH-#29A41, IRGKangXi=1449.140, RSKangXi=188.6
29A42 CJK UNIFIED IDEOGRAPH-#29A42, IRGKangXi=1449.150, RSKangXi=188.6
29A43 CJK UNIFIED IDEOGRAPH-#29A43, IRGKangXi=1449.160, RSKangXi=188.6
29A44 CJK UNIFIED IDEOGRAPH-#29A44, IRGKangXi=1449.161, RSKangXi=188.6
29A45 CJK UNIFIED IDEOGRAPH-#29A45, IRGKangXi=1449.161, RSKangXi=188.6
29A46 CJK UNIFIED IDEOGRAPH-#29A46, IRGKangXi=1449.161, RSKangXi=188.6
29A47 CJK UNIFIED IDEOGRAPH-#29A47, IRGKangXi=1449.161, RSKangXi=188.6
29A48 CJK UNIFIED IDEOGRAPH-#29A48, IRGKangXi=1449.161, RSKangXi=188.6
29A49 CJK UNIFIED IDEOGRAPH-#29A49, IRGKangXi=1449.180, RSKangXi=188.7
29A4A CJK UNIFIED IDEOGRAPH-#29A4A, IRGKangXi=1449.210, RSKangXi=188.7
29A4B CJK UNIFIED IDEOGRAPH-#29A4B, IRGKangXi=1449.230, RSKangXi=188.7
29A4C CJK UNIFIED IDEOGRAPH-#29A4C, IRGKangXi=1449.250, RSKangXi=188.7
29A4D CJK UNIFIED IDEOGRAPH-#29A4D, IRGKangXi=1449.260, RSKangXi=188.7, Def{(Cant.) ribs, rib-cage}
29A4E CJK UNIFIED IDEOGRAPH-#29A4E, IRGKangXi=1449.300, RSKangXi=188.7
29A4F CJK UNIFIED IDEOGRAPH-#29A4F, IRGKangXi=1449.310, RSKangXi=188.7
29A50 CJK UNIFIED IDEOGRAPH-#29A50, IRGKangXi=1449.311, RSKangXi=188.7
29A51 CJK UNIFIED IDEOGRAPH-#29A51, IRGKangXi=1449.311, RSKangXi=188.7
29A52 CJK UNIFIED IDEOGRAPH-#29A52, IRGKangXi=1449.311, RSKangXi=188.7
29A53 CJK UNIFIED IDEOGRAPH-#29A53, IRGKangXi=1449.311, RSKangXi=188.7
29A54 CJK UNIFIED IDEOGRAPH-#29A54, IRGKangXi=1449.311, RSKangXi=188.7
29A55 CJK UNIFIED IDEOGRAPH-#29A55, IRGKangXi=1449.311, RSKangXi=188.7
29A56 CJK UNIFIED IDEOGRAPH-#29A56, IRGKangXi=1449.311, RSKangXi=188.7
29A57 CJK UNIFIED IDEOGRAPH-#29A57, IRGKangXi=1449.320, RSKangXi=188.8
29A58 CJK UNIFIED IDEOGRAPH-#29A58, IRGKangXi=1449.330, RSKangXi=188.8
29A59 CJK UNIFIED IDEOGRAPH-#29A59, IRGKangXi=1449.360, RSKangXi=188.8
29A5A CJK UNIFIED IDEOGRAPH-#29A5A, IRGKangXi=1449.370, RSKangXi=188.8
29A5B CJK UNIFIED IDEOGRAPH-#29A5B, IRGKangXi=1449.380, RSKangXi=188.8
29A5C CJK UNIFIED IDEOGRAPH-#29A5C, IRGKangXi=1449.400, RSKangXi=188.8
29A5D CJK UNIFIED IDEOGRAPH-#29A5D, IRGKangXi=1449.410, RSKangXi=188.8
29A5E CJK UNIFIED IDEOGRAPH-#29A5E, IRGKangXi=1449.430, RSKangXi=188.8
29A5F CJK UNIFIED IDEOGRAPH-#29A5F, IRGKangXi=1449.440, RSKangXi=188.8
29A60 CJK UNIFIED IDEOGRAPH-#29A60, IRGKangXi=1449.450, RSKangXi=188.8
29A61 CJK UNIFIED IDEOGRAPH-#29A61, IRGKangXi=1450.010, RSKangXi=188.8
29A62 CJK UNIFIED IDEOGRAPH-#29A62, IRGKangXi=1450.020, RSKangXi=188.8
29A63 CJK UNIFIED IDEOGRAPH-#29A63, IRGKangXi=1450.030, RSKangXi=188.8
29A64 CJK UNIFIED IDEOGRAPH-#29A64, IRGKangXi=1450.031, RSKangXi=188.8
29A65 CJK UNIFIED IDEOGRAPH-#29A65, IRGKangXi=1450.031, RSKangXi=188.8
29A66 CJK UNIFIED IDEOGRAPH-#29A66, IRGKangXi=1450.031, RSKangXi=188.8
29A67 CJK UNIFIED IDEOGRAPH-#29A67, IRGKangXi=1450.031, RSKangXi=188.8
29A68 CJK UNIFIED IDEOGRAPH-#29A68, IRGKangXi=1450.031, RSKangXi=188.8
29A69 CJK UNIFIED IDEOGRAPH-#29A69, IRGKangXi=1450.031, RSKangXi=188.8
29A6A CJK UNIFIED IDEOGRAPH-#29A6A, IRGKangXi=1450.031, RSKangXi=188.8
29A6B CJK UNIFIED IDEOGRAPH-#29A6B, IRGKangXi=1450.031, RSKangXi=188.8
29A6C CJK UNIFIED IDEOGRAPH-#29A6C, IRGKangXi=1450.031, RSKangXi=188.8
29A6D CJK UNIFIED IDEOGRAPH-#29A6D, IRGKangXi=1450.050, RSKangXi=188.9
29A6E CJK UNIFIED IDEOGRAPH-#29A6E, IRGKangXi=1450.060, RSKangXi=188.9
29A6F CJK UNIFIED IDEOGRAPH-#29A6F, IRGKangXi=1450.070, RSKangXi=188.9
29A70 CJK UNIFIED IDEOGRAPH-#29A70, IRGKangXi=1450.080, RSKangXi=188.9
29A71 CJK UNIFIED IDEOGRAPH-#29A71, IRGKangXi=1450.100, RSKangXi=188.9
29A72 CJK UNIFIED IDEOGRAPH-#29A72, IRGKangXi=1450.130, RSKangXi=188.9
29A73 CJK UNIFIED IDEOGRAPH-#29A73, IRGKangXi=1450.140, RSKangXi=188.9
29A74 CJK UNIFIED IDEOGRAPH-#29A74, IRGKangXi=1450.150, RSKangXi=188.9
29A75 CJK UNIFIED IDEOGRAPH-#29A75, IRGKangXi=1450.160, RSKangXi=188.9
29A76 CJK UNIFIED IDEOGRAPH-#29A76, IRGKangXi=1450.180, RSKangXi=188.9
29A77 CJK UNIFIED IDEOGRAPH-#29A77, IRGKangXi=1450.181, RSKangXi=188.9
29A78 CJK UNIFIED IDEOGRAPH-#29A78, IRGKangXi=1450.181, RSKangXi=188.9
29A79 CJK UNIFIED IDEOGRAPH-#29A79, IRGKangXi=1450.181, RSKangXi=188.9
29A7A CJK UNIFIED IDEOGRAPH-#29A7A, IRGKangXi=1450.181, RSKangXi=188.9
29A7B CJK UNIFIED IDEOGRAPH-#29A7B, IRGKangXi=1450.181, RSKangXi=188.9
29A7C CJK UNIFIED IDEOGRAPH-#29A7C, IRGKangXi=1450.181, RSKangXi=188.9
29A7D CJK UNIFIED IDEOGRAPH-#29A7D, IRGKangXi=1450.181, RSKangXi=188.9
29A7E CJK UNIFIED IDEOGRAPH-#29A7E, IRGKangXi=1450.181, RSKangXi=188.9
29A7F CJK UNIFIED IDEOGRAPH-#29A7F, IRGKangXi=1450.181, RSKangXi=188.9
29A80 CJK UNIFIED IDEOGRAPH-#29A80, IRGKangXi=1450.200, RSKangXi=188.10
29A81 CJK UNIFIED IDEOGRAPH-#29A81, IRGKangXi=1450.220, RSKangXi=188.10
29A82 CJK UNIFIED IDEOGRAPH-#29A82, IRGKangXi=1450.230, RSKangXi=188.10
29A83 CJK UNIFIED IDEOGRAPH-#29A83, IRGKangXi=1450.260, RSKangXi=188.10
29A84 CJK UNIFIED IDEOGRAPH-#29A84, IRGKangXi=1450.270, RSKangXi=188.10
29A85 CJK UNIFIED IDEOGRAPH-#29A85, IRGKangXi=1450.280, RSKangXi=188.10
29A86 CJK UNIFIED IDEOGRAPH-#29A86, IRGKangXi=1450.320, RSKangXi=188.10
29A87 CJK UNIFIED IDEOGRAPH-#29A87, IRGKangXi=1450.321, RSKangXi=188.10
29A88 CJK UNIFIED IDEOGRAPH-#29A88, IRGKangXi=1450.321, RSKangXi=188.10
29A89 CJK UNIFIED IDEOGRAPH-#29A89, IRGKangXi=1450.350, RSKangXi=188.11
29A8A CJK UNIFIED IDEOGRAPH-#29A8A, IRGKangXi=1450.360, RSKangXi=188.11
29A8B CJK UNIFIED IDEOGRAPH-#29A8B, IRGKangXi=1450.370, RSKangXi=188.11
29A8C CJK UNIFIED IDEOGRAPH-#29A8C, IRGKangXi=1450.380, RSKangXi=188.11
29A8D CJK UNIFIED IDEOGRAPH-#29A8D, IRGKangXi=1450.390, RSKangXi=188.11
29A8E CJK UNIFIED IDEOGRAPH-#29A8E, IRGKangXi=1450.410, RSKangXi=188.11
29A8F CJK UNIFIED IDEOGRAPH-#29A8F, IRGKangXi=1450.420, RSKangXi=188.11
29A90 CJK UNIFIED IDEOGRAPH-#29A90, IRGKangXi=1450.430, RSKangXi=188.11
29A91 CJK UNIFIED IDEOGRAPH-#29A91, IRGKangXi=1450.450, RSKangXi=188.11
29A92 CJK UNIFIED IDEOGRAPH-#29A92, IRGKangXi=1450.460, RSKangXi=188.11
29A93 CJK UNIFIED IDEOGRAPH-#29A93, IRGKangXi=1450.461, RSKangXi=188.11
29A94 CJK UNIFIED IDEOGRAPH-#29A94, IRGKangXi=1450.461, RSKangXi=188.11
29A95 CJK UNIFIED IDEOGRAPH-#29A95, IRGKangXi=1450.461, RSKangXi=188.11
29A96 CJK UNIFIED IDEOGRAPH-#29A96, IRGKangXi=1450.461, RSKangXi=188.11
29A97 CJK UNIFIED IDEOGRAPH-#29A97, IRGKangXi=1450.470, RSKangXi=188.12, Def{tailbones, the coccyx}
29A98 CJK UNIFIED IDEOGRAPH-#29A98, IRGKangXi=1450.490, RSKangXi=188.12
29A99 CJK UNIFIED IDEOGRAPH-#29A99, IRGKangXi=1450.500, RSKangXi=188.12
29A9A CJK UNIFIED IDEOGRAPH-#29A9A, IRGKangXi=1450.520, RSKangXi=188.12
29A9B CJK UNIFIED IDEOGRAPH-#29A9B, IRGKangXi=1450.530, RSKangXi=188.12
29A9C CJK UNIFIED IDEOGRAPH-#29A9C, IRGKangXi=1450.540, RSKangXi=188.12
29A9D CJK UNIFIED IDEOGRAPH-#29A9D, IRGKangXi=1450.541, RSKangXi=188.12
29A9E CJK UNIFIED IDEOGRAPH-#29A9E, IRGKangXi=1450.541, RSKangXi=188.12
29A9F CJK UNIFIED IDEOGRAPH-#29A9F, IRGKangXi=1450.541, RSKangXi=188.12
29AA0 CJK UNIFIED IDEOGRAPH-#29AA0, IRGKangXi=1450.550, RSKangXi=188.13
29AA1 CJK UNIFIED IDEOGRAPH-#29AA1, IRGKangXi=1450.560, RSKangXi=188.13
29AA2 CJK UNIFIED IDEOGRAPH-#29AA2, IRGKangXi=1450.580, RSKangXi=188.13
29AA3 CJK UNIFIED IDEOGRAPH-#29AA3, IRGKangXi=1450.590, RSKangXi=188.13
29AA4 CJK UNIFIED IDEOGRAPH-#29AA4, IRGKangXi=1451.010, RSKangXi=188.13
29AA5 CJK UNIFIED IDEOGRAPH-#29AA5, IRGKangXi=1451.020, RSKangXi=188.13
29AA6 CJK UNIFIED IDEOGRAPH-#29AA6, IRGKangXi=1451.030, RSKangXi=188.13
29AA7 CJK UNIFIED IDEOGRAPH-#29AA7, IRGKangXi=1451.050, RSKangXi=188.13
29AA8 CJK UNIFIED IDEOGRAPH-#29AA8, IRGKangXi=1451.080, RSKangXi=188.13
29AA9 CJK UNIFIED IDEOGRAPH-#29AA9, IRGKangXi=1451.090, RSKangXi=188.13
29AAA CJK UNIFIED IDEOGRAPH-#29AAA, IRGKangXi=1451.100, RSKangXi=188.13
29AAB CJK UNIFIED IDEOGRAPH-#29AAB, IRGKangXi=1451.101, RSKangXi=188.13
29AAC CJK UNIFIED IDEOGRAPH-#29AAC, IRGKangXi=1451.101, RSKangXi=188.14
29AAD CJK UNIFIED IDEOGRAPH-#29AAD, IRGKangXi=1451.120, RSKangXi=188.14
29AAE CJK UNIFIED IDEOGRAPH-#29AAE, IRGKangXi=1451.130, RSKangXi=188.14
29AAF CJK UNIFIED IDEOGRAPH-#29AAF, IRGKangXi=1451.141, RSKangXi=188.14
29AB0 CJK UNIFIED IDEOGRAPH-#29AB0, IRGKangXi=1451.141, RSKangXi=188.14
29AB1 CJK UNIFIED IDEOGRAPH-#29AB1, IRGKangXi=1451.141, RSKangXi=188.14
29AB2 CJK UNIFIED IDEOGRAPH-#29AB2, IRGKangXi=1451.160, RSKangXi=188.15
29AB3 CJK UNIFIED IDEOGRAPH-#29AB3, IRGKangXi=1451.180, RSKangXi=188.15
29AB4 CJK UNIFIED IDEOGRAPH-#29AB4, IRGKangXi=1451.181, RSKangXi=188.15
29AB5 CJK UNIFIED IDEOGRAPH-#29AB5, IRGKangXi=1451.181, RSKangXi=188.15
29AB6 CJK UNIFIED IDEOGRAPH-#29AB6, IRGKangXi=1451.181, RSKangXi=188.15
29AB7 CJK UNIFIED IDEOGRAPH-#29AB7, IRGKangXi=1451.200, RSKangXi=188.16
29AB8 CJK UNIFIED IDEOGRAPH-#29AB8, IRGKangXi=1451.210, RSKangXi=188.16
29AB9 CJK UNIFIED IDEOGRAPH-#29AB9, IRGKangXi=1451.220, RSKangXi=188.16
29ABA CJK UNIFIED IDEOGRAPH-#29ABA, IRGKangXi=1451.221, RSKangXi=188.16
29ABB CJK UNIFIED IDEOGRAPH-#29ABB, IRGKangXi=1451.230, RSKangXi=188.17
29ABC CJK UNIFIED IDEOGRAPH-#29ABC, IRGKangXi=1451.240, RSKangXi=188.18
29ABD CJK UNIFIED IDEOGRAPH-#29ABD, IRGKangXi=1451.241, RSKangXi=188.18
29ABE CJK UNIFIED IDEOGRAPH-#29ABE, IRGKangXi=1451.250, RSKangXi=188.19
29ABF CJK UNIFIED IDEOGRAPH-#29ABF, IRGKangXi=1451.280, RSKangXi=189.3
29AC0 CJK UNIFIED IDEOGRAPH-#29AC0, IRGKangXi=1451.300, RSKangXi=189.3
29AC1 CJK UNIFIED IDEOGRAPH-#29AC1, IRGKangXi=1451.310, RSKangXi=189.4
29AC2 CJK UNIFIED IDEOGRAPH-#29AC2, IRGKangXi=1451.330, RSKangXi=189.4
29AC3 CJK UNIFIED IDEOGRAPH-#29AC3, IRGKangXi=1451.340, RSKangXi=189.4
29AC4 CJK UNIFIED IDEOGRAPH-#29AC4, IRGKangXi=1451.341, RSKangXi=189.4
29AC5 CJK UNIFIED IDEOGRAPH-#29AC5, IRGKangXi=1451.341, RSKangXi=189.4
29AC6 CJK UNIFIED IDEOGRAPH-#29AC6, IRGKangXi=1451.341, RSKangXi=189.4
29AC7 CJK UNIFIED IDEOGRAPH-#29AC7, IRGKangXi=1451.341, RSKangXi=189.4
29AC8 CJK UNIFIED IDEOGRAPH-#29AC8, IRGKangXi=1451.341, RSKangXi=189.4
29AC9 CJK UNIFIED IDEOGRAPH-#29AC9, IRGKangXi=1451.341, RSKangXi=189.4
29ACA CJK UNIFIED IDEOGRAPH-#29ACA, IRGKangXi=1452.010, RSKangXi=189.5
29ACB CJK UNIFIED IDEOGRAPH-#29ACB, IRGKangXi=1452.011, RSKangXi=189.5
29ACC CJK UNIFIED IDEOGRAPH-#29ACC, IRGKangXi=1452.011, RSKangXi=189.5
29ACD CJK UNIFIED IDEOGRAPH-#29ACD, IRGKangXi=1452.011, RSKangXi=189.5
29ACE CJK UNIFIED IDEOGRAPH-#29ACE, IRGKangXi=1452.020, RSKangXi=189.6
29ACF CJK UNIFIED IDEOGRAPH-#29ACF, IRGKangXi=1452.030, RSKangXi=189.6
29AD0 CJK UNIFIED IDEOGRAPH-#29AD0, IRGKangXi=1452.031, RSKangXi=189.6
29AD1 CJK UNIFIED IDEOGRAPH-#29AD1, IRGKangXi=1452.031, RSKangXi=189.6
29AD2 CJK UNIFIED IDEOGRAPH-#29AD2, IRGKangXi=1452.031, RSKangXi=189.6
29AD3 CJK UNIFIED IDEOGRAPH-#29AD3, IRGKangXi=1452.031, RSKangXi=189.6
29AD4 CJK UNIFIED IDEOGRAPH-#29AD4, IRGKangXi=1452.031, RSKangXi=189.6
29AD5 CJK UNIFIED IDEOGRAPH-#29AD5, IRGKangXi=1452.040, RSKangXi=189.7
29AD6 CJK UNIFIED IDEOGRAPH-#29AD6, IRGKangXi=1452.050, RSKangXi=189.7
29AD7 CJK UNIFIED IDEOGRAPH-#29AD7, IRGKangXi=1452.051, RSKangXi=189.7
29AD8 CJK UNIFIED IDEOGRAPH-#29AD8, IRGKangXi=1452.051, RSKangXi=189.7
29AD9 CJK UNIFIED IDEOGRAPH-#29AD9, IRGKangXi=1452.051, RSKangXi=189.7
29ADA CJK UNIFIED IDEOGRAPH-#29ADA, IRGKangXi=1452.070, RSKangXi=189.8
29ADB CJK UNIFIED IDEOGRAPH-#29ADB, IRGKangXi=1452.071, RSKangXi=189.8
29ADC CJK UNIFIED IDEOGRAPH-#29ADC, IRGKangXi=1452.071, RSKangXi=189.8
29ADD CJK UNIFIED IDEOGRAPH-#29ADD, IRGKangXi=1452.071, RSKangXi=189.8
29ADE CJK UNIFIED IDEOGRAPH-#29ADE, IRGKangXi=1452.090, RSKangXi=189.9
29ADF CJK UNIFIED IDEOGRAPH-#29ADF, IRGKangXi=1452.091, RSKangXi=189.9
29AE0 CJK UNIFIED IDEOGRAPH-#29AE0, IRGKangXi=1452.100, RSKangXi=189.10
29AE1 CJK UNIFIED IDEOGRAPH-#29AE1, IRGKangXi=1452.101, RSKangXi=189.10
29AE2 CJK UNIFIED IDEOGRAPH-#29AE2, IRGKangXi=1452.101, RSKangXi=189.10
29AE3 CJK UNIFIED IDEOGRAPH-#29AE3, IRGKangXi=1452.101, RSKangXi=189.10
29AE4 CJK UNIFIED IDEOGRAPH-#29AE4, IRGKangXi=1452.101, RSKangXi=189.10
29AE5 CJK UNIFIED IDEOGRAPH-#29AE5, IRGKangXi=1452.110, RSKangXi=189.11
29AE6 CJK UNIFIED IDEOGRAPH-#29AE6, IRGKangXi=1452.120, RSKangXi=189.11
29AE7 CJK UNIFIED IDEOGRAPH-#29AE7, IRGKangXi=1452.140, RSKangXi=189.12
29AE8 CJK UNIFIED IDEOGRAPH-#29AE8, IRGKangXi=1452.160, RSKangXi=189.13
29AE9 CJK UNIFIED IDEOGRAPH-#29AE9, IRGKangXi=1452.180, RSKangXi=189.13
29AEA CJK UNIFIED IDEOGRAPH-#29AEA, IRGKangXi=1452.181, RSKangXi=189.13
29AEB CJK UNIFIED IDEOGRAPH-#29AEB, IRGKangXi=1452.190, RSKangXi=189.14
29AEC CJK UNIFIED IDEOGRAPH-#29AEC, IRGKangXi=1452.191, RSKangXi=189.14
29AED CJK UNIFIED IDEOGRAPH-#29AED, IRGKangXi=1452.200, RSKangXi=189.15
29AEE CJK UNIFIED IDEOGRAPH-#29AEE, IRGKangXi=1452.201, RSKangXi=189.16
29AEF CJK UNIFIED IDEOGRAPH-#29AEF, IRGKangXi=1452.210, RSKangXi=189.16
29AF0 CJK UNIFIED IDEOGRAPH-#29AF0, IRGKangXi=1452.220, RSKangXi=189.17
29AF1 CJK UNIFIED IDEOGRAPH-#29AF1, IRGKangXi=1452.230, RSKangXi=189.17
29AF2 CJK UNIFIED IDEOGRAPH-#29AF2, IRGKangXi=1452.241, RSKangXi=189.18
29AF3 CJK UNIFIED IDEOGRAPH-#29AF3, IRGKangXi=1452.250, RSKangXi=189.21
29AF4 CJK UNIFIED IDEOGRAPH-#29AF4, IRGKangXi=1452.290, RSKangXi=190.2
29AF5 CJK UNIFIED IDEOGRAPH-#29AF5, IRGKangXi=1452.301, RSKangXi=190.2
29AF6 CJK UNIFIED IDEOGRAPH-#29AF6, IRGKangXi=1452.301, RSKangXi=190.2
29AF7 CJK UNIFIED IDEOGRAPH-#29AF7, IRGKangXi=1452.301, RSKangXi=190.2
29AF8 CJK UNIFIED IDEOGRAPH-#29AF8, IRGKangXi=1452.301, RSKangXi=190.2
29AF9 CJK UNIFIED IDEOGRAPH-#29AF9, IRGKangXi=1452.320, RSKangXi=190.3
29AFA CJK UNIFIED IDEOGRAPH-#29AFA, IRGKangXi=1452.340, RSKangXi=190.3
29AFB CJK UNIFIED IDEOGRAPH-#29AFB, IRGKangXi=1452.341, RSKangXi=190.3
29AFC CJK UNIFIED IDEOGRAPH-#29AFC, IRGKangXi=1452.341, RSKangXi=190.3
29AFD CJK UNIFIED IDEOGRAPH-#29AFD, IRGKangXi=1452.341, RSKangXi=190.3
29AFE CJK UNIFIED IDEOGRAPH-#29AFE, IRGKangXi=1452.341, RSKangXi=190.3
29AFF CJK UNIFIED IDEOGRAPH-#29AFF, IRGKangXi=1452.370, RSKangXi=190.4
29B00 CJK UNIFIED IDEOGRAPH-#29B00, IRGKangXi=1452.380, RSKangXi=190.4
29B01 CJK UNIFIED IDEOGRAPH-#29B01, IRGKangXi=1452.420, RSKangXi=190.4
29B02 CJK UNIFIED IDEOGRAPH-#29B02, IRGKangXi=1453.010, RSKangXi=190.4
29B03 CJK UNIFIED IDEOGRAPH-#29B03, IRGKangXi=1453.060, RSKangXi=190.4
29B04 CJK UNIFIED IDEOGRAPH-#29B04, IRGKangXi=1453.081, RSKangXi=190.4
29B05 CJK UNIFIED IDEOGRAPH-#29B05, IRGKangXi=1453.081, RSKangXi=190.4
29B06 CJK UNIFIED IDEOGRAPH-#29B06, IRGKangXi=1453.081, RSKangXi=190.4
29B07 CJK UNIFIED IDEOGRAPH-#29B07, IRGKangXi=1453.081, RSKangXi=190.4
29B08 CJK UNIFIED IDEOGRAPH-#29B08, IRGKangXi=1453.081, RSKangXi=190.4
29B09 CJK UNIFIED IDEOGRAPH-#29B09, IRGKangXi=1453.081, RSKangXi=190.4
29B0A CJK UNIFIED IDEOGRAPH-#29B0A, IRGKangXi=1453.081, RSKangXi=190.4
29B0B CJK UNIFIED IDEOGRAPH-#29B0B, IRGKangXi=1453.081, RSKangXi=190.4
29B0C CJK UNIFIED IDEOGRAPH-#29B0C, IRGKangXi=1453.081, RSKangXi=190.4
29B0D CJK UNIFIED IDEOGRAPH-#29B0D, IRGKangXi=1453.081, RSKangXi=190.4
29B0E CJK UNIFIED IDEOGRAPH-#29B0E, IRGKangXi=1453.081, RSKangXi=190.4, Def{(Cant.) bangs (hair)}
29B0F CJK UNIFIED IDEOGRAPH-#29B0F, IRGKangXi=1453.081, RSKangXi=190.4
29B10 CJK UNIFIED IDEOGRAPH-#29B10, IRGKangXi=1453.081, RSKangXi=190.4
29B11 CJK UNIFIED IDEOGRAPH-#29B11, IRGKangXi=1453.090, RSKangXi=190.5
29B12 CJK UNIFIED IDEOGRAPH-#29B12, IRGKangXi=1453.100, RSKangXi=190.5
29B13 CJK UNIFIED IDEOGRAPH-#29B13, IRGKangXi=1453.110, RSKangXi=190.5
29B14 CJK UNIFIED IDEOGRAPH-#29B14, IRGKangXi=1453.120, RSKangXi=190.5
29B15 CJK UNIFIED IDEOGRAPH-#29B15, IRGKangXi=1453.140, RSKangXi=190.5
29B16 CJK UNIFIED IDEOGRAPH-#29B16, IRGKangXi=1453.150, RSKangXi=190.5
29B17 CJK UNIFIED IDEOGRAPH-#29B17, IRGKangXi=1453.160, RSKangXi=190.5
29B18 CJK UNIFIED IDEOGRAPH-#29B18, IRGKangXi=1453.170, RSKangXi=190.5
29B19 CJK UNIFIED IDEOGRAPH-#29B19, IRGKangXi=1453.260, RSKangXi=190.5
29B1A CJK UNIFIED IDEOGRAPH-#29B1A, IRGKangXi=1453.270, RSKangXi=190.5
29B1B CJK UNIFIED IDEOGRAPH-#29B1B, IRGKangXi=1453.280, RSKangXi=190.5
29B1C CJK UNIFIED IDEOGRAPH-#29B1C, IRGKangXi=1453.300, RSKangXi=190.5
29B1D CJK UNIFIED IDEOGRAPH-#29B1D, IRGKangXi=1453.310, RSKangXi=190.5
29B1E CJK UNIFIED IDEOGRAPH-#29B1E, IRGKangXi=1453.320, RSKangXi=190.5
29B1F CJK UNIFIED IDEOGRAPH-#29B1F, IRGKangXi=1453.330, RSKangXi=190.5
29B20 CJK UNIFIED IDEOGRAPH-#29B20, IRGKangXi=1453.380, RSKangXi=190.5
29B21 CJK UNIFIED IDEOGRAPH-#29B21, IRGKangXi=1453.400, RSKangXi=190.5
29B22 CJK UNIFIED IDEOGRAPH-#29B22, IRGKangXi=1453.410, RSKangXi=190.5
29B23 CJK UNIFIED IDEOGRAPH-#29B23, IRGKangXi=1453.411, RSKangXi=190.5
29B24 CJK UNIFIED IDEOGRAPH-#29B24, IRGKangXi=1453.411, RSKangXi=190.5
29B25 CJK UNIFIED IDEOGRAPH-#29B25, IRGKangXi=1453.411, RSKangXi=190.5
29B26 CJK UNIFIED IDEOGRAPH-#29B26, IRGKangXi=1453.411, RSKangXi=190.5
29B27 CJK UNIFIED IDEOGRAPH-#29B27, IRGKangXi=1453.411, RSKangXi=190.5
29B28 CJK UNIFIED IDEOGRAPH-#29B28, IRGKangXi=1453.411, RSKangXi=190.5
29B29 CJK UNIFIED IDEOGRAPH-#29B29, IRGKangXi=1453.411, RSKangXi=190.5
29B2A CJK UNIFIED IDEOGRAPH-#29B2A, IRGKangXi=1453.411, RSKangXi=190.5
29B2B CJK UNIFIED IDEOGRAPH-#29B2B, IRGKangXi=1453.411, RSKangXi=190.5
29B2C CJK UNIFIED IDEOGRAPH-#29B2C, IRGKangXi=1453.411, RSKangXi=190.5
29B2D CJK UNIFIED IDEOGRAPH-#29B2D, IRGKangXi=1453.411, RSKangXi=190.5
29B2E CJK UNIFIED IDEOGRAPH-#29B2E, IRGKangXi=1453.411, RSKangXi=190.5
29B2F CJK UNIFIED IDEOGRAPH-#29B2F, IRGKangXi=1453.411, RSKangXi=190.5
29B30 CJK UNIFIED IDEOGRAPH-#29B30, IRGKangXi=1453.440, RSKangXi=190.6
29B31 CJK UNIFIED IDEOGRAPH-#29B31, IRGKangXi=1454.010, RSKangXi=190.6
29B32 CJK UNIFIED IDEOGRAPH-#29B32, IRGKangXi=1454.030, RSKangXi=190.6
29B33 CJK UNIFIED IDEOGRAPH-#29B33, IRGKangXi=1454.040, RSKangXi=190.6
29B34 CJK UNIFIED IDEOGRAPH-#29B34, IRGKangXi=1454.070, RSKangXi=190.6
29B35 CJK UNIFIED IDEOGRAPH-#29B35, IRGKangXi=1454.080, RSKangXi=190.6
29B36 CJK UNIFIED IDEOGRAPH-#29B36, IRGKangXi=1454.090, RSKangXi=190.6
29B37 CJK UNIFIED IDEOGRAPH-#29B37, IRGKangXi=1454.110, RSKangXi=190.6
29B38 CJK UNIFIED IDEOGRAPH-#29B38, IRGKangXi=1454.120, RSKangXi=190.6
29B39 CJK UNIFIED IDEOGRAPH-#29B39, IRGKangXi=1454.130, RSKangXi=190.6
29B3A CJK UNIFIED IDEOGRAPH-#29B3A, IRGKangXi=1454.140, RSKangXi=190.6
29B3B CJK UNIFIED IDEOGRAPH-#29B3B, IRGKangXi=1454.160, RSKangXi=190.6
29B3C CJK UNIFIED IDEOGRAPH-#29B3C, IRGKangXi=1454.170, RSKangXi=190.6
29B3D CJK UNIFIED IDEOGRAPH-#29B3D, IRGKangXi=1454.190, RSKangXi=190.6
29B3E CJK UNIFIED IDEOGRAPH-#29B3E, IRGKangXi=1454.191, RSKangXi=190.6
29B3F CJK UNIFIED IDEOGRAPH-#29B3F, IRGKangXi=1454.191, RSKangXi=190.6
29B40 CJK UNIFIED IDEOGRAPH-#29B40, IRGKangXi=1454.191, RSKangXi=190.6
29B41 CJK UNIFIED IDEOGRAPH-#29B41, IRGKangXi=1454.191, RSKangXi=190.6
29B42 CJK UNIFIED IDEOGRAPH-#29B42, IRGKangXi=1454.191, RSKangXi=190.6
29B43 CJK UNIFIED IDEOGRAPH-#29B43, IRGKangXi=1454.191, RSKangXi=190.6
29B44 CJK UNIFIED IDEOGRAPH-#29B44, IRGKangXi=1454.191, RSKangXi=190.6
29B45 CJK UNIFIED IDEOGRAPH-#29B45, IRGKangXi=1454.191, RSKangXi=190.6
29B46 CJK UNIFIED IDEOGRAPH-#29B46, IRGKangXi=1454.191, RSKangXi=190.6
29B47 CJK UNIFIED IDEOGRAPH-#29B47, IRGKangXi=1454.200, RSKangXi=190.7
29B48 CJK UNIFIED IDEOGRAPH-#29B48, IRGKangXi=1454.220, RSKangXi=190.7
29B49 CJK UNIFIED IDEOGRAPH-#29B49, IRGKangXi=1454.230, RSKangXi=190.7
29B4A CJK UNIFIED IDEOGRAPH-#29B4A, IRGKangXi=1454.240, RSKangXi=190.7
29B4B CJK UNIFIED IDEOGRAPH-#29B4B, IRGKangXi=1454.250, RSKangXi=190.7
29B4C CJK UNIFIED IDEOGRAPH-#29B4C, IRGKangXi=1454.260, RSKangXi=190.7
29B4D CJK UNIFIED IDEOGRAPH-#29B4D, IRGKangXi=1454.270, RSKangXi=190.7
29B4E CJK UNIFIED IDEOGRAPH-#29B4E, IRGKangXi=1454.280, RSKangXi=190.7
29B4F CJK UNIFIED IDEOGRAPH-#29B4F, IRGKangXi=1454.310, RSKangXi=190.7
29B50 CJK UNIFIED IDEOGRAPH-#29B50, IRGKangXi=1454.320, RSKangXi=190.7
29B51 CJK UNIFIED IDEOGRAPH-#29B51, IRGKangXi=1454.330, RSKangXi=190.7
29B52 CJK UNIFIED IDEOGRAPH-#29B52, IRGKangXi=1454.340, RSKangXi=190.7
29B53 CJK UNIFIED IDEOGRAPH-#29B53, IRGKangXi=1454.380, RSKangXi=190.7
29B54 CJK UNIFIED IDEOGRAPH-#29B54, IRGKangXi=1454.391, RSKangXi=190.7
29B55 CJK UNIFIED IDEOGRAPH-#29B55, IRGKangXi=1454.391, RSKangXi=190.7
29B56 CJK UNIFIED IDEOGRAPH-#29B56, IRGKangXi=1454.391, RSKangXi=190.7
29B57 CJK UNIFIED IDEOGRAPH-#29B57, IRGKangXi=1454.391, RSKangXi=190.7
29B58 CJK UNIFIED IDEOGRAPH-#29B58, IRGKangXi=1454.391, RSKangXi=190.7
29B59 CJK UNIFIED IDEOGRAPH-#29B59, IRGKangXi=1454.391, RSKangXi=190.7
29B5A CJK UNIFIED IDEOGRAPH-#29B5A, IRGKangXi=1454.391, RSKangXi=190.7
29B5B CJK UNIFIED IDEOGRAPH-#29B5B, IRGKangXi=1454.391, RSKangXi=190.7
29B5C CJK UNIFIED IDEOGRAPH-#29B5C, IRGKangXi=1454.391, RSKangXi=190.7
29B5D CJK UNIFIED IDEOGRAPH-#29B5D, IRGKangXi=1454.391, RSKangXi=190.7
29B5E CJK UNIFIED IDEOGRAPH-#29B5E, IRGKangXi=1454.420, RSKangXi=190.8
29B5F CJK UNIFIED IDEOGRAPH-#29B5F, IRGKangXi=1454.480, RSKangXi=190.8
29B60 CJK UNIFIED IDEOGRAPH-#29B60, IRGKangXi=1455.010, RSKangXi=190.8
29B61 CJK UNIFIED IDEOGRAPH-#29B61, IRGKangXi=1455.030, RSKangXi=190.8
29B62 CJK UNIFIED IDEOGRAPH-#29B62, IRGKangXi=1455.040, RSKangXi=190.8
29B63 CJK UNIFIED IDEOGRAPH-#29B63, IRGKangXi=1455.060, RSKangXi=190.8
29B64 CJK UNIFIED IDEOGRAPH-#29B64, IRGKangXi=1455.070, RSKangXi=190.8
29B65 CJK UNIFIED IDEOGRAPH-#29B65, IRGKangXi=1455.080, RSKangXi=190.8
29B66 CJK UNIFIED IDEOGRAPH-#29B66, IRGKangXi=1455.090, RSKangXi=190.8
29B67 CJK UNIFIED IDEOGRAPH-#29B67, IRGKangXi=1455.120, RSKangXi=190.8
29B68 CJK UNIFIED IDEOGRAPH-#29B68, IRGKangXi=1455.130, RSKangXi=190.8
29B69 CJK UNIFIED IDEOGRAPH-#29B69, IRGKangXi=1455.140, RSKangXi=190.8
29B6A CJK UNIFIED IDEOGRAPH-#29B6A, IRGKangXi=1455.150, RSKangXi=190.8
29B6B CJK UNIFIED IDEOGRAPH-#29B6B, IRGKangXi=1455.160, RSKangXi=190.8
29B6C CJK UNIFIED IDEOGRAPH-#29B6C, IRGKangXi=1455.161, RSKangXi=190.8
29B6D CJK UNIFIED IDEOGRAPH-#29B6D, IRGKangXi=1455.161, RSKangXi=190.8
29B6E CJK UNIFIED IDEOGRAPH-#29B6E, IRGKangXi=1455.161, RSKangXi=190.8
29B6F CJK UNIFIED IDEOGRAPH-#29B6F, IRGKangXi=1455.161, RSKangXi=190.8
29B70 CJK UNIFIED IDEOGRAPH-#29B70, IRGKangXi=1455.161, RSKangXi=190.8
29B71 CJK UNIFIED IDEOGRAPH-#29B71, IRGKangXi=1455.161, RSKangXi=190.8
29B72 CJK UNIFIED IDEOGRAPH-#29B72, IRGKangXi=1455.161, RSKangXi=190.8
29B73 CJK UNIFIED IDEOGRAPH-#29B73, IRGKangXi=1455.161, RSKangXi=190.8
29B74 CJK UNIFIED IDEOGRAPH-#29B74, IRGKangXi=1455.161, RSKangXi=190.8
29B75 CJK UNIFIED IDEOGRAPH-#29B75, IRGKangXi=1455.161, RSKangXi=190.8
29B76 CJK UNIFIED IDEOGRAPH-#29B76, IRGKangXi=1455.161, RSKangXi=190.8
29B77 CJK UNIFIED IDEOGRAPH-#29B77, IRGKangXi=1455.161, RSKangXi=190.8
29B78 CJK UNIFIED IDEOGRAPH-#29B78, IRGKangXi=1455.161, RSKangXi=190.8
29B79 CJK UNIFIED IDEOGRAPH-#29B79, IRGKangXi=1455.161, RSKangXi=190.8
29B7A CJK UNIFIED IDEOGRAPH-#29B7A, IRGKangXi=1455.180, RSKangXi=190.9
29B7B CJK UNIFIED IDEOGRAPH-#29B7B, IRGKangXi=1455.210, RSKangXi=190.9
29B7C CJK UNIFIED IDEOGRAPH-#29B7C, IRGKangXi=1455.220, RSKangXi=190.9
29B7D CJK UNIFIED IDEOGRAPH-#29B7D, IRGKangXi=1455.230, RSKangXi=190.9
29B7E CJK UNIFIED IDEOGRAPH-#29B7E, IRGKangXi=1455.240, RSKangXi=190.9
29B7F CJK UNIFIED IDEOGRAPH-#29B7F, IRGKangXi=1455.250, RSKangXi=190.9
29B80 CJK UNIFIED IDEOGRAPH-#29B80, IRGKangXi=1455.260, RSKangXi=190.9
29B81 CJK UNIFIED IDEOGRAPH-#29B81, IRGKangXi=1455.270, RSKangXi=190.9
29B82 CJK UNIFIED IDEOGRAPH-#29B82, IRGKangXi=1455.280, RSKangXi=190.9
29B83 CJK UNIFIED IDEOGRAPH-#29B83, IRGKangXi=1455.290, RSKangXi=190.9
29B84 CJK UNIFIED IDEOGRAPH-#29B84, IRGKangXi=1455.310, RSKangXi=190.9
29B85 CJK UNIFIED IDEOGRAPH-#29B85, IRGKangXi=1455.350, RSKangXi=190.9
29B86 CJK UNIFIED IDEOGRAPH-#29B86, IRGKangXi=1455.370, RSKangXi=190.9
29B87 CJK UNIFIED IDEOGRAPH-#29B87, IRGKangXi=1455.380, RSKangXi=190.9
29B88 CJK UNIFIED IDEOGRAPH-#29B88, IRGKangXi=1455.400, RSKangXi=190.9
29B89 CJK UNIFIED IDEOGRAPH-#29B89, IRGKangXi=1455.410, RSKangXi=190.9
29B8A CJK UNIFIED IDEOGRAPH-#29B8A, IRGKangXi=1455.421, RSKangXi=190.9
29B8B CJK UNIFIED IDEOGRAPH-#29B8B, IRGKangXi=1455.421, RSKangXi=190.9
29B8C CJK UNIFIED IDEOGRAPH-#29B8C, IRGKangXi=1455.421, RSKangXi=190.9
29B8D CJK UNIFIED IDEOGRAPH-#29B8D, IRGKangXi=1455.421, RSKangXi=190.9
29B8E CJK UNIFIED IDEOGRAPH-#29B8E, IRGKangXi=1455.421, RSKangXi=190.9
29B8F CJK UNIFIED IDEOGRAPH-#29B8F, IRGKangXi=1455.421, RSKangXi=190.9
29B90 CJK UNIFIED IDEOGRAPH-#29B90, IRGKangXi=1455.421, RSKangXi=190.9
29B91 CJK UNIFIED IDEOGRAPH-#29B91, IRGKangXi=1455.421, RSKangXi=190.9
29B92 CJK UNIFIED IDEOGRAPH-#29B92, IRGKangXi=1455.421, RSKangXi=190.9
29B93 CJK UNIFIED IDEOGRAPH-#29B93, IRGKangXi=1455.421, RSKangXi=190.9
29B94 CJK UNIFIED IDEOGRAPH-#29B94, IRGKangXi=1455.421, RSKangXi=190.9
29B95 CJK UNIFIED IDEOGRAPH-#29B95, IRGKangXi=1455.421, RSKangXi=190.9
29B96 CJK UNIFIED IDEOGRAPH-#29B96, IRGKangXi=1455.430, RSKangXi=190.10
29B97 CJK UNIFIED IDEOGRAPH-#29B97, IRGKangXi=1455.440, RSKangXi=190.10
29B98 CJK UNIFIED IDEOGRAPH-#29B98, IRGKangXi=1455.450, RSKangXi=190.10
29B99 CJK UNIFIED IDEOGRAPH-#29B99, IRGKangXi=1455.460, RSKangXi=190.10
29B9A CJK UNIFIED IDEOGRAPH-#29B9A, IRGKangXi=1455.470, RSKangXi=190.10
29B9B CJK UNIFIED IDEOGRAPH-#29B9B, IRGKangXi=1455.480, RSKangXi=190.10
29B9C CJK UNIFIED IDEOGRAPH-#29B9C, IRGKangXi=1455.490, RSKangXi=190.10
29B9D CJK UNIFIED IDEOGRAPH-#29B9D, IRGKangXi=1455.500, RSKangXi=190.10
29B9E CJK UNIFIED IDEOGRAPH-#29B9E, IRGKangXi=1455.520, RSKangXi=190.10
29B9F CJK UNIFIED IDEOGRAPH-#29B9F, IRGKangXi=1455.530, RSKangXi=190.10
29BA0 CJK UNIFIED IDEOGRAPH-#29BA0, IRGKangXi=1455.540, RSKangXi=190.10
29BA1 CJK UNIFIED IDEOGRAPH-#29BA1, IRGKangXi=1456.060, RSKangXi=190.10
29BA2 CJK UNIFIED IDEOGRAPH-#29BA2, IRGKangXi=1456.070, RSKangXi=190.10
29BA3 CJK UNIFIED IDEOGRAPH-#29BA3, IRGKangXi=1456.080, RSKangXi=190.10
29BA4 CJK UNIFIED IDEOGRAPH-#29BA4, IRGKangXi=1456.091, RSKangXi=190.10
29BA5 CJK UNIFIED IDEOGRAPH-#29BA5, IRGKangXi=1456.091, RSKangXi=190.10
29BA6 CJK UNIFIED IDEOGRAPH-#29BA6, IRGKangXi=1456.091, RSKangXi=190.10
29BA7 CJK UNIFIED IDEOGRAPH-#29BA7, IRGKangXi=1456.091, RSKangXi=190.10
29BA8 CJK UNIFIED IDEOGRAPH-#29BA8, IRGKangXi=1456.091, RSKangXi=190.10
29BA9 CJK UNIFIED IDEOGRAPH-#29BA9, IRGKangXi=1456.091, RSKangXi=190.10
29BAA CJK UNIFIED IDEOGRAPH-#29BAA, IRGKangXi=1456.091, RSKangXi=190.10
29BAB CJK UNIFIED IDEOGRAPH-#29BAB, IRGKangXi=1456.091, RSKangXi=190.10
29BAC CJK UNIFIED IDEOGRAPH-#29BAC, IRGKangXi=1456.091, RSKangXi=190.10
29BAD CJK UNIFIED IDEOGRAPH-#29BAD, IRGKangXi=1456.091, RSKangXi=190.10
29BAE CJK UNIFIED IDEOGRAPH-#29BAE, IRGKangXi=1456.091, RSKangXi=190.10
29BAF CJK UNIFIED IDEOGRAPH-#29BAF, IRGKangXi=1456.100, RSKangXi=190.11
29BB0 CJK UNIFIED IDEOGRAPH-#29BB0, IRGKangXi=1456.130, RSKangXi=190.11
29BB1 CJK UNIFIED IDEOGRAPH-#29BB1, IRGKangXi=1456.160, RSKangXi=190.11
29BB2 CJK UNIFIED IDEOGRAPH-#29BB2, IRGKangXi=1456.170, RSKangXi=190.11
29BB3 CJK UNIFIED IDEOGRAPH-#29BB3, IRGKangXi=1456.180, RSKangXi=190.11
29BB4 CJK UNIFIED IDEOGRAPH-#29BB4, IRGKangXi=1456.190, RSKangXi=190.11
29BB5 CJK UNIFIED IDEOGRAPH-#29BB5, IRGKangXi=1456.200, RSKangXi=190.11
29BB6 CJK UNIFIED IDEOGRAPH-#29BB6, IRGKangXi=1456.220, RSKangXi=190.11
29BB7 CJK UNIFIED IDEOGRAPH-#29BB7, IRGKangXi=1456.230, RSKangXi=190.11
29BB8 CJK UNIFIED IDEOGRAPH-#29BB8, IRGKangXi=1456.240, RSKangXi=190.11
29BB9 CJK UNIFIED IDEOGRAPH-#29BB9, IRGKangXi=1456.250, RSKangXi=190.11
29BBA CJK UNIFIED IDEOGRAPH-#29BBA, IRGKangXi=1456.280, RSKangXi=190.11
29BBB CJK UNIFIED IDEOGRAPH-#29BBB, IRGKangXi=1456.281, RSKangXi=190.11
29BBC CJK UNIFIED IDEOGRAPH-#29BBC, IRGKangXi=1456.281, RSKangXi=190.11
29BBD CJK UNIFIED IDEOGRAPH-#29BBD, IRGKangXi=1456.281, RSKangXi=190.11
29BBE CJK UNIFIED IDEOGRAPH-#29BBE, IRGKangXi=1456.281, RSKangXi=190.11
29BBF CJK UNIFIED IDEOGRAPH-#29BBF, IRGKangXi=1456.281, RSKangXi=190.11
29BC0 CJK UNIFIED IDEOGRAPH-#29BC0, IRGKangXi=1456.281, RSKangXi=190.11
29BC1 CJK UNIFIED IDEOGRAPH-#29BC1, IRGKangXi=1456.281, RSKangXi=190.11
29BC2 CJK UNIFIED IDEOGRAPH-#29BC2, IRGKangXi=1456.281, RSKangXi=190.11
29BC3 CJK UNIFIED IDEOGRAPH-#29BC3, IRGKangXi=1456.290, RSKangXi=190.12
29BC4 CJK UNIFIED IDEOGRAPH-#29BC4, IRGKangXi=1456.300, RSKangXi=190.12
29BC5 CJK UNIFIED IDEOGRAPH-#29BC5, IRGKangXi=1456.310, RSKangXi=190.12
29BC6 CJK UNIFIED IDEOGRAPH-#29BC6, IRGKangXi=1456.320, RSKangXi=190.12
29BC7 CJK UNIFIED IDEOGRAPH-#29BC7, IRGKangXi=1456.330, RSKangXi=190.12
29BC8 CJK UNIFIED IDEOGRAPH-#29BC8, IRGKangXi=1456.350, RSKangXi=190.12
29BC9 CJK UNIFIED IDEOGRAPH-#29BC9, IRGKangXi=1456.370, RSKangXi=190.12
29BCA CJK UNIFIED IDEOGRAPH-#29BCA, IRGKangXi=1456.390, RSKangXi=190.12
29BCB CJK UNIFIED IDEOGRAPH-#29BCB, IRGKangXi=1456.400, RSKangXi=190.12
29BCC CJK UNIFIED IDEOGRAPH-#29BCC, IRGKangXi=1456.410, RSKangXi=190.12
29BCD CJK UNIFIED IDEOGRAPH-#29BCD, IRGKangXi=1456.430, RSKangXi=190.12
29BCE CJK UNIFIED IDEOGRAPH-#29BCE, IRGKangXi=1456.440, RSKangXi=190.12
29BCF CJK UNIFIED IDEOGRAPH-#29BCF, IRGKangXi=1456.460, RSKangXi=190.12
29BD0 CJK UNIFIED IDEOGRAPH-#29BD0, IRGKangXi=1456.470, RSKangXi=190.12
29BD1 CJK UNIFIED IDEOGRAPH-#29BD1, IRGKangXi=1456.480, RSKangXi=190.12
29BD2 CJK UNIFIED IDEOGRAPH-#29BD2, IRGKangXi=1456.481, RSKangXi=190.12
29BD3 CJK UNIFIED IDEOGRAPH-#29BD3, IRGKangXi=1456.481, RSKangXi=190.12
29BD4 CJK UNIFIED IDEOGRAPH-#29BD4, IRGKangXi=1456.481, RSKangXi=190.12
29BD5 CJK UNIFIED IDEOGRAPH-#29BD5, IRGKangXi=1456.481, RSKangXi=190.12
29BD6 CJK UNIFIED IDEOGRAPH-#29BD6, IRGKangXi=1456.481, RSKangXi=190.12
29BD7 CJK UNIFIED IDEOGRAPH-#29BD7, IRGKangXi=1456.481, RSKangXi=190.12
29BD8 CJK UNIFIED IDEOGRAPH-#29BD8, IRGKangXi=1456.481, RSKangXi=190.12
29BD9 CJK UNIFIED IDEOGRAPH-#29BD9, IRGKangXi=1456.481, RSKangXi=190.12
29BDA CJK UNIFIED IDEOGRAPH-#29BDA, IRGKangXi=1456.481, RSKangXi=190.12
29BDB CJK UNIFIED IDEOGRAPH-#29BDB, IRGKangXi=1456.490, RSKangXi=190.13
29BDC CJK UNIFIED IDEOGRAPH-#29BDC, IRGKangXi=1456.500, RSKangXi=190.13
29BDD CJK UNIFIED IDEOGRAPH-#29BDD, IRGKangXi=1456.510, RSKangXi=190.13
29BDE CJK UNIFIED IDEOGRAPH-#29BDE, IRGKangXi=1456.530, RSKangXi=190.13
29BDF CJK UNIFIED IDEOGRAPH-#29BDF, IRGKangXi=1457.010, RSKangXi=190.13
29BE0 CJK UNIFIED IDEOGRAPH-#29BE0, IRGKangXi=1457.020, RSKangXi=190.13
29BE1 CJK UNIFIED IDEOGRAPH-#29BE1, IRGKangXi=1457.021, RSKangXi=190.13
29BE2 CJK UNIFIED IDEOGRAPH-#29BE2, IRGKangXi=1457.021, RSKangXi=190.13
29BE3 CJK UNIFIED IDEOGRAPH-#29BE3, IRGKangXi=1457.021, RSKangXi=190.13
29BE4 CJK UNIFIED IDEOGRAPH-#29BE4, IRGKangXi=1457.021, RSKangXi=190.13
29BE5 CJK UNIFIED IDEOGRAPH-#29BE5, IRGKangXi=1457.021, RSKangXi=190.13
29BE6 CJK UNIFIED IDEOGRAPH-#29BE6, IRGKangXi=1457.040, RSKangXi=190.14
29BE7 CJK UNIFIED IDEOGRAPH-#29BE7, IRGKangXi=1457.090, RSKangXi=190.14
29BE8 CJK UNIFIED IDEOGRAPH-#29BE8, IRGKangXi=1457.110, RSKangXi=190.14
29BE9 CJK UNIFIED IDEOGRAPH-#29BE9, IRGKangXi=1457.120, RSKangXi=190.14
29BEA CJK UNIFIED IDEOGRAPH-#29BEA, IRGKangXi=1457.121, RSKangXi=190.14
29BEB CJK UNIFIED IDEOGRAPH-#29BEB, IRGKangXi=1457.121, RSKangXi=190.14
29BEC CJK UNIFIED IDEOGRAPH-#29BEC, IRGKangXi=1457.121, RSKangXi=190.14
29BED CJK UNIFIED IDEOGRAPH-#29BED, IRGKangXi=1457.121, RSKangXi=190.14, Def{hair on the temples}
29BEE CJK UNIFIED IDEOGRAPH-#29BEE, IRGKangXi=1457.121, RSKangXi=190.14
29BEF CJK UNIFIED IDEOGRAPH-#29BEF, IRGKangXi=1457.121, RSKangXi=190.14
29BF0 CJK UNIFIED IDEOGRAPH-#29BF0, IRGKangXi=1457.130, RSKangXi=190.15
29BF1 CJK UNIFIED IDEOGRAPH-#29BF1, IRGKangXi=1457.170, RSKangXi=190.15
29BF2 CJK UNIFIED IDEOGRAPH-#29BF2, IRGKangXi=1457.180, RSKangXi=190.15
29BF3 CJK UNIFIED IDEOGRAPH-#29BF3, IRGKangXi=1457.190, RSKangXi=190.15
29BF4 CJK UNIFIED IDEOGRAPH-#29BF4, IRGKangXi=1457.191, RSKangXi=190.15
29BF5 CJK UNIFIED IDEOGRAPH-#29BF5, IRGKangXi=1457.191, RSKangXi=190.15
29BF6 CJK UNIFIED IDEOGRAPH-#29BF6, IRGKangXi=1457.191, RSKangXi=190.15
29BF7 CJK UNIFIED IDEOGRAPH-#29BF7, IRGKangXi=1457.191, RSKangXi=190.15
29BF8 CJK UNIFIED IDEOGRAPH-#29BF8, IRGKangXi=1457.191, RSKangXi=190.15
29BF9 CJK UNIFIED IDEOGRAPH-#29BF9, IRGKangXi=1457.191, RSKangXi=190.15
29BFA CJK UNIFIED IDEOGRAPH-#29BFA, IRGKangXi=1457.210, RSKangXi=190.16
29BFB CJK UNIFIED IDEOGRAPH-#29BFB, IRGKangXi=1457.220, RSKangXi=190.16
29BFC CJK UNIFIED IDEOGRAPH-#29BFC, IRGKangXi=1457.221, RSKangXi=190.16
29BFD CJK UNIFIED IDEOGRAPH-#29BFD, IRGKangXi=1457.221, RSKangXi=190.16
29BFE CJK UNIFIED IDEOGRAPH-#29BFE, IRGKangXi=1457.221, RSKangXi=190.16
29BFF CJK UNIFIED IDEOGRAPH-#29BFF, IRGKangXi=1457.221, RSKangXi=190.16
29C00 CJK UNIFIED IDEOGRAPH-#29C00, IRGKangXi=1457.221, RSKangXi=190.16
29C01 CJK UNIFIED IDEOGRAPH-#29C01, IRGKangXi=1457.240, RSKangXi=190.17
29C02 CJK UNIFIED IDEOGRAPH-#29C02, IRGKangXi=1457.250, RSKangXi=190.17
29C03 CJK UNIFIED IDEOGRAPH-#29C03, IRGKangXi=1457.260, RSKangXi=190.17
29C04 CJK UNIFIED IDEOGRAPH-#29C04, IRGKangXi=1457.261, RSKangXi=190.17
29C05 CJK UNIFIED IDEOGRAPH-#29C05, IRGKangXi=1457.270, RSKangXi=190.18
29C06 CJK UNIFIED IDEOGRAPH-#29C06, IRGKangXi=1457.271, RSKangXi=190.18
29C07 CJK UNIFIED IDEOGRAPH-#29C07, IRGKangXi=1457.271, RSKangXi=190.18
29C08 CJK UNIFIED IDEOGRAPH-#29C08, IRGKangXi=1457.281, RSKangXi=190.21
29C09 CJK UNIFIED IDEOGRAPH-#29C09, IRGKangXi=1457.281, RSKangXi=190.22
29C0A CJK UNIFIED IDEOGRAPH-#29C0A, IRGKangXi=1457.291, RSKangXi=191.-5
29C0B CJK UNIFIED IDEOGRAPH-#29C0B, IRGKangXi=1457.291, RSKangXi=191.-5
29C0C CJK UNIFIED IDEOGRAPH-#29C0C, IRGKangXi=1457.291, RSKangXi=191.3
29C0D CJK UNIFIED IDEOGRAPH-#29C0D, IRGKangXi=1457.300, RSKangXi=191.4
29C0E CJK UNIFIED IDEOGRAPH-#29C0E, IRGKangXi=1457.320, RSKangXi=191.4
29C0F CJK UNIFIED IDEOGRAPH-#29C0F, IRGKangXi=1457.330, RSKangXi=191.4
29C10 CJK UNIFIED IDEOGRAPH-#29C10, IRGKangXi=1457.350, RSKangXi=191.5
29C11 CJK UNIFIED IDEOGRAPH-#29C11, IRGKangXi=1457.361, RSKangXi=191.6
29C12 CJK UNIFIED IDEOGRAPH-#29C12, IRGKangXi=1457.361, RSKangXi=191.7
29C13 CJK UNIFIED IDEOGRAPH-#29C13, IRGKangXi=1457.380, RSKangXi=191.8
29C14 CJK UNIFIED IDEOGRAPH-#29C14, IRGKangXi=1457.390, RSKangXi=191.8
29C15 CJK UNIFIED IDEOGRAPH-#29C15, IRGKangXi=1457.411, RSKangXi=191.10
29C16 CJK UNIFIED IDEOGRAPH-#29C16, IRGKangXi=1457.420, RSKangXi=191.11
29C17 CJK UNIFIED IDEOGRAPH-#29C17, IRGKangXi=1458.010, RSKangXi=191.11
29C18 CJK UNIFIED IDEOGRAPH-#29C18, IRGKangXi=1458.011, RSKangXi=191.11
29C19 CJK UNIFIED IDEOGRAPH-#29C19, IRGKangXi=1458.030, RSKangXi=191.12
29C1A CJK UNIFIED IDEOGRAPH-#29C1A, IRGKangXi=1458.031, RSKangXi=191.12
29C1B CJK UNIFIED IDEOGRAPH-#29C1B, IRGKangXi=1458.031, RSKangXi=191.13
29C1C CJK UNIFIED IDEOGRAPH-#29C1C, IRGKangXi=1458.040, RSKangXi=191.14
29C1D CJK UNIFIED IDEOGRAPH-#29C1D, IRGKangXi=1458.050, RSKangXi=191.14
29C1E CJK UNIFIED IDEOGRAPH-#29C1E, IRGKangXi=1458.070, RSKangXi=191.14
29C1F CJK UNIFIED IDEOGRAPH-#29C1F, IRGKangXi=1458.090, RSKangXi=191.18
29C20 CJK UNIFIED IDEOGRAPH-#29C20, IRGKangXi=1458.110, RSKangXi=192.5
29C21 CJK UNIFIED IDEOGRAPH-#29C21, IRGKangXi=1458.120, RSKangXi=192.5
29C22 CJK UNIFIED IDEOGRAPH-#29C22, IRGKangXi=1458.130, RSKangXi=192.6
29C23 CJK UNIFIED IDEOGRAPH-#29C23, IRGKangXi=1458.131, RSKangXi=192.8
29C24 CJK UNIFIED IDEOGRAPH-#29C24, IRGKangXi=1458.140, RSKangXi=192.10
29C25 CJK UNIFIED IDEOGRAPH-#29C25, IRGKangXi=1458.150, RSKangXi=192.11
29C26 CJK UNIFIED IDEOGRAPH-#29C26, IRGKangXi=1458.151, RSKangXi=192.11
29C27 CJK UNIFIED IDEOGRAPH-#29C27, IRGKangXi=1458.160, RSKangXi=192.12
29C28 CJK UNIFIED IDEOGRAPH-#29C28, IRGKangXi=1458.161, RSKangXi=192.13
29C29 CJK UNIFIED IDEOGRAPH-#29C29, IRGKangXi=1458.161, RSKangXi=192.17
29C2A CJK UNIFIED IDEOGRAPH-#29C2A, IRGKangXi=1458.170, RSKangXi=192.18
29C2B CJK UNIFIED IDEOGRAPH-#29C2B, IRGKangXi=1459.010, RSKangXi=193.3
29C2C CJK UNIFIED IDEOGRAPH-#29C2C, IRGKangXi=1459.020, RSKangXi=193.3
29C2D CJK UNIFIED IDEOGRAPH-#29C2D, IRGKangXi=1459.050, RSKangXi=193.4
29C2E CJK UNIFIED IDEOGRAPH-#29C2E, IRGKangXi=1459.060, RSKangXi=193.4
29C2F CJK UNIFIED IDEOGRAPH-#29C2F, IRGKangXi=1459.080, RSKangXi=193.5
29C30 CJK UNIFIED IDEOGRAPH-#29C30, IRGKangXi=1459.081, RSKangXi=193.5
29C31 CJK UNIFIED IDEOGRAPH-#29C31, IRGKangXi=1459.100, RSKangXi=193.6
29C32 CJK UNIFIED IDEOGRAPH-#29C32, IRGKangXi=1459.110, RSKangXi=193.6
29C33 CJK UNIFIED IDEOGRAPH-#29C33, IRGKangXi=1459.120, RSKangXi=193.6
29C34 CJK UNIFIED IDEOGRAPH-#29C34, IRGKangXi=1459.130, RSKangXi=193.6
29C35 CJK UNIFIED IDEOGRAPH-#29C35, IRGKangXi=1459.140, RSKangXi=193.6
29C36 CJK UNIFIED IDEOGRAPH-#29C36, IRGKangXi=1459.150, RSKangXi=193.6
29C37 CJK UNIFIED IDEOGRAPH-#29C37, IRGKangXi=1459.170, RSKangXi=193.6
29C38 CJK UNIFIED IDEOGRAPH-#29C38, IRGKangXi=1459.171, RSKangXi=193.6
29C39 CJK UNIFIED IDEOGRAPH-#29C39, IRGKangXi=1459.190, RSKangXi=193.7
29C3A CJK UNIFIED IDEOGRAPH-#29C3A, IRGKangXi=1459.191, RSKangXi=193.7
29C3B CJK UNIFIED IDEOGRAPH-#29C3B, IRGKangXi=1459.191, RSKangXi=193.7
29C3C CJK UNIFIED IDEOGRAPH-#29C3C, IRGKangXi=1459.191, RSKangXi=193.7
29C3D CJK UNIFIED IDEOGRAPH-#29C3D, IRGKangXi=1459.191, RSKangXi=193.7
29C3E CJK UNIFIED IDEOGRAPH-#29C3E, IRGKangXi=1459.200, RSKangXi=193.8
29C3F CJK UNIFIED IDEOGRAPH-#29C3F, IRGKangXi=1459.230, RSKangXi=193.8
29C40 CJK UNIFIED IDEOGRAPH-#29C40, IRGKangXi=1459.240, RSKangXi=193.8
29C41 CJK UNIFIED IDEOGRAPH-#29C41, IRGKangXi=1459.241, RSKangXi=193.8
29C42 CJK UNIFIED IDEOGRAPH-#29C42, IRGKangXi=1459.241, RSKangXi=193.8
29C43 CJK UNIFIED IDEOGRAPH-#29C43, IRGKangXi=1459.250, RSKangXi=193.9
29C44 CJK UNIFIED IDEOGRAPH-#29C44, IRGKangXi=1459.260, RSKangXi=193.9
29C45 CJK UNIFIED IDEOGRAPH-#29C45, IRGKangXi=1459.280, RSKangXi=193.9
29C46 CJK UNIFIED IDEOGRAPH-#29C46, IRGKangXi=1459.281, RSKangXi=193.9
29C47 CJK UNIFIED IDEOGRAPH-#29C47, IRGKangXi=1459.290, RSKangXi=193.10
29C48 CJK UNIFIED IDEOGRAPH-#29C48, IRGKangXi=1459.300, RSKangXi=193.10
29C49 CJK UNIFIED IDEOGRAPH-#29C49, IRGKangXi=1459.310, RSKangXi=193.10
29C4A CJK UNIFIED IDEOGRAPH-#29C4A, IRGKangXi=1459.320, RSKangXi=193.10
29C4B CJK UNIFIED IDEOGRAPH-#29C4B, IRGKangXi=1459.330, RSKangXi=193.10
29C4C CJK UNIFIED IDEOGRAPH-#29C4C, IRGKangXi=1459.350, RSKangXi=193.11
29C4D CJK UNIFIED IDEOGRAPH-#29C4D, IRGKangXi=1459.360, RSKangXi=193.11
29C4E CJK UNIFIED IDEOGRAPH-#29C4E, IRGKangXi=1459.370, RSKangXi=193.11
29C4F CJK UNIFIED IDEOGRAPH-#29C4F, IRGKangXi=1459.390, RSKangXi=193.11
29C50 CJK UNIFIED IDEOGRAPH-#29C50, IRGKangXi=1459.410, RSKangXi=193.11
29C51 CJK UNIFIED IDEOGRAPH-#29C51, IRGKangXi=1459.411, RSKangXi=193.11
29C52 CJK UNIFIED IDEOGRAPH-#29C52, IRGKangXi=1459.411, RSKangXi=193.12
29C53 CJK UNIFIED IDEOGRAPH-#29C53, IRGKangXi=1459.420, RSKangXi=193.12
29C54 CJK UNIFIED IDEOGRAPH-#29C54, IRGKangXi=1459.430, RSKangXi=193.12
29C55 CJK UNIFIED IDEOGRAPH-#29C55, IRGKangXi=1459.451, RSKangXi=193.12
29C56 CJK UNIFIED IDEOGRAPH-#29C56, IRGKangXi=1460.010, RSKangXi=193.13
29C57 CJK UNIFIED IDEOGRAPH-#29C57, IRGKangXi=1460.020, RSKangXi=193.13
29C58 CJK UNIFIED IDEOGRAPH-#29C58, IRGKangXi=1460.030, RSKangXi=193.13
29C59 CJK UNIFIED IDEOGRAPH-#29C59, IRGKangXi=1460.040, RSKangXi=193.13
29C5A CJK UNIFIED IDEOGRAPH-#29C5A, IRGKangXi=1460.050, RSKangXi=193.13
29C5B CJK UNIFIED IDEOGRAPH-#29C5B, IRGKangXi=1460.060, RSKangXi=193.13
29C5C CJK UNIFIED IDEOGRAPH-#29C5C, IRGKangXi=1460.070, RSKangXi=193.13
29C5D CJK UNIFIED IDEOGRAPH-#29C5D, IRGKangXi=1460.071, RSKangXi=193.13
29C5E CJK UNIFIED IDEOGRAPH-#29C5E, IRGKangXi=1460.071, RSKangXi=193.13
29C5F CJK UNIFIED IDEOGRAPH-#29C5F, IRGKangXi=1460.071, RSKangXi=193.13
29C60 CJK UNIFIED IDEOGRAPH-#29C60, IRGKangXi=1460.080, RSKangXi=193.14
29C61 CJK UNIFIED IDEOGRAPH-#29C61, IRGKangXi=1460.090, RSKangXi=193.14
29C62 CJK UNIFIED IDEOGRAPH-#29C62, IRGKangXi=1460.100, RSKangXi=193.14
29C63 CJK UNIFIED IDEOGRAPH-#29C63, IRGKangXi=1460.101, RSKangXi=193.14
29C64 CJK UNIFIED IDEOGRAPH-#29C64, IRGKangXi=1460.110, RSKangXi=193.15
29C65 CJK UNIFIED IDEOGRAPH-#29C65, IRGKangXi=1460.130, RSKangXi=193.15
29C66 CJK UNIFIED IDEOGRAPH-#29C66, IRGKangXi=1460.140, RSKangXi=193.16
29C67 CJK UNIFIED IDEOGRAPH-#29C67, IRGKangXi=1460.150, RSKangXi=193.16
29C68 CJK UNIFIED IDEOGRAPH-#29C68, IRGKangXi=1460.160, RSKangXi=193.16
29C69 CJK UNIFIED IDEOGRAPH-#29C69, IRGKangXi=1460.170, RSKangXi=193.16
29C6A CJK UNIFIED IDEOGRAPH-#29C6A, IRGKangXi=1460.171, RSKangXi=193.16
29C6B CJK UNIFIED IDEOGRAPH-#29C6B, IRGKangXi=1460.180, RSKangXi=193.17
29C6C CJK UNIFIED IDEOGRAPH-#29C6C, IRGKangXi=1460.190, RSKangXi=193.17
29C6D CJK UNIFIED IDEOGRAPH-#29C6D, IRGKangXi=1460.200, RSKangXi=193.18
29C6E CJK UNIFIED IDEOGRAPH-#29C6E, IRGKangXi=1460.201, RSKangXi=193.18
29C6F CJK UNIFIED IDEOGRAPH-#29C6F, IRGKangXi=1460.210, RSKangXi=193.19
29C70 CJK UNIFIED IDEOGRAPH-#29C70, IRGKangXi=1460.220, RSKangXi=193.19
29C71 CJK UNIFIED IDEOGRAPH-#29C71, IRGKangXi=1460.230, RSKangXi=193.20
29C72 CJK UNIFIED IDEOGRAPH-#29C72, IRGKangXi=1460.240, RSKangXi=193.20
29C73 CJK UNIFIED IDEOGRAPH-#29C73, IRGKangXi=1460.250, RSKangXi=193.20
29C74 CJK UNIFIED IDEOGRAPH-#29C74, IRGKangXi=1460.260, RSKangXi=193.21
29C75 CJK UNIFIED IDEOGRAPH-#29C75, IRGKangXi=1460.270, RSKangXi=193.21
29C76 CJK UNIFIED IDEOGRAPH-#29C76, IRGKangXi=1460.280, RSKangXi=193.22
29C77 CJK UNIFIED IDEOGRAPH-#29C77, IRGKangXi=1460.290, RSKangXi=193.27
29C78 CJK UNIFIED IDEOGRAPH-#29C78, IRGKangXi=1460.291, RSKangXi=193.27
29C79 CJK UNIFIED IDEOGRAPH-#29C79, IRGKangXi=1460.340, RSKangXi=194.2
29C7A CJK UNIFIED IDEOGRAPH-#29C7A, IRGKangXi=1460.341, RSKangXi=194.2
29C7B CJK UNIFIED IDEOGRAPH-#29C7B, IRGKangXi=1460.341, RSKangXi=194.2
29C7C CJK UNIFIED IDEOGRAPH-#29C7C, IRGKangXi=1460.341, RSKangXi=194.2
29C7D CJK UNIFIED IDEOGRAPH-#29C7D, IRGKangXi=1460.350, RSKangXi=194.3
29C7E CJK UNIFIED IDEOGRAPH-#29C7E, IRGKangXi=1460.360, RSKangXi=194.3
29C7F CJK UNIFIED IDEOGRAPH-#29C7F, IRGKangXi=1460.370, RSKangXi=194.3
29C80 CJK UNIFIED IDEOGRAPH-#29C80, IRGKangXi=1460.380, RSKangXi=194.3
29C81 CJK UNIFIED IDEOGRAPH-#29C81, IRGKangXi=1460.390, RSKangXi=194.3
29C82 CJK UNIFIED IDEOGRAPH-#29C82, IRGKangXi=1460.410, RSKangXi=194.3
29C83 CJK UNIFIED IDEOGRAPH-#29C83, IRGKangXi=1460.420, RSKangXi=194.3
29C84 CJK UNIFIED IDEOGRAPH-#29C84, IRGKangXi=1460.430, RSKangXi=194.3
29C85 CJK UNIFIED IDEOGRAPH-#29C85, IRGKangXi=1460.440, RSKangXi=194.3
29C86 CJK UNIFIED IDEOGRAPH-#29C86, IRGKangXi=1460.441, RSKangXi=194.3
29C87 CJK UNIFIED IDEOGRAPH-#29C87, IRGKangXi=1460.441, RSKangXi=194.3
29C88 CJK UNIFIED IDEOGRAPH-#29C88, IRGKangXi=1460.441, RSKangXi=194.3
29C89 CJK UNIFIED IDEOGRAPH-#29C89, IRGKangXi=1460.441, RSKangXi=194.3
29C8A CJK UNIFIED IDEOGRAPH-#29C8A, IRGKangXi=1461.010, RSKangXi=194.4
29C8B CJK UNIFIED IDEOGRAPH-#29C8B, IRGKangXi=1461.020, RSKangXi=194.4
29C8C CJK UNIFIED IDEOGRAPH-#29C8C, IRGKangXi=1461.030, RSKangXi=194.4
29C8D CJK UNIFIED IDEOGRAPH-#29C8D, IRGKangXi=1461.050, RSKangXi=194.4
29C8E CJK UNIFIED IDEOGRAPH-#29C8E, IRGKangXi=1461.060, RSKangXi=194.4
29C8F CJK UNIFIED IDEOGRAPH-#29C8F, IRGKangXi=1461.080, RSKangXi=194.4
29C90 CJK UNIFIED IDEOGRAPH-#29C90, IRGKangXi=1461.110, RSKangXi=194.4
29C91 CJK UNIFIED IDEOGRAPH-#29C91, IRGKangXi=1461.140, RSKangXi=194.4
29C92 CJK UNIFIED IDEOGRAPH-#29C92, IRGKangXi=1461.141, RSKangXi=194.4
29C93 CJK UNIFIED IDEOGRAPH-#29C93, IRGKangXi=1461.141, RSKangXi=194.4
29C94 CJK UNIFIED IDEOGRAPH-#29C94, IRGKangXi=1461.150, RSKangXi=194.4
29C95 CJK UNIFIED IDEOGRAPH-#29C95, IRGKangXi=1461.151, RSKangXi=194.4
29C96 CJK UNIFIED IDEOGRAPH-#29C96, IRGKangXi=1461.151, RSKangXi=194.4
29C97 CJK UNIFIED IDEOGRAPH-#29C97, IRGKangXi=1461.151, RSKangXi=194.4
29C98 CJK UNIFIED IDEOGRAPH-#29C98, IRGKangXi=1461.151, RSKangXi=194.4
29C99 CJK UNIFIED IDEOGRAPH-#29C99, IRGKangXi=1461.151, RSKangXi=194.4
29C9A CJK UNIFIED IDEOGRAPH-#29C9A, IRGKangXi=1461.151, RSKangXi=194.4
29C9B CJK UNIFIED IDEOGRAPH-#29C9B, IRGKangXi=1461.151, RSKangXi=194.4
29C9C CJK UNIFIED IDEOGRAPH-#29C9C, IRGKangXi=1461.151, RSKangXi=194.4
29C9D CJK UNIFIED IDEOGRAPH-#29C9D, IRGKangXi=1461.151, RSKangXi=194.4
29C9E CJK UNIFIED IDEOGRAPH-#29C9E, IRGKangXi=1461.151, RSKangXi=194.4
29C9F CJK UNIFIED IDEOGRAPH-#29C9F, IRGKangXi=1461.151, RSKangXi=194.4
29CA0 CJK UNIFIED IDEOGRAPH-#29CA0, IRGKangXi=1461.151, RSKangXi=194.4
29CA1 CJK UNIFIED IDEOGRAPH-#29CA1, IRGKangXi=1461.160, RSKangXi=194.5
29CA2 CJK UNIFIED IDEOGRAPH-#29CA2, IRGKangXi=1461.170, RSKangXi=194.5
29CA3 CJK UNIFIED IDEOGRAPH-#29CA3, IRGKangXi=1461.190, RSKangXi=194.5
29CA4 CJK UNIFIED IDEOGRAPH-#29CA4, IRGKangXi=1461.200, RSKangXi=194.5
29CA5 CJK UNIFIED IDEOGRAPH-#29CA5, IRGKangXi=1461.210, RSKangXi=194.5
29CA6 CJK UNIFIED IDEOGRAPH-#29CA6, IRGKangXi=1461.220, RSKangXi=194.5
29CA7 CJK UNIFIED IDEOGRAPH-#29CA7, IRGKangXi=1461.230, RSKangXi=194.5
29CA8 CJK UNIFIED IDEOGRAPH-#29CA8, IRGKangXi=1461.250, RSKangXi=194.5
29CA9 CJK UNIFIED IDEOGRAPH-#29CA9, IRGKangXi=1461.260, RSKangXi=194.5
29CAA CJK UNIFIED IDEOGRAPH-#29CAA, IRGKangXi=1461.270, RSKangXi=194.5
29CAB CJK UNIFIED IDEOGRAPH-#29CAB, IRGKangXi=1461.330, RSKangXi=194.5
29CAC CJK UNIFIED IDEOGRAPH-#29CAC, IRGKangXi=1462.010, RSKangXi=194.5
29CAD CJK UNIFIED IDEOGRAPH-#29CAD, IRGKangXi=1462.011, RSKangXi=194.5
29CAE CJK UNIFIED IDEOGRAPH-#29CAE, IRGKangXi=1462.011, RSKangXi=194.5
29CAF CJK UNIFIED IDEOGRAPH-#29CAF, IRGKangXi=1462.011, RSKangXi=194.5
29CB0 CJK UNIFIED IDEOGRAPH-#29CB0, IRGKangXi=1462.011, RSKangXi=194.5
29CB1 CJK UNIFIED IDEOGRAPH-#29CB1, IRGKangXi=1462.011, RSKangXi=194.5
29CB2 CJK UNIFIED IDEOGRAPH-#29CB2, IRGKangXi=1462.011, RSKangXi=194.5
29CB3 CJK UNIFIED IDEOGRAPH-#29CB3, IRGKangXi=1462.011, RSKangXi=194.5
29CB4 CJK UNIFIED IDEOGRAPH-#29CB4, IRGKangXi=1462.011, RSKangXi=194.5
29CB5 CJK UNIFIED IDEOGRAPH-#29CB5, IRGKangXi=1462.011, RSKangXi=194.5
29CB6 CJK UNIFIED IDEOGRAPH-#29CB6, IRGKangXi=1462.011, RSKangXi=194.5
29CB7 CJK UNIFIED IDEOGRAPH-#29CB7, IRGKangXi=1462.011, RSKangXi=194.5
29CB8 CJK UNIFIED IDEOGRAPH-#29CB8, IRGKangXi=1462.011, RSKangXi=194.5
29CB9 CJK UNIFIED IDEOGRAPH-#29CB9, IRGKangXi=1462.011, RSKangXi=194.5
29CBA CJK UNIFIED IDEOGRAPH-#29CBA, IRGKangXi=1462.020, RSKangXi=194.6
29CBB CJK UNIFIED IDEOGRAPH-#29CBB, IRGKangXi=1462.030, RSKangXi=194.6
29CBC CJK UNIFIED IDEOGRAPH-#29CBC, IRGKangXi=1462.040, RSKangXi=194.6
29CBD CJK UNIFIED IDEOGRAPH-#29CBD, IRGKangXi=1462.060, RSKangXi=194.6
29CBE CJK UNIFIED IDEOGRAPH-#29CBE, IRGKangXi=1462.070, RSKangXi=194.6
29CBF CJK UNIFIED IDEOGRAPH-#29CBF, IRGKangXi=1462.080, RSKangXi=194.6
29CC0 CJK UNIFIED IDEOGRAPH-#29CC0, IRGKangXi=1462.090, RSKangXi=194.6
29CC1 CJK UNIFIED IDEOGRAPH-#29CC1, IRGKangXi=1462.100, RSKangXi=194.6
29CC2 CJK UNIFIED IDEOGRAPH-#29CC2, IRGKangXi=1462.110, RSKangXi=194.6
29CC3 CJK UNIFIED IDEOGRAPH-#29CC3, IRGKangXi=1462.120, RSKangXi=194.6
29CC4 CJK UNIFIED IDEOGRAPH-#29CC4, IRGKangXi=1462.121, RSKangXi=194.6
29CC5 CJK UNIFIED IDEOGRAPH-#29CC5, IRGKangXi=1462.121, RSKangXi=194.6
29CC6 CJK UNIFIED IDEOGRAPH-#29CC6, IRGKangXi=1462.121, RSKangXi=194.6
29CC7 CJK UNIFIED IDEOGRAPH-#29CC7, IRGKangXi=1462.121, RSKangXi=194.6
29CC8 CJK UNIFIED IDEOGRAPH-#29CC8, IRGKangXi=1462.121, RSKangXi=194.6
29CC9 CJK UNIFIED IDEOGRAPH-#29CC9, IRGKangXi=1462.121, RSKangXi=194.6
29CCA CJK UNIFIED IDEOGRAPH-#29CCA, IRGKangXi=1462.121, RSKangXi=194.6
29CCB CJK UNIFIED IDEOGRAPH-#29CCB, IRGKangXi=1462.121, RSKangXi=194.6
29CCC CJK UNIFIED IDEOGRAPH-#29CCC, IRGKangXi=1462.130, RSKangXi=194.7
29CCD CJK UNIFIED IDEOGRAPH-#29CCD, IRGKangXi=1462.140, RSKangXi=194.7
29CCE CJK UNIFIED IDEOGRAPH-#29CCE, IRGKangXi=1462.160, RSKangXi=194.7
29CCF CJK UNIFIED IDEOGRAPH-#29CCF, IRGKangXi=1462.170, RSKangXi=194.7
29CD0 CJK UNIFIED IDEOGRAPH-#29CD0, IRGKangXi=1462.180, RSKangXi=194.7
29CD1 CJK UNIFIED IDEOGRAPH-#29CD1, IRGKangXi=1462.190, RSKangXi=194.7
29CD2 CJK UNIFIED IDEOGRAPH-#29CD2, IRGKangXi=1462.200, RSKangXi=194.7
29CD3 CJK UNIFIED IDEOGRAPH-#29CD3, IRGKangXi=1462.210, RSKangXi=194.7
29CD4 CJK UNIFIED IDEOGRAPH-#29CD4, IRGKangXi=1462.220, RSKangXi=194.7
29CD5 CJK UNIFIED IDEOGRAPH-#29CD5, IRGKangXi=1462.230, RSKangXi=194.7
29CD6 CJK UNIFIED IDEOGRAPH-#29CD6, IRGKangXi=1462.240, RSKangXi=194.7
29CD7 CJK UNIFIED IDEOGRAPH-#29CD7, IRGKangXi=1462.241, RSKangXi=194.7
29CD8 CJK UNIFIED IDEOGRAPH-#29CD8, IRGKangXi=1462.241, RSKangXi=194.7
29CD9 CJK UNIFIED IDEOGRAPH-#29CD9, IRGKangXi=1462.241, RSKangXi=194.7
29CDA CJK UNIFIED IDEOGRAPH-#29CDA, IRGKangXi=1462.241, RSKangXi=194.7
29CDB CJK UNIFIED IDEOGRAPH-#29CDB, IRGKangXi=1462.241, RSKangXi=194.7
29CDC CJK UNIFIED IDEOGRAPH-#29CDC, IRGKangXi=1462.241, RSKangXi=194.7
29CDD CJK UNIFIED IDEOGRAPH-#29CDD, IRGKangXi=1462.241, RSKangXi=194.7
29CDE CJK UNIFIED IDEOGRAPH-#29CDE, IRGKangXi=1462.241, RSKangXi=194.7
29CDF CJK UNIFIED IDEOGRAPH-#29CDF, IRGKangXi=1462.241, RSKangXi=194.7
29CE0 CJK UNIFIED IDEOGRAPH-#29CE0, IRGKangXi=1462.241, RSKangXi=194.7
29CE1 CJK UNIFIED IDEOGRAPH-#29CE1, IRGKangXi=1462.241, RSKangXi=194.7
29CE2 CJK UNIFIED IDEOGRAPH-#29CE2, IRGKangXi=1462.260, RSKangXi=194.8
29CE3 CJK UNIFIED IDEOGRAPH-#29CE3, IRGKangXi=1462.270, RSKangXi=194.8
29CE4 CJK UNIFIED IDEOGRAPH-#29CE4, IRGKangXi=1462.280, RSKangXi=194.8
29CE5 CJK UNIFIED IDEOGRAPH-#29CE5, IRGKangXi=1462.320, RSKangXi=194.8
29CE6 CJK UNIFIED IDEOGRAPH-#29CE6, IRGKangXi=1462.360, RSKangXi=194.8
29CE7 CJK UNIFIED IDEOGRAPH-#29CE7, IRGKangXi=1462.370, RSKangXi=194.8
29CE8 CJK UNIFIED IDEOGRAPH-#29CE8, IRGKangXi=1462.410, RSKangXi=194.8
29CE9 CJK UNIFIED IDEOGRAPH-#29CE9, IRGKangXi=1462.420, RSKangXi=194.8
29CEA CJK UNIFIED IDEOGRAPH-#29CEA, IRGKangXi=1462.430, RSKangXi=194.8
29CEB CJK UNIFIED IDEOGRAPH-#29CEB, IRGKangXi=1462.431, RSKangXi=194.8
29CEC CJK UNIFIED IDEOGRAPH-#29CEC, IRGKangXi=1462.431, RSKangXi=194.8
29CED CJK UNIFIED IDEOGRAPH-#29CED, IRGKangXi=1462.431, RSKangXi=194.8
29CEE CJK UNIFIED IDEOGRAPH-#29CEE, IRGKangXi=1462.431, RSKangXi=194.8
29CEF CJK UNIFIED IDEOGRAPH-#29CEF, IRGKangXi=1462.431, RSKangXi=194.8
29CF0 CJK UNIFIED IDEOGRAPH-#29CF0, IRGKangXi=1462.431, RSKangXi=194.8
29CF1 CJK UNIFIED IDEOGRAPH-#29CF1, IRGKangXi=1462.431, RSKangXi=194.8
29CF2 CJK UNIFIED IDEOGRAPH-#29CF2, IRGKangXi=1462.431, RSKangXi=194.8
29CF3 CJK UNIFIED IDEOGRAPH-#29CF3, IRGKangXi=1462.431, RSKangXi=194.8
29CF4 CJK UNIFIED IDEOGRAPH-#29CF4, IRGKangXi=1462.431, RSKangXi=194.8
29CF5 CJK UNIFIED IDEOGRAPH-#29CF5, IRGKangXi=1462.440, RSKangXi=194.9
29CF6 CJK UNIFIED IDEOGRAPH-#29CF6, IRGKangXi=1462.450, RSKangXi=194.9
29CF7 CJK UNIFIED IDEOGRAPH-#29CF7, IRGKangXi=1462.460, RSKangXi=194.9
29CF8 CJK UNIFIED IDEOGRAPH-#29CF8, IRGKangXi=1462.490, RSKangXi=194.9
29CF9 CJK UNIFIED IDEOGRAPH-#29CF9, IRGKangXi=1462.500, RSKangXi=194.9
29CFA CJK UNIFIED IDEOGRAPH-#29CFA, IRGKangXi=1462.510, RSKangXi=194.9
29CFB CJK UNIFIED IDEOGRAPH-#29CFB, IRGKangXi=1462.511, RSKangXi=194.9
29CFC CJK UNIFIED IDEOGRAPH-#29CFC, IRGKangXi=1462.511, RSKangXi=194.9
29CFD CJK UNIFIED IDEOGRAPH-#29CFD, IRGKangXi=1462.511, RSKangXi=194.9
29CFE CJK UNIFIED IDEOGRAPH-#29CFE, IRGKangXi=1462.511, RSKangXi=194.9
29CFF CJK UNIFIED IDEOGRAPH-#29CFF, IRGKangXi=1462.511, RSKangXi=194.9
29D00 CJK UNIFIED IDEOGRAPH-#29D00, IRGKangXi=1462.511, RSKangXi=194.9
29D01 CJK UNIFIED IDEOGRAPH-#29D01, IRGKangXi=1462.511, RSKangXi=194.9
29D02 CJK UNIFIED IDEOGRAPH-#29D02, IRGKangXi=1462.511, RSKangXi=194.9
29D03 CJK UNIFIED IDEOGRAPH-#29D03, IRGKangXi=1462.511, RSKangXi=194.9
29D04 CJK UNIFIED IDEOGRAPH-#29D04, IRGKangXi=1462.511, RSKangXi=194.9
29D05 CJK UNIFIED IDEOGRAPH-#29D05, IRGKangXi=1462.511, RSKangXi=194.9
29D06 CJK UNIFIED IDEOGRAPH-#29D06, IRGKangXi=1462.520, RSKangXi=194.10
29D07 CJK UNIFIED IDEOGRAPH-#29D07, IRGKangXi=1462.540, RSKangXi=194.10
29D08 CJK UNIFIED IDEOGRAPH-#29D08, IRGKangXi=1462.550, RSKangXi=194.10
29D09 CJK UNIFIED IDEOGRAPH-#29D09, IRGKangXi=1462.560, RSKangXi=194.10
29D0A CJK UNIFIED IDEOGRAPH-#29D0A, IRGKangXi=1462.580, RSKangXi=194.10
29D0B CJK UNIFIED IDEOGRAPH-#29D0B, IRGKangXi=1462.590, RSKangXi=194.10
29D0C CJK UNIFIED IDEOGRAPH-#29D0C, IRGKangXi=1462.591, RSKangXi=194.10
29D0D CJK UNIFIED IDEOGRAPH-#29D0D, IRGKangXi=1462.591, RSKangXi=194.10
29D0E CJK UNIFIED IDEOGRAPH-#29D0E, IRGKangXi=1462.591, RSKangXi=194.10
29D0F CJK UNIFIED IDEOGRAPH-#29D0F, IRGKangXi=1462.591, RSKangXi=194.10
29D10 CJK UNIFIED IDEOGRAPH-#29D10, IRGKangXi=1462.600, RSKangXi=194.11
29D11 CJK UNIFIED IDEOGRAPH-#29D11, IRGKangXi=1462.630, RSKangXi=194.11
29D12 CJK UNIFIED IDEOGRAPH-#29D12, IRGKangXi=1462.640, RSKangXi=194.11
29D13 CJK UNIFIED IDEOGRAPH-#29D13, IRGKangXi=1462.680, RSKangXi=194.11
29D14 CJK UNIFIED IDEOGRAPH-#29D14, IRGKangXi=1463.010, RSKangXi=194.11
29D15 CJK UNIFIED IDEOGRAPH-#29D15, IRGKangXi=1463.020, RSKangXi=194.11
29D16 CJK UNIFIED IDEOGRAPH-#29D16, IRGKangXi=1463.021, RSKangXi=194.11
29D17 CJK UNIFIED IDEOGRAPH-#29D17, IRGKangXi=1463.021, RSKangXi=194.11
29D18 CJK UNIFIED IDEOGRAPH-#29D18, IRGKangXi=1463.021, RSKangXi=194.11
29D19 CJK UNIFIED IDEOGRAPH-#29D19, IRGKangXi=1463.021, RSKangXi=194.11
29D1A CJK UNIFIED IDEOGRAPH-#29D1A, IRGKangXi=1463.021, RSKangXi=194.11
29D1B CJK UNIFIED IDEOGRAPH-#29D1B, IRGKangXi=1463.021, RSKangXi=194.11
29D1C CJK UNIFIED IDEOGRAPH-#29D1C, IRGKangXi=1463.021, RSKangXi=194.12
29D1D CJK UNIFIED IDEOGRAPH-#29D1D, IRGKangXi=1463.030, RSKangXi=194.12
29D1E CJK UNIFIED IDEOGRAPH-#29D1E, IRGKangXi=1463.040, RSKangXi=194.12
29D1F CJK UNIFIED IDEOGRAPH-#29D1F, IRGKangXi=1463.050, RSKangXi=194.12
29D20 CJK UNIFIED IDEOGRAPH-#29D20, IRGKangXi=1463.070, RSKangXi=194.12
29D21 CJK UNIFIED IDEOGRAPH-#29D21, IRGKangXi=1463.080, RSKangXi=194.12
29D22 CJK UNIFIED IDEOGRAPH-#29D22, IRGKangXi=1463.100, RSKangXi=194.12
29D23 CJK UNIFIED IDEOGRAPH-#29D23, IRGKangXi=1463.110, RSKangXi=194.12
29D24 CJK UNIFIED IDEOGRAPH-#29D24, IRGKangXi=1463.120, RSKangXi=194.12
29D25 CJK UNIFIED IDEOGRAPH-#29D25, IRGKangXi=1463.151, RSKangXi=194.12
29D26 CJK UNIFIED IDEOGRAPH-#29D26, IRGKangXi=1463.151, RSKangXi=194.12
29D27 CJK UNIFIED IDEOGRAPH-#29D27, IRGKangXi=1463.151, RSKangXi=194.12
29D28 CJK UNIFIED IDEOGRAPH-#29D28, IRGKangXi=1463.151, RSKangXi=194.12
29D29 CJK UNIFIED IDEOGRAPH-#29D29, IRGKangXi=1463.151, RSKangXi=194.12
29D2A CJK UNIFIED IDEOGRAPH-#29D2A, IRGKangXi=1463.151, RSKangXi=194.12
29D2B CJK UNIFIED IDEOGRAPH-#29D2B, IRGKangXi=1463.151, RSKangXi=194.12
29D2C CJK UNIFIED IDEOGRAPH-#29D2C, IRGKangXi=1463.151, RSKangXi=194.12
29D2D CJK UNIFIED IDEOGRAPH-#29D2D, IRGKangXi=1463.151, RSKangXi=194.12
29D2E CJK UNIFIED IDEOGRAPH-#29D2E, IRGKangXi=1463.160, RSKangXi=194.13
29D2F CJK UNIFIED IDEOGRAPH-#29D2F, IRGKangXi=1463.161, RSKangXi=194.13
29D30 CJK UNIFIED IDEOGRAPH-#29D30, IRGKangXi=1463.161, RSKangXi=194.13
29D31 CJK UNIFIED IDEOGRAPH-#29D31, IRGKangXi=1463.170, RSKangXi=194.14
29D32 CJK UNIFIED IDEOGRAPH-#29D32, IRGKangXi=1463.180, RSKangXi=194.14
29D33 CJK UNIFIED IDEOGRAPH-#29D33, IRGKangXi=1463.220, RSKangXi=194.14
29D34 CJK UNIFIED IDEOGRAPH-#29D34, IRGKangXi=1463.250, RSKangXi=194.14
29D35 CJK UNIFIED IDEOGRAPH-#29D35, IRGKangXi=1463.251, RSKangXi=194.14
29D36 CJK UNIFIED IDEOGRAPH-#29D36, IRGKangXi=1463.251, RSKangXi=194.14
29D37 CJK UNIFIED IDEOGRAPH-#29D37, IRGKangXi=1463.251, RSKangXi=194.14
29D38 CJK UNIFIED IDEOGRAPH-#29D38, IRGKangXi=1463.251, RSKangXi=194.14
29D39 CJK UNIFIED IDEOGRAPH-#29D39, IRGKangXi=1463.251, RSKangXi=194.14
29D3A CJK UNIFIED IDEOGRAPH-#29D3A, IRGKangXi=1463.260, RSKangXi=194.15
29D3B CJK UNIFIED IDEOGRAPH-#29D3B, IRGKangXi=1463.270, RSKangXi=194.15
29D3C CJK UNIFIED IDEOGRAPH-#29D3C, IRGKangXi=1463.271, RSKangXi=194.15
29D3D CJK UNIFIED IDEOGRAPH-#29D3D, IRGKangXi=1463.271, RSKangXi=194.15
29D3E CJK UNIFIED IDEOGRAPH-#29D3E, IRGKangXi=1463.271, RSKangXi=194.15
29D3F CJK UNIFIED IDEOGRAPH-#29D3F, IRGKangXi=1463.271, RSKangXi=194.16
29D40 CJK UNIFIED IDEOGRAPH-#29D40, IRGKangXi=1463.280, RSKangXi=194.17
29D41 CJK UNIFIED IDEOGRAPH-#29D41, IRGKangXi=1463.281, RSKangXi=194.17
29D42 CJK UNIFIED IDEOGRAPH-#29D42, IRGKangXi=1463.281, RSKangXi=194.17
29D43 CJK UNIFIED IDEOGRAPH-#29D43, IRGKangXi=1463.281, RSKangXi=194.17
29D44 CJK UNIFIED IDEOGRAPH-#29D44, IRGKangXi=1463.290, RSKangXi=194.18
29D45 CJK UNIFIED IDEOGRAPH-#29D45, IRGKangXi=1463.300, RSKangXi=194.18
29D46 CJK UNIFIED IDEOGRAPH-#29D46, IRGKangXi=1463.301, RSKangXi=194.19
29D47 CJK UNIFIED IDEOGRAPH-#29D47, IRGKangXi=1463.301, RSKangXi=194.19
29D48 CJK UNIFIED IDEOGRAPH-#29D48, IRGKangXi=1463.301, RSKangXi=194.20
29D49 CJK UNIFIED IDEOGRAPH-#29D49, IRGKangXi=1463.301, RSKangXi=194.22
29D4A CJK UNIFIED IDEOGRAPH-#29D4A, IRGKangXi=1463.301, RSKangXi=194.23
29D4B CJK UNIFIED IDEOGRAPH-#29D4B, IRGKangXi=1465.011, RSKangXi=195.0, Def{(J) nonstandard variant of 魚 U+9B5A, fish}
29D4C CJK UNIFIED IDEOGRAPH-#29D4C, IRGKangXi=1465.050, RSKangXi=195.2
29D4D CJK UNIFIED IDEOGRAPH-#29D4D, IRGKangXi=1465.060, RSKangXi=195.2
29D4E CJK UNIFIED IDEOGRAPH-#29D4E, IRGKangXi=1465.090, RSKangXi=195.2
29D4F CJK UNIFIED IDEOGRAPH-#29D4F, IRGKangXi=1465.100, RSKangXi=195.2
29D50 CJK UNIFIED IDEOGRAPH-#29D50, IRGKangXi=1465.110, RSKangXi=195.2
29D51 CJK UNIFIED IDEOGRAPH-#29D51, IRGKangXi=1465.120, RSKangXi=195.2
29D52 CJK UNIFIED IDEOGRAPH-#29D52, IRGKangXi=1465.121, RSKangXi=195.2
29D53 CJK UNIFIED IDEOGRAPH-#29D53, IRGKangXi=1465.121, RSKangXi=195.2
29D54 CJK UNIFIED IDEOGRAPH-#29D54, IRGKangXi=1465.150, RSKangXi=195.3
29D55 CJK UNIFIED IDEOGRAPH-#29D55, IRGKangXi=1465.170, RSKangXi=195.3
29D56 CJK UNIFIED IDEOGRAPH-#29D56, IRGKangXi=1465.180, RSKangXi=195.3
29D57 CJK UNIFIED IDEOGRAPH-#29D57, IRGKangXi=1465.200, RSKangXi=195.3
29D58 CJK UNIFIED IDEOGRAPH-#29D58, IRGKangXi=1465.211, RSKangXi=195.3
29D59 CJK UNIFIED IDEOGRAPH-#29D59, IRGKangXi=1465.211, RSKangXi=195.3
29D5A CJK UNIFIED IDEOGRAPH-#29D5A, IRGKangXi=1465.211, RSKangXi=195.3
29D5B CJK UNIFIED IDEOGRAPH-#29D5B, IRGKangXi=1465.211, RSKangXi=195.3
29D5C CJK UNIFIED IDEOGRAPH-#29D5C, IRGKangXi=1465.211, RSKangXi=195.3
29D5D CJK UNIFIED IDEOGRAPH-#29D5D, IRGKangXi=1465.211, RSKangXi=195.3
29D5E CJK UNIFIED IDEOGRAPH-#29D5E, IRGKangXi=1465.211, RSKangXi=195.3
29D5F CJK UNIFIED IDEOGRAPH-#29D5F, IRGKangXi=1465.211, RSKangXi=195.3
29D60 CJK UNIFIED IDEOGRAPH-#29D60, IRGKangXi=1465.220, RSKangXi=195.4
29D61 CJK UNIFIED IDEOGRAPH-#29D61, IRGKangXi=1465.250, RSKangXi=195.4
29D62 CJK UNIFIED IDEOGRAPH-#29D62, IRGKangXi=1466.020, RSKangXi=195.4
29D63 CJK UNIFIED IDEOGRAPH-#29D63, IRGKangXi=1466.080, RSKangXi=195.4
29D64 CJK UNIFIED IDEOGRAPH-#29D64, IRGKangXi=1466.090, RSKangXi=195.4
29D65 CJK UNIFIED IDEOGRAPH-#29D65, IRGKangXi=1466.110, RSKangXi=195.4
29D66 CJK UNIFIED IDEOGRAPH-#29D66, IRGKangXi=1466.120, RSKangXi=195.4
29D67 CJK UNIFIED IDEOGRAPH-#29D67, IRGKangXi=1466.130, RSKangXi=195.4
29D68 CJK UNIFIED IDEOGRAPH-#29D68, IRGKangXi=1466.180, RSKangXi=195.4
29D69 CJK UNIFIED IDEOGRAPH-#29D69, IRGKangXi=1466.200, RSKangXi=195.4
29D6A CJK UNIFIED IDEOGRAPH-#29D6A, IRGKangXi=1466.230, RSKangXi=195.4
29D6B CJK UNIFIED IDEOGRAPH-#29D6B, IRGKangXi=1466.240, RSKangXi=195.4
29D6C CJK UNIFIED IDEOGRAPH-#29D6C, IRGKangXi=1466.290, RSKangXi=195.4
29D6D CJK UNIFIED IDEOGRAPH-#29D6D, IRGKangXi=1466.300, RSKangXi=195.4
29D6E CJK UNIFIED IDEOGRAPH-#29D6E, IRGKangXi=1467.010, RSKangXi=195.4
29D6F CJK UNIFIED IDEOGRAPH-#29D6F, IRGKangXi=1467.020, RSKangXi=195.4
29D70 CJK UNIFIED IDEOGRAPH-#29D70, IRGKangXi=1467.030, RSKangXi=195.4
29D71 CJK UNIFIED IDEOGRAPH-#29D71, IRGKangXi=1467.040, RSKangXi=195.4
29D72 CJK UNIFIED IDEOGRAPH-#29D72, IRGKangXi=1467.041, RSKangXi=195.4
29D73 CJK UNIFIED IDEOGRAPH-#29D73, IRGKangXi=1467.041, RSKangXi=195.4
29D74 CJK UNIFIED IDEOGRAPH-#29D74, IRGKangXi=1467.041, RSKangXi=195.4
29D75 CJK UNIFIED IDEOGRAPH-#29D75, IRGKangXi=1467.041, RSKangXi=195.4
29D76 CJK UNIFIED IDEOGRAPH-#29D76, IRGKangXi=1467.041, RSKangXi=195.4
29D77 CJK UNIFIED IDEOGRAPH-#29D77, IRGKangXi=1467.041, RSKangXi=195.4
29D78 CJK UNIFIED IDEOGRAPH-#29D78, IRGKangXi=1467.041, RSKangXi=195.4
29D79 CJK UNIFIED IDEOGRAPH-#29D79, IRGKangXi=1467.041, RSKangXi=195.4
29D7A CJK UNIFIED IDEOGRAPH-#29D7A, IRGKangXi=1467.041, RSKangXi=195.4
29D7B CJK UNIFIED IDEOGRAPH-#29D7B, IRGKangXi=1467.041, RSKangXi=195.4
29D7C CJK UNIFIED IDEOGRAPH-#29D7C, IRGKangXi=1467.041, RSKangXi=195.4
29D7D CJK UNIFIED IDEOGRAPH-#29D7D, IRGKangXi=1467.041, RSKangXi=195.4
29D7E CJK UNIFIED IDEOGRAPH-#29D7E, IRGKangXi=1467.041, RSKangXi=195.4
29D7F CJK UNIFIED IDEOGRAPH-#29D7F, IRGKangXi=1467.041, RSKangXi=195.4
29D80 CJK UNIFIED IDEOGRAPH-#29D80, IRGKangXi=1467.041, RSKangXi=195.4
29D81 CJK UNIFIED IDEOGRAPH-#29D81, IRGKangXi=1467.060, RSKangXi=195.5
29D82 CJK UNIFIED IDEOGRAPH-#29D82, IRGKangXi=1467.180, RSKangXi=195.5
29D83 CJK UNIFIED IDEOGRAPH-#29D83, IRGKangXi=1467.210, RSKangXi=195.5
29D84 CJK UNIFIED IDEOGRAPH-#29D84, IRGKangXi=1467.220, RSKangXi=195.5
29D85 CJK UNIFIED IDEOGRAPH-#29D85, IRGKangXi=1467.230, RSKangXi=195.5, Def{mackerel}
29D86 CJK UNIFIED IDEOGRAPH-#29D86, IRGKangXi=1467.270, RSKangXi=195.5
29D87 CJK UNIFIED IDEOGRAPH-#29D87, IRGKangXi=1467.290, RSKangXi=195.5
29D88 CJK UNIFIED IDEOGRAPH-#29D88, IRGKangXi=1467.330, RSKangXi=195.5
29D89 CJK UNIFIED IDEOGRAPH-#29D89, IRGKangXi=1468.020, RSKangXi=195.5
29D8A CJK UNIFIED IDEOGRAPH-#29D8A, IRGKangXi=1468.050, RSKangXi=195.5
29D8B CJK UNIFIED IDEOGRAPH-#29D8B, IRGKangXi=1468.180, RSKangXi=195.5
29D8C CJK UNIFIED IDEOGRAPH-#29D8C, IRGKangXi=1468.190, RSKangXi=195.5
29D8D CJK UNIFIED IDEOGRAPH-#29D8D, IRGKangXi=1468.210, RSKangXi=195.5
29D8E CJK UNIFIED IDEOGRAPH-#29D8E, IRGKangXi=1468.220, RSKangXi=195.5
29D8F CJK UNIFIED IDEOGRAPH-#29D8F, IRGKangXi=1468.221, RSKangXi=195.5
29D90 CJK UNIFIED IDEOGRAPH-#29D90, IRGKangXi=1468.221, RSKangXi=195.5
29D91 CJK UNIFIED IDEOGRAPH-#29D91, IRGKangXi=1468.221, RSKangXi=195.5
29D92 CJK UNIFIED IDEOGRAPH-#29D92, IRGKangXi=1468.221, RSKangXi=195.5
29D93 CJK UNIFIED IDEOGRAPH-#29D93, IRGKangXi=1468.221, RSKangXi=195.5
29D94 CJK UNIFIED IDEOGRAPH-#29D94, IRGKangXi=1468.221, RSKangXi=195.5
29D95 CJK UNIFIED IDEOGRAPH-#29D95, IRGKangXi=1468.221, RSKangXi=195.5
29D96 CJK UNIFIED IDEOGRAPH-#29D96, IRGKangXi=1468.221, RSKangXi=195.5
29D97 CJK UNIFIED IDEOGRAPH-#29D97, IRGKangXi=1468.221, RSKangXi=195.5
29D98 CJK UNIFIED IDEOGRAPH-#29D98, IRGKangXi=1468.221, RSKangXi=195.5, Def{a general name for perch, etc.}
29D99 CJK UNIFIED IDEOGRAPH-#29D99, IRGKangXi=1468.221, RSKangXi=195.5
29D9A CJK UNIFIED IDEOGRAPH-#29D9A, IRGKangXi=1468.221, RSKangXi=195.5
29D9B CJK UNIFIED IDEOGRAPH-#29D9B, IRGKangXi=1468.221, RSKangXi=195.5
29D9C CJK UNIFIED IDEOGRAPH-#29D9C, IRGKangXi=1468.221, RSKangXi=195.5
29D9D CJK UNIFIED IDEOGRAPH-#29D9D, IRGKangXi=1468.221, RSKangXi=195.5
29D9E CJK UNIFIED IDEOGRAPH-#29D9E, IRGKangXi=1468.221, RSKangXi=195.5
29D9F CJK UNIFIED IDEOGRAPH-#29D9F, IRGKangXi=1468.221, RSKangXi=195.5
29DA0 CJK UNIFIED IDEOGRAPH-#29DA0, IRGKangXi=1468.221, RSKangXi=195.5
29DA1 CJK UNIFIED IDEOGRAPH-#29DA1, IRGKangXi=1468.250, RSKangXi=195.6
29DA2 CJK UNIFIED IDEOGRAPH-#29DA2, IRGKangXi=1468.260, RSKangXi=195.6
29DA3 CJK UNIFIED IDEOGRAPH-#29DA3, IRGKangXi=1468.280, RSKangXi=195.6
29DA4 CJK UNIFIED IDEOGRAPH-#29DA4, IRGKangXi=1468.290, RSKangXi=195.6
29DA5 CJK UNIFIED IDEOGRAPH-#29DA5, IRGKangXi=1468.320, RSKangXi=195.6
29DA6 CJK UNIFIED IDEOGRAPH-#29DA6, IRGKangXi=1468.330, RSKangXi=195.6
29DA7 CJK UNIFIED IDEOGRAPH-#29DA7, IRGKangXi=1468.340, RSKangXi=195.6
29DA8 CJK UNIFIED IDEOGRAPH-#29DA8, IRGKangXi=1469.010, RSKangXi=195.6
29DA9 CJK UNIFIED IDEOGRAPH-#29DA9, IRGKangXi=1469.020, RSKangXi=195.6
29DAA CJK UNIFIED IDEOGRAPH-#29DAA, IRGKangXi=1469.040, RSKangXi=195.6
29DAB CJK UNIFIED IDEOGRAPH-#29DAB, IRGKangXi=1469.060, RSKangXi=195.6
29DAC CJK UNIFIED IDEOGRAPH-#29DAC, IRGKangXi=1469.130, RSKangXi=195.6
29DAD CJK UNIFIED IDEOGRAPH-#29DAD, IRGKangXi=1470.020, RSKangXi=195.6
29DAE CJK UNIFIED IDEOGRAPH-#29DAE, IRGKangXi=1470.040, RSKangXi=195.6
29DAF CJK UNIFIED IDEOGRAPH-#29DAF, IRGKangXi=1470.080, RSKangXi=195.6
29DB0 CJK UNIFIED IDEOGRAPH-#29DB0, IRGKangXi=1470.090, RSKangXi=195.6
29DB1 CJK UNIFIED IDEOGRAPH-#29DB1, IRGKangXi=1470.100, RSKangXi=195.6
29DB2 CJK UNIFIED IDEOGRAPH-#29DB2, IRGKangXi=1470.101, RSKangXi=195.6
29DB3 CJK UNIFIED IDEOGRAPH-#29DB3, IRGKangXi=1470.101, RSKangXi=195.6
29DB4 CJK UNIFIED IDEOGRAPH-#29DB4, IRGKangXi=1470.101, RSKangXi=195.6
29DB5 CJK UNIFIED IDEOGRAPH-#29DB5, IRGKangXi=1470.101, RSKangXi=195.6
29DB6 CJK UNIFIED IDEOGRAPH-#29DB6, IRGKangXi=1470.101, RSKangXi=195.6
29DB7 CJK UNIFIED IDEOGRAPH-#29DB7, IRGKangXi=1470.101, RSKangXi=195.3
29DB8 CJK UNIFIED IDEOGRAPH-#29DB8, IRGKangXi=1470.101, RSKangXi=195.6
29DB9 CJK UNIFIED IDEOGRAPH-#29DB9, IRGKangXi=1470.101, RSKangXi=195.6
29DBA CJK UNIFIED IDEOGRAPH-#29DBA, IRGKangXi=1470.101, RSKangXi=195.6
29DBB CJK UNIFIED IDEOGRAPH-#29DBB, IRGKangXi=1470.101, RSKangXi=195.6
29DBC CJK UNIFIED IDEOGRAPH-#29DBC, IRGKangXi=1470.101, RSKangXi=195.6
29DBD CJK UNIFIED IDEOGRAPH-#29DBD, IRGKangXi=1470.101, RSKangXi=195.6
29DBE CJK UNIFIED IDEOGRAPH-#29DBE, IRGKangXi=1470.101, RSKangXi=195.6
29DBF CJK UNIFIED IDEOGRAPH-#29DBF, IRGKangXi=1470.101, RSKangXi=195.6
29DC0 CJK UNIFIED IDEOGRAPH-#29DC0, IRGKangXi=1470.101, RSKangXi=195.6
29DC1 CJK UNIFIED IDEOGRAPH-#29DC1, IRGKangXi=1470.101, RSKangXi=195.6
29DC2 CJK UNIFIED IDEOGRAPH-#29DC2, IRGKangXi=1470.101, RSKangXi=195.6
29DC3 CJK UNIFIED IDEOGRAPH-#29DC3, IRGKangXi=1470.101, RSKangXi=195.6
29DC4 CJK UNIFIED IDEOGRAPH-#29DC4, IRGKangXi=1470.101, RSKangXi=195.6
29DC5 CJK UNIFIED IDEOGRAPH-#29DC5, IRGKangXi=1470.101, RSKangXi=195.6
29DC6 CJK UNIFIED IDEOGRAPH-#29DC6, IRGKangXi=1470.101, RSKangXi=195.6
29DC7 CJK UNIFIED IDEOGRAPH-#29DC7, IRGKangXi=1470.101, RSKangXi=195.6
29DC8 CJK UNIFIED IDEOGRAPH-#29DC8, IRGKangXi=1470.101, RSKangXi=195.6
29DC9 CJK UNIFIED IDEOGRAPH-#29DC9, IRGKangXi=1470.101, RSKangXi=195.6
29DCA CJK UNIFIED IDEOGRAPH-#29DCA, IRGKangXi=1470.101, RSKangXi=195.6
29DCB CJK UNIFIED IDEOGRAPH-#29DCB, IRGKangXi=1470.101, RSKangXi=195.6
29DCC CJK UNIFIED IDEOGRAPH-#29DCC, IRGKangXi=1470.101, RSKangXi=195.6
29DCD CJK UNIFIED IDEOGRAPH-#29DCD, IRGKangXi=1470.140, RSKangXi=195.7
29DCE CJK UNIFIED IDEOGRAPH-#29DCE, IRGKangXi=1470.150, RSKangXi=195.7
29DCF CJK UNIFIED IDEOGRAPH-#29DCF, IRGKangXi=1470.160, RSKangXi=195.7
29DD0 CJK UNIFIED IDEOGRAPH-#29DD0, IRGKangXi=1470.200, RSKangXi=195.7
29DD1 CJK UNIFIED IDEOGRAPH-#29DD1, IRGKangXi=1470.240, RSKangXi=195.7
29DD2 CJK UNIFIED IDEOGRAPH-#29DD2, IRGKangXi=1470.250, RSKangXi=195.7
29DD3 CJK UNIFIED IDEOGRAPH-#29DD3, IRGKangXi=1470.260, RSKangXi=195.7
29DD4 CJK UNIFIED IDEOGRAPH-#29DD4, IRGKangXi=1470.290, RSKangXi=195.7
29DD5 CJK UNIFIED IDEOGRAPH-#29DD5, IRGKangXi=1471.050, RSKangXi=195.7
29DD6 CJK UNIFIED IDEOGRAPH-#29DD6, IRGKangXi=1471.160, RSKangXi=195.7
29DD7 CJK UNIFIED IDEOGRAPH-#29DD7, IRGKangXi=1471.230, RSKangXi=195.7
29DD8 CJK UNIFIED IDEOGRAPH-#29DD8, IRGKangXi=1471.240, RSKangXi=195.7
29DD9 CJK UNIFIED IDEOGRAPH-#29DD9, IRGKangXi=1471.250, RSKangXi=195.7
29DDA CJK UNIFIED IDEOGRAPH-#29DDA, IRGKangXi=1471.270, RSKangXi=195.7
29DDB CJK UNIFIED IDEOGRAPH-#29DDB, IRGKangXi=1471.281, RSKangXi=195.7
29DDC CJK UNIFIED IDEOGRAPH-#29DDC, IRGKangXi=1471.281, RSKangXi=195.7
29DDD CJK UNIFIED IDEOGRAPH-#29DDD, IRGKangXi=1471.281, RSKangXi=195.7
29DDE CJK UNIFIED IDEOGRAPH-#29DDE, IRGKangXi=1471.281, RSKangXi=195.7
29DDF CJK UNIFIED IDEOGRAPH-#29DDF, IRGKangXi=1471.281, RSKangXi=195.7
29DE0 CJK UNIFIED IDEOGRAPH-#29DE0, IRGKangXi=1471.281, RSKangXi=195.7
29DE1 CJK UNIFIED IDEOGRAPH-#29DE1, IRGKangXi=1471.281, RSKangXi=195.7
29DE2 CJK UNIFIED IDEOGRAPH-#29DE2, IRGKangXi=1471.281, RSKangXi=195.7
29DE3 CJK UNIFIED IDEOGRAPH-#29DE3, IRGKangXi=1471.281, RSKangXi=195.7
29DE4 CJK UNIFIED IDEOGRAPH-#29DE4, IRGKangXi=1471.281, RSKangXi=195.7
29DE5 CJK UNIFIED IDEOGRAPH-#29DE5, IRGKangXi=1471.281, RSKangXi=195.7
29DE6 CJK UNIFIED IDEOGRAPH-#29DE6, IRGKangXi=1471.281, RSKangXi=195.7
29DE7 CJK UNIFIED IDEOGRAPH-#29DE7, IRGKangXi=1471.281, RSKangXi=195.7
29DE8 CJK UNIFIED IDEOGRAPH-#29DE8, IRGKangXi=1471.281, RSKangXi=195.7
29DE9 CJK UNIFIED IDEOGRAPH-#29DE9, IRGKangXi=1471.281, RSKangXi=195.7
29DEA CJK UNIFIED IDEOGRAPH-#29DEA, IRGKangXi=1471.281, RSKangXi=195.7
29DEB CJK UNIFIED IDEOGRAPH-#29DEB, IRGKangXi=1471.281, RSKangXi=195.7
29DEC CJK UNIFIED IDEOGRAPH-#29DEC, IRGKangXi=1471.281, RSKangXi=195.7
29DED CJK UNIFIED IDEOGRAPH-#29DED, IRGKangXi=1471.281, RSKangXi=195.7
29DEE CJK UNIFIED IDEOGRAPH-#29DEE, IRGKangXi=1471.281, RSKangXi=195.7
29DEF CJK UNIFIED IDEOGRAPH-#29DEF, IRGKangXi=1471.281, RSKangXi=195.7
29DF0 CJK UNIFIED IDEOGRAPH-#29DF0, IRGKangXi=1471.281, RSKangXi=195.7
29DF1 CJK UNIFIED IDEOGRAPH-#29DF1, IRGKangXi=1471.281, RSKangXi=195.7
29DF2 CJK UNIFIED IDEOGRAPH-#29DF2, IRGKangXi=1471.281, RSKangXi=195.7
29DF3 CJK UNIFIED IDEOGRAPH-#29DF3, IRGKangXi=1471.281, RSKangXi=195.7
29DF4 CJK UNIFIED IDEOGRAPH-#29DF4, IRGKangXi=1471.281, RSKangXi=195.7
29DF5 CJK UNIFIED IDEOGRAPH-#29DF5, IRGKangXi=1471.281, RSKangXi=195.7
29DF6 CJK UNIFIED IDEOGRAPH-#29DF6, IRGKangXi=1471.281, RSKangXi=195.7
29DF7 CJK UNIFIED IDEOGRAPH-#29DF7, IRGKangXi=1471.290, RSKangXi=195.8
29DF8 CJK UNIFIED IDEOGRAPH-#29DF8, IRGKangXi=1471.300, RSKangXi=195.8, Def{(same as U+9B74 魴) triangular bream}
29DF9 CJK UNIFIED IDEOGRAPH-#29DF9, IRGKangXi=1471.310, RSKangXi=195.8
29DFA CJK UNIFIED IDEOGRAPH-#29DFA, IRGKangXi=1472.050, RSKangXi=195.8
29DFB CJK UNIFIED IDEOGRAPH-#29DFB, IRGKangXi=1472.100, RSKangXi=195.8
29DFC CJK UNIFIED IDEOGRAPH-#29DFC, IRGKangXi=1472.120, RSKangXi=195.8
29DFD CJK UNIFIED IDEOGRAPH-#29DFD, IRGKangXi=1472.130, RSKangXi=195.8
29DFE CJK UNIFIED IDEOGRAPH-#29DFE, IRGKangXi=1472.200, RSKangXi=195.8
29DFF CJK UNIFIED IDEOGRAPH-#29DFF, IRGKangXi=1472.210, RSKangXi=195.8
29E00 CJK UNIFIED IDEOGRAPH-#29E00, IRGKangXi=1472.220, RSKangXi=195.8
29E01 CJK UNIFIED IDEOGRAPH-#29E01, IRGKangXi=1472.240, RSKangXi=195.8
29E02 CJK UNIFIED IDEOGRAPH-#29E02, IRGKangXi=1472.270, RSKangXi=195.8
29E03 CJK UNIFIED IDEOGRAPH-#29E03, IRGKangXi=1472.300, RSKangXi=195.8
29E04 CJK UNIFIED IDEOGRAPH-#29E04, IRGKangXi=1472.310, RSKangXi=195.8
29E05 CJK UNIFIED IDEOGRAPH-#29E05, IRGKangXi=1472.340, RSKangXi=195.8
29E06 CJK UNIFIED IDEOGRAPH-#29E06, IRGKangXi=1472.360, RSKangXi=195.8
29E07 CJK UNIFIED IDEOGRAPH-#29E07, IRGKangXi=1473.010, RSKangXi=195.8
29E08 CJK UNIFIED IDEOGRAPH-#29E08, IRGKangXi=1473.030, RSKangXi=195.8
29E09 CJK UNIFIED IDEOGRAPH-#29E09, IRGKangXi=1473.070, RSKangXi=195.8
29E0A CJK UNIFIED IDEOGRAPH-#29E0A, IRGKangXi=1473.110, RSKangXi=195.8
29E0B CJK UNIFIED IDEOGRAPH-#29E0B, IRGKangXi=1473.200, RSKangXi=195.8
29E0C CJK UNIFIED IDEOGRAPH-#29E0C, IRGKangXi=1473.220, RSKangXi=195.8
29E0D CJK UNIFIED IDEOGRAPH-#29E0D, IRGKangXi=1473.230, RSKangXi=195.8
29E0E CJK UNIFIED IDEOGRAPH-#29E0E, IRGKangXi=1473.240, RSKangXi=195.8
29E0F CJK UNIFIED IDEOGRAPH-#29E0F, IRGKangXi=1473.250, RSKangXi=195.8
29E10 CJK UNIFIED IDEOGRAPH-#29E10, IRGKangXi=1473.260, RSKangXi=195.8
29E11 CJK UNIFIED IDEOGRAPH-#29E11, IRGKangXi=1473.271, RSKangXi=195.8
29E12 CJK UNIFIED IDEOGRAPH-#29E12, IRGKangXi=1473.271, RSKangXi=195.8
29E13 CJK UNIFIED IDEOGRAPH-#29E13, IRGKangXi=1473.271, RSKangXi=195.8
29E14 CJK UNIFIED IDEOGRAPH-#29E14, IRGKangXi=1473.271, RSKangXi=195.8
29E15 CJK UNIFIED IDEOGRAPH-#29E15, IRGKangXi=1473.271, RSKangXi=195.8
29E16 CJK UNIFIED IDEOGRAPH-#29E16, IRGKangXi=1473.271, RSKangXi=195.8
29E17 CJK UNIFIED IDEOGRAPH-#29E17, IRGKangXi=1473.271, RSKangXi=195.8
29E18 CJK UNIFIED IDEOGRAPH-#29E18, IRGKangXi=1473.271, RSKangXi=195.8
29E19 CJK UNIFIED IDEOGRAPH-#29E19, IRGKangXi=1473.271, RSKangXi=195.8
29E1A CJK UNIFIED IDEOGRAPH-#29E1A, IRGKangXi=1473.271, RSKangXi=195.8
29E1B CJK UNIFIED IDEOGRAPH-#29E1B, IRGKangXi=1473.271, RSKangXi=195.8
29E1C CJK UNIFIED IDEOGRAPH-#29E1C, IRGKangXi=1473.271, RSKangXi=195.8
29E1D CJK UNIFIED IDEOGRAPH-#29E1D, IRGKangXi=1473.271, RSKangXi=195.8
29E1E CJK UNIFIED IDEOGRAPH-#29E1E, IRGKangXi=1473.271, RSKangXi=195.8
29E1F CJK UNIFIED IDEOGRAPH-#29E1F, IRGKangXi=1473.271, RSKangXi=195.8
29E20 CJK UNIFIED IDEOGRAPH-#29E20, IRGKangXi=1473.271, RSKangXi=195.8
29E21 CJK UNIFIED IDEOGRAPH-#29E21, IRGKangXi=1473.271, RSKangXi=195.8
29E22 CJK UNIFIED IDEOGRAPH-#29E22, IRGKangXi=1473.271, RSKangXi=195.8
29E23 CJK UNIFIED IDEOGRAPH-#29E23, IRGKangXi=1473.271, RSKangXi=195.8
29E24 CJK UNIFIED IDEOGRAPH-#29E24, IRGKangXi=1473.271, RSKangXi=195.8
29E25 CJK UNIFIED IDEOGRAPH-#29E25, IRGKangXi=1473.271, RSKangXi=195.8
29E26 CJK UNIFIED IDEOGRAPH-#29E26, IRGKangXi=1473.271, RSKangXi=195.8
29E27 CJK UNIFIED IDEOGRAPH-#29E27, IRGKangXi=1473.271, RSKangXi=195.8
29E28 CJK UNIFIED IDEOGRAPH-#29E28, IRGKangXi=1473.271, RSKangXi=195.8, Def{male whale}
29E29 CJK UNIFIED IDEOGRAPH-#29E29, IRGKangXi=1473.271, RSKangXi=195.8
29E2A CJK UNIFIED IDEOGRAPH-#29E2A, IRGKangXi=1473.271, RSKangXi=195.8
29E2B CJK UNIFIED IDEOGRAPH-#29E2B, IRGKangXi=1473.271, RSKangXi=195.8
29E2C CJK UNIFIED IDEOGRAPH-#29E2C, IRGKangXi=1473.271, RSKangXi=195.8
29E2D CJK UNIFIED IDEOGRAPH-#29E2D, IRGKangXi=1473.271, RSKangXi=195.8
29E2E CJK UNIFIED IDEOGRAPH-#29E2E, IRGKangXi=1473.271, RSKangXi=195.8
29E2F CJK UNIFIED IDEOGRAPH-#29E2F, IRGKangXi=1473.271, RSKangXi=195.8
29E30 CJK UNIFIED IDEOGRAPH-#29E30, IRGKangXi=1473.271, RSKangXi=195.8
29E31 CJK UNIFIED IDEOGRAPH-#29E31, IRGKangXi=1473.271, RSKangXi=195.8
29E32 CJK UNIFIED IDEOGRAPH-#29E32, IRGKangXi=1473.271, RSKangXi=195.8
29E33 CJK UNIFIED IDEOGRAPH-#29E33, IRGKangXi=1473.271, RSKangXi=195.8
29E34 CJK UNIFIED IDEOGRAPH-#29E34, IRGKangXi=1473.271, RSKangXi=195.8
29E35 CJK UNIFIED IDEOGRAPH-#29E35, IRGKangXi=1473.271, RSKangXi=195.8
29E36 CJK UNIFIED IDEOGRAPH-#29E36, IRGKangXi=1473.271, RSKangXi=195.8
29E37 CJK UNIFIED IDEOGRAPH-#29E37, IRGKangXi=1473.271, RSKangXi=195.8
29E38 CJK UNIFIED IDEOGRAPH-#29E38, IRGKangXi=1473.271, RSKangXi=195.8
29E39 CJK UNIFIED IDEOGRAPH-#29E39, IRGKangXi=1473.271, RSKangXi=195.8
29E3A CJK UNIFIED IDEOGRAPH-#29E3A, IRGKangXi=1473.271, RSKangXi=195.8
29E3B CJK UNIFIED IDEOGRAPH-#29E3B, IRGKangXi=1473.271, RSKangXi=195.8
29E3C CJK UNIFIED IDEOGRAPH-#29E3C, IRGKangXi=1473.271, RSKangXi=195.8
29E3D CJK UNIFIED IDEOGRAPH-#29E3D, IRGKangXi=1473.271, RSKangXi=195.8
29E3E CJK UNIFIED IDEOGRAPH-#29E3E, IRGKangXi=1473.310, RSKangXi=195.9
29E3F CJK UNIFIED IDEOGRAPH-#29E3F, IRGKangXi=1473.330, RSKangXi=195.9
29E40 CJK UNIFIED IDEOGRAPH-#29E40, IRGKangXi=1473.340, RSKangXi=195.9
29E41 CJK UNIFIED IDEOGRAPH-#29E41, IRGKangXi=1473.360, RSKangXi=195.9
29E42 CJK UNIFIED IDEOGRAPH-#29E42, IRGKangXi=1474.020, RSKangXi=195.9
29E43 CJK UNIFIED IDEOGRAPH-#29E43, IRGKangXi=1474.130, RSKangXi=195.9
29E44 CJK UNIFIED IDEOGRAPH-#29E44, IRGKangXi=1474.140, RSKangXi=195.9
29E45 CJK UNIFIED IDEOGRAPH-#29E45, IRGKangXi=1474.180, RSKangXi=195.9
29E46 CJK UNIFIED IDEOGRAPH-#29E46, IRGKangXi=1474.200, RSKangXi=195.9
29E47 CJK UNIFIED IDEOGRAPH-#29E47, IRGKangXi=1474.220, RSKangXi=195.9
29E48 CJK UNIFIED IDEOGRAPH-#29E48, IRGKangXi=1474.230, RSKangXi=195.9
29E49 CJK UNIFIED IDEOGRAPH-#29E49, IRGKangXi=1474.290, RSKangXi=195.9
29E4A CJK UNIFIED IDEOGRAPH-#29E4A, IRGKangXi=1474.300, RSKangXi=195.9
29E4B CJK UNIFIED IDEOGRAPH-#29E4B, IRGKangXi=1474.360, RSKangXi=195.9
29E4C CJK UNIFIED IDEOGRAPH-#29E4C, IRGKangXi=1474.370, RSKangXi=195.9
29E4D CJK UNIFIED IDEOGRAPH-#29E4D, IRGKangXi=1475.050, RSKangXi=195.9
29E4E CJK UNIFIED IDEOGRAPH-#29E4E, IRGKangXi=1475.060, RSKangXi=195.9
29E4F CJK UNIFIED IDEOGRAPH-#29E4F, IRGKangXi=1475.070, RSKangXi=195.9
29E50 CJK UNIFIED IDEOGRAPH-#29E50, IRGKangXi=1475.120, RSKangXi=195.9
29E51 CJK UNIFIED IDEOGRAPH-#29E51, IRGKangXi=1475.130, RSKangXi=195.9
29E52 CJK UNIFIED IDEOGRAPH-#29E52, IRGKangXi=1475.150, RSKangXi=195.9
29E53 CJK UNIFIED IDEOGRAPH-#29E53, IRGKangXi=1475.161, RSKangXi=195.9
29E54 CJK UNIFIED IDEOGRAPH-#29E54, IRGKangXi=1475.161, RSKangXi=195.9
29E55 CJK UNIFIED IDEOGRAPH-#29E55, IRGKangXi=1475.161, RSKangXi=195.9
29E56 CJK UNIFIED IDEOGRAPH-#29E56, IRGKangXi=1475.161, RSKangXi=195.9
29E57 CJK UNIFIED IDEOGRAPH-#29E57, IRGKangXi=1475.161, RSKangXi=195.9
29E58 CJK UNIFIED IDEOGRAPH-#29E58, IRGKangXi=1475.161, RSKangXi=195.9
29E59 CJK UNIFIED IDEOGRAPH-#29E59, IRGKangXi=1475.161, RSKangXi=195.9
29E5A CJK UNIFIED IDEOGRAPH-#29E5A, IRGKangXi=1475.161, RSKangXi=195.9
29E5B CJK UNIFIED IDEOGRAPH-#29E5B, IRGKangXi=1475.161, RSKangXi=195.9
29E5C CJK UNIFIED IDEOGRAPH-#29E5C, IRGKangXi=1475.161, RSKangXi=195.9
29E5D CJK UNIFIED IDEOGRAPH-#29E5D, IRGKangXi=1475.161, RSKangXi=195.9
29E5E CJK UNIFIED IDEOGRAPH-#29E5E, IRGKangXi=1475.161, RSKangXi=195.9
29E5F CJK UNIFIED IDEOGRAPH-#29E5F, IRGKangXi=1475.161, RSKangXi=195.9
29E60 CJK UNIFIED IDEOGRAPH-#29E60, IRGKangXi=1475.161, RSKangXi=195.9
29E61 CJK UNIFIED IDEOGRAPH-#29E61, IRGKangXi=1475.161, RSKangXi=195.9
29E62 CJK UNIFIED IDEOGRAPH-#29E62, IRGKangXi=1475.161, RSKangXi=195.9
29E63 CJK UNIFIED IDEOGRAPH-#29E63, IRGKangXi=1475.161, RSKangXi=195.9
29E64 CJK UNIFIED IDEOGRAPH-#29E64, IRGKangXi=1475.161, RSKangXi=195.9
29E65 CJK UNIFIED IDEOGRAPH-#29E65, IRGKangXi=1475.161, RSKangXi=195.9
29E66 CJK UNIFIED IDEOGRAPH-#29E66, IRGKangXi=1475.161, RSKangXi=195.9
29E67 CJK UNIFIED IDEOGRAPH-#29E67, IRGKangXi=1475.161, RSKangXi=195.9
29E68 CJK UNIFIED IDEOGRAPH-#29E68, IRGKangXi=1475.161, RSKangXi=195.9
29E69 CJK UNIFIED IDEOGRAPH-#29E69, IRGKangXi=1475.161, RSKangXi=195.9
29E6A CJK UNIFIED IDEOGRAPH-#29E6A, IRGKangXi=1475.161, RSKangXi=195.9
29E6B CJK UNIFIED IDEOGRAPH-#29E6B, IRGKangXi=1475.161, RSKangXi=195.9
29E6C CJK UNIFIED IDEOGRAPH-#29E6C, IRGKangXi=1475.161, RSKangXi=195.9
29E6D CJK UNIFIED IDEOGRAPH-#29E6D, IRGKangXi=1475.161, RSKangXi=195.9
29E6E CJK UNIFIED IDEOGRAPH-#29E6E, IRGKangXi=1475.161, RSKangXi=195.9
29E6F CJK UNIFIED IDEOGRAPH-#29E6F, IRGKangXi=1475.161, RSKangXi=195.9
29E70 CJK UNIFIED IDEOGRAPH-#29E70, IRGKangXi=1475.161, RSKangXi=195.9
29E71 CJK UNIFIED IDEOGRAPH-#29E71, IRGKangXi=1475.180, RSKangXi=195.10
29E72 CJK UNIFIED IDEOGRAPH-#29E72, IRGKangXi=1475.190, RSKangXi=195.10
29E73 CJK UNIFIED IDEOGRAPH-#29E73, IRGKangXi=1475.240, RSKangXi=195.10
29E74 CJK UNIFIED IDEOGRAPH-#29E74, IRGKangXi=1475.250, RSKangXi=195.10
29E75 CJK UNIFIED IDEOGRAPH-#29E75, IRGKangXi=1475.260, RSKangXi=195.10
29E76 CJK UNIFIED IDEOGRAPH-#29E76, IRGKangXi=1475.270, RSKangXi=195.10
29E77 CJK UNIFIED IDEOGRAPH-#29E77, IRGKangXi=1475.280, RSKangXi=195.10
29E78 CJK UNIFIED IDEOGRAPH-#29E78, IRGKangXi=1475.290, RSKangXi=195.10
29E79 CJK UNIFIED IDEOGRAPH-#29E79, IRGKangXi=1475.320, RSKangXi=195.10
29E7A CJK UNIFIED IDEOGRAPH-#29E7A, IRGKangXi=1475.340, RSKangXi=195.10
29E7B CJK UNIFIED IDEOGRAPH-#29E7B, IRGKangXi=1475.370, RSKangXi=195.10
29E7C CJK UNIFIED IDEOGRAPH-#29E7C, IRGKangXi=1476.020, RSKangXi=195.10
29E7D CJK UNIFIED IDEOGRAPH-#29E7D, IRGKangXi=1476.040, RSKangXi=195.10
29E7E CJK UNIFIED IDEOGRAPH-#29E7E, IRGKangXi=1476.070, RSKangXi=195.10
29E7F CJK UNIFIED IDEOGRAPH-#29E7F, IRGKangXi=1476.120, RSKangXi=195.10
29E80 CJK UNIFIED IDEOGRAPH-#29E80, IRGKangXi=1476.150, RSKangXi=195.10
29E81 CJK UNIFIED IDEOGRAPH-#29E81, IRGKangXi=1476.190, RSKangXi=195.10
29E82 CJK UNIFIED IDEOGRAPH-#29E82, IRGKangXi=1476.210, RSKangXi=195.10
29E83 CJK UNIFIED IDEOGRAPH-#29E83, IRGKangXi=1476.220, RSKangXi=195.10
29E84 CJK UNIFIED IDEOGRAPH-#29E84, IRGKangXi=1476.230, RSKangXi=195.10
29E85 CJK UNIFIED IDEOGRAPH-#29E85, IRGKangXi=1476.240, RSKangXi=195.10
29E86 CJK UNIFIED IDEOGRAPH-#29E86, IRGKangXi=1476.250, RSKangXi=195.10
29E87 CJK UNIFIED IDEOGRAPH-#29E87, IRGKangXi=1476.251, RSKangXi=195.10
29E88 CJK UNIFIED IDEOGRAPH-#29E88, IRGKangXi=1476.251, RSKangXi=195.10
29E89 CJK UNIFIED IDEOGRAPH-#29E89, IRGKangXi=1476.251, RSKangXi=195.10
29E8A CJK UNIFIED IDEOGRAPH-#29E8A, IRGKangXi=1476.251, RSKangXi=195.10
29E8B CJK UNIFIED IDEOGRAPH-#29E8B, IRGKangXi=1476.251, RSKangXi=195.10
29E8C CJK UNIFIED IDEOGRAPH-#29E8C, IRGKangXi=1476.251, RSKangXi=195.10
29E8D CJK UNIFIED IDEOGRAPH-#29E8D, IRGKangXi=1476.251, RSKangXi=195.10
29E8E CJK UNIFIED IDEOGRAPH-#29E8E, IRGKangXi=1476.251, RSKangXi=195.10
29E8F CJK UNIFIED IDEOGRAPH-#29E8F, IRGKangXi=1476.251, RSKangXi=195.10
29E90 CJK UNIFIED IDEOGRAPH-#29E90, IRGKangXi=1476.251, RSKangXi=195.10
29E91 CJK UNIFIED IDEOGRAPH-#29E91, IRGKangXi=1476.251, RSKangXi=195.10
29E92 CJK UNIFIED IDEOGRAPH-#29E92, IRGKangXi=1476.251, RSKangXi=195.10
29E93 CJK UNIFIED IDEOGRAPH-#29E93, IRGKangXi=1476.251, RSKangXi=195.10
29E94 CJK UNIFIED IDEOGRAPH-#29E94, IRGKangXi=1476.251, RSKangXi=195.10
29E95 CJK UNIFIED IDEOGRAPH-#29E95, IRGKangXi=1476.251, RSKangXi=195.10
29E96 CJK UNIFIED IDEOGRAPH-#29E96, IRGKangXi=1476.251, RSKangXi=195.10
29E97 CJK UNIFIED IDEOGRAPH-#29E97, IRGKangXi=1476.251, RSKangXi=195.10
29E98 CJK UNIFIED IDEOGRAPH-#29E98, IRGKangXi=1476.251, RSKangXi=195.10
29E99 CJK UNIFIED IDEOGRAPH-#29E99, IRGKangXi=1476.251, RSKangXi=195.10
29E9A CJK UNIFIED IDEOGRAPH-#29E9A, IRGKangXi=1476.251, RSKangXi=195.10
29E9B CJK UNIFIED IDEOGRAPH-#29E9B, IRGKangXi=1476.251, RSKangXi=195.10
29E9C CJK UNIFIED IDEOGRAPH-#29E9C, IRGKangXi=1476.251, RSKangXi=195.10
29E9D CJK UNIFIED IDEOGRAPH-#29E9D, IRGKangXi=1476.251, RSKangXi=195.10
29E9E CJK UNIFIED IDEOGRAPH-#29E9E, IRGKangXi=1476.251, RSKangXi=195.10
29E9F CJK UNIFIED IDEOGRAPH-#29E9F, IRGKangXi=1476.251, RSKangXi=195.10
29EA0 CJK UNIFIED IDEOGRAPH-#29EA0, IRGKangXi=1476.251, RSKangXi=195.10
29EA1 CJK UNIFIED IDEOGRAPH-#29EA1, IRGKangXi=1476.251, RSKangXi=195.10
29EA2 CJK UNIFIED IDEOGRAPH-#29EA2, IRGKangXi=1476.251, RSKangXi=195.10
29EA3 CJK UNIFIED IDEOGRAPH-#29EA3, IRGKangXi=1476.251, RSKangXi=195.10
29EA4 CJK UNIFIED IDEOGRAPH-#29EA4, IRGKangXi=1476.251, RSKangXi=195.10
29EA5 CJK UNIFIED IDEOGRAPH-#29EA5, IRGKangXi=1476.251, RSKangXi=195.10
29EA6 CJK UNIFIED IDEOGRAPH-#29EA6, IRGKangXi=1476.251, RSKangXi=195.10
29EA7 CJK UNIFIED IDEOGRAPH-#29EA7, IRGKangXi=1476.251, RSKangXi=195.10
29EA8 CJK UNIFIED IDEOGRAPH-#29EA8, IRGKangXi=1476.251, RSKangXi=195.10
29EA9 CJK UNIFIED IDEOGRAPH-#29EA9, IRGKangXi=1476.251, RSKangXi=195.10
29EAA CJK UNIFIED IDEOGRAPH-#29EAA, IRGKangXi=1476.251, RSKangXi=195.10
29EAB CJK UNIFIED IDEOGRAPH-#29EAB, IRGKangXi=1476.251, RSKangXi=195.10
29EAC CJK UNIFIED IDEOGRAPH-#29EAC, IRGKangXi=1476.251, RSKangXi=195.10
29EAD CJK UNIFIED IDEOGRAPH-#29EAD, IRGKangXi=1476.290, RSKangXi=195.11
29EAE CJK UNIFIED IDEOGRAPH-#29EAE, IRGKangXi=1476.300, RSKangXi=195.11
29EAF CJK UNIFIED IDEOGRAPH-#29EAF, IRGKangXi=1476.320, RSKangXi=195.11
29EB0 CJK UNIFIED IDEOGRAPH-#29EB0, IRGKangXi=1476.340, RSKangXi=195.11
29EB1 CJK UNIFIED IDEOGRAPH-#29EB1, IRGKangXi=1476.350, RSKangXi=195.11
29EB2 CJK UNIFIED IDEOGRAPH-#29EB2, IRGKangXi=1476.370, RSKangXi=195.11
29EB3 CJK UNIFIED IDEOGRAPH-#29EB3, IRGKangXi=1476.390, RSKangXi=195.11
29EB4 CJK UNIFIED IDEOGRAPH-#29EB4, IRGKangXi=1476.430, RSKangXi=195.11
29EB5 CJK UNIFIED IDEOGRAPH-#29EB5, IRGKangXi=1477.030, RSKangXi=195.11
29EB6 CJK UNIFIED IDEOGRAPH-#29EB6, IRGKangXi=1477.040, RSKangXi=195.11
29EB7 CJK UNIFIED IDEOGRAPH-#29EB7, IRGKangXi=1477.100, RSKangXi=195.11
29EB8 CJK UNIFIED IDEOGRAPH-#29EB8, IRGKangXi=1477.120, RSKangXi=195.11
29EB9 CJK UNIFIED IDEOGRAPH-#29EB9, IRGKangXi=1477.150, RSKangXi=195.11
29EBA CJK UNIFIED IDEOGRAPH-#29EBA, IRGKangXi=1477.170, RSKangXi=195.11
29EBB CJK UNIFIED IDEOGRAPH-#29EBB, IRGKangXi=1477.190, RSKangXi=195.11
29EBC CJK UNIFIED IDEOGRAPH-#29EBC, IRGKangXi=1477.250, RSKangXi=195.11
29EBD CJK UNIFIED IDEOGRAPH-#29EBD, IRGKangXi=1477.270, RSKangXi=195.11
29EBE CJK UNIFIED IDEOGRAPH-#29EBE, IRGKangXi=1477.300, RSKangXi=195.11
29EBF CJK UNIFIED IDEOGRAPH-#29EBF, IRGKangXi=1477.301, RSKangXi=195.11
29EC0 CJK UNIFIED IDEOGRAPH-#29EC0, IRGKangXi=1477.301, RSKangXi=195.11
29EC1 CJK UNIFIED IDEOGRAPH-#29EC1, IRGKangXi=1477.301, RSKangXi=195.11
29EC2 CJK UNIFIED IDEOGRAPH-#29EC2, IRGKangXi=1477.301, RSKangXi=195.11
29EC3 CJK UNIFIED IDEOGRAPH-#29EC3, IRGKangXi=1477.301, RSKangXi=195.11
29EC4 CJK UNIFIED IDEOGRAPH-#29EC4, IRGKangXi=1477.301, RSKangXi=195.11
29EC5 CJK UNIFIED IDEOGRAPH-#29EC5, IRGKangXi=1477.301, RSKangXi=195.11
29EC6 CJK UNIFIED IDEOGRAPH-#29EC6, IRGKangXi=1477.301, RSKangXi=195.11
29EC7 CJK UNIFIED IDEOGRAPH-#29EC7, IRGKangXi=1477.301, RSKangXi=195.11
29EC8 CJK UNIFIED IDEOGRAPH-#29EC8, IRGKangXi=1477.301, RSKangXi=195.11
29EC9 CJK UNIFIED IDEOGRAPH-#29EC9, IRGKangXi=1477.301, RSKangXi=195.11
29ECA CJK UNIFIED IDEOGRAPH-#29ECA, IRGKangXi=1477.301, RSKangXi=195.11
29ECB CJK UNIFIED IDEOGRAPH-#29ECB, IRGKangXi=1477.301, RSKangXi=195.11
29ECC CJK UNIFIED IDEOGRAPH-#29ECC, IRGKangXi=1477.301, RSKangXi=195.11
29ECD CJK UNIFIED IDEOGRAPH-#29ECD, IRGKangXi=1477.301, RSKangXi=195.11
29ECE CJK UNIFIED IDEOGRAPH-#29ECE, IRGKangXi=1477.301, RSKangXi=195.11
29ECF CJK UNIFIED IDEOGRAPH-#29ECF, IRGKangXi=1477.301, RSKangXi=195.11
29ED0 CJK UNIFIED IDEOGRAPH-#29ED0, IRGKangXi=1477.301, RSKangXi=195.11
29ED1 CJK UNIFIED IDEOGRAPH-#29ED1, IRGKangXi=1477.301, RSKangXi=195.11
29ED2 CJK UNIFIED IDEOGRAPH-#29ED2, IRGKangXi=1477.301, RSKangXi=195.11
29ED3 CJK UNIFIED IDEOGRAPH-#29ED3, IRGKangXi=1477.301, RSKangXi=195.11
29ED4 CJK UNIFIED IDEOGRAPH-#29ED4, IRGKangXi=1477.301, RSKangXi=195.11
29ED5 CJK UNIFIED IDEOGRAPH-#29ED5, IRGKangXi=1477.301, RSKangXi=195.11
29ED6 CJK UNIFIED IDEOGRAPH-#29ED6, IRGKangXi=1477.301, RSKangXi=195.11
29ED7 CJK UNIFIED IDEOGRAPH-#29ED7, IRGKangXi=1477.301, RSKangXi=195.11
29ED8 CJK UNIFIED IDEOGRAPH-#29ED8, IRGKangXi=1477.340, RSKangXi=195.12
29ED9 CJK UNIFIED IDEOGRAPH-#29ED9, IRGKangXi=1477.350, RSKangXi=195.12
29EDA CJK UNIFIED IDEOGRAPH-#29EDA, IRGKangXi=1477.360, RSKangXi=195.12
29EDB CJK UNIFIED IDEOGRAPH-#29EDB, IRGKangXi=1477.390, RSKangXi=195.12
29EDC CJK UNIFIED IDEOGRAPH-#29EDC, IRGKangXi=1478.020, RSKangXi=195.12
29EDD CJK UNIFIED IDEOGRAPH-#29EDD, IRGKangXi=1478.030, RSKangXi=195.12
29EDE CJK UNIFIED IDEOGRAPH-#29EDE, IRGKangXi=1478.060, RSKangXi=195.12
29EDF CJK UNIFIED IDEOGRAPH-#29EDF, IRGKangXi=1478.110, RSKangXi=195.12
29EE0 CJK UNIFIED IDEOGRAPH-#29EE0, IRGKangXi=1478.130, RSKangXi=195.12
29EE1 CJK UNIFIED IDEOGRAPH-#29EE1, IRGKangXi=1478.140, RSKangXi=195.12
29EE2 CJK UNIFIED IDEOGRAPH-#29EE2, IRGKangXi=1478.180, RSKangXi=195.12
29EE3 CJK UNIFIED IDEOGRAPH-#29EE3, IRGKangXi=1478.230, RSKangXi=195.12
29EE4 CJK UNIFIED IDEOGRAPH-#29EE4, IRGKangXi=1478.250, RSKangXi=195.12
29EE5 CJK UNIFIED IDEOGRAPH-#29EE5, IRGKangXi=1478.270, RSKangXi=195.12
29EE6 CJK UNIFIED IDEOGRAPH-#29EE6, IRGKangXi=1478.280, RSKangXi=195.12
29EE7 CJK UNIFIED IDEOGRAPH-#29EE7, IRGKangXi=1478.300, RSKangXi=195.12
29EE8 CJK UNIFIED IDEOGRAPH-#29EE8, IRGKangXi=1478.310, RSKangXi=195.12
29EE9 CJK UNIFIED IDEOGRAPH-#29EE9, IRGKangXi=1478.311, RSKangXi=195.12
29EEA CJK UNIFIED IDEOGRAPH-#29EEA, IRGKangXi=1478.311, RSKangXi=195.12
29EEB CJK UNIFIED IDEOGRAPH-#29EEB, IRGKangXi=1478.311, RSKangXi=195.12
29EEC CJK UNIFIED IDEOGRAPH-#29EEC, IRGKangXi=1478.311, RSKangXi=195.12
29EED CJK UNIFIED IDEOGRAPH-#29EED, IRGKangXi=1478.311, RSKangXi=195.12
29EEE CJK UNIFIED IDEOGRAPH-#29EEE, IRGKangXi=1478.311, RSKangXi=195.12
29EEF CJK UNIFIED IDEOGRAPH-#29EEF, IRGKangXi=1478.311, RSKangXi=195.12
29EF0 CJK UNIFIED IDEOGRAPH-#29EF0, IRGKangXi=1478.311, RSKangXi=195.12
29EF1 CJK UNIFIED IDEOGRAPH-#29EF1, IRGKangXi=1478.311, RSKangXi=195.12
29EF2 CJK UNIFIED IDEOGRAPH-#29EF2, IRGKangXi=1478.311, RSKangXi=195.12
29EF3 CJK UNIFIED IDEOGRAPH-#29EF3, IRGKangXi=1478.311, RSKangXi=195.12
29EF4 CJK UNIFIED IDEOGRAPH-#29EF4, IRGKangXi=1478.311, RSKangXi=195.12
29EF5 CJK UNIFIED IDEOGRAPH-#29EF5, IRGKangXi=1478.311, RSKangXi=195.12
29EF6 CJK UNIFIED IDEOGRAPH-#29EF6, IRGKangXi=1478.311, RSKangXi=195.12
29EF7 CJK UNIFIED IDEOGRAPH-#29EF7, IRGKangXi=1478.311, RSKangXi=195.12
29EF8 CJK UNIFIED IDEOGRAPH-#29EF8, IRGKangXi=1478.311, RSKangXi=195.12
29EF9 CJK UNIFIED IDEOGRAPH-#29EF9, IRGKangXi=1478.311, RSKangXi=195.12
29EFA CJK UNIFIED IDEOGRAPH-#29EFA, IRGKangXi=1478.311, RSKangXi=195.12
29EFB CJK UNIFIED IDEOGRAPH-#29EFB, IRGKangXi=1478.311, RSKangXi=195.12
29EFC CJK UNIFIED IDEOGRAPH-#29EFC, IRGKangXi=1478.311, RSKangXi=195.12
29EFD CJK UNIFIED IDEOGRAPH-#29EFD, IRGKangXi=1478.311, RSKangXi=195.12
29EFE CJK UNIFIED IDEOGRAPH-#29EFE, IRGKangXi=1478.311, RSKangXi=195.12
29EFF CJK UNIFIED IDEOGRAPH-#29EFF, IRGKangXi=1478.311, RSKangXi=195.12
29F00 CJK UNIFIED IDEOGRAPH-#29F00, IRGKangXi=1478.321, RSKangXi=195.12
29F01 CJK UNIFIED IDEOGRAPH-#29F01, IRGKangXi=1478.321, RSKangXi=195.12
29F02 CJK UNIFIED IDEOGRAPH-#29F02, IRGKangXi=1478.340, RSKangXi=195.13
29F03 CJK UNIFIED IDEOGRAPH-#29F03, IRGKangXi=1478.350, RSKangXi=195.13
29F04 CJK UNIFIED IDEOGRAPH-#29F04, IRGKangXi=1478.370, RSKangXi=195.13
29F05 CJK UNIFIED IDEOGRAPH-#29F05, IRGKangXi=1479.010, RSKangXi=195.13
29F06 CJK UNIFIED IDEOGRAPH-#29F06, IRGKangXi=1479.070, RSKangXi=195.13
29F07 CJK UNIFIED IDEOGRAPH-#29F07, IRGKangXi=1479.090, RSKangXi=195.13
29F08 CJK UNIFIED IDEOGRAPH-#29F08, IRGKangXi=1479.100, RSKangXi=195.13, Def{a variety of perch}
29F09 CJK UNIFIED IDEOGRAPH-#29F09, IRGKangXi=1479.150, RSKangXi=195.13
29F0A CJK UNIFIED IDEOGRAPH-#29F0A, IRGKangXi=1479.160, RSKangXi=195.13
29F0B CJK UNIFIED IDEOGRAPH-#29F0B, IRGKangXi=1479.170, RSKangXi=195.13
29F0C CJK UNIFIED IDEOGRAPH-#29F0C, IRGKangXi=1479.190, RSKangXi=195.13
29F0D CJK UNIFIED IDEOGRAPH-#29F0D, IRGKangXi=1479.200, RSKangXi=195.13
29F0E CJK UNIFIED IDEOGRAPH-#29F0E, IRGKangXi=1479.210, RSKangXi=195.13
29F0F CJK UNIFIED IDEOGRAPH-#29F0F, IRGKangXi=1479.220, RSKangXi=195.13
29F10 CJK UNIFIED IDEOGRAPH-#29F10, IRGKangXi=1479.230, RSKangXi=195.13
29F11 CJK UNIFIED IDEOGRAPH-#29F11, IRGKangXi=1479.250, RSKangXi=195.13
29F12 CJK UNIFIED IDEOGRAPH-#29F12, IRGKangXi=1479.260, RSKangXi=195.13
29F13 CJK UNIFIED IDEOGRAPH-#29F13, IRGKangXi=1479.261, RSKangXi=195.13
29F14 CJK UNIFIED IDEOGRAPH-#29F14, IRGKangXi=1479.261, RSKangXi=195.13
29F15 CJK UNIFIED IDEOGRAPH-#29F15, IRGKangXi=1479.261, RSKangXi=195.13
29F16 CJK UNIFIED IDEOGRAPH-#29F16, IRGKangXi=1479.261, RSKangXi=195.13
29F17 CJK UNIFIED IDEOGRAPH-#29F17, IRGKangXi=1479.261, RSKangXi=195.13
29F18 CJK UNIFIED IDEOGRAPH-#29F18, IRGKangXi=1479.261, RSKangXi=195.13
29F19 CJK UNIFIED IDEOGRAPH-#29F19, IRGKangXi=1479.261, RSKangXi=195.13
29F1A CJK UNIFIED IDEOGRAPH-#29F1A, IRGKangXi=1479.261, RSKangXi=195.13
29F1B CJK UNIFIED IDEOGRAPH-#29F1B, IRGKangXi=1479.261, RSKangXi=195.13
29F1C CJK UNIFIED IDEOGRAPH-#29F1C, IRGKangXi=1479.261, RSKangXi=195.13
29F1D CJK UNIFIED IDEOGRAPH-#29F1D, IRGKangXi=1479.261, RSKangXi=195.13
29F1E CJK UNIFIED IDEOGRAPH-#29F1E, IRGKangXi=1479.261, RSKangXi=195.13
29F1F CJK UNIFIED IDEOGRAPH-#29F1F, IRGKangXi=1479.261, RSKangXi=195.13
29F20 CJK UNIFIED IDEOGRAPH-#29F20, IRGKangXi=1479.261, RSKangXi=195.13
29F21 CJK UNIFIED IDEOGRAPH-#29F21, IRGKangXi=1479.261, RSKangXi=195.13
29F22 CJK UNIFIED IDEOGRAPH-#29F22, IRGKangXi=1479.261, RSKangXi=195.13
29F23 CJK UNIFIED IDEOGRAPH-#29F23, IRGKangXi=1479.261, RSKangXi=195.13
29F24 CJK UNIFIED IDEOGRAPH-#29F24, IRGKangXi=1479.261, RSKangXi=195.13
29F25 CJK UNIFIED IDEOGRAPH-#29F25, IRGKangXi=1479.270, RSKangXi=195.14
29F26 CJK UNIFIED IDEOGRAPH-#29F26, IRGKangXi=1479.280, RSKangXi=195.14
29F27 CJK UNIFIED IDEOGRAPH-#29F27, IRGKangXi=1479.300, RSKangXi=195.14
29F28 CJK UNIFIED IDEOGRAPH-#29F28, IRGKangXi=1479.320, RSKangXi=195.14
29F29 CJK UNIFIED IDEOGRAPH-#29F29, IRGKangXi=1480.010, RSKangXi=195.14
29F2A CJK UNIFIED IDEOGRAPH-#29F2A, IRGKangXi=1480.020, RSKangXi=195.14
29F2B CJK UNIFIED IDEOGRAPH-#29F2B, IRGKangXi=1480.030, RSKangXi=195.14
29F2C CJK UNIFIED IDEOGRAPH-#29F2C, IRGKangXi=1480.040, RSKangXi=195.14
29F2D CJK UNIFIED IDEOGRAPH-#29F2D, IRGKangXi=1480.050, RSKangXi=195.14
29F2E CJK UNIFIED IDEOGRAPH-#29F2E, IRGKangXi=1480.070, RSKangXi=195.14
29F2F CJK UNIFIED IDEOGRAPH-#29F2F, IRGKangXi=1480.071, RSKangXi=195.14
29F30 CJK UNIFIED IDEOGRAPH-#29F30, IRGKangXi=1480.071, RSKangXi=195.14
29F31 CJK UNIFIED IDEOGRAPH-#29F31, IRGKangXi=1480.071, RSKangXi=195.14
29F32 CJK UNIFIED IDEOGRAPH-#29F32, IRGKangXi=1480.071, RSKangXi=195.14
29F33 CJK UNIFIED IDEOGRAPH-#29F33, IRGKangXi=1480.071, RSKangXi=195.14
29F34 CJK UNIFIED IDEOGRAPH-#29F34, IRGKangXi=1480.071, RSKangXi=195.14
29F35 CJK UNIFIED IDEOGRAPH-#29F35, IRGKangXi=1480.071, RSKangXi=195.14
29F36 CJK UNIFIED IDEOGRAPH-#29F36, IRGKangXi=1480.071, RSKangXi=195.14
29F37 CJK UNIFIED IDEOGRAPH-#29F37, IRGKangXi=1480.071, RSKangXi=195.14
29F38 CJK UNIFIED IDEOGRAPH-#29F38, IRGKangXi=1480.071, RSKangXi=195.14
29F39 CJK UNIFIED IDEOGRAPH-#29F39, IRGKangXi=1480.071, RSKangXi=195.14
29F3A CJK UNIFIED IDEOGRAPH-#29F3A, IRGKangXi=1480.071, RSKangXi=195.14
29F3B CJK UNIFIED IDEOGRAPH-#29F3B, IRGKangXi=1480.080, RSKangXi=195.15
29F3C CJK UNIFIED IDEOGRAPH-#29F3C, IRGKangXi=1480.100, RSKangXi=195.15
29F3D CJK UNIFIED IDEOGRAPH-#29F3D, IRGKangXi=1480.120, RSKangXi=195.15
29F3E CJK UNIFIED IDEOGRAPH-#29F3E, IRGKangXi=1480.180, RSKangXi=195.15
29F3F CJK UNIFIED IDEOGRAPH-#29F3F, IRGKangXi=1480.190, RSKangXi=195.15
29F40 CJK UNIFIED IDEOGRAPH-#29F40, IRGKangXi=1480.200, RSKangXi=195.15
29F41 CJK UNIFIED IDEOGRAPH-#29F41, IRGKangXi=1480.210, RSKangXi=195.15
29F42 CJK UNIFIED IDEOGRAPH-#29F42, IRGKangXi=1480.211, RSKangXi=195.15
29F43 CJK UNIFIED IDEOGRAPH-#29F43, IRGKangXi=1480.211, RSKangXi=195.15
29F44 CJK UNIFIED IDEOGRAPH-#29F44, IRGKangXi=1480.211, RSKangXi=195.15
29F45 CJK UNIFIED IDEOGRAPH-#29F45, IRGKangXi=1480.211, RSKangXi=195.15
29F46 CJK UNIFIED IDEOGRAPH-#29F46, IRGKangXi=1480.211, RSKangXi=195.15
29F47 CJK UNIFIED IDEOGRAPH-#29F47, IRGKangXi=1480.211, RSKangXi=195.15
29F48 CJK UNIFIED IDEOGRAPH-#29F48, IRGKangXi=1480.211, RSKangXi=195.15
29F49 CJK UNIFIED IDEOGRAPH-#29F49, IRGKangXi=1480.211, RSKangXi=195.15
29F4A CJK UNIFIED IDEOGRAPH-#29F4A, IRGKangXi=1480.211, RSKangXi=195.15
29F4B CJK UNIFIED IDEOGRAPH-#29F4B, IRGKangXi=1480.211, RSKangXi=195.15
29F4C CJK UNIFIED IDEOGRAPH-#29F4C, IRGKangXi=1480.211, RSKangXi=195.15
29F4D CJK UNIFIED IDEOGRAPH-#29F4D, IRGKangXi=1480.250, RSKangXi=195.16
29F4E CJK UNIFIED IDEOGRAPH-#29F4E, IRGKangXi=1480.260, RSKangXi=195.16
29F4F CJK UNIFIED IDEOGRAPH-#29F4F, IRGKangXi=1480.270, RSKangXi=195.16
29F50 CJK UNIFIED IDEOGRAPH-#29F50, IRGKangXi=1480.290, RSKangXi=195.16
29F51 CJK UNIFIED IDEOGRAPH-#29F51, IRGKangXi=1480.291, RSKangXi=195.16
29F52 CJK UNIFIED IDEOGRAPH-#29F52, IRGKangXi=1480.291, RSKangXi=195.16
29F53 CJK UNIFIED IDEOGRAPH-#29F53, IRGKangXi=1480.291, RSKangXi=195.16
29F54 CJK UNIFIED IDEOGRAPH-#29F54, IRGKangXi=1480.291, RSKangXi=195.16
29F55 CJK UNIFIED IDEOGRAPH-#29F55, IRGKangXi=1480.291, RSKangXi=195.16
29F56 CJK UNIFIED IDEOGRAPH-#29F56, IRGKangXi=1480.291, RSKangXi=195.16
29F57 CJK UNIFIED IDEOGRAPH-#29F57, IRGKangXi=1480.291, RSKangXi=195.16
29F58 CJK UNIFIED IDEOGRAPH-#29F58, IRGKangXi=1480.291, RSKangXi=195.16
29F59 CJK UNIFIED IDEOGRAPH-#29F59, IRGKangXi=1480.291, RSKangXi=195.16
29F5A CJK UNIFIED IDEOGRAPH-#29F5A, IRGKangXi=1480.300, RSKangXi=195.17
29F5B CJK UNIFIED IDEOGRAPH-#29F5B, IRGKangXi=1480.310, RSKangXi=195.17
29F5C CJK UNIFIED IDEOGRAPH-#29F5C, IRGKangXi=1480.320, RSKangXi=195.17
29F5D CJK UNIFIED IDEOGRAPH-#29F5D, IRGKangXi=1480.330, RSKangXi=195.17
29F5E CJK UNIFIED IDEOGRAPH-#29F5E, IRGKangXi=1480.340, RSKangXi=195.17
29F5F CJK UNIFIED IDEOGRAPH-#29F5F, IRGKangXi=1480.350, RSKangXi=195.17
29F60 CJK UNIFIED IDEOGRAPH-#29F60, IRGKangXi=1480.360, RSKangXi=195.17
29F61 CJK UNIFIED IDEOGRAPH-#29F61, IRGKangXi=1480.361, RSKangXi=195.17
29F62 CJK UNIFIED IDEOGRAPH-#29F62, IRGKangXi=1480.361, RSKangXi=195.17
29F63 CJK UNIFIED IDEOGRAPH-#29F63, IRGKangXi=1480.361, RSKangXi=195.17
29F64 CJK UNIFIED IDEOGRAPH-#29F64, IRGKangXi=1480.361, RSKangXi=195.17
29F65 CJK UNIFIED IDEOGRAPH-#29F65, IRGKangXi=1480.361, RSKangXi=195.17
29F66 CJK UNIFIED IDEOGRAPH-#29F66, IRGKangXi=1480.361, RSKangXi=195.17
29F67 CJK UNIFIED IDEOGRAPH-#29F67, IRGKangXi=1480.370, RSKangXi=195.18
29F68 CJK UNIFIED IDEOGRAPH-#29F68, IRGKangXi=1480.380, RSKangXi=195.18
29F69 CJK UNIFIED IDEOGRAPH-#29F69, IRGKangXi=1480.400, RSKangXi=195.18
29F6A CJK UNIFIED IDEOGRAPH-#29F6A, IRGKangXi=1480.410, RSKangXi=195.18
29F6B CJK UNIFIED IDEOGRAPH-#29F6B, IRGKangXi=1480.420, RSKangXi=195.18
29F6C CJK UNIFIED IDEOGRAPH-#29F6C, IRGKangXi=1480.430, RSKangXi=195.18
29F6D CJK UNIFIED IDEOGRAPH-#29F6D, IRGKangXi=1480.431, RSKangXi=195.18
29F6E CJK UNIFIED IDEOGRAPH-#29F6E, IRGKangXi=1480.431, RSKangXi=195.18
29F6F CJK UNIFIED IDEOGRAPH-#29F6F, IRGKangXi=1480.431, RSKangXi=195.18
29F70 CJK UNIFIED IDEOGRAPH-#29F70, IRGKangXi=1480.440, RSKangXi=195.19
29F71 CJK UNIFIED IDEOGRAPH-#29F71, IRGKangXi=1480.460, RSKangXi=195.19
29F72 CJK UNIFIED IDEOGRAPH-#29F72, IRGKangXi=1480.461, RSKangXi=195.19
29F73 CJK UNIFIED IDEOGRAPH-#29F73, IRGKangXi=1480.470, RSKangXi=195.20
29F74 CJK UNIFIED IDEOGRAPH-#29F74, IRGKangXi=1480.471, RSKangXi=195.20
29F75 CJK UNIFIED IDEOGRAPH-#29F75, IRGKangXi=1480.480, RSKangXi=195.21
29F76 CJK UNIFIED IDEOGRAPH-#29F76, IRGKangXi=1480.490, RSKangXi=195.21
29F77 CJK UNIFIED IDEOGRAPH-#29F77, IRGKangXi=1480.491, RSKangXi=195.21
29F78 CJK UNIFIED IDEOGRAPH-#29F78, IRGKangXi=1480.491, RSKangXi=195.21
29F79 CJK UNIFIED IDEOGRAPH-#29F79, IRGKangXi=1480.511, RSKangXi=195.4
29F7A CJK UNIFIED IDEOGRAPH-#29F7A, IRGKangXi=1480.511, RSKangXi=195.4
29F7B CJK UNIFIED IDEOGRAPH-#29F7B, IRGKangXi=1480.511, RSKangXi=195.4
29F7C CJK UNIFIED IDEOGRAPH-#29F7C, IRGKangXi=1480.511, RSKangXi=195.6
29F7D CJK UNIFIED IDEOGRAPH-#29F7D, IRGKangXi=1480.511, RSKangXi=195.6
29F7E CJK UNIFIED IDEOGRAPH-#29F7E, IRGKangXi=1480.511, RSKangXi=195.6
29F7F CJK UNIFIED IDEOGRAPH-#29F7F, IRGKangXi=1480.511, RSKangXi=195.6
29F80 CJK UNIFIED IDEOGRAPH-#29F80, IRGKangXi=1480.511, RSKangXi=195.5
29F81 CJK UNIFIED IDEOGRAPH-#29F81, IRGKangXi=1480.511, RSKangXi=195.7
29F82 CJK UNIFIED IDEOGRAPH-#29F82, IRGKangXi=1480.511, RSKangXi=195.7
29F83 CJK UNIFIED IDEOGRAPH-#29F83, IRGKangXi=1480.511, RSKangXi=195.7
29F84 CJK UNIFIED IDEOGRAPH-#29F84, IRGKangXi=1480.511, RSKangXi=195.7
29F85 CJK UNIFIED IDEOGRAPH-#29F85, IRGKangXi=1480.511, RSKangXi=195.8
29F86 CJK UNIFIED IDEOGRAPH-#29F86, IRGKangXi=1480.511, RSKangXi=195.8
29F87 CJK UNIFIED IDEOGRAPH-#29F87, IRGKangXi=1480.511, RSKangXi=195.8
29F88 CJK UNIFIED IDEOGRAPH-#29F88, IRGKangXi=1480.511, RSKangXi=195.8
29F89 CJK UNIFIED IDEOGRAPH-#29F89, IRGKangXi=1480.511, RSKangXi=195.7
29F8A CJK UNIFIED IDEOGRAPH-#29F8A, IRGKangXi=1480.511, RSKangXi=195.9
29F8B CJK UNIFIED IDEOGRAPH-#29F8B, IRGKangXi=1480.511, RSKangXi=195.9
29F8C CJK UNIFIED IDEOGRAPH-#29F8C, IRGKangXi=1480.511, RSKangXi=195.11
29F8D CJK UNIFIED IDEOGRAPH-#29F8D, IRGKangXi=1480.511, RSKangXi=195.13
29F8E CJK UNIFIED IDEOGRAPH-#29F8E, IRGKangXi=1480.511, RSKangXi=195.15
29F8F CJK UNIFIED IDEOGRAPH-#29F8F, IRGKangXi=1481.020, RSKangXi=196.1
29F90 CJK UNIFIED IDEOGRAPH-#29F90, IRGKangXi=1481.021, RSKangXi=196.1
29F91 CJK UNIFIED IDEOGRAPH-#29F91, IRGKangXi=1481.021, RSKangXi=196.1
29F92 CJK UNIFIED IDEOGRAPH-#29F92, IRGKangXi=1481.030, RSKangXi=196.2
29F93 CJK UNIFIED IDEOGRAPH-#29F93, IRGKangXi=1481.040, RSKangXi=196.2
29F94 CJK UNIFIED IDEOGRAPH-#29F94, IRGKangXi=1481.050, RSKangXi=196.2
29F95 CJK UNIFIED IDEOGRAPH-#29F95, IRGKangXi=1481.060, RSKangXi=196.2
29F96 CJK UNIFIED IDEOGRAPH-#29F96, IRGKangXi=1481.080, RSKangXi=196.2
29F97 CJK UNIFIED IDEOGRAPH-#29F97, IRGKangXi=1481.110, RSKangXi=196.2
29F98 CJK UNIFIED IDEOGRAPH-#29F98, IRGKangXi=1481.130, RSKangXi=196.2
29F99 CJK UNIFIED IDEOGRAPH-#29F99, IRGKangXi=1482.020, RSKangXi=196.2
29F9A CJK UNIFIED IDEOGRAPH-#29F9A, IRGKangXi=1482.021, RSKangXi=196.2
29F9B CJK UNIFIED IDEOGRAPH-#29F9B, IRGKangXi=1482.021, RSKangXi=196.2
29F9C CJK UNIFIED IDEOGRAPH-#29F9C, IRGKangXi=1482.021, RSKangXi=196.2
29F9D CJK UNIFIED IDEOGRAPH-#29F9D, IRGKangXi=1482.040, RSKangXi=196.3
29F9E CJK UNIFIED IDEOGRAPH-#29F9E, IRGKangXi=1482.070, RSKangXi=196.3
29F9F CJK UNIFIED IDEOGRAPH-#29F9F, IRGKangXi=1482.080, RSKangXi=196.3
29FA0 CJK UNIFIED IDEOGRAPH-#29FA0, IRGKangXi=1482.090, RSKangXi=196.3
29FA1 CJK UNIFIED IDEOGRAPH-#29FA1, IRGKangXi=1482.120, RSKangXi=196.3
29FA2 CJK UNIFIED IDEOGRAPH-#29FA2, IRGKangXi=1482.210, RSKangXi=196.3
29FA3 CJK UNIFIED IDEOGRAPH-#29FA3, IRGKangXi=1482.220, RSKangXi=196.3
29FA4 CJK UNIFIED IDEOGRAPH-#29FA4, IRGKangXi=1482.230, RSKangXi=196.3
29FA5 CJK UNIFIED IDEOGRAPH-#29FA5, IRGKangXi=1482.240, RSKangXi=196.3
29FA6 CJK UNIFIED IDEOGRAPH-#29FA6, IRGKangXi=1483.010, RSKangXi=196.3
29FA7 CJK UNIFIED IDEOGRAPH-#29FA7, IRGKangXi=1483.030, RSKangXi=196.3
29FA8 CJK UNIFIED IDEOGRAPH-#29FA8, IRGKangXi=1483.031, RSKangXi=196.3
29FA9 CJK UNIFIED IDEOGRAPH-#29FA9, IRGKangXi=1483.031, RSKangXi=196.3
29FAA CJK UNIFIED IDEOGRAPH-#29FAA, IRGKangXi=1483.031, RSKangXi=196.3
29FAB CJK UNIFIED IDEOGRAPH-#29FAB, IRGKangXi=1483.031, RSKangXi=196.3
29FAC CJK UNIFIED IDEOGRAPH-#29FAC, IRGKangXi=1483.031, RSKangXi=196.3
29FAD CJK UNIFIED IDEOGRAPH-#29FAD, IRGKangXi=1483.031, RSKangXi=196.3
29FAE CJK UNIFIED IDEOGRAPH-#29FAE, IRGKangXi=1483.031, RSKangXi=196.3
29FAF CJK UNIFIED IDEOGRAPH-#29FAF, IRGKangXi=1483.031, RSKangXi=196.3
29FB0 CJK UNIFIED IDEOGRAPH-#29FB0, IRGKangXi=1483.031, RSKangXi=196.4
29FB1 CJK UNIFIED IDEOGRAPH-#29FB1, IRGKangXi=1483.050, RSKangXi=196.4
29FB2 CJK UNIFIED IDEOGRAPH-#29FB2, IRGKangXi=1483.070, RSKangXi=196.4
29FB3 CJK UNIFIED IDEOGRAPH-#29FB3, IRGKangXi=1483.100, RSKangXi=196.4
29FB4 CJK UNIFIED IDEOGRAPH-#29FB4, IRGKangXi=1483.110, RSKangXi=196.4
29FB5 CJK UNIFIED IDEOGRAPH-#29FB5, IRGKangXi=1483.120, RSKangXi=196.4
29FB6 CJK UNIFIED IDEOGRAPH-#29FB6, IRGKangXi=1483.190, RSKangXi=196.4
29FB7 CJK UNIFIED IDEOGRAPH-#29FB7, IRGKangXi=1483.200, RSKangXi=196.4
29FB8 CJK UNIFIED IDEOGRAPH-#29FB8, IRGKangXi=1483.210, RSKangXi=196.4
29FB9 CJK UNIFIED IDEOGRAPH-#29FB9, IRGKangXi=1483.220, RSKangXi=196.4
29FBA CJK UNIFIED IDEOGRAPH-#29FBA, IRGKangXi=1483.240, RSKangXi=196.4
29FBB CJK UNIFIED IDEOGRAPH-#29FBB, IRGKangXi=1483.250, RSKangXi=196.4
29FBC CJK UNIFIED IDEOGRAPH-#29FBC, IRGKangXi=1483.260, RSKangXi=196.4
29FBD CJK UNIFIED IDEOGRAPH-#29FBD, IRGKangXi=1483.290, RSKangXi=196.4
29FBE CJK UNIFIED IDEOGRAPH-#29FBE, IRGKangXi=1483.310, RSKangXi=196.4
29FBF CJK UNIFIED IDEOGRAPH-#29FBF, IRGKangXi=1483.360, RSKangXi=196.4
29FC0 CJK UNIFIED IDEOGRAPH-#29FC0, IRGKangXi=1484.030, RSKangXi=196.4
29FC1 CJK UNIFIED IDEOGRAPH-#29FC1, IRGKangXi=1484.060, RSKangXi=196.4
29FC2 CJK UNIFIED IDEOGRAPH-#29FC2, IRGKangXi=1484.070, RSKangXi=196.4
29FC3 CJK UNIFIED IDEOGRAPH-#29FC3, IRGKangXi=1484.100, RSKangXi=196.4
29FC4 CJK UNIFIED IDEOGRAPH-#29FC4, IRGKangXi=1484.110, RSKangXi=196.4
29FC5 CJK UNIFIED IDEOGRAPH-#29FC5, IRGKangXi=1484.140, RSKangXi=196.4
29FC6 CJK UNIFIED IDEOGRAPH-#29FC6, IRGKangXi=1484.150, RSKangXi=196.4
29FC7 CJK UNIFIED IDEOGRAPH-#29FC7, IRGKangXi=1484.180, RSKangXi=196.4
29FC8 CJK UNIFIED IDEOGRAPH-#29FC8, IRGKangXi=1484.190, RSKangXi=196.4
29FC9 CJK UNIFIED IDEOGRAPH-#29FC9, IRGKangXi=1484.200, RSKangXi=196.4
29FCA CJK UNIFIED IDEOGRAPH-#29FCA, IRGKangXi=1484.210, RSKangXi=196.4
29FCB CJK UNIFIED IDEOGRAPH-#29FCB, IRGKangXi=1484.230, RSKangXi=196.4
29FCC CJK UNIFIED IDEOGRAPH-#29FCC, IRGKangXi=1484.260, RSKangXi=196.4
29FCD CJK UNIFIED IDEOGRAPH-#29FCD, IRGKangXi=1484.261, RSKangXi=196.4
29FCE CJK UNIFIED IDEOGRAPH-#29FCE, IRGKangXi=1484.261, RSKangXi=196.4
29FCF CJK UNIFIED IDEOGRAPH-#29FCF, IRGKangXi=1484.261, RSKangXi=196.4
29FD0 CJK UNIFIED IDEOGRAPH-#29FD0, IRGKangXi=1484.261, RSKangXi=196.4
29FD1 CJK UNIFIED IDEOGRAPH-#29FD1, IRGKangXi=1484.261, RSKangXi=196.4
29FD2 CJK UNIFIED IDEOGRAPH-#29FD2, IRGKangXi=1484.261, RSKangXi=196.4
29FD3 CJK UNIFIED IDEOGRAPH-#29FD3, IRGKangXi=1484.261, RSKangXi=196.4
29FD4 CJK UNIFIED IDEOGRAPH-#29FD4, IRGKangXi=1484.261, RSKangXi=196.4
29FD5 CJK UNIFIED IDEOGRAPH-#29FD5, IRGKangXi=1484.261, RSKangXi=196.4
29FD6 CJK UNIFIED IDEOGRAPH-#29FD6, IRGKangXi=1484.261, RSKangXi=196.4
29FD7 CJK UNIFIED IDEOGRAPH-#29FD7, IRGKangXi=1484.261, RSKangXi=196.4
29FD8 CJK UNIFIED IDEOGRAPH-#29FD8, IRGKangXi=1484.261, RSKangXi=196.4
29FD9 CJK UNIFIED IDEOGRAPH-#29FD9, IRGKangXi=1484.261, RSKangXi=196.4
29FDA CJK UNIFIED IDEOGRAPH-#29FDA, IRGKangXi=1484.261, RSKangXi=196.4
29FDB CJK UNIFIED IDEOGRAPH-#29FDB, IRGKangXi=1484.261, RSKangXi=196.4
29FDC CJK UNIFIED IDEOGRAPH-#29FDC, IRGKangXi=1484.290, RSKangXi=196.5
29FDD CJK UNIFIED IDEOGRAPH-#29FDD, IRGKangXi=1484.320, RSKangXi=196.5
29FDE CJK UNIFIED IDEOGRAPH-#29FDE, IRGKangXi=1485.010, RSKangXi=196.5
29FDF CJK UNIFIED IDEOGRAPH-#29FDF, IRGKangXi=1485.030, RSKangXi=196.5
29FE0 CJK UNIFIED IDEOGRAPH-#29FE0, IRGKangXi=1485.060, RSKangXi=196.5
29FE1 CJK UNIFIED IDEOGRAPH-#29FE1, IRGKangXi=1485.070, RSKangXi=196.5
29FE2 CJK UNIFIED IDEOGRAPH-#29FE2, IRGKangXi=1485.090, RSKangXi=196.5
29FE3 CJK UNIFIED IDEOGRAPH-#29FE3, IRGKangXi=1485.170, RSKangXi=196.5
29FE4 CJK UNIFIED IDEOGRAPH-#29FE4, IRGKangXi=1485.220, RSKangXi=196.5
29FE5 CJK UNIFIED IDEOGRAPH-#29FE5, IRGKangXi=1485.230, RSKangXi=196.5
29FE6 CJK UNIFIED IDEOGRAPH-#29FE6, IRGKangXi=1486.030, RSKangXi=196.5
29FE7 CJK UNIFIED IDEOGRAPH-#29FE7, IRGKangXi=1486.090, RSKangXi=196.5
29FE8 CJK UNIFIED IDEOGRAPH-#29FE8, IRGKangXi=1486.110, RSKangXi=196.5
29FE9 CJK UNIFIED IDEOGRAPH-#29FE9, IRGKangXi=1487.010, RSKangXi=196.5
29FEA CJK UNIFIED IDEOGRAPH-#29FEA, IRGKangXi=1487.040, RSKangXi=196.5
29FEB CJK UNIFIED IDEOGRAPH-#29FEB, IRGKangXi=1487.110, RSKangXi=196.5
29FEC CJK UNIFIED IDEOGRAPH-#29FEC, IRGKangXi=1487.120, RSKangXi=196.5
29FED CJK UNIFIED IDEOGRAPH-#29FED, IRGKangXi=1487.140, RSKangXi=196.5
29FEE CJK UNIFIED IDEOGRAPH-#29FEE, IRGKangXi=1487.150, RSKangXi=196.5
29FEF CJK UNIFIED IDEOGRAPH-#29FEF, IRGKangXi=1487.151, RSKangXi=196.5
29FF0 CJK UNIFIED IDEOGRAPH-#29FF0, IRGKangXi=1487.151, RSKangXi=196.5
29FF1 CJK UNIFIED IDEOGRAPH-#29FF1, IRGKangXi=1487.151, RSKangXi=196.5
29FF2 CJK UNIFIED IDEOGRAPH-#29FF2, IRGKangXi=1487.151, RSKangXi=196.5
29FF3 CJK UNIFIED IDEOGRAPH-#29FF3, IRGKangXi=1487.151, RSKangXi=196.5
29FF4 CJK UNIFIED IDEOGRAPH-#29FF4, IRGKangXi=1487.151, RSKangXi=196.5
29FF5 CJK UNIFIED IDEOGRAPH-#29FF5, IRGKangXi=1487.151, RSKangXi=196.5
29FF6 CJK UNIFIED IDEOGRAPH-#29FF6, IRGKangXi=1487.151, RSKangXi=196.5
29FF7 CJK UNIFIED IDEOGRAPH-#29FF7, IRGKangXi=1487.151, RSKangXi=196.5
29FF8 CJK UNIFIED IDEOGRAPH-#29FF8, IRGKangXi=1487.151, RSKangXi=196.5
29FF9 CJK UNIFIED IDEOGRAPH-#29FF9, IRGKangXi=1487.151, RSKangXi=196.5
29FFA CJK UNIFIED IDEOGRAPH-#29FFA, IRGKangXi=1487.151, RSKangXi=196.5
29FFB CJK UNIFIED IDEOGRAPH-#29FFB, IRGKangXi=1487.151, RSKangXi=196.5
29FFC CJK UNIFIED IDEOGRAPH-#29FFC, IRGKangXi=1487.151, RSKangXi=196.5
29FFD CJK UNIFIED IDEOGRAPH-#29FFD, IRGKangXi=1487.151, RSKangXi=196.5
29FFE CJK UNIFIED IDEOGRAPH-#29FFE, IRGKangXi=1487.151, RSKangXi=196.5
29FFF CJK UNIFIED IDEOGRAPH-#29FFF, IRGKangXi=1487.151, RSKangXi=196.5
2A000 CJK UNIFIED IDEOGRAPH-#2A000, IRGKangXi=1487.151, RSKangXi=196.5
2A001 CJK UNIFIED IDEOGRAPH-#2A001, IRGKangXi=1487.151, RSKangXi=196.5
2A002 CJK UNIFIED IDEOGRAPH-#2A002, IRGKangXi=1487.151, RSKangXi=196.5
2A003 CJK UNIFIED IDEOGRAPH-#2A003, IRGKangXi=1487.151, RSKangXi=196.5
2A004 CJK UNIFIED IDEOGRAPH-#2A004, IRGKangXi=1487.151, RSKangXi=196.5
2A005 CJK UNIFIED IDEOGRAPH-#2A005, IRGKangXi=1487.151, RSKangXi=196.5
2A006 CJK UNIFIED IDEOGRAPH-#2A006, IRGKangXi=1487.151, RSKangXi=196.5
2A007 CJK UNIFIED IDEOGRAPH-#2A007, IRGKangXi=1487.151, RSKangXi=196.5
2A008 CJK UNIFIED IDEOGRAPH-#2A008, IRGKangXi=1487.151, RSKangXi=196.5
2A009 CJK UNIFIED IDEOGRAPH-#2A009, IRGKangXi=1487.151, RSKangXi=196.5
2A00A CJK UNIFIED IDEOGRAPH-#2A00A, IRGKangXi=1487.151, RSKangXi=196.5
2A00B CJK UNIFIED IDEOGRAPH-#2A00B, IRGKangXi=1487.151, RSKangXi=196.5
2A00C CJK UNIFIED IDEOGRAPH-#2A00C, IRGKangXi=1487.151, RSKangXi=196.5
2A00D CJK UNIFIED IDEOGRAPH-#2A00D, IRGKangXi=1487.151, RSKangXi=196.5
2A00E CJK UNIFIED IDEOGRAPH-#2A00E, IRGKangXi=1487.151, RSKangXi=196.5
2A00F CJK UNIFIED IDEOGRAPH-#2A00F, IRGKangXi=1487.151, RSKangXi=196.5
2A010 CJK UNIFIED IDEOGRAPH-#2A010, IRGKangXi=1487.151, RSKangXi=196.5
2A011 CJK UNIFIED IDEOGRAPH-#2A011, IRGKangXi=1487.151, RSKangXi=196.5
2A012 CJK UNIFIED IDEOGRAPH-#2A012, IRGKangXi=1487.160, RSKangXi=196.6, Def{variant of 鴟 U+9D1F, a kite (bird)}
2A013 CJK UNIFIED IDEOGRAPH-#2A013, IRGKangXi=1487.170, RSKangXi=196.6
2A014 CJK UNIFIED IDEOGRAPH-#2A014, IRGKangXi=1487.180, RSKangXi=196.6
2A015 CJK UNIFIED IDEOGRAPH-#2A015, IRGKangXi=1487.200, RSKangXi=196.6
2A016 CJK UNIFIED IDEOGRAPH-#2A016, IRGKangXi=1487.220, RSKangXi=196.6
2A017 CJK UNIFIED IDEOGRAPH-#2A017, IRGKangXi=1487.230, RSKangXi=196.6
2A018 CJK UNIFIED IDEOGRAPH-#2A018, IRGKangXi=1487.240, RSKangXi=196.6
2A019 CJK UNIFIED IDEOGRAPH-#2A019, IRGKangXi=1487.270, RSKangXi=196.6
2A01A CJK UNIFIED IDEOGRAPH-#2A01A, IRGKangXi=1487.310, RSKangXi=196.6
2A01B CJK UNIFIED IDEOGRAPH-#2A01B, IRGKangXi=1487.330, RSKangXi=196.6
2A01C CJK UNIFIED IDEOGRAPH-#2A01C, IRGKangXi=1487.340, RSKangXi=196.6
2A01D CJK UNIFIED IDEOGRAPH-#2A01D, IRGKangXi=1487.360, RSKangXi=196.6
2A01E CJK UNIFIED IDEOGRAPH-#2A01E, IRGKangXi=1488.030, RSKangXi=196.6
2A01F CJK UNIFIED IDEOGRAPH-#2A01F, IRGKangXi=1488.050, RSKangXi=196.6
2A020 CJK UNIFIED IDEOGRAPH-#2A020, IRGKangXi=1488.110, RSKangXi=196.6
2A021 CJK UNIFIED IDEOGRAPH-#2A021, IRGKangXi=1488.130, RSKangXi=196.6
2A022 CJK UNIFIED IDEOGRAPH-#2A022, IRGKangXi=1488.140, RSKangXi=196.6
2A023 CJK UNIFIED IDEOGRAPH-#2A023, IRGKangXi=1488.180, RSKangXi=196.6
2A024 CJK UNIFIED IDEOGRAPH-#2A024, IRGKangXi=1488.190, RSKangXi=196.6
2A025 CJK UNIFIED IDEOGRAPH-#2A025, IRGKangXi=1488.230, RSKangXi=196.6
2A026 CJK UNIFIED IDEOGRAPH-#2A026, IRGKangXi=1488.240, RSKangXi=196.6
2A027 CJK UNIFIED IDEOGRAPH-#2A027, IRGKangXi=1489.090, RSKangXi=196.6
2A028 CJK UNIFIED IDEOGRAPH-#2A028, IRGKangXi=1489.100, RSKangXi=196.6
2A029 CJK UNIFIED IDEOGRAPH-#2A029, IRGKangXi=1489.110, RSKangXi=196.6
2A02A CJK UNIFIED IDEOGRAPH-#2A02A, IRGKangXi=1489.120, RSKangXi=196.6
2A02B CJK UNIFIED IDEOGRAPH-#2A02B, IRGKangXi=1489.130, RSKangXi=196.6
2A02C CJK UNIFIED IDEOGRAPH-#2A02C, IRGKangXi=1489.140, RSKangXi=196.6
2A02D CJK UNIFIED IDEOGRAPH-#2A02D, IRGKangXi=1489.160, RSKangXi=196.6
2A02E CJK UNIFIED IDEOGRAPH-#2A02E, IRGKangXi=1489.161, RSKangXi=196.6
2A02F CJK UNIFIED IDEOGRAPH-#2A02F, IRGKangXi=1489.161, RSKangXi=196.6
2A030 CJK UNIFIED IDEOGRAPH-#2A030, IRGKangXi=1489.161, RSKangXi=196.6
2A031 CJK UNIFIED IDEOGRAPH-#2A031, IRGKangXi=1489.161, RSKangXi=196.6
2A032 CJK UNIFIED IDEOGRAPH-#2A032, IRGKangXi=1489.161, RSKangXi=196.6
2A033 CJK UNIFIED IDEOGRAPH-#2A033, IRGKangXi=1489.161, RSKangXi=196.6
2A034 CJK UNIFIED IDEOGRAPH-#2A034, IRGKangXi=1489.161, RSKangXi=196.6
2A035 CJK UNIFIED IDEOGRAPH-#2A035, IRGKangXi=1489.161, RSKangXi=196.6
2A036 CJK UNIFIED IDEOGRAPH-#2A036, IRGKangXi=1489.161, RSKangXi=196.6
2A037 CJK UNIFIED IDEOGRAPH-#2A037, IRGKangXi=1489.161, RSKangXi=196.6
2A038 CJK UNIFIED IDEOGRAPH-#2A038, IRGKangXi=1489.161, RSKangXi=196.6
2A039 CJK UNIFIED IDEOGRAPH-#2A039, IRGKangXi=1489.161, RSKangXi=196.6
2A03A CJK UNIFIED IDEOGRAPH-#2A03A, IRGKangXi=1489.161, RSKangXi=196.6
2A03B CJK UNIFIED IDEOGRAPH-#2A03B, IRGKangXi=1489.161, RSKangXi=196.6
2A03C CJK UNIFIED IDEOGRAPH-#2A03C, IRGKangXi=1489.161, RSKangXi=196.6
2A03D CJK UNIFIED IDEOGRAPH-#2A03D, IRGKangXi=1489.161, RSKangXi=196.6
2A03E CJK UNIFIED IDEOGRAPH-#2A03E, IRGKangXi=1489.161, RSKangXi=196.6
2A03F CJK UNIFIED IDEOGRAPH-#2A03F, IRGKangXi=1489.161, RSKangXi=196.6
2A040 CJK UNIFIED IDEOGRAPH-#2A040, IRGKangXi=1489.161, RSKangXi=196.6
2A041 CJK UNIFIED IDEOGRAPH-#2A041, IRGKangXi=1489.161, RSKangXi=196.6
2A042 CJK UNIFIED IDEOGRAPH-#2A042, IRGKangXi=1489.161, RSKangXi=196.6
2A043 CJK UNIFIED IDEOGRAPH-#2A043, IRGKangXi=1489.161, RSKangXi=196.6
2A044 CJK UNIFIED IDEOGRAPH-#2A044, IRGKangXi=1489.161, RSKangXi=196.6
2A045 CJK UNIFIED IDEOGRAPH-#2A045, IRGKangXi=1489.161, RSKangXi=196.6
2A046 CJK UNIFIED IDEOGRAPH-#2A046, IRGKangXi=1489.161, RSKangXi=196.6
2A047 CJK UNIFIED IDEOGRAPH-#2A047, IRGKangXi=1489.161, RSKangXi=196.6
2A048 CJK UNIFIED IDEOGRAPH-#2A048, IRGKangXi=1489.161, RSKangXi=196.6
2A049 CJK UNIFIED IDEOGRAPH-#2A049, IRGKangXi=1489.161, RSKangXi=196.6
2A04A CJK UNIFIED IDEOGRAPH-#2A04A, IRGKangXi=1489.180, RSKangXi=196.7
2A04B CJK UNIFIED IDEOGRAPH-#2A04B, IRGKangXi=1489.190, RSKangXi=196.7
2A04C CJK UNIFIED IDEOGRAPH-#2A04C, IRGKangXi=1489.240, RSKangXi=196.7
2A04D CJK UNIFIED IDEOGRAPH-#2A04D, IRGKangXi=1489.250, RSKangXi=196.7
2A04E CJK UNIFIED IDEOGRAPH-#2A04E, IRGKangXi=1489.270, RSKangXi=196.7
2A04F CJK UNIFIED IDEOGRAPH-#2A04F, IRGKangXi=1490.010, RSKangXi=196.7
2A050 CJK UNIFIED IDEOGRAPH-#2A050, IRGKangXi=1490.030, RSKangXi=196.7
2A051 CJK UNIFIED IDEOGRAPH-#2A051, IRGKangXi=1490.050, RSKangXi=196.7
2A052 CJK UNIFIED IDEOGRAPH-#2A052, IRGKangXi=1490.080, RSKangXi=196.7
2A053 CJK UNIFIED IDEOGRAPH-#2A053, IRGKangXi=1490.120, RSKangXi=196.7
2A054 CJK UNIFIED IDEOGRAPH-#2A054, IRGKangXi=1490.140, RSKangXi=196.7
2A055 CJK UNIFIED IDEOGRAPH-#2A055, IRGKangXi=1490.150, RSKangXi=196.7
2A056 CJK UNIFIED IDEOGRAPH-#2A056, IRGKangXi=1490.160, RSKangXi=196.7
2A057 CJK UNIFIED IDEOGRAPH-#2A057, IRGKangXi=1490.170, RSKangXi=196.7
2A058 CJK UNIFIED IDEOGRAPH-#2A058, IRGKangXi=1490.180, RSKangXi=196.7
2A059 CJK UNIFIED IDEOGRAPH-#2A059, IRGKangXi=1490.190, RSKangXi=196.7
2A05A CJK UNIFIED IDEOGRAPH-#2A05A, IRGKangXi=1490.210, RSKangXi=196.7
2A05B CJK UNIFIED IDEOGRAPH-#2A05B, IRGKangXi=1490.240, RSKangXi=196.7
2A05C CJK UNIFIED IDEOGRAPH-#2A05C, IRGKangXi=1490.280, RSKangXi=196.7
2A05D CJK UNIFIED IDEOGRAPH-#2A05D, IRGKangXi=1490.290, RSKangXi=196.7
2A05E CJK UNIFIED IDEOGRAPH-#2A05E, IRGKangXi=1491.070, RSKangXi=196.7
2A05F CJK UNIFIED IDEOGRAPH-#2A05F, IRGKangXi=1491.090, RSKangXi=196.7
2A060 CJK UNIFIED IDEOGRAPH-#2A060, IRGKangXi=1491.110, RSKangXi=196.7
2A061 CJK UNIFIED IDEOGRAPH-#2A061, IRGKangXi=1491.120, RSKangXi=196.7
2A062 CJK UNIFIED IDEOGRAPH-#2A062, IRGKangXi=1491.130, RSKangXi=196.7
2A063 CJK UNIFIED IDEOGRAPH-#2A063, IRGKangXi=1491.150, RSKangXi=196.7
2A064 CJK UNIFIED IDEOGRAPH-#2A064, IRGKangXi=1491.160, RSKangXi=196.7
2A065 CJK UNIFIED IDEOGRAPH-#2A065, IRGKangXi=1491.170, RSKangXi=196.7
2A066 CJK UNIFIED IDEOGRAPH-#2A066, IRGKangXi=1491.190, RSKangXi=196.7
2A067 CJK UNIFIED IDEOGRAPH-#2A067, IRGKangXi=1491.200, RSKangXi=196.7
2A068 CJK UNIFIED IDEOGRAPH-#2A068, IRGKangXi=1491.210, RSKangXi=196.7
2A069 CJK UNIFIED IDEOGRAPH-#2A069, IRGKangXi=1491.230, RSKangXi=196.7
2A06A CJK UNIFIED IDEOGRAPH-#2A06A, IRGKangXi=1491.240, RSKangXi=196.7
2A06B CJK UNIFIED IDEOGRAPH-#2A06B, IRGKangXi=1491.241, RSKangXi=196.7
2A06C CJK UNIFIED IDEOGRAPH-#2A06C, IRGKangXi=1491.241, RSKangXi=196.7
2A06D CJK UNIFIED IDEOGRAPH-#2A06D, IRGKangXi=1491.241, RSKangXi=196.7
2A06E CJK UNIFIED IDEOGRAPH-#2A06E, IRGKangXi=1491.241, RSKangXi=196.7
2A06F CJK UNIFIED IDEOGRAPH-#2A06F, IRGKangXi=1491.241, RSKangXi=196.7
2A070 CJK UNIFIED IDEOGRAPH-#2A070, IRGKangXi=1491.241, RSKangXi=196.7
2A071 CJK UNIFIED IDEOGRAPH-#2A071, IRGKangXi=1491.241, RSKangXi=196.7
2A072 CJK UNIFIED IDEOGRAPH-#2A072, IRGKangXi=1491.241, RSKangXi=196.7
2A073 CJK UNIFIED IDEOGRAPH-#2A073, IRGKangXi=1491.241, RSKangXi=196.7
2A074 CJK UNIFIED IDEOGRAPH-#2A074, IRGKangXi=1491.241, RSKangXi=196.7
2A075 CJK UNIFIED IDEOGRAPH-#2A075, IRGKangXi=1491.241, RSKangXi=196.7
2A076 CJK UNIFIED IDEOGRAPH-#2A076, IRGKangXi=1491.241, RSKangXi=196.7
2A077 CJK UNIFIED IDEOGRAPH-#2A077, IRGKangXi=1491.250, RSKangXi=196.8
2A078 CJK UNIFIED IDEOGRAPH-#2A078, IRGKangXi=1491.260, RSKangXi=196.8
2A079 CJK UNIFIED IDEOGRAPH-#2A079, IRGKangXi=1491.280, RSKangXi=196.8
2A07A CJK UNIFIED IDEOGRAPH-#2A07A, IRGKangXi=1491.290, RSKangXi=196.8
2A07B CJK UNIFIED IDEOGRAPH-#2A07B, IRGKangXi=1491.300, RSKangXi=196.8
2A07C CJK UNIFIED IDEOGRAPH-#2A07C, IRGKangXi=1491.310, RSKangXi=196.8
2A07D CJK UNIFIED IDEOGRAPH-#2A07D, IRGKangXi=1491.320, RSKangXi=196.8
2A07E CJK UNIFIED IDEOGRAPH-#2A07E, IRGKangXi=1491.330, RSKangXi=196.8
2A07F CJK UNIFIED IDEOGRAPH-#2A07F, IRGKangXi=1491.340, RSKangXi=196.8
2A080 CJK UNIFIED IDEOGRAPH-#2A080, IRGKangXi=1491.370, RSKangXi=196.8
2A081 CJK UNIFIED IDEOGRAPH-#2A081, IRGKangXi=1492.020, RSKangXi=196.8
2A082 CJK UNIFIED IDEOGRAPH-#2A082, IRGKangXi=1492.040, RSKangXi=196.8
2A083 CJK UNIFIED IDEOGRAPH-#2A083, IRGKangXi=1492.100, RSKangXi=196.8
2A084 CJK UNIFIED IDEOGRAPH-#2A084, IRGKangXi=1492.150, RSKangXi=196.8
2A085 CJK UNIFIED IDEOGRAPH-#2A085, IRGKangXi=1492.170, RSKangXi=196.8
2A086 CJK UNIFIED IDEOGRAPH-#2A086, IRGKangXi=1492.190, RSKangXi=196.8
2A087 CJK UNIFIED IDEOGRAPH-#2A087, IRGKangXi=1492.200, RSKangXi=196.8
2A088 CJK UNIFIED IDEOGRAPH-#2A088, IRGKangXi=1492.230, RSKangXi=196.8
2A089 CJK UNIFIED IDEOGRAPH-#2A089, IRGKangXi=1492.250, RSKangXi=196.8
2A08A CJK UNIFIED IDEOGRAPH-#2A08A, IRGKangXi=1493.070, RSKangXi=196.8
2A08B CJK UNIFIED IDEOGRAPH-#2A08B, IRGKangXi=1493.080, RSKangXi=196.8
2A08C CJK UNIFIED IDEOGRAPH-#2A08C, IRGKangXi=1493.100, RSKangXi=196.8
2A08D CJK UNIFIED IDEOGRAPH-#2A08D, IRGKangXi=1494.020, RSKangXi=196.8
2A08E CJK UNIFIED IDEOGRAPH-#2A08E, IRGKangXi=1494.030, RSKangXi=196.8
2A08F CJK UNIFIED IDEOGRAPH-#2A08F, IRGKangXi=1494.040, RSKangXi=196.8
2A090 CJK UNIFIED IDEOGRAPH-#2A090, IRGKangXi=1494.050, RSKangXi=196.8
2A091 CJK UNIFIED IDEOGRAPH-#2A091, IRGKangXi=1494.060, RSKangXi=196.8
2A092 CJK UNIFIED IDEOGRAPH-#2A092, IRGKangXi=1494.070, RSKangXi=196.8
2A093 CJK UNIFIED IDEOGRAPH-#2A093, IRGKangXi=1494.080, RSKangXi=196.8
2A094 CJK UNIFIED IDEOGRAPH-#2A094, IRGKangXi=1494.090, RSKangXi=196.8
2A095 CJK UNIFIED IDEOGRAPH-#2A095, IRGKangXi=1494.100, RSKangXi=196.8
2A096 CJK UNIFIED IDEOGRAPH-#2A096, IRGKangXi=1494.101, RSKangXi=196.8
2A097 CJK UNIFIED IDEOGRAPH-#2A097, IRGKangXi=1494.101, RSKangXi=196.8
2A098 CJK UNIFIED IDEOGRAPH-#2A098, IRGKangXi=1494.101, RSKangXi=196.8
2A099 CJK UNIFIED IDEOGRAPH-#2A099, IRGKangXi=1494.101, RSKangXi=196.8
2A09A CJK UNIFIED IDEOGRAPH-#2A09A, IRGKangXi=1494.101, RSKangXi=196.8
2A09B CJK UNIFIED IDEOGRAPH-#2A09B, IRGKangXi=1494.101, RSKangXi=196.8
2A09C CJK UNIFIED IDEOGRAPH-#2A09C, IRGKangXi=1494.101, RSKangXi=196.8
2A09D CJK UNIFIED IDEOGRAPH-#2A09D, IRGKangXi=1494.101, RSKangXi=196.8
2A09E CJK UNIFIED IDEOGRAPH-#2A09E, IRGKangXi=1494.101, RSKangXi=196.8
2A09F CJK UNIFIED IDEOGRAPH-#2A09F, IRGKangXi=1494.101, RSKangXi=196.8
2A0A0 CJK UNIFIED IDEOGRAPH-#2A0A0, IRGKangXi=1494.101, RSKangXi=196.8
2A0A1 CJK UNIFIED IDEOGRAPH-#2A0A1, IRGKangXi=1494.101, RSKangXi=196.8
2A0A2 CJK UNIFIED IDEOGRAPH-#2A0A2, IRGKangXi=1494.101, RSKangXi=196.8
2A0A3 CJK UNIFIED IDEOGRAPH-#2A0A3, IRGKangXi=1494.101, RSKangXi=196.8
2A0A4 CJK UNIFIED IDEOGRAPH-#2A0A4, IRGKangXi=1494.101, RSKangXi=196.8
2A0A5 CJK UNIFIED IDEOGRAPH-#2A0A5, IRGKangXi=1494.101, RSKangXi=196.8
2A0A6 CJK UNIFIED IDEOGRAPH-#2A0A6, IRGKangXi=1494.101, RSKangXi=196.8
2A0A7 CJK UNIFIED IDEOGRAPH-#2A0A7, IRGKangXi=1494.101, RSKangXi=196.8
2A0A8 CJK UNIFIED IDEOGRAPH-#2A0A8, IRGKangXi=1494.101, RSKangXi=196.8
2A0A9 CJK UNIFIED IDEOGRAPH-#2A0A9, IRGKangXi=1494.101, RSKangXi=196.8
2A0AA CJK UNIFIED IDEOGRAPH-#2A0AA, IRGKangXi=1494.101, RSKangXi=196.8
2A0AB CJK UNIFIED IDEOGRAPH-#2A0AB, IRGKangXi=1494.101, RSKangXi=196.8
2A0AC CJK UNIFIED IDEOGRAPH-#2A0AC, IRGKangXi=1494.101, RSKangXi=196.8
2A0AD CJK UNIFIED IDEOGRAPH-#2A0AD, IRGKangXi=1494.101, RSKangXi=196.8
2A0AE CJK UNIFIED IDEOGRAPH-#2A0AE, IRGKangXi=1494.101, RSKangXi=196.8
2A0AF CJK UNIFIED IDEOGRAPH-#2A0AF, IRGKangXi=1494.101, RSKangXi=196.8
2A0B0 CJK UNIFIED IDEOGRAPH-#2A0B0, IRGKangXi=1494.101, RSKangXi=196.8
2A0B1 CJK UNIFIED IDEOGRAPH-#2A0B1, IRGKangXi=1494.101, RSKangXi=196.8
2A0B2 CJK UNIFIED IDEOGRAPH-#2A0B2, IRGKangXi=1494.101, RSKangXi=196.8
2A0B3 CJK UNIFIED IDEOGRAPH-#2A0B3, IRGKangXi=1494.101, RSKangXi=196.8
2A0B4 CJK UNIFIED IDEOGRAPH-#2A0B4, IRGKangXi=1494.101, RSKangXi=196.8
2A0B5 CJK UNIFIED IDEOGRAPH-#2A0B5, IRGKangXi=1494.101, RSKangXi=196.8
2A0B6 CJK UNIFIED IDEOGRAPH-#2A0B6, IRGKangXi=1494.130, RSKangXi=196.9
2A0B7 CJK UNIFIED IDEOGRAPH-#2A0B7, IRGKangXi=1494.140, RSKangXi=196.9
2A0B8 CJK UNIFIED IDEOGRAPH-#2A0B8, IRGKangXi=1494.150, RSKangXi=196.9
2A0B9 CJK UNIFIED IDEOGRAPH-#2A0B9, IRGKangXi=1494.160, RSKangXi=196.9
2A0BA CJK UNIFIED IDEOGRAPH-#2A0BA, IRGKangXi=1494.190, RSKangXi=196.9
2A0BB CJK UNIFIED IDEOGRAPH-#2A0BB, IRGKangXi=1494.200, RSKangXi=196.9
2A0BC CJK UNIFIED IDEOGRAPH-#2A0BC, IRGKangXi=1494.230, RSKangXi=196.9
2A0BD CJK UNIFIED IDEOGRAPH-#2A0BD, IRGKangXi=1494.240, RSKangXi=196.9
2A0BE CJK UNIFIED IDEOGRAPH-#2A0BE, IRGKangXi=1494.250, RSKangXi=196.9
2A0BF CJK UNIFIED IDEOGRAPH-#2A0BF, IRGKangXi=1494.280, RSKangXi=196.9
2A0C0 CJK UNIFIED IDEOGRAPH-#2A0C0, IRGKangXi=1494.330, RSKangXi=196.9
2A0C1 CJK UNIFIED IDEOGRAPH-#2A0C1, IRGKangXi=1494.340, RSKangXi=196.9
2A0C2 CJK UNIFIED IDEOGRAPH-#2A0C2, IRGKangXi=1494.350, RSKangXi=196.9
2A0C3 CJK UNIFIED IDEOGRAPH-#2A0C3, IRGKangXi=1494.370, RSKangXi=196.9
2A0C4 CJK UNIFIED IDEOGRAPH-#2A0C4, IRGKangXi=1494.390, RSKangXi=196.9
2A0C5 CJK UNIFIED IDEOGRAPH-#2A0C5, IRGKangXi=1494.400, RSKangXi=196.9
2A0C6 CJK UNIFIED IDEOGRAPH-#2A0C6, IRGKangXi=1494.410, RSKangXi=196.9
2A0C7 CJK UNIFIED IDEOGRAPH-#2A0C7, IRGKangXi=1494.430, RSKangXi=196.9
2A0C8 CJK UNIFIED IDEOGRAPH-#2A0C8, IRGKangXi=1494.480, RSKangXi=196.9
2A0C9 CJK UNIFIED IDEOGRAPH-#2A0C9, IRGKangXi=1494.490, RSKangXi=196.9
2A0CA CJK UNIFIED IDEOGRAPH-#2A0CA, IRGKangXi=1494.510, RSKangXi=196.9
2A0CB CJK UNIFIED IDEOGRAPH-#2A0CB, IRGKangXi=1495.030, RSKangXi=196.9
2A0CC CJK UNIFIED IDEOGRAPH-#2A0CC, IRGKangXi=1495.050, RSKangXi=196.9
2A0CD CJK UNIFIED IDEOGRAPH-#2A0CD, IRGKangXi=1495.080, RSKangXi=196.9
2A0CE CJK UNIFIED IDEOGRAPH-#2A0CE, IRGKangXi=1495.090, RSKangXi=196.9
2A0CF CJK UNIFIED IDEOGRAPH-#2A0CF, IRGKangXi=1495.130, RSKangXi=196.9
2A0D0 CJK UNIFIED IDEOGRAPH-#2A0D0, IRGKangXi=1495.140, RSKangXi=196.9
2A0D1 CJK UNIFIED IDEOGRAPH-#2A0D1, IRGKangXi=1495.150, RSKangXi=196.9
2A0D2 CJK UNIFIED IDEOGRAPH-#2A0D2, IRGKangXi=1495.170, RSKangXi=196.9
2A0D3 CJK UNIFIED IDEOGRAPH-#2A0D3, IRGKangXi=1495.200, RSKangXi=196.9
2A0D4 CJK UNIFIED IDEOGRAPH-#2A0D4, IRGKangXi=1495.240, RSKangXi=196.9
2A0D5 CJK UNIFIED IDEOGRAPH-#2A0D5, IRGKangXi=1495.250, RSKangXi=196.9
2A0D6 CJK UNIFIED IDEOGRAPH-#2A0D6, IRGKangXi=1495.260, RSKangXi=196.9
2A0D7 CJK UNIFIED IDEOGRAPH-#2A0D7, IRGKangXi=1495.270, RSKangXi=196.9
2A0D8 CJK UNIFIED IDEOGRAPH-#2A0D8, IRGKangXi=1495.280, RSKangXi=196.9
2A0D9 CJK UNIFIED IDEOGRAPH-#2A0D9, IRGKangXi=1495.290, RSKangXi=196.9
2A0DA CJK UNIFIED IDEOGRAPH-#2A0DA, IRGKangXi=1495.300, RSKangXi=196.9
2A0DB CJK UNIFIED IDEOGRAPH-#2A0DB, IRGKangXi=1495.310, RSKangXi=196.9
2A0DC CJK UNIFIED IDEOGRAPH-#2A0DC, IRGKangXi=1495.320, RSKangXi=196.9
2A0DD CJK UNIFIED IDEOGRAPH-#2A0DD, IRGKangXi=1495.330, RSKangXi=196.9
2A0DE CJK UNIFIED IDEOGRAPH-#2A0DE, IRGKangXi=1495.341, RSKangXi=196.9
2A0DF CJK UNIFIED IDEOGRAPH-#2A0DF, IRGKangXi=1495.341, RSKangXi=196.9
2A0E0 CJK UNIFIED IDEOGRAPH-#2A0E0, IRGKangXi=1495.341, RSKangXi=196.9
2A0E1 CJK UNIFIED IDEOGRAPH-#2A0E1, IRGKangXi=1495.341, RSKangXi=196.9
2A0E2 CJK UNIFIED IDEOGRAPH-#2A0E2, IRGKangXi=1495.341, RSKangXi=196.9
2A0E3 CJK UNIFIED IDEOGRAPH-#2A0E3, IRGKangXi=1495.341, RSKangXi=196.9
2A0E4 CJK UNIFIED IDEOGRAPH-#2A0E4, IRGKangXi=1495.341, RSKangXi=196.9
2A0E5 CJK UNIFIED IDEOGRAPH-#2A0E5, IRGKangXi=1495.341, RSKangXi=196.9
2A0E6 CJK UNIFIED IDEOGRAPH-#2A0E6, IRGKangXi=1495.341, RSKangXi=196.9
2A0E7 CJK UNIFIED IDEOGRAPH-#2A0E7, IRGKangXi=1495.341, RSKangXi=196.9
2A0E8 CJK UNIFIED IDEOGRAPH-#2A0E8, IRGKangXi=1495.341, RSKangXi=196.9
2A0E9 CJK UNIFIED IDEOGRAPH-#2A0E9, IRGKangXi=1495.341, RSKangXi=196.9
2A0EA CJK UNIFIED IDEOGRAPH-#2A0EA, IRGKangXi=1495.341, RSKangXi=196.9
2A0EB CJK UNIFIED IDEOGRAPH-#2A0EB, IRGKangXi=1495.341, RSKangXi=196.9
2A0EC CJK UNIFIED IDEOGRAPH-#2A0EC, IRGKangXi=1495.341, RSKangXi=196.9
2A0ED CJK UNIFIED IDEOGRAPH-#2A0ED, IRGKangXi=1495.341, RSKangXi=196.9
2A0EE CJK UNIFIED IDEOGRAPH-#2A0EE, IRGKangXi=1495.341, RSKangXi=196.9
2A0EF CJK UNIFIED IDEOGRAPH-#2A0EF, IRGKangXi=1495.341, RSKangXi=196.9
2A0F0 CJK UNIFIED IDEOGRAPH-#2A0F0, IRGKangXi=1495.341, RSKangXi=196.9
2A0F1 CJK UNIFIED IDEOGRAPH-#2A0F1, IRGKangXi=1495.341, RSKangXi=196.9
2A0F2 CJK UNIFIED IDEOGRAPH-#2A0F2, IRGKangXi=1495.341, RSKangXi=196.9
2A0F3 CJK UNIFIED IDEOGRAPH-#2A0F3, IRGKangXi=1495.341, RSKangXi=196.9
2A0F4 CJK UNIFIED IDEOGRAPH-#2A0F4, IRGKangXi=1495.341, RSKangXi=196.9
2A0F5 CJK UNIFIED IDEOGRAPH-#2A0F5, IRGKangXi=1495.341, RSKangXi=196.9
2A0F6 CJK UNIFIED IDEOGRAPH-#2A0F6, IRGKangXi=1495.341, RSKangXi=196.9
2A0F7 CJK UNIFIED IDEOGRAPH-#2A0F7, IRGKangXi=1495.341, RSKangXi=196.9
2A0F8 CJK UNIFIED IDEOGRAPH-#2A0F8, IRGKangXi=1495.341, RSKangXi=196.9
2A0F9 CJK UNIFIED IDEOGRAPH-#2A0F9, IRGKangXi=1495.341, RSKangXi=196.9
2A0FA CJK UNIFIED IDEOGRAPH-#2A0FA, IRGKangXi=1496.020, RSKangXi=196.10
2A0FB CJK UNIFIED IDEOGRAPH-#2A0FB, IRGKangXi=1496.040, RSKangXi=196.10
2A0FC CJK UNIFIED IDEOGRAPH-#2A0FC, IRGKangXi=1496.060, RSKangXi=196.10
2A0FD CJK UNIFIED IDEOGRAPH-#2A0FD, IRGKangXi=1496.090, RSKangXi=196.10
2A0FE CJK UNIFIED IDEOGRAPH-#2A0FE, IRGKangXi=1496.100, RSKangXi=196.10
2A0FF CJK UNIFIED IDEOGRAPH-#2A0FF, IRGKangXi=1496.110, RSKangXi=196.10, Def{a goose}
2A100 CJK UNIFIED IDEOGRAPH-#2A100, IRGKangXi=1496.150, RSKangXi=196.10
2A101 CJK UNIFIED IDEOGRAPH-#2A101, IRGKangXi=1496.160, RSKangXi=196.10
2A102 CJK UNIFIED IDEOGRAPH-#2A102, IRGKangXi=1496.180, RSKangXi=196.10
2A103 CJK UNIFIED IDEOGRAPH-#2A103, IRGKangXi=1496.190, RSKangXi=196.10
2A104 CJK UNIFIED IDEOGRAPH-#2A104, IRGKangXi=1496.230, RSKangXi=196.10
2A105 CJK UNIFIED IDEOGRAPH-#2A105, IRGKangXi=1496.260, RSKangXi=196.10
2A106 CJK UNIFIED IDEOGRAPH-#2A106, IRGKangXi=1496.280, RSKangXi=196.10
2A107 CJK UNIFIED IDEOGRAPH-#2A107, IRGKangXi=1496.300, RSKangXi=196.10
2A108 CJK UNIFIED IDEOGRAPH-#2A108, IRGKangXi=1497.060, RSKangXi=196.10
2A109 CJK UNIFIED IDEOGRAPH-#2A109, IRGKangXi=1498.010, RSKangXi=196.10
2A10A CJK UNIFIED IDEOGRAPH-#2A10A, IRGKangXi=1498.040, RSKangXi=196.10
2A10B CJK UNIFIED IDEOGRAPH-#2A10B, IRGKangXi=1498.060, RSKangXi=196.10
2A10C CJK UNIFIED IDEOGRAPH-#2A10C, IRGKangXi=1498.110, RSKangXi=196.10
2A10D CJK UNIFIED IDEOGRAPH-#2A10D, IRGKangXi=1498.140, RSKangXi=196.10
2A10E CJK UNIFIED IDEOGRAPH-#2A10E, IRGKangXi=1498.150, RSKangXi=196.10
2A10F CJK UNIFIED IDEOGRAPH-#2A10F, IRGKangXi=1498.170, RSKangXi=196.10
2A110 CJK UNIFIED IDEOGRAPH-#2A110, IRGKangXi=1498.180, RSKangXi=196.10
2A111 CJK UNIFIED IDEOGRAPH-#2A111, IRGKangXi=1498.200, RSKangXi=196.10
2A112 CJK UNIFIED IDEOGRAPH-#2A112, IRGKangXi=1498.201, RSKangXi=196.10
2A113 CJK UNIFIED IDEOGRAPH-#2A113, IRGKangXi=1498.201, RSKangXi=196.10
2A114 CJK UNIFIED IDEOGRAPH-#2A114, IRGKangXi=1498.201, RSKangXi=196.10
2A115 CJK UNIFIED IDEOGRAPH-#2A115, IRGKangXi=1498.201, RSKangXi=196.10
2A116 CJK UNIFIED IDEOGRAPH-#2A116, IRGKangXi=1498.201, RSKangXi=196.10
2A117 CJK UNIFIED IDEOGRAPH-#2A117, IRGKangXi=1498.201, RSKangXi=196.10
2A118 CJK UNIFIED IDEOGRAPH-#2A118, IRGKangXi=1498.201, RSKangXi=196.10
2A119 CJK UNIFIED IDEOGRAPH-#2A119, IRGKangXi=1498.201, RSKangXi=196.10
2A11A CJK UNIFIED IDEOGRAPH-#2A11A, IRGKangXi=1498.201, RSKangXi=196.10
2A11B CJK UNIFIED IDEOGRAPH-#2A11B, IRGKangXi=1498.201, RSKangXi=196.10
2A11C CJK UNIFIED IDEOGRAPH-#2A11C, IRGKangXi=1498.201, RSKangXi=196.10
2A11D CJK UNIFIED IDEOGRAPH-#2A11D, IRGKangXi=1498.201, RSKangXi=196.10
2A11E CJK UNIFIED IDEOGRAPH-#2A11E, IRGKangXi=1498.201, RSKangXi=196.10
2A11F CJK UNIFIED IDEOGRAPH-#2A11F, IRGKangXi=1498.201, RSKangXi=196.10
2A120 CJK UNIFIED IDEOGRAPH-#2A120, IRGKangXi=1498.201, RSKangXi=196.10
2A121 CJK UNIFIED IDEOGRAPH-#2A121, IRGKangXi=1498.201, RSKangXi=196.10
2A122 CJK UNIFIED IDEOGRAPH-#2A122, IRGKangXi=1498.201, RSKangXi=196.10
2A123 CJK UNIFIED IDEOGRAPH-#2A123, IRGKangXi=1498.201, RSKangXi=196.10
2A124 CJK UNIFIED IDEOGRAPH-#2A124, IRGKangXi=1498.201, RSKangXi=196.10
2A125 CJK UNIFIED IDEOGRAPH-#2A125, IRGKangXi=1498.201, RSKangXi=196.10
2A126 CJK UNIFIED IDEOGRAPH-#2A126, IRGKangXi=1498.201, RSKangXi=196.10
2A127 CJK UNIFIED IDEOGRAPH-#2A127, IRGKangXi=1498.201, RSKangXi=196.10
2A128 CJK UNIFIED IDEOGRAPH-#2A128, IRGKangXi=1498.201, RSKangXi=196.10
2A129 CJK UNIFIED IDEOGRAPH-#2A129, IRGKangXi=1498.201, RSKangXi=196.10
2A12A CJK UNIFIED IDEOGRAPH-#2A12A, IRGKangXi=1498.201, RSKangXi=196.10
2A12B CJK UNIFIED IDEOGRAPH-#2A12B, IRGKangXi=1498.201, RSKangXi=196.10
2A12C CJK UNIFIED IDEOGRAPH-#2A12C, IRGKangXi=1498.201, RSKangXi=196.10
2A12D CJK UNIFIED IDEOGRAPH-#2A12D, IRGKangXi=1498.210, RSKangXi=196.11
2A12E CJK UNIFIED IDEOGRAPH-#2A12E, IRGKangXi=1498.240, RSKangXi=196.11
2A12F CJK UNIFIED IDEOGRAPH-#2A12F, IRGKangXi=1498.250, RSKangXi=196.11
2A130 CJK UNIFIED IDEOGRAPH-#2A130, IRGKangXi=1498.270, RSKangXi=196.11
2A131 CJK UNIFIED IDEOGRAPH-#2A131, IRGKangXi=1498.280, RSKangXi=196.11
2A132 CJK UNIFIED IDEOGRAPH-#2A132, IRGKangXi=1498.290, RSKangXi=196.11
2A133 CJK UNIFIED IDEOGRAPH-#2A133, IRGKangXi=1498.300, RSKangXi=196.11
2A134 CJK UNIFIED IDEOGRAPH-#2A134, IRGKangXi=1498.340, RSKangXi=196.11
2A135 CJK UNIFIED IDEOGRAPH-#2A135, IRGKangXi=1498.350, RSKangXi=196.11
2A136 CJK UNIFIED IDEOGRAPH-#2A136, IRGKangXi=1498.360, RSKangXi=196.11
2A137 CJK UNIFIED IDEOGRAPH-#2A137, IRGKangXi=1498.370, RSKangXi=196.11
2A138 CJK UNIFIED IDEOGRAPH-#2A138, IRGKangXi=1498.380, RSKangXi=196.11
2A139 CJK UNIFIED IDEOGRAPH-#2A139, IRGKangXi=1498.390, RSKangXi=196.11
2A13A CJK UNIFIED IDEOGRAPH-#2A13A, IRGKangXi=1498.400, RSKangXi=196.11
2A13B CJK UNIFIED IDEOGRAPH-#2A13B, IRGKangXi=1498.410, RSKangXi=196.11
2A13C CJK UNIFIED IDEOGRAPH-#2A13C, IRGKangXi=1499.020, RSKangXi=196.11
2A13D CJK UNIFIED IDEOGRAPH-#2A13D, IRGKangXi=1499.030, RSKangXi=196.11
2A13E CJK UNIFIED IDEOGRAPH-#2A13E, IRGKangXi=1499.050, RSKangXi=196.11
2A13F CJK UNIFIED IDEOGRAPH-#2A13F, IRGKangXi=1499.080, RSKangXi=196.11
2A140 CJK UNIFIED IDEOGRAPH-#2A140, IRGKangXi=1499.090, RSKangXi=196.11
2A141 CJK UNIFIED IDEOGRAPH-#2A141, IRGKangXi=1499.100, RSKangXi=196.11
2A142 CJK UNIFIED IDEOGRAPH-#2A142, IRGKangXi=1499.120, RSKangXi=196.11
2A143 CJK UNIFIED IDEOGRAPH-#2A143, IRGKangXi=1499.140, RSKangXi=196.11
2A144 CJK UNIFIED IDEOGRAPH-#2A144, IRGKangXi=1499.150, RSKangXi=196.11
2A145 CJK UNIFIED IDEOGRAPH-#2A145, IRGKangXi=1499.180, RSKangXi=196.11
2A146 CJK UNIFIED IDEOGRAPH-#2A146, IRGKangXi=1499.200, RSKangXi=196.11
2A147 CJK UNIFIED IDEOGRAPH-#2A147, IRGKangXi=1499.220, RSKangXi=196.11
2A148 CJK UNIFIED IDEOGRAPH-#2A148, IRGKangXi=1500.030, RSKangXi=196.11
2A149 CJK UNIFIED IDEOGRAPH-#2A149, IRGKangXi=1500.040, RSKangXi=196.11
2A14A CJK UNIFIED IDEOGRAPH-#2A14A, IRGKangXi=1500.050, RSKangXi=196.11
2A14B CJK UNIFIED IDEOGRAPH-#2A14B, IRGKangXi=1500.060, RSKangXi=196.11
2A14C CJK UNIFIED IDEOGRAPH-#2A14C, IRGKangXi=1500.070, RSKangXi=196.11
2A14D CJK UNIFIED IDEOGRAPH-#2A14D, IRGKangXi=1500.080, RSKangXi=196.11
2A14E CJK UNIFIED IDEOGRAPH-#2A14E, IRGKangXi=1500.090, RSKangXi=196.11
2A14F CJK UNIFIED IDEOGRAPH-#2A14F, IRGKangXi=1500.091, RSKangXi=196.11
2A150 CJK UNIFIED IDEOGRAPH-#2A150, IRGKangXi=1500.091, RSKangXi=196.11
2A151 CJK UNIFIED IDEOGRAPH-#2A151, IRGKangXi=1500.091, RSKangXi=196.11
2A152 CJK UNIFIED IDEOGRAPH-#2A152, IRGKangXi=1500.091, RSKangXi=196.11
2A153 CJK UNIFIED IDEOGRAPH-#2A153, IRGKangXi=1500.091, RSKangXi=196.11
2A154 CJK UNIFIED IDEOGRAPH-#2A154, IRGKangXi=1500.091, RSKangXi=196.11
2A155 CJK UNIFIED IDEOGRAPH-#2A155, IRGKangXi=1500.091, RSKangXi=196.11
2A156 CJK UNIFIED IDEOGRAPH-#2A156, IRGKangXi=1500.091, RSKangXi=196.11
2A157 CJK UNIFIED IDEOGRAPH-#2A157, IRGKangXi=1500.091, RSKangXi=196.11
2A158 CJK UNIFIED IDEOGRAPH-#2A158, IRGKangXi=1500.091, RSKangXi=196.11
2A159 CJK UNIFIED IDEOGRAPH-#2A159, IRGKangXi=1500.091, RSKangXi=196.11
2A15A CJK UNIFIED IDEOGRAPH-#2A15A, IRGKangXi=1500.091, RSKangXi=196.11
2A15B CJK UNIFIED IDEOGRAPH-#2A15B, IRGKangXi=1500.091, RSKangXi=196.11
2A15C CJK UNIFIED IDEOGRAPH-#2A15C, IRGKangXi=1500.091, RSKangXi=196.11
2A15D CJK UNIFIED IDEOGRAPH-#2A15D, IRGKangXi=1500.091, RSKangXi=196.11
2A15E CJK UNIFIED IDEOGRAPH-#2A15E, IRGKangXi=1500.091, RSKangXi=196.11
2A15F CJK UNIFIED IDEOGRAPH-#2A15F, IRGKangXi=1500.091, RSKangXi=196.11
2A160 CJK UNIFIED IDEOGRAPH-#2A160, IRGKangXi=1500.091, RSKangXi=196.11
2A161 CJK UNIFIED IDEOGRAPH-#2A161, IRGKangXi=1500.091, RSKangXi=196.11
2A162 CJK UNIFIED IDEOGRAPH-#2A162, IRGKangXi=1500.091, RSKangXi=196.11
2A163 CJK UNIFIED IDEOGRAPH-#2A163, IRGKangXi=1500.091, RSKangXi=196.11
2A164 CJK UNIFIED IDEOGRAPH-#2A164, IRGKangXi=1500.091, RSKangXi=196.11
2A165 CJK UNIFIED IDEOGRAPH-#2A165, IRGKangXi=1500.091, RSKangXi=196.11
2A166 CJK UNIFIED IDEOGRAPH-#2A166, IRGKangXi=1500.091, RSKangXi=196.11
2A167 CJK UNIFIED IDEOGRAPH-#2A167, IRGKangXi=1500.091, RSKangXi=196.11
2A168 CJK UNIFIED IDEOGRAPH-#2A168, IRGKangXi=1500.091, RSKangXi=196.11
2A169 CJK UNIFIED IDEOGRAPH-#2A169, IRGKangXi=1500.091, RSKangXi=196.11
2A16A CJK UNIFIED IDEOGRAPH-#2A16A, IRGKangXi=1500.091, RSKangXi=196.11
2A16B CJK UNIFIED IDEOGRAPH-#2A16B, IRGKangXi=1500.091, RSKangXi=196.11
2A16C CJK UNIFIED IDEOGRAPH-#2A16C, IRGKangXi=1500.091, RSKangXi=196.11
2A16D CJK UNIFIED IDEOGRAPH-#2A16D, IRGKangXi=1500.091, RSKangXi=196.11
2A16E CJK UNIFIED IDEOGRAPH-#2A16E, IRGKangXi=1500.091, RSKangXi=196.11
2A16F CJK UNIFIED IDEOGRAPH-#2A16F, IRGKangXi=1500.110, RSKangXi=196.12
2A170 CJK UNIFIED IDEOGRAPH-#2A170, IRGKangXi=1500.170, RSKangXi=196.12
2A171 CJK UNIFIED IDEOGRAPH-#2A171, IRGKangXi=1500.180, RSKangXi=196.12
2A172 CJK UNIFIED IDEOGRAPH-#2A172, IRGKangXi=1500.190, RSKangXi=196.12
2A173 CJK UNIFIED IDEOGRAPH-#2A173, IRGKangXi=1500.220, RSKangXi=196.12
2A174 CJK UNIFIED IDEOGRAPH-#2A174, IRGKangXi=1500.260, RSKangXi=196.12
2A175 CJK UNIFIED IDEOGRAPH-#2A175, IRGKangXi=1500.280, RSKangXi=196.12
2A176 CJK UNIFIED IDEOGRAPH-#2A176, IRGKangXi=1500.300, RSKangXi=196.12
2A177 CJK UNIFIED IDEOGRAPH-#2A177, IRGKangXi=1500.330, RSKangXi=196.12
2A178 CJK UNIFIED IDEOGRAPH-#2A178, IRGKangXi=1500.340, RSKangXi=196.12
2A179 CJK UNIFIED IDEOGRAPH-#2A179, IRGKangXi=1500.350, RSKangXi=196.12
2A17A CJK UNIFIED IDEOGRAPH-#2A17A, IRGKangXi=1500.380, RSKangXi=196.12
2A17B CJK UNIFIED IDEOGRAPH-#2A17B, IRGKangXi=1500.400, RSKangXi=196.12
2A17C CJK UNIFIED IDEOGRAPH-#2A17C, IRGKangXi=1500.410, RSKangXi=196.12
2A17D CJK UNIFIED IDEOGRAPH-#2A17D, IRGKangXi=1500.420, RSKangXi=196.12
2A17E CJK UNIFIED IDEOGRAPH-#2A17E, IRGKangXi=1500.430, RSKangXi=196.12
2A17F CJK UNIFIED IDEOGRAPH-#2A17F, IRGKangXi=1501.090, RSKangXi=196.12
2A180 CJK UNIFIED IDEOGRAPH-#2A180, IRGKangXi=1501.110, RSKangXi=196.12
2A181 CJK UNIFIED IDEOGRAPH-#2A181, IRGKangXi=1501.120, RSKangXi=196.12
2A182 CJK UNIFIED IDEOGRAPH-#2A182, IRGKangXi=1501.140, RSKangXi=196.12
2A183 CJK UNIFIED IDEOGRAPH-#2A183, IRGKangXi=1501.170, RSKangXi=196.12
2A184 CJK UNIFIED IDEOGRAPH-#2A184, IRGKangXi=1502.030, RSKangXi=196.12
2A185 CJK UNIFIED IDEOGRAPH-#2A185, IRGKangXi=1502.040, RSKangXi=196.12
2A186 CJK UNIFIED IDEOGRAPH-#2A186, IRGKangXi=1502.050, RSKangXi=196.12
2A187 CJK UNIFIED IDEOGRAPH-#2A187, IRGKangXi=1502.060, RSKangXi=196.12
2A188 CJK UNIFIED IDEOGRAPH-#2A188, IRGKangXi=1502.070, RSKangXi=196.12
2A189 CJK UNIFIED IDEOGRAPH-#2A189, IRGKangXi=1502.080, RSKangXi=196.12
2A18A CJK UNIFIED IDEOGRAPH-#2A18A, IRGKangXi=1502.090, RSKangXi=196.12
2A18B CJK UNIFIED IDEOGRAPH-#2A18B, IRGKangXi=1502.100, RSKangXi=196.12
2A18C CJK UNIFIED IDEOGRAPH-#2A18C, IRGKangXi=1502.110, RSKangXi=196.12
2A18D CJK UNIFIED IDEOGRAPH-#2A18D, IRGKangXi=1502.120, RSKangXi=196.12
2A18E CJK UNIFIED IDEOGRAPH-#2A18E, IRGKangXi=1502.121, RSKangXi=196.12
2A18F CJK UNIFIED IDEOGRAPH-#2A18F, IRGKangXi=1502.121, RSKangXi=196.12
2A190 CJK UNIFIED IDEOGRAPH-#2A190, IRGKangXi=1502.121, RSKangXi=196.12
2A191 CJK UNIFIED IDEOGRAPH-#2A191, IRGKangXi=1502.121, RSKangXi=196.12
2A192 CJK UNIFIED IDEOGRAPH-#2A192, IRGKangXi=1502.121, RSKangXi=196.12
2A193 CJK UNIFIED IDEOGRAPH-#2A193, IRGKangXi=1502.121, RSKangXi=196.12
2A194 CJK UNIFIED IDEOGRAPH-#2A194, IRGKangXi=1502.121, RSKangXi=196.12
2A195 CJK UNIFIED IDEOGRAPH-#2A195, IRGKangXi=1502.121, RSKangXi=196.12
2A196 CJK UNIFIED IDEOGRAPH-#2A196, IRGKangXi=1502.121, RSKangXi=196.12
2A197 CJK UNIFIED IDEOGRAPH-#2A197, IRGKangXi=1502.121, RSKangXi=196.12
2A198 CJK UNIFIED IDEOGRAPH-#2A198, IRGKangXi=1502.121, RSKangXi=196.12
2A199 CJK UNIFIED IDEOGRAPH-#2A199, IRGKangXi=1502.121, RSKangXi=196.12
2A19A CJK UNIFIED IDEOGRAPH-#2A19A, IRGKangXi=1502.121, RSKangXi=196.12
2A19B CJK UNIFIED IDEOGRAPH-#2A19B, IRGKangXi=1502.121, RSKangXi=196.12
2A19C CJK UNIFIED IDEOGRAPH-#2A19C, IRGKangXi=1502.121, RSKangXi=196.12
2A19D CJK UNIFIED IDEOGRAPH-#2A19D, IRGKangXi=1502.121, RSKangXi=196.12
2A19E CJK UNIFIED IDEOGRAPH-#2A19E, IRGKangXi=1502.121, RSKangXi=196.12
2A19F CJK UNIFIED IDEOGRAPH-#2A19F, IRGKangXi=1502.121, RSKangXi=196.12
2A1A0 CJK UNIFIED IDEOGRAPH-#2A1A0, IRGKangXi=1502.121, RSKangXi=196.12
2A1A1 CJK UNIFIED IDEOGRAPH-#2A1A1, IRGKangXi=1502.121, RSKangXi=196.12
2A1A2 CJK UNIFIED IDEOGRAPH-#2A1A2, IRGKangXi=1502.121, RSKangXi=196.12
2A1A3 CJK UNIFIED IDEOGRAPH-#2A1A3, IRGKangXi=1502.121, RSKangXi=196.12
2A1A4 CJK UNIFIED IDEOGRAPH-#2A1A4, IRGKangXi=1502.121, RSKangXi=196.12
2A1A5 CJK UNIFIED IDEOGRAPH-#2A1A5, IRGKangXi=1502.121, RSKangXi=196.12
2A1A6 CJK UNIFIED IDEOGRAPH-#2A1A6, IRGKangXi=1502.121, RSKangXi=196.12
2A1A7 CJK UNIFIED IDEOGRAPH-#2A1A7, IRGKangXi=1502.121, RSKangXi=196.12
2A1A8 CJK UNIFIED IDEOGRAPH-#2A1A8, IRGKangXi=1502.121, RSKangXi=196.12
2A1A9 CJK UNIFIED IDEOGRAPH-#2A1A9, IRGKangXi=1502.121, RSKangXi=196.12
2A1AA CJK UNIFIED IDEOGRAPH-#2A1AA, IRGKangXi=1502.121, RSKangXi=196.12
2A1AB CJK UNIFIED IDEOGRAPH-#2A1AB, IRGKangXi=1502.121, RSKangXi=196.12
2A1AC CJK UNIFIED IDEOGRAPH-#2A1AC, IRGKangXi=1502.121, RSKangXi=196.13
2A1AD CJK UNIFIED IDEOGRAPH-#2A1AD, IRGKangXi=1502.121, RSKangXi=196.12
2A1AE CJK UNIFIED IDEOGRAPH-#2A1AE, IRGKangXi=1502.130, RSKangXi=196.13
2A1AF CJK UNIFIED IDEOGRAPH-#2A1AF, IRGKangXi=1502.150, RSKangXi=196.13
2A1B0 CJK UNIFIED IDEOGRAPH-#2A1B0, IRGKangXi=1502.160, RSKangXi=196.13
2A1B1 CJK UNIFIED IDEOGRAPH-#2A1B1, IRGKangXi=1502.180, RSKangXi=196.13
2A1B2 CJK UNIFIED IDEOGRAPH-#2A1B2, IRGKangXi=1502.200, RSKangXi=196.13
2A1B3 CJK UNIFIED IDEOGRAPH-#2A1B3, IRGKangXi=1502.210, RSKangXi=196.13
2A1B4 CJK UNIFIED IDEOGRAPH-#2A1B4, IRGKangXi=1502.240, RSKangXi=196.13
2A1B5 CJK UNIFIED IDEOGRAPH-#2A1B5, IRGKangXi=1502.290, RSKangXi=196.13
2A1B6 CJK UNIFIED IDEOGRAPH-#2A1B6, IRGKangXi=1502.300, RSKangXi=196.13
2A1B7 CJK UNIFIED IDEOGRAPH-#2A1B7, IRGKangXi=1502.310, RSKangXi=196.13
2A1B8 CJK UNIFIED IDEOGRAPH-#2A1B8, IRGKangXi=1502.340, RSKangXi=196.13
2A1B9 CJK UNIFIED IDEOGRAPH-#2A1B9, IRGKangXi=1502.350, RSKangXi=196.13
2A1BA CJK UNIFIED IDEOGRAPH-#2A1BA, IRGKangXi=1503.010, RSKangXi=196.13
2A1BB CJK UNIFIED IDEOGRAPH-#2A1BB, IRGKangXi=1503.020, RSKangXi=196.13
2A1BC CJK UNIFIED IDEOGRAPH-#2A1BC, IRGKangXi=1503.050, RSKangXi=196.13
2A1BD CJK UNIFIED IDEOGRAPH-#2A1BD, IRGKangXi=1503.110, RSKangXi=196.13
2A1BE CJK UNIFIED IDEOGRAPH-#2A1BE, IRGKangXi=1503.120, RSKangXi=196.13
2A1BF CJK UNIFIED IDEOGRAPH-#2A1BF, IRGKangXi=1503.130, RSKangXi=196.13
2A1C0 CJK UNIFIED IDEOGRAPH-#2A1C0, IRGKangXi=1503.140, RSKangXi=196.13
2A1C1 CJK UNIFIED IDEOGRAPH-#2A1C1, IRGKangXi=1503.150, RSKangXi=196.13
2A1C2 CJK UNIFIED IDEOGRAPH-#2A1C2, IRGKangXi=1503.160, RSKangXi=196.13
2A1C3 CJK UNIFIED IDEOGRAPH-#2A1C3, IRGKangXi=1503.161, RSKangXi=196.13
2A1C4 CJK UNIFIED IDEOGRAPH-#2A1C4, IRGKangXi=1503.161, RSKangXi=196.13
2A1C5 CJK UNIFIED IDEOGRAPH-#2A1C5, IRGKangXi=1503.161, RSKangXi=196.13
2A1C6 CJK UNIFIED IDEOGRAPH-#2A1C6, IRGKangXi=1503.161, RSKangXi=196.13
2A1C7 CJK UNIFIED IDEOGRAPH-#2A1C7, IRGKangXi=1503.161, RSKangXi=196.13
2A1C8 CJK UNIFIED IDEOGRAPH-#2A1C8, IRGKangXi=1503.161, RSKangXi=196.13
2A1C9 CJK UNIFIED IDEOGRAPH-#2A1C9, IRGKangXi=1503.161, RSKangXi=196.13
2A1CA CJK UNIFIED IDEOGRAPH-#2A1CA, IRGKangXi=1503.161, RSKangXi=196.13
2A1CB CJK UNIFIED IDEOGRAPH-#2A1CB, IRGKangXi=1503.161, RSKangXi=196.13
2A1CC CJK UNIFIED IDEOGRAPH-#2A1CC, IRGKangXi=1503.161, RSKangXi=196.13
2A1CD CJK UNIFIED IDEOGRAPH-#2A1CD, IRGKangXi=1503.161, RSKangXi=196.13
2A1CE CJK UNIFIED IDEOGRAPH-#2A1CE, IRGKangXi=1503.161, RSKangXi=196.13
2A1CF CJK UNIFIED IDEOGRAPH-#2A1CF, IRGKangXi=1503.161, RSKangXi=196.13
2A1D0 CJK UNIFIED IDEOGRAPH-#2A1D0, IRGKangXi=1503.161, RSKangXi=196.13
2A1D1 CJK UNIFIED IDEOGRAPH-#2A1D1, IRGKangXi=1503.190, RSKangXi=196.14
2A1D2 CJK UNIFIED IDEOGRAPH-#2A1D2, IRGKangXi=1503.200, RSKangXi=196.14
2A1D3 CJK UNIFIED IDEOGRAPH-#2A1D3, IRGKangXi=1503.230, RSKangXi=196.14
2A1D4 CJK UNIFIED IDEOGRAPH-#2A1D4, IRGKangXi=1503.240, RSKangXi=196.14
2A1D5 CJK UNIFIED IDEOGRAPH-#2A1D5, IRGKangXi=1503.250, RSKangXi=196.14
2A1D6 CJK UNIFIED IDEOGRAPH-#2A1D6, IRGKangXi=1503.280, RSKangXi=196.14
2A1D7 CJK UNIFIED IDEOGRAPH-#2A1D7, IRGKangXi=1503.290, RSKangXi=196.14
2A1D8 CJK UNIFIED IDEOGRAPH-#2A1D8, IRGKangXi=1503.300, RSKangXi=196.14
2A1D9 CJK UNIFIED IDEOGRAPH-#2A1D9, IRGKangXi=1503.350, RSKangXi=196.14
2A1DA CJK UNIFIED IDEOGRAPH-#2A1DA, IRGKangXi=1503.360, RSKangXi=196.14
2A1DB CJK UNIFIED IDEOGRAPH-#2A1DB, IRGKangXi=1503.370, RSKangXi=196.14
2A1DC CJK UNIFIED IDEOGRAPH-#2A1DC, IRGKangXi=1503.380, RSKangXi=196.14, Def{a kind of bird}
2A1DD CJK UNIFIED IDEOGRAPH-#2A1DD, IRGKangXi=1503.390, RSKangXi=196.14
2A1DE CJK UNIFIED IDEOGRAPH-#2A1DE, IRGKangXi=1503.391, RSKangXi=207.12
2A1DF CJK UNIFIED IDEOGRAPH-#2A1DF, IRGKangXi=1503.391, RSKangXi=196.14
2A1E0 CJK UNIFIED IDEOGRAPH-#2A1E0, IRGKangXi=1503.391, RSKangXi=196.14
2A1E1 CJK UNIFIED IDEOGRAPH-#2A1E1, IRGKangXi=1503.391, RSKangXi=196.14
2A1E2 CJK UNIFIED IDEOGRAPH-#2A1E2, IRGKangXi=1503.391, RSKangXi=196.14
2A1E3 CJK UNIFIED IDEOGRAPH-#2A1E3, IRGKangXi=1503.391, RSKangXi=196.14
2A1E4 CJK UNIFIED IDEOGRAPH-#2A1E4, IRGKangXi=1503.391, RSKangXi=196.14
2A1E5 CJK UNIFIED IDEOGRAPH-#2A1E5, IRGKangXi=1503.391, RSKangXi=196.14
2A1E6 CJK UNIFIED IDEOGRAPH-#2A1E6, IRGKangXi=1503.391, RSKangXi=196.14
2A1E7 CJK UNIFIED IDEOGRAPH-#2A1E7, IRGKangXi=1503.391, RSKangXi=196.14
2A1E8 CJK UNIFIED IDEOGRAPH-#2A1E8, IRGKangXi=1503.391, RSKangXi=196.14
2A1E9 CJK UNIFIED IDEOGRAPH-#2A1E9, IRGKangXi=1503.391, RSKangXi=196.14
2A1EA CJK UNIFIED IDEOGRAPH-#2A1EA, IRGKangXi=1503.391, RSKangXi=196.14
2A1EB CJK UNIFIED IDEOGRAPH-#2A1EB, IRGKangXi=1503.391, RSKangXi=196.14
2A1EC CJK UNIFIED IDEOGRAPH-#2A1EC, IRGKangXi=1503.391, RSKangXi=196.14
2A1ED CJK UNIFIED IDEOGRAPH-#2A1ED, IRGKangXi=1503.400, RSKangXi=196.15
2A1EE CJK UNIFIED IDEOGRAPH-#2A1EE, IRGKangXi=1503.410, RSKangXi=196.15
2A1EF CJK UNIFIED IDEOGRAPH-#2A1EF, IRGKangXi=1504.010, RSKangXi=196.15
2A1F0 CJK UNIFIED IDEOGRAPH-#2A1F0, IRGKangXi=1504.020, RSKangXi=196.15
2A1F1 CJK UNIFIED IDEOGRAPH-#2A1F1, IRGKangXi=1504.030, RSKangXi=196.15
2A1F2 CJK UNIFIED IDEOGRAPH-#2A1F2, IRGKangXi=1504.040, RSKangXi=196.15
2A1F3 CJK UNIFIED IDEOGRAPH-#2A1F3, IRGKangXi=1504.050, RSKangXi=196.15
2A1F4 CJK UNIFIED IDEOGRAPH-#2A1F4, IRGKangXi=1504.060, RSKangXi=196.15
2A1F5 CJK UNIFIED IDEOGRAPH-#2A1F5, IRGKangXi=1504.070, RSKangXi=196.15
2A1F6 CJK UNIFIED IDEOGRAPH-#2A1F6, IRGKangXi=1504.080, RSKangXi=196.15
2A1F7 CJK UNIFIED IDEOGRAPH-#2A1F7, IRGKangXi=1504.090, RSKangXi=196.15
2A1F8 CJK UNIFIED IDEOGRAPH-#2A1F8, IRGKangXi=1504.100, RSKangXi=196.15
2A1F9 CJK UNIFIED IDEOGRAPH-#2A1F9, IRGKangXi=1504.110, RSKangXi=196.15
2A1FA CJK UNIFIED IDEOGRAPH-#2A1FA, IRGKangXi=1504.130, RSKangXi=196.15
2A1FB CJK UNIFIED IDEOGRAPH-#2A1FB, IRGKangXi=1504.131, RSKangXi=196.15
2A1FC CJK UNIFIED IDEOGRAPH-#2A1FC, IRGKangXi=1504.131, RSKangXi=196.15
2A1FD CJK UNIFIED IDEOGRAPH-#2A1FD, IRGKangXi=1504.131, RSKangXi=196.15
2A1FE CJK UNIFIED IDEOGRAPH-#2A1FE, IRGKangXi=1504.131, RSKangXi=196.15
2A1FF CJK UNIFIED IDEOGRAPH-#2A1FF, IRGKangXi=1504.131, RSKangXi=196.15
2A200 CJK UNIFIED IDEOGRAPH-#2A200, IRGKangXi=1504.131, RSKangXi=196.15
2A201 CJK UNIFIED IDEOGRAPH-#2A201, IRGKangXi=1504.131, RSKangXi=196.15
2A202 CJK UNIFIED IDEOGRAPH-#2A202, IRGKangXi=1504.131, RSKangXi=196.15
2A203 CJK UNIFIED IDEOGRAPH-#2A203, IRGKangXi=1504.150, RSKangXi=196.16
2A204 CJK UNIFIED IDEOGRAPH-#2A204, IRGKangXi=1504.170, RSKangXi=196.16
2A205 CJK UNIFIED IDEOGRAPH-#2A205, IRGKangXi=1504.180, RSKangXi=196.16
2A206 CJK UNIFIED IDEOGRAPH-#2A206, IRGKangXi=1504.190, RSKangXi=196.16
2A207 CJK UNIFIED IDEOGRAPH-#2A207, IRGKangXi=1504.210, RSKangXi=196.16
2A208 CJK UNIFIED IDEOGRAPH-#2A208, IRGKangXi=1504.220, RSKangXi=196.16
2A209 CJK UNIFIED IDEOGRAPH-#2A209, IRGKangXi=1504.230, RSKangXi=196.16
2A20A CJK UNIFIED IDEOGRAPH-#2A20A, IRGKangXi=1504.240, RSKangXi=196.16
2A20B CJK UNIFIED IDEOGRAPH-#2A20B, IRGKangXi=1504.250, RSKangXi=196.16
2A20C CJK UNIFIED IDEOGRAPH-#2A20C, IRGKangXi=1504.260, RSKangXi=196.16
2A20D CJK UNIFIED IDEOGRAPH-#2A20D, IRGKangXi=1504.270, RSKangXi=196.16
2A20E CJK UNIFIED IDEOGRAPH-#2A20E, IRGKangXi=1504.271, RSKangXi=196.16
2A20F CJK UNIFIED IDEOGRAPH-#2A20F, IRGKangXi=1504.271, RSKangXi=196.16
2A210 CJK UNIFIED IDEOGRAPH-#2A210, IRGKangXi=1504.271, RSKangXi=196.16
2A211 CJK UNIFIED IDEOGRAPH-#2A211, IRGKangXi=1504.271, RSKangXi=196.16
2A212 CJK UNIFIED IDEOGRAPH-#2A212, IRGKangXi=1504.271, RSKangXi=196.16
2A213 CJK UNIFIED IDEOGRAPH-#2A213, IRGKangXi=1504.271, RSKangXi=196.16
2A214 CJK UNIFIED IDEOGRAPH-#2A214, IRGKangXi=1504.271, RSKangXi=196.16
2A215 CJK UNIFIED IDEOGRAPH-#2A215, IRGKangXi=1504.271, RSKangXi=196.16
2A216 CJK UNIFIED IDEOGRAPH-#2A216, IRGKangXi=1504.271, RSKangXi=196.16
2A217 CJK UNIFIED IDEOGRAPH-#2A217, IRGKangXi=1504.271, RSKangXi=196.16
2A218 CJK UNIFIED IDEOGRAPH-#2A218, IRGKangXi=1504.280, RSKangXi=196.17
2A219 CJK UNIFIED IDEOGRAPH-#2A219, IRGKangXi=1504.320, RSKangXi=196.17
2A21A CJK UNIFIED IDEOGRAPH-#2A21A, IRGKangXi=1504.330, RSKangXi=196.17
2A21B CJK UNIFIED IDEOGRAPH-#2A21B, IRGKangXi=1504.340, RSKangXi=196.17
2A21C CJK UNIFIED IDEOGRAPH-#2A21C, IRGKangXi=1504.350, RSKangXi=196.17
2A21D CJK UNIFIED IDEOGRAPH-#2A21D, IRGKangXi=1504.360, RSKangXi=196.17
2A21E CJK UNIFIED IDEOGRAPH-#2A21E, IRGKangXi=1504.370, RSKangXi=196.17
2A21F CJK UNIFIED IDEOGRAPH-#2A21F, IRGKangXi=1504.371, RSKangXi=196.17
2A220 CJK UNIFIED IDEOGRAPH-#2A220, IRGKangXi=1504.371, RSKangXi=196.17
2A221 CJK UNIFIED IDEOGRAPH-#2A221, IRGKangXi=1504.371, RSKangXi=196.17
2A222 CJK UNIFIED IDEOGRAPH-#2A222, IRGKangXi=1504.371, RSKangXi=196.17
2A223 CJK UNIFIED IDEOGRAPH-#2A223, IRGKangXi=1504.371, RSKangXi=196.17
2A224 CJK UNIFIED IDEOGRAPH-#2A224, IRGKangXi=1504.371, RSKangXi=196.17
2A225 CJK UNIFIED IDEOGRAPH-#2A225, IRGKangXi=1504.380, RSKangXi=196.18
2A226 CJK UNIFIED IDEOGRAPH-#2A226, IRGKangXi=1504.410, RSKangXi=196.18
2A227 CJK UNIFIED IDEOGRAPH-#2A227, IRGKangXi=1504.420, RSKangXi=196.18
2A228 CJK UNIFIED IDEOGRAPH-#2A228, IRGKangXi=1504.430, RSKangXi=196.18
2A229 CJK UNIFIED IDEOGRAPH-#2A229, IRGKangXi=1504.431, RSKangXi=196.18
2A22A CJK UNIFIED IDEOGRAPH-#2A22A, IRGKangXi=1504.431, RSKangXi=196.18
2A22B CJK UNIFIED IDEOGRAPH-#2A22B, IRGKangXi=1504.431, RSKangXi=196.18
2A22C CJK UNIFIED IDEOGRAPH-#2A22C, IRGKangXi=1504.431, RSKangXi=196.18
2A22D CJK UNIFIED IDEOGRAPH-#2A22D, IRGKangXi=1504.431, RSKangXi=196.18
2A22E CJK UNIFIED IDEOGRAPH-#2A22E, IRGKangXi=1505.020, RSKangXi=196.19
2A22F CJK UNIFIED IDEOGRAPH-#2A22F, IRGKangXi=1505.030, RSKangXi=196.19
2A230 CJK UNIFIED IDEOGRAPH-#2A230, IRGKangXi=1505.040, RSKangXi=196.19
2A231 CJK UNIFIED IDEOGRAPH-#2A231, IRGKangXi=1505.050, RSKangXi=196.19
2A232 CJK UNIFIED IDEOGRAPH-#2A232, IRGKangXi=1505.051, RSKangXi=196.19
2A233 CJK UNIFIED IDEOGRAPH-#2A233, IRGKangXi=1505.051, RSKangXi=196.19
2A234 CJK UNIFIED IDEOGRAPH-#2A234, IRGKangXi=1505.070, RSKangXi=196.20
2A235 CJK UNIFIED IDEOGRAPH-#2A235, IRGKangXi=1505.071, RSKangXi=196.20
2A236 CJK UNIFIED IDEOGRAPH-#2A236, IRGKangXi=1505.071, RSKangXi=196.20
2A237 CJK UNIFIED IDEOGRAPH-#2A237, IRGKangXi=1505.071, RSKangXi=196.20
2A238 CJK UNIFIED IDEOGRAPH-#2A238, IRGKangXi=1505.080, RSKangXi=196.21
2A239 CJK UNIFIED IDEOGRAPH-#2A239, IRGKangXi=1505.081, RSKangXi=196.21
2A23A CJK UNIFIED IDEOGRAPH-#2A23A, IRGKangXi=1505.081, RSKangXi=196.21
2A23B CJK UNIFIED IDEOGRAPH-#2A23B, IRGKangXi=1505.090, RSKangXi=196.22
2A23C CJK UNIFIED IDEOGRAPH-#2A23C, IRGKangXi=1505.100, RSKangXi=196.22
2A23D CJK UNIFIED IDEOGRAPH-#2A23D, IRGKangXi=1505.101, RSKangXi=196.22
2A23E CJK UNIFIED IDEOGRAPH-#2A23E, IRGKangXi=1505.121, RSKangXi=196.24
2A23F CJK UNIFIED IDEOGRAPH-#2A23F, IRGKangXi=1505.130, RSKangXi=196.25
2A240 CJK UNIFIED IDEOGRAPH-#2A240, IRGKangXi=1505.140, RSKangXi=196.25
2A241 CJK UNIFIED IDEOGRAPH-#2A241, IRGKangXi=1505.141, RSKangXi=196.4
2A242 CJK UNIFIED IDEOGRAPH-#2A242, IRGKangXi=1505.141, RSKangXi=196.4
2A243 CJK UNIFIED IDEOGRAPH-#2A243, IRGKangXi=1505.141, RSKangXi=196.4
2A244 CJK UNIFIED IDEOGRAPH-#2A244, IRGKangXi=1505.141, RSKangXi=196.5
2A245 CJK UNIFIED IDEOGRAPH-#2A245, IRGKangXi=1505.141, RSKangXi=196.6
2A246 CJK UNIFIED IDEOGRAPH-#2A246, IRGKangXi=1505.141, RSKangXi=196.6
2A247 CJK UNIFIED IDEOGRAPH-#2A247, IRGKangXi=1505.141, RSKangXi=196.6
2A248 CJK UNIFIED IDEOGRAPH-#2A248, IRGKangXi=1505.141, RSKangXi=196.6
2A249 CJK UNIFIED IDEOGRAPH-#2A249, IRGKangXi=1505.141, RSKangXi=196.6
2A24A CJK UNIFIED IDEOGRAPH-#2A24A, IRGKangXi=1505.141, RSKangXi=196.6
2A24B CJK UNIFIED IDEOGRAPH-#2A24B, IRGKangXi=1505.141, RSKangXi=196.6
2A24C CJK UNIFIED IDEOGRAPH-#2A24C, IRGKangXi=1505.141, RSKangXi=196.7
2A24D CJK UNIFIED IDEOGRAPH-#2A24D, IRGKangXi=1505.141, RSKangXi=196.7
2A24E CJK UNIFIED IDEOGRAPH-#2A24E, IRGKangXi=1505.141, RSKangXi=196.8
2A24F CJK UNIFIED IDEOGRAPH-#2A24F, IRGKangXi=1505.141, RSKangXi=196.9
2A250 CJK UNIFIED IDEOGRAPH-#2A250, IRGKangXi=1505.141, RSKangXi=196.9
2A251 CJK UNIFIED IDEOGRAPH-#2A251, IRGKangXi=1505.141, RSKangXi=196.10
2A252 CJK UNIFIED IDEOGRAPH-#2A252, IRGKangXi=1505.141, RSKangXi=196.10
2A253 CJK UNIFIED IDEOGRAPH-#2A253, IRGKangXi=1505.141, RSKangXi=196.10
2A254 CJK UNIFIED IDEOGRAPH-#2A254, IRGKangXi=1505.141, RSKangXi=196.10
2A255 CJK UNIFIED IDEOGRAPH-#2A255, IRGKangXi=1505.141, RSKangXi=196.15
2A256 CJK UNIFIED IDEOGRAPH-#2A256, IRGKangXi=1507.020, RSKangXi=197.3
2A257 CJK UNIFIED IDEOGRAPH-#2A257, IRGKangXi=1507.030, RSKangXi=197.3
2A258 CJK UNIFIED IDEOGRAPH-#2A258, IRGKangXi=1507.040, RSKangXi=197.4
2A259 CJK UNIFIED IDEOGRAPH-#2A259, IRGKangXi=1507.070, RSKangXi=197.4
2A25A CJK UNIFIED IDEOGRAPH-#2A25A, IRGKangXi=1507.071, RSKangXi=197.4
2A25B CJK UNIFIED IDEOGRAPH-#2A25B, IRGKangXi=1507.071, RSKangXi=197.4
2A25C CJK UNIFIED IDEOGRAPH-#2A25C, IRGKangXi=1507.080, RSKangXi=197.5
2A25D CJK UNIFIED IDEOGRAPH-#2A25D, IRGKangXi=1507.090, RSKangXi=197.5
2A25E CJK UNIFIED IDEOGRAPH-#2A25E, IRGKangXi=1507.100, RSKangXi=197.5
2A25F CJK UNIFIED IDEOGRAPH-#2A25F, IRGKangXi=1507.120, RSKangXi=197.5
2A260 CJK UNIFIED IDEOGRAPH-#2A260, IRGKangXi=1507.121, RSKangXi=197.5
2A261 CJK UNIFIED IDEOGRAPH-#2A261, IRGKangXi=1507.121, RSKangXi=197.5
2A262 CJK UNIFIED IDEOGRAPH-#2A262, IRGKangXi=1507.121, RSKangXi=197.6
2A263 CJK UNIFIED IDEOGRAPH-#2A263, IRGKangXi=1507.140, RSKangXi=197.7
2A264 CJK UNIFIED IDEOGRAPH-#2A264, IRGKangXi=1507.141, RSKangXi=197.7
2A265 CJK UNIFIED IDEOGRAPH-#2A265, IRGKangXi=1507.141, RSKangXi=197.7
2A266 CJK UNIFIED IDEOGRAPH-#2A266, IRGKangXi=1507.150, RSKangXi=197.8
2A267 CJK UNIFIED IDEOGRAPH-#2A267, IRGKangXi=1507.160, RSKangXi=197.8
2A268 CJK UNIFIED IDEOGRAPH-#2A268, IRGKangXi=1507.170, RSKangXi=197.8
2A269 CJK UNIFIED IDEOGRAPH-#2A269, IRGKangXi=1507.180, RSKangXi=197.8, Def{variant of 塩 U+5869, salt}
2A26A CJK UNIFIED IDEOGRAPH-#2A26A, IRGKangXi=1507.181, RSKangXi=197.8
2A26B CJK UNIFIED IDEOGRAPH-#2A26B, IRGKangXi=1507.181, RSKangXi=197.8
2A26C CJK UNIFIED IDEOGRAPH-#2A26C, IRGKangXi=1507.181, RSKangXi=197.8
2A26D CJK UNIFIED IDEOGRAPH-#2A26D, IRGKangXi=1507.190, RSKangXi=197.9
2A26E CJK UNIFIED IDEOGRAPH-#2A26E, IRGKangXi=1507.210, RSKangXi=197.9
2A26F CJK UNIFIED IDEOGRAPH-#2A26F, IRGKangXi=1507.220, RSKangXi=197.9
2A270 CJK UNIFIED IDEOGRAPH-#2A270, IRGKangXi=1507.230, RSKangXi=197.9
2A271 CJK UNIFIED IDEOGRAPH-#2A271, IRGKangXi=1507.240, RSKangXi=197.9
2A272 CJK UNIFIED IDEOGRAPH-#2A272, IRGKangXi=1507.250, RSKangXi=197.9
2A273 CJK UNIFIED IDEOGRAPH-#2A273, IRGKangXi=1507.251, RSKangXi=197.9
2A274 CJK UNIFIED IDEOGRAPH-#2A274, IRGKangXi=1507.251, RSKangXi=197.9
2A275 CJK UNIFIED IDEOGRAPH-#2A275, IRGKangXi=1507.251, RSKangXi=197.10
2A276 CJK UNIFIED IDEOGRAPH-#2A276, IRGKangXi=1507.270, RSKangXi=197.10
2A277 CJK UNIFIED IDEOGRAPH-#2A277, IRGKangXi=1507.280, RSKangXi=197.10
2A278 CJK UNIFIED IDEOGRAPH-#2A278, IRGKangXi=1507.310, RSKangXi=197.10
2A279 CJK UNIFIED IDEOGRAPH-#2A279, IRGKangXi=1507.311, RSKangXi=197.10
2A27A CJK UNIFIED IDEOGRAPH-#2A27A, IRGKangXi=1507.320, RSKangXi=197.11
2A27B CJK UNIFIED IDEOGRAPH-#2A27B, IRGKangXi=1507.321, RSKangXi=197.11
2A27C CJK UNIFIED IDEOGRAPH-#2A27C, IRGKangXi=1507.321, RSKangXi=197.11
2A27D CJK UNIFIED IDEOGRAPH-#2A27D, IRGKangXi=1507.321, RSKangXi=197.11
2A27E CJK UNIFIED IDEOGRAPH-#2A27E, IRGKangXi=1507.321, RSKangXi=197.11
2A27F CJK UNIFIED IDEOGRAPH-#2A27F, IRGKangXi=1508.010, RSKangXi=197.12
2A280 CJK UNIFIED IDEOGRAPH-#2A280, IRGKangXi=1508.030, RSKangXi=197.12
2A281 CJK UNIFIED IDEOGRAPH-#2A281, IRGKangXi=1508.031, RSKangXi=197.12
2A282 CJK UNIFIED IDEOGRAPH-#2A282, IRGKangXi=1508.031, RSKangXi=197.12
2A283 CJK UNIFIED IDEOGRAPH-#2A283, IRGKangXi=1508.050, RSKangXi=197.13
2A284 CJK UNIFIED IDEOGRAPH-#2A284, IRGKangXi=1508.060, RSKangXi=197.13
2A285 CJK UNIFIED IDEOGRAPH-#2A285, IRGKangXi=1508.071, RSKangXi=197.13
2A286 CJK UNIFIED IDEOGRAPH-#2A286, IRGKangXi=1508.080, RSKangXi=197.14
2A287 CJK UNIFIED IDEOGRAPH-#2A287, IRGKangXi=1508.100, RSKangXi=197.14
2A288 CJK UNIFIED IDEOGRAPH-#2A288, IRGKangXi=1508.110, RSKangXi=197.15
2A289 CJK UNIFIED IDEOGRAPH-#2A289, IRGKangXi=1508.120, RSKangXi=197.16
2A28A CJK UNIFIED IDEOGRAPH-#2A28A, IRGKangXi=1508.130, RSKangXi=197.17
2A28B CJK UNIFIED IDEOGRAPH-#2A28B, IRGKangXi=1509.030, RSKangXi=198.2
2A28C CJK UNIFIED IDEOGRAPH-#2A28C, IRGKangXi=1509.031, RSKangXi=198.2
2A28D CJK UNIFIED IDEOGRAPH-#2A28D, IRGKangXi=1509.040, RSKangXi=198.3
2A28E CJK UNIFIED IDEOGRAPH-#2A28E, IRGKangXi=1509.051, RSKangXi=198.3
2A28F CJK UNIFIED IDEOGRAPH-#2A28F, IRGKangXi=1509.070, RSKangXi=198.4
2A290 CJK UNIFIED IDEOGRAPH-#2A290, IRGKangXi=1509.080, RSKangXi=198.4
2A291 CJK UNIFIED IDEOGRAPH-#2A291, IRGKangXi=1509.090, RSKangXi=198.4
2A292 CJK UNIFIED IDEOGRAPH-#2A292, IRGKangXi=1509.100, RSKangXi=198.4
2A293 CJK UNIFIED IDEOGRAPH-#2A293, IRGKangXi=1509.120, RSKangXi=198.4
2A294 CJK UNIFIED IDEOGRAPH-#2A294, IRGKangXi=1509.130, RSKangXi=198.4
2A295 CJK UNIFIED IDEOGRAPH-#2A295, IRGKangXi=1509.140, RSKangXi=198.4
2A296 CJK UNIFIED IDEOGRAPH-#2A296, IRGKangXi=1509.150, RSKangXi=198.4
2A297 CJK UNIFIED IDEOGRAPH-#2A297, IRGKangXi=1509.160, RSKangXi=198.4
2A298 CJK UNIFIED IDEOGRAPH-#2A298, IRGKangXi=1509.171, RSKangXi=198.4
2A299 CJK UNIFIED IDEOGRAPH-#2A299, IRGKangXi=1509.171, RSKangXi=198.4
2A29A CJK UNIFIED IDEOGRAPH-#2A29A, IRGKangXi=1509.171, RSKangXi=198.4
2A29B CJK UNIFIED IDEOGRAPH-#2A29B, IRGKangXi=1509.190, RSKangXi=198.5
2A29C CJK UNIFIED IDEOGRAPH-#2A29C, IRGKangXi=1509.250, RSKangXi=198.5
2A29D CJK UNIFIED IDEOGRAPH-#2A29D, IRGKangXi=1509.261, RSKangXi=198.5
2A29E CJK UNIFIED IDEOGRAPH-#2A29E, IRGKangXi=1509.261, RSKangXi=198.5
2A29F CJK UNIFIED IDEOGRAPH-#2A29F, IRGKangXi=1509.261, RSKangXi=198.5
2A2A0 CJK UNIFIED IDEOGRAPH-#2A2A0, IRGKangXi=1509.261, RSKangXi=198.5
2A2A1 CJK UNIFIED IDEOGRAPH-#2A2A1, IRGKangXi=1509.261, RSKangXi=198.5
2A2A2 CJK UNIFIED IDEOGRAPH-#2A2A2, IRGKangXi=1509.261, RSKangXi=198.5
2A2A3 CJK UNIFIED IDEOGRAPH-#2A2A3, IRGKangXi=1509.261, RSKangXi=198.5
2A2A4 CJK UNIFIED IDEOGRAPH-#2A2A4, IRGKangXi=1509.261, RSKangXi=198.5
2A2A5 CJK UNIFIED IDEOGRAPH-#2A2A5, IRGKangXi=1509.270, RSKangXi=198.6
2A2A6 CJK UNIFIED IDEOGRAPH-#2A2A6, IRGKangXi=1509.280, RSKangXi=198.6
2A2A7 CJK UNIFIED IDEOGRAPH-#2A2A7, IRGKangXi=1509.290, RSKangXi=198.6
2A2A8 CJK UNIFIED IDEOGRAPH-#2A2A8, IRGKangXi=1509.300, RSKangXi=198.6
2A2A9 CJK UNIFIED IDEOGRAPH-#2A2A9, IRGKangXi=1509.350, RSKangXi=198.6
2A2AA CJK UNIFIED IDEOGRAPH-#2A2AA, IRGKangXi=1509.360, RSKangXi=198.6
2A2AB CJK UNIFIED IDEOGRAPH-#2A2AB, IRGKangXi=1510.010, RSKangXi=198.6
2A2AC CJK UNIFIED IDEOGRAPH-#2A2AC, IRGKangXi=1510.020, RSKangXi=198.6
2A2AD CJK UNIFIED IDEOGRAPH-#2A2AD, IRGKangXi=1510.030, RSKangXi=198.6
2A2AE CJK UNIFIED IDEOGRAPH-#2A2AE, IRGKangXi=1510.031, RSKangXi=198.6
2A2AF CJK UNIFIED IDEOGRAPH-#2A2AF, IRGKangXi=1510.031, RSKangXi=198.6
2A2B0 CJK UNIFIED IDEOGRAPH-#2A2B0, IRGKangXi=1510.031, RSKangXi=198.6
2A2B1 CJK UNIFIED IDEOGRAPH-#2A2B1, IRGKangXi=1510.031, RSKangXi=198.6
2A2B2 CJK UNIFIED IDEOGRAPH-#2A2B2, IRGKangXi=1510.031, RSKangXi=198.6
2A2B3 CJK UNIFIED IDEOGRAPH-#2A2B3, IRGKangXi=1510.031, RSKangXi=198.6
2A2B4 CJK UNIFIED IDEOGRAPH-#2A2B4, IRGKangXi=1510.050, RSKangXi=198.7
2A2B5 CJK UNIFIED IDEOGRAPH-#2A2B5, IRGKangXi=1510.080, RSKangXi=198.7
2A2B6 CJK UNIFIED IDEOGRAPH-#2A2B6, IRGKangXi=1510.100, RSKangXi=198.7
2A2B7 CJK UNIFIED IDEOGRAPH-#2A2B7, IRGKangXi=1510.110, RSKangXi=198.7
2A2B8 CJK UNIFIED IDEOGRAPH-#2A2B8, IRGKangXi=1510.140, RSKangXi=198.7
2A2B9 CJK UNIFIED IDEOGRAPH-#2A2B9, IRGKangXi=1510.150, RSKangXi=198.7
2A2BA CJK UNIFIED IDEOGRAPH-#2A2BA, IRGKangXi=1510.160, RSKangXi=198.7
2A2BB CJK UNIFIED IDEOGRAPH-#2A2BB, IRGKangXi=1510.170, RSKangXi=198.7
2A2BC CJK UNIFIED IDEOGRAPH-#2A2BC, IRGKangXi=1510.171, RSKangXi=198.7
2A2BD CJK UNIFIED IDEOGRAPH-#2A2BD, IRGKangXi=1510.171, RSKangXi=198.7
2A2BE CJK UNIFIED IDEOGRAPH-#2A2BE, IRGKangXi=1510.171, RSKangXi=198.7
2A2BF CJK UNIFIED IDEOGRAPH-#2A2BF, IRGKangXi=1510.171, RSKangXi=198.7
2A2C0 CJK UNIFIED IDEOGRAPH-#2A2C0, IRGKangXi=1510.171, RSKangXi=198.7
2A2C1 CJK UNIFIED IDEOGRAPH-#2A2C1, IRGKangXi=1510.171, RSKangXi=198.7
2A2C2 CJK UNIFIED IDEOGRAPH-#2A2C2, IRGKangXi=1510.171, RSKangXi=198.7
2A2C3 CJK UNIFIED IDEOGRAPH-#2A2C3, IRGKangXi=1510.171, RSKangXi=198.7
2A2C4 CJK UNIFIED IDEOGRAPH-#2A2C4, IRGKangXi=1510.180, RSKangXi=198.8
2A2C5 CJK UNIFIED IDEOGRAPH-#2A2C5, IRGKangXi=1510.190, RSKangXi=198.8
2A2C6 CJK UNIFIED IDEOGRAPH-#2A2C6, IRGKangXi=1510.200, RSKangXi=198.8
2A2C7 CJK UNIFIED IDEOGRAPH-#2A2C7, IRGKangXi=1510.220, RSKangXi=198.8
2A2C8 CJK UNIFIED IDEOGRAPH-#2A2C8, IRGKangXi=1510.300, RSKangXi=198.8
2A2C9 CJK UNIFIED IDEOGRAPH-#2A2C9, IRGKangXi=1511.010, RSKangXi=198.8
2A2CA CJK UNIFIED IDEOGRAPH-#2A2CA, IRGKangXi=1511.011, RSKangXi=198.8
2A2CB CJK UNIFIED IDEOGRAPH-#2A2CB, IRGKangXi=1511.011, RSKangXi=198.8
2A2CC CJK UNIFIED IDEOGRAPH-#2A2CC, IRGKangXi=1511.011, RSKangXi=198.8
2A2CD CJK UNIFIED IDEOGRAPH-#2A2CD, IRGKangXi=1511.011, RSKangXi=198.8
2A2CE CJK UNIFIED IDEOGRAPH-#2A2CE, IRGKangXi=1511.050, RSKangXi=198.9
2A2CF CJK UNIFIED IDEOGRAPH-#2A2CF, IRGKangXi=1511.060, RSKangXi=198.9
2A2D0 CJK UNIFIED IDEOGRAPH-#2A2D0, IRGKangXi=1511.070, RSKangXi=198.9
2A2D1 CJK UNIFIED IDEOGRAPH-#2A2D1, IRGKangXi=1511.090, RSKangXi=198.9
2A2D2 CJK UNIFIED IDEOGRAPH-#2A2D2, IRGKangXi=1511.091, RSKangXi=198.9
2A2D3 CJK UNIFIED IDEOGRAPH-#2A2D3, IRGKangXi=1511.091, RSKangXi=198.9
2A2D4 CJK UNIFIED IDEOGRAPH-#2A2D4, IRGKangXi=1511.091, RSKangXi=198.9
2A2D5 CJK UNIFIED IDEOGRAPH-#2A2D5, IRGKangXi=1511.091, RSKangXi=198.9
2A2D6 CJK UNIFIED IDEOGRAPH-#2A2D6, IRGKangXi=1511.091, RSKangXi=198.9
2A2D7 CJK UNIFIED IDEOGRAPH-#2A2D7, IRGKangXi=1511.100, RSKangXi=198.10
2A2D8 CJK UNIFIED IDEOGRAPH-#2A2D8, IRGKangXi=1511.120, RSKangXi=198.10
2A2D9 CJK UNIFIED IDEOGRAPH-#2A2D9, IRGKangXi=1511.140, RSKangXi=198.10
2A2DA CJK UNIFIED IDEOGRAPH-#2A2DA, IRGKangXi=1511.150, RSKangXi=198.10
2A2DB CJK UNIFIED IDEOGRAPH-#2A2DB, IRGKangXi=1511.151, RSKangXi=198.10
2A2DC CJK UNIFIED IDEOGRAPH-#2A2DC, IRGKangXi=1511.160, RSKangXi=198.11
2A2DD CJK UNIFIED IDEOGRAPH-#2A2DD, IRGKangXi=1511.170, RSKangXi=198.11
2A2DE CJK UNIFIED IDEOGRAPH-#2A2DE, IRGKangXi=1511.191, RSKangXi=198.11
2A2DF CJK UNIFIED IDEOGRAPH-#2A2DF, IRGKangXi=1511.191, RSKangXi=198.11
2A2E0 CJK UNIFIED IDEOGRAPH-#2A2E0, IRGKangXi=1511.191, RSKangXi=198.11
2A2E1 CJK UNIFIED IDEOGRAPH-#2A2E1, IRGKangXi=1511.210, RSKangXi=198.12
2A2E2 CJK UNIFIED IDEOGRAPH-#2A2E2, IRGKangXi=1511.220, RSKangXi=198.12
2A2E3 CJK UNIFIED IDEOGRAPH-#2A2E3, IRGKangXi=1511.230, RSKangXi=198.12
2A2E4 CJK UNIFIED IDEOGRAPH-#2A2E4, IRGKangXi=1511.231, RSKangXi=198.12
2A2E5 CJK UNIFIED IDEOGRAPH-#2A2E5, IRGKangXi=1511.231, RSKangXi=198.12
2A2E6 CJK UNIFIED IDEOGRAPH-#2A2E6, IRGKangXi=1511.231, RSKangXi=198.12
2A2E7 CJK UNIFIED IDEOGRAPH-#2A2E7, IRGKangXi=1511.231, RSKangXi=198.12
2A2E8 CJK UNIFIED IDEOGRAPH-#2A2E8, IRGKangXi=1511.231, RSKangXi=198.12
2A2E9 CJK UNIFIED IDEOGRAPH-#2A2E9, IRGKangXi=1511.231, RSKangXi=198.12
2A2EA CJK UNIFIED IDEOGRAPH-#2A2EA, IRGKangXi=1511.240, RSKangXi=198.13
2A2EB CJK UNIFIED IDEOGRAPH-#2A2EB, IRGKangXi=1511.250, RSKangXi=198.13
2A2EC CJK UNIFIED IDEOGRAPH-#2A2EC, IRGKangXi=1511.270, RSKangXi=198.13
2A2ED CJK UNIFIED IDEOGRAPH-#2A2ED, IRGKangXi=1511.281, RSKangXi=198.13
2A2EE CJK UNIFIED IDEOGRAPH-#2A2EE, IRGKangXi=1511.300, RSKangXi=198.14
2A2EF CJK UNIFIED IDEOGRAPH-#2A2EF, IRGKangXi=1512.010, RSKangXi=198.14
2A2F0 CJK UNIFIED IDEOGRAPH-#2A2F0, IRGKangXi=1512.020, RSKangXi=198.14
2A2F1 CJK UNIFIED IDEOGRAPH-#2A2F1, IRGKangXi=1512.021, RSKangXi=198.14
2A2F2 CJK UNIFIED IDEOGRAPH-#2A2F2, IRGKangXi=1512.021, RSKangXi=198.14
2A2F3 CJK UNIFIED IDEOGRAPH-#2A2F3, IRGKangXi=1512.021, RSKangXi=198.14
2A2F4 CJK UNIFIED IDEOGRAPH-#2A2F4, IRGKangXi=1512.021, RSKangXi=198.14
2A2F5 CJK UNIFIED IDEOGRAPH-#2A2F5, IRGKangXi=1512.021, RSKangXi=198.16
2A2F6 CJK UNIFIED IDEOGRAPH-#2A2F6, IRGKangXi=1512.031, RSKangXi=198.17
2A2F7 CJK UNIFIED IDEOGRAPH-#2A2F7, IRGKangXi=1512.031, RSKangXi=198.17
2A2F8 CJK UNIFIED IDEOGRAPH-#2A2F8, IRGKangXi=1512.040, RSKangXi=198.18
2A2F9 CJK UNIFIED IDEOGRAPH-#2A2F9, IRGKangXi=1512.051, RSKangXi=198.20
2A2FA CJK UNIFIED IDEOGRAPH-#2A2FA, IRGKangXi=1512.061, RSKangXi=198.24
2A2FB CJK UNIFIED IDEOGRAPH-#2A2FB, IRGKangXi=1512.070, RSKangXi=198.25
2A2FC CJK UNIFIED IDEOGRAPH-#2A2FC, IRGKangXi=1512.100, RSKangXi=199.2
2A2FD CJK UNIFIED IDEOGRAPH-#2A2FD, IRGKangXi=1512.110, RSKangXi=199.2
2A2FE CJK UNIFIED IDEOGRAPH-#2A2FE, IRGKangXi=1512.120, RSKangXi=199.2
2A2FF CJK UNIFIED IDEOGRAPH-#2A2FF, IRGKangXi=1512.121, RSKangXi=199.2
2A300 CJK UNIFIED IDEOGRAPH-#2A300, IRGKangXi=1512.121, RSKangXi=199.2
2A301 CJK UNIFIED IDEOGRAPH-#2A301, IRGKangXi=1512.130, RSKangXi=199.3
2A302 CJK UNIFIED IDEOGRAPH-#2A302, IRGKangXi=1512.160, RSKangXi=199.3
2A303 CJK UNIFIED IDEOGRAPH-#2A303, IRGKangXi=1512.181, RSKangXi=199.3
2A304 CJK UNIFIED IDEOGRAPH-#2A304, IRGKangXi=1512.181, RSKangXi=199.3
2A305 CJK UNIFIED IDEOGRAPH-#2A305, IRGKangXi=1512.190, RSKangXi=199.4
2A306 CJK UNIFIED IDEOGRAPH-#2A306, IRGKangXi=1512.200, RSKangXi=199.4
2A307 CJK UNIFIED IDEOGRAPH-#2A307, IRGKangXi=1512.220, RSKangXi=199.4
2A308 CJK UNIFIED IDEOGRAPH-#2A308, IRGKangXi=1512.240, RSKangXi=199.4
2A309 CJK UNIFIED IDEOGRAPH-#2A309, IRGKangXi=1512.250, RSKangXi=199.4
2A30A CJK UNIFIED IDEOGRAPH-#2A30A, IRGKangXi=1512.280, RSKangXi=199.4
2A30B CJK UNIFIED IDEOGRAPH-#2A30B, IRGKangXi=1512.290, RSKangXi=199.4
2A30C CJK UNIFIED IDEOGRAPH-#2A30C, IRGKangXi=1513.010, RSKangXi=199.4
2A30D CJK UNIFIED IDEOGRAPH-#2A30D, IRGKangXi=1513.020, RSKangXi=199.4
2A30E CJK UNIFIED IDEOGRAPH-#2A30E, IRGKangXi=1513.021, RSKangXi=199.4
2A30F CJK UNIFIED IDEOGRAPH-#2A30F, IRGKangXi=1513.021, RSKangXi=199.4
2A310 CJK UNIFIED IDEOGRAPH-#2A310, IRGKangXi=1513.021, RSKangXi=199.4
2A311 CJK UNIFIED IDEOGRAPH-#2A311, IRGKangXi=1513.021, RSKangXi=199.4
2A312 CJK UNIFIED IDEOGRAPH-#2A312, IRGKangXi=1513.021, RSKangXi=199.4
2A313 CJK UNIFIED IDEOGRAPH-#2A313, IRGKangXi=1513.021, RSKangXi=199.4
2A314 CJK UNIFIED IDEOGRAPH-#2A314, IRGKangXi=1513.040, RSKangXi=199.5
2A315 CJK UNIFIED IDEOGRAPH-#2A315, IRGKangXi=1513.060, RSKangXi=199.5
2A316 CJK UNIFIED IDEOGRAPH-#2A316, IRGKangXi=1513.090, RSKangXi=199.5
2A317 CJK UNIFIED IDEOGRAPH-#2A317, IRGKangXi=1513.100, RSKangXi=199.5
2A318 CJK UNIFIED IDEOGRAPH-#2A318, IRGKangXi=1513.110, RSKangXi=199.5
2A319 CJK UNIFIED IDEOGRAPH-#2A319, IRGKangXi=1513.150, RSKangXi=199.5
2A31A CJK UNIFIED IDEOGRAPH-#2A31A, IRGKangXi=1513.160, RSKangXi=199.5
2A31B CJK UNIFIED IDEOGRAPH-#2A31B, IRGKangXi=1513.161, RSKangXi=34.9
2A31C CJK UNIFIED IDEOGRAPH-#2A31C, IRGKangXi=1513.161, RSKangXi=199.5
2A31D CJK UNIFIED IDEOGRAPH-#2A31D, IRGKangXi=1513.161, RSKangXi=199.5
2A31E CJK UNIFIED IDEOGRAPH-#2A31E, IRGKangXi=1513.161, RSKangXi=199.5
2A31F CJK UNIFIED IDEOGRAPH-#2A31F, IRGKangXi=1513.161, RSKangXi=199.5
2A320 CJK UNIFIED IDEOGRAPH-#2A320, IRGKangXi=1513.161, RSKangXi=199.5
2A321 CJK UNIFIED IDEOGRAPH-#2A321, IRGKangXi=1513.161, RSKangXi=199.5
2A322 CJK UNIFIED IDEOGRAPH-#2A322, IRGKangXi=1513.180, RSKangXi=199.6
2A323 CJK UNIFIED IDEOGRAPH-#2A323, IRGKangXi=1513.200, RSKangXi=199.6
2A324 CJK UNIFIED IDEOGRAPH-#2A324, IRGKangXi=1513.210, RSKangXi=199.6
2A325 CJK UNIFIED IDEOGRAPH-#2A325, IRGKangXi=1513.230, RSKangXi=199.6
2A326 CJK UNIFIED IDEOGRAPH-#2A326, IRGKangXi=1513.231, RSKangXi=199.6
2A327 CJK UNIFIED IDEOGRAPH-#2A327, IRGKangXi=1513.231, RSKangXi=199.6
2A328 CJK UNIFIED IDEOGRAPH-#2A328, IRGKangXi=1513.231, RSKangXi=199.6
2A329 CJK UNIFIED IDEOGRAPH-#2A329, IRGKangXi=1513.231, RSKangXi=199.6
2A32A CJK UNIFIED IDEOGRAPH-#2A32A, IRGKangXi=1513.231, RSKangXi=199.6
2A32B CJK UNIFIED IDEOGRAPH-#2A32B, IRGKangXi=1513.231, RSKangXi=199.6
2A32C CJK UNIFIED IDEOGRAPH-#2A32C, IRGKangXi=1513.231, RSKangXi=199.6
2A32D CJK UNIFIED IDEOGRAPH-#2A32D, IRGKangXi=1513.240, RSKangXi=199.7
2A32E CJK UNIFIED IDEOGRAPH-#2A32E, IRGKangXi=1513.260, RSKangXi=199.7
2A32F CJK UNIFIED IDEOGRAPH-#2A32F, IRGKangXi=1513.270, RSKangXi=199.7
2A330 CJK UNIFIED IDEOGRAPH-#2A330, IRGKangXi=1513.280, RSKangXi=199.7
2A331 CJK UNIFIED IDEOGRAPH-#2A331, IRGKangXi=1513.310, RSKangXi=199.7
2A332 CJK UNIFIED IDEOGRAPH-#2A332, IRGKangXi=1513.320, RSKangXi=199.7
2A333 CJK UNIFIED IDEOGRAPH-#2A333, IRGKangXi=1513.350, RSKangXi=199.7
2A334 CJK UNIFIED IDEOGRAPH-#2A334, IRGKangXi=1513.351, RSKangXi=199.7
2A335 CJK UNIFIED IDEOGRAPH-#2A335, IRGKangXi=1513.351, RSKangXi=199.7
2A336 CJK UNIFIED IDEOGRAPH-#2A336, IRGKangXi=1513.351, RSKangXi=199.7
2A337 CJK UNIFIED IDEOGRAPH-#2A337, IRGKangXi=1513.351, RSKangXi=199.7
2A338 CJK UNIFIED IDEOGRAPH-#2A338, IRGKangXi=1513.351, RSKangXi=199.7
2A339 CJK UNIFIED IDEOGRAPH-#2A339, IRGKangXi=1513.351, RSKangXi=199.7
2A33A CJK UNIFIED IDEOGRAPH-#2A33A, IRGKangXi=1513.351, RSKangXi=199.7
2A33B CJK UNIFIED IDEOGRAPH-#2A33B, IRGKangXi=1513.351, RSKangXi=199.7
2A33C CJK UNIFIED IDEOGRAPH-#2A33C, IRGKangXi=1513.370, RSKangXi=199.8
2A33D CJK UNIFIED IDEOGRAPH-#2A33D, IRGKangXi=1513.380, RSKangXi=199.8
2A33E CJK UNIFIED IDEOGRAPH-#2A33E, IRGKangXi=1513.390, RSKangXi=199.8
2A33F CJK UNIFIED IDEOGRAPH-#2A33F, IRGKangXi=1513.400, RSKangXi=199.8
2A340 CJK UNIFIED IDEOGRAPH-#2A340, IRGKangXi=1513.410, RSKangXi=199.8
2A341 CJK UNIFIED IDEOGRAPH-#2A341, IRGKangXi=1513.420, RSKangXi=199.8
2A342 CJK UNIFIED IDEOGRAPH-#2A342, IRGKangXi=1513.440, RSKangXi=199.8
2A343 CJK UNIFIED IDEOGRAPH-#2A343, IRGKangXi=1513.470, RSKangXi=199.8
2A344 CJK UNIFIED IDEOGRAPH-#2A344, IRGKangXi=1513.480, RSKangXi=199.8
2A345 CJK UNIFIED IDEOGRAPH-#2A345, IRGKangXi=1513.490, RSKangXi=199.8
2A346 CJK UNIFIED IDEOGRAPH-#2A346, IRGKangXi=1514.010, RSKangXi=199.8
2A347 CJK UNIFIED IDEOGRAPH-#2A347, IRGKangXi=1514.020, RSKangXi=199.8
2A348 CJK UNIFIED IDEOGRAPH-#2A348, IRGKangXi=1514.021, RSKangXi=199.8
2A349 CJK UNIFIED IDEOGRAPH-#2A349, IRGKangXi=1514.021, RSKangXi=199.8
2A34A CJK UNIFIED IDEOGRAPH-#2A34A, IRGKangXi=1514.021, RSKangXi=199.8
2A34B CJK UNIFIED IDEOGRAPH-#2A34B, IRGKangXi=1514.021, RSKangXi=199.8
2A34C CJK UNIFIED IDEOGRAPH-#2A34C, IRGKangXi=1514.030, RSKangXi=199.9
2A34D CJK UNIFIED IDEOGRAPH-#2A34D, IRGKangXi=1514.040, RSKangXi=199.9
2A34E CJK UNIFIED IDEOGRAPH-#2A34E, IRGKangXi=1514.050, RSKangXi=199.9
2A34F CJK UNIFIED IDEOGRAPH-#2A34F, IRGKangXi=1514.060, RSKangXi=199.9
2A350 CJK UNIFIED IDEOGRAPH-#2A350, IRGKangXi=1514.080, RSKangXi=199.9
2A351 CJK UNIFIED IDEOGRAPH-#2A351, IRGKangXi=1514.090, RSKangXi=199.9
2A352 CJK UNIFIED IDEOGRAPH-#2A352, IRGKangXi=1514.100, RSKangXi=199.9
2A353 CJK UNIFIED IDEOGRAPH-#2A353, IRGKangXi=1514.110, RSKangXi=199.9
2A354 CJK UNIFIED IDEOGRAPH-#2A354, IRGKangXi=1514.120, RSKangXi=199.9
2A355 CJK UNIFIED IDEOGRAPH-#2A355, IRGKangXi=1514.121, RSKangXi=199.9
2A356 CJK UNIFIED IDEOGRAPH-#2A356, IRGKangXi=1514.121, RSKangXi=199.9
2A357 CJK UNIFIED IDEOGRAPH-#2A357, IRGKangXi=1514.121, RSKangXi=199.9
2A358 CJK UNIFIED IDEOGRAPH-#2A358, IRGKangXi=1514.121, RSKangXi=199.9
2A359 CJK UNIFIED IDEOGRAPH-#2A359, IRGKangXi=1514.121, RSKangXi=199.9
2A35A CJK UNIFIED IDEOGRAPH-#2A35A, IRGKangXi=1514.121, RSKangXi=199.9
2A35B CJK UNIFIED IDEOGRAPH-#2A35B, IRGKangXi=1514.130, RSKangXi=199.10
2A35C CJK UNIFIED IDEOGRAPH-#2A35C, IRGKangXi=1514.150, RSKangXi=199.10
2A35D CJK UNIFIED IDEOGRAPH-#2A35D, IRGKangXi=1514.170, RSKangXi=199.10
2A35E CJK UNIFIED IDEOGRAPH-#2A35E, IRGKangXi=1514.180, RSKangXi=199.10
2A35F CJK UNIFIED IDEOGRAPH-#2A35F, IRGKangXi=1514.190, RSKangXi=199.10
2A360 CJK UNIFIED IDEOGRAPH-#2A360, IRGKangXi=1514.210, RSKangXi=199.10
2A361 CJK UNIFIED IDEOGRAPH-#2A361, IRGKangXi=1514.220, RSKangXi=199.10
2A362 CJK UNIFIED IDEOGRAPH-#2A362, IRGKangXi=1514.221, RSKangXi=199.10
2A363 CJK UNIFIED IDEOGRAPH-#2A363, IRGKangXi=1514.230, RSKangXi=199.11
2A364 CJK UNIFIED IDEOGRAPH-#2A364, IRGKangXi=1514.240, RSKangXi=199.11
2A365 CJK UNIFIED IDEOGRAPH-#2A365, IRGKangXi=1514.250, RSKangXi=199.11
2A366 CJK UNIFIED IDEOGRAPH-#2A366, IRGKangXi=1514.260, RSKangXi=199.11
2A367 CJK UNIFIED IDEOGRAPH-#2A367, IRGKangXi=1514.270, RSKangXi=199.11
2A368 CJK UNIFIED IDEOGRAPH-#2A368, IRGKangXi=1514.280, RSKangXi=199.11
2A369 CJK UNIFIED IDEOGRAPH-#2A369, IRGKangXi=1514.300, RSKangXi=199.11
2A36A CJK UNIFIED IDEOGRAPH-#2A36A, IRGKangXi=1514.330, RSKangXi=199.11
2A36B CJK UNIFIED IDEOGRAPH-#2A36B, IRGKangXi=1514.340, RSKangXi=199.11
2A36C CJK UNIFIED IDEOGRAPH-#2A36C, IRGKangXi=1514.350, RSKangXi=199.11
2A36D CJK UNIFIED IDEOGRAPH-#2A36D, IRGKangXi=1514.360, RSKangXi=199.11
2A36E CJK UNIFIED IDEOGRAPH-#2A36E, IRGKangXi=1514.361, RSKangXi=199.11
2A36F CJK UNIFIED IDEOGRAPH-#2A36F, IRGKangXi=1514.361, RSKangXi=199.11
2A370 CJK UNIFIED IDEOGRAPH-#2A370, IRGKangXi=1514.361, RSKangXi=199.11
2A371 CJK UNIFIED IDEOGRAPH-#2A371, IRGKangXi=1514.361, RSKangXi=199.11
2A372 CJK UNIFIED IDEOGRAPH-#2A372, IRGKangXi=1514.370, RSKangXi=199.12
2A373 CJK UNIFIED IDEOGRAPH-#2A373, IRGKangXi=1514.380, RSKangXi=199.12
2A374 CJK UNIFIED IDEOGRAPH-#2A374, IRGKangXi=1514.390, RSKangXi=199.12
2A375 CJK UNIFIED IDEOGRAPH-#2A375, IRGKangXi=1514.400, RSKangXi=199.12
2A376 CJK UNIFIED IDEOGRAPH-#2A376, IRGKangXi=1514.410, RSKangXi=199.12
2A377 CJK UNIFIED IDEOGRAPH-#2A377, IRGKangXi=1514.421, RSKangXi=199.12
2A378 CJK UNIFIED IDEOGRAPH-#2A378, IRGKangXi=1514.440, RSKangXi=199.13, Def{young wheat}
2A379 CJK UNIFIED IDEOGRAPH-#2A379, IRGKangXi=1514.450, RSKangXi=199.13
2A37A CJK UNIFIED IDEOGRAPH-#2A37A, IRGKangXi=1514.460, RSKangXi=199.13
2A37B CJK UNIFIED IDEOGRAPH-#2A37B, IRGKangXi=1514.470, RSKangXi=199.13
2A37C CJK UNIFIED IDEOGRAPH-#2A37C, IRGKangXi=1514.480, RSKangXi=199.13
2A37D CJK UNIFIED IDEOGRAPH-#2A37D, IRGKangXi=1514.481, RSKangXi=199.13
2A37E CJK UNIFIED IDEOGRAPH-#2A37E, IRGKangXi=1514.481, RSKangXi=199.13
2A37F CJK UNIFIED IDEOGRAPH-#2A37F, IRGKangXi=1514.500, RSKangXi=199.15
2A380 CJK UNIFIED IDEOGRAPH-#2A380, IRGKangXi=1514.501, RSKangXi=199.15
2A381 CJK UNIFIED IDEOGRAPH-#2A381, IRGKangXi=1514.510, RSKangXi=199.16
2A382 CJK UNIFIED IDEOGRAPH-#2A382, IRGKangXi=1514.520, RSKangXi=199.16
2A383 CJK UNIFIED IDEOGRAPH-#2A383, IRGKangXi=1514.530, RSKangXi=199.17
2A384 CJK UNIFIED IDEOGRAPH-#2A384, IRGKangXi=1514.540, RSKangXi=199.17
2A385 CJK UNIFIED IDEOGRAPH-#2A385, IRGKangXi=1514.551, RSKangXi=199.17
2A386 CJK UNIFIED IDEOGRAPH-#2A386, IRGKangXi=1514.560, RSKangXi=199.19
2A387 CJK UNIFIED IDEOGRAPH-#2A387, IRGKangXi=1514.570, RSKangXi=199.20
2A388 CJK UNIFIED IDEOGRAPH-#2A388, IRGKangXi=1514.571, RSKangXi=199.3
2A389 CJK UNIFIED IDEOGRAPH-#2A389, IRGKangXi=1514.571, RSKangXi=199.4
2A38A CJK UNIFIED IDEOGRAPH-#2A38A, IRGKangXi=1514.571, RSKangXi=199.4
2A38B CJK UNIFIED IDEOGRAPH-#2A38B, IRGKangXi=1514.571, RSKangXi=199.5
2A38C CJK UNIFIED IDEOGRAPH-#2A38C, IRGKangXi=1514.571, RSKangXi=199.7
2A38D CJK UNIFIED IDEOGRAPH-#2A38D, IRGKangXi=1514.571, RSKangXi=199.2
2A38E CJK UNIFIED IDEOGRAPH-#2A38E, IRGKangXi=1514.571, RSKangXi=199.8
2A38F CJK UNIFIED IDEOGRAPH-#2A38F, IRGKangXi=1514.571, RSKangXi=199.8
2A390 CJK UNIFIED IDEOGRAPH-#2A390, IRGKangXi=1514.571, RSKangXi=199.11
2A391 CJK UNIFIED IDEOGRAPH-#2A391, IRGKangXi=1515.021, RSKangXi=200.2
2A392 CJK UNIFIED IDEOGRAPH-#2A392, IRGKangXi=1515.030, RSKangXi=200.3
2A393 CJK UNIFIED IDEOGRAPH-#2A393, IRGKangXi=1515.040, RSKangXi=200.3
2A394 CJK UNIFIED IDEOGRAPH-#2A394, IRGKangXi=1515.070, RSKangXi=200.3
2A395 CJK UNIFIED IDEOGRAPH-#2A395, IRGKangXi=1515.080, RSKangXi=200.4
2A396 CJK UNIFIED IDEOGRAPH-#2A396, IRGKangXi=1515.100, RSKangXi=200.4
2A397 CJK UNIFIED IDEOGRAPH-#2A397, IRGKangXi=1515.110, RSKangXi=200.4
2A398 CJK UNIFIED IDEOGRAPH-#2A398, IRGKangXi=1515.120, RSKangXi=200.4
2A399 CJK UNIFIED IDEOGRAPH-#2A399, IRGKangXi=1515.131, RSKangXi=200.4
2A39A CJK UNIFIED IDEOGRAPH-#2A39A, IRGKangXi=1515.131, RSKangXi=200.4
2A39B CJK UNIFIED IDEOGRAPH-#2A39B, IRGKangXi=1515.140, RSKangXi=200.5
2A39C CJK UNIFIED IDEOGRAPH-#2A39C, IRGKangXi=1515.150, RSKangXi=200.5
2A39D CJK UNIFIED IDEOGRAPH-#2A39D, IRGKangXi=1515.160, RSKangXi=200.5
2A39E CJK UNIFIED IDEOGRAPH-#2A39E, IRGKangXi=1515.170, RSKangXi=200.5
2A39F CJK UNIFIED IDEOGRAPH-#2A39F, IRGKangXi=1515.171, RSKangXi=200.5
2A3A0 CJK UNIFIED IDEOGRAPH-#2A3A0, IRGKangXi=1515.180, RSKangXi=200.6
2A3A1 CJK UNIFIED IDEOGRAPH-#2A3A1, IRGKangXi=1515.190, RSKangXi=200.6
2A3A2 CJK UNIFIED IDEOGRAPH-#2A3A2, IRGKangXi=1515.191, RSKangXi=200.6
2A3A3 CJK UNIFIED IDEOGRAPH-#2A3A3, IRGKangXi=1515.200, RSKangXi=200.7
2A3A4 CJK UNIFIED IDEOGRAPH-#2A3A4, IRGKangXi=1515.210, RSKangXi=200.7
2A3A5 CJK UNIFIED IDEOGRAPH-#2A3A5, IRGKangXi=1515.220, RSKangXi=200.8
2A3A6 CJK UNIFIED IDEOGRAPH-#2A3A6, IRGKangXi=1515.250, RSKangXi=200.8
2A3A7 CJK UNIFIED IDEOGRAPH-#2A3A7, IRGKangXi=1515.251, RSKangXi=200.8
2A3A8 CJK UNIFIED IDEOGRAPH-#2A3A8, IRGKangXi=1515.270, RSKangXi=200.9
2A3A9 CJK UNIFIED IDEOGRAPH-#2A3A9, IRGKangXi=1515.281, RSKangXi=200.9
2A3AA CJK UNIFIED IDEOGRAPH-#2A3AA, IRGKangXi=1515.290, RSKangXi=200.10
2A3AB CJK UNIFIED IDEOGRAPH-#2A3AB, IRGKangXi=1515.300, RSKangXi=200.10
2A3AC CJK UNIFIED IDEOGRAPH-#2A3AC, IRGKangXi=1515.310, RSKangXi=200.11
2A3AD CJK UNIFIED IDEOGRAPH-#2A3AD, IRGKangXi=1515.320, RSKangXi=200.12
2A3AE CJK UNIFIED IDEOGRAPH-#2A3AE, IRGKangXi=1515.330, RSKangXi=200.12
2A3AF CJK UNIFIED IDEOGRAPH-#2A3AF, IRGKangXi=1515.340, RSKangXi=200.12
2A3B0 CJK UNIFIED IDEOGRAPH-#2A3B0, IRGKangXi=1516.010, RSKangXi=200.13
2A3B1 CJK UNIFIED IDEOGRAPH-#2A3B1, IRGKangXi=1516.011, RSKangXi=200.14
2A3B2 CJK UNIFIED IDEOGRAPH-#2A3B2, IRGKangXi=1516.020, RSKangXi=200.20
2A3B3 CJK UNIFIED IDEOGRAPH-#2A3B3, IRGKangXi=1516.041, RSKangXi=201.2
2A3B4 CJK UNIFIED IDEOGRAPH-#2A3B4, IRGKangXi=1516.041, RSKangXi=201.3
2A3B5 CJK UNIFIED IDEOGRAPH-#2A3B5, IRGKangXi=1516.070, RSKangXi=201.4
2A3B6 CJK UNIFIED IDEOGRAPH-#2A3B6, IRGKangXi=1516.090, RSKangXi=201.4
2A3B7 CJK UNIFIED IDEOGRAPH-#2A3B7, IRGKangXi=1516.091, RSKangXi=201.4
2A3B8 CJK UNIFIED IDEOGRAPH-#2A3B8, IRGKangXi=1516.091, RSKangXi=201.4
2A3B9 CJK UNIFIED IDEOGRAPH-#2A3B9, IRGKangXi=1516.091, RSKangXi=201.4
2A3BA CJK UNIFIED IDEOGRAPH-#2A3BA, IRGKangXi=1516.110, RSKangXi=201.5
2A3BB CJK UNIFIED IDEOGRAPH-#2A3BB, IRGKangXi=1516.140, RSKangXi=201.6
2A3BC CJK UNIFIED IDEOGRAPH-#2A3BC, IRGKangXi=1516.150, RSKangXi=201.6
2A3BD CJK UNIFIED IDEOGRAPH-#2A3BD, IRGKangXi=1516.170, RSKangXi=201.6
2A3BE CJK UNIFIED IDEOGRAPH-#2A3BE, IRGKangXi=1516.180, RSKangXi=201.6
2A3BF CJK UNIFIED IDEOGRAPH-#2A3BF, IRGKangXi=1516.191, RSKangXi=201.6
2A3C0 CJK UNIFIED IDEOGRAPH-#2A3C0, IRGKangXi=1516.191, RSKangXi=201.6
2A3C1 CJK UNIFIED IDEOGRAPH-#2A3C1, IRGKangXi=1516.191, RSKangXi=201.6
2A3C2 CJK UNIFIED IDEOGRAPH-#2A3C2, IRGKangXi=1516.210, RSKangXi=201.7
2A3C3 CJK UNIFIED IDEOGRAPH-#2A3C3, IRGKangXi=1516.211, RSKangXi=201.7
2A3C4 CJK UNIFIED IDEOGRAPH-#2A3C4, IRGKangXi=1516.211, RSKangXi=201.7
2A3C5 CJK UNIFIED IDEOGRAPH-#2A3C5, IRGKangXi=1516.211, RSKangXi=201.7
2A3C6 CJK UNIFIED IDEOGRAPH-#2A3C6, IRGKangXi=1516.220, RSKangXi=201.8
2A3C7 CJK UNIFIED IDEOGRAPH-#2A3C7, IRGKangXi=1517.010, RSKangXi=201.8
2A3C8 CJK UNIFIED IDEOGRAPH-#2A3C8, IRGKangXi=1517.020, RSKangXi=201.8
2A3C9 CJK UNIFIED IDEOGRAPH-#2A3C9, IRGKangXi=1517.030, RSKangXi=201.8
2A3CA CJK UNIFIED IDEOGRAPH-#2A3CA, IRGKangXi=1517.040, RSKangXi=201.8
2A3CB CJK UNIFIED IDEOGRAPH-#2A3CB, IRGKangXi=1517.050, RSKangXi=201.8
2A3CC CJK UNIFIED IDEOGRAPH-#2A3CC, IRGKangXi=1517.060, RSKangXi=201.8
2A3CD CJK UNIFIED IDEOGRAPH-#2A3CD, IRGKangXi=1517.080, RSKangXi=201.8
2A3CE CJK UNIFIED IDEOGRAPH-#2A3CE, IRGKangXi=1517.081, RSKangXi=201.8
2A3CF CJK UNIFIED IDEOGRAPH-#2A3CF, IRGKangXi=1517.081, RSKangXi=201.8
2A3D0 CJK UNIFIED IDEOGRAPH-#2A3D0, IRGKangXi=1517.081, RSKangXi=201.8
2A3D1 CJK UNIFIED IDEOGRAPH-#2A3D1, IRGKangXi=1517.081, RSKangXi=201.8
2A3D2 CJK UNIFIED IDEOGRAPH-#2A3D2, IRGKangXi=1517.081, RSKangXi=201.8
2A3D3 CJK UNIFIED IDEOGRAPH-#2A3D3, IRGKangXi=1517.100, RSKangXi=201.9
2A3D4 CJK UNIFIED IDEOGRAPH-#2A3D4, IRGKangXi=1517.110, RSKangXi=201.9
2A3D5 CJK UNIFIED IDEOGRAPH-#2A3D5, IRGKangXi=1517.120, RSKangXi=201.9
2A3D6 CJK UNIFIED IDEOGRAPH-#2A3D6, IRGKangXi=1517.130, RSKangXi=201.9
2A3D7 CJK UNIFIED IDEOGRAPH-#2A3D7, IRGKangXi=1517.131, RSKangXi=201.9
2A3D8 CJK UNIFIED IDEOGRAPH-#2A3D8, IRGKangXi=1517.131, RSKangXi=201.9
2A3D9 CJK UNIFIED IDEOGRAPH-#2A3D9, IRGKangXi=1517.140, RSKangXi=201.10, Def{a yolk}
2A3DA CJK UNIFIED IDEOGRAPH-#2A3DA, IRGKangXi=1517.150, RSKangXi=201.10
2A3DB CJK UNIFIED IDEOGRAPH-#2A3DB, IRGKangXi=1517.160, RSKangXi=201.10
2A3DC CJK UNIFIED IDEOGRAPH-#2A3DC, IRGKangXi=1517.170, RSKangXi=201.10
2A3DD CJK UNIFIED IDEOGRAPH-#2A3DD, IRGKangXi=1517.171, RSKangXi=201.10
2A3DE CJK UNIFIED IDEOGRAPH-#2A3DE, IRGKangXi=1517.171, RSKangXi=201.10
2A3DF CJK UNIFIED IDEOGRAPH-#2A3DF, IRGKangXi=1517.181, RSKangXi=201.11
2A3E0 CJK UNIFIED IDEOGRAPH-#2A3E0, IRGKangXi=1517.181, RSKangXi=201.11
2A3E1 CJK UNIFIED IDEOGRAPH-#2A3E1, IRGKangXi=1517.181, RSKangXi=201.11
2A3E2 CJK UNIFIED IDEOGRAPH-#2A3E2, IRGKangXi=1517.181, RSKangXi=201.11
2A3E3 CJK UNIFIED IDEOGRAPH-#2A3E3, IRGKangXi=1517.181, RSKangXi=201.11
2A3E4 CJK UNIFIED IDEOGRAPH-#2A3E4, IRGKangXi=1517.200, RSKangXi=201.12
2A3E5 CJK UNIFIED IDEOGRAPH-#2A3E5, IRGKangXi=1517.210, RSKangXi=201.12
2A3E6 CJK UNIFIED IDEOGRAPH-#2A3E6, IRGKangXi=1517.211, RSKangXi=201.12
2A3E7 CJK UNIFIED IDEOGRAPH-#2A3E7, IRGKangXi=1517.230, RSKangXi=201.13
2A3E8 CJK UNIFIED IDEOGRAPH-#2A3E8, IRGKangXi=1517.240, RSKangXi=201.13
2A3E9 CJK UNIFIED IDEOGRAPH-#2A3E9, IRGKangXi=1517.241, RSKangXi=201.13
2A3EA CJK UNIFIED IDEOGRAPH-#2A3EA, IRGKangXi=1517.241, RSKangXi=201.15
2A3EB CJK UNIFIED IDEOGRAPH-#2A3EB, IRGKangXi=1517.241, RSKangXi=201.16
2A3EC CJK UNIFIED IDEOGRAPH-#2A3EC, IRGKangXi=1517.241, RSKangXi=201.20
2A3ED CJK UNIFIED IDEOGRAPH-#2A3ED, IRGKangXi=1517.251, RSKangXi=202.2
2A3EE CJK UNIFIED IDEOGRAPH-#2A3EE, IRGKangXi=1517.260, RSKangXi=202.3
2A3EF CJK UNIFIED IDEOGRAPH-#2A3EF, IRGKangXi=1517.290, RSKangXi=202.3
2A3F0 CJK UNIFIED IDEOGRAPH-#2A3F0, IRGKangXi=1517.300, RSKangXi=202.4
2A3F1 CJK UNIFIED IDEOGRAPH-#2A3F1, IRGKangXi=1517.310, RSKangXi=202.4
2A3F2 CJK UNIFIED IDEOGRAPH-#2A3F2, IRGKangXi=1517.330, RSKangXi=202.4
2A3F3 CJK UNIFIED IDEOGRAPH-#2A3F3, IRGKangXi=1517.340, RSKangXi=202.4
2A3F4 CJK UNIFIED IDEOGRAPH-#2A3F4, IRGKangXi=1517.350, RSKangXi=202.4
2A3F5 CJK UNIFIED IDEOGRAPH-#2A3F5, IRGKangXi=1517.361, RSKangXi=202.4
2A3F6 CJK UNIFIED IDEOGRAPH-#2A3F6, IRGKangXi=1518.010, RSKangXi=202.5
2A3F7 CJK UNIFIED IDEOGRAPH-#2A3F7, IRGKangXi=1518.020, RSKangXi=202.5
2A3F8 CJK UNIFIED IDEOGRAPH-#2A3F8, IRGKangXi=1518.030, RSKangXi=202.5
2A3F9 CJK UNIFIED IDEOGRAPH-#2A3F9, IRGKangXi=1518.040, RSKangXi=202.5
2A3FA CJK UNIFIED IDEOGRAPH-#2A3FA, IRGKangXi=1518.060, RSKangXi=202.5
2A3FB CJK UNIFIED IDEOGRAPH-#2A3FB, IRGKangXi=1518.070, RSKangXi=202.5
2A3FC CJK UNIFIED IDEOGRAPH-#2A3FC, IRGKangXi=1518.080, RSKangXi=202.5
2A3FD CJK UNIFIED IDEOGRAPH-#2A3FD, IRGKangXi=1518.081, RSKangXi=202.5
2A3FE CJK UNIFIED IDEOGRAPH-#2A3FE, IRGKangXi=1518.081, RSKangXi=202.5
2A3FF CJK UNIFIED IDEOGRAPH-#2A3FF, IRGKangXi=1518.090, RSKangXi=202.6
2A400 CJK UNIFIED IDEOGRAPH-#2A400, IRGKangXi=1518.100, RSKangXi=202.6, Def{(Cant.) relationship; together}
2A401 CJK UNIFIED IDEOGRAPH-#2A401, IRGKangXi=1518.101, RSKangXi=202.7
2A402 CJK UNIFIED IDEOGRAPH-#2A402, IRGKangXi=1518.120, RSKangXi=202.8
2A403 CJK UNIFIED IDEOGRAPH-#2A403, IRGKangXi=1518.130, RSKangXi=202.8
2A404 CJK UNIFIED IDEOGRAPH-#2A404, IRGKangXi=1518.160, RSKangXi=202.8
2A405 CJK UNIFIED IDEOGRAPH-#2A405, IRGKangXi=1518.161, RSKangXi=202.8
2A406 CJK UNIFIED IDEOGRAPH-#2A406, IRGKangXi=1518.161, RSKangXi=202.8
2A407 CJK UNIFIED IDEOGRAPH-#2A407, IRGKangXi=1518.170, RSKangXi=202.9
2A408 CJK UNIFIED IDEOGRAPH-#2A408, IRGKangXi=1518.190, RSKangXi=202.9
2A409 CJK UNIFIED IDEOGRAPH-#2A409, IRGKangXi=1518.220, RSKangXi=202.9
2A40A CJK UNIFIED IDEOGRAPH-#2A40A, IRGKangXi=1518.221, RSKangXi=202.9
2A40B CJK UNIFIED IDEOGRAPH-#2A40B, IRGKangXi=1518.230, RSKangXi=202.10
2A40C CJK UNIFIED IDEOGRAPH-#2A40C, IRGKangXi=1518.250, RSKangXi=202.11
2A40D CJK UNIFIED IDEOGRAPH-#2A40D, IRGKangXi=1518.270, RSKangXi=202.11
2A40E CJK UNIFIED IDEOGRAPH-#2A40E, IRGKangXi=1518.280, RSKangXi=202.11
2A40F CJK UNIFIED IDEOGRAPH-#2A40F, IRGKangXi=1518.290, RSKangXi=202.11
2A410 CJK UNIFIED IDEOGRAPH-#2A410, IRGKangXi=1518.301, RSKangXi=202.12
2A411 CJK UNIFIED IDEOGRAPH-#2A411, IRGKangXi=1518.320, RSKangXi=202.14
2A412 CJK UNIFIED IDEOGRAPH-#2A412, IRGKangXi=1518.321, RSKangXi=202.13
2A413 CJK UNIFIED IDEOGRAPH-#2A413, IRGKangXi=1518.330, RSKangXi=202.14
2A414 CJK UNIFIED IDEOGRAPH-#2A414, IRGKangXi=1518.340, RSKangXi=202.16
2A415 CJK UNIFIED IDEOGRAPH-#2A415, IRGKangXi=1518.341, RSKangXi=202.16
2A416 CJK UNIFIED IDEOGRAPH-#2A416, IRGKangXi=1518.350, RSKangXi=202.16
2A417 CJK UNIFIED IDEOGRAPH-#2A417, IRGKangXi=1518.370, RSKangXi=203.0
2A418 CJK UNIFIED IDEOGRAPH-#2A418, IRGKangXi=1518.381, RSKangXi=203.1
2A419 CJK UNIFIED IDEOGRAPH-#2A419, IRGKangXi=1518.390, RSKangXi=203.2
2A41A CJK UNIFIED IDEOGRAPH-#2A41A, IRGKangXi=1518.410, RSKangXi=203.2
2A41B CJK UNIFIED IDEOGRAPH-#2A41B, IRGKangXi=1518.411, RSKangXi=203.2
2A41C CJK UNIFIED IDEOGRAPH-#2A41C, IRGKangXi=1518.420, RSKangXi=203.3
2A41D CJK UNIFIED IDEOGRAPH-#2A41D, IRGKangXi=1518.440, RSKangXi=203.3
2A41E CJK UNIFIED IDEOGRAPH-#2A41E, IRGKangXi=1518.450, RSKangXi=203.3
2A41F CJK UNIFIED IDEOGRAPH-#2A41F, IRGKangXi=1519.020, RSKangXi=203.3
2A420 CJK UNIFIED IDEOGRAPH-#2A420, IRGKangXi=1519.030, RSKangXi=203.3
2A421 CJK UNIFIED IDEOGRAPH-#2A421, IRGKangXi=1519.031, RSKangXi=203.3
2A422 CJK UNIFIED IDEOGRAPH-#2A422, IRGKangXi=1519.031, RSKangXi=203.3
2A423 CJK UNIFIED IDEOGRAPH-#2A423, IRGKangXi=1519.031, RSKangXi=203.3
2A424 CJK UNIFIED IDEOGRAPH-#2A424, IRGKangXi=1519.080, RSKangXi=203.4
2A425 CJK UNIFIED IDEOGRAPH-#2A425, IRGKangXi=1519.120, RSKangXi=203.4
2A426 CJK UNIFIED IDEOGRAPH-#2A426, IRGKangXi=1519.130, RSKangXi=203.4
2A427 CJK UNIFIED IDEOGRAPH-#2A427, IRGKangXi=1519.140, RSKangXi=203.4
2A428 CJK UNIFIED IDEOGRAPH-#2A428, IRGKangXi=1519.150, RSKangXi=203.4
2A429 CJK UNIFIED IDEOGRAPH-#2A429, IRGKangXi=1519.160, RSKangXi=203.4
2A42A CJK UNIFIED IDEOGRAPH-#2A42A, IRGKangXi=1519.170, RSKangXi=203.4
2A42B CJK UNIFIED IDEOGRAPH-#2A42B, IRGKangXi=1519.180, RSKangXi=203.4
2A42C CJK UNIFIED IDEOGRAPH-#2A42C, IRGKangXi=1519.181, RSKangXi=203.4
2A42D CJK UNIFIED IDEOGRAPH-#2A42D, IRGKangXi=1519.181, RSKangXi=203.4
2A42E CJK UNIFIED IDEOGRAPH-#2A42E, IRGKangXi=1519.181, RSKangXi=203.4
2A42F CJK UNIFIED IDEOGRAPH-#2A42F, IRGKangXi=1519.181, RSKangXi=203.4
2A430 CJK UNIFIED IDEOGRAPH-#2A430, IRGKangXi=1519.181, RSKangXi=203.4
2A431 CJK UNIFIED IDEOGRAPH-#2A431, IRGKangXi=1519.181, RSKangXi=203.4
2A432 CJK UNIFIED IDEOGRAPH-#2A432, IRGKangXi=1519.240, RSKangXi=203.5
2A433 CJK UNIFIED IDEOGRAPH-#2A433, IRGKangXi=1519.250, RSKangXi=203.5
2A434 CJK UNIFIED IDEOGRAPH-#2A434, IRGKangXi=1519.260, RSKangXi=203.5
2A435 CJK UNIFIED IDEOGRAPH-#2A435, IRGKangXi=1519.281, RSKangXi=203.5
2A436 CJK UNIFIED IDEOGRAPH-#2A436, IRGKangXi=1519.281, RSKangXi=203.5
2A437 CJK UNIFIED IDEOGRAPH-#2A437, IRGKangXi=1519.281, RSKangXi=203.5
2A438 CJK UNIFIED IDEOGRAPH-#2A438, IRGKangXi=1519.281, RSKangXi=203.5
2A439 CJK UNIFIED IDEOGRAPH-#2A439, IRGKangXi=1519.281, RSKangXi=203.5
2A43A CJK UNIFIED IDEOGRAPH-#2A43A, IRGKangXi=1519.281, RSKangXi=203.5
2A43B CJK UNIFIED IDEOGRAPH-#2A43B, IRGKangXi=1519.281, RSKangXi=203.5
2A43C CJK UNIFIED IDEOGRAPH-#2A43C, IRGKangXi=1519.281, RSKangXi=203.5
2A43D CJK UNIFIED IDEOGRAPH-#2A43D, IRGKangXi=1519.281, RSKangXi=203.5
2A43E CJK UNIFIED IDEOGRAPH-#2A43E, IRGKangXi=1519.281, RSKangXi=203.5
2A43F CJK UNIFIED IDEOGRAPH-#2A43F, IRGKangXi=1519.300, RSKangXi=203.6
2A440 CJK UNIFIED IDEOGRAPH-#2A440, IRGKangXi=1519.310, RSKangXi=203.6
2A441 CJK UNIFIED IDEOGRAPH-#2A441, IRGKangXi=1519.330, RSKangXi=203.6
2A442 CJK UNIFIED IDEOGRAPH-#2A442, IRGKangXi=1520.010, RSKangXi=203.6
2A443 CJK UNIFIED IDEOGRAPH-#2A443, IRGKangXi=1520.030, RSKangXi=203.6
2A444 CJK UNIFIED IDEOGRAPH-#2A444, IRGKangXi=1520.060, RSKangXi=203.6
2A445 CJK UNIFIED IDEOGRAPH-#2A445, IRGKangXi=1520.061, RSKangXi=203.6
2A446 CJK UNIFIED IDEOGRAPH-#2A446, IRGKangXi=1520.061, RSKangXi=203.6
2A447 CJK UNIFIED IDEOGRAPH-#2A447, IRGKangXi=1520.061, RSKangXi=203.6
2A448 CJK UNIFIED IDEOGRAPH-#2A448, IRGKangXi=1520.080, RSKangXi=203.7
2A449 CJK UNIFIED IDEOGRAPH-#2A449, IRGKangXi=1520.100, RSKangXi=203.7
2A44A CJK UNIFIED IDEOGRAPH-#2A44A, IRGKangXi=1520.110, RSKangXi=203.7
2A44B CJK UNIFIED IDEOGRAPH-#2A44B, IRGKangXi=1520.120, RSKangXi=203.7
2A44C CJK UNIFIED IDEOGRAPH-#2A44C, IRGKangXi=1520.130, RSKangXi=203.7
2A44D CJK UNIFIED IDEOGRAPH-#2A44D, IRGKangXi=1520.160, RSKangXi=203.7
2A44E CJK UNIFIED IDEOGRAPH-#2A44E, IRGKangXi=1520.170, RSKangXi=203.7
2A44F CJK UNIFIED IDEOGRAPH-#2A44F, IRGKangXi=1520.171, RSKangXi=203.7
2A450 CJK UNIFIED IDEOGRAPH-#2A450, IRGKangXi=1520.171, RSKangXi=203.7
2A451 CJK UNIFIED IDEOGRAPH-#2A451, IRGKangXi=1520.171, RSKangXi=203.7
2A452 CJK UNIFIED IDEOGRAPH-#2A452, IRGKangXi=1520.180, RSKangXi=203.8
2A453 CJK UNIFIED IDEOGRAPH-#2A453, IRGKangXi=1520.210, RSKangXi=203.8
2A454 CJK UNIFIED IDEOGRAPH-#2A454, IRGKangXi=1520.220, RSKangXi=203.8
2A455 CJK UNIFIED IDEOGRAPH-#2A455, IRGKangXi=1520.230, RSKangXi=203.8
2A456 CJK UNIFIED IDEOGRAPH-#2A456, IRGKangXi=1520.240, RSKangXi=203.8
2A457 CJK UNIFIED IDEOGRAPH-#2A457, IRGKangXi=1520.250, RSKangXi=203.8
2A458 CJK UNIFIED IDEOGRAPH-#2A458, IRGKangXi=1520.280, RSKangXi=203.8
2A459 CJK UNIFIED IDEOGRAPH-#2A459, IRGKangXi=1520.290, RSKangXi=203.8
2A45A CJK UNIFIED IDEOGRAPH-#2A45A, IRGKangXi=1520.320, RSKangXi=203.8
2A45B CJK UNIFIED IDEOGRAPH-#2A45B, IRGKangXi=1520.330, RSKangXi=203.8
2A45C CJK UNIFIED IDEOGRAPH-#2A45C, IRGKangXi=1520.340, RSKangXi=203.8
2A45D CJK UNIFIED IDEOGRAPH-#2A45D, IRGKangXi=1520.380, RSKangXi=203.8
2A45E CJK UNIFIED IDEOGRAPH-#2A45E, IRGKangXi=1520.390, RSKangXi=203.8
2A45F CJK UNIFIED IDEOGRAPH-#2A45F, IRGKangXi=1521.010, RSKangXi=203.8
2A460 CJK UNIFIED IDEOGRAPH-#2A460, IRGKangXi=1521.011, RSKangXi=203.8
2A461 CJK UNIFIED IDEOGRAPH-#2A461, IRGKangXi=1521.011, RSKangXi=203.8
2A462 CJK UNIFIED IDEOGRAPH-#2A462, IRGKangXi=1521.011, RSKangXi=203.8
2A463 CJK UNIFIED IDEOGRAPH-#2A463, IRGKangXi=1521.011, RSKangXi=203.9
2A464 CJK UNIFIED IDEOGRAPH-#2A464, IRGKangXi=1521.011, RSKangXi=203.8
2A465 CJK UNIFIED IDEOGRAPH-#2A465, IRGKangXi=1521.030, RSKangXi=203.9
2A466 CJK UNIFIED IDEOGRAPH-#2A466, IRGKangXi=1521.040, RSKangXi=203.9
2A467 CJK UNIFIED IDEOGRAPH-#2A467, IRGKangXi=1521.050, RSKangXi=203.9
2A468 CJK UNIFIED IDEOGRAPH-#2A468, IRGKangXi=1521.060, RSKangXi=203.9
2A469 CJK UNIFIED IDEOGRAPH-#2A469, IRGKangXi=1521.080, RSKangXi=203.9
2A46A CJK UNIFIED IDEOGRAPH-#2A46A, IRGKangXi=1521.090, RSKangXi=203.9
2A46B CJK UNIFIED IDEOGRAPH-#2A46B, IRGKangXi=1521.100, RSKangXi=203.9
2A46C CJK UNIFIED IDEOGRAPH-#2A46C, IRGKangXi=1521.110, RSKangXi=203.9
2A46D CJK UNIFIED IDEOGRAPH-#2A46D, IRGKangXi=1521.130, RSKangXi=203.9
2A46E CJK UNIFIED IDEOGRAPH-#2A46E, IRGKangXi=1521.150, RSKangXi=203.9
2A46F CJK UNIFIED IDEOGRAPH-#2A46F, IRGKangXi=1521.160, RSKangXi=203.9
2A470 CJK UNIFIED IDEOGRAPH-#2A470, IRGKangXi=1521.200, RSKangXi=203.9
2A471 CJK UNIFIED IDEOGRAPH-#2A471, IRGKangXi=1521.210, RSKangXi=203.9
2A472 CJK UNIFIED IDEOGRAPH-#2A472, IRGKangXi=1521.220, RSKangXi=203.9
2A473 CJK UNIFIED IDEOGRAPH-#2A473, IRGKangXi=1521.240, RSKangXi=203.9
2A474 CJK UNIFIED IDEOGRAPH-#2A474, IRGKangXi=1521.250, RSKangXi=203.9
2A475 CJK UNIFIED IDEOGRAPH-#2A475, IRGKangXi=1521.260, RSKangXi=203.9
2A476 CJK UNIFIED IDEOGRAPH-#2A476, IRGKangXi=1521.270, RSKangXi=203.9
2A477 CJK UNIFIED IDEOGRAPH-#2A477, IRGKangXi=1521.280, RSKangXi=203.9
2A478 CJK UNIFIED IDEOGRAPH-#2A478, IRGKangXi=1521.281, RSKangXi=203.9
2A479 CJK UNIFIED IDEOGRAPH-#2A479, IRGKangXi=1521.281, RSKangXi=203.9
2A47A CJK UNIFIED IDEOGRAPH-#2A47A, IRGKangXi=1521.281, RSKangXi=203.9
2A47B CJK UNIFIED IDEOGRAPH-#2A47B, IRGKangXi=1521.281, RSKangXi=203.9
2A47C CJK UNIFIED IDEOGRAPH-#2A47C, IRGKangXi=1521.281, RSKangXi=203.9
2A47D CJK UNIFIED IDEOGRAPH-#2A47D, IRGKangXi=1521.281, RSKangXi=203.9
2A47E CJK UNIFIED IDEOGRAPH-#2A47E, IRGKangXi=1521.290, RSKangXi=203.10
2A47F CJK UNIFIED IDEOGRAPH-#2A47F, IRGKangXi=1521.300, RSKangXi=203.10
2A480 CJK UNIFIED IDEOGRAPH-#2A480, IRGKangXi=1521.310, RSKangXi=203.10
2A481 CJK UNIFIED IDEOGRAPH-#2A481, IRGKangXi=1521.320, RSKangXi=203.10
2A482 CJK UNIFIED IDEOGRAPH-#2A482, IRGKangXi=1521.330, RSKangXi=203.10
2A483 CJK UNIFIED IDEOGRAPH-#2A483, IRGKangXi=1521.340, RSKangXi=203.10
2A484 CJK UNIFIED IDEOGRAPH-#2A484, IRGKangXi=1521.360, RSKangXi=203.10
2A485 CJK UNIFIED IDEOGRAPH-#2A485, IRGKangXi=1521.380, RSKangXi=203.10
2A486 CJK UNIFIED IDEOGRAPH-#2A486, IRGKangXi=1521.381, RSKangXi=203.10
2A487 CJK UNIFIED IDEOGRAPH-#2A487, IRGKangXi=1521.381, RSKangXi=203.10
2A488 CJK UNIFIED IDEOGRAPH-#2A488, IRGKangXi=1521.381, RSKangXi=203.10
2A489 CJK UNIFIED IDEOGRAPH-#2A489, IRGKangXi=1521.381, RSKangXi=203.10
2A48A CJK UNIFIED IDEOGRAPH-#2A48A, IRGKangXi=1521.381, RSKangXi=203.10
2A48B CJK UNIFIED IDEOGRAPH-#2A48B, IRGKangXi=1521.381, RSKangXi=203.10
2A48C CJK UNIFIED IDEOGRAPH-#2A48C, IRGKangXi=1521.381, RSKangXi=203.10
2A48D CJK UNIFIED IDEOGRAPH-#2A48D, IRGKangXi=1521.381, RSKangXi=203.10
2A48E CJK UNIFIED IDEOGRAPH-#2A48E, IRGKangXi=1521.381, RSKangXi=203.10
2A48F CJK UNIFIED IDEOGRAPH-#2A48F, IRGKangXi=1521.400, RSKangXi=203.11
2A490 CJK UNIFIED IDEOGRAPH-#2A490, IRGKangXi=1521.410, RSKangXi=203.11
2A491 CJK UNIFIED IDEOGRAPH-#2A491, IRGKangXi=1521.430, RSKangXi=203.11
2A492 CJK UNIFIED IDEOGRAPH-#2A492, IRGKangXi=1521.440, RSKangXi=203.11
2A493 CJK UNIFIED IDEOGRAPH-#2A493, IRGKangXi=1521.450, RSKangXi=203.11
2A494 CJK UNIFIED IDEOGRAPH-#2A494, IRGKangXi=1521.460, RSKangXi=203.11
2A495 CJK UNIFIED IDEOGRAPH-#2A495, IRGKangXi=1522.020, RSKangXi=203.11
2A496 CJK UNIFIED IDEOGRAPH-#2A496, IRGKangXi=1522.030, RSKangXi=203.11
2A497 CJK UNIFIED IDEOGRAPH-#2A497, IRGKangXi=1522.031, RSKangXi=203.11
2A498 CJK UNIFIED IDEOGRAPH-#2A498, IRGKangXi=1522.040, RSKangXi=203.12
2A499 CJK UNIFIED IDEOGRAPH-#2A499, IRGKangXi=1522.050, RSKangXi=203.12
2A49A CJK UNIFIED IDEOGRAPH-#2A49A, IRGKangXi=1522.060, RSKangXi=203.12
2A49B CJK UNIFIED IDEOGRAPH-#2A49B, IRGKangXi=1522.070, RSKangXi=203.12
2A49C CJK UNIFIED IDEOGRAPH-#2A49C, IRGKangXi=1522.080, RSKangXi=203.12
2A49D CJK UNIFIED IDEOGRAPH-#2A49D, IRGKangXi=1522.090, RSKangXi=203.12
2A49E CJK UNIFIED IDEOGRAPH-#2A49E, IRGKangXi=1522.110, RSKangXi=203.12
2A49F CJK UNIFIED IDEOGRAPH-#2A49F, IRGKangXi=1522.120, RSKangXi=203.12
2A4A0 CJK UNIFIED IDEOGRAPH-#2A4A0, IRGKangXi=1522.130, RSKangXi=203.12
2A4A1 CJK UNIFIED IDEOGRAPH-#2A4A1, IRGKangXi=1522.140, RSKangXi=203.12
2A4A2 CJK UNIFIED IDEOGRAPH-#2A4A2, IRGKangXi=1522.150, RSKangXi=203.12
2A4A3 CJK UNIFIED IDEOGRAPH-#2A4A3, IRGKangXi=1522.160, RSKangXi=203.12
2A4A4 CJK UNIFIED IDEOGRAPH-#2A4A4, IRGKangXi=1522.161, RSKangXi=203.12
2A4A5 CJK UNIFIED IDEOGRAPH-#2A4A5, IRGKangXi=1522.161, RSKangXi=203.12
2A4A6 CJK UNIFIED IDEOGRAPH-#2A4A6, IRGKangXi=1522.161, RSKangXi=203.12
2A4A7 CJK UNIFIED IDEOGRAPH-#2A4A7, IRGKangXi=1522.161, RSKangXi=203.12
2A4A8 CJK UNIFIED IDEOGRAPH-#2A4A8, IRGKangXi=1522.161, RSKangXi=203.12
2A4A9 CJK UNIFIED IDEOGRAPH-#2A4A9, IRGKangXi=1522.180, RSKangXi=203.13
2A4AA CJK UNIFIED IDEOGRAPH-#2A4AA, IRGKangXi=1522.190, RSKangXi=203.13
2A4AB CJK UNIFIED IDEOGRAPH-#2A4AB, IRGKangXi=1522.200, RSKangXi=203.13
2A4AC CJK UNIFIED IDEOGRAPH-#2A4AC, IRGKangXi=1522.210, RSKangXi=203.13, Def{(Cant.) burned}
2A4AD CJK UNIFIED IDEOGRAPH-#2A4AD, IRGKangXi=1522.220, RSKangXi=203.13
2A4AE CJK UNIFIED IDEOGRAPH-#2A4AE, IRGKangXi=1522.240, RSKangXi=203.13
2A4AF CJK UNIFIED IDEOGRAPH-#2A4AF, IRGKangXi=1522.270, RSKangXi=203.13
2A4B0 CJK UNIFIED IDEOGRAPH-#2A4B0, IRGKangXi=1522.280, RSKangXi=203.13
2A4B1 CJK UNIFIED IDEOGRAPH-#2A4B1, IRGKangXi=1522.281, RSKangXi=203.13
2A4B2 CJK UNIFIED IDEOGRAPH-#2A4B2, IRGKangXi=1522.281, RSKangXi=203.13
2A4B3 CJK UNIFIED IDEOGRAPH-#2A4B3, IRGKangXi=1522.281, RSKangXi=203.13
2A4B4 CJK UNIFIED IDEOGRAPH-#2A4B4, IRGKangXi=1522.290, RSKangXi=203.14
2A4B5 CJK UNIFIED IDEOGRAPH-#2A4B5, IRGKangXi=1522.320, RSKangXi=203.14
2A4B6 CJK UNIFIED IDEOGRAPH-#2A4B6, IRGKangXi=1522.321, RSKangXi=203.14
2A4B7 CJK UNIFIED IDEOGRAPH-#2A4B7, IRGKangXi=1522.321, RSKangXi=203.14
2A4B8 CJK UNIFIED IDEOGRAPH-#2A4B8, IRGKangXi=1522.321, RSKangXi=203.14
2A4B9 CJK UNIFIED IDEOGRAPH-#2A4B9, IRGKangXi=1522.330, RSKangXi=203.15
2A4BA CJK UNIFIED IDEOGRAPH-#2A4BA, IRGKangXi=1522.340, RSKangXi=203.15
2A4BB CJK UNIFIED IDEOGRAPH-#2A4BB, IRGKangXi=1522.360, RSKangXi=203.15
2A4BC CJK UNIFIED IDEOGRAPH-#2A4BC, IRGKangXi=1522.361, RSKangXi=203.15
2A4BD CJK UNIFIED IDEOGRAPH-#2A4BD, IRGKangXi=1522.361, RSKangXi=203.15
2A4BE CJK UNIFIED IDEOGRAPH-#2A4BE, IRGKangXi=1522.361, RSKangXi=203.15
2A4BF CJK UNIFIED IDEOGRAPH-#2A4BF, IRGKangXi=1522.370, RSKangXi=203.16
2A4C0 CJK UNIFIED IDEOGRAPH-#2A4C0, IRGKangXi=1522.380, RSKangXi=203.16
2A4C1 CJK UNIFIED IDEOGRAPH-#2A4C1, IRGKangXi=1522.400, RSKangXi=203.16
2A4C2 CJK UNIFIED IDEOGRAPH-#2A4C2, IRGKangXi=1522.401, RSKangXi=203.16
2A4C3 CJK UNIFIED IDEOGRAPH-#2A4C3, IRGKangXi=1522.410, RSKangXi=203.17
2A4C4 CJK UNIFIED IDEOGRAPH-#2A4C4, IRGKangXi=1522.420, RSKangXi=203.17
2A4C5 CJK UNIFIED IDEOGRAPH-#2A4C5, IRGKangXi=1522.421, RSKangXi=203.18
2A4C6 CJK UNIFIED IDEOGRAPH-#2A4C6, IRGKangXi=1522.421, RSKangXi=203.18
2A4C7 CJK UNIFIED IDEOGRAPH-#2A4C7, IRGKangXi=1522.421, RSKangXi=203.20
2A4C8 CJK UNIFIED IDEOGRAPH-#2A4C8, IRGKangXi=1522.421, RSKangXi=203.20
2A4C9 CJK UNIFIED IDEOGRAPH-#2A4C9, IRGKangXi=1522.430, RSKangXi=203.26
2A4CA CJK UNIFIED IDEOGRAPH-#2A4CA, IRGKangXi=1522.440, RSKangXi=203.29
2A4CB CJK UNIFIED IDEOGRAPH-#2A4CB, IRGKangXi=1523.030, RSKangXi=204.6
2A4CC CJK UNIFIED IDEOGRAPH-#2A4CC, IRGKangXi=1523.050, RSKangXi=204.8
2A4CD CJK UNIFIED IDEOGRAPH-#2A4CD, IRGKangXi=1523.060, RSKangXi=204.9
2A4CE CJK UNIFIED IDEOGRAPH-#2A4CE, IRGKangXi=1523.070, RSKangXi=204.9
2A4CF CJK UNIFIED IDEOGRAPH-#2A4CF, IRGKangXi=1523.071, RSKangXi=204.9
2A4D0 CJK UNIFIED IDEOGRAPH-#2A4D0, IRGKangXi=1523.080, RSKangXi=204.11
2A4D1 CJK UNIFIED IDEOGRAPH-#2A4D1, IRGKangXi=1523.101, RSKangXi=205.1
2A4D2 CJK UNIFIED IDEOGRAPH-#2A4D2, IRGKangXi=1523.101, RSKangXi=205.2
2A4D3 CJK UNIFIED IDEOGRAPH-#2A4D3, IRGKangXi=1523.101, RSKangXi=205.2
2A4D4 CJK UNIFIED IDEOGRAPH-#2A4D4, IRGKangXi=1523.120, RSKangXi=205.4
2A4D5 CJK UNIFIED IDEOGRAPH-#2A4D5, IRGKangXi=1523.130, RSKangXi=205.4
2A4D6 CJK UNIFIED IDEOGRAPH-#2A4D6, IRGKangXi=1523.140, RSKangXi=205.4
2A4D7 CJK UNIFIED IDEOGRAPH-#2A4D7, IRGKangXi=1523.141, RSKangXi=205.4
2A4D8 CJK UNIFIED IDEOGRAPH-#2A4D8, IRGKangXi=1523.141, RSKangXi=205.4
2A4D9 CJK UNIFIED IDEOGRAPH-#2A4D9, IRGKangXi=1523.141, RSKangXi=205.4
2A4DA CJK UNIFIED IDEOGRAPH-#2A4DA, IRGKangXi=1523.150, RSKangXi=205.5
2A4DB CJK UNIFIED IDEOGRAPH-#2A4DB, IRGKangXi=1523.170, RSKangXi=205.5
2A4DC CJK UNIFIED IDEOGRAPH-#2A4DC, IRGKangXi=1524.010, RSKangXi=205.5
2A4DD CJK UNIFIED IDEOGRAPH-#2A4DD, IRGKangXi=1524.061, RSKangXi=205.5
2A4DE CJK UNIFIED IDEOGRAPH-#2A4DE, IRGKangXi=1524.061, RSKangXi=205.5
2A4DF CJK UNIFIED IDEOGRAPH-#2A4DF, IRGKangXi=1524.061, RSKangXi=205.5
2A4E0 CJK UNIFIED IDEOGRAPH-#2A4E0, IRGKangXi=1524.061, RSKangXi=205.5
2A4E1 CJK UNIFIED IDEOGRAPH-#2A4E1, IRGKangXi=1524.070, RSKangXi=205.6
2A4E2 CJK UNIFIED IDEOGRAPH-#2A4E2, IRGKangXi=1524.080, RSKangXi=205.6
2A4E3 CJK UNIFIED IDEOGRAPH-#2A4E3, IRGKangXi=1524.111, RSKangXi=205.6
2A4E4 CJK UNIFIED IDEOGRAPH-#2A4E4, IRGKangXi=1524.111, RSKangXi=205.6
2A4E5 CJK UNIFIED IDEOGRAPH-#2A4E5, IRGKangXi=1524.111, RSKangXi=205.6
2A4E6 CJK UNIFIED IDEOGRAPH-#2A4E6, IRGKangXi=1524.111, RSKangXi=205.6
2A4E7 CJK UNIFIED IDEOGRAPH-#2A4E7, IRGKangXi=1524.120, RSKangXi=205.7
2A4E8 CJK UNIFIED IDEOGRAPH-#2A4E8, IRGKangXi=1524.130, RSKangXi=205.7
2A4E9 CJK UNIFIED IDEOGRAPH-#2A4E9, IRGKangXi=1524.131, RSKangXi=205.7
2A4EA CJK UNIFIED IDEOGRAPH-#2A4EA, IRGKangXi=1524.131, RSKangXi=205.7
2A4EB CJK UNIFIED IDEOGRAPH-#2A4EB, IRGKangXi=1524.131, RSKangXi=205.7
2A4EC CJK UNIFIED IDEOGRAPH-#2A4EC, IRGKangXi=1524.150, RSKangXi=205.8
2A4ED CJK UNIFIED IDEOGRAPH-#2A4ED, IRGKangXi=1524.151, RSKangXi=205.8
2A4EE CJK UNIFIED IDEOGRAPH-#2A4EE, IRGKangXi=1524.160, RSKangXi=205.9
2A4EF CJK UNIFIED IDEOGRAPH-#2A4EF, IRGKangXi=1524.180, RSKangXi=205.9
2A4F0 CJK UNIFIED IDEOGRAPH-#2A4F0, IRGKangXi=1524.190, RSKangXi=205.9
2A4F1 CJK UNIFIED IDEOGRAPH-#2A4F1, IRGKangXi=1524.200, RSKangXi=205.9
2A4F2 CJK UNIFIED IDEOGRAPH-#2A4F2, IRGKangXi=1524.210, RSKangXi=205.9
2A4F3 CJK UNIFIED IDEOGRAPH-#2A4F3, IRGKangXi=1524.211, RSKangXi=205.9
2A4F4 CJK UNIFIED IDEOGRAPH-#2A4F4, IRGKangXi=1524.211, RSKangXi=205.9
2A4F5 CJK UNIFIED IDEOGRAPH-#2A4F5, IRGKangXi=1524.211, RSKangXi=205.9
2A4F6 CJK UNIFIED IDEOGRAPH-#2A4F6, IRGKangXi=1524.211, RSKangXi=205.9
2A4F7 CJK UNIFIED IDEOGRAPH-#2A4F7, IRGKangXi=1524.220, RSKangXi=205.10
2A4F8 CJK UNIFIED IDEOGRAPH-#2A4F8, IRGKangXi=1524.241, RSKangXi=205.10
2A4F9 CJK UNIFIED IDEOGRAPH-#2A4F9, IRGKangXi=1524.250, RSKangXi=205.11
2A4FA CJK UNIFIED IDEOGRAPH-#2A4FA, IRGKangXi=1525.011, RSKangXi=205.12
2A4FB CJK UNIFIED IDEOGRAPH-#2A4FB, IRGKangXi=1525.011, RSKangXi=213.9
2A4FC CJK UNIFIED IDEOGRAPH-#2A4FC, IRGKangXi=1525.020, RSKangXi=205.13
2A4FD CJK UNIFIED IDEOGRAPH-#2A4FD, IRGKangXi=1525.040, RSKangXi=205.12
2A4FE CJK UNIFIED IDEOGRAPH-#2A4FE, IRGKangXi=1525.050, RSKangXi=205.13
2A4FF CJK UNIFIED IDEOGRAPH-#2A4FF, IRGKangXi=1525.060, RSKangXi=205.14
2A500 CJK UNIFIED IDEOGRAPH-#2A500, IRGKangXi=1525.061, RSKangXi=205.14
2A501 CJK UNIFIED IDEOGRAPH-#2A501, IRGKangXi=1525.070, RSKangXi=205.15
2A502 CJK UNIFIED IDEOGRAPH-#2A502, IRGKangXi=1525.100, RSKangXi=206.0, Def{tripod}
2A503 CJK UNIFIED IDEOGRAPH-#2A503, IRGKangXi=1525.140, RSKangXi=206.2
2A504 CJK UNIFIED IDEOGRAPH-#2A504, IRGKangXi=1525.160, RSKangXi=206.3
2A505 CJK UNIFIED IDEOGRAPH-#2A505, IRGKangXi=1525.170, RSKangXi=206.3
2A506 CJK UNIFIED IDEOGRAPH-#2A506, IRGKangXi=1525.190, RSKangXi=206.3
2A507 CJK UNIFIED IDEOGRAPH-#2A507, IRGKangXi=1525.191, RSKangXi=206.4
2A508 CJK UNIFIED IDEOGRAPH-#2A508, IRGKangXi=1525.200, RSKangXi=206.6
2A509 CJK UNIFIED IDEOGRAPH-#2A509, IRGKangXi=1525.201, RSKangXi=206.10
2A50A CJK UNIFIED IDEOGRAPH-#2A50A, IRGKangXi=1525.230, RSKangXi=206.15
2A50B CJK UNIFIED IDEOGRAPH-#2A50B, IRGKangXi=1526.040, RSKangXi=207.3
2A50C CJK UNIFIED IDEOGRAPH-#2A50C, IRGKangXi=1526.041, RSKangXi=207.3
2A50D CJK UNIFIED IDEOGRAPH-#2A50D, IRGKangXi=1526.050, RSKangXi=207.4
2A50E CJK UNIFIED IDEOGRAPH-#2A50E, IRGKangXi=1526.060, RSKangXi=207.4
2A50F CJK UNIFIED IDEOGRAPH-#2A50F, IRGKangXi=1526.061, RSKangXi=207.4
2A510 CJK UNIFIED IDEOGRAPH-#2A510, IRGKangXi=1526.080, RSKangXi=207.5
2A511 CJK UNIFIED IDEOGRAPH-#2A511, IRGKangXi=1526.090, RSKangXi=207.5
2A512 CJK UNIFIED IDEOGRAPH-#2A512, IRGKangXi=1526.131, RSKangXi=207.5
2A513 CJK UNIFIED IDEOGRAPH-#2A513, IRGKangXi=1526.131, RSKangXi=207.5
2A514 CJK UNIFIED IDEOGRAPH-#2A514, IRGKangXi=1526.140, RSKangXi=207.6
2A515 CJK UNIFIED IDEOGRAPH-#2A515, IRGKangXi=1526.150, RSKangXi=207.6
2A516 CJK UNIFIED IDEOGRAPH-#2A516, IRGKangXi=1526.180, RSKangXi=207.6
2A517 CJK UNIFIED IDEOGRAPH-#2A517, IRGKangXi=1526.190, RSKangXi=207.6
2A518 CJK UNIFIED IDEOGRAPH-#2A518, IRGKangXi=1526.220, RSKangXi=207.6
2A519 CJK UNIFIED IDEOGRAPH-#2A519, IRGKangXi=1526.221, RSKangXi=207.6
2A51A CJK UNIFIED IDEOGRAPH-#2A51A, IRGKangXi=1526.221, RSKangXi=207.6
2A51B CJK UNIFIED IDEOGRAPH-#2A51B, IRGKangXi=1526.221, RSKangXi=207.6
2A51C CJK UNIFIED IDEOGRAPH-#2A51C, IRGKangXi=1526.230, RSKangXi=207.7
2A51D CJK UNIFIED IDEOGRAPH-#2A51D, IRGKangXi=1526.240, RSKangXi=207.7
2A51E CJK UNIFIED IDEOGRAPH-#2A51E, IRGKangXi=1526.241, RSKangXi=207.7
2A51F CJK UNIFIED IDEOGRAPH-#2A51F, IRGKangXi=1526.241, RSKangXi=207.7
2A520 CJK UNIFIED IDEOGRAPH-#2A520, IRGKangXi=1526.241, RSKangXi=207.7
2A521 CJK UNIFIED IDEOGRAPH-#2A521, IRGKangXi=1526.241, RSKangXi=207.7
2A522 CJK UNIFIED IDEOGRAPH-#2A522, IRGKangXi=1526.290, RSKangXi=207.8
2A523 CJK UNIFIED IDEOGRAPH-#2A523, IRGKangXi=1526.300, RSKangXi=207.8
2A524 CJK UNIFIED IDEOGRAPH-#2A524, IRGKangXi=1526.311, RSKangXi=207.8
2A525 CJK UNIFIED IDEOGRAPH-#2A525, IRGKangXi=1526.311, RSKangXi=207.8
2A526 CJK UNIFIED IDEOGRAPH-#2A526, IRGKangXi=1526.320, RSKangXi=207.9
2A527 CJK UNIFIED IDEOGRAPH-#2A527, IRGKangXi=1526.330, RSKangXi=207.9
2A528 CJK UNIFIED IDEOGRAPH-#2A528, IRGKangXi=1526.340, RSKangXi=207.9
2A529 CJK UNIFIED IDEOGRAPH-#2A529, IRGKangXi=1526.350, RSKangXi=207.9
2A52A CJK UNIFIED IDEOGRAPH-#2A52A, IRGKangXi=1526.360, RSKangXi=207.9
2A52B CJK UNIFIED IDEOGRAPH-#2A52B, IRGKangXi=1527.010, RSKangXi=207.9
2A52C CJK UNIFIED IDEOGRAPH-#2A52C, IRGKangXi=1527.020, RSKangXi=207.9
2A52D CJK UNIFIED IDEOGRAPH-#2A52D, IRGKangXi=1527.021, RSKangXi=207.9
2A52E CJK UNIFIED IDEOGRAPH-#2A52E, IRGKangXi=1527.040, RSKangXi=207.10
2A52F CJK UNIFIED IDEOGRAPH-#2A52F, IRGKangXi=1527.070, RSKangXi=207.11
2A530 CJK UNIFIED IDEOGRAPH-#2A530, IRGKangXi=1527.080, RSKangXi=207.11
2A531 CJK UNIFIED IDEOGRAPH-#2A531, IRGKangXi=1527.081, RSKangXi=207.11
2A532 CJK UNIFIED IDEOGRAPH-#2A532, IRGKangXi=1527.081, RSKangXi=207.11
2A533 CJK UNIFIED IDEOGRAPH-#2A533, IRGKangXi=1527.100, RSKangXi=207.12
2A534 CJK UNIFIED IDEOGRAPH-#2A534, IRGKangXi=1527.101, RSKangXi=207.12
2A535 CJK UNIFIED IDEOGRAPH-#2A535, IRGKangXi=1527.110, RSKangXi=207.13
2A536 CJK UNIFIED IDEOGRAPH-#2A536, IRGKangXi=1527.120, RSKangXi=207.14
2A537 CJK UNIFIED IDEOGRAPH-#2A537, IRGKangXi=1527.130, RSKangXi=207.16
2A538 CJK UNIFIED IDEOGRAPH-#2A538, IRGKangXi=1527.150, RSKangXi=208.2
2A539 CJK UNIFIED IDEOGRAPH-#2A539, IRGKangXi=1527.151, RSKangXi=208.2
2A53A CJK UNIFIED IDEOGRAPH-#2A53A, IRGKangXi=1527.160, RSKangXi=208.3
2A53B CJK UNIFIED IDEOGRAPH-#2A53B, IRGKangXi=1527.180, RSKangXi=208.3
2A53C CJK UNIFIED IDEOGRAPH-#2A53C, IRGKangXi=1527.190, RSKangXi=208.3
2A53D CJK UNIFIED IDEOGRAPH-#2A53D, IRGKangXi=1527.200, RSKangXi=208.4
2A53E CJK UNIFIED IDEOGRAPH-#2A53E, IRGKangXi=1527.220, RSKangXi=208.4, Def{a rat, mouse}
2A53F CJK UNIFIED IDEOGRAPH-#2A53F, IRGKangXi=1527.240, RSKangXi=208.4
2A540 CJK UNIFIED IDEOGRAPH-#2A540, IRGKangXi=1527.250, RSKangXi=208.4
2A541 CJK UNIFIED IDEOGRAPH-#2A541, IRGKangXi=1527.260, RSKangXi=208.4
2A542 CJK UNIFIED IDEOGRAPH-#2A542, IRGKangXi=1527.280, RSKangXi=208.4
2A543 CJK UNIFIED IDEOGRAPH-#2A543, IRGKangXi=1527.290, RSKangXi=208.4
2A544 CJK UNIFIED IDEOGRAPH-#2A544, IRGKangXi=1527.310, RSKangXi=208.4
2A545 CJK UNIFIED IDEOGRAPH-#2A545, IRGKangXi=1527.311, RSKangXi=208.4
2A546 CJK UNIFIED IDEOGRAPH-#2A546, IRGKangXi=1527.311, RSKangXi=208.4
2A547 CJK UNIFIED IDEOGRAPH-#2A547, IRGKangXi=1527.311, RSKangXi=208.4
2A548 CJK UNIFIED IDEOGRAPH-#2A548, IRGKangXi=1527.311, RSKangXi=208.4
2A549 CJK UNIFIED IDEOGRAPH-#2A549, IRGKangXi=1528.020, RSKangXi=208.5
2A54A CJK UNIFIED IDEOGRAPH-#2A54A, IRGKangXi=1528.030, RSKangXi=208.5
2A54B CJK UNIFIED IDEOGRAPH-#2A54B, IRGKangXi=1528.050, RSKangXi=208.5
2A54C CJK UNIFIED IDEOGRAPH-#2A54C, IRGKangXi=1528.070, RSKangXi=208.5
2A54D CJK UNIFIED IDEOGRAPH-#2A54D, IRGKangXi=1528.080, RSKangXi=208.5
2A54E CJK UNIFIED IDEOGRAPH-#2A54E, IRGKangXi=1528.130, RSKangXi=208.5
2A54F CJK UNIFIED IDEOGRAPH-#2A54F, IRGKangXi=1528.150, RSKangXi=208.5
2A550 CJK UNIFIED IDEOGRAPH-#2A550, IRGKangXi=1528.160, RSKangXi=208.5
2A551 CJK UNIFIED IDEOGRAPH-#2A551, IRGKangXi=1528.161, RSKangXi=208.5
2A552 CJK UNIFIED IDEOGRAPH-#2A552, IRGKangXi=1528.170, RSKangXi=208.6
2A553 CJK UNIFIED IDEOGRAPH-#2A553, IRGKangXi=1528.190, RSKangXi=208.6
2A554 CJK UNIFIED IDEOGRAPH-#2A554, IRGKangXi=1528.210, RSKangXi=208.6
2A555 CJK UNIFIED IDEOGRAPH-#2A555, IRGKangXi=1528.211, RSKangXi=208.6
2A556 CJK UNIFIED IDEOGRAPH-#2A556, IRGKangXi=1528.211, RSKangXi=208.6
2A557 CJK UNIFIED IDEOGRAPH-#2A557, IRGKangXi=1528.211, RSKangXi=208.6
2A558 CJK UNIFIED IDEOGRAPH-#2A558, IRGKangXi=1528.211, RSKangXi=208.6
2A559 CJK UNIFIED IDEOGRAPH-#2A559, IRGKangXi=1528.211, RSKangXi=208.6
2A55A CJK UNIFIED IDEOGRAPH-#2A55A, IRGKangXi=1528.230, RSKangXi=208.7
2A55B CJK UNIFIED IDEOGRAPH-#2A55B, IRGKangXi=1528.240, RSKangXi=208.7
2A55C CJK UNIFIED IDEOGRAPH-#2A55C, IRGKangXi=1528.260, RSKangXi=208.7
2A55D CJK UNIFIED IDEOGRAPH-#2A55D, IRGKangXi=1528.270, RSKangXi=208.7
2A55E CJK UNIFIED IDEOGRAPH-#2A55E, IRGKangXi=1528.280, RSKangXi=208.7
2A55F CJK UNIFIED IDEOGRAPH-#2A55F, IRGKangXi=1528.290, RSKangXi=208.6
2A560 CJK UNIFIED IDEOGRAPH-#2A560, IRGKangXi=1528.300, RSKangXi=208.7
2A561 CJK UNIFIED IDEOGRAPH-#2A561, IRGKangXi=1528.311, RSKangXi=208.7
2A562 CJK UNIFIED IDEOGRAPH-#2A562, IRGKangXi=1528.311, RSKangXi=208.7
2A563 CJK UNIFIED IDEOGRAPH-#2A563, IRGKangXi=1528.311, RSKangXi=208.7
2A564 CJK UNIFIED IDEOGRAPH-#2A564, IRGKangXi=1528.311, RSKangXi=208.7
2A565 CJK UNIFIED IDEOGRAPH-#2A565, IRGKangXi=1528.311, RSKangXi=208.7
2A566 CJK UNIFIED IDEOGRAPH-#2A566, IRGKangXi=1528.311, RSKangXi=208.7
2A567 CJK UNIFIED IDEOGRAPH-#2A567, IRGKangXi=1528.311, RSKangXi=208.7
2A568 CJK UNIFIED IDEOGRAPH-#2A568, IRGKangXi=1528.320, RSKangXi=208.8
2A569 CJK UNIFIED IDEOGRAPH-#2A569, IRGKangXi=1528.340, RSKangXi=208.8
2A56A CJK UNIFIED IDEOGRAPH-#2A56A, IRGKangXi=1529.010, RSKangXi=208.8
2A56B CJK UNIFIED IDEOGRAPH-#2A56B, IRGKangXi=1529.020, RSKangXi=208.9
2A56C CJK UNIFIED IDEOGRAPH-#2A56C, IRGKangXi=1529.040, RSKangXi=208.9
2A56D CJK UNIFIED IDEOGRAPH-#2A56D, IRGKangXi=1529.070, RSKangXi=208.9
2A56E CJK UNIFIED IDEOGRAPH-#2A56E, IRGKangXi=1529.080, RSKangXi=208.9
2A56F CJK UNIFIED IDEOGRAPH-#2A56F, IRGKangXi=1529.090, RSKangXi=208.9
2A570 CJK UNIFIED IDEOGRAPH-#2A570, IRGKangXi=1529.120, RSKangXi=208.9
2A571 CJK UNIFIED IDEOGRAPH-#2A571, IRGKangXi=1529.130, RSKangXi=208.9
2A572 CJK UNIFIED IDEOGRAPH-#2A572, IRGKangXi=1529.131, RSKangXi=208.9
2A573 CJK UNIFIED IDEOGRAPH-#2A573, IRGKangXi=1529.131, RSKangXi=208.9
2A574 CJK UNIFIED IDEOGRAPH-#2A574, IRGKangXi=1529.131, RSKangXi=208.9
2A575 CJK UNIFIED IDEOGRAPH-#2A575, IRGKangXi=1529.140, RSKangXi=208.10
2A576 CJK UNIFIED IDEOGRAPH-#2A576, IRGKangXi=1529.150, RSKangXi=208.10
2A577 CJK UNIFIED IDEOGRAPH-#2A577, IRGKangXi=1529.160, RSKangXi=208.10
2A578 CJK UNIFIED IDEOGRAPH-#2A578, IRGKangXi=1529.170, RSKangXi=208.10
2A579 CJK UNIFIED IDEOGRAPH-#2A579, IRGKangXi=1529.180, RSKangXi=208.10
2A57A CJK UNIFIED IDEOGRAPH-#2A57A, IRGKangXi=1529.240, RSKangXi=208.10
2A57B CJK UNIFIED IDEOGRAPH-#2A57B, IRGKangXi=1529.251, RSKangXi=208.10
2A57C CJK UNIFIED IDEOGRAPH-#2A57C, IRGKangXi=1529.251, RSKangXi=208.10
2A57D CJK UNIFIED IDEOGRAPH-#2A57D, IRGKangXi=1529.251, RSKangXi=208.10
2A57E CJK UNIFIED IDEOGRAPH-#2A57E, IRGKangXi=1529.251, RSKangXi=208.10
2A57F CJK UNIFIED IDEOGRAPH-#2A57F, IRGKangXi=1529.251, RSKangXi=209.10
2A580 CJK UNIFIED IDEOGRAPH-#2A580, IRGKangXi=1529.260, RSKangXi=208.11
2A581 CJK UNIFIED IDEOGRAPH-#2A581, IRGKangXi=1529.270, RSKangXi=208.11
2A582 CJK UNIFIED IDEOGRAPH-#2A582, IRGKangXi=1529.280, RSKangXi=208.11
2A583 CJK UNIFIED IDEOGRAPH-#2A583, IRGKangXi=1529.290, RSKangXi=208.11
2A584 CJK UNIFIED IDEOGRAPH-#2A584, IRGKangXi=1529.291, RSKangXi=208.11
2A585 CJK UNIFIED IDEOGRAPH-#2A585, IRGKangXi=1529.300, RSKangXi=208.12
2A586 CJK UNIFIED IDEOGRAPH-#2A586, IRGKangXi=1529.310, RSKangXi=208.12
2A587 CJK UNIFIED IDEOGRAPH-#2A587, IRGKangXi=1529.320, RSKangXi=208.12
2A588 CJK UNIFIED IDEOGRAPH-#2A588, IRGKangXi=1529.330, RSKangXi=208.12
2A589 CJK UNIFIED IDEOGRAPH-#2A589, IRGKangXi=1529.331, RSKangXi=208.12
2A58A CJK UNIFIED IDEOGRAPH-#2A58A, IRGKangXi=1529.331, RSKangXi=208.13
2A58B CJK UNIFIED IDEOGRAPH-#2A58B, IRGKangXi=1529.340, RSKangXi=208.14
2A58C CJK UNIFIED IDEOGRAPH-#2A58C, IRGKangXi=1529.360, RSKangXi=208.16
2A58D CJK UNIFIED IDEOGRAPH-#2A58D, IRGKangXi=1529.370, RSKangXi=208.16
2A58E CJK UNIFIED IDEOGRAPH-#2A58E, IRGKangXi=1529.380, RSKangXi=208.17
2A58F CJK UNIFIED IDEOGRAPH-#2A58F, IRGKangXi=1529.390, RSKangXi=208.18
2A590 CJK UNIFIED IDEOGRAPH-#2A590, IRGKangXi=1530.030, RSKangXi=209.1
2A591 CJK UNIFIED IDEOGRAPH-#2A591, IRGKangXi=1530.050, RSKangXi=209.2
2A592 CJK UNIFIED IDEOGRAPH-#2A592, IRGKangXi=1530.070, RSKangXi=209.2
2A593 CJK UNIFIED IDEOGRAPH-#2A593, IRGKangXi=1530.101, RSKangXi=209.3
2A594 CJK UNIFIED IDEOGRAPH-#2A594, IRGKangXi=1530.101, RSKangXi=209.3
2A595 CJK UNIFIED IDEOGRAPH-#2A595, IRGKangXi=1530.130, RSKangXi=209.4
2A596 CJK UNIFIED IDEOGRAPH-#2A596, IRGKangXi=1530.140, RSKangXi=209.4
2A597 CJK UNIFIED IDEOGRAPH-#2A597, IRGKangXi=1530.150, RSKangXi=209.4
2A598 CJK UNIFIED IDEOGRAPH-#2A598, IRGKangXi=1530.160, RSKangXi=209.4
2A599 CJK UNIFIED IDEOGRAPH-#2A599, IRGKangXi=1530.161, RSKangXi=209.4, Def{to snore}
2A59A CJK UNIFIED IDEOGRAPH-#2A59A, IRGKangXi=1530.180, RSKangXi=209.5
2A59B CJK UNIFIED IDEOGRAPH-#2A59B, IRGKangXi=1530.190, RSKangXi=209.5
2A59C CJK UNIFIED IDEOGRAPH-#2A59C, IRGKangXi=1530.211, RSKangXi=209.5
2A59D CJK UNIFIED IDEOGRAPH-#2A59D, IRGKangXi=1530.211, RSKangXi=209.5
2A59E CJK UNIFIED IDEOGRAPH-#2A59E, IRGKangXi=1530.211, RSKangXi=209.5
2A59F CJK UNIFIED IDEOGRAPH-#2A59F, IRGKangXi=1530.211, RSKangXi=209.5
2A5A0 CJK UNIFIED IDEOGRAPH-#2A5A0, IRGKangXi=1530.211, RSKangXi=209.5
2A5A1 CJK UNIFIED IDEOGRAPH-#2A5A1, IRGKangXi=1530.220, RSKangXi=209.6
2A5A2 CJK UNIFIED IDEOGRAPH-#2A5A2, IRGKangXi=1530.240, RSKangXi=209.6
2A5A3 CJK UNIFIED IDEOGRAPH-#2A5A3, IRGKangXi=1530.260, RSKangXi=209.6
2A5A4 CJK UNIFIED IDEOGRAPH-#2A5A4, IRGKangXi=1530.261, RSKangXi=209.6
2A5A5 CJK UNIFIED IDEOGRAPH-#2A5A5, IRGKangXi=1530.270, RSKangXi=209.7
2A5A6 CJK UNIFIED IDEOGRAPH-#2A5A6, IRGKangXi=1530.290, RSKangXi=209.7
2A5A7 CJK UNIFIED IDEOGRAPH-#2A5A7, IRGKangXi=1530.300, RSKangXi=209.7
2A5A8 CJK UNIFIED IDEOGRAPH-#2A5A8, IRGKangXi=1530.310, RSKangXi=209.7
2A5A9 CJK UNIFIED IDEOGRAPH-#2A5A9, IRGKangXi=1530.320, RSKangXi=209.7
2A5AA CJK UNIFIED IDEOGRAPH-#2A5AA, IRGKangXi=1530.321, RSKangXi=209.7
2A5AB CJK UNIFIED IDEOGRAPH-#2A5AB, IRGKangXi=1530.321, RSKangXi=209.7
2A5AC CJK UNIFIED IDEOGRAPH-#2A5AC, IRGKangXi=1530.321, RSKangXi=209.7
2A5AD CJK UNIFIED IDEOGRAPH-#2A5AD, IRGKangXi=1530.331, RSKangXi=209.8
2A5AE CJK UNIFIED IDEOGRAPH-#2A5AE, IRGKangXi=1530.331, RSKangXi=209.8
2A5AF CJK UNIFIED IDEOGRAPH-#2A5AF, IRGKangXi=1530.340, RSKangXi=209.9
2A5B0 CJK UNIFIED IDEOGRAPH-#2A5B0, IRGKangXi=1530.360, RSKangXi=209.9
2A5B1 CJK UNIFIED IDEOGRAPH-#2A5B1, IRGKangXi=1530.361, RSKangXi=209.9
2A5B2 CJK UNIFIED IDEOGRAPH-#2A5B2, IRGKangXi=1530.361, RSKangXi=209.9
2A5B3 CJK UNIFIED IDEOGRAPH-#2A5B3, IRGKangXi=1530.370, RSKangXi=209.10
2A5B4 CJK UNIFIED IDEOGRAPH-#2A5B4, IRGKangXi=1530.391, RSKangXi=209.10
2A5B5 CJK UNIFIED IDEOGRAPH-#2A5B5, IRGKangXi=1530.391, RSKangXi=209.10
2A5B6 CJK UNIFIED IDEOGRAPH-#2A5B6, IRGKangXi=1530.410, RSKangXi=209.11
2A5B7 CJK UNIFIED IDEOGRAPH-#2A5B7, IRGKangXi=1530.420, RSKangXi=209.11
2A5B8 CJK UNIFIED IDEOGRAPH-#2A5B8, IRGKangXi=1530.421, RSKangXi=209.11
2A5B9 CJK UNIFIED IDEOGRAPH-#2A5B9, IRGKangXi=1530.421, RSKangXi=209.11
2A5BA CJK UNIFIED IDEOGRAPH-#2A5BA, IRGKangXi=1530.421, RSKangXi=209.11
2A5BB CJK UNIFIED IDEOGRAPH-#2A5BB, IRGKangXi=1530.430, RSKangXi=209.12
2A5BC CJK UNIFIED IDEOGRAPH-#2A5BC, IRGKangXi=1530.440, RSKangXi=209.12
2A5BD CJK UNIFIED IDEOGRAPH-#2A5BD, IRGKangXi=1530.450, RSKangXi=209.12
2A5BE CJK UNIFIED IDEOGRAPH-#2A5BE, IRGKangXi=1531.020, RSKangXi=209.13
2A5BF CJK UNIFIED IDEOGRAPH-#2A5BF, IRGKangXi=1531.021, RSKangXi=209.13
2A5C0 CJK UNIFIED IDEOGRAPH-#2A5C0, IRGKangXi=1531.021, RSKangXi=209.13
2A5C1 CJK UNIFIED IDEOGRAPH-#2A5C1, IRGKangXi=1531.040, RSKangXi=209.16
2A5C2 CJK UNIFIED IDEOGRAPH-#2A5C2, IRGKangXi=1531.050, RSKangXi=209.17
2A5C3 CJK UNIFIED IDEOGRAPH-#2A5C3, IRGKangXi=1531.051, RSKangXi=209.18
2A5C4 CJK UNIFIED IDEOGRAPH-#2A5C4, IRGKangXi=1531.071, RSKangXi=210.0
2A5C5 CJK UNIFIED IDEOGRAPH-#2A5C5, IRGKangXi=1531.080, RSKangXi=210.2
2A5C6 CJK UNIFIED IDEOGRAPH-#2A5C6, IRGKangXi=1531.100, RSKangXi=210.3
2A5C7 CJK UNIFIED IDEOGRAPH-#2A5C7, IRGKangXi=1531.150, RSKangXi=210.4
2A5C8 CJK UNIFIED IDEOGRAPH-#2A5C8, IRGKangXi=1531.151, RSKangXi=210.4
2A5C9 CJK UNIFIED IDEOGRAPH-#2A5C9, IRGKangXi=1531.170, RSKangXi=210.5
2A5CA CJK UNIFIED IDEOGRAPH-#2A5CA, IRGKangXi=1531.171, RSKangXi=210.5
2A5CB CJK UNIFIED IDEOGRAPH-#2A5CB, IRGKangXi=1532.010, RSKangXi=210.6
2A5CC CJK UNIFIED IDEOGRAPH-#2A5CC, IRGKangXi=1532.011, RSKangXi=210.6
2A5CD CJK UNIFIED IDEOGRAPH-#2A5CD, IRGKangXi=1532.030, RSKangXi=210.8
2A5CE CJK UNIFIED IDEOGRAPH-#2A5CE, IRGKangXi=1532.031, RSKangXi=210.7
2A5CF CJK UNIFIED IDEOGRAPH-#2A5CF, IRGKangXi=1532.050, RSKangXi=210.11
2A5D0 CJK UNIFIED IDEOGRAPH-#2A5D0, IRGKangXi=1532.060, RSKangXi=210.11
2A5D1 CJK UNIFIED IDEOGRAPH-#2A5D1, IRGKangXi=1532.061, RSKangXi=210.11
2A5D2 CJK UNIFIED IDEOGRAPH-#2A5D2, IRGKangXi=1532.070, RSKangXi=210.14
2A5D3 CJK UNIFIED IDEOGRAPH-#2A5D3, IRGKangXi=1532.071, RSKangXi=210.16
2A5D4 CJK UNIFIED IDEOGRAPH-#2A5D4, IRGKangXi=1532.150, RSKangXi=211.2
2A5D5 CJK UNIFIED IDEOGRAPH-#2A5D5, IRGKangXi=1532.170, RSKangXi=211.2
2A5D6 CJK UNIFIED IDEOGRAPH-#2A5D6, IRGKangXi=1532.171, RSKangXi=211.2
2A5D7 CJK UNIFIED IDEOGRAPH-#2A5D7, IRGKangXi=1532.171, RSKangXi=211.2
2A5D8 CJK UNIFIED IDEOGRAPH-#2A5D8, IRGKangXi=1532.190, RSKangXi=211.3
2A5D9 CJK UNIFIED IDEOGRAPH-#2A5D9, IRGKangXi=1532.210, RSKangXi=211.3
2A5DA CJK UNIFIED IDEOGRAPH-#2A5DA, IRGKangXi=1532.211, RSKangXi=211.3
2A5DB CJK UNIFIED IDEOGRAPH-#2A5DB, IRGKangXi=1532.220, RSKangXi=211.4
2A5DC CJK UNIFIED IDEOGRAPH-#2A5DC, IRGKangXi=1532.240, RSKangXi=211.4
2A5DD CJK UNIFIED IDEOGRAPH-#2A5DD, IRGKangXi=1532.250, RSKangXi=211.4
2A5DE CJK UNIFIED IDEOGRAPH-#2A5DE, IRGKangXi=1533.020, RSKangXi=211.4
2A5DF CJK UNIFIED IDEOGRAPH-#2A5DF, IRGKangXi=1533.040, RSKangXi=211.4
2A5E0 CJK UNIFIED IDEOGRAPH-#2A5E0, IRGKangXi=1533.041, RSKangXi=211.4
2A5E1 CJK UNIFIED IDEOGRAPH-#2A5E1, IRGKangXi=1533.041, RSKangXi=211.4
2A5E2 CJK UNIFIED IDEOGRAPH-#2A5E2, IRGKangXi=1533.041, RSKangXi=211.4
2A5E3 CJK UNIFIED IDEOGRAPH-#2A5E3, IRGKangXi=1533.041, RSKangXi=211.4
2A5E4 CJK UNIFIED IDEOGRAPH-#2A5E4, IRGKangXi=1533.041, RSKangXi=211.4
2A5E5 CJK UNIFIED IDEOGRAPH-#2A5E5, IRGKangXi=1533.050, RSKangXi=211.5
2A5E6 CJK UNIFIED IDEOGRAPH-#2A5E6, IRGKangXi=1533.060, RSKangXi=211.5
2A5E7 CJK UNIFIED IDEOGRAPH-#2A5E7, IRGKangXi=1533.080, RSKangXi=211.5
2A5E8 CJK UNIFIED IDEOGRAPH-#2A5E8, IRGKangXi=1533.100, RSKangXi=211.5
2A5E9 CJK UNIFIED IDEOGRAPH-#2A5E9, IRGKangXi=1533.130, RSKangXi=211.5
2A5EA CJK UNIFIED IDEOGRAPH-#2A5EA, IRGKangXi=1533.170, RSKangXi=211.5
2A5EB CJK UNIFIED IDEOGRAPH-#2A5EB, IRGKangXi=1533.180, RSKangXi=211.5
2A5EC CJK UNIFIED IDEOGRAPH-#2A5EC, IRGKangXi=1533.220, RSKangXi=211.5
2A5ED CJK UNIFIED IDEOGRAPH-#2A5ED, IRGKangXi=1533.230, RSKangXi=211.5
2A5EE CJK UNIFIED IDEOGRAPH-#2A5EE, IRGKangXi=1533.240, RSKangXi=211.5
2A5EF CJK UNIFIED IDEOGRAPH-#2A5EF, IRGKangXi=1533.270, RSKangXi=211.5
2A5F0 CJK UNIFIED IDEOGRAPH-#2A5F0, IRGKangXi=1533.280, RSKangXi=211.5
2A5F1 CJK UNIFIED IDEOGRAPH-#2A5F1, IRGKangXi=1533.281, RSKangXi=211.5
2A5F2 CJK UNIFIED IDEOGRAPH-#2A5F2, IRGKangXi=1533.281, RSKangXi=211.5
2A5F3 CJK UNIFIED IDEOGRAPH-#2A5F3, IRGKangXi=1533.281, RSKangXi=211.5
2A5F4 CJK UNIFIED IDEOGRAPH-#2A5F4, IRGKangXi=1533.281, RSKangXi=211.5
2A5F5 CJK UNIFIED IDEOGRAPH-#2A5F5, IRGKangXi=1533.281, RSKangXi=211.5
2A5F6 CJK UNIFIED IDEOGRAPH-#2A5F6, IRGKangXi=1533.281, RSKangXi=211.5
2A5F7 CJK UNIFIED IDEOGRAPH-#2A5F7, IRGKangXi=1533.290, RSKangXi=211.6
2A5F8 CJK UNIFIED IDEOGRAPH-#2A5F8, IRGKangXi=1533.300, RSKangXi=211.6
2A5F9 CJK UNIFIED IDEOGRAPH-#2A5F9, IRGKangXi=1533.310, RSKangXi=211.6
2A5FA CJK UNIFIED IDEOGRAPH-#2A5FA, IRGKangXi=1533.320, RSKangXi=211.6
2A5FB CJK UNIFIED IDEOGRAPH-#2A5FB, IRGKangXi=1533.340, RSKangXi=211.6
2A5FC CJK UNIFIED IDEOGRAPH-#2A5FC, IRGKangXi=1533.360, RSKangXi=211.6
2A5FD CJK UNIFIED IDEOGRAPH-#2A5FD, IRGKangXi=1534.010, RSKangXi=211.6
2A5FE CJK UNIFIED IDEOGRAPH-#2A5FE, IRGKangXi=1534.030, RSKangXi=211.6
2A5FF CJK UNIFIED IDEOGRAPH-#2A5FF, IRGKangXi=1534.080, RSKangXi=211.6
2A600 CJK UNIFIED IDEOGRAPH-#2A600, IRGKangXi=1534.090, RSKangXi=211.6
2A601 CJK UNIFIED IDEOGRAPH-#2A601, IRGKangXi=1534.100, RSKangXi=211.6, Def{(Cant.) to bite}
2A602 CJK UNIFIED IDEOGRAPH-#2A602, IRGKangXi=1534.101, RSKangXi=211.6
2A603 CJK UNIFIED IDEOGRAPH-#2A603, IRGKangXi=1534.101, RSKangXi=211.6
2A604 CJK UNIFIED IDEOGRAPH-#2A604, IRGKangXi=1534.101, RSKangXi=211.6
2A605 CJK UNIFIED IDEOGRAPH-#2A605, IRGKangXi=1534.101, RSKangXi=211.6
2A606 CJK UNIFIED IDEOGRAPH-#2A606, IRGKangXi=1534.101, RSKangXi=211.6
2A607 CJK UNIFIED IDEOGRAPH-#2A607, IRGKangXi=1534.101, RSKangXi=211.6
2A608 CJK UNIFIED IDEOGRAPH-#2A608, IRGKangXi=1534.101, RSKangXi=211.6
2A609 CJK UNIFIED IDEOGRAPH-#2A609, IRGKangXi=1534.101, RSKangXi=211.6
2A60A CJK UNIFIED IDEOGRAPH-#2A60A, IRGKangXi=1534.101, RSKangXi=211.6
2A60B CJK UNIFIED IDEOGRAPH-#2A60B, IRGKangXi=1534.101, RSKangXi=211.6
2A60C CJK UNIFIED IDEOGRAPH-#2A60C, IRGKangXi=1534.101, RSKangXi=211.6
2A60D CJK UNIFIED IDEOGRAPH-#2A60D, IRGKangXi=1534.101, RSKangXi=211.6
2A60E CJK UNIFIED IDEOGRAPH-#2A60E, IRGKangXi=1534.120, RSKangXi=211.7
2A60F CJK UNIFIED IDEOGRAPH-#2A60F, IRGKangXi=1534.140, RSKangXi=211.7
2A610 CJK UNIFIED IDEOGRAPH-#2A610, IRGKangXi=1534.150, RSKangXi=211.7
2A611 CJK UNIFIED IDEOGRAPH-#2A611, IRGKangXi=1534.160, RSKangXi=211.7
2A612 CJK UNIFIED IDEOGRAPH-#2A612, IRGKangXi=1534.180, RSKangXi=211.7
2A613 CJK UNIFIED IDEOGRAPH-#2A613, IRGKangXi=1534.190, RSKangXi=211.7
2A614 CJK UNIFIED IDEOGRAPH-#2A614, IRGKangXi=1534.210, RSKangXi=211.7
2A615 CJK UNIFIED IDEOGRAPH-#2A615, IRGKangXi=1534.230, RSKangXi=211.7
2A616 CJK UNIFIED IDEOGRAPH-#2A616, IRGKangXi=1534.240, RSKangXi=211.7
2A617 CJK UNIFIED IDEOGRAPH-#2A617, IRGKangXi=1534.250, RSKangXi=211.7
2A618 CJK UNIFIED IDEOGRAPH-#2A618, IRGKangXi=1534.260, RSKangXi=211.7
2A619 CJK UNIFIED IDEOGRAPH-#2A619, IRGKangXi=1534.261, RSKangXi=211.7
2A61A CJK UNIFIED IDEOGRAPH-#2A61A, IRGKangXi=1534.261, RSKangXi=211.7
2A61B CJK UNIFIED IDEOGRAPH-#2A61B, IRGKangXi=1534.261, RSKangXi=211.7
2A61C CJK UNIFIED IDEOGRAPH-#2A61C, IRGKangXi=1534.261, RSKangXi=211.7
2A61D CJK UNIFIED IDEOGRAPH-#2A61D, IRGKangXi=1534.261, RSKangXi=211.7
2A61E CJK UNIFIED IDEOGRAPH-#2A61E, IRGKangXi=1534.261, RSKangXi=211.7
2A61F CJK UNIFIED IDEOGRAPH-#2A61F, IRGKangXi=1534.261, RSKangXi=211.7
2A620 CJK UNIFIED IDEOGRAPH-#2A620, IRGKangXi=1534.261, RSKangXi=211.7
2A621 CJK UNIFIED IDEOGRAPH-#2A621, IRGKangXi=1534.261, RSKangXi=211.7
2A622 CJK UNIFIED IDEOGRAPH-#2A622, IRGKangXi=1534.261, RSKangXi=211.7
2A623 CJK UNIFIED IDEOGRAPH-#2A623, IRGKangXi=1534.261, RSKangXi=211.7
2A624 CJK UNIFIED IDEOGRAPH-#2A624, IRGKangXi=1534.261, RSKangXi=211.7
2A625 CJK UNIFIED IDEOGRAPH-#2A625, IRGKangXi=1534.270, RSKangXi=211.8
2A626 CJK UNIFIED IDEOGRAPH-#2A626, IRGKangXi=1534.280, RSKangXi=211.8
2A627 CJK UNIFIED IDEOGRAPH-#2A627, IRGKangXi=1534.300, RSKangXi=211.8
2A628 CJK UNIFIED IDEOGRAPH-#2A628, IRGKangXi=1534.340, RSKangXi=211.8
2A629 CJK UNIFIED IDEOGRAPH-#2A629, IRGKangXi=1534.360, RSKangXi=211.8
2A62A CJK UNIFIED IDEOGRAPH-#2A62A, IRGKangXi=1534.370, RSKangXi=211.8
2A62B CJK UNIFIED IDEOGRAPH-#2A62B, IRGKangXi=1534.390, RSKangXi=211.8
2A62C CJK UNIFIED IDEOGRAPH-#2A62C, IRGKangXi=1534.400, RSKangXi=211.8
2A62D CJK UNIFIED IDEOGRAPH-#2A62D, IRGKangXi=1535.020, RSKangXi=211.8
2A62E CJK UNIFIED IDEOGRAPH-#2A62E, IRGKangXi=1535.030, RSKangXi=211.8
2A62F CJK UNIFIED IDEOGRAPH-#2A62F, IRGKangXi=1535.031, RSKangXi=211.8
2A630 CJK UNIFIED IDEOGRAPH-#2A630, IRGKangXi=1535.031, RSKangXi=211.8
2A631 CJK UNIFIED IDEOGRAPH-#2A631, IRGKangXi=1535.031, RSKangXi=211.8
2A632 CJK UNIFIED IDEOGRAPH-#2A632, IRGKangXi=1535.031, RSKangXi=211.8, Def{(Cant.) to grin, smile}
2A633 CJK UNIFIED IDEOGRAPH-#2A633, IRGKangXi=1535.031, RSKangXi=211.8
2A634 CJK UNIFIED IDEOGRAPH-#2A634, IRGKangXi=1535.031, RSKangXi=211.8
2A635 CJK UNIFIED IDEOGRAPH-#2A635, IRGKangXi=1535.031, RSKangXi=211.8
2A636 CJK UNIFIED IDEOGRAPH-#2A636, IRGKangXi=1535.031, RSKangXi=211.8
2A637 CJK UNIFIED IDEOGRAPH-#2A637, IRGKangXi=1535.031, RSKangXi=211.8
2A638 CJK UNIFIED IDEOGRAPH-#2A638, IRGKangXi=1535.031, RSKangXi=211.8
2A639 CJK UNIFIED IDEOGRAPH-#2A639, IRGKangXi=1535.060, RSKangXi=211.9
2A63A CJK UNIFIED IDEOGRAPH-#2A63A, IRGKangXi=1535.070, RSKangXi=211.9
2A63B CJK UNIFIED IDEOGRAPH-#2A63B, IRGKangXi=1535.080, RSKangXi=211.9
2A63C CJK UNIFIED IDEOGRAPH-#2A63C, IRGKangXi=1535.100, RSKangXi=211.9
2A63D CJK UNIFIED IDEOGRAPH-#2A63D, IRGKangXi=1535.150, RSKangXi=211.9
2A63E CJK UNIFIED IDEOGRAPH-#2A63E, IRGKangXi=1535.170, RSKangXi=211.9
2A63F CJK UNIFIED IDEOGRAPH-#2A63F, IRGKangXi=1535.180, RSKangXi=211.9
2A640 CJK UNIFIED IDEOGRAPH-#2A640, IRGKangXi=1535.190, RSKangXi=211.9
2A641 CJK UNIFIED IDEOGRAPH-#2A641, IRGKangXi=1535.200, RSKangXi=211.9
2A642 CJK UNIFIED IDEOGRAPH-#2A642, IRGKangXi=1535.220, RSKangXi=211.9
2A643 CJK UNIFIED IDEOGRAPH-#2A643, IRGKangXi=1535.221, RSKangXi=211.9
2A644 CJK UNIFIED IDEOGRAPH-#2A644, IRGKangXi=1535.221, RSKangXi=211.9
2A645 CJK UNIFIED IDEOGRAPH-#2A645, IRGKangXi=1535.221, RSKangXi=211.9
2A646 CJK UNIFIED IDEOGRAPH-#2A646, IRGKangXi=1535.221, RSKangXi=211.9
2A647 CJK UNIFIED IDEOGRAPH-#2A647, IRGKangXi=1535.221, RSKangXi=211.9
2A648 CJK UNIFIED IDEOGRAPH-#2A648, IRGKangXi=1535.221, RSKangXi=211.9
2A649 CJK UNIFIED IDEOGRAPH-#2A649, IRGKangXi=1535.260, RSKangXi=211.10
2A64A CJK UNIFIED IDEOGRAPH-#2A64A, IRGKangXi=1535.270, RSKangXi=211.10
2A64B CJK UNIFIED IDEOGRAPH-#2A64B, IRGKangXi=1535.280, RSKangXi=211.10
2A64C CJK UNIFIED IDEOGRAPH-#2A64C, IRGKangXi=1535.290, RSKangXi=211.10
2A64D CJK UNIFIED IDEOGRAPH-#2A64D, IRGKangXi=1535.320, RSKangXi=211.10
2A64E CJK UNIFIED IDEOGRAPH-#2A64E, IRGKangXi=1535.340, RSKangXi=211.10
2A64F CJK UNIFIED IDEOGRAPH-#2A64F, IRGKangXi=1535.350, RSKangXi=211.10
2A650 CJK UNIFIED IDEOGRAPH-#2A650, IRGKangXi=1535.360, RSKangXi=211.10
2A651 CJK UNIFIED IDEOGRAPH-#2A651, IRGKangXi=1535.370, RSKangXi=211.10
2A652 CJK UNIFIED IDEOGRAPH-#2A652, IRGKangXi=1535.380, RSKangXi=211.10
2A653 CJK UNIFIED IDEOGRAPH-#2A653, IRGKangXi=1535.381, RSKangXi=211.10
2A654 CJK UNIFIED IDEOGRAPH-#2A654, IRGKangXi=1535.381, RSKangXi=211.10
2A655 CJK UNIFIED IDEOGRAPH-#2A655, IRGKangXi=1535.381, RSKangXi=211.10
2A656 CJK UNIFIED IDEOGRAPH-#2A656, IRGKangXi=1535.381, RSKangXi=211.10
2A657 CJK UNIFIED IDEOGRAPH-#2A657, IRGKangXi=1535.381, RSKangXi=211.10
2A658 CJK UNIFIED IDEOGRAPH-#2A658, IRGKangXi=1535.381, RSKangXi=211.10
2A659 CJK UNIFIED IDEOGRAPH-#2A659, IRGKangXi=1535.381, RSKangXi=211.10
2A65A CJK UNIFIED IDEOGRAPH-#2A65A, IRGKangXi=1535.381, RSKangXi=211.11
2A65B CJK UNIFIED IDEOGRAPH-#2A65B, IRGKangXi=1535.390, RSKangXi=211.11, Def{(Cant.) decayed teeth; tongue-tied}
2A65C CJK UNIFIED IDEOGRAPH-#2A65C, IRGKangXi=1536.010, RSKangXi=211.11
2A65D CJK UNIFIED IDEOGRAPH-#2A65D, IRGKangXi=1536.020, RSKangXi=211.11
2A65E CJK UNIFIED IDEOGRAPH-#2A65E, IRGKangXi=1536.030, RSKangXi=211.11
2A65F CJK UNIFIED IDEOGRAPH-#2A65F, IRGKangXi=1536.050, RSKangXi=211.11
2A660 CJK UNIFIED IDEOGRAPH-#2A660, IRGKangXi=1536.051, RSKangXi=211.11
2A661 CJK UNIFIED IDEOGRAPH-#2A661, IRGKangXi=1536.051, RSKangXi=211.11
2A662 CJK UNIFIED IDEOGRAPH-#2A662, IRGKangXi=1536.051, RSKangXi=211.11
2A663 CJK UNIFIED IDEOGRAPH-#2A663, IRGKangXi=1536.060, RSKangXi=211.12
2A664 CJK UNIFIED IDEOGRAPH-#2A664, IRGKangXi=1536.070, RSKangXi=211.12
2A665 CJK UNIFIED IDEOGRAPH-#2A665, IRGKangXi=1536.090, RSKangXi=211.12
2A666 CJK UNIFIED IDEOGRAPH-#2A666, IRGKangXi=1536.100, RSKangXi=211.12
2A667 CJK UNIFIED IDEOGRAPH-#2A667, IRGKangXi=1536.110, RSKangXi=211.12
2A668 CJK UNIFIED IDEOGRAPH-#2A668, IRGKangXi=1536.120, RSKangXi=211.12
2A669 CJK UNIFIED IDEOGRAPH-#2A669, IRGKangXi=1536.121, RSKangXi=211.12
2A66A CJK UNIFIED IDEOGRAPH-#2A66A, IRGKangXi=1536.121, RSKangXi=211.12
2A66B CJK UNIFIED IDEOGRAPH-#2A66B, IRGKangXi=1536.121, RSKangXi=211.12
2A66C CJK UNIFIED IDEOGRAPH-#2A66C, IRGKangXi=1536.121, RSKangXi=211.12
2A66D CJK UNIFIED IDEOGRAPH-#2A66D, IRGKangXi=1536.121, RSKangXi=211.12
2A66E CJK UNIFIED IDEOGRAPH-#2A66E, IRGKangXi=1536.121, RSKangXi=211.12
2A66F CJK UNIFIED IDEOGRAPH-#2A66F, IRGKangXi=1536.121, RSKangXi=211.12
2A670 CJK UNIFIED IDEOGRAPH-#2A670, IRGKangXi=1536.140, RSKangXi=211.13
2A671 CJK UNIFIED IDEOGRAPH-#2A671, IRGKangXi=1536.150, RSKangXi=211.13
2A672 CJK UNIFIED IDEOGRAPH-#2A672, IRGKangXi=1536.160, RSKangXi=211.13
2A673 CJK UNIFIED IDEOGRAPH-#2A673, IRGKangXi=1536.180, RSKangXi=211.13
2A674 CJK UNIFIED IDEOGRAPH-#2A674, IRGKangXi=1536.200, RSKangXi=211.13
2A675 CJK UNIFIED IDEOGRAPH-#2A675, IRGKangXi=1536.201, RSKangXi=211.13
2A676 CJK UNIFIED IDEOGRAPH-#2A676, IRGKangXi=1536.221, RSKangXi=211.14
2A677 CJK UNIFIED IDEOGRAPH-#2A677, IRGKangXi=1536.230, RSKangXi=211.15
2A678 CJK UNIFIED IDEOGRAPH-#2A678, IRGKangXi=1536.240, RSKangXi=211.15
2A679 CJK UNIFIED IDEOGRAPH-#2A679, IRGKangXi=1536.250, RSKangXi=211.15
2A67A CJK UNIFIED IDEOGRAPH-#2A67A, IRGKangXi=1536.251, RSKangXi=211.15
2A67B CJK UNIFIED IDEOGRAPH-#2A67B, IRGKangXi=1536.251, RSKangXi=211.15
2A67C CJK UNIFIED IDEOGRAPH-#2A67C, IRGKangXi=1536.251, RSKangXi=211.15
2A67D CJK UNIFIED IDEOGRAPH-#2A67D, IRGKangXi=1536.260, RSKangXi=211.16
2A67E CJK UNIFIED IDEOGRAPH-#2A67E, IRGKangXi=1536.261, RSKangXi=211.16
2A67F CJK UNIFIED IDEOGRAPH-#2A67F, IRGKangXi=1536.261, RSKangXi=211.16
2A680 CJK UNIFIED IDEOGRAPH-#2A680, IRGKangXi=1536.261, RSKangXi=211.16
2A681 CJK UNIFIED IDEOGRAPH-#2A681, IRGKangXi=1536.270, RSKangXi=211.17
2A682 CJK UNIFIED IDEOGRAPH-#2A682, IRGKangXi=1536.280, RSKangXi=211.17
2A683 CJK UNIFIED IDEOGRAPH-#2A683, IRGKangXi=1536.290, RSKangXi=211.17
2A684 CJK UNIFIED IDEOGRAPH-#2A684, IRGKangXi=1536.291, RSKangXi=211.17
2A685 CJK UNIFIED IDEOGRAPH-#2A685, IRGKangXi=1536.291, RSKangXi=211.18
2A686 CJK UNIFIED IDEOGRAPH-#2A686, IRGKangXi=1536.291, RSKangXi=211.19
2A687 CJK UNIFIED IDEOGRAPH-#2A687, IRGKangXi=1536.291, RSKangXi=211.19
2A688 CJK UNIFIED IDEOGRAPH-#2A688, IRGKangXi=1536.291, RSKangXi=211.19
2A689 CJK UNIFIED IDEOGRAPH-#2A689, IRGKangXi=1536.291, RSKangXi=211.19
2A68A CJK UNIFIED IDEOGRAPH-#2A68A, IRGKangXi=1536.311, RSKangXi=211.20
2A68B CJK UNIFIED IDEOGRAPH-#2A68B, IRGKangXi=1536.311, RSKangXi=211.20
2A68C CJK UNIFIED IDEOGRAPH-#2A68C, IRGKangXi=1536.311, RSKangXi=211.21
2A68D CJK UNIFIED IDEOGRAPH-#2A68D, IRGKangXi=1536.320, RSKangXi=211.25
2A68E CJK UNIFIED IDEOGRAPH-#2A68E, IRGKangXi=1536.321, RSKangXi=211.25
2A68F CJK UNIFIED IDEOGRAPH-#2A68F, IRGKangXi=1536.321, RSKangXi=211.6
2A690 CJK UNIFIED IDEOGRAPH-#2A690, IRGKangXi=1536.321, RSKangXi=211.8
2A691 CJK UNIFIED IDEOGRAPH-#2A691, IRGKangXi=1536.420, RSKangXi=212.3
2A692 CJK UNIFIED IDEOGRAPH-#2A692, IRGKangXi=1536.430, RSKangXi=212.3
2A693 CJK UNIFIED IDEOGRAPH-#2A693, IRGKangXi=1537.010, RSKangXi=212.3
2A694 CJK UNIFIED IDEOGRAPH-#2A694, IRGKangXi=1537.031, RSKangXi=212.3
2A695 CJK UNIFIED IDEOGRAPH-#2A695, IRGKangXi=1537.040, RSKangXi=212.4
2A696 CJK UNIFIED IDEOGRAPH-#2A696, IRGKangXi=1537.050, RSKangXi=212.4
2A697 CJK UNIFIED IDEOGRAPH-#2A697, IRGKangXi=1537.070, RSKangXi=212.4
2A698 CJK UNIFIED IDEOGRAPH-#2A698, IRGKangXi=1537.080, RSKangXi=212.4
2A699 CJK UNIFIED IDEOGRAPH-#2A699, IRGKangXi=1537.100, RSKangXi=212.5
2A69A CJK UNIFIED IDEOGRAPH-#2A69A, IRGKangXi=1537.101, RSKangXi=212.4
2A69B CJK UNIFIED IDEOGRAPH-#2A69B, IRGKangXi=1537.101, RSKangXi=212.4
2A69C CJK UNIFIED IDEOGRAPH-#2A69C, IRGKangXi=1537.130, RSKangXi=212.6
2A69D CJK UNIFIED IDEOGRAPH-#2A69D, IRGKangXi=1537.150, RSKangXi=212.6
2A69E CJK UNIFIED IDEOGRAPH-#2A69E, IRGKangXi=1537.170, RSKangXi=212.6
2A69F CJK UNIFIED IDEOGRAPH-#2A69F, IRGKangXi=1537.171, RSKangXi=212.6
2A6A0 CJK UNIFIED IDEOGRAPH-#2A6A0, IRGKangXi=1537.180, RSKangXi=212.7
2A6A1 CJK UNIFIED IDEOGRAPH-#2A6A1, IRGKangXi=1537.181, RSKangXi=212.7
2A6A2 CJK UNIFIED IDEOGRAPH-#2A6A2, IRGKangXi=1537.181, RSKangXi=212.9
2A6A3 CJK UNIFIED IDEOGRAPH-#2A6A3, IRGKangXi=1537.181, RSKangXi=212.11
2A6A4 CJK UNIFIED IDEOGRAPH-#2A6A4, IRGKangXi=1537.181, RSKangXi=212.11
2A6A5 CJK UNIFIED IDEOGRAPH-#2A6A5, IRGKangXi=1537.251, RSKangXi=212.48
2A6A6 CJK UNIFIED IDEOGRAPH-#2A6A6, IRGKangXi=1538.011, RSKangXi=213.0
2A6A7 CJK UNIFIED IDEOGRAPH-#2A6A7, IRGKangXi=1538.011, RSKangXi=213.5
2A6A8 CJK UNIFIED IDEOGRAPH-#2A6A8, IRGKangXi=1538.020, RSKangXi=213.2
2A6A9 CJK UNIFIED IDEOGRAPH-#2A6A9, IRGKangXi=1538.031, RSKangXi=213.3, Def{(Cant.) sound of shouting}
2A6AA CJK UNIFIED IDEOGRAPH-#2A6AA, IRGKangXi=1538.031, RSKangXi=213.3
2A6AB CJK UNIFIED IDEOGRAPH-#2A6AB, IRGKangXi=1538.031, RSKangXi=213.4
2A6AC CJK UNIFIED IDEOGRAPH-#2A6AC, IRGKangXi=1538.050, RSKangXi=213.4
2A6AD CJK UNIFIED IDEOGRAPH-#2A6AD, IRGKangXi=1538.060, RSKangXi=213.4
2A6AE CJK UNIFIED IDEOGRAPH-#2A6AE, IRGKangXi=1538.070, RSKangXi=213.4
2A6AF CJK UNIFIED IDEOGRAPH-#2A6AF, IRGKangXi=1538.080, RSKangXi=213.4
2A6B0 CJK UNIFIED IDEOGRAPH-#2A6B0, IRGKangXi=1538.090, RSKangXi=213.4
2A6B1 CJK UNIFIED IDEOGRAPH-#2A6B1, IRGKangXi=1538.100, RSKangXi=213.4
2A6B2 CJK UNIFIED IDEOGRAPH-#2A6B2, IRGKangXi=1538.101, RSKangXi=213.4
2A6B3 CJK UNIFIED IDEOGRAPH-#2A6B3, IRGKangXi=1538.101, RSKangXi=213.4
2A6B4 CJK UNIFIED IDEOGRAPH-#2A6B4, IRGKangXi=1538.101, RSKangXi=213.4
2A6B5 CJK UNIFIED IDEOGRAPH-#2A6B5, IRGKangXi=1538.101, RSKangXi=213.4
2A6B6 CJK UNIFIED IDEOGRAPH-#2A6B6, IRGKangXi=1538.120, RSKangXi=213.5
2A6B7 CJK UNIFIED IDEOGRAPH-#2A6B7, IRGKangXi=1538.130, RSKangXi=213.5
2A6B8 CJK UNIFIED IDEOGRAPH-#2A6B8, IRGKangXi=1538.140, RSKangXi=213.5
2A6B9 CJK UNIFIED IDEOGRAPH-#2A6B9, IRGKangXi=1538.150, RSKangXi=213.5
2A6BA CJK UNIFIED IDEOGRAPH-#2A6BA, IRGKangXi=1538.160, RSKangXi=213.5
2A6BB CJK UNIFIED IDEOGRAPH-#2A6BB, IRGKangXi=1538.180, RSKangXi=213.5
2A6BC CJK UNIFIED IDEOGRAPH-#2A6BC, IRGKangXi=1538.190, RSKangXi=213.5
2A6BD CJK UNIFIED IDEOGRAPH-#2A6BD, IRGKangXi=1538.191, RSKangXi=213.5
2A6BE CJK UNIFIED IDEOGRAPH-#2A6BE, IRGKangXi=1538.191, RSKangXi=213.7
2A6BF CJK UNIFIED IDEOGRAPH-#2A6BF, IRGKangXi=1538.191, RSKangXi=213.7
2A6C0 CJK UNIFIED IDEOGRAPH-#2A6C0, IRGKangXi=1538.200, RSKangXi=213.8
2A6C1 CJK UNIFIED IDEOGRAPH-#2A6C1, IRGKangXi=1538.210, RSKangXi=213.9
2A6C2 CJK UNIFIED IDEOGRAPH-#2A6C2, IRGKangXi=1538.220, RSKangXi=213.11
2A6C3 CJK UNIFIED IDEOGRAPH-#2A6C3, IRGKangXi=1538.221, RSKangXi=213.11
2A6C4 CJK UNIFIED IDEOGRAPH-#2A6C4, IRGKangXi=1538.221, RSKangXi=213.11
2A6C5 CJK UNIFIED IDEOGRAPH-#2A6C5, IRGKangXi=1538.231, RSKangXi=213.12
2A6C6 CJK UNIFIED IDEOGRAPH-#2A6C6, IRGKangXi=1538.231, RSKangXi=213.12
2A6C7 CJK UNIFIED IDEOGRAPH-#2A6C7, IRGKangXi=1538.231, RSKangXi=213.14
2A6C8 CJK UNIFIED IDEOGRAPH-#2A6C8, IRGKangXi=1538.240, RSKangXi=213.17
2A6C9 CJK UNIFIED IDEOGRAPH-#2A6C9, IRGKangXi=1538.241, RSKangXi=213.0
2A6CA CJK UNIFIED IDEOGRAPH-#2A6CA, IRGKangXi=1538.280, RSKangXi=214.4
2A6CB CJK UNIFIED IDEOGRAPH-#2A6CB, IRGKangXi=1538.320, RSKangXi=214.8
2A6CC CJK UNIFIED IDEOGRAPH-#2A6CC, IRGKangXi=1538.321, RSKangXi=214.8
2A6CD CJK UNIFIED IDEOGRAPH-#2A6CD, IRGKangXi=1538.321, RSKangXi=214.8
2A6CE CJK UNIFIED IDEOGRAPH-#2A6CE, IRGKangXi=1538.330, RSKangXi=214.9
2A6CF CJK UNIFIED IDEOGRAPH-#2A6CF, IRGKangXi=1538.340, RSKangXi=214.9
2A6D0 CJK UNIFIED IDEOGRAPH-#2A6D0, IRGKangXi=1538.370, RSKangXi=214.9
2A6D1 CJK UNIFIED IDEOGRAPH-#2A6D1, IRGKangXi=1538.380, RSKangXi=214.9
2A6D2 CJK UNIFIED IDEOGRAPH-#2A6D2, IRGKangXi=1538.390, RSKangXi=214.10
2A6D3 CJK UNIFIED IDEOGRAPH-#2A6D3, IRGKangXi=1538.410, RSKangXi=214.11
2A6D4 CJK UNIFIED IDEOGRAPH-#2A6D4, IRGKangXi=1538.420, RSKangXi=214.14
2A6D5 CJK UNIFIED IDEOGRAPH-#2A6D5, IRGKangXi=1538.430, RSKangXi=214.16
2A6D6 CJK UNIFIED IDEOGRAPH-#2A6D6, IRGKangXi=1538.440, RSKangXi=214.20
2A700 CJK UNIFIED IDEOGRAPH-#2A700
2A701 CJK UNIFIED IDEOGRAPH-#2A701
2A702 CJK UNIFIED IDEOGRAPH-#2A702
2A703 CJK UNIFIED IDEOGRAPH-#2A703
2A704 CJK UNIFIED IDEOGRAPH-#2A704
2A705 CJK UNIFIED IDEOGRAPH-#2A705
2A706 CJK UNIFIED IDEOGRAPH-#2A706
2A707 CJK UNIFIED IDEOGRAPH-#2A707
2A708 CJK UNIFIED IDEOGRAPH-#2A708
2A709 CJK UNIFIED IDEOGRAPH-#2A709
2A70A CJK UNIFIED IDEOGRAPH-#2A70A
2A70B CJK UNIFIED IDEOGRAPH-#2A70B
2A70C CJK UNIFIED IDEOGRAPH-#2A70C
2A70D CJK UNIFIED IDEOGRAPH-#2A70D
2A70E CJK UNIFIED IDEOGRAPH-#2A70E
2A70F CJK UNIFIED IDEOGRAPH-#2A70F
2A710 CJK UNIFIED IDEOGRAPH-#2A710
2A711 CJK UNIFIED IDEOGRAPH-#2A711
2A712 CJK UNIFIED IDEOGRAPH-#2A712
2A713 CJK UNIFIED IDEOGRAPH-#2A713
2A714 CJK UNIFIED IDEOGRAPH-#2A714
2A715 CJK UNIFIED IDEOGRAPH-#2A715
2A716 CJK UNIFIED IDEOGRAPH-#2A716
2A717 CJK UNIFIED IDEOGRAPH-#2A717
2A718 CJK UNIFIED IDEOGRAPH-#2A718
2A719 CJK UNIFIED IDEOGRAPH-#2A719
2A71A CJK UNIFIED IDEOGRAPH-#2A71A
2A71B CJK UNIFIED IDEOGRAPH-#2A71B
2A71C CJK UNIFIED IDEOGRAPH-#2A71C
2A71D CJK UNIFIED IDEOGRAPH-#2A71D
2A71E CJK UNIFIED IDEOGRAPH-#2A71E
2A71F CJK UNIFIED IDEOGRAPH-#2A71F
2A720 CJK UNIFIED IDEOGRAPH-#2A720
2A721 CJK UNIFIED IDEOGRAPH-#2A721
2A722 CJK UNIFIED IDEOGRAPH-#2A722
2A723 CJK UNIFIED IDEOGRAPH-#2A723
2A724 CJK UNIFIED IDEOGRAPH-#2A724
2A725 CJK UNIFIED IDEOGRAPH-#2A725
2A726 CJK UNIFIED IDEOGRAPH-#2A726
2A727 CJK UNIFIED IDEOGRAPH-#2A727
2A728 CJK UNIFIED IDEOGRAPH-#2A728
2A729 CJK UNIFIED IDEOGRAPH-#2A729
2A72A CJK UNIFIED IDEOGRAPH-#2A72A
2A72B CJK UNIFIED IDEOGRAPH-#2A72B
2A72C CJK UNIFIED IDEOGRAPH-#2A72C
2A72D CJK UNIFIED IDEOGRAPH-#2A72D
2A72E CJK UNIFIED IDEOGRAPH-#2A72E
2A72F CJK UNIFIED IDEOGRAPH-#2A72F
2A730 CJK UNIFIED IDEOGRAPH-#2A730
2A731 CJK UNIFIED IDEOGRAPH-#2A731
2A732 CJK UNIFIED IDEOGRAPH-#2A732
2A733 CJK UNIFIED IDEOGRAPH-#2A733
2A734 CJK UNIFIED IDEOGRAPH-#2A734
2A735 CJK UNIFIED IDEOGRAPH-#2A735
2A736 CJK UNIFIED IDEOGRAPH-#2A736
2A737 CJK UNIFIED IDEOGRAPH-#2A737
2A738 CJK UNIFIED IDEOGRAPH-#2A738
2A739 CJK UNIFIED IDEOGRAPH-#2A739
2A73A CJK UNIFIED IDEOGRAPH-#2A73A
2A73B CJK UNIFIED IDEOGRAPH-#2A73B
2A73C CJK UNIFIED IDEOGRAPH-#2A73C
2A73D CJK UNIFIED IDEOGRAPH-#2A73D
2A73E CJK UNIFIED IDEOGRAPH-#2A73E
2A73F CJK UNIFIED IDEOGRAPH-#2A73F
2A740 CJK UNIFIED IDEOGRAPH-#2A740
2A741 CJK UNIFIED IDEOGRAPH-#2A741
2A742 CJK UNIFIED IDEOGRAPH-#2A742
2A743 CJK UNIFIED IDEOGRAPH-#2A743
2A744 CJK UNIFIED IDEOGRAPH-#2A744
2A745 CJK UNIFIED IDEOGRAPH-#2A745
2A746 CJK UNIFIED IDEOGRAPH-#2A746
2A747 CJK UNIFIED IDEOGRAPH-#2A747
2A748 CJK UNIFIED IDEOGRAPH-#2A748
2A749 CJK UNIFIED IDEOGRAPH-#2A749
2A74A CJK UNIFIED IDEOGRAPH-#2A74A
2A74B CJK UNIFIED IDEOGRAPH-#2A74B
2A74C CJK UNIFIED IDEOGRAPH-#2A74C
2A74D CJK UNIFIED IDEOGRAPH-#2A74D
2A74E CJK UNIFIED IDEOGRAPH-#2A74E
2A74F CJK UNIFIED IDEOGRAPH-#2A74F
2A750 CJK UNIFIED IDEOGRAPH-#2A750
2A751 CJK UNIFIED IDEOGRAPH-#2A751
2A752 CJK UNIFIED IDEOGRAPH-#2A752
2A753 CJK UNIFIED IDEOGRAPH-#2A753
2A754 CJK UNIFIED IDEOGRAPH-#2A754
2A755 CJK UNIFIED IDEOGRAPH-#2A755
2A756 CJK UNIFIED IDEOGRAPH-#2A756
2A757 CJK UNIFIED IDEOGRAPH-#2A757
2A758 CJK UNIFIED IDEOGRAPH-#2A758
2A759 CJK UNIFIED IDEOGRAPH-#2A759
2A75A CJK UNIFIED IDEOGRAPH-#2A75A
2A75B CJK UNIFIED IDEOGRAPH-#2A75B
2A75C CJK UNIFIED IDEOGRAPH-#2A75C
2A75D CJK UNIFIED IDEOGRAPH-#2A75D
2A75E CJK UNIFIED IDEOGRAPH-#2A75E
2A75F CJK UNIFIED IDEOGRAPH-#2A75F
2A760 CJK UNIFIED IDEOGRAPH-#2A760
2A761 CJK UNIFIED IDEOGRAPH-#2A761
2A762 CJK UNIFIED IDEOGRAPH-#2A762
2A763 CJK UNIFIED IDEOGRAPH-#2A763
2A764 CJK UNIFIED IDEOGRAPH-#2A764
2A765 CJK UNIFIED IDEOGRAPH-#2A765
2A766 CJK UNIFIED IDEOGRAPH-#2A766
2A767 CJK UNIFIED IDEOGRAPH-#2A767
2A768 CJK UNIFIED IDEOGRAPH-#2A768
2A769 CJK UNIFIED IDEOGRAPH-#2A769
2A76A CJK UNIFIED IDEOGRAPH-#2A76A
2A76B CJK UNIFIED IDEOGRAPH-#2A76B
2A76C CJK UNIFIED IDEOGRAPH-#2A76C
2A76D CJK UNIFIED IDEOGRAPH-#2A76D
2A76E CJK UNIFIED IDEOGRAPH-#2A76E
2A76F CJK UNIFIED IDEOGRAPH-#2A76F
2A770 CJK UNIFIED IDEOGRAPH-#2A770
2A771 CJK UNIFIED IDEOGRAPH-#2A771
2A772 CJK UNIFIED IDEOGRAPH-#2A772
2A773 CJK UNIFIED IDEOGRAPH-#2A773
2A774 CJK UNIFIED IDEOGRAPH-#2A774
2A775 CJK UNIFIED IDEOGRAPH-#2A775
2A776 CJK UNIFIED IDEOGRAPH-#2A776
2A777 CJK UNIFIED IDEOGRAPH-#2A777
2A778 CJK UNIFIED IDEOGRAPH-#2A778
2A779 CJK UNIFIED IDEOGRAPH-#2A779
2A77A CJK UNIFIED IDEOGRAPH-#2A77A
2A77B CJK UNIFIED IDEOGRAPH-#2A77B
2A77C CJK UNIFIED IDEOGRAPH-#2A77C
2A77D CJK UNIFIED IDEOGRAPH-#2A77D
2A77E CJK UNIFIED IDEOGRAPH-#2A77E
2A77F CJK UNIFIED IDEOGRAPH-#2A77F
2A780 CJK UNIFIED IDEOGRAPH-#2A780
2A781 CJK UNIFIED IDEOGRAPH-#2A781
2A782 CJK UNIFIED IDEOGRAPH-#2A782
2A783 CJK UNIFIED IDEOGRAPH-#2A783
2A784 CJK UNIFIED IDEOGRAPH-#2A784
2A785 CJK UNIFIED IDEOGRAPH-#2A785
2A786 CJK UNIFIED IDEOGRAPH-#2A786
2A787 CJK UNIFIED IDEOGRAPH-#2A787
2A788 CJK UNIFIED IDEOGRAPH-#2A788
2A789 CJK UNIFIED IDEOGRAPH-#2A789
2A78A CJK UNIFIED IDEOGRAPH-#2A78A
2A78B CJK UNIFIED IDEOGRAPH-#2A78B
2A78C CJK UNIFIED IDEOGRAPH-#2A78C
2A78D CJK UNIFIED IDEOGRAPH-#2A78D
2A78E CJK UNIFIED IDEOGRAPH-#2A78E
2A78F CJK UNIFIED IDEOGRAPH-#2A78F
2A790 CJK UNIFIED IDEOGRAPH-#2A790
2A791 CJK UNIFIED IDEOGRAPH-#2A791
2A792 CJK UNIFIED IDEOGRAPH-#2A792
2A793 CJK UNIFIED IDEOGRAPH-#2A793
2A794 CJK UNIFIED IDEOGRAPH-#2A794
2A795 CJK UNIFIED IDEOGRAPH-#2A795
2A796 CJK UNIFIED IDEOGRAPH-#2A796
2A797 CJK UNIFIED IDEOGRAPH-#2A797
2A798 CJK UNIFIED IDEOGRAPH-#2A798
2A799 CJK UNIFIED IDEOGRAPH-#2A799
2A79A CJK UNIFIED IDEOGRAPH-#2A79A
2A79B CJK UNIFIED IDEOGRAPH-#2A79B
2A79C CJK UNIFIED IDEOGRAPH-#2A79C
2A79D CJK UNIFIED IDEOGRAPH-#2A79D, Def{an icicle}
2A79E CJK UNIFIED IDEOGRAPH-#2A79E
2A79F CJK UNIFIED IDEOGRAPH-#2A79F
2A7A0 CJK UNIFIED IDEOGRAPH-#2A7A0
2A7A1 CJK UNIFIED IDEOGRAPH-#2A7A1
2A7A2 CJK UNIFIED IDEOGRAPH-#2A7A2
2A7A3 CJK UNIFIED IDEOGRAPH-#2A7A3
2A7A4 CJK UNIFIED IDEOGRAPH-#2A7A4
2A7A5 CJK UNIFIED IDEOGRAPH-#2A7A5
2A7A6 CJK UNIFIED IDEOGRAPH-#2A7A6
2A7A7 CJK UNIFIED IDEOGRAPH-#2A7A7
2A7A8 CJK UNIFIED IDEOGRAPH-#2A7A8
2A7A9 CJK UNIFIED IDEOGRAPH-#2A7A9
2A7AA CJK UNIFIED IDEOGRAPH-#2A7AA
2A7AB CJK UNIFIED IDEOGRAPH-#2A7AB
2A7AC CJK UNIFIED IDEOGRAPH-#2A7AC
2A7AD CJK UNIFIED IDEOGRAPH-#2A7AD
2A7AE CJK UNIFIED IDEOGRAPH-#2A7AE
2A7AF CJK UNIFIED IDEOGRAPH-#2A7AF
2A7B0 CJK UNIFIED IDEOGRAPH-#2A7B0
2A7B1 CJK UNIFIED IDEOGRAPH-#2A7B1
2A7B2 CJK UNIFIED IDEOGRAPH-#2A7B2
2A7B3 CJK UNIFIED IDEOGRAPH-#2A7B3
2A7B4 CJK UNIFIED IDEOGRAPH-#2A7B4
2A7B5 CJK UNIFIED IDEOGRAPH-#2A7B5
2A7B6 CJK UNIFIED IDEOGRAPH-#2A7B6
2A7B7 CJK UNIFIED IDEOGRAPH-#2A7B7
2A7B8 CJK UNIFIED IDEOGRAPH-#2A7B8
2A7B9 CJK UNIFIED IDEOGRAPH-#2A7B9
2A7BA CJK UNIFIED IDEOGRAPH-#2A7BA
2A7BB CJK UNIFIED IDEOGRAPH-#2A7BB
2A7BC CJK UNIFIED IDEOGRAPH-#2A7BC
2A7BD CJK UNIFIED IDEOGRAPH-#2A7BD
2A7BE CJK UNIFIED IDEOGRAPH-#2A7BE
2A7BF CJK UNIFIED IDEOGRAPH-#2A7BF
2A7C0 CJK UNIFIED IDEOGRAPH-#2A7C0
2A7C1 CJK UNIFIED IDEOGRAPH-#2A7C1
2A7C2 CJK UNIFIED IDEOGRAPH-#2A7C2
2A7C3 CJK UNIFIED IDEOGRAPH-#2A7C3
2A7C4 CJK UNIFIED IDEOGRAPH-#2A7C4
2A7C5 CJK UNIFIED IDEOGRAPH-#2A7C5
2A7C6 CJK UNIFIED IDEOGRAPH-#2A7C6
2A7C7 CJK UNIFIED IDEOGRAPH-#2A7C7
2A7C8 CJK UNIFIED IDEOGRAPH-#2A7C8
2A7C9 CJK UNIFIED IDEOGRAPH-#2A7C9
2A7CA CJK UNIFIED IDEOGRAPH-#2A7CA
2A7CB CJK UNIFIED IDEOGRAPH-#2A7CB
2A7CC CJK UNIFIED IDEOGRAPH-#2A7CC
2A7CD CJK UNIFIED IDEOGRAPH-#2A7CD
2A7CE CJK UNIFIED IDEOGRAPH-#2A7CE
2A7CF CJK UNIFIED IDEOGRAPH-#2A7CF
2A7D0 CJK UNIFIED IDEOGRAPH-#2A7D0
2A7D1 CJK UNIFIED IDEOGRAPH-#2A7D1
2A7D2 CJK UNIFIED IDEOGRAPH-#2A7D2
2A7D3 CJK UNIFIED IDEOGRAPH-#2A7D3
2A7D4 CJK UNIFIED IDEOGRAPH-#2A7D4
2A7D5 CJK UNIFIED IDEOGRAPH-#2A7D5
2A7D6 CJK UNIFIED IDEOGRAPH-#2A7D6
2A7D7 CJK UNIFIED IDEOGRAPH-#2A7D7
2A7D8 CJK UNIFIED IDEOGRAPH-#2A7D8
2A7D9 CJK UNIFIED IDEOGRAPH-#2A7D9
2A7DA CJK UNIFIED IDEOGRAPH-#2A7DA
2A7DB CJK UNIFIED IDEOGRAPH-#2A7DB
2A7DC CJK UNIFIED IDEOGRAPH-#2A7DC
2A7DD CJK UNIFIED IDEOGRAPH-#2A7DD
2A7DE CJK UNIFIED IDEOGRAPH-#2A7DE
2A7DF CJK UNIFIED IDEOGRAPH-#2A7DF
2A7E0 CJK UNIFIED IDEOGRAPH-#2A7E0
2A7E1 CJK UNIFIED IDEOGRAPH-#2A7E1
2A7E2 CJK UNIFIED IDEOGRAPH-#2A7E2
2A7E3 CJK UNIFIED IDEOGRAPH-#2A7E3
2A7E4 CJK UNIFIED IDEOGRAPH-#2A7E4
2A7E5 CJK UNIFIED IDEOGRAPH-#2A7E5
2A7E6 CJK UNIFIED IDEOGRAPH-#2A7E6
2A7E7 CJK UNIFIED IDEOGRAPH-#2A7E7
2A7E8 CJK UNIFIED IDEOGRAPH-#2A7E8
2A7E9 CJK UNIFIED IDEOGRAPH-#2A7E9
2A7EA CJK UNIFIED IDEOGRAPH-#2A7EA
2A7EB CJK UNIFIED IDEOGRAPH-#2A7EB
2A7EC CJK UNIFIED IDEOGRAPH-#2A7EC
2A7ED CJK UNIFIED IDEOGRAPH-#2A7ED
2A7EE CJK UNIFIED IDEOGRAPH-#2A7EE
2A7EF CJK UNIFIED IDEOGRAPH-#2A7EF
2A7F0 CJK UNIFIED IDEOGRAPH-#2A7F0
2A7F1 CJK UNIFIED IDEOGRAPH-#2A7F1
2A7F2 CJK UNIFIED IDEOGRAPH-#2A7F2
2A7F3 CJK UNIFIED IDEOGRAPH-#2A7F3
2A7F4 CJK UNIFIED IDEOGRAPH-#2A7F4
2A7F5 CJK UNIFIED IDEOGRAPH-#2A7F5
2A7F6 CJK UNIFIED IDEOGRAPH-#2A7F6
2A7F7 CJK UNIFIED IDEOGRAPH-#2A7F7
2A7F8 CJK UNIFIED IDEOGRAPH-#2A7F8
2A7F9 CJK UNIFIED IDEOGRAPH-#2A7F9
2A7FA CJK UNIFIED IDEOGRAPH-#2A7FA
2A7FB CJK UNIFIED IDEOGRAPH-#2A7FB
2A7FC CJK UNIFIED IDEOGRAPH-#2A7FC
2A7FD CJK UNIFIED IDEOGRAPH-#2A7FD
2A7FE CJK UNIFIED IDEOGRAPH-#2A7FE
2A7FF CJK UNIFIED IDEOGRAPH-#2A7FF
2A800 CJK UNIFIED IDEOGRAPH-#2A800
2A801 CJK UNIFIED IDEOGRAPH-#2A801
2A802 CJK UNIFIED IDEOGRAPH-#2A802
2A803 CJK UNIFIED IDEOGRAPH-#2A803
2A804 CJK UNIFIED IDEOGRAPH-#2A804
2A805 CJK UNIFIED IDEOGRAPH-#2A805
2A806 CJK UNIFIED IDEOGRAPH-#2A806
2A807 CJK UNIFIED IDEOGRAPH-#2A807
2A808 CJK UNIFIED IDEOGRAPH-#2A808
2A809 CJK UNIFIED IDEOGRAPH-#2A809
2A80A CJK UNIFIED IDEOGRAPH-#2A80A
2A80B CJK UNIFIED IDEOGRAPH-#2A80B
2A80C CJK UNIFIED IDEOGRAPH-#2A80C
2A80D CJK UNIFIED IDEOGRAPH-#2A80D
2A80E CJK UNIFIED IDEOGRAPH-#2A80E
2A80F CJK UNIFIED IDEOGRAPH-#2A80F
2A810 CJK UNIFIED IDEOGRAPH-#2A810
2A811 CJK UNIFIED IDEOGRAPH-#2A811
2A812 CJK UNIFIED IDEOGRAPH-#2A812
2A813 CJK UNIFIED IDEOGRAPH-#2A813
2A814 CJK UNIFIED IDEOGRAPH-#2A814
2A815 CJK UNIFIED IDEOGRAPH-#2A815
2A816 CJK UNIFIED IDEOGRAPH-#2A816
2A817 CJK UNIFIED IDEOGRAPH-#2A817
2A818 CJK UNIFIED IDEOGRAPH-#2A818
2A819 CJK UNIFIED IDEOGRAPH-#2A819
2A81A CJK UNIFIED IDEOGRAPH-#2A81A
2A81B CJK UNIFIED IDEOGRAPH-#2A81B
2A81C CJK UNIFIED IDEOGRAPH-#2A81C
2A81D CJK UNIFIED IDEOGRAPH-#2A81D
2A81E CJK UNIFIED IDEOGRAPH-#2A81E
2A81F CJK UNIFIED IDEOGRAPH-#2A81F
2A820 CJK UNIFIED IDEOGRAPH-#2A820
2A821 CJK UNIFIED IDEOGRAPH-#2A821
2A822 CJK UNIFIED IDEOGRAPH-#2A822
2A823 CJK UNIFIED IDEOGRAPH-#2A823
2A824 CJK UNIFIED IDEOGRAPH-#2A824
2A825 CJK UNIFIED IDEOGRAPH-#2A825
2A826 CJK UNIFIED IDEOGRAPH-#2A826
2A827 CJK UNIFIED IDEOGRAPH-#2A827
2A828 CJK UNIFIED IDEOGRAPH-#2A828
2A829 CJK UNIFIED IDEOGRAPH-#2A829
2A82A CJK UNIFIED IDEOGRAPH-#2A82A
2A82B CJK UNIFIED IDEOGRAPH-#2A82B
2A82C CJK UNIFIED IDEOGRAPH-#2A82C
2A82D CJK UNIFIED IDEOGRAPH-#2A82D
2A82E CJK UNIFIED IDEOGRAPH-#2A82E
2A82F CJK UNIFIED IDEOGRAPH-#2A82F
2A830 CJK UNIFIED IDEOGRAPH-#2A830
2A831 CJK UNIFIED IDEOGRAPH-#2A831
2A832 CJK UNIFIED IDEOGRAPH-#2A832
2A833 CJK UNIFIED IDEOGRAPH-#2A833
2A834 CJK UNIFIED IDEOGRAPH-#2A834
2A835 CJK UNIFIED IDEOGRAPH-#2A835
2A836 CJK UNIFIED IDEOGRAPH-#2A836
2A837 CJK UNIFIED IDEOGRAPH-#2A837
2A838 CJK UNIFIED IDEOGRAPH-#2A838
2A839 CJK UNIFIED IDEOGRAPH-#2A839
2A83A CJK UNIFIED IDEOGRAPH-#2A83A
2A83B CJK UNIFIED IDEOGRAPH-#2A83B
2A83C CJK UNIFIED IDEOGRAPH-#2A83C
2A83D CJK UNIFIED IDEOGRAPH-#2A83D
2A83E CJK UNIFIED IDEOGRAPH-#2A83E
2A83F CJK UNIFIED IDEOGRAPH-#2A83F
2A840 CJK UNIFIED IDEOGRAPH-#2A840
2A841 CJK UNIFIED IDEOGRAPH-#2A841
2A842 CJK UNIFIED IDEOGRAPH-#2A842
2A843 CJK UNIFIED IDEOGRAPH-#2A843
2A844 CJK UNIFIED IDEOGRAPH-#2A844
2A845 CJK UNIFIED IDEOGRAPH-#2A845
2A846 CJK UNIFIED IDEOGRAPH-#2A846
2A847 CJK UNIFIED IDEOGRAPH-#2A847
2A848 CJK UNIFIED IDEOGRAPH-#2A848, Def{used in transliteration}
2A849 CJK UNIFIED IDEOGRAPH-#2A849
2A84A CJK UNIFIED IDEOGRAPH-#2A84A
2A84B CJK UNIFIED IDEOGRAPH-#2A84B
2A84C CJK UNIFIED IDEOGRAPH-#2A84C
2A84D CJK UNIFIED IDEOGRAPH-#2A84D
2A84E CJK UNIFIED IDEOGRAPH-#2A84E
2A84F CJK UNIFIED IDEOGRAPH-#2A84F, Def{gruel}
2A850 CJK UNIFIED IDEOGRAPH-#2A850
2A851 CJK UNIFIED IDEOGRAPH-#2A851
2A852 CJK UNIFIED IDEOGRAPH-#2A852
2A853 CJK UNIFIED IDEOGRAPH-#2A853
2A854 CJK UNIFIED IDEOGRAPH-#2A854
2A855 CJK UNIFIED IDEOGRAPH-#2A855
2A856 CJK UNIFIED IDEOGRAPH-#2A856
2A857 CJK UNIFIED IDEOGRAPH-#2A857
2A858 CJK UNIFIED IDEOGRAPH-#2A858
2A859 CJK UNIFIED IDEOGRAPH-#2A859
2A85A CJK UNIFIED IDEOGRAPH-#2A85A
2A85B CJK UNIFIED IDEOGRAPH-#2A85B
2A85C CJK UNIFIED IDEOGRAPH-#2A85C
2A85D CJK UNIFIED IDEOGRAPH-#2A85D
2A85E CJK UNIFIED IDEOGRAPH-#2A85E
2A85F CJK UNIFIED IDEOGRAPH-#2A85F
2A860 CJK UNIFIED IDEOGRAPH-#2A860
2A861 CJK UNIFIED IDEOGRAPH-#2A861
2A862 CJK UNIFIED IDEOGRAPH-#2A862
2A863 CJK UNIFIED IDEOGRAPH-#2A863
2A864 CJK UNIFIED IDEOGRAPH-#2A864
2A865 CJK UNIFIED IDEOGRAPH-#2A865
2A866 CJK UNIFIED IDEOGRAPH-#2A866
2A867 CJK UNIFIED IDEOGRAPH-#2A867
2A868 CJK UNIFIED IDEOGRAPH-#2A868
2A869 CJK UNIFIED IDEOGRAPH-#2A869
2A86A CJK UNIFIED IDEOGRAPH-#2A86A
2A86B CJK UNIFIED IDEOGRAPH-#2A86B
2A86C CJK UNIFIED IDEOGRAPH-#2A86C
2A86D CJK UNIFIED IDEOGRAPH-#2A86D
2A86E CJK UNIFIED IDEOGRAPH-#2A86E
2A86F CJK UNIFIED IDEOGRAPH-#2A86F
2A870 CJK UNIFIED IDEOGRAPH-#2A870
2A871 CJK UNIFIED IDEOGRAPH-#2A871
2A872 CJK UNIFIED IDEOGRAPH-#2A872
2A873 CJK UNIFIED IDEOGRAPH-#2A873
2A874 CJK UNIFIED IDEOGRAPH-#2A874
2A875 CJK UNIFIED IDEOGRAPH-#2A875
2A876 CJK UNIFIED IDEOGRAPH-#2A876
2A877 CJK UNIFIED IDEOGRAPH-#2A877
2A878 CJK UNIFIED IDEOGRAPH-#2A878
2A879 CJK UNIFIED IDEOGRAPH-#2A879
2A87A CJK UNIFIED IDEOGRAPH-#2A87A
2A87B CJK UNIFIED IDEOGRAPH-#2A87B
2A87C CJK UNIFIED IDEOGRAPH-#2A87C
2A87D CJK UNIFIED IDEOGRAPH-#2A87D
2A87E CJK UNIFIED IDEOGRAPH-#2A87E
2A87F CJK UNIFIED IDEOGRAPH-#2A87F
2A880 CJK UNIFIED IDEOGRAPH-#2A880
2A881 CJK UNIFIED IDEOGRAPH-#2A881
2A882 CJK UNIFIED IDEOGRAPH-#2A882
2A883 CJK UNIFIED IDEOGRAPH-#2A883
2A884 CJK UNIFIED IDEOGRAPH-#2A884
2A885 CJK UNIFIED IDEOGRAPH-#2A885
2A886 CJK UNIFIED IDEOGRAPH-#2A886
2A887 CJK UNIFIED IDEOGRAPH-#2A887
2A888 CJK UNIFIED IDEOGRAPH-#2A888
2A889 CJK UNIFIED IDEOGRAPH-#2A889
2A88A CJK UNIFIED IDEOGRAPH-#2A88A
2A88B CJK UNIFIED IDEOGRAPH-#2A88B
2A88C CJK UNIFIED IDEOGRAPH-#2A88C
2A88D CJK UNIFIED IDEOGRAPH-#2A88D
2A88E CJK UNIFIED IDEOGRAPH-#2A88E
2A88F CJK UNIFIED IDEOGRAPH-#2A88F
2A890 CJK UNIFIED IDEOGRAPH-#2A890
2A891 CJK UNIFIED IDEOGRAPH-#2A891
2A892 CJK UNIFIED IDEOGRAPH-#2A892
2A893 CJK UNIFIED IDEOGRAPH-#2A893
2A894 CJK UNIFIED IDEOGRAPH-#2A894
2A895 CJK UNIFIED IDEOGRAPH-#2A895
2A896 CJK UNIFIED IDEOGRAPH-#2A896
2A897 CJK UNIFIED IDEOGRAPH-#2A897
2A898 CJK UNIFIED IDEOGRAPH-#2A898
2A899 CJK UNIFIED IDEOGRAPH-#2A899
2A89A CJK UNIFIED IDEOGRAPH-#2A89A
2A89B CJK UNIFIED IDEOGRAPH-#2A89B
2A89C CJK UNIFIED IDEOGRAPH-#2A89C
2A89D CJK UNIFIED IDEOGRAPH-#2A89D
2A89E CJK UNIFIED IDEOGRAPH-#2A89E
2A89F CJK UNIFIED IDEOGRAPH-#2A89F
2A8A0 CJK UNIFIED IDEOGRAPH-#2A8A0
2A8A1 CJK UNIFIED IDEOGRAPH-#2A8A1
2A8A2 CJK UNIFIED IDEOGRAPH-#2A8A2
2A8A3 CJK UNIFIED IDEOGRAPH-#2A8A3
2A8A4 CJK UNIFIED IDEOGRAPH-#2A8A4
2A8A5 CJK UNIFIED IDEOGRAPH-#2A8A5
2A8A6 CJK UNIFIED IDEOGRAPH-#2A8A6
2A8A7 CJK UNIFIED IDEOGRAPH-#2A8A7
2A8A8 CJK UNIFIED IDEOGRAPH-#2A8A8
2A8A9 CJK UNIFIED IDEOGRAPH-#2A8A9
2A8AA CJK UNIFIED IDEOGRAPH-#2A8AA
2A8AB CJK UNIFIED IDEOGRAPH-#2A8AB
2A8AC CJK UNIFIED IDEOGRAPH-#2A8AC
2A8AD CJK UNIFIED IDEOGRAPH-#2A8AD
2A8AE CJK UNIFIED IDEOGRAPH-#2A8AE, Def{entire, complete; round}
2A8AF CJK UNIFIED IDEOGRAPH-#2A8AF
2A8B0 CJK UNIFIED IDEOGRAPH-#2A8B0
2A8B1 CJK UNIFIED IDEOGRAPH-#2A8B1
2A8B2 CJK UNIFIED IDEOGRAPH-#2A8B2
2A8B3 CJK UNIFIED IDEOGRAPH-#2A8B3
2A8B4 CJK UNIFIED IDEOGRAPH-#2A8B4
2A8B5 CJK UNIFIED IDEOGRAPH-#2A8B5
2A8B6 CJK UNIFIED IDEOGRAPH-#2A8B6
2A8B7 CJK UNIFIED IDEOGRAPH-#2A8B7
2A8B8 CJK UNIFIED IDEOGRAPH-#2A8B8
2A8B9 CJK UNIFIED IDEOGRAPH-#2A8B9
2A8BA CJK UNIFIED IDEOGRAPH-#2A8BA
2A8BB CJK UNIFIED IDEOGRAPH-#2A8BB
2A8BC CJK UNIFIED IDEOGRAPH-#2A8BC
2A8BD CJK UNIFIED IDEOGRAPH-#2A8BD
2A8BE CJK UNIFIED IDEOGRAPH-#2A8BE
2A8BF CJK UNIFIED IDEOGRAPH-#2A8BF
2A8C0 CJK UNIFIED IDEOGRAPH-#2A8C0
2A8C1 CJK UNIFIED IDEOGRAPH-#2A8C1
2A8C2 CJK UNIFIED IDEOGRAPH-#2A8C2
2A8C3 CJK UNIFIED IDEOGRAPH-#2A8C3
2A8C4 CJK UNIFIED IDEOGRAPH-#2A8C4
2A8C5 CJK UNIFIED IDEOGRAPH-#2A8C5
2A8C6 CJK UNIFIED IDEOGRAPH-#2A8C6
2A8C7 CJK UNIFIED IDEOGRAPH-#2A8C7
2A8C8 CJK UNIFIED IDEOGRAPH-#2A8C8
2A8C9 CJK UNIFIED IDEOGRAPH-#2A8C9
2A8CA CJK UNIFIED IDEOGRAPH-#2A8CA
2A8CB CJK UNIFIED IDEOGRAPH-#2A8CB
2A8CC CJK UNIFIED IDEOGRAPH-#2A8CC
2A8CD CJK UNIFIED IDEOGRAPH-#2A8CD
2A8CE CJK UNIFIED IDEOGRAPH-#2A8CE
2A8CF CJK UNIFIED IDEOGRAPH-#2A8CF
2A8D0 CJK UNIFIED IDEOGRAPH-#2A8D0
2A8D1 CJK UNIFIED IDEOGRAPH-#2A8D1
2A8D2 CJK UNIFIED IDEOGRAPH-#2A8D2
2A8D3 CJK UNIFIED IDEOGRAPH-#2A8D3
2A8D4 CJK UNIFIED IDEOGRAPH-#2A8D4
2A8D5 CJK UNIFIED IDEOGRAPH-#2A8D5
2A8D6 CJK UNIFIED IDEOGRAPH-#2A8D6
2A8D7 CJK UNIFIED IDEOGRAPH-#2A8D7
2A8D8 CJK UNIFIED IDEOGRAPH-#2A8D8
2A8D9 CJK UNIFIED IDEOGRAPH-#2A8D9
2A8DA CJK UNIFIED IDEOGRAPH-#2A8DA
2A8DB CJK UNIFIED IDEOGRAPH-#2A8DB
2A8DC CJK UNIFIED IDEOGRAPH-#2A8DC
2A8DD CJK UNIFIED IDEOGRAPH-#2A8DD
2A8DE CJK UNIFIED IDEOGRAPH-#2A8DE
2A8DF CJK UNIFIED IDEOGRAPH-#2A8DF
2A8E0 CJK UNIFIED IDEOGRAPH-#2A8E0
2A8E1 CJK UNIFIED IDEOGRAPH-#2A8E1
2A8E2 CJK UNIFIED IDEOGRAPH-#2A8E2
2A8E3 CJK UNIFIED IDEOGRAPH-#2A8E3
2A8E4 CJK UNIFIED IDEOGRAPH-#2A8E4
2A8E5 CJK UNIFIED IDEOGRAPH-#2A8E5
2A8E6 CJK UNIFIED IDEOGRAPH-#2A8E6
2A8E7 CJK UNIFIED IDEOGRAPH-#2A8E7
2A8E8 CJK UNIFIED IDEOGRAPH-#2A8E8
2A8E9 CJK UNIFIED IDEOGRAPH-#2A8E9
2A8EA CJK UNIFIED IDEOGRAPH-#2A8EA
2A8EB CJK UNIFIED IDEOGRAPH-#2A8EB
2A8EC CJK UNIFIED IDEOGRAPH-#2A8EC
2A8ED CJK UNIFIED IDEOGRAPH-#2A8ED
2A8EE CJK UNIFIED IDEOGRAPH-#2A8EE
2A8EF CJK UNIFIED IDEOGRAPH-#2A8EF
2A8F0 CJK UNIFIED IDEOGRAPH-#2A8F0
2A8F1 CJK UNIFIED IDEOGRAPH-#2A8F1
2A8F2 CJK UNIFIED IDEOGRAPH-#2A8F2
2A8F3 CJK UNIFIED IDEOGRAPH-#2A8F3
2A8F4 CJK UNIFIED IDEOGRAPH-#2A8F4
2A8F5 CJK UNIFIED IDEOGRAPH-#2A8F5
2A8F6 CJK UNIFIED IDEOGRAPH-#2A8F6
2A8F7 CJK UNIFIED IDEOGRAPH-#2A8F7
2A8F8 CJK UNIFIED IDEOGRAPH-#2A8F8
2A8F9 CJK UNIFIED IDEOGRAPH-#2A8F9
2A8FA CJK UNIFIED IDEOGRAPH-#2A8FA
2A8FB CJK UNIFIED IDEOGRAPH-#2A8FB
2A8FC CJK UNIFIED IDEOGRAPH-#2A8FC
2A8FD CJK UNIFIED IDEOGRAPH-#2A8FD
2A8FE CJK UNIFIED IDEOGRAPH-#2A8FE
2A8FF CJK UNIFIED IDEOGRAPH-#2A8FF
2A900 CJK UNIFIED IDEOGRAPH-#2A900
2A901 CJK UNIFIED IDEOGRAPH-#2A901
2A902 CJK UNIFIED IDEOGRAPH-#2A902
2A903 CJK UNIFIED IDEOGRAPH-#2A903
2A904 CJK UNIFIED IDEOGRAPH-#2A904
2A905 CJK UNIFIED IDEOGRAPH-#2A905
2A906 CJK UNIFIED IDEOGRAPH-#2A906
2A907 CJK UNIFIED IDEOGRAPH-#2A907
2A908 CJK UNIFIED IDEOGRAPH-#2A908
2A909 CJK UNIFIED IDEOGRAPH-#2A909
2A90A CJK UNIFIED IDEOGRAPH-#2A90A
2A90B CJK UNIFIED IDEOGRAPH-#2A90B
2A90C CJK UNIFIED IDEOGRAPH-#2A90C
2A90D CJK UNIFIED IDEOGRAPH-#2A90D
2A90E CJK UNIFIED IDEOGRAPH-#2A90E
2A90F CJK UNIFIED IDEOGRAPH-#2A90F
2A910 CJK UNIFIED IDEOGRAPH-#2A910
2A911 CJK UNIFIED IDEOGRAPH-#2A911
2A912 CJK UNIFIED IDEOGRAPH-#2A912
2A913 CJK UNIFIED IDEOGRAPH-#2A913
2A914 CJK UNIFIED IDEOGRAPH-#2A914
2A915 CJK UNIFIED IDEOGRAPH-#2A915
2A916 CJK UNIFIED IDEOGRAPH-#2A916
2A917 CJK UNIFIED IDEOGRAPH-#2A917
2A918 CJK UNIFIED IDEOGRAPH-#2A918
2A919 CJK UNIFIED IDEOGRAPH-#2A919
2A91A CJK UNIFIED IDEOGRAPH-#2A91A
2A91B CJK UNIFIED IDEOGRAPH-#2A91B
2A91C CJK UNIFIED IDEOGRAPH-#2A91C
2A91D CJK UNIFIED IDEOGRAPH-#2A91D
2A91E CJK UNIFIED IDEOGRAPH-#2A91E
2A91F CJK UNIFIED IDEOGRAPH-#2A91F
2A920 CJK UNIFIED IDEOGRAPH-#2A920
2A921 CJK UNIFIED IDEOGRAPH-#2A921
2A922 CJK UNIFIED IDEOGRAPH-#2A922
2A923 CJK UNIFIED IDEOGRAPH-#2A923
2A924 CJK UNIFIED IDEOGRAPH-#2A924
2A925 CJK UNIFIED IDEOGRAPH-#2A925
2A926 CJK UNIFIED IDEOGRAPH-#2A926
2A927 CJK UNIFIED IDEOGRAPH-#2A927
2A928 CJK UNIFIED IDEOGRAPH-#2A928
2A929 CJK UNIFIED IDEOGRAPH-#2A929
2A92A CJK UNIFIED IDEOGRAPH-#2A92A
2A92B CJK UNIFIED IDEOGRAPH-#2A92B
2A92C CJK UNIFIED IDEOGRAPH-#2A92C
2A92D CJK UNIFIED IDEOGRAPH-#2A92D
2A92E CJK UNIFIED IDEOGRAPH-#2A92E
2A92F CJK UNIFIED IDEOGRAPH-#2A92F
2A930 CJK UNIFIED IDEOGRAPH-#2A930
2A931 CJK UNIFIED IDEOGRAPH-#2A931
2A932 CJK UNIFIED IDEOGRAPH-#2A932
2A933 CJK UNIFIED IDEOGRAPH-#2A933
2A934 CJK UNIFIED IDEOGRAPH-#2A934
2A935 CJK UNIFIED IDEOGRAPH-#2A935
2A936 CJK UNIFIED IDEOGRAPH-#2A936
2A937 CJK UNIFIED IDEOGRAPH-#2A937
2A938 CJK UNIFIED IDEOGRAPH-#2A938
2A939 CJK UNIFIED IDEOGRAPH-#2A939
2A93A CJK UNIFIED IDEOGRAPH-#2A93A
2A93B CJK UNIFIED IDEOGRAPH-#2A93B
2A93C CJK UNIFIED IDEOGRAPH-#2A93C
2A93D CJK UNIFIED IDEOGRAPH-#2A93D
2A93E CJK UNIFIED IDEOGRAPH-#2A93E
2A93F CJK UNIFIED IDEOGRAPH-#2A93F
2A940 CJK UNIFIED IDEOGRAPH-#2A940
2A941 CJK UNIFIED IDEOGRAPH-#2A941
2A942 CJK UNIFIED IDEOGRAPH-#2A942
2A943 CJK UNIFIED IDEOGRAPH-#2A943
2A944 CJK UNIFIED IDEOGRAPH-#2A944
2A945 CJK UNIFIED IDEOGRAPH-#2A945
2A946 CJK UNIFIED IDEOGRAPH-#2A946
2A947 CJK UNIFIED IDEOGRAPH-#2A947
2A948 CJK UNIFIED IDEOGRAPH-#2A948
2A949 CJK UNIFIED IDEOGRAPH-#2A949
2A94A CJK UNIFIED IDEOGRAPH-#2A94A
2A94B CJK UNIFIED IDEOGRAPH-#2A94B
2A94C CJK UNIFIED IDEOGRAPH-#2A94C
2A94D CJK UNIFIED IDEOGRAPH-#2A94D
2A94E CJK UNIFIED IDEOGRAPH-#2A94E
2A94F CJK UNIFIED IDEOGRAPH-#2A94F
2A950 CJK UNIFIED IDEOGRAPH-#2A950
2A951 CJK UNIFIED IDEOGRAPH-#2A951
2A952 CJK UNIFIED IDEOGRAPH-#2A952
2A953 CJK UNIFIED IDEOGRAPH-#2A953
2A954 CJK UNIFIED IDEOGRAPH-#2A954
2A955 CJK UNIFIED IDEOGRAPH-#2A955
2A956 CJK UNIFIED IDEOGRAPH-#2A956
2A957 CJK UNIFIED IDEOGRAPH-#2A957
2A958 CJK UNIFIED IDEOGRAPH-#2A958
2A959 CJK UNIFIED IDEOGRAPH-#2A959
2A95A CJK UNIFIED IDEOGRAPH-#2A95A
2A95B CJK UNIFIED IDEOGRAPH-#2A95B
2A95C CJK UNIFIED IDEOGRAPH-#2A95C
2A95D CJK UNIFIED IDEOGRAPH-#2A95D
2A95E CJK UNIFIED IDEOGRAPH-#2A95E
2A95F CJK UNIFIED IDEOGRAPH-#2A95F
2A960 CJK UNIFIED IDEOGRAPH-#2A960
2A961 CJK UNIFIED IDEOGRAPH-#2A961
2A962 CJK UNIFIED IDEOGRAPH-#2A962
2A963 CJK UNIFIED IDEOGRAPH-#2A963
2A964 CJK UNIFIED IDEOGRAPH-#2A964
2A965 CJK UNIFIED IDEOGRAPH-#2A965
2A966 CJK UNIFIED IDEOGRAPH-#2A966
2A967 CJK UNIFIED IDEOGRAPH-#2A967
2A968 CJK UNIFIED IDEOGRAPH-#2A968
2A969 CJK UNIFIED IDEOGRAPH-#2A969
2A96A CJK UNIFIED IDEOGRAPH-#2A96A
2A96B CJK UNIFIED IDEOGRAPH-#2A96B
2A96C CJK UNIFIED IDEOGRAPH-#2A96C
2A96D CJK UNIFIED IDEOGRAPH-#2A96D
2A96E CJK UNIFIED IDEOGRAPH-#2A96E
2A96F CJK UNIFIED IDEOGRAPH-#2A96F
2A970 CJK UNIFIED IDEOGRAPH-#2A970
2A971 CJK UNIFIED IDEOGRAPH-#2A971
2A972 CJK UNIFIED IDEOGRAPH-#2A972
2A973 CJK UNIFIED IDEOGRAPH-#2A973
2A974 CJK UNIFIED IDEOGRAPH-#2A974
2A975 CJK UNIFIED IDEOGRAPH-#2A975
2A976 CJK UNIFIED IDEOGRAPH-#2A976
2A977 CJK UNIFIED IDEOGRAPH-#2A977
2A978 CJK UNIFIED IDEOGRAPH-#2A978
2A979 CJK UNIFIED IDEOGRAPH-#2A979
2A97A CJK UNIFIED IDEOGRAPH-#2A97A
2A97B CJK UNIFIED IDEOGRAPH-#2A97B
2A97C CJK UNIFIED IDEOGRAPH-#2A97C
2A97D CJK UNIFIED IDEOGRAPH-#2A97D
2A97E CJK UNIFIED IDEOGRAPH-#2A97E
2A97F CJK UNIFIED IDEOGRAPH-#2A97F
2A980 CJK UNIFIED IDEOGRAPH-#2A980
2A981 CJK UNIFIED IDEOGRAPH-#2A981
2A982 CJK UNIFIED IDEOGRAPH-#2A982
2A983 CJK UNIFIED IDEOGRAPH-#2A983
2A984 CJK UNIFIED IDEOGRAPH-#2A984
2A985 CJK UNIFIED IDEOGRAPH-#2A985
2A986 CJK UNIFIED IDEOGRAPH-#2A986
2A987 CJK UNIFIED IDEOGRAPH-#2A987
2A988 CJK UNIFIED IDEOGRAPH-#2A988
2A989 CJK UNIFIED IDEOGRAPH-#2A989
2A98A CJK UNIFIED IDEOGRAPH-#2A98A
2A98B CJK UNIFIED IDEOGRAPH-#2A98B
2A98C CJK UNIFIED IDEOGRAPH-#2A98C
2A98D CJK UNIFIED IDEOGRAPH-#2A98D
2A98E CJK UNIFIED IDEOGRAPH-#2A98E
2A98F CJK UNIFIED IDEOGRAPH-#2A98F
2A990 CJK UNIFIED IDEOGRAPH-#2A990
2A991 CJK UNIFIED IDEOGRAPH-#2A991
2A992 CJK UNIFIED IDEOGRAPH-#2A992
2A993 CJK UNIFIED IDEOGRAPH-#2A993
2A994 CJK UNIFIED IDEOGRAPH-#2A994
2A995 CJK UNIFIED IDEOGRAPH-#2A995
2A996 CJK UNIFIED IDEOGRAPH-#2A996
2A997 CJK UNIFIED IDEOGRAPH-#2A997
2A998 CJK UNIFIED IDEOGRAPH-#2A998
2A999 CJK UNIFIED IDEOGRAPH-#2A999
2A99A CJK UNIFIED IDEOGRAPH-#2A99A
2A99B CJK UNIFIED IDEOGRAPH-#2A99B
2A99C CJK UNIFIED IDEOGRAPH-#2A99C
2A99D CJK UNIFIED IDEOGRAPH-#2A99D
2A99E CJK UNIFIED IDEOGRAPH-#2A99E
2A99F CJK UNIFIED IDEOGRAPH-#2A99F
2A9A0 CJK UNIFIED IDEOGRAPH-#2A9A0
2A9A1 CJK UNIFIED IDEOGRAPH-#2A9A1
2A9A2 CJK UNIFIED IDEOGRAPH-#2A9A2
2A9A3 CJK UNIFIED IDEOGRAPH-#2A9A3
2A9A4 CJK UNIFIED IDEOGRAPH-#2A9A4
2A9A5 CJK UNIFIED IDEOGRAPH-#2A9A5
2A9A6 CJK UNIFIED IDEOGRAPH-#2A9A6
2A9A7 CJK UNIFIED IDEOGRAPH-#2A9A7
2A9A8 CJK UNIFIED IDEOGRAPH-#2A9A8
2A9A9 CJK UNIFIED IDEOGRAPH-#2A9A9
2A9AA CJK UNIFIED IDEOGRAPH-#2A9AA
2A9AB CJK UNIFIED IDEOGRAPH-#2A9AB
2A9AC CJK UNIFIED IDEOGRAPH-#2A9AC
2A9AD CJK UNIFIED IDEOGRAPH-#2A9AD
2A9AE CJK UNIFIED IDEOGRAPH-#2A9AE
2A9AF CJK UNIFIED IDEOGRAPH-#2A9AF
2A9B0 CJK UNIFIED IDEOGRAPH-#2A9B0
2A9B1 CJK UNIFIED IDEOGRAPH-#2A9B1
2A9B2 CJK UNIFIED IDEOGRAPH-#2A9B2
2A9B3 CJK UNIFIED IDEOGRAPH-#2A9B3
2A9B4 CJK UNIFIED IDEOGRAPH-#2A9B4
2A9B5 CJK UNIFIED IDEOGRAPH-#2A9B5
2A9B6 CJK UNIFIED IDEOGRAPH-#2A9B6
2A9B7 CJK UNIFIED IDEOGRAPH-#2A9B7
2A9B8 CJK UNIFIED IDEOGRAPH-#2A9B8
2A9B9 CJK UNIFIED IDEOGRAPH-#2A9B9
2A9BA CJK UNIFIED IDEOGRAPH-#2A9BA
2A9BB CJK UNIFIED IDEOGRAPH-#2A9BB
2A9BC CJK UNIFIED IDEOGRAPH-#2A9BC
2A9BD CJK UNIFIED IDEOGRAPH-#2A9BD
2A9BE CJK UNIFIED IDEOGRAPH-#2A9BE
2A9BF CJK UNIFIED IDEOGRAPH-#2A9BF
2A9C0 CJK UNIFIED IDEOGRAPH-#2A9C0
2A9C1 CJK UNIFIED IDEOGRAPH-#2A9C1
2A9C2 CJK UNIFIED IDEOGRAPH-#2A9C2
2A9C3 CJK UNIFIED IDEOGRAPH-#2A9C3
2A9C4 CJK UNIFIED IDEOGRAPH-#2A9C4
2A9C5 CJK UNIFIED IDEOGRAPH-#2A9C5
2A9C6 CJK UNIFIED IDEOGRAPH-#2A9C6
2A9C7 CJK UNIFIED IDEOGRAPH-#2A9C7
2A9C8 CJK UNIFIED IDEOGRAPH-#2A9C8
2A9C9 CJK UNIFIED IDEOGRAPH-#2A9C9
2A9CA CJK UNIFIED IDEOGRAPH-#2A9CA
2A9CB CJK UNIFIED IDEOGRAPH-#2A9CB
2A9CC CJK UNIFIED IDEOGRAPH-#2A9CC
2A9CD CJK UNIFIED IDEOGRAPH-#2A9CD
2A9CE CJK UNIFIED IDEOGRAPH-#2A9CE
2A9CF CJK UNIFIED IDEOGRAPH-#2A9CF
2A9D0 CJK UNIFIED IDEOGRAPH-#2A9D0
2A9D1 CJK UNIFIED IDEOGRAPH-#2A9D1
2A9D2 CJK UNIFIED IDEOGRAPH-#2A9D2
2A9D3 CJK UNIFIED IDEOGRAPH-#2A9D3
2A9D4 CJK UNIFIED IDEOGRAPH-#2A9D4
2A9D5 CJK UNIFIED IDEOGRAPH-#2A9D5
2A9D6 CJK UNIFIED IDEOGRAPH-#2A9D6
2A9D7 CJK UNIFIED IDEOGRAPH-#2A9D7
2A9D8 CJK UNIFIED IDEOGRAPH-#2A9D8
2A9D9 CJK UNIFIED IDEOGRAPH-#2A9D9
2A9DA CJK UNIFIED IDEOGRAPH-#2A9DA
2A9DB CJK UNIFIED IDEOGRAPH-#2A9DB
2A9DC CJK UNIFIED IDEOGRAPH-#2A9DC
2A9DD CJK UNIFIED IDEOGRAPH-#2A9DD
2A9DE CJK UNIFIED IDEOGRAPH-#2A9DE
2A9DF CJK UNIFIED IDEOGRAPH-#2A9DF
2A9E0 CJK UNIFIED IDEOGRAPH-#2A9E0
2A9E1 CJK UNIFIED IDEOGRAPH-#2A9E1
2A9E2 CJK UNIFIED IDEOGRAPH-#2A9E2
2A9E3 CJK UNIFIED IDEOGRAPH-#2A9E3
2A9E4 CJK UNIFIED IDEOGRAPH-#2A9E4
2A9E5 CJK UNIFIED IDEOGRAPH-#2A9E5
2A9E6 CJK UNIFIED IDEOGRAPH-#2A9E6
2A9E7 CJK UNIFIED IDEOGRAPH-#2A9E7
2A9E8 CJK UNIFIED IDEOGRAPH-#2A9E8
2A9E9 CJK UNIFIED IDEOGRAPH-#2A9E9
2A9EA CJK UNIFIED IDEOGRAPH-#2A9EA
2A9EB CJK UNIFIED IDEOGRAPH-#2A9EB
2A9EC CJK UNIFIED IDEOGRAPH-#2A9EC
2A9ED CJK UNIFIED IDEOGRAPH-#2A9ED
2A9EE CJK UNIFIED IDEOGRAPH-#2A9EE
2A9EF CJK UNIFIED IDEOGRAPH-#2A9EF
2A9F0 CJK UNIFIED IDEOGRAPH-#2A9F0
2A9F1 CJK UNIFIED IDEOGRAPH-#2A9F1
2A9F2 CJK UNIFIED IDEOGRAPH-#2A9F2
2A9F3 CJK UNIFIED IDEOGRAPH-#2A9F3
2A9F4 CJK UNIFIED IDEOGRAPH-#2A9F4
2A9F5 CJK UNIFIED IDEOGRAPH-#2A9F5
2A9F6 CJK UNIFIED IDEOGRAPH-#2A9F6
2A9F7 CJK UNIFIED IDEOGRAPH-#2A9F7
2A9F8 CJK UNIFIED IDEOGRAPH-#2A9F8
2A9F9 CJK UNIFIED IDEOGRAPH-#2A9F9
2A9FA CJK UNIFIED IDEOGRAPH-#2A9FA
2A9FB CJK UNIFIED IDEOGRAPH-#2A9FB
2A9FC CJK UNIFIED IDEOGRAPH-#2A9FC
2A9FD CJK UNIFIED IDEOGRAPH-#2A9FD
2A9FE CJK UNIFIED IDEOGRAPH-#2A9FE
2A9FF CJK UNIFIED IDEOGRAPH-#2A9FF
2AA00 CJK UNIFIED IDEOGRAPH-#2AA00
2AA01 CJK UNIFIED IDEOGRAPH-#2AA01
2AA02 CJK UNIFIED IDEOGRAPH-#2AA02
2AA03 CJK UNIFIED IDEOGRAPH-#2AA03
2AA04 CJK UNIFIED IDEOGRAPH-#2AA04
2AA05 CJK UNIFIED IDEOGRAPH-#2AA05
2AA06 CJK UNIFIED IDEOGRAPH-#2AA06
2AA07 CJK UNIFIED IDEOGRAPH-#2AA07
2AA08 CJK UNIFIED IDEOGRAPH-#2AA08
2AA09 CJK UNIFIED IDEOGRAPH-#2AA09
2AA0A CJK UNIFIED IDEOGRAPH-#2AA0A, Def{semen}
2AA0B CJK UNIFIED IDEOGRAPH-#2AA0B
2AA0C CJK UNIFIED IDEOGRAPH-#2AA0C
2AA0D CJK UNIFIED IDEOGRAPH-#2AA0D
2AA0E CJK UNIFIED IDEOGRAPH-#2AA0E
2AA0F CJK UNIFIED IDEOGRAPH-#2AA0F
2AA10 CJK UNIFIED IDEOGRAPH-#2AA10
2AA11 CJK UNIFIED IDEOGRAPH-#2AA11
2AA12 CJK UNIFIED IDEOGRAPH-#2AA12
2AA13 CJK UNIFIED IDEOGRAPH-#2AA13
2AA14 CJK UNIFIED IDEOGRAPH-#2AA14
2AA15 CJK UNIFIED IDEOGRAPH-#2AA15
2AA16 CJK UNIFIED IDEOGRAPH-#2AA16
2AA17 CJK UNIFIED IDEOGRAPH-#2AA17, Def{straw sandals}
2AA18 CJK UNIFIED IDEOGRAPH-#2AA18
2AA19 CJK UNIFIED IDEOGRAPH-#2AA19
2AA1A CJK UNIFIED IDEOGRAPH-#2AA1A
2AA1B CJK UNIFIED IDEOGRAPH-#2AA1B
2AA1C CJK UNIFIED IDEOGRAPH-#2AA1C
2AA1D CJK UNIFIED IDEOGRAPH-#2AA1D
2AA1E CJK UNIFIED IDEOGRAPH-#2AA1E
2AA1F CJK UNIFIED IDEOGRAPH-#2AA1F
2AA20 CJK UNIFIED IDEOGRAPH-#2AA20
2AA21 CJK UNIFIED IDEOGRAPH-#2AA21
2AA22 CJK UNIFIED IDEOGRAPH-#2AA22
2AA23 CJK UNIFIED IDEOGRAPH-#2AA23
2AA24 CJK UNIFIED IDEOGRAPH-#2AA24
2AA25 CJK UNIFIED IDEOGRAPH-#2AA25
2AA26 CJK UNIFIED IDEOGRAPH-#2AA26
2AA27 CJK UNIFIED IDEOGRAPH-#2AA27
2AA28 CJK UNIFIED IDEOGRAPH-#2AA28
2AA29 CJK UNIFIED IDEOGRAPH-#2AA29
2AA2A CJK UNIFIED IDEOGRAPH-#2AA2A
2AA2B CJK UNIFIED IDEOGRAPH-#2AA2B
2AA2C CJK UNIFIED IDEOGRAPH-#2AA2C
2AA2D CJK UNIFIED IDEOGRAPH-#2AA2D
2AA2E CJK UNIFIED IDEOGRAPH-#2AA2E
2AA2F CJK UNIFIED IDEOGRAPH-#2AA2F
2AA30 CJK UNIFIED IDEOGRAPH-#2AA30
2AA31 CJK UNIFIED IDEOGRAPH-#2AA31
2AA32 CJK UNIFIED IDEOGRAPH-#2AA32
2AA33 CJK UNIFIED IDEOGRAPH-#2AA33
2AA34 CJK UNIFIED IDEOGRAPH-#2AA34
2AA35 CJK UNIFIED IDEOGRAPH-#2AA35
2AA36 CJK UNIFIED IDEOGRAPH-#2AA36
2AA37 CJK UNIFIED IDEOGRAPH-#2AA37
2AA38 CJK UNIFIED IDEOGRAPH-#2AA38
2AA39 CJK UNIFIED IDEOGRAPH-#2AA39
2AA3A CJK UNIFIED IDEOGRAPH-#2AA3A
2AA3B CJK UNIFIED IDEOGRAPH-#2AA3B
2AA3C CJK UNIFIED IDEOGRAPH-#2AA3C
2AA3D CJK UNIFIED IDEOGRAPH-#2AA3D
2AA3E CJK UNIFIED IDEOGRAPH-#2AA3E
2AA3F CJK UNIFIED IDEOGRAPH-#2AA3F
2AA40 CJK UNIFIED IDEOGRAPH-#2AA40
2AA41 CJK UNIFIED IDEOGRAPH-#2AA41
2AA42 CJK UNIFIED IDEOGRAPH-#2AA42
2AA43 CJK UNIFIED IDEOGRAPH-#2AA43
2AA44 CJK UNIFIED IDEOGRAPH-#2AA44
2AA45 CJK UNIFIED IDEOGRAPH-#2AA45
2AA46 CJK UNIFIED IDEOGRAPH-#2AA46
2AA47 CJK UNIFIED IDEOGRAPH-#2AA47
2AA48 CJK UNIFIED IDEOGRAPH-#2AA48
2AA49 CJK UNIFIED IDEOGRAPH-#2AA49
2AA4A CJK UNIFIED IDEOGRAPH-#2AA4A
2AA4B CJK UNIFIED IDEOGRAPH-#2AA4B
2AA4C CJK UNIFIED IDEOGRAPH-#2AA4C
2AA4D CJK UNIFIED IDEOGRAPH-#2AA4D
2AA4E CJK UNIFIED IDEOGRAPH-#2AA4E
2AA4F CJK UNIFIED IDEOGRAPH-#2AA4F
2AA50 CJK UNIFIED IDEOGRAPH-#2AA50
2AA51 CJK UNIFIED IDEOGRAPH-#2AA51
2AA52 CJK UNIFIED IDEOGRAPH-#2AA52
2AA53 CJK UNIFIED IDEOGRAPH-#2AA53
2AA54 CJK UNIFIED IDEOGRAPH-#2AA54
2AA55 CJK UNIFIED IDEOGRAPH-#2AA55
2AA56 CJK UNIFIED IDEOGRAPH-#2AA56
2AA57 CJK UNIFIED IDEOGRAPH-#2AA57
2AA58 CJK UNIFIED IDEOGRAPH-#2AA58
2AA59 CJK UNIFIED IDEOGRAPH-#2AA59
2AA5A CJK UNIFIED IDEOGRAPH-#2AA5A
2AA5B CJK UNIFIED IDEOGRAPH-#2AA5B
2AA5C CJK UNIFIED IDEOGRAPH-#2AA5C
2AA5D CJK UNIFIED IDEOGRAPH-#2AA5D
2AA5E CJK UNIFIED IDEOGRAPH-#2AA5E
2AA5F CJK UNIFIED IDEOGRAPH-#2AA5F
2AA60 CJK UNIFIED IDEOGRAPH-#2AA60
2AA61 CJK UNIFIED IDEOGRAPH-#2AA61
2AA62 CJK UNIFIED IDEOGRAPH-#2AA62
2AA63 CJK UNIFIED IDEOGRAPH-#2AA63
2AA64 CJK UNIFIED IDEOGRAPH-#2AA64
2AA65 CJK UNIFIED IDEOGRAPH-#2AA65
2AA66 CJK UNIFIED IDEOGRAPH-#2AA66
2AA67 CJK UNIFIED IDEOGRAPH-#2AA67
2AA68 CJK UNIFIED IDEOGRAPH-#2AA68
2AA69 CJK UNIFIED IDEOGRAPH-#2AA69
2AA6A CJK UNIFIED IDEOGRAPH-#2AA6A
2AA6B CJK UNIFIED IDEOGRAPH-#2AA6B
2AA6C CJK UNIFIED IDEOGRAPH-#2AA6C
2AA6D CJK UNIFIED IDEOGRAPH-#2AA6D
2AA6E CJK UNIFIED IDEOGRAPH-#2AA6E
2AA6F CJK UNIFIED IDEOGRAPH-#2AA6F
2AA70 CJK UNIFIED IDEOGRAPH-#2AA70
2AA71 CJK UNIFIED IDEOGRAPH-#2AA71
2AA72 CJK UNIFIED IDEOGRAPH-#2AA72
2AA73 CJK UNIFIED IDEOGRAPH-#2AA73
2AA74 CJK UNIFIED IDEOGRAPH-#2AA74
2AA75 CJK UNIFIED IDEOGRAPH-#2AA75
2AA76 CJK UNIFIED IDEOGRAPH-#2AA76
2AA77 CJK UNIFIED IDEOGRAPH-#2AA77
2AA78 CJK UNIFIED IDEOGRAPH-#2AA78
2AA79 CJK UNIFIED IDEOGRAPH-#2AA79
2AA7A CJK UNIFIED IDEOGRAPH-#2AA7A
2AA7B CJK UNIFIED IDEOGRAPH-#2AA7B
2AA7C CJK UNIFIED IDEOGRAPH-#2AA7C
2AA7D CJK UNIFIED IDEOGRAPH-#2AA7D
2AA7E CJK UNIFIED IDEOGRAPH-#2AA7E
2AA7F CJK UNIFIED IDEOGRAPH-#2AA7F
2AA80 CJK UNIFIED IDEOGRAPH-#2AA80
2AA81 CJK UNIFIED IDEOGRAPH-#2AA81
2AA82 CJK UNIFIED IDEOGRAPH-#2AA82
2AA83 CJK UNIFIED IDEOGRAPH-#2AA83
2AA84 CJK UNIFIED IDEOGRAPH-#2AA84
2AA85 CJK UNIFIED IDEOGRAPH-#2AA85
2AA86 CJK UNIFIED IDEOGRAPH-#2AA86
2AA87 CJK UNIFIED IDEOGRAPH-#2AA87
2AA88 CJK UNIFIED IDEOGRAPH-#2AA88
2AA89 CJK UNIFIED IDEOGRAPH-#2AA89
2AA8A CJK UNIFIED IDEOGRAPH-#2AA8A
2AA8B CJK UNIFIED IDEOGRAPH-#2AA8B
2AA8C CJK UNIFIED IDEOGRAPH-#2AA8C
2AA8D CJK UNIFIED IDEOGRAPH-#2AA8D
2AA8E CJK UNIFIED IDEOGRAPH-#2AA8E
2AA8F CJK UNIFIED IDEOGRAPH-#2AA8F
2AA90 CJK UNIFIED IDEOGRAPH-#2AA90
2AA91 CJK UNIFIED IDEOGRAPH-#2AA91
2AA92 CJK UNIFIED IDEOGRAPH-#2AA92
2AA93 CJK UNIFIED IDEOGRAPH-#2AA93
2AA94 CJK UNIFIED IDEOGRAPH-#2AA94
2AA95 CJK UNIFIED IDEOGRAPH-#2AA95
2AA96 CJK UNIFIED IDEOGRAPH-#2AA96
2AA97 CJK UNIFIED IDEOGRAPH-#2AA97
2AA98 CJK UNIFIED IDEOGRAPH-#2AA98
2AA99 CJK UNIFIED IDEOGRAPH-#2AA99
2AA9A CJK UNIFIED IDEOGRAPH-#2AA9A
2AA9B CJK UNIFIED IDEOGRAPH-#2AA9B
2AA9C CJK UNIFIED IDEOGRAPH-#2AA9C
2AA9D CJK UNIFIED IDEOGRAPH-#2AA9D, Def{the Hall of Learning; a marsh, feces; harmony}
2AA9E CJK UNIFIED IDEOGRAPH-#2AA9E
2AA9F CJK UNIFIED IDEOGRAPH-#2AA9F
2AAA0 CJK UNIFIED IDEOGRAPH-#2AAA0
2AAA1 CJK UNIFIED IDEOGRAPH-#2AAA1
2AAA2 CJK UNIFIED IDEOGRAPH-#2AAA2
2AAA3 CJK UNIFIED IDEOGRAPH-#2AAA3
2AAA4 CJK UNIFIED IDEOGRAPH-#2AAA4
2AAA5 CJK UNIFIED IDEOGRAPH-#2AAA5
2AAA6 CJK UNIFIED IDEOGRAPH-#2AAA6
2AAA7 CJK UNIFIED IDEOGRAPH-#2AAA7
2AAA8 CJK UNIFIED IDEOGRAPH-#2AAA8
2AAA9 CJK UNIFIED IDEOGRAPH-#2AAA9
2AAAA CJK UNIFIED IDEOGRAPH-#2AAAA
2AAAB CJK UNIFIED IDEOGRAPH-#2AAAB
2AAAC CJK UNIFIED IDEOGRAPH-#2AAAC
2AAAD CJK UNIFIED IDEOGRAPH-#2AAAD
2AAAE CJK UNIFIED IDEOGRAPH-#2AAAE
2AAAF CJK UNIFIED IDEOGRAPH-#2AAAF
2AAB0 CJK UNIFIED IDEOGRAPH-#2AAB0
2AAB1 CJK UNIFIED IDEOGRAPH-#2AAB1
2AAB2 CJK UNIFIED IDEOGRAPH-#2AAB2
2AAB3 CJK UNIFIED IDEOGRAPH-#2AAB3
2AAB4 CJK UNIFIED IDEOGRAPH-#2AAB4
2AAB5 CJK UNIFIED IDEOGRAPH-#2AAB5
2AAB6 CJK UNIFIED IDEOGRAPH-#2AAB6
2AAB7 CJK UNIFIED IDEOGRAPH-#2AAB7
2AAB8 CJK UNIFIED IDEOGRAPH-#2AAB8
2AAB9 CJK UNIFIED IDEOGRAPH-#2AAB9
2AABA CJK UNIFIED IDEOGRAPH-#2AABA
2AABB CJK UNIFIED IDEOGRAPH-#2AABB
2AABC CJK UNIFIED IDEOGRAPH-#2AABC
2AABD CJK UNIFIED IDEOGRAPH-#2AABD
2AABE CJK UNIFIED IDEOGRAPH-#2AABE
2AABF CJK UNIFIED IDEOGRAPH-#2AABF
2AAC0 CJK UNIFIED IDEOGRAPH-#2AAC0
2AAC1 CJK UNIFIED IDEOGRAPH-#2AAC1
2AAC2 CJK UNIFIED IDEOGRAPH-#2AAC2
2AAC3 CJK UNIFIED IDEOGRAPH-#2AAC3
2AAC4 CJK UNIFIED IDEOGRAPH-#2AAC4
2AAC5 CJK UNIFIED IDEOGRAPH-#2AAC5
2AAC6 CJK UNIFIED IDEOGRAPH-#2AAC6
2AAC7 CJK UNIFIED IDEOGRAPH-#2AAC7
2AAC8 CJK UNIFIED IDEOGRAPH-#2AAC8
2AAC9 CJK UNIFIED IDEOGRAPH-#2AAC9
2AACA CJK UNIFIED IDEOGRAPH-#2AACA
2AACB CJK UNIFIED IDEOGRAPH-#2AACB
2AACC CJK UNIFIED IDEOGRAPH-#2AACC
2AACD CJK UNIFIED IDEOGRAPH-#2AACD
2AACE CJK UNIFIED IDEOGRAPH-#2AACE
2AACF CJK UNIFIED IDEOGRAPH-#2AACF
2AAD0 CJK UNIFIED IDEOGRAPH-#2AAD0
2AAD1 CJK UNIFIED IDEOGRAPH-#2AAD1
2AAD2 CJK UNIFIED IDEOGRAPH-#2AAD2
2AAD3 CJK UNIFIED IDEOGRAPH-#2AAD3
2AAD4 CJK UNIFIED IDEOGRAPH-#2AAD4
2AAD5 CJK UNIFIED IDEOGRAPH-#2AAD5
2AAD6 CJK UNIFIED IDEOGRAPH-#2AAD6
2AAD7 CJK UNIFIED IDEOGRAPH-#2AAD7
2AAD8 CJK UNIFIED IDEOGRAPH-#2AAD8
2AAD9 CJK UNIFIED IDEOGRAPH-#2AAD9
2AADA CJK UNIFIED IDEOGRAPH-#2AADA
2AADB CJK UNIFIED IDEOGRAPH-#2AADB
2AADC CJK UNIFIED IDEOGRAPH-#2AADC
2AADD CJK UNIFIED IDEOGRAPH-#2AADD
2AADE CJK UNIFIED IDEOGRAPH-#2AADE
2AADF CJK UNIFIED IDEOGRAPH-#2AADF
2AAE0 CJK UNIFIED IDEOGRAPH-#2AAE0
2AAE1 CJK UNIFIED IDEOGRAPH-#2AAE1
2AAE2 CJK UNIFIED IDEOGRAPH-#2AAE2
2AAE3 CJK UNIFIED IDEOGRAPH-#2AAE3
2AAE4 CJK UNIFIED IDEOGRAPH-#2AAE4
2AAE5 CJK UNIFIED IDEOGRAPH-#2AAE5
2AAE6 CJK UNIFIED IDEOGRAPH-#2AAE6
2AAE7 CJK UNIFIED IDEOGRAPH-#2AAE7
2AAE8 CJK UNIFIED IDEOGRAPH-#2AAE8
2AAE9 CJK UNIFIED IDEOGRAPH-#2AAE9
2AAEA CJK UNIFIED IDEOGRAPH-#2AAEA
2AAEB CJK UNIFIED IDEOGRAPH-#2AAEB
2AAEC CJK UNIFIED IDEOGRAPH-#2AAEC
2AAED CJK UNIFIED IDEOGRAPH-#2AAED
2AAEE CJK UNIFIED IDEOGRAPH-#2AAEE
2AAEF CJK UNIFIED IDEOGRAPH-#2AAEF
2AAF0 CJK UNIFIED IDEOGRAPH-#2AAF0
2AAF1 CJK UNIFIED IDEOGRAPH-#2AAF1
2AAF2 CJK UNIFIED IDEOGRAPH-#2AAF2
2AAF3 CJK UNIFIED IDEOGRAPH-#2AAF3
2AAF4 CJK UNIFIED IDEOGRAPH-#2AAF4
2AAF5 CJK UNIFIED IDEOGRAPH-#2AAF5
2AAF6 CJK UNIFIED IDEOGRAPH-#2AAF6
2AAF7 CJK UNIFIED IDEOGRAPH-#2AAF7
2AAF8 CJK UNIFIED IDEOGRAPH-#2AAF8
2AAF9 CJK UNIFIED IDEOGRAPH-#2AAF9
2AAFA CJK UNIFIED IDEOGRAPH-#2AAFA
2AAFB CJK UNIFIED IDEOGRAPH-#2AAFB
2AAFC CJK UNIFIED IDEOGRAPH-#2AAFC
2AAFD CJK UNIFIED IDEOGRAPH-#2AAFD
2AAFE CJK UNIFIED IDEOGRAPH-#2AAFE
2AAFF CJK UNIFIED IDEOGRAPH-#2AAFF
2AB00 CJK UNIFIED IDEOGRAPH-#2AB00
2AB01 CJK UNIFIED IDEOGRAPH-#2AB01
2AB02 CJK UNIFIED IDEOGRAPH-#2AB02
2AB03 CJK UNIFIED IDEOGRAPH-#2AB03
2AB04 CJK UNIFIED IDEOGRAPH-#2AB04
2AB05 CJK UNIFIED IDEOGRAPH-#2AB05
2AB06 CJK UNIFIED IDEOGRAPH-#2AB06
2AB07 CJK UNIFIED IDEOGRAPH-#2AB07
2AB08 CJK UNIFIED IDEOGRAPH-#2AB08
2AB09 CJK UNIFIED IDEOGRAPH-#2AB09
2AB0A CJK UNIFIED IDEOGRAPH-#2AB0A
2AB0B CJK UNIFIED IDEOGRAPH-#2AB0B
2AB0C CJK UNIFIED IDEOGRAPH-#2AB0C
2AB0D CJK UNIFIED IDEOGRAPH-#2AB0D
2AB0E CJK UNIFIED IDEOGRAPH-#2AB0E
2AB0F CJK UNIFIED IDEOGRAPH-#2AB0F
2AB10 CJK UNIFIED IDEOGRAPH-#2AB10
2AB11 CJK UNIFIED IDEOGRAPH-#2AB11
2AB12 CJK UNIFIED IDEOGRAPH-#2AB12
2AB13 CJK UNIFIED IDEOGRAPH-#2AB13
2AB14 CJK UNIFIED IDEOGRAPH-#2AB14
2AB15 CJK UNIFIED IDEOGRAPH-#2AB15
2AB16 CJK UNIFIED IDEOGRAPH-#2AB16
2AB17 CJK UNIFIED IDEOGRAPH-#2AB17
2AB18 CJK UNIFIED IDEOGRAPH-#2AB18
2AB19 CJK UNIFIED IDEOGRAPH-#2AB19
2AB1A CJK UNIFIED IDEOGRAPH-#2AB1A
2AB1B CJK UNIFIED IDEOGRAPH-#2AB1B
2AB1C CJK UNIFIED IDEOGRAPH-#2AB1C
2AB1D CJK UNIFIED IDEOGRAPH-#2AB1D
2AB1E CJK UNIFIED IDEOGRAPH-#2AB1E
2AB1F CJK UNIFIED IDEOGRAPH-#2AB1F
2AB20 CJK UNIFIED IDEOGRAPH-#2AB20
2AB21 CJK UNIFIED IDEOGRAPH-#2AB21
2AB22 CJK UNIFIED IDEOGRAPH-#2AB22
2AB23 CJK UNIFIED IDEOGRAPH-#2AB23
2AB24 CJK UNIFIED IDEOGRAPH-#2AB24
2AB25 CJK UNIFIED IDEOGRAPH-#2AB25
2AB26 CJK UNIFIED IDEOGRAPH-#2AB26
2AB27 CJK UNIFIED IDEOGRAPH-#2AB27
2AB28 CJK UNIFIED IDEOGRAPH-#2AB28
2AB29 CJK UNIFIED IDEOGRAPH-#2AB29
2AB2A CJK UNIFIED IDEOGRAPH-#2AB2A
2AB2B CJK UNIFIED IDEOGRAPH-#2AB2B
2AB2C CJK UNIFIED IDEOGRAPH-#2AB2C
2AB2D CJK UNIFIED IDEOGRAPH-#2AB2D
2AB2E CJK UNIFIED IDEOGRAPH-#2AB2E
2AB2F CJK UNIFIED IDEOGRAPH-#2AB2F
2AB30 CJK UNIFIED IDEOGRAPH-#2AB30
2AB31 CJK UNIFIED IDEOGRAPH-#2AB31
2AB32 CJK UNIFIED IDEOGRAPH-#2AB32
2AB33 CJK UNIFIED IDEOGRAPH-#2AB33
2AB34 CJK UNIFIED IDEOGRAPH-#2AB34
2AB35 CJK UNIFIED IDEOGRAPH-#2AB35
2AB36 CJK UNIFIED IDEOGRAPH-#2AB36
2AB37 CJK UNIFIED IDEOGRAPH-#2AB37
2AB38 CJK UNIFIED IDEOGRAPH-#2AB38
2AB39 CJK UNIFIED IDEOGRAPH-#2AB39
2AB3A CJK UNIFIED IDEOGRAPH-#2AB3A
2AB3B CJK UNIFIED IDEOGRAPH-#2AB3B
2AB3C CJK UNIFIED IDEOGRAPH-#2AB3C
2AB3D CJK UNIFIED IDEOGRAPH-#2AB3D
2AB3E CJK UNIFIED IDEOGRAPH-#2AB3E
2AB3F CJK UNIFIED IDEOGRAPH-#2AB3F
2AB40 CJK UNIFIED IDEOGRAPH-#2AB40
2AB41 CJK UNIFIED IDEOGRAPH-#2AB41
2AB42 CJK UNIFIED IDEOGRAPH-#2AB42
2AB43 CJK UNIFIED IDEOGRAPH-#2AB43
2AB44 CJK UNIFIED IDEOGRAPH-#2AB44
2AB45 CJK UNIFIED IDEOGRAPH-#2AB45
2AB46 CJK UNIFIED IDEOGRAPH-#2AB46
2AB47 CJK UNIFIED IDEOGRAPH-#2AB47
2AB48 CJK UNIFIED IDEOGRAPH-#2AB48
2AB49 CJK UNIFIED IDEOGRAPH-#2AB49
2AB4A CJK UNIFIED IDEOGRAPH-#2AB4A
2AB4B CJK UNIFIED IDEOGRAPH-#2AB4B
2AB4C CJK UNIFIED IDEOGRAPH-#2AB4C
2AB4D CJK UNIFIED IDEOGRAPH-#2AB4D
2AB4E CJK UNIFIED IDEOGRAPH-#2AB4E
2AB4F CJK UNIFIED IDEOGRAPH-#2AB4F
2AB50 CJK UNIFIED IDEOGRAPH-#2AB50
2AB51 CJK UNIFIED IDEOGRAPH-#2AB51
2AB52 CJK UNIFIED IDEOGRAPH-#2AB52
2AB53 CJK UNIFIED IDEOGRAPH-#2AB53
2AB54 CJK UNIFIED IDEOGRAPH-#2AB54
2AB55 CJK UNIFIED IDEOGRAPH-#2AB55
2AB56 CJK UNIFIED IDEOGRAPH-#2AB56
2AB57 CJK UNIFIED IDEOGRAPH-#2AB57
2AB58 CJK UNIFIED IDEOGRAPH-#2AB58
2AB59 CJK UNIFIED IDEOGRAPH-#2AB59
2AB5A CJK UNIFIED IDEOGRAPH-#2AB5A
2AB5B CJK UNIFIED IDEOGRAPH-#2AB5B
2AB5C CJK UNIFIED IDEOGRAPH-#2AB5C
2AB5D CJK UNIFIED IDEOGRAPH-#2AB5D
2AB5E CJK UNIFIED IDEOGRAPH-#2AB5E
2AB5F CJK UNIFIED IDEOGRAPH-#2AB5F
2AB60 CJK UNIFIED IDEOGRAPH-#2AB60
2AB61 CJK UNIFIED IDEOGRAPH-#2AB61
2AB62 CJK UNIFIED IDEOGRAPH-#2AB62
2AB63 CJK UNIFIED IDEOGRAPH-#2AB63
2AB64 CJK UNIFIED IDEOGRAPH-#2AB64
2AB65 CJK UNIFIED IDEOGRAPH-#2AB65
2AB66 CJK UNIFIED IDEOGRAPH-#2AB66
2AB67 CJK UNIFIED IDEOGRAPH-#2AB67
2AB68 CJK UNIFIED IDEOGRAPH-#2AB68
2AB69 CJK UNIFIED IDEOGRAPH-#2AB69
2AB6A CJK UNIFIED IDEOGRAPH-#2AB6A
2AB6B CJK UNIFIED IDEOGRAPH-#2AB6B
2AB6C CJK UNIFIED IDEOGRAPH-#2AB6C
2AB6D CJK UNIFIED IDEOGRAPH-#2AB6D
2AB6E CJK UNIFIED IDEOGRAPH-#2AB6E
2AB6F CJK UNIFIED IDEOGRAPH-#2AB6F
2AB70 CJK UNIFIED IDEOGRAPH-#2AB70
2AB71 CJK UNIFIED IDEOGRAPH-#2AB71
2AB72 CJK UNIFIED IDEOGRAPH-#2AB72
2AB73 CJK UNIFIED IDEOGRAPH-#2AB73
2AB74 CJK UNIFIED IDEOGRAPH-#2AB74
2AB75 CJK UNIFIED IDEOGRAPH-#2AB75
2AB76 CJK UNIFIED IDEOGRAPH-#2AB76
2AB77 CJK UNIFIED IDEOGRAPH-#2AB77
2AB78 CJK UNIFIED IDEOGRAPH-#2AB78
2AB79 CJK UNIFIED IDEOGRAPH-#2AB79
2AB7A CJK UNIFIED IDEOGRAPH-#2AB7A
2AB7B CJK UNIFIED IDEOGRAPH-#2AB7B
2AB7C CJK UNIFIED IDEOGRAPH-#2AB7C
2AB7D CJK UNIFIED IDEOGRAPH-#2AB7D
2AB7E CJK UNIFIED IDEOGRAPH-#2AB7E
2AB7F CJK UNIFIED IDEOGRAPH-#2AB7F
2AB80 CJK UNIFIED IDEOGRAPH-#2AB80
2AB81 CJK UNIFIED IDEOGRAPH-#2AB81
2AB82 CJK UNIFIED IDEOGRAPH-#2AB82
2AB83 CJK UNIFIED IDEOGRAPH-#2AB83
2AB84 CJK UNIFIED IDEOGRAPH-#2AB84
2AB85 CJK UNIFIED IDEOGRAPH-#2AB85
2AB86 CJK UNIFIED IDEOGRAPH-#2AB86
2AB87 CJK UNIFIED IDEOGRAPH-#2AB87
2AB88 CJK UNIFIED IDEOGRAPH-#2AB88
2AB89 CJK UNIFIED IDEOGRAPH-#2AB89
2AB8A CJK UNIFIED IDEOGRAPH-#2AB8A
2AB8B CJK UNIFIED IDEOGRAPH-#2AB8B
2AB8C CJK UNIFIED IDEOGRAPH-#2AB8C
2AB8D CJK UNIFIED IDEOGRAPH-#2AB8D
2AB8E CJK UNIFIED IDEOGRAPH-#2AB8E
2AB8F CJK UNIFIED IDEOGRAPH-#2AB8F
2AB90 CJK UNIFIED IDEOGRAPH-#2AB90
2AB91 CJK UNIFIED IDEOGRAPH-#2AB91
2AB92 CJK UNIFIED IDEOGRAPH-#2AB92
2AB93 CJK UNIFIED IDEOGRAPH-#2AB93
2AB94 CJK UNIFIED IDEOGRAPH-#2AB94
2AB95 CJK UNIFIED IDEOGRAPH-#2AB95
2AB96 CJK UNIFIED IDEOGRAPH-#2AB96
2AB97 CJK UNIFIED IDEOGRAPH-#2AB97
2AB98 CJK UNIFIED IDEOGRAPH-#2AB98
2AB99 CJK UNIFIED IDEOGRAPH-#2AB99
2AB9A CJK UNIFIED IDEOGRAPH-#2AB9A
2AB9B CJK UNIFIED IDEOGRAPH-#2AB9B
2AB9C CJK UNIFIED IDEOGRAPH-#2AB9C
2AB9D CJK UNIFIED IDEOGRAPH-#2AB9D
2AB9E CJK UNIFIED IDEOGRAPH-#2AB9E
2AB9F CJK UNIFIED IDEOGRAPH-#2AB9F
2ABA0 CJK UNIFIED IDEOGRAPH-#2ABA0
2ABA1 CJK UNIFIED IDEOGRAPH-#2ABA1
2ABA2 CJK UNIFIED IDEOGRAPH-#2ABA2
2ABA3 CJK UNIFIED IDEOGRAPH-#2ABA3
2ABA4 CJK UNIFIED IDEOGRAPH-#2ABA4
2ABA5 CJK UNIFIED IDEOGRAPH-#2ABA5
2ABA6 CJK UNIFIED IDEOGRAPH-#2ABA6
2ABA7 CJK UNIFIED IDEOGRAPH-#2ABA7
2ABA8 CJK UNIFIED IDEOGRAPH-#2ABA8
2ABA9 CJK UNIFIED IDEOGRAPH-#2ABA9
2ABAA CJK UNIFIED IDEOGRAPH-#2ABAA
2ABAB CJK UNIFIED IDEOGRAPH-#2ABAB
2ABAC CJK UNIFIED IDEOGRAPH-#2ABAC
2ABAD CJK UNIFIED IDEOGRAPH-#2ABAD
2ABAE CJK UNIFIED IDEOGRAPH-#2ABAE
2ABAF CJK UNIFIED IDEOGRAPH-#2ABAF
2ABB0 CJK UNIFIED IDEOGRAPH-#2ABB0
2ABB1 CJK UNIFIED IDEOGRAPH-#2ABB1
2ABB2 CJK UNIFIED IDEOGRAPH-#2ABB2
2ABB3 CJK UNIFIED IDEOGRAPH-#2ABB3
2ABB4 CJK UNIFIED IDEOGRAPH-#2ABB4
2ABB5 CJK UNIFIED IDEOGRAPH-#2ABB5
2ABB6 CJK UNIFIED IDEOGRAPH-#2ABB6
2ABB7 CJK UNIFIED IDEOGRAPH-#2ABB7
2ABB8 CJK UNIFIED IDEOGRAPH-#2ABB8
2ABB9 CJK UNIFIED IDEOGRAPH-#2ABB9
2ABBA CJK UNIFIED IDEOGRAPH-#2ABBA
2ABBB CJK UNIFIED IDEOGRAPH-#2ABBB
2ABBC CJK UNIFIED IDEOGRAPH-#2ABBC
2ABBD CJK UNIFIED IDEOGRAPH-#2ABBD
2ABBE CJK UNIFIED IDEOGRAPH-#2ABBE
2ABBF CJK UNIFIED IDEOGRAPH-#2ABBF
2ABC0 CJK UNIFIED IDEOGRAPH-#2ABC0
2ABC1 CJK UNIFIED IDEOGRAPH-#2ABC1
2ABC2 CJK UNIFIED IDEOGRAPH-#2ABC2
2ABC3 CJK UNIFIED IDEOGRAPH-#2ABC3
2ABC4 CJK UNIFIED IDEOGRAPH-#2ABC4
2ABC5 CJK UNIFIED IDEOGRAPH-#2ABC5
2ABC6 CJK UNIFIED IDEOGRAPH-#2ABC6
2ABC7 CJK UNIFIED IDEOGRAPH-#2ABC7
2ABC8 CJK UNIFIED IDEOGRAPH-#2ABC8
2ABC9 CJK UNIFIED IDEOGRAPH-#2ABC9
2ABCA CJK UNIFIED IDEOGRAPH-#2ABCA
2ABCB CJK UNIFIED IDEOGRAPH-#2ABCB
2ABCC CJK UNIFIED IDEOGRAPH-#2ABCC
2ABCD CJK UNIFIED IDEOGRAPH-#2ABCD
2ABCE CJK UNIFIED IDEOGRAPH-#2ABCE
2ABCF CJK UNIFIED IDEOGRAPH-#2ABCF
2ABD0 CJK UNIFIED IDEOGRAPH-#2ABD0
2ABD1 CJK UNIFIED IDEOGRAPH-#2ABD1
2ABD2 CJK UNIFIED IDEOGRAPH-#2ABD2
2ABD3 CJK UNIFIED IDEOGRAPH-#2ABD3
2ABD4 CJK UNIFIED IDEOGRAPH-#2ABD4
2ABD5 CJK UNIFIED IDEOGRAPH-#2ABD5
2ABD6 CJK UNIFIED IDEOGRAPH-#2ABD6
2ABD7 CJK UNIFIED IDEOGRAPH-#2ABD7
2ABD8 CJK UNIFIED IDEOGRAPH-#2ABD8
2ABD9 CJK UNIFIED IDEOGRAPH-#2ABD9
2ABDA CJK UNIFIED IDEOGRAPH-#2ABDA
2ABDB CJK UNIFIED IDEOGRAPH-#2ABDB
2ABDC CJK UNIFIED IDEOGRAPH-#2ABDC
2ABDD CJK UNIFIED IDEOGRAPH-#2ABDD
2ABDE CJK UNIFIED IDEOGRAPH-#2ABDE
2ABDF CJK UNIFIED IDEOGRAPH-#2ABDF
2ABE0 CJK UNIFIED IDEOGRAPH-#2ABE0
2ABE1 CJK UNIFIED IDEOGRAPH-#2ABE1
2ABE2 CJK UNIFIED IDEOGRAPH-#2ABE2
2ABE3 CJK UNIFIED IDEOGRAPH-#2ABE3
2ABE4 CJK UNIFIED IDEOGRAPH-#2ABE4
2ABE5 CJK UNIFIED IDEOGRAPH-#2ABE5
2ABE6 CJK UNIFIED IDEOGRAPH-#2ABE6
2ABE7 CJK UNIFIED IDEOGRAPH-#2ABE7
2ABE8 CJK UNIFIED IDEOGRAPH-#2ABE8
2ABE9 CJK UNIFIED IDEOGRAPH-#2ABE9
2ABEA CJK UNIFIED IDEOGRAPH-#2ABEA
2ABEB CJK UNIFIED IDEOGRAPH-#2ABEB
2ABEC CJK UNIFIED IDEOGRAPH-#2ABEC
2ABED CJK UNIFIED IDEOGRAPH-#2ABED
2ABEE CJK UNIFIED IDEOGRAPH-#2ABEE
2ABEF CJK UNIFIED IDEOGRAPH-#2ABEF
2ABF0 CJK UNIFIED IDEOGRAPH-#2ABF0
2ABF1 CJK UNIFIED IDEOGRAPH-#2ABF1
2ABF2 CJK UNIFIED IDEOGRAPH-#2ABF2
2ABF3 CJK UNIFIED IDEOGRAPH-#2ABF3
2ABF4 CJK UNIFIED IDEOGRAPH-#2ABF4
2ABF5 CJK UNIFIED IDEOGRAPH-#2ABF5
2ABF6 CJK UNIFIED IDEOGRAPH-#2ABF6
2ABF7 CJK UNIFIED IDEOGRAPH-#2ABF7
2ABF8 CJK UNIFIED IDEOGRAPH-#2ABF8
2ABF9 CJK UNIFIED IDEOGRAPH-#2ABF9
2ABFA CJK UNIFIED IDEOGRAPH-#2ABFA
2ABFB CJK UNIFIED IDEOGRAPH-#2ABFB
2ABFC CJK UNIFIED IDEOGRAPH-#2ABFC
2ABFD CJK UNIFIED IDEOGRAPH-#2ABFD
2ABFE CJK UNIFIED IDEOGRAPH-#2ABFE
2ABFF CJK UNIFIED IDEOGRAPH-#2ABFF
2AC00 CJK UNIFIED IDEOGRAPH-#2AC00
2AC01 CJK UNIFIED IDEOGRAPH-#2AC01
2AC02 CJK UNIFIED IDEOGRAPH-#2AC02
2AC03 CJK UNIFIED IDEOGRAPH-#2AC03
2AC04 CJK UNIFIED IDEOGRAPH-#2AC04
2AC05 CJK UNIFIED IDEOGRAPH-#2AC05
2AC06 CJK UNIFIED IDEOGRAPH-#2AC06
2AC07 CJK UNIFIED IDEOGRAPH-#2AC07
2AC08 CJK UNIFIED IDEOGRAPH-#2AC08
2AC09 CJK UNIFIED IDEOGRAPH-#2AC09
2AC0A CJK UNIFIED IDEOGRAPH-#2AC0A
2AC0B CJK UNIFIED IDEOGRAPH-#2AC0B
2AC0C CJK UNIFIED IDEOGRAPH-#2AC0C
2AC0D CJK UNIFIED IDEOGRAPH-#2AC0D
2AC0E CJK UNIFIED IDEOGRAPH-#2AC0E
2AC0F CJK UNIFIED IDEOGRAPH-#2AC0F
2AC10 CJK UNIFIED IDEOGRAPH-#2AC10
2AC11 CJK UNIFIED IDEOGRAPH-#2AC11
2AC12 CJK UNIFIED IDEOGRAPH-#2AC12
2AC13 CJK UNIFIED IDEOGRAPH-#2AC13
2AC14 CJK UNIFIED IDEOGRAPH-#2AC14
2AC15 CJK UNIFIED IDEOGRAPH-#2AC15
2AC16 CJK UNIFIED IDEOGRAPH-#2AC16
2AC17 CJK UNIFIED IDEOGRAPH-#2AC17
2AC18 CJK UNIFIED IDEOGRAPH-#2AC18
2AC19 CJK UNIFIED IDEOGRAPH-#2AC19
2AC1A CJK UNIFIED IDEOGRAPH-#2AC1A
2AC1B CJK UNIFIED IDEOGRAPH-#2AC1B
2AC1C CJK UNIFIED IDEOGRAPH-#2AC1C
2AC1D CJK UNIFIED IDEOGRAPH-#2AC1D
2AC1E CJK UNIFIED IDEOGRAPH-#2AC1E
2AC1F CJK UNIFIED IDEOGRAPH-#2AC1F
2AC20 CJK UNIFIED IDEOGRAPH-#2AC20
2AC21 CJK UNIFIED IDEOGRAPH-#2AC21
2AC22 CJK UNIFIED IDEOGRAPH-#2AC22
2AC23 CJK UNIFIED IDEOGRAPH-#2AC23
2AC24 CJK UNIFIED IDEOGRAPH-#2AC24
2AC25 CJK UNIFIED IDEOGRAPH-#2AC25
2AC26 CJK UNIFIED IDEOGRAPH-#2AC26
2AC27 CJK UNIFIED IDEOGRAPH-#2AC27
2AC28 CJK UNIFIED IDEOGRAPH-#2AC28
2AC29 CJK UNIFIED IDEOGRAPH-#2AC29
2AC2A CJK UNIFIED IDEOGRAPH-#2AC2A
2AC2B CJK UNIFIED IDEOGRAPH-#2AC2B
2AC2C CJK UNIFIED IDEOGRAPH-#2AC2C
2AC2D CJK UNIFIED IDEOGRAPH-#2AC2D
2AC2E CJK UNIFIED IDEOGRAPH-#2AC2E
2AC2F CJK UNIFIED IDEOGRAPH-#2AC2F
2AC30 CJK UNIFIED IDEOGRAPH-#2AC30
2AC31 CJK UNIFIED IDEOGRAPH-#2AC31
2AC32 CJK UNIFIED IDEOGRAPH-#2AC32
2AC33 CJK UNIFIED IDEOGRAPH-#2AC33
2AC34 CJK UNIFIED IDEOGRAPH-#2AC34
2AC35 CJK UNIFIED IDEOGRAPH-#2AC35
2AC36 CJK UNIFIED IDEOGRAPH-#2AC36
2AC37 CJK UNIFIED IDEOGRAPH-#2AC37
2AC38 CJK UNIFIED IDEOGRAPH-#2AC38
2AC39 CJK UNIFIED IDEOGRAPH-#2AC39
2AC3A CJK UNIFIED IDEOGRAPH-#2AC3A
2AC3B CJK UNIFIED IDEOGRAPH-#2AC3B
2AC3C CJK UNIFIED IDEOGRAPH-#2AC3C
2AC3D CJK UNIFIED IDEOGRAPH-#2AC3D
2AC3E CJK UNIFIED IDEOGRAPH-#2AC3E
2AC3F CJK UNIFIED IDEOGRAPH-#2AC3F
2AC40 CJK UNIFIED IDEOGRAPH-#2AC40
2AC41 CJK UNIFIED IDEOGRAPH-#2AC41
2AC42 CJK UNIFIED IDEOGRAPH-#2AC42
2AC43 CJK UNIFIED IDEOGRAPH-#2AC43
2AC44 CJK UNIFIED IDEOGRAPH-#2AC44
2AC45 CJK UNIFIED IDEOGRAPH-#2AC45
2AC46 CJK UNIFIED IDEOGRAPH-#2AC46
2AC47 CJK UNIFIED IDEOGRAPH-#2AC47
2AC48 CJK UNIFIED IDEOGRAPH-#2AC48
2AC49 CJK UNIFIED IDEOGRAPH-#2AC49
2AC4A CJK UNIFIED IDEOGRAPH-#2AC4A
2AC4B CJK UNIFIED IDEOGRAPH-#2AC4B
2AC4C CJK UNIFIED IDEOGRAPH-#2AC4C
2AC4D CJK UNIFIED IDEOGRAPH-#2AC4D
2AC4E CJK UNIFIED IDEOGRAPH-#2AC4E
2AC4F CJK UNIFIED IDEOGRAPH-#2AC4F
2AC50 CJK UNIFIED IDEOGRAPH-#2AC50
2AC51 CJK UNIFIED IDEOGRAPH-#2AC51
2AC52 CJK UNIFIED IDEOGRAPH-#2AC52
2AC53 CJK UNIFIED IDEOGRAPH-#2AC53
2AC54 CJK UNIFIED IDEOGRAPH-#2AC54
2AC55 CJK UNIFIED IDEOGRAPH-#2AC55
2AC56 CJK UNIFIED IDEOGRAPH-#2AC56
2AC57 CJK UNIFIED IDEOGRAPH-#2AC57
2AC58 CJK UNIFIED IDEOGRAPH-#2AC58
2AC59 CJK UNIFIED IDEOGRAPH-#2AC59
2AC5A CJK UNIFIED IDEOGRAPH-#2AC5A
2AC5B CJK UNIFIED IDEOGRAPH-#2AC5B
2AC5C CJK UNIFIED IDEOGRAPH-#2AC5C
2AC5D CJK UNIFIED IDEOGRAPH-#2AC5D
2AC5E CJK UNIFIED IDEOGRAPH-#2AC5E
2AC5F CJK UNIFIED IDEOGRAPH-#2AC5F
2AC60 CJK UNIFIED IDEOGRAPH-#2AC60
2AC61 CJK UNIFIED IDEOGRAPH-#2AC61
2AC62 CJK UNIFIED IDEOGRAPH-#2AC62
2AC63 CJK UNIFIED IDEOGRAPH-#2AC63
2AC64 CJK UNIFIED IDEOGRAPH-#2AC64
2AC65 CJK UNIFIED IDEOGRAPH-#2AC65
2AC66 CJK UNIFIED IDEOGRAPH-#2AC66
2AC67 CJK UNIFIED IDEOGRAPH-#2AC67
2AC68 CJK UNIFIED IDEOGRAPH-#2AC68
2AC69 CJK UNIFIED IDEOGRAPH-#2AC69
2AC6A CJK UNIFIED IDEOGRAPH-#2AC6A
2AC6B CJK UNIFIED IDEOGRAPH-#2AC6B
2AC6C CJK UNIFIED IDEOGRAPH-#2AC6C
2AC6D CJK UNIFIED IDEOGRAPH-#2AC6D
2AC6E CJK UNIFIED IDEOGRAPH-#2AC6E
2AC6F CJK UNIFIED IDEOGRAPH-#2AC6F
2AC70 CJK UNIFIED IDEOGRAPH-#2AC70
2AC71 CJK UNIFIED IDEOGRAPH-#2AC71
2AC72 CJK UNIFIED IDEOGRAPH-#2AC72
2AC73 CJK UNIFIED IDEOGRAPH-#2AC73
2AC74 CJK UNIFIED IDEOGRAPH-#2AC74
2AC75 CJK UNIFIED IDEOGRAPH-#2AC75
2AC76 CJK UNIFIED IDEOGRAPH-#2AC76
2AC77 CJK UNIFIED IDEOGRAPH-#2AC77
2AC78 CJK UNIFIED IDEOGRAPH-#2AC78
2AC79 CJK UNIFIED IDEOGRAPH-#2AC79
2AC7A CJK UNIFIED IDEOGRAPH-#2AC7A
2AC7B CJK UNIFIED IDEOGRAPH-#2AC7B
2AC7C CJK UNIFIED IDEOGRAPH-#2AC7C
2AC7D CJK UNIFIED IDEOGRAPH-#2AC7D
2AC7E CJK UNIFIED IDEOGRAPH-#2AC7E
2AC7F CJK UNIFIED IDEOGRAPH-#2AC7F
2AC80 CJK UNIFIED IDEOGRAPH-#2AC80
2AC81 CJK UNIFIED IDEOGRAPH-#2AC81
2AC82 CJK UNIFIED IDEOGRAPH-#2AC82
2AC83 CJK UNIFIED IDEOGRAPH-#2AC83
2AC84 CJK UNIFIED IDEOGRAPH-#2AC84
2AC85 CJK UNIFIED IDEOGRAPH-#2AC85
2AC86 CJK UNIFIED IDEOGRAPH-#2AC86
2AC87 CJK UNIFIED IDEOGRAPH-#2AC87
2AC88 CJK UNIFIED IDEOGRAPH-#2AC88
2AC89 CJK UNIFIED IDEOGRAPH-#2AC89
2AC8A CJK UNIFIED IDEOGRAPH-#2AC8A
2AC8B CJK UNIFIED IDEOGRAPH-#2AC8B
2AC8C CJK UNIFIED IDEOGRAPH-#2AC8C
2AC8D CJK UNIFIED IDEOGRAPH-#2AC8D
2AC8E CJK UNIFIED IDEOGRAPH-#2AC8E
2AC8F CJK UNIFIED IDEOGRAPH-#2AC8F
2AC90 CJK UNIFIED IDEOGRAPH-#2AC90
2AC91 CJK UNIFIED IDEOGRAPH-#2AC91
2AC92 CJK UNIFIED IDEOGRAPH-#2AC92
2AC93 CJK UNIFIED IDEOGRAPH-#2AC93
2AC94 CJK UNIFIED IDEOGRAPH-#2AC94
2AC95 CJK UNIFIED IDEOGRAPH-#2AC95
2AC96 CJK UNIFIED IDEOGRAPH-#2AC96
2AC97 CJK UNIFIED IDEOGRAPH-#2AC97
2AC98 CJK UNIFIED IDEOGRAPH-#2AC98
2AC99 CJK UNIFIED IDEOGRAPH-#2AC99
2AC9A CJK UNIFIED IDEOGRAPH-#2AC9A
2AC9B CJK UNIFIED IDEOGRAPH-#2AC9B
2AC9C CJK UNIFIED IDEOGRAPH-#2AC9C
2AC9D CJK UNIFIED IDEOGRAPH-#2AC9D
2AC9E CJK UNIFIED IDEOGRAPH-#2AC9E
2AC9F CJK UNIFIED IDEOGRAPH-#2AC9F
2ACA0 CJK UNIFIED IDEOGRAPH-#2ACA0
2ACA1 CJK UNIFIED IDEOGRAPH-#2ACA1
2ACA2 CJK UNIFIED IDEOGRAPH-#2ACA2
2ACA3 CJK UNIFIED IDEOGRAPH-#2ACA3
2ACA4 CJK UNIFIED IDEOGRAPH-#2ACA4
2ACA5 CJK UNIFIED IDEOGRAPH-#2ACA5
2ACA6 CJK UNIFIED IDEOGRAPH-#2ACA6
2ACA7 CJK UNIFIED IDEOGRAPH-#2ACA7
2ACA8 CJK UNIFIED IDEOGRAPH-#2ACA8
2ACA9 CJK UNIFIED IDEOGRAPH-#2ACA9
2ACAA CJK UNIFIED IDEOGRAPH-#2ACAA
2ACAB CJK UNIFIED IDEOGRAPH-#2ACAB
2ACAC CJK UNIFIED IDEOGRAPH-#2ACAC
2ACAD CJK UNIFIED IDEOGRAPH-#2ACAD
2ACAE CJK UNIFIED IDEOGRAPH-#2ACAE
2ACAF CJK UNIFIED IDEOGRAPH-#2ACAF
2ACB0 CJK UNIFIED IDEOGRAPH-#2ACB0
2ACB1 CJK UNIFIED IDEOGRAPH-#2ACB1
2ACB2 CJK UNIFIED IDEOGRAPH-#2ACB2
2ACB3 CJK UNIFIED IDEOGRAPH-#2ACB3
2ACB4 CJK UNIFIED IDEOGRAPH-#2ACB4
2ACB5 CJK UNIFIED IDEOGRAPH-#2ACB5
2ACB6 CJK UNIFIED IDEOGRAPH-#2ACB6
2ACB7 CJK UNIFIED IDEOGRAPH-#2ACB7
2ACB8 CJK UNIFIED IDEOGRAPH-#2ACB8
2ACB9 CJK UNIFIED IDEOGRAPH-#2ACB9
2ACBA CJK UNIFIED IDEOGRAPH-#2ACBA
2ACBB CJK UNIFIED IDEOGRAPH-#2ACBB
2ACBC CJK UNIFIED IDEOGRAPH-#2ACBC
2ACBD CJK UNIFIED IDEOGRAPH-#2ACBD
2ACBE CJK UNIFIED IDEOGRAPH-#2ACBE
2ACBF CJK UNIFIED IDEOGRAPH-#2ACBF
2ACC0 CJK UNIFIED IDEOGRAPH-#2ACC0
2ACC1 CJK UNIFIED IDEOGRAPH-#2ACC1
2ACC2 CJK UNIFIED IDEOGRAPH-#2ACC2
2ACC3 CJK UNIFIED IDEOGRAPH-#2ACC3
2ACC4 CJK UNIFIED IDEOGRAPH-#2ACC4
2ACC5 CJK UNIFIED IDEOGRAPH-#2ACC5
2ACC6 CJK UNIFIED IDEOGRAPH-#2ACC6
2ACC7 CJK UNIFIED IDEOGRAPH-#2ACC7
2ACC8 CJK UNIFIED IDEOGRAPH-#2ACC8
2ACC9 CJK UNIFIED IDEOGRAPH-#2ACC9
2ACCA CJK UNIFIED IDEOGRAPH-#2ACCA
2ACCB CJK UNIFIED IDEOGRAPH-#2ACCB
2ACCC CJK UNIFIED IDEOGRAPH-#2ACCC
2ACCD CJK UNIFIED IDEOGRAPH-#2ACCD
2ACCE CJK UNIFIED IDEOGRAPH-#2ACCE
2ACCF CJK UNIFIED IDEOGRAPH-#2ACCF
2ACD0 CJK UNIFIED IDEOGRAPH-#2ACD0
2ACD1 CJK UNIFIED IDEOGRAPH-#2ACD1
2ACD2 CJK UNIFIED IDEOGRAPH-#2ACD2
2ACD3 CJK UNIFIED IDEOGRAPH-#2ACD3
2ACD4 CJK UNIFIED IDEOGRAPH-#2ACD4
2ACD5 CJK UNIFIED IDEOGRAPH-#2ACD5
2ACD6 CJK UNIFIED IDEOGRAPH-#2ACD6
2ACD7 CJK UNIFIED IDEOGRAPH-#2ACD7
2ACD8 CJK UNIFIED IDEOGRAPH-#2ACD8
2ACD9 CJK UNIFIED IDEOGRAPH-#2ACD9
2ACDA CJK UNIFIED IDEOGRAPH-#2ACDA
2ACDB CJK UNIFIED IDEOGRAPH-#2ACDB
2ACDC CJK UNIFIED IDEOGRAPH-#2ACDC
2ACDD CJK UNIFIED IDEOGRAPH-#2ACDD
2ACDE CJK UNIFIED IDEOGRAPH-#2ACDE
2ACDF CJK UNIFIED IDEOGRAPH-#2ACDF
2ACE0 CJK UNIFIED IDEOGRAPH-#2ACE0
2ACE1 CJK UNIFIED IDEOGRAPH-#2ACE1
2ACE2 CJK UNIFIED IDEOGRAPH-#2ACE2
2ACE3 CJK UNIFIED IDEOGRAPH-#2ACE3
2ACE4 CJK UNIFIED IDEOGRAPH-#2ACE4
2ACE5 CJK UNIFIED IDEOGRAPH-#2ACE5
2ACE6 CJK UNIFIED IDEOGRAPH-#2ACE6
2ACE7 CJK UNIFIED IDEOGRAPH-#2ACE7
2ACE8 CJK UNIFIED IDEOGRAPH-#2ACE8
2ACE9 CJK UNIFIED IDEOGRAPH-#2ACE9
2ACEA CJK UNIFIED IDEOGRAPH-#2ACEA
2ACEB CJK UNIFIED IDEOGRAPH-#2ACEB
2ACEC CJK UNIFIED IDEOGRAPH-#2ACEC
2ACED CJK UNIFIED IDEOGRAPH-#2ACED
2ACEE CJK UNIFIED IDEOGRAPH-#2ACEE
2ACEF CJK UNIFIED IDEOGRAPH-#2ACEF
2ACF0 CJK UNIFIED IDEOGRAPH-#2ACF0
2ACF1 CJK UNIFIED IDEOGRAPH-#2ACF1
2ACF2 CJK UNIFIED IDEOGRAPH-#2ACF2
2ACF3 CJK UNIFIED IDEOGRAPH-#2ACF3
2ACF4 CJK UNIFIED IDEOGRAPH-#2ACF4
2ACF5 CJK UNIFIED IDEOGRAPH-#2ACF5
2ACF6 CJK UNIFIED IDEOGRAPH-#2ACF6
2ACF7 CJK UNIFIED IDEOGRAPH-#2ACF7
2ACF8 CJK UNIFIED IDEOGRAPH-#2ACF8
2ACF9 CJK UNIFIED IDEOGRAPH-#2ACF9
2ACFA CJK UNIFIED IDEOGRAPH-#2ACFA
2ACFB CJK UNIFIED IDEOGRAPH-#2ACFB
2ACFC CJK UNIFIED IDEOGRAPH-#2ACFC
2ACFD CJK UNIFIED IDEOGRAPH-#2ACFD
2ACFE CJK UNIFIED IDEOGRAPH-#2ACFE
2ACFF CJK UNIFIED IDEOGRAPH-#2ACFF
2AD00 CJK UNIFIED IDEOGRAPH-#2AD00
2AD01 CJK UNIFIED IDEOGRAPH-#2AD01
2AD02 CJK UNIFIED IDEOGRAPH-#2AD02
2AD03 CJK UNIFIED IDEOGRAPH-#2AD03
2AD04 CJK UNIFIED IDEOGRAPH-#2AD04
2AD05 CJK UNIFIED IDEOGRAPH-#2AD05
2AD06 CJK UNIFIED IDEOGRAPH-#2AD06
2AD07 CJK UNIFIED IDEOGRAPH-#2AD07
2AD08 CJK UNIFIED IDEOGRAPH-#2AD08
2AD09 CJK UNIFIED IDEOGRAPH-#2AD09
2AD0A CJK UNIFIED IDEOGRAPH-#2AD0A
2AD0B CJK UNIFIED IDEOGRAPH-#2AD0B
2AD0C CJK UNIFIED IDEOGRAPH-#2AD0C
2AD0D CJK UNIFIED IDEOGRAPH-#2AD0D
2AD0E CJK UNIFIED IDEOGRAPH-#2AD0E
2AD0F CJK UNIFIED IDEOGRAPH-#2AD0F
2AD10 CJK UNIFIED IDEOGRAPH-#2AD10
2AD11 CJK UNIFIED IDEOGRAPH-#2AD11
2AD12 CJK UNIFIED IDEOGRAPH-#2AD12
2AD13 CJK UNIFIED IDEOGRAPH-#2AD13
2AD14 CJK UNIFIED IDEOGRAPH-#2AD14
2AD15 CJK UNIFIED IDEOGRAPH-#2AD15
2AD16 CJK UNIFIED IDEOGRAPH-#2AD16
2AD17 CJK UNIFIED IDEOGRAPH-#2AD17
2AD18 CJK UNIFIED IDEOGRAPH-#2AD18
2AD19 CJK UNIFIED IDEOGRAPH-#2AD19
2AD1A CJK UNIFIED IDEOGRAPH-#2AD1A
2AD1B CJK UNIFIED IDEOGRAPH-#2AD1B
2AD1C CJK UNIFIED IDEOGRAPH-#2AD1C
2AD1D CJK UNIFIED IDEOGRAPH-#2AD1D
2AD1E CJK UNIFIED IDEOGRAPH-#2AD1E
2AD1F CJK UNIFIED IDEOGRAPH-#2AD1F
2AD20 CJK UNIFIED IDEOGRAPH-#2AD20
2AD21 CJK UNIFIED IDEOGRAPH-#2AD21
2AD22 CJK UNIFIED IDEOGRAPH-#2AD22
2AD23 CJK UNIFIED IDEOGRAPH-#2AD23
2AD24 CJK UNIFIED IDEOGRAPH-#2AD24
2AD25 CJK UNIFIED IDEOGRAPH-#2AD25
2AD26 CJK UNIFIED IDEOGRAPH-#2AD26
2AD27 CJK UNIFIED IDEOGRAPH-#2AD27
2AD28 CJK UNIFIED IDEOGRAPH-#2AD28
2AD29 CJK UNIFIED IDEOGRAPH-#2AD29
2AD2A CJK UNIFIED IDEOGRAPH-#2AD2A
2AD2B CJK UNIFIED IDEOGRAPH-#2AD2B
2AD2C CJK UNIFIED IDEOGRAPH-#2AD2C
2AD2D CJK UNIFIED IDEOGRAPH-#2AD2D
2AD2E CJK UNIFIED IDEOGRAPH-#2AD2E
2AD2F CJK UNIFIED IDEOGRAPH-#2AD2F
2AD30 CJK UNIFIED IDEOGRAPH-#2AD30
2AD31 CJK UNIFIED IDEOGRAPH-#2AD31
2AD32 CJK UNIFIED IDEOGRAPH-#2AD32
2AD33 CJK UNIFIED IDEOGRAPH-#2AD33
2AD34 CJK UNIFIED IDEOGRAPH-#2AD34
2AD35 CJK UNIFIED IDEOGRAPH-#2AD35
2AD36 CJK UNIFIED IDEOGRAPH-#2AD36
2AD37 CJK UNIFIED IDEOGRAPH-#2AD37
2AD38 CJK UNIFIED IDEOGRAPH-#2AD38
2AD39 CJK UNIFIED IDEOGRAPH-#2AD39
2AD3A CJK UNIFIED IDEOGRAPH-#2AD3A
2AD3B CJK UNIFIED IDEOGRAPH-#2AD3B
2AD3C CJK UNIFIED IDEOGRAPH-#2AD3C
2AD3D CJK UNIFIED IDEOGRAPH-#2AD3D
2AD3E CJK UNIFIED IDEOGRAPH-#2AD3E
2AD3F CJK UNIFIED IDEOGRAPH-#2AD3F
2AD40 CJK UNIFIED IDEOGRAPH-#2AD40
2AD41 CJK UNIFIED IDEOGRAPH-#2AD41
2AD42 CJK UNIFIED IDEOGRAPH-#2AD42
2AD43 CJK UNIFIED IDEOGRAPH-#2AD43
2AD44 CJK UNIFIED IDEOGRAPH-#2AD44
2AD45 CJK UNIFIED IDEOGRAPH-#2AD45
2AD46 CJK UNIFIED IDEOGRAPH-#2AD46
2AD47 CJK UNIFIED IDEOGRAPH-#2AD47
2AD48 CJK UNIFIED IDEOGRAPH-#2AD48
2AD49 CJK UNIFIED IDEOGRAPH-#2AD49
2AD4A CJK UNIFIED IDEOGRAPH-#2AD4A
2AD4B CJK UNIFIED IDEOGRAPH-#2AD4B
2AD4C CJK UNIFIED IDEOGRAPH-#2AD4C
2AD4D CJK UNIFIED IDEOGRAPH-#2AD4D
2AD4E CJK UNIFIED IDEOGRAPH-#2AD4E
2AD4F CJK UNIFIED IDEOGRAPH-#2AD4F
2AD50 CJK UNIFIED IDEOGRAPH-#2AD50
2AD51 CJK UNIFIED IDEOGRAPH-#2AD51
2AD52 CJK UNIFIED IDEOGRAPH-#2AD52
2AD53 CJK UNIFIED IDEOGRAPH-#2AD53
2AD54 CJK UNIFIED IDEOGRAPH-#2AD54
2AD55 CJK UNIFIED IDEOGRAPH-#2AD55
2AD56 CJK UNIFIED IDEOGRAPH-#2AD56
2AD57 CJK UNIFIED IDEOGRAPH-#2AD57
2AD58 CJK UNIFIED IDEOGRAPH-#2AD58
2AD59 CJK UNIFIED IDEOGRAPH-#2AD59
2AD5A CJK UNIFIED IDEOGRAPH-#2AD5A
2AD5B CJK UNIFIED IDEOGRAPH-#2AD5B
2AD5C CJK UNIFIED IDEOGRAPH-#2AD5C
2AD5D CJK UNIFIED IDEOGRAPH-#2AD5D
2AD5E CJK UNIFIED IDEOGRAPH-#2AD5E
2AD5F CJK UNIFIED IDEOGRAPH-#2AD5F
2AD60 CJK UNIFIED IDEOGRAPH-#2AD60
2AD61 CJK UNIFIED IDEOGRAPH-#2AD61
2AD62 CJK UNIFIED IDEOGRAPH-#2AD62
2AD63 CJK UNIFIED IDEOGRAPH-#2AD63
2AD64 CJK UNIFIED IDEOGRAPH-#2AD64
2AD65 CJK UNIFIED IDEOGRAPH-#2AD65
2AD66 CJK UNIFIED IDEOGRAPH-#2AD66
2AD67 CJK UNIFIED IDEOGRAPH-#2AD67
2AD68 CJK UNIFIED IDEOGRAPH-#2AD68
2AD69 CJK UNIFIED IDEOGRAPH-#2AD69
2AD6A CJK UNIFIED IDEOGRAPH-#2AD6A
2AD6B CJK UNIFIED IDEOGRAPH-#2AD6B
2AD6C CJK UNIFIED IDEOGRAPH-#2AD6C
2AD6D CJK UNIFIED IDEOGRAPH-#2AD6D
2AD6E CJK UNIFIED IDEOGRAPH-#2AD6E
2AD6F CJK UNIFIED IDEOGRAPH-#2AD6F
2AD70 CJK UNIFIED IDEOGRAPH-#2AD70
2AD71 CJK UNIFIED IDEOGRAPH-#2AD71
2AD72 CJK UNIFIED IDEOGRAPH-#2AD72
2AD73 CJK UNIFIED IDEOGRAPH-#2AD73
2AD74 CJK UNIFIED IDEOGRAPH-#2AD74
2AD75 CJK UNIFIED IDEOGRAPH-#2AD75
2AD76 CJK UNIFIED IDEOGRAPH-#2AD76
2AD77 CJK UNIFIED IDEOGRAPH-#2AD77
2AD78 CJK UNIFIED IDEOGRAPH-#2AD78
2AD79 CJK UNIFIED IDEOGRAPH-#2AD79
2AD7A CJK UNIFIED IDEOGRAPH-#2AD7A
2AD7B CJK UNIFIED IDEOGRAPH-#2AD7B
2AD7C CJK UNIFIED IDEOGRAPH-#2AD7C
2AD7D CJK UNIFIED IDEOGRAPH-#2AD7D
2AD7E CJK UNIFIED IDEOGRAPH-#2AD7E
2AD7F CJK UNIFIED IDEOGRAPH-#2AD7F
2AD80 CJK UNIFIED IDEOGRAPH-#2AD80
2AD81 CJK UNIFIED IDEOGRAPH-#2AD81
2AD82 CJK UNIFIED IDEOGRAPH-#2AD82
2AD83 CJK UNIFIED IDEOGRAPH-#2AD83
2AD84 CJK UNIFIED IDEOGRAPH-#2AD84
2AD85 CJK UNIFIED IDEOGRAPH-#2AD85
2AD86 CJK UNIFIED IDEOGRAPH-#2AD86
2AD87 CJK UNIFIED IDEOGRAPH-#2AD87
2AD88 CJK UNIFIED IDEOGRAPH-#2AD88
2AD89 CJK UNIFIED IDEOGRAPH-#2AD89
2AD8A CJK UNIFIED IDEOGRAPH-#2AD8A
2AD8B CJK UNIFIED IDEOGRAPH-#2AD8B
2AD8C CJK UNIFIED IDEOGRAPH-#2AD8C
2AD8D CJK UNIFIED IDEOGRAPH-#2AD8D
2AD8E CJK UNIFIED IDEOGRAPH-#2AD8E
2AD8F CJK UNIFIED IDEOGRAPH-#2AD8F
2AD90 CJK UNIFIED IDEOGRAPH-#2AD90
2AD91 CJK UNIFIED IDEOGRAPH-#2AD91
2AD92 CJK UNIFIED IDEOGRAPH-#2AD92
2AD93 CJK UNIFIED IDEOGRAPH-#2AD93
2AD94 CJK UNIFIED IDEOGRAPH-#2AD94
2AD95 CJK UNIFIED IDEOGRAPH-#2AD95
2AD96 CJK UNIFIED IDEOGRAPH-#2AD96
2AD97 CJK UNIFIED IDEOGRAPH-#2AD97
2AD98 CJK UNIFIED IDEOGRAPH-#2AD98
2AD99 CJK UNIFIED IDEOGRAPH-#2AD99
2AD9A CJK UNIFIED IDEOGRAPH-#2AD9A
2AD9B CJK UNIFIED IDEOGRAPH-#2AD9B
2AD9C CJK UNIFIED IDEOGRAPH-#2AD9C
2AD9D CJK UNIFIED IDEOGRAPH-#2AD9D
2AD9E CJK UNIFIED IDEOGRAPH-#2AD9E
2AD9F CJK UNIFIED IDEOGRAPH-#2AD9F
2ADA0 CJK UNIFIED IDEOGRAPH-#2ADA0
2ADA1 CJK UNIFIED IDEOGRAPH-#2ADA1
2ADA2 CJK UNIFIED IDEOGRAPH-#2ADA2
2ADA3 CJK UNIFIED IDEOGRAPH-#2ADA3
2ADA4 CJK UNIFIED IDEOGRAPH-#2ADA4
2ADA5 CJK UNIFIED IDEOGRAPH-#2ADA5
2ADA6 CJK UNIFIED IDEOGRAPH-#2ADA6
2ADA7 CJK UNIFIED IDEOGRAPH-#2ADA7
2ADA8 CJK UNIFIED IDEOGRAPH-#2ADA8
2ADA9 CJK UNIFIED IDEOGRAPH-#2ADA9
2ADAA CJK UNIFIED IDEOGRAPH-#2ADAA
2ADAB CJK UNIFIED IDEOGRAPH-#2ADAB
2ADAC CJK UNIFIED IDEOGRAPH-#2ADAC
2ADAD CJK UNIFIED IDEOGRAPH-#2ADAD
2ADAE CJK UNIFIED IDEOGRAPH-#2ADAE
2ADAF CJK UNIFIED IDEOGRAPH-#2ADAF
2ADB0 CJK UNIFIED IDEOGRAPH-#2ADB0
2ADB1 CJK UNIFIED IDEOGRAPH-#2ADB1
2ADB2 CJK UNIFIED IDEOGRAPH-#2ADB2
2ADB3 CJK UNIFIED IDEOGRAPH-#2ADB3
2ADB4 CJK UNIFIED IDEOGRAPH-#2ADB4
2ADB5 CJK UNIFIED IDEOGRAPH-#2ADB5
2ADB6 CJK UNIFIED IDEOGRAPH-#2ADB6
2ADB7 CJK UNIFIED IDEOGRAPH-#2ADB7
2ADB8 CJK UNIFIED IDEOGRAPH-#2ADB8
2ADB9 CJK UNIFIED IDEOGRAPH-#2ADB9
2ADBA CJK UNIFIED IDEOGRAPH-#2ADBA
2ADBB CJK UNIFIED IDEOGRAPH-#2ADBB
2ADBC CJK UNIFIED IDEOGRAPH-#2ADBC
2ADBD CJK UNIFIED IDEOGRAPH-#2ADBD
2ADBE CJK UNIFIED IDEOGRAPH-#2ADBE
2ADBF CJK UNIFIED IDEOGRAPH-#2ADBF
2ADC0 CJK UNIFIED IDEOGRAPH-#2ADC0
2ADC1 CJK UNIFIED IDEOGRAPH-#2ADC1
2ADC2 CJK UNIFIED IDEOGRAPH-#2ADC2
2ADC3 CJK UNIFIED IDEOGRAPH-#2ADC3
2ADC4 CJK UNIFIED IDEOGRAPH-#2ADC4
2ADC5 CJK UNIFIED IDEOGRAPH-#2ADC5
2ADC6 CJK UNIFIED IDEOGRAPH-#2ADC6
2ADC7 CJK UNIFIED IDEOGRAPH-#2ADC7
2ADC8 CJK UNIFIED IDEOGRAPH-#2ADC8
2ADC9 CJK UNIFIED IDEOGRAPH-#2ADC9
2ADCA CJK UNIFIED IDEOGRAPH-#2ADCA
2ADCB CJK UNIFIED IDEOGRAPH-#2ADCB
2ADCC CJK UNIFIED IDEOGRAPH-#2ADCC
2ADCD CJK UNIFIED IDEOGRAPH-#2ADCD
2ADCE CJK UNIFIED IDEOGRAPH-#2ADCE
2ADCF CJK UNIFIED IDEOGRAPH-#2ADCF
2ADD0 CJK UNIFIED IDEOGRAPH-#2ADD0
2ADD1 CJK UNIFIED IDEOGRAPH-#2ADD1
2ADD2 CJK UNIFIED IDEOGRAPH-#2ADD2
2ADD3 CJK UNIFIED IDEOGRAPH-#2ADD3
2ADD4 CJK UNIFIED IDEOGRAPH-#2ADD4
2ADD5 CJK UNIFIED IDEOGRAPH-#2ADD5
2ADD6 CJK UNIFIED IDEOGRAPH-#2ADD6
2ADD7 CJK UNIFIED IDEOGRAPH-#2ADD7
2ADD8 CJK UNIFIED IDEOGRAPH-#2ADD8
2ADD9 CJK UNIFIED IDEOGRAPH-#2ADD9
2ADDA CJK UNIFIED IDEOGRAPH-#2ADDA
2ADDB CJK UNIFIED IDEOGRAPH-#2ADDB
2ADDC CJK UNIFIED IDEOGRAPH-#2ADDC
2ADDD CJK UNIFIED IDEOGRAPH-#2ADDD
2ADDE CJK UNIFIED IDEOGRAPH-#2ADDE
2ADDF CJK UNIFIED IDEOGRAPH-#2ADDF
2ADE0 CJK UNIFIED IDEOGRAPH-#2ADE0
2ADE1 CJK UNIFIED IDEOGRAPH-#2ADE1
2ADE2 CJK UNIFIED IDEOGRAPH-#2ADE2
2ADE3 CJK UNIFIED IDEOGRAPH-#2ADE3
2ADE4 CJK UNIFIED IDEOGRAPH-#2ADE4
2ADE5 CJK UNIFIED IDEOGRAPH-#2ADE5
2ADE6 CJK UNIFIED IDEOGRAPH-#2ADE6
2ADE7 CJK UNIFIED IDEOGRAPH-#2ADE7
2ADE8 CJK UNIFIED IDEOGRAPH-#2ADE8
2ADE9 CJK UNIFIED IDEOGRAPH-#2ADE9
2ADEA CJK UNIFIED IDEOGRAPH-#2ADEA
2ADEB CJK UNIFIED IDEOGRAPH-#2ADEB
2ADEC CJK UNIFIED IDEOGRAPH-#2ADEC
2ADED CJK UNIFIED IDEOGRAPH-#2ADED
2ADEE CJK UNIFIED IDEOGRAPH-#2ADEE
2ADEF CJK UNIFIED IDEOGRAPH-#2ADEF
2ADF0 CJK UNIFIED IDEOGRAPH-#2ADF0
2ADF1 CJK UNIFIED IDEOGRAPH-#2ADF1
2ADF2 CJK UNIFIED IDEOGRAPH-#2ADF2
2ADF3 CJK UNIFIED IDEOGRAPH-#2ADF3
2ADF4 CJK UNIFIED IDEOGRAPH-#2ADF4
2ADF5 CJK UNIFIED IDEOGRAPH-#2ADF5
2ADF6 CJK UNIFIED IDEOGRAPH-#2ADF6
2ADF7 CJK UNIFIED IDEOGRAPH-#2ADF7
2ADF8 CJK UNIFIED IDEOGRAPH-#2ADF8
2ADF9 CJK UNIFIED IDEOGRAPH-#2ADF9
2ADFA CJK UNIFIED IDEOGRAPH-#2ADFA
2ADFB CJK UNIFIED IDEOGRAPH-#2ADFB
2ADFC CJK UNIFIED IDEOGRAPH-#2ADFC
2ADFD CJK UNIFIED IDEOGRAPH-#2ADFD
2ADFE CJK UNIFIED IDEOGRAPH-#2ADFE
2ADFF CJK UNIFIED IDEOGRAPH-#2ADFF
2AE00 CJK UNIFIED IDEOGRAPH-#2AE00
2AE01 CJK UNIFIED IDEOGRAPH-#2AE01
2AE02 CJK UNIFIED IDEOGRAPH-#2AE02
2AE03 CJK UNIFIED IDEOGRAPH-#2AE03
2AE04 CJK UNIFIED IDEOGRAPH-#2AE04
2AE05 CJK UNIFIED IDEOGRAPH-#2AE05
2AE06 CJK UNIFIED IDEOGRAPH-#2AE06
2AE07 CJK UNIFIED IDEOGRAPH-#2AE07
2AE08 CJK UNIFIED IDEOGRAPH-#2AE08
2AE09 CJK UNIFIED IDEOGRAPH-#2AE09
2AE0A CJK UNIFIED IDEOGRAPH-#2AE0A
2AE0B CJK UNIFIED IDEOGRAPH-#2AE0B
2AE0C CJK UNIFIED IDEOGRAPH-#2AE0C
2AE0D CJK UNIFIED IDEOGRAPH-#2AE0D
2AE0E CJK UNIFIED IDEOGRAPH-#2AE0E
2AE0F CJK UNIFIED IDEOGRAPH-#2AE0F
2AE10 CJK UNIFIED IDEOGRAPH-#2AE10
2AE11 CJK UNIFIED IDEOGRAPH-#2AE11
2AE12 CJK UNIFIED IDEOGRAPH-#2AE12
2AE13 CJK UNIFIED IDEOGRAPH-#2AE13
2AE14 CJK UNIFIED IDEOGRAPH-#2AE14
2AE15 CJK UNIFIED IDEOGRAPH-#2AE15
2AE16 CJK UNIFIED IDEOGRAPH-#2AE16
2AE17 CJK UNIFIED IDEOGRAPH-#2AE17
2AE18 CJK UNIFIED IDEOGRAPH-#2AE18
2AE19 CJK UNIFIED IDEOGRAPH-#2AE19
2AE1A CJK UNIFIED IDEOGRAPH-#2AE1A
2AE1B CJK UNIFIED IDEOGRAPH-#2AE1B
2AE1C CJK UNIFIED IDEOGRAPH-#2AE1C
2AE1D CJK UNIFIED IDEOGRAPH-#2AE1D
2AE1E CJK UNIFIED IDEOGRAPH-#2AE1E
2AE1F CJK UNIFIED IDEOGRAPH-#2AE1F
2AE20 CJK UNIFIED IDEOGRAPH-#2AE20
2AE21 CJK UNIFIED IDEOGRAPH-#2AE21
2AE22 CJK UNIFIED IDEOGRAPH-#2AE22
2AE23 CJK UNIFIED IDEOGRAPH-#2AE23
2AE24 CJK UNIFIED IDEOGRAPH-#2AE24
2AE25 CJK UNIFIED IDEOGRAPH-#2AE25
2AE26 CJK UNIFIED IDEOGRAPH-#2AE26
2AE27 CJK UNIFIED IDEOGRAPH-#2AE27
2AE28 CJK UNIFIED IDEOGRAPH-#2AE28
2AE29 CJK UNIFIED IDEOGRAPH-#2AE29
2AE2A CJK UNIFIED IDEOGRAPH-#2AE2A
2AE2B CJK UNIFIED IDEOGRAPH-#2AE2B
2AE2C CJK UNIFIED IDEOGRAPH-#2AE2C
2AE2D CJK UNIFIED IDEOGRAPH-#2AE2D
2AE2E CJK UNIFIED IDEOGRAPH-#2AE2E
2AE2F CJK UNIFIED IDEOGRAPH-#2AE2F
2AE30 CJK UNIFIED IDEOGRAPH-#2AE30
2AE31 CJK UNIFIED IDEOGRAPH-#2AE31
2AE32 CJK UNIFIED IDEOGRAPH-#2AE32
2AE33 CJK UNIFIED IDEOGRAPH-#2AE33
2AE34 CJK UNIFIED IDEOGRAPH-#2AE34
2AE35 CJK UNIFIED IDEOGRAPH-#2AE35
2AE36 CJK UNIFIED IDEOGRAPH-#2AE36
2AE37 CJK UNIFIED IDEOGRAPH-#2AE37
2AE38 CJK UNIFIED IDEOGRAPH-#2AE38
2AE39 CJK UNIFIED IDEOGRAPH-#2AE39
2AE3A CJK UNIFIED IDEOGRAPH-#2AE3A
2AE3B CJK UNIFIED IDEOGRAPH-#2AE3B
2AE3C CJK UNIFIED IDEOGRAPH-#2AE3C
2AE3D CJK UNIFIED IDEOGRAPH-#2AE3D
2AE3E CJK UNIFIED IDEOGRAPH-#2AE3E
2AE3F CJK UNIFIED IDEOGRAPH-#2AE3F
2AE40 CJK UNIFIED IDEOGRAPH-#2AE40
2AE41 CJK UNIFIED IDEOGRAPH-#2AE41
2AE42 CJK UNIFIED IDEOGRAPH-#2AE42
2AE43 CJK UNIFIED IDEOGRAPH-#2AE43
2AE44 CJK UNIFIED IDEOGRAPH-#2AE44
2AE45 CJK UNIFIED IDEOGRAPH-#2AE45
2AE46 CJK UNIFIED IDEOGRAPH-#2AE46
2AE47 CJK UNIFIED IDEOGRAPH-#2AE47
2AE48 CJK UNIFIED IDEOGRAPH-#2AE48
2AE49 CJK UNIFIED IDEOGRAPH-#2AE49
2AE4A CJK UNIFIED IDEOGRAPH-#2AE4A
2AE4B CJK UNIFIED IDEOGRAPH-#2AE4B
2AE4C CJK UNIFIED IDEOGRAPH-#2AE4C
2AE4D CJK UNIFIED IDEOGRAPH-#2AE4D
2AE4E CJK UNIFIED IDEOGRAPH-#2AE4E
2AE4F CJK UNIFIED IDEOGRAPH-#2AE4F
2AE50 CJK UNIFIED IDEOGRAPH-#2AE50
2AE51 CJK UNIFIED IDEOGRAPH-#2AE51
2AE52 CJK UNIFIED IDEOGRAPH-#2AE52
2AE53 CJK UNIFIED IDEOGRAPH-#2AE53
2AE54 CJK UNIFIED IDEOGRAPH-#2AE54
2AE55 CJK UNIFIED IDEOGRAPH-#2AE55
2AE56 CJK UNIFIED IDEOGRAPH-#2AE56
2AE57 CJK UNIFIED IDEOGRAPH-#2AE57
2AE58 CJK UNIFIED IDEOGRAPH-#2AE58
2AE59 CJK UNIFIED IDEOGRAPH-#2AE59
2AE5A CJK UNIFIED IDEOGRAPH-#2AE5A
2AE5B CJK UNIFIED IDEOGRAPH-#2AE5B
2AE5C CJK UNIFIED IDEOGRAPH-#2AE5C
2AE5D CJK UNIFIED IDEOGRAPH-#2AE5D
2AE5E CJK UNIFIED IDEOGRAPH-#2AE5E
2AE5F CJK UNIFIED IDEOGRAPH-#2AE5F
2AE60 CJK UNIFIED IDEOGRAPH-#2AE60
2AE61 CJK UNIFIED IDEOGRAPH-#2AE61
2AE62 CJK UNIFIED IDEOGRAPH-#2AE62
2AE63 CJK UNIFIED IDEOGRAPH-#2AE63
2AE64 CJK UNIFIED IDEOGRAPH-#2AE64
2AE65 CJK UNIFIED IDEOGRAPH-#2AE65
2AE66 CJK UNIFIED IDEOGRAPH-#2AE66
2AE67 CJK UNIFIED IDEOGRAPH-#2AE67
2AE68 CJK UNIFIED IDEOGRAPH-#2AE68
2AE69 CJK UNIFIED IDEOGRAPH-#2AE69
2AE6A CJK UNIFIED IDEOGRAPH-#2AE6A
2AE6B CJK UNIFIED IDEOGRAPH-#2AE6B
2AE6C CJK UNIFIED IDEOGRAPH-#2AE6C
2AE6D CJK UNIFIED IDEOGRAPH-#2AE6D
2AE6E CJK UNIFIED IDEOGRAPH-#2AE6E
2AE6F CJK UNIFIED IDEOGRAPH-#2AE6F
2AE70 CJK UNIFIED IDEOGRAPH-#2AE70
2AE71 CJK UNIFIED IDEOGRAPH-#2AE71
2AE72 CJK UNIFIED IDEOGRAPH-#2AE72
2AE73 CJK UNIFIED IDEOGRAPH-#2AE73
2AE74 CJK UNIFIED IDEOGRAPH-#2AE74
2AE75 CJK UNIFIED IDEOGRAPH-#2AE75
2AE76 CJK UNIFIED IDEOGRAPH-#2AE76
2AE77 CJK UNIFIED IDEOGRAPH-#2AE77
2AE78 CJK UNIFIED IDEOGRAPH-#2AE78
2AE79 CJK UNIFIED IDEOGRAPH-#2AE79
2AE7A CJK UNIFIED IDEOGRAPH-#2AE7A
2AE7B CJK UNIFIED IDEOGRAPH-#2AE7B
2AE7C CJK UNIFIED IDEOGRAPH-#2AE7C
2AE7D CJK UNIFIED IDEOGRAPH-#2AE7D
2AE7E CJK UNIFIED IDEOGRAPH-#2AE7E
2AE7F CJK UNIFIED IDEOGRAPH-#2AE7F
2AE80 CJK UNIFIED IDEOGRAPH-#2AE80
2AE81 CJK UNIFIED IDEOGRAPH-#2AE81
2AE82 CJK UNIFIED IDEOGRAPH-#2AE82
2AE83 CJK UNIFIED IDEOGRAPH-#2AE83
2AE84 CJK UNIFIED IDEOGRAPH-#2AE84
2AE85 CJK UNIFIED IDEOGRAPH-#2AE85
2AE86 CJK UNIFIED IDEOGRAPH-#2AE86
2AE87 CJK UNIFIED IDEOGRAPH-#2AE87
2AE88 CJK UNIFIED IDEOGRAPH-#2AE88
2AE89 CJK UNIFIED IDEOGRAPH-#2AE89
2AE8A CJK UNIFIED IDEOGRAPH-#2AE8A
2AE8B CJK UNIFIED IDEOGRAPH-#2AE8B
2AE8C CJK UNIFIED IDEOGRAPH-#2AE8C
2AE8D CJK UNIFIED IDEOGRAPH-#2AE8D
2AE8E CJK UNIFIED IDEOGRAPH-#2AE8E
2AE8F CJK UNIFIED IDEOGRAPH-#2AE8F
2AE90 CJK UNIFIED IDEOGRAPH-#2AE90
2AE91 CJK UNIFIED IDEOGRAPH-#2AE91
2AE92 CJK UNIFIED IDEOGRAPH-#2AE92
2AE93 CJK UNIFIED IDEOGRAPH-#2AE93
2AE94 CJK UNIFIED IDEOGRAPH-#2AE94
2AE95 CJK UNIFIED IDEOGRAPH-#2AE95
2AE96 CJK UNIFIED IDEOGRAPH-#2AE96
2AE97 CJK UNIFIED IDEOGRAPH-#2AE97
2AE98 CJK UNIFIED IDEOGRAPH-#2AE98
2AE99 CJK UNIFIED IDEOGRAPH-#2AE99
2AE9A CJK UNIFIED IDEOGRAPH-#2AE9A
2AE9B CJK UNIFIED IDEOGRAPH-#2AE9B
2AE9C CJK UNIFIED IDEOGRAPH-#2AE9C
2AE9D CJK UNIFIED IDEOGRAPH-#2AE9D
2AE9E CJK UNIFIED IDEOGRAPH-#2AE9E
2AE9F CJK UNIFIED IDEOGRAPH-#2AE9F
2AEA0 CJK UNIFIED IDEOGRAPH-#2AEA0
2AEA1 CJK UNIFIED IDEOGRAPH-#2AEA1
2AEA2 CJK UNIFIED IDEOGRAPH-#2AEA2
2AEA3 CJK UNIFIED IDEOGRAPH-#2AEA3
2AEA4 CJK UNIFIED IDEOGRAPH-#2AEA4
2AEA5 CJK UNIFIED IDEOGRAPH-#2AEA5
2AEA6 CJK UNIFIED IDEOGRAPH-#2AEA6
2AEA7 CJK UNIFIED IDEOGRAPH-#2AEA7
2AEA8 CJK UNIFIED IDEOGRAPH-#2AEA8
2AEA9 CJK UNIFIED IDEOGRAPH-#2AEA9
2AEAA CJK UNIFIED IDEOGRAPH-#2AEAA
2AEAB CJK UNIFIED IDEOGRAPH-#2AEAB
2AEAC CJK UNIFIED IDEOGRAPH-#2AEAC
2AEAD CJK UNIFIED IDEOGRAPH-#2AEAD
2AEAE CJK UNIFIED IDEOGRAPH-#2AEAE
2AEAF CJK UNIFIED IDEOGRAPH-#2AEAF
2AEB0 CJK UNIFIED IDEOGRAPH-#2AEB0
2AEB1 CJK UNIFIED IDEOGRAPH-#2AEB1
2AEB2 CJK UNIFIED IDEOGRAPH-#2AEB2
2AEB3 CJK UNIFIED IDEOGRAPH-#2AEB3
2AEB4 CJK UNIFIED IDEOGRAPH-#2AEB4
2AEB5 CJK UNIFIED IDEOGRAPH-#2AEB5
2AEB6 CJK UNIFIED IDEOGRAPH-#2AEB6
2AEB7 CJK UNIFIED IDEOGRAPH-#2AEB7
2AEB8 CJK UNIFIED IDEOGRAPH-#2AEB8
2AEB9 CJK UNIFIED IDEOGRAPH-#2AEB9, Def{a tribe in southwest Yunnan}
2AEBA CJK UNIFIED IDEOGRAPH-#2AEBA
2AEBB CJK UNIFIED IDEOGRAPH-#2AEBB
2AEBC CJK UNIFIED IDEOGRAPH-#2AEBC
2AEBD CJK UNIFIED IDEOGRAPH-#2AEBD
2AEBE CJK UNIFIED IDEOGRAPH-#2AEBE
2AEBF CJK UNIFIED IDEOGRAPH-#2AEBF
2AEC0 CJK UNIFIED IDEOGRAPH-#2AEC0
2AEC1 CJK UNIFIED IDEOGRAPH-#2AEC1
2AEC2 CJK UNIFIED IDEOGRAPH-#2AEC2
2AEC3 CJK UNIFIED IDEOGRAPH-#2AEC3
2AEC4 CJK UNIFIED IDEOGRAPH-#2AEC4
2AEC5 CJK UNIFIED IDEOGRAPH-#2AEC5
2AEC6 CJK UNIFIED IDEOGRAPH-#2AEC6
2AEC7 CJK UNIFIED IDEOGRAPH-#2AEC7
2AEC8 CJK UNIFIED IDEOGRAPH-#2AEC8
2AEC9 CJK UNIFIED IDEOGRAPH-#2AEC9
2AECA CJK UNIFIED IDEOGRAPH-#2AECA
2AECB CJK UNIFIED IDEOGRAPH-#2AECB
2AECC CJK UNIFIED IDEOGRAPH-#2AECC
2AECD CJK UNIFIED IDEOGRAPH-#2AECD
2AECE CJK UNIFIED IDEOGRAPH-#2AECE
2AECF CJK UNIFIED IDEOGRAPH-#2AECF
2AED0 CJK UNIFIED IDEOGRAPH-#2AED0, Def{tinkling of jade pendants}
2AED1 CJK UNIFIED IDEOGRAPH-#2AED1
2AED2 CJK UNIFIED IDEOGRAPH-#2AED2
2AED3 CJK UNIFIED IDEOGRAPH-#2AED3
2AED4 CJK UNIFIED IDEOGRAPH-#2AED4
2AED5 CJK UNIFIED IDEOGRAPH-#2AED5
2AED6 CJK UNIFIED IDEOGRAPH-#2AED6
2AED7 CJK UNIFIED IDEOGRAPH-#2AED7
2AED8 CJK UNIFIED IDEOGRAPH-#2AED8
2AED9 CJK UNIFIED IDEOGRAPH-#2AED9
2AEDA CJK UNIFIED IDEOGRAPH-#2AEDA
2AEDB CJK UNIFIED IDEOGRAPH-#2AEDB
2AEDC CJK UNIFIED IDEOGRAPH-#2AEDC
2AEDD CJK UNIFIED IDEOGRAPH-#2AEDD
2AEDE CJK UNIFIED IDEOGRAPH-#2AEDE
2AEDF CJK UNIFIED IDEOGRAPH-#2AEDF
2AEE0 CJK UNIFIED IDEOGRAPH-#2AEE0
2AEE1 CJK UNIFIED IDEOGRAPH-#2AEE1
2AEE2 CJK UNIFIED IDEOGRAPH-#2AEE2
2AEE3 CJK UNIFIED IDEOGRAPH-#2AEE3
2AEE4 CJK UNIFIED IDEOGRAPH-#2AEE4
2AEE5 CJK UNIFIED IDEOGRAPH-#2AEE5
2AEE6 CJK UNIFIED IDEOGRAPH-#2AEE6
2AEE7 CJK UNIFIED IDEOGRAPH-#2AEE7
2AEE8 CJK UNIFIED IDEOGRAPH-#2AEE8
2AEE9 CJK UNIFIED IDEOGRAPH-#2AEE9
2AEEA CJK UNIFIED IDEOGRAPH-#2AEEA
2AEEB CJK UNIFIED IDEOGRAPH-#2AEEB
2AEEC CJK UNIFIED IDEOGRAPH-#2AEEC
2AEED CJK UNIFIED IDEOGRAPH-#2AEED
2AEEE CJK UNIFIED IDEOGRAPH-#2AEEE
2AEEF CJK UNIFIED IDEOGRAPH-#2AEEF
2AEF0 CJK UNIFIED IDEOGRAPH-#2AEF0
2AEF1 CJK UNIFIED IDEOGRAPH-#2AEF1
2AEF2 CJK UNIFIED IDEOGRAPH-#2AEF2
2AEF3 CJK UNIFIED IDEOGRAPH-#2AEF3
2AEF4 CJK UNIFIED IDEOGRAPH-#2AEF4
2AEF5 CJK UNIFIED IDEOGRAPH-#2AEF5
2AEF6 CJK UNIFIED IDEOGRAPH-#2AEF6
2AEF7 CJK UNIFIED IDEOGRAPH-#2AEF7
2AEF8 CJK UNIFIED IDEOGRAPH-#2AEF8
2AEF9 CJK UNIFIED IDEOGRAPH-#2AEF9
2AEFA CJK UNIFIED IDEOGRAPH-#2AEFA
2AEFB CJK UNIFIED IDEOGRAPH-#2AEFB
2AEFC CJK UNIFIED IDEOGRAPH-#2AEFC
2AEFD CJK UNIFIED IDEOGRAPH-#2AEFD
2AEFE CJK UNIFIED IDEOGRAPH-#2AEFE
2AEFF CJK UNIFIED IDEOGRAPH-#2AEFF
2AF00 CJK UNIFIED IDEOGRAPH-#2AF00
2AF01 CJK UNIFIED IDEOGRAPH-#2AF01
2AF02 CJK UNIFIED IDEOGRAPH-#2AF02
2AF03 CJK UNIFIED IDEOGRAPH-#2AF03
2AF04 CJK UNIFIED IDEOGRAPH-#2AF04
2AF05 CJK UNIFIED IDEOGRAPH-#2AF05
2AF06 CJK UNIFIED IDEOGRAPH-#2AF06
2AF07 CJK UNIFIED IDEOGRAPH-#2AF07
2AF08 CJK UNIFIED IDEOGRAPH-#2AF08
2AF09 CJK UNIFIED IDEOGRAPH-#2AF09
2AF0A CJK UNIFIED IDEOGRAPH-#2AF0A
2AF0B CJK UNIFIED IDEOGRAPH-#2AF0B
2AF0C CJK UNIFIED IDEOGRAPH-#2AF0C
2AF0D CJK UNIFIED IDEOGRAPH-#2AF0D
2AF0E CJK UNIFIED IDEOGRAPH-#2AF0E
2AF0F CJK UNIFIED IDEOGRAPH-#2AF0F
2AF10 CJK UNIFIED IDEOGRAPH-#2AF10
2AF11 CJK UNIFIED IDEOGRAPH-#2AF11
2AF12 CJK UNIFIED IDEOGRAPH-#2AF12
2AF13 CJK UNIFIED IDEOGRAPH-#2AF13
2AF14 CJK UNIFIED IDEOGRAPH-#2AF14
2AF15 CJK UNIFIED IDEOGRAPH-#2AF15
2AF16 CJK UNIFIED IDEOGRAPH-#2AF16
2AF17 CJK UNIFIED IDEOGRAPH-#2AF17
2AF18 CJK UNIFIED IDEOGRAPH-#2AF18
2AF19 CJK UNIFIED IDEOGRAPH-#2AF19
2AF1A CJK UNIFIED IDEOGRAPH-#2AF1A
2AF1B CJK UNIFIED IDEOGRAPH-#2AF1B
2AF1C CJK UNIFIED IDEOGRAPH-#2AF1C
2AF1D CJK UNIFIED IDEOGRAPH-#2AF1D
2AF1E CJK UNIFIED IDEOGRAPH-#2AF1E
2AF1F CJK UNIFIED IDEOGRAPH-#2AF1F
2AF20 CJK UNIFIED IDEOGRAPH-#2AF20
2AF21 CJK UNIFIED IDEOGRAPH-#2AF21
2AF22 CJK UNIFIED IDEOGRAPH-#2AF22
2AF23 CJK UNIFIED IDEOGRAPH-#2AF23
2AF24 CJK UNIFIED IDEOGRAPH-#2AF24
2AF25 CJK UNIFIED IDEOGRAPH-#2AF25
2AF26 CJK UNIFIED IDEOGRAPH-#2AF26
2AF27 CJK UNIFIED IDEOGRAPH-#2AF27
2AF28 CJK UNIFIED IDEOGRAPH-#2AF28
2AF29 CJK UNIFIED IDEOGRAPH-#2AF29
2AF2A CJK UNIFIED IDEOGRAPH-#2AF2A
2AF2B CJK UNIFIED IDEOGRAPH-#2AF2B
2AF2C CJK UNIFIED IDEOGRAPH-#2AF2C
2AF2D CJK UNIFIED IDEOGRAPH-#2AF2D
2AF2E CJK UNIFIED IDEOGRAPH-#2AF2E
2AF2F CJK UNIFIED IDEOGRAPH-#2AF2F
2AF30 CJK UNIFIED IDEOGRAPH-#2AF30
2AF31 CJK UNIFIED IDEOGRAPH-#2AF31
2AF32 CJK UNIFIED IDEOGRAPH-#2AF32
2AF33 CJK UNIFIED IDEOGRAPH-#2AF33
2AF34 CJK UNIFIED IDEOGRAPH-#2AF34
2AF35 CJK UNIFIED IDEOGRAPH-#2AF35
2AF36 CJK UNIFIED IDEOGRAPH-#2AF36
2AF37 CJK UNIFIED IDEOGRAPH-#2AF37
2AF38 CJK UNIFIED IDEOGRAPH-#2AF38
2AF39 CJK UNIFIED IDEOGRAPH-#2AF39
2AF3A CJK UNIFIED IDEOGRAPH-#2AF3A
2AF3B CJK UNIFIED IDEOGRAPH-#2AF3B
2AF3C CJK UNIFIED IDEOGRAPH-#2AF3C
2AF3D CJK UNIFIED IDEOGRAPH-#2AF3D
2AF3E CJK UNIFIED IDEOGRAPH-#2AF3E
2AF3F CJK UNIFIED IDEOGRAPH-#2AF3F
2AF40 CJK UNIFIED IDEOGRAPH-#2AF40
2AF41 CJK UNIFIED IDEOGRAPH-#2AF41
2AF42 CJK UNIFIED IDEOGRAPH-#2AF42
2AF43 CJK UNIFIED IDEOGRAPH-#2AF43
2AF44 CJK UNIFIED IDEOGRAPH-#2AF44
2AF45 CJK UNIFIED IDEOGRAPH-#2AF45
2AF46 CJK UNIFIED IDEOGRAPH-#2AF46
2AF47 CJK UNIFIED IDEOGRAPH-#2AF47
2AF48 CJK UNIFIED IDEOGRAPH-#2AF48
2AF49 CJK UNIFIED IDEOGRAPH-#2AF49
2AF4A CJK UNIFIED IDEOGRAPH-#2AF4A
2AF4B CJK UNIFIED IDEOGRAPH-#2AF4B
2AF4C CJK UNIFIED IDEOGRAPH-#2AF4C
2AF4D CJK UNIFIED IDEOGRAPH-#2AF4D
2AF4E CJK UNIFIED IDEOGRAPH-#2AF4E
2AF4F CJK UNIFIED IDEOGRAPH-#2AF4F
2AF50 CJK UNIFIED IDEOGRAPH-#2AF50
2AF51 CJK UNIFIED IDEOGRAPH-#2AF51
2AF52 CJK UNIFIED IDEOGRAPH-#2AF52
2AF53 CJK UNIFIED IDEOGRAPH-#2AF53
2AF54 CJK UNIFIED IDEOGRAPH-#2AF54
2AF55 CJK UNIFIED IDEOGRAPH-#2AF55
2AF56 CJK UNIFIED IDEOGRAPH-#2AF56
2AF57 CJK UNIFIED IDEOGRAPH-#2AF57
2AF58 CJK UNIFIED IDEOGRAPH-#2AF58
2AF59 CJK UNIFIED IDEOGRAPH-#2AF59
2AF5A CJK UNIFIED IDEOGRAPH-#2AF5A
2AF5B CJK UNIFIED IDEOGRAPH-#2AF5B
2AF5C CJK UNIFIED IDEOGRAPH-#2AF5C
2AF5D CJK UNIFIED IDEOGRAPH-#2AF5D
2AF5E CJK UNIFIED IDEOGRAPH-#2AF5E
2AF5F CJK UNIFIED IDEOGRAPH-#2AF5F
2AF60 CJK UNIFIED IDEOGRAPH-#2AF60
2AF61 CJK UNIFIED IDEOGRAPH-#2AF61
2AF62 CJK UNIFIED IDEOGRAPH-#2AF62
2AF63 CJK UNIFIED IDEOGRAPH-#2AF63
2AF64 CJK UNIFIED IDEOGRAPH-#2AF64
2AF65 CJK UNIFIED IDEOGRAPH-#2AF65
2AF66 CJK UNIFIED IDEOGRAPH-#2AF66
2AF67 CJK UNIFIED IDEOGRAPH-#2AF67
2AF68 CJK UNIFIED IDEOGRAPH-#2AF68
2AF69 CJK UNIFIED IDEOGRAPH-#2AF69
2AF6A CJK UNIFIED IDEOGRAPH-#2AF6A
2AF6B CJK UNIFIED IDEOGRAPH-#2AF6B
2AF6C CJK UNIFIED IDEOGRAPH-#2AF6C
2AF6D CJK UNIFIED IDEOGRAPH-#2AF6D
2AF6E CJK UNIFIED IDEOGRAPH-#2AF6E
2AF6F CJK UNIFIED IDEOGRAPH-#2AF6F
2AF70 CJK UNIFIED IDEOGRAPH-#2AF70
2AF71 CJK UNIFIED IDEOGRAPH-#2AF71
2AF72 CJK UNIFIED IDEOGRAPH-#2AF72
2AF73 CJK UNIFIED IDEOGRAPH-#2AF73
2AF74 CJK UNIFIED IDEOGRAPH-#2AF74
2AF75 CJK UNIFIED IDEOGRAPH-#2AF75
2AF76 CJK UNIFIED IDEOGRAPH-#2AF76
2AF77 CJK UNIFIED IDEOGRAPH-#2AF77
2AF78 CJK UNIFIED IDEOGRAPH-#2AF78
2AF79 CJK UNIFIED IDEOGRAPH-#2AF79
2AF7A CJK UNIFIED IDEOGRAPH-#2AF7A
2AF7B CJK UNIFIED IDEOGRAPH-#2AF7B
2AF7C CJK UNIFIED IDEOGRAPH-#2AF7C
2AF7D CJK UNIFIED IDEOGRAPH-#2AF7D
2AF7E CJK UNIFIED IDEOGRAPH-#2AF7E
2AF7F CJK UNIFIED IDEOGRAPH-#2AF7F
2AF80 CJK UNIFIED IDEOGRAPH-#2AF80
2AF81 CJK UNIFIED IDEOGRAPH-#2AF81
2AF82 CJK UNIFIED IDEOGRAPH-#2AF82
2AF83 CJK UNIFIED IDEOGRAPH-#2AF83
2AF84 CJK UNIFIED IDEOGRAPH-#2AF84
2AF85 CJK UNIFIED IDEOGRAPH-#2AF85
2AF86 CJK UNIFIED IDEOGRAPH-#2AF86
2AF87 CJK UNIFIED IDEOGRAPH-#2AF87
2AF88 CJK UNIFIED IDEOGRAPH-#2AF88
2AF89 CJK UNIFIED IDEOGRAPH-#2AF89
2AF8A CJK UNIFIED IDEOGRAPH-#2AF8A
2AF8B CJK UNIFIED IDEOGRAPH-#2AF8B
2AF8C CJK UNIFIED IDEOGRAPH-#2AF8C
2AF8D CJK UNIFIED IDEOGRAPH-#2AF8D
2AF8E CJK UNIFIED IDEOGRAPH-#2AF8E
2AF8F CJK UNIFIED IDEOGRAPH-#2AF8F
2AF90 CJK UNIFIED IDEOGRAPH-#2AF90
2AF91 CJK UNIFIED IDEOGRAPH-#2AF91
2AF92 CJK UNIFIED IDEOGRAPH-#2AF92
2AF93 CJK UNIFIED IDEOGRAPH-#2AF93
2AF94 CJK UNIFIED IDEOGRAPH-#2AF94
2AF95 CJK UNIFIED IDEOGRAPH-#2AF95
2AF96 CJK UNIFIED IDEOGRAPH-#2AF96
2AF97 CJK UNIFIED IDEOGRAPH-#2AF97
2AF98 CJK UNIFIED IDEOGRAPH-#2AF98
2AF99 CJK UNIFIED IDEOGRAPH-#2AF99
2AF9A CJK UNIFIED IDEOGRAPH-#2AF9A
2AF9B CJK UNIFIED IDEOGRAPH-#2AF9B
2AF9C CJK UNIFIED IDEOGRAPH-#2AF9C
2AF9D CJK UNIFIED IDEOGRAPH-#2AF9D
2AF9E CJK UNIFIED IDEOGRAPH-#2AF9E
2AF9F CJK UNIFIED IDEOGRAPH-#2AF9F
2AFA0 CJK UNIFIED IDEOGRAPH-#2AFA0
2AFA1 CJK UNIFIED IDEOGRAPH-#2AFA1
2AFA2 CJK UNIFIED IDEOGRAPH-#2AFA2, Def{to look at fearfully; overly cautious}
2AFA3 CJK UNIFIED IDEOGRAPH-#2AFA3
2AFA4 CJK UNIFIED IDEOGRAPH-#2AFA4
2AFA5 CJK UNIFIED IDEOGRAPH-#2AFA5
2AFA6 CJK UNIFIED IDEOGRAPH-#2AFA6
2AFA7 CJK UNIFIED IDEOGRAPH-#2AFA7
2AFA8 CJK UNIFIED IDEOGRAPH-#2AFA8
2AFA9 CJK UNIFIED IDEOGRAPH-#2AFA9
2AFAA CJK UNIFIED IDEOGRAPH-#2AFAA
2AFAB CJK UNIFIED IDEOGRAPH-#2AFAB
2AFAC CJK UNIFIED IDEOGRAPH-#2AFAC
2AFAD CJK UNIFIED IDEOGRAPH-#2AFAD
2AFAE CJK UNIFIED IDEOGRAPH-#2AFAE
2AFAF CJK UNIFIED IDEOGRAPH-#2AFAF
2AFB0 CJK UNIFIED IDEOGRAPH-#2AFB0
2AFB1 CJK UNIFIED IDEOGRAPH-#2AFB1
2AFB2 CJK UNIFIED IDEOGRAPH-#2AFB2
2AFB3 CJK UNIFIED IDEOGRAPH-#2AFB3
2AFB4 CJK UNIFIED IDEOGRAPH-#2AFB4
2AFB5 CJK UNIFIED IDEOGRAPH-#2AFB5
2AFB6 CJK UNIFIED IDEOGRAPH-#2AFB6
2AFB7 CJK UNIFIED IDEOGRAPH-#2AFB7
2AFB8 CJK UNIFIED IDEOGRAPH-#2AFB8
2AFB9 CJK UNIFIED IDEOGRAPH-#2AFB9
2AFBA CJK UNIFIED IDEOGRAPH-#2AFBA
2AFBB CJK UNIFIED IDEOGRAPH-#2AFBB
2AFBC CJK UNIFIED IDEOGRAPH-#2AFBC
2AFBD CJK UNIFIED IDEOGRAPH-#2AFBD
2AFBE CJK UNIFIED IDEOGRAPH-#2AFBE
2AFBF CJK UNIFIED IDEOGRAPH-#2AFBF
2AFC0 CJK UNIFIED IDEOGRAPH-#2AFC0
2AFC1 CJK UNIFIED IDEOGRAPH-#2AFC1
2AFC2 CJK UNIFIED IDEOGRAPH-#2AFC2
2AFC3 CJK UNIFIED IDEOGRAPH-#2AFC3
2AFC4 CJK UNIFIED IDEOGRAPH-#2AFC4
2AFC5 CJK UNIFIED IDEOGRAPH-#2AFC5
2AFC6 CJK UNIFIED IDEOGRAPH-#2AFC6
2AFC7 CJK UNIFIED IDEOGRAPH-#2AFC7
2AFC8 CJK UNIFIED IDEOGRAPH-#2AFC8
2AFC9 CJK UNIFIED IDEOGRAPH-#2AFC9
2AFCA CJK UNIFIED IDEOGRAPH-#2AFCA
2AFCB CJK UNIFIED IDEOGRAPH-#2AFCB
2AFCC CJK UNIFIED IDEOGRAPH-#2AFCC
2AFCD CJK UNIFIED IDEOGRAPH-#2AFCD
2AFCE CJK UNIFIED IDEOGRAPH-#2AFCE
2AFCF CJK UNIFIED IDEOGRAPH-#2AFCF
2AFD0 CJK UNIFIED IDEOGRAPH-#2AFD0
2AFD1 CJK UNIFIED IDEOGRAPH-#2AFD1
2AFD2 CJK UNIFIED IDEOGRAPH-#2AFD2
2AFD3 CJK UNIFIED IDEOGRAPH-#2AFD3
2AFD4 CJK UNIFIED IDEOGRAPH-#2AFD4
2AFD5 CJK UNIFIED IDEOGRAPH-#2AFD5
2AFD6 CJK UNIFIED IDEOGRAPH-#2AFD6
2AFD7 CJK UNIFIED IDEOGRAPH-#2AFD7
2AFD8 CJK UNIFIED IDEOGRAPH-#2AFD8
2AFD9 CJK UNIFIED IDEOGRAPH-#2AFD9
2AFDA CJK UNIFIED IDEOGRAPH-#2AFDA
2AFDB CJK UNIFIED IDEOGRAPH-#2AFDB
2AFDC CJK UNIFIED IDEOGRAPH-#2AFDC
2AFDD CJK UNIFIED IDEOGRAPH-#2AFDD
2AFDE CJK UNIFIED IDEOGRAPH-#2AFDE
2AFDF CJK UNIFIED IDEOGRAPH-#2AFDF
2AFE0 CJK UNIFIED IDEOGRAPH-#2AFE0
2AFE1 CJK UNIFIED IDEOGRAPH-#2AFE1
2AFE2 CJK UNIFIED IDEOGRAPH-#2AFE2
2AFE3 CJK UNIFIED IDEOGRAPH-#2AFE3
2AFE4 CJK UNIFIED IDEOGRAPH-#2AFE4
2AFE5 CJK UNIFIED IDEOGRAPH-#2AFE5
2AFE6 CJK UNIFIED IDEOGRAPH-#2AFE6
2AFE7 CJK UNIFIED IDEOGRAPH-#2AFE7
2AFE8 CJK UNIFIED IDEOGRAPH-#2AFE8
2AFE9 CJK UNIFIED IDEOGRAPH-#2AFE9
2AFEA CJK UNIFIED IDEOGRAPH-#2AFEA
2AFEB CJK UNIFIED IDEOGRAPH-#2AFEB
2AFEC CJK UNIFIED IDEOGRAPH-#2AFEC
2AFED CJK UNIFIED IDEOGRAPH-#2AFED
2AFEE CJK UNIFIED IDEOGRAPH-#2AFEE
2AFEF CJK UNIFIED IDEOGRAPH-#2AFEF
2AFF0 CJK UNIFIED IDEOGRAPH-#2AFF0
2AFF1 CJK UNIFIED IDEOGRAPH-#2AFF1
2AFF2 CJK UNIFIED IDEOGRAPH-#2AFF2
2AFF3 CJK UNIFIED IDEOGRAPH-#2AFF3
2AFF4 CJK UNIFIED IDEOGRAPH-#2AFF4
2AFF5 CJK UNIFIED IDEOGRAPH-#2AFF5
2AFF6 CJK UNIFIED IDEOGRAPH-#2AFF6
2AFF7 CJK UNIFIED IDEOGRAPH-#2AFF7
2AFF8 CJK UNIFIED IDEOGRAPH-#2AFF8
2AFF9 CJK UNIFIED IDEOGRAPH-#2AFF9
2AFFA CJK UNIFIED IDEOGRAPH-#2AFFA
2AFFB CJK UNIFIED IDEOGRAPH-#2AFFB
2AFFC CJK UNIFIED IDEOGRAPH-#2AFFC
2AFFD CJK UNIFIED IDEOGRAPH-#2AFFD
2AFFE CJK UNIFIED IDEOGRAPH-#2AFFE
2AFFF CJK UNIFIED IDEOGRAPH-#2AFFF
2B000 CJK UNIFIED IDEOGRAPH-#2B000
2B001 CJK UNIFIED IDEOGRAPH-#2B001
2B002 CJK UNIFIED IDEOGRAPH-#2B002
2B003 CJK UNIFIED IDEOGRAPH-#2B003
2B004 CJK UNIFIED IDEOGRAPH-#2B004
2B005 CJK UNIFIED IDEOGRAPH-#2B005
2B006 CJK UNIFIED IDEOGRAPH-#2B006
2B007 CJK UNIFIED IDEOGRAPH-#2B007
2B008 CJK UNIFIED IDEOGRAPH-#2B008
2B009 CJK UNIFIED IDEOGRAPH-#2B009
2B00A CJK UNIFIED IDEOGRAPH-#2B00A
2B00B CJK UNIFIED IDEOGRAPH-#2B00B
2B00C CJK UNIFIED IDEOGRAPH-#2B00C
2B00D CJK UNIFIED IDEOGRAPH-#2B00D
2B00E CJK UNIFIED IDEOGRAPH-#2B00E
2B00F CJK UNIFIED IDEOGRAPH-#2B00F
2B010 CJK UNIFIED IDEOGRAPH-#2B010
2B011 CJK UNIFIED IDEOGRAPH-#2B011
2B012 CJK UNIFIED IDEOGRAPH-#2B012
2B013 CJK UNIFIED IDEOGRAPH-#2B013
2B014 CJK UNIFIED IDEOGRAPH-#2B014
2B015 CJK UNIFIED IDEOGRAPH-#2B015
2B016 CJK UNIFIED IDEOGRAPH-#2B016
2B017 CJK UNIFIED IDEOGRAPH-#2B017
2B018 CJK UNIFIED IDEOGRAPH-#2B018
2B019 CJK UNIFIED IDEOGRAPH-#2B019
2B01A CJK UNIFIED IDEOGRAPH-#2B01A
2B01B CJK UNIFIED IDEOGRAPH-#2B01B
2B01C CJK UNIFIED IDEOGRAPH-#2B01C
2B01D CJK UNIFIED IDEOGRAPH-#2B01D
2B01E CJK UNIFIED IDEOGRAPH-#2B01E
2B01F CJK UNIFIED IDEOGRAPH-#2B01F
2B020 CJK UNIFIED IDEOGRAPH-#2B020
2B021 CJK UNIFIED IDEOGRAPH-#2B021
2B022 CJK UNIFIED IDEOGRAPH-#2B022
2B023 CJK UNIFIED IDEOGRAPH-#2B023
2B024 CJK UNIFIED IDEOGRAPH-#2B024
2B025 CJK UNIFIED IDEOGRAPH-#2B025
2B026 CJK UNIFIED IDEOGRAPH-#2B026
2B027 CJK UNIFIED IDEOGRAPH-#2B027
2B028 CJK UNIFIED IDEOGRAPH-#2B028
2B029 CJK UNIFIED IDEOGRAPH-#2B029
2B02A CJK UNIFIED IDEOGRAPH-#2B02A
2B02B CJK UNIFIED IDEOGRAPH-#2B02B
2B02C CJK UNIFIED IDEOGRAPH-#2B02C
2B02D CJK UNIFIED IDEOGRAPH-#2B02D
2B02E CJK UNIFIED IDEOGRAPH-#2B02E
2B02F CJK UNIFIED IDEOGRAPH-#2B02F
2B030 CJK UNIFIED IDEOGRAPH-#2B030
2B031 CJK UNIFIED IDEOGRAPH-#2B031
2B032 CJK UNIFIED IDEOGRAPH-#2B032
2B033 CJK UNIFIED IDEOGRAPH-#2B033
2B034 CJK UNIFIED IDEOGRAPH-#2B034
2B035 CJK UNIFIED IDEOGRAPH-#2B035
2B036 CJK UNIFIED IDEOGRAPH-#2B036
2B037 CJK UNIFIED IDEOGRAPH-#2B037
2B038 CJK UNIFIED IDEOGRAPH-#2B038
2B039 CJK UNIFIED IDEOGRAPH-#2B039
2B03A CJK UNIFIED IDEOGRAPH-#2B03A
2B03B CJK UNIFIED IDEOGRAPH-#2B03B
2B03C CJK UNIFIED IDEOGRAPH-#2B03C
2B03D CJK UNIFIED IDEOGRAPH-#2B03D
2B03E CJK UNIFIED IDEOGRAPH-#2B03E
2B03F CJK UNIFIED IDEOGRAPH-#2B03F
2B040 CJK UNIFIED IDEOGRAPH-#2B040
2B041 CJK UNIFIED IDEOGRAPH-#2B041
2B042 CJK UNIFIED IDEOGRAPH-#2B042
2B043 CJK UNIFIED IDEOGRAPH-#2B043
2B044 CJK UNIFIED IDEOGRAPH-#2B044
2B045 CJK UNIFIED IDEOGRAPH-#2B045
2B046 CJK UNIFIED IDEOGRAPH-#2B046
2B047 CJK UNIFIED IDEOGRAPH-#2B047
2B048 CJK UNIFIED IDEOGRAPH-#2B048
2B049 CJK UNIFIED IDEOGRAPH-#2B049
2B04A CJK UNIFIED IDEOGRAPH-#2B04A
2B04B CJK UNIFIED IDEOGRAPH-#2B04B
2B04C CJK UNIFIED IDEOGRAPH-#2B04C
2B04D CJK UNIFIED IDEOGRAPH-#2B04D
2B04E CJK UNIFIED IDEOGRAPH-#2B04E
2B04F CJK UNIFIED IDEOGRAPH-#2B04F
2B050 CJK UNIFIED IDEOGRAPH-#2B050
2B051 CJK UNIFIED IDEOGRAPH-#2B051
2B052 CJK UNIFIED IDEOGRAPH-#2B052
2B053 CJK UNIFIED IDEOGRAPH-#2B053
2B054 CJK UNIFIED IDEOGRAPH-#2B054
2B055 CJK UNIFIED IDEOGRAPH-#2B055
2B056 CJK UNIFIED IDEOGRAPH-#2B056
2B057 CJK UNIFIED IDEOGRAPH-#2B057
2B058 CJK UNIFIED IDEOGRAPH-#2B058
2B059 CJK UNIFIED IDEOGRAPH-#2B059
2B05A CJK UNIFIED IDEOGRAPH-#2B05A
2B05B CJK UNIFIED IDEOGRAPH-#2B05B
2B05C CJK UNIFIED IDEOGRAPH-#2B05C
2B05D CJK UNIFIED IDEOGRAPH-#2B05D
2B05E CJK UNIFIED IDEOGRAPH-#2B05E
2B05F CJK UNIFIED IDEOGRAPH-#2B05F
2B060 CJK UNIFIED IDEOGRAPH-#2B060
2B061 CJK UNIFIED IDEOGRAPH-#2B061, Def{kingfisher}
2B062 CJK UNIFIED IDEOGRAPH-#2B062
2B063 CJK UNIFIED IDEOGRAPH-#2B063
2B064 CJK UNIFIED IDEOGRAPH-#2B064
2B065 CJK UNIFIED IDEOGRAPH-#2B065
2B066 CJK UNIFIED IDEOGRAPH-#2B066
2B067 CJK UNIFIED IDEOGRAPH-#2B067
2B068 CJK UNIFIED IDEOGRAPH-#2B068
2B069 CJK UNIFIED IDEOGRAPH-#2B069
2B06A CJK UNIFIED IDEOGRAPH-#2B06A
2B06B CJK UNIFIED IDEOGRAPH-#2B06B
2B06C CJK UNIFIED IDEOGRAPH-#2B06C
2B06D CJK UNIFIED IDEOGRAPH-#2B06D
2B06E CJK UNIFIED IDEOGRAPH-#2B06E
2B06F CJK UNIFIED IDEOGRAPH-#2B06F
2B070 CJK UNIFIED IDEOGRAPH-#2B070
2B071 CJK UNIFIED IDEOGRAPH-#2B071
2B072 CJK UNIFIED IDEOGRAPH-#2B072
2B073 CJK UNIFIED IDEOGRAPH-#2B073
2B074 CJK UNIFIED IDEOGRAPH-#2B074
2B075 CJK UNIFIED IDEOGRAPH-#2B075
2B076 CJK UNIFIED IDEOGRAPH-#2B076
2B077 CJK UNIFIED IDEOGRAPH-#2B077
2B078 CJK UNIFIED IDEOGRAPH-#2B078
2B079 CJK UNIFIED IDEOGRAPH-#2B079
2B07A CJK UNIFIED IDEOGRAPH-#2B07A
2B07B CJK UNIFIED IDEOGRAPH-#2B07B
2B07C CJK UNIFIED IDEOGRAPH-#2B07C
2B07D CJK UNIFIED IDEOGRAPH-#2B07D
2B07E CJK UNIFIED IDEOGRAPH-#2B07E
2B07F CJK UNIFIED IDEOGRAPH-#2B07F
2B080 CJK UNIFIED IDEOGRAPH-#2B080
2B081 CJK UNIFIED IDEOGRAPH-#2B081
2B082 CJK UNIFIED IDEOGRAPH-#2B082
2B083 CJK UNIFIED IDEOGRAPH-#2B083
2B084 CJK UNIFIED IDEOGRAPH-#2B084
2B085 CJK UNIFIED IDEOGRAPH-#2B085
2B086 CJK UNIFIED IDEOGRAPH-#2B086
2B087 CJK UNIFIED IDEOGRAPH-#2B087
2B088 CJK UNIFIED IDEOGRAPH-#2B088, Def{coarse bamboo mats}
2B089 CJK UNIFIED IDEOGRAPH-#2B089
2B08A CJK UNIFIED IDEOGRAPH-#2B08A
2B08B CJK UNIFIED IDEOGRAPH-#2B08B
2B08C CJK UNIFIED IDEOGRAPH-#2B08C
2B08D CJK UNIFIED IDEOGRAPH-#2B08D
2B08E CJK UNIFIED IDEOGRAPH-#2B08E
2B08F CJK UNIFIED IDEOGRAPH-#2B08F
2B090 CJK UNIFIED IDEOGRAPH-#2B090
2B091 CJK UNIFIED IDEOGRAPH-#2B091
2B092 CJK UNIFIED IDEOGRAPH-#2B092
2B093 CJK UNIFIED IDEOGRAPH-#2B093
2B094 CJK UNIFIED IDEOGRAPH-#2B094
2B095 CJK UNIFIED IDEOGRAPH-#2B095
2B096 CJK UNIFIED IDEOGRAPH-#2B096
2B097 CJK UNIFIED IDEOGRAPH-#2B097
2B098 CJK UNIFIED IDEOGRAPH-#2B098
2B099 CJK UNIFIED IDEOGRAPH-#2B099, Def{luxuriant and dense vegetation; a fine sieve}
2B09A CJK UNIFIED IDEOGRAPH-#2B09A
2B09B CJK UNIFIED IDEOGRAPH-#2B09B
2B09C CJK UNIFIED IDEOGRAPH-#2B09C
2B09D CJK UNIFIED IDEOGRAPH-#2B09D
2B09E CJK UNIFIED IDEOGRAPH-#2B09E
2B09F CJK UNIFIED IDEOGRAPH-#2B09F
2B0A0 CJK UNIFIED IDEOGRAPH-#2B0A0
2B0A1 CJK UNIFIED IDEOGRAPH-#2B0A1
2B0A2 CJK UNIFIED IDEOGRAPH-#2B0A2
2B0A3 CJK UNIFIED IDEOGRAPH-#2B0A3
2B0A4 CJK UNIFIED IDEOGRAPH-#2B0A4
2B0A5 CJK UNIFIED IDEOGRAPH-#2B0A5
2B0A6 CJK UNIFIED IDEOGRAPH-#2B0A6
2B0A7 CJK UNIFIED IDEOGRAPH-#2B0A7
2B0A8 CJK UNIFIED IDEOGRAPH-#2B0A8
2B0A9 CJK UNIFIED IDEOGRAPH-#2B0A9
2B0AA CJK UNIFIED IDEOGRAPH-#2B0AA
2B0AB CJK UNIFIED IDEOGRAPH-#2B0AB
2B0AC CJK UNIFIED IDEOGRAPH-#2B0AC
2B0AD CJK UNIFIED IDEOGRAPH-#2B0AD
2B0AE CJK UNIFIED IDEOGRAPH-#2B0AE
2B0AF CJK UNIFIED IDEOGRAPH-#2B0AF
2B0B0 CJK UNIFIED IDEOGRAPH-#2B0B0
2B0B1 CJK UNIFIED IDEOGRAPH-#2B0B1
2B0B2 CJK UNIFIED IDEOGRAPH-#2B0B2
2B0B3 CJK UNIFIED IDEOGRAPH-#2B0B3
2B0B4 CJK UNIFIED IDEOGRAPH-#2B0B4
2B0B5 CJK UNIFIED IDEOGRAPH-#2B0B5
2B0B6 CJK UNIFIED IDEOGRAPH-#2B0B6
2B0B7 CJK UNIFIED IDEOGRAPH-#2B0B7
2B0B8 CJK UNIFIED IDEOGRAPH-#2B0B8
2B0B9 CJK UNIFIED IDEOGRAPH-#2B0B9
2B0BA CJK UNIFIED IDEOGRAPH-#2B0BA
2B0BB CJK UNIFIED IDEOGRAPH-#2B0BB
2B0BC CJK UNIFIED IDEOGRAPH-#2B0BC
2B0BD CJK UNIFIED IDEOGRAPH-#2B0BD
2B0BE CJK UNIFIED IDEOGRAPH-#2B0BE
2B0BF CJK UNIFIED IDEOGRAPH-#2B0BF
2B0C0 CJK UNIFIED IDEOGRAPH-#2B0C0
2B0C1 CJK UNIFIED IDEOGRAPH-#2B0C1
2B0C2 CJK UNIFIED IDEOGRAPH-#2B0C2
2B0C3 CJK UNIFIED IDEOGRAPH-#2B0C3
2B0C4 CJK UNIFIED IDEOGRAPH-#2B0C4
2B0C5 CJK UNIFIED IDEOGRAPH-#2B0C5
2B0C6 CJK UNIFIED IDEOGRAPH-#2B0C6
2B0C7 CJK UNIFIED IDEOGRAPH-#2B0C7
2B0C8 CJK UNIFIED IDEOGRAPH-#2B0C8
2B0C9 CJK UNIFIED IDEOGRAPH-#2B0C9
2B0CA CJK UNIFIED IDEOGRAPH-#2B0CA
2B0CB CJK UNIFIED IDEOGRAPH-#2B0CB
2B0CC CJK UNIFIED IDEOGRAPH-#2B0CC
2B0CD CJK UNIFIED IDEOGRAPH-#2B0CD
2B0CE CJK UNIFIED IDEOGRAPH-#2B0CE
2B0CF CJK UNIFIED IDEOGRAPH-#2B0CF
2B0D0 CJK UNIFIED IDEOGRAPH-#2B0D0
2B0D1 CJK UNIFIED IDEOGRAPH-#2B0D1
2B0D2 CJK UNIFIED IDEOGRAPH-#2B0D2
2B0D3 CJK UNIFIED IDEOGRAPH-#2B0D3
2B0D4 CJK UNIFIED IDEOGRAPH-#2B0D4
2B0D5 CJK UNIFIED IDEOGRAPH-#2B0D5
2B0D6 CJK UNIFIED IDEOGRAPH-#2B0D6
2B0D7 CJK UNIFIED IDEOGRAPH-#2B0D7
2B0D8 CJK UNIFIED IDEOGRAPH-#2B0D8
2B0D9 CJK UNIFIED IDEOGRAPH-#2B0D9
2B0DA CJK UNIFIED IDEOGRAPH-#2B0DA
2B0DB CJK UNIFIED IDEOGRAPH-#2B0DB
2B0DC CJK UNIFIED IDEOGRAPH-#2B0DC, Def{a button; a plaited knob; to fasten; to hook back}
2B0DD CJK UNIFIED IDEOGRAPH-#2B0DD
2B0DE CJK UNIFIED IDEOGRAPH-#2B0DE
2B0DF CJK UNIFIED IDEOGRAPH-#2B0DF
2B0E0 CJK UNIFIED IDEOGRAPH-#2B0E0
2B0E1 CJK UNIFIED IDEOGRAPH-#2B0E1
2B0E2 CJK UNIFIED IDEOGRAPH-#2B0E2
2B0E3 CJK UNIFIED IDEOGRAPH-#2B0E3
2B0E4 CJK UNIFIED IDEOGRAPH-#2B0E4
2B0E5 CJK UNIFIED IDEOGRAPH-#2B0E5
2B0E6 CJK UNIFIED IDEOGRAPH-#2B0E6
2B0E7 CJK UNIFIED IDEOGRAPH-#2B0E7
2B0E8 CJK UNIFIED IDEOGRAPH-#2B0E8
2B0E9 CJK UNIFIED IDEOGRAPH-#2B0E9
2B0EA CJK UNIFIED IDEOGRAPH-#2B0EA
2B0EB CJK UNIFIED IDEOGRAPH-#2B0EB
2B0EC CJK UNIFIED IDEOGRAPH-#2B0EC
2B0ED CJK UNIFIED IDEOGRAPH-#2B0ED
2B0EE CJK UNIFIED IDEOGRAPH-#2B0EE
2B0EF CJK UNIFIED IDEOGRAPH-#2B0EF
2B0F0 CJK UNIFIED IDEOGRAPH-#2B0F0
2B0F1 CJK UNIFIED IDEOGRAPH-#2B0F1
2B0F2 CJK UNIFIED IDEOGRAPH-#2B0F2
2B0F3 CJK UNIFIED IDEOGRAPH-#2B0F3
2B0F4 CJK UNIFIED IDEOGRAPH-#2B0F4
2B0F5 CJK UNIFIED IDEOGRAPH-#2B0F5
2B0F6 CJK UNIFIED IDEOGRAPH-#2B0F6
2B0F7 CJK UNIFIED IDEOGRAPH-#2B0F7
2B0F8 CJK UNIFIED IDEOGRAPH-#2B0F8
2B0F9 CJK UNIFIED IDEOGRAPH-#2B0F9
2B0FA CJK UNIFIED IDEOGRAPH-#2B0FA
2B0FB CJK UNIFIED IDEOGRAPH-#2B0FB
2B0FC CJK UNIFIED IDEOGRAPH-#2B0FC
2B0FD CJK UNIFIED IDEOGRAPH-#2B0FD
2B0FE CJK UNIFIED IDEOGRAPH-#2B0FE
2B0FF CJK UNIFIED IDEOGRAPH-#2B0FF
2B100 CJK UNIFIED IDEOGRAPH-#2B100
2B101 CJK UNIFIED IDEOGRAPH-#2B101
2B102 CJK UNIFIED IDEOGRAPH-#2B102
2B103 CJK UNIFIED IDEOGRAPH-#2B103
2B104 CJK UNIFIED IDEOGRAPH-#2B104
2B105 CJK UNIFIED IDEOGRAPH-#2B105
2B106 CJK UNIFIED IDEOGRAPH-#2B106
2B107 CJK UNIFIED IDEOGRAPH-#2B107
2B108 CJK UNIFIED IDEOGRAPH-#2B108
2B109 CJK UNIFIED IDEOGRAPH-#2B109
2B10A CJK UNIFIED IDEOGRAPH-#2B10A
2B10B CJK UNIFIED IDEOGRAPH-#2B10B
2B10C CJK UNIFIED IDEOGRAPH-#2B10C
2B10D CJK UNIFIED IDEOGRAPH-#2B10D
2B10E CJK UNIFIED IDEOGRAPH-#2B10E
2B10F CJK UNIFIED IDEOGRAPH-#2B10F
2B110 CJK UNIFIED IDEOGRAPH-#2B110
2B111 CJK UNIFIED IDEOGRAPH-#2B111
2B112 CJK UNIFIED IDEOGRAPH-#2B112
2B113 CJK UNIFIED IDEOGRAPH-#2B113
2B114 CJK UNIFIED IDEOGRAPH-#2B114
2B115 CJK UNIFIED IDEOGRAPH-#2B115
2B116 CJK UNIFIED IDEOGRAPH-#2B116
2B117 CJK UNIFIED IDEOGRAPH-#2B117
2B118 CJK UNIFIED IDEOGRAPH-#2B118
2B119 CJK UNIFIED IDEOGRAPH-#2B119
2B11A CJK UNIFIED IDEOGRAPH-#2B11A
2B11B CJK UNIFIED IDEOGRAPH-#2B11B
2B11C CJK UNIFIED IDEOGRAPH-#2B11C
2B11D CJK UNIFIED IDEOGRAPH-#2B11D
2B11E CJK UNIFIED IDEOGRAPH-#2B11E
2B11F CJK UNIFIED IDEOGRAPH-#2B11F
2B120 CJK UNIFIED IDEOGRAPH-#2B120
2B121 CJK UNIFIED IDEOGRAPH-#2B121
2B122 CJK UNIFIED IDEOGRAPH-#2B122
2B123 CJK UNIFIED IDEOGRAPH-#2B123
2B124 CJK UNIFIED IDEOGRAPH-#2B124
2B125 CJK UNIFIED IDEOGRAPH-#2B125
2B126 CJK UNIFIED IDEOGRAPH-#2B126
2B127 CJK UNIFIED IDEOGRAPH-#2B127
2B128 CJK UNIFIED IDEOGRAPH-#2B128, Def{fine linen, fine help cloth}
2B129 CJK UNIFIED IDEOGRAPH-#2B129
2B12A CJK UNIFIED IDEOGRAPH-#2B12A
2B12B CJK UNIFIED IDEOGRAPH-#2B12B
2B12C CJK UNIFIED IDEOGRAPH-#2B12C
2B12D CJK UNIFIED IDEOGRAPH-#2B12D
2B12E CJK UNIFIED IDEOGRAPH-#2B12E
2B12F CJK UNIFIED IDEOGRAPH-#2B12F
2B130 CJK UNIFIED IDEOGRAPH-#2B130
2B131 CJK UNIFIED IDEOGRAPH-#2B131
2B132 CJK UNIFIED IDEOGRAPH-#2B132
2B133 CJK UNIFIED IDEOGRAPH-#2B133
2B134 CJK UNIFIED IDEOGRAPH-#2B134
2B135 CJK UNIFIED IDEOGRAPH-#2B135
2B136 CJK UNIFIED IDEOGRAPH-#2B136
2B137 CJK UNIFIED IDEOGRAPH-#2B137
2B138 CJK UNIFIED IDEOGRAPH-#2B138, Def{light red, pink}
2B139 CJK UNIFIED IDEOGRAPH-#2B139
2B13A CJK UNIFIED IDEOGRAPH-#2B13A
2B13B CJK UNIFIED IDEOGRAPH-#2B13B
2B13C CJK UNIFIED IDEOGRAPH-#2B13C
2B13D CJK UNIFIED IDEOGRAPH-#2B13D
2B13E CJK UNIFIED IDEOGRAPH-#2B13E
2B13F CJK UNIFIED IDEOGRAPH-#2B13F
2B140 CJK UNIFIED IDEOGRAPH-#2B140
2B141 CJK UNIFIED IDEOGRAPH-#2B141
2B142 CJK UNIFIED IDEOGRAPH-#2B142
2B143 CJK UNIFIED IDEOGRAPH-#2B143
2B144 CJK UNIFIED IDEOGRAPH-#2B144
2B145 CJK UNIFIED IDEOGRAPH-#2B145
2B146 CJK UNIFIED IDEOGRAPH-#2B146
2B147 CJK UNIFIED IDEOGRAPH-#2B147
2B148 CJK UNIFIED IDEOGRAPH-#2B148
2B149 CJK UNIFIED IDEOGRAPH-#2B149
2B14A CJK UNIFIED IDEOGRAPH-#2B14A
2B14B CJK UNIFIED IDEOGRAPH-#2B14B
2B14C CJK UNIFIED IDEOGRAPH-#2B14C
2B14D CJK UNIFIED IDEOGRAPH-#2B14D
2B14E CJK UNIFIED IDEOGRAPH-#2B14E
2B14F CJK UNIFIED IDEOGRAPH-#2B14F
2B150 CJK UNIFIED IDEOGRAPH-#2B150
2B151 CJK UNIFIED IDEOGRAPH-#2B151
2B152 CJK UNIFIED IDEOGRAPH-#2B152
2B153 CJK UNIFIED IDEOGRAPH-#2B153
2B154 CJK UNIFIED IDEOGRAPH-#2B154
2B155 CJK UNIFIED IDEOGRAPH-#2B155
2B156 CJK UNIFIED IDEOGRAPH-#2B156
2B157 CJK UNIFIED IDEOGRAPH-#2B157
2B158 CJK UNIFIED IDEOGRAPH-#2B158
2B159 CJK UNIFIED IDEOGRAPH-#2B159
2B15A CJK UNIFIED IDEOGRAPH-#2B15A
2B15B CJK UNIFIED IDEOGRAPH-#2B15B
2B15C CJK UNIFIED IDEOGRAPH-#2B15C
2B15D CJK UNIFIED IDEOGRAPH-#2B15D
2B15E CJK UNIFIED IDEOGRAPH-#2B15E
2B15F CJK UNIFIED IDEOGRAPH-#2B15F
2B160 CJK UNIFIED IDEOGRAPH-#2B160
2B161 CJK UNIFIED IDEOGRAPH-#2B161
2B162 CJK UNIFIED IDEOGRAPH-#2B162
2B163 CJK UNIFIED IDEOGRAPH-#2B163
2B164 CJK UNIFIED IDEOGRAPH-#2B164
2B165 CJK UNIFIED IDEOGRAPH-#2B165
2B166 CJK UNIFIED IDEOGRAPH-#2B166
2B167 CJK UNIFIED IDEOGRAPH-#2B167
2B168 CJK UNIFIED IDEOGRAPH-#2B168
2B169 CJK UNIFIED IDEOGRAPH-#2B169
2B16A CJK UNIFIED IDEOGRAPH-#2B16A
2B16B CJK UNIFIED IDEOGRAPH-#2B16B
2B16C CJK UNIFIED IDEOGRAPH-#2B16C
2B16D CJK UNIFIED IDEOGRAPH-#2B16D
2B16E CJK UNIFIED IDEOGRAPH-#2B16E
2B16F CJK UNIFIED IDEOGRAPH-#2B16F
2B170 CJK UNIFIED IDEOGRAPH-#2B170
2B171 CJK UNIFIED IDEOGRAPH-#2B171
2B172 CJK UNIFIED IDEOGRAPH-#2B172
2B173 CJK UNIFIED IDEOGRAPH-#2B173
2B174 CJK UNIFIED IDEOGRAPH-#2B174
2B175 CJK UNIFIED IDEOGRAPH-#2B175
2B176 CJK UNIFIED IDEOGRAPH-#2B176
2B177 CJK UNIFIED IDEOGRAPH-#2B177
2B178 CJK UNIFIED IDEOGRAPH-#2B178
2B179 CJK UNIFIED IDEOGRAPH-#2B179
2B17A CJK UNIFIED IDEOGRAPH-#2B17A
2B17B CJK UNIFIED IDEOGRAPH-#2B17B
2B17C CJK UNIFIED IDEOGRAPH-#2B17C
2B17D CJK UNIFIED IDEOGRAPH-#2B17D
2B17E CJK UNIFIED IDEOGRAPH-#2B17E
2B17F CJK UNIFIED IDEOGRAPH-#2B17F
2B180 CJK UNIFIED IDEOGRAPH-#2B180
2B181 CJK UNIFIED IDEOGRAPH-#2B181
2B182 CJK UNIFIED IDEOGRAPH-#2B182
2B183 CJK UNIFIED IDEOGRAPH-#2B183
2B184 CJK UNIFIED IDEOGRAPH-#2B184
2B185 CJK UNIFIED IDEOGRAPH-#2B185
2B186 CJK UNIFIED IDEOGRAPH-#2B186
2B187 CJK UNIFIED IDEOGRAPH-#2B187
2B188 CJK UNIFIED IDEOGRAPH-#2B188
2B189 CJK UNIFIED IDEOGRAPH-#2B189
2B18A CJK UNIFIED IDEOGRAPH-#2B18A
2B18B CJK UNIFIED IDEOGRAPH-#2B18B
2B18C CJK UNIFIED IDEOGRAPH-#2B18C
2B18D CJK UNIFIED IDEOGRAPH-#2B18D
2B18E CJK UNIFIED IDEOGRAPH-#2B18E
2B18F CJK UNIFIED IDEOGRAPH-#2B18F
2B190 CJK UNIFIED IDEOGRAPH-#2B190
2B191 CJK UNIFIED IDEOGRAPH-#2B191
2B192 CJK UNIFIED IDEOGRAPH-#2B192
2B193 CJK UNIFIED IDEOGRAPH-#2B193
2B194 CJK UNIFIED IDEOGRAPH-#2B194
2B195 CJK UNIFIED IDEOGRAPH-#2B195
2B196 CJK UNIFIED IDEOGRAPH-#2B196
2B197 CJK UNIFIED IDEOGRAPH-#2B197
2B198 CJK UNIFIED IDEOGRAPH-#2B198
2B199 CJK UNIFIED IDEOGRAPH-#2B199
2B19A CJK UNIFIED IDEOGRAPH-#2B19A
2B19B CJK UNIFIED IDEOGRAPH-#2B19B
2B19C CJK UNIFIED IDEOGRAPH-#2B19C
2B19D CJK UNIFIED IDEOGRAPH-#2B19D
2B19E CJK UNIFIED IDEOGRAPH-#2B19E
2B19F CJK UNIFIED IDEOGRAPH-#2B19F
2B1A0 CJK UNIFIED IDEOGRAPH-#2B1A0
2B1A1 CJK UNIFIED IDEOGRAPH-#2B1A1
2B1A2 CJK UNIFIED IDEOGRAPH-#2B1A2
2B1A3 CJK UNIFIED IDEOGRAPH-#2B1A3
2B1A4 CJK UNIFIED IDEOGRAPH-#2B1A4
2B1A5 CJK UNIFIED IDEOGRAPH-#2B1A5
2B1A6 CJK UNIFIED IDEOGRAPH-#2B1A6
2B1A7 CJK UNIFIED IDEOGRAPH-#2B1A7
2B1A8 CJK UNIFIED IDEOGRAPH-#2B1A8
2B1A9 CJK UNIFIED IDEOGRAPH-#2B1A9
2B1AA CJK UNIFIED IDEOGRAPH-#2B1AA
2B1AB CJK UNIFIED IDEOGRAPH-#2B1AB
2B1AC CJK UNIFIED IDEOGRAPH-#2B1AC
2B1AD CJK UNIFIED IDEOGRAPH-#2B1AD
2B1AE CJK UNIFIED IDEOGRAPH-#2B1AE
2B1AF CJK UNIFIED IDEOGRAPH-#2B1AF
2B1B0 CJK UNIFIED IDEOGRAPH-#2B1B0
2B1B1 CJK UNIFIED IDEOGRAPH-#2B1B1
2B1B2 CJK UNIFIED IDEOGRAPH-#2B1B2
2B1B3 CJK UNIFIED IDEOGRAPH-#2B1B3
2B1B4 CJK UNIFIED IDEOGRAPH-#2B1B4
2B1B5 CJK UNIFIED IDEOGRAPH-#2B1B5
2B1B6 CJK UNIFIED IDEOGRAPH-#2B1B6
2B1B7 CJK UNIFIED IDEOGRAPH-#2B1B7
2B1B8 CJK UNIFIED IDEOGRAPH-#2B1B8
2B1B9 CJK UNIFIED IDEOGRAPH-#2B1B9
2B1BA CJK UNIFIED IDEOGRAPH-#2B1BA
2B1BB CJK UNIFIED IDEOGRAPH-#2B1BB
2B1BC CJK UNIFIED IDEOGRAPH-#2B1BC
2B1BD CJK UNIFIED IDEOGRAPH-#2B1BD
2B1BE CJK UNIFIED IDEOGRAPH-#2B1BE
2B1BF CJK UNIFIED IDEOGRAPH-#2B1BF
2B1C0 CJK UNIFIED IDEOGRAPH-#2B1C0
2B1C1 CJK UNIFIED IDEOGRAPH-#2B1C1
2B1C2 CJK UNIFIED IDEOGRAPH-#2B1C2
2B1C3 CJK UNIFIED IDEOGRAPH-#2B1C3
2B1C4 CJK UNIFIED IDEOGRAPH-#2B1C4
2B1C5 CJK UNIFIED IDEOGRAPH-#2B1C5
2B1C6 CJK UNIFIED IDEOGRAPH-#2B1C6
2B1C7 CJK UNIFIED IDEOGRAPH-#2B1C7
2B1C8 CJK UNIFIED IDEOGRAPH-#2B1C8
2B1C9 CJK UNIFIED IDEOGRAPH-#2B1C9
2B1CA CJK UNIFIED IDEOGRAPH-#2B1CA
2B1CB CJK UNIFIED IDEOGRAPH-#2B1CB
2B1CC CJK UNIFIED IDEOGRAPH-#2B1CC
2B1CD CJK UNIFIED IDEOGRAPH-#2B1CD
2B1CE CJK UNIFIED IDEOGRAPH-#2B1CE
2B1CF CJK UNIFIED IDEOGRAPH-#2B1CF
2B1D0 CJK UNIFIED IDEOGRAPH-#2B1D0
2B1D1 CJK UNIFIED IDEOGRAPH-#2B1D1
2B1D2 CJK UNIFIED IDEOGRAPH-#2B1D2
2B1D3 CJK UNIFIED IDEOGRAPH-#2B1D3
2B1D4 CJK UNIFIED IDEOGRAPH-#2B1D4
2B1D5 CJK UNIFIED IDEOGRAPH-#2B1D5
2B1D6 CJK UNIFIED IDEOGRAPH-#2B1D6
2B1D7 CJK UNIFIED IDEOGRAPH-#2B1D7
2B1D8 CJK UNIFIED IDEOGRAPH-#2B1D8
2B1D9 CJK UNIFIED IDEOGRAPH-#2B1D9
2B1DA CJK UNIFIED IDEOGRAPH-#2B1DA
2B1DB CJK UNIFIED IDEOGRAPH-#2B1DB
2B1DC CJK UNIFIED IDEOGRAPH-#2B1DC
2B1DD CJK UNIFIED IDEOGRAPH-#2B1DD
2B1DE CJK UNIFIED IDEOGRAPH-#2B1DE
2B1DF CJK UNIFIED IDEOGRAPH-#2B1DF
2B1E0 CJK UNIFIED IDEOGRAPH-#2B1E0
2B1E1 CJK UNIFIED IDEOGRAPH-#2B1E1
2B1E2 CJK UNIFIED IDEOGRAPH-#2B1E2
2B1E3 CJK UNIFIED IDEOGRAPH-#2B1E3
2B1E4 CJK UNIFIED IDEOGRAPH-#2B1E4
2B1E5 CJK UNIFIED IDEOGRAPH-#2B1E5
2B1E6 CJK UNIFIED IDEOGRAPH-#2B1E6
2B1E7 CJK UNIFIED IDEOGRAPH-#2B1E7
2B1E8 CJK UNIFIED IDEOGRAPH-#2B1E8
2B1E9 CJK UNIFIED IDEOGRAPH-#2B1E9
2B1EA CJK UNIFIED IDEOGRAPH-#2B1EA
2B1EB CJK UNIFIED IDEOGRAPH-#2B1EB
2B1EC CJK UNIFIED IDEOGRAPH-#2B1EC
2B1ED CJK UNIFIED IDEOGRAPH-#2B1ED
2B1EE CJK UNIFIED IDEOGRAPH-#2B1EE
2B1EF CJK UNIFIED IDEOGRAPH-#2B1EF
2B1F0 CJK UNIFIED IDEOGRAPH-#2B1F0
2B1F1 CJK UNIFIED IDEOGRAPH-#2B1F1
2B1F2 CJK UNIFIED IDEOGRAPH-#2B1F2
2B1F3 CJK UNIFIED IDEOGRAPH-#2B1F3
2B1F4 CJK UNIFIED IDEOGRAPH-#2B1F4
2B1F5 CJK UNIFIED IDEOGRAPH-#2B1F5
2B1F6 CJK UNIFIED IDEOGRAPH-#2B1F6
2B1F7 CJK UNIFIED IDEOGRAPH-#2B1F7
2B1F8 CJK UNIFIED IDEOGRAPH-#2B1F8
2B1F9 CJK UNIFIED IDEOGRAPH-#2B1F9
2B1FA CJK UNIFIED IDEOGRAPH-#2B1FA
2B1FB CJK UNIFIED IDEOGRAPH-#2B1FB
2B1FC CJK UNIFIED IDEOGRAPH-#2B1FC
2B1FD CJK UNIFIED IDEOGRAPH-#2B1FD
2B1FE CJK UNIFIED IDEOGRAPH-#2B1FE
2B1FF CJK UNIFIED IDEOGRAPH-#2B1FF
2B200 CJK UNIFIED IDEOGRAPH-#2B200
2B201 CJK UNIFIED IDEOGRAPH-#2B201
2B202 CJK UNIFIED IDEOGRAPH-#2B202
2B203 CJK UNIFIED IDEOGRAPH-#2B203
2B204 CJK UNIFIED IDEOGRAPH-#2B204
2B205 CJK UNIFIED IDEOGRAPH-#2B205
2B206 CJK UNIFIED IDEOGRAPH-#2B206
2B207 CJK UNIFIED IDEOGRAPH-#2B207
2B208 CJK UNIFIED IDEOGRAPH-#2B208
2B209 CJK UNIFIED IDEOGRAPH-#2B209
2B20A CJK UNIFIED IDEOGRAPH-#2B20A
2B20B CJK UNIFIED IDEOGRAPH-#2B20B
2B20C CJK UNIFIED IDEOGRAPH-#2B20C
2B20D CJK UNIFIED IDEOGRAPH-#2B20D
2B20E CJK UNIFIED IDEOGRAPH-#2B20E
2B20F CJK UNIFIED IDEOGRAPH-#2B20F
2B210 CJK UNIFIED IDEOGRAPH-#2B210
2B211 CJK UNIFIED IDEOGRAPH-#2B211
2B212 CJK UNIFIED IDEOGRAPH-#2B212
2B213 CJK UNIFIED IDEOGRAPH-#2B213
2B214 CJK UNIFIED IDEOGRAPH-#2B214
2B215 CJK UNIFIED IDEOGRAPH-#2B215
2B216 CJK UNIFIED IDEOGRAPH-#2B216
2B217 CJK UNIFIED IDEOGRAPH-#2B217
2B218 CJK UNIFIED IDEOGRAPH-#2B218
2B219 CJK UNIFIED IDEOGRAPH-#2B219
2B21A CJK UNIFIED IDEOGRAPH-#2B21A
2B21B CJK UNIFIED IDEOGRAPH-#2B21B
2B21C CJK UNIFIED IDEOGRAPH-#2B21C
2B21D CJK UNIFIED IDEOGRAPH-#2B21D
2B21E CJK UNIFIED IDEOGRAPH-#2B21E
2B21F CJK UNIFIED IDEOGRAPH-#2B21F
2B220 CJK UNIFIED IDEOGRAPH-#2B220
2B221 CJK UNIFIED IDEOGRAPH-#2B221
2B222 CJK UNIFIED IDEOGRAPH-#2B222
2B223 CJK UNIFIED IDEOGRAPH-#2B223
2B224 CJK UNIFIED IDEOGRAPH-#2B224
2B225 CJK UNIFIED IDEOGRAPH-#2B225
2B226 CJK UNIFIED IDEOGRAPH-#2B226
2B227 CJK UNIFIED IDEOGRAPH-#2B227
2B228 CJK UNIFIED IDEOGRAPH-#2B228
2B229 CJK UNIFIED IDEOGRAPH-#2B229
2B22A CJK UNIFIED IDEOGRAPH-#2B22A
2B22B CJK UNIFIED IDEOGRAPH-#2B22B
2B22C CJK UNIFIED IDEOGRAPH-#2B22C
2B22D CJK UNIFIED IDEOGRAPH-#2B22D
2B22E CJK UNIFIED IDEOGRAPH-#2B22E
2B22F CJK UNIFIED IDEOGRAPH-#2B22F
2B230 CJK UNIFIED IDEOGRAPH-#2B230, Def{june grass}
2B231 CJK UNIFIED IDEOGRAPH-#2B231
2B232 CJK UNIFIED IDEOGRAPH-#2B232
2B233 CJK UNIFIED IDEOGRAPH-#2B233
2B234 CJK UNIFIED IDEOGRAPH-#2B234
2B235 CJK UNIFIED IDEOGRAPH-#2B235
2B236 CJK UNIFIED IDEOGRAPH-#2B236
2B237 CJK UNIFIED IDEOGRAPH-#2B237
2B238 CJK UNIFIED IDEOGRAPH-#2B238
2B239 CJK UNIFIED IDEOGRAPH-#2B239
2B23A CJK UNIFIED IDEOGRAPH-#2B23A
2B23B CJK UNIFIED IDEOGRAPH-#2B23B
2B23C CJK UNIFIED IDEOGRAPH-#2B23C
2B23D CJK UNIFIED IDEOGRAPH-#2B23D
2B23E CJK UNIFIED IDEOGRAPH-#2B23E
2B23F CJK UNIFIED IDEOGRAPH-#2B23F
2B240 CJK UNIFIED IDEOGRAPH-#2B240
2B241 CJK UNIFIED IDEOGRAPH-#2B241
2B242 CJK UNIFIED IDEOGRAPH-#2B242
2B243 CJK UNIFIED IDEOGRAPH-#2B243
2B244 CJK UNIFIED IDEOGRAPH-#2B244
2B245 CJK UNIFIED IDEOGRAPH-#2B245
2B246 CJK UNIFIED IDEOGRAPH-#2B246
2B247 CJK UNIFIED IDEOGRAPH-#2B247
2B248 CJK UNIFIED IDEOGRAPH-#2B248
2B249 CJK UNIFIED IDEOGRAPH-#2B249
2B24A CJK UNIFIED IDEOGRAPH-#2B24A
2B24B CJK UNIFIED IDEOGRAPH-#2B24B
2B24C CJK UNIFIED IDEOGRAPH-#2B24C
2B24D CJK UNIFIED IDEOGRAPH-#2B24D
2B24E CJK UNIFIED IDEOGRAPH-#2B24E
2B24F CJK UNIFIED IDEOGRAPH-#2B24F
2B250 CJK UNIFIED IDEOGRAPH-#2B250
2B251 CJK UNIFIED IDEOGRAPH-#2B251
2B252 CJK UNIFIED IDEOGRAPH-#2B252
2B253 CJK UNIFIED IDEOGRAPH-#2B253
2B254 CJK UNIFIED IDEOGRAPH-#2B254
2B255 CJK UNIFIED IDEOGRAPH-#2B255
2B256 CJK UNIFIED IDEOGRAPH-#2B256
2B257 CJK UNIFIED IDEOGRAPH-#2B257
2B258 CJK UNIFIED IDEOGRAPH-#2B258
2B259 CJK UNIFIED IDEOGRAPH-#2B259
2B25A CJK UNIFIED IDEOGRAPH-#2B25A
2B25B CJK UNIFIED IDEOGRAPH-#2B25B
2B25C CJK UNIFIED IDEOGRAPH-#2B25C
2B25D CJK UNIFIED IDEOGRAPH-#2B25D
2B25E CJK UNIFIED IDEOGRAPH-#2B25E
2B25F CJK UNIFIED IDEOGRAPH-#2B25F
2B260 CJK UNIFIED IDEOGRAPH-#2B260
2B261 CJK UNIFIED IDEOGRAPH-#2B261
2B262 CJK UNIFIED IDEOGRAPH-#2B262
2B263 CJK UNIFIED IDEOGRAPH-#2B263
2B264 CJK UNIFIED IDEOGRAPH-#2B264
2B265 CJK UNIFIED IDEOGRAPH-#2B265
2B266 CJK UNIFIED IDEOGRAPH-#2B266
2B267 CJK UNIFIED IDEOGRAPH-#2B267
2B268 CJK UNIFIED IDEOGRAPH-#2B268
2B269 CJK UNIFIED IDEOGRAPH-#2B269
2B26A CJK UNIFIED IDEOGRAPH-#2B26A
2B26B CJK UNIFIED IDEOGRAPH-#2B26B
2B26C CJK UNIFIED IDEOGRAPH-#2B26C
2B26D CJK UNIFIED IDEOGRAPH-#2B26D
2B26E CJK UNIFIED IDEOGRAPH-#2B26E
2B26F CJK UNIFIED IDEOGRAPH-#2B26F
2B270 CJK UNIFIED IDEOGRAPH-#2B270
2B271 CJK UNIFIED IDEOGRAPH-#2B271
2B272 CJK UNIFIED IDEOGRAPH-#2B272
2B273 CJK UNIFIED IDEOGRAPH-#2B273
2B274 CJK UNIFIED IDEOGRAPH-#2B274
2B275 CJK UNIFIED IDEOGRAPH-#2B275
2B276 CJK UNIFIED IDEOGRAPH-#2B276
2B277 CJK UNIFIED IDEOGRAPH-#2B277
2B278 CJK UNIFIED IDEOGRAPH-#2B278
2B279 CJK UNIFIED IDEOGRAPH-#2B279
2B27A CJK UNIFIED IDEOGRAPH-#2B27A
2B27B CJK UNIFIED IDEOGRAPH-#2B27B
2B27C CJK UNIFIED IDEOGRAPH-#2B27C
2B27D CJK UNIFIED IDEOGRAPH-#2B27D
2B27E CJK UNIFIED IDEOGRAPH-#2B27E
2B27F CJK UNIFIED IDEOGRAPH-#2B27F
2B280 CJK UNIFIED IDEOGRAPH-#2B280
2B281 CJK UNIFIED IDEOGRAPH-#2B281
2B282 CJK UNIFIED IDEOGRAPH-#2B282
2B283 CJK UNIFIED IDEOGRAPH-#2B283
2B284 CJK UNIFIED IDEOGRAPH-#2B284
2B285 CJK UNIFIED IDEOGRAPH-#2B285
2B286 CJK UNIFIED IDEOGRAPH-#2B286
2B287 CJK UNIFIED IDEOGRAPH-#2B287
2B288 CJK UNIFIED IDEOGRAPH-#2B288
2B289 CJK UNIFIED IDEOGRAPH-#2B289
2B28A CJK UNIFIED IDEOGRAPH-#2B28A
2B28B CJK UNIFIED IDEOGRAPH-#2B28B
2B28C CJK UNIFIED IDEOGRAPH-#2B28C
2B28D CJK UNIFIED IDEOGRAPH-#2B28D
2B28E CJK UNIFIED IDEOGRAPH-#2B28E
2B28F CJK UNIFIED IDEOGRAPH-#2B28F
2B290 CJK UNIFIED IDEOGRAPH-#2B290
2B291 CJK UNIFIED IDEOGRAPH-#2B291
2B292 CJK UNIFIED IDEOGRAPH-#2B292
2B293 CJK UNIFIED IDEOGRAPH-#2B293
2B294 CJK UNIFIED IDEOGRAPH-#2B294
2B295 CJK UNIFIED IDEOGRAPH-#2B295
2B296 CJK UNIFIED IDEOGRAPH-#2B296
2B297 CJK UNIFIED IDEOGRAPH-#2B297
2B298 CJK UNIFIED IDEOGRAPH-#2B298
2B299 CJK UNIFIED IDEOGRAPH-#2B299
2B29A CJK UNIFIED IDEOGRAPH-#2B29A
2B29B CJK UNIFIED IDEOGRAPH-#2B29B
2B29C CJK UNIFIED IDEOGRAPH-#2B29C
2B29D CJK UNIFIED IDEOGRAPH-#2B29D
2B29E CJK UNIFIED IDEOGRAPH-#2B29E
2B29F CJK UNIFIED IDEOGRAPH-#2B29F
2B2A0 CJK UNIFIED IDEOGRAPH-#2B2A0
2B2A1 CJK UNIFIED IDEOGRAPH-#2B2A1
2B2A2 CJK UNIFIED IDEOGRAPH-#2B2A2
2B2A3 CJK UNIFIED IDEOGRAPH-#2B2A3
2B2A4 CJK UNIFIED IDEOGRAPH-#2B2A4
2B2A5 CJK UNIFIED IDEOGRAPH-#2B2A5
2B2A6 CJK UNIFIED IDEOGRAPH-#2B2A6
2B2A7 CJK UNIFIED IDEOGRAPH-#2B2A7
2B2A8 CJK UNIFIED IDEOGRAPH-#2B2A8
2B2A9 CJK UNIFIED IDEOGRAPH-#2B2A9
2B2AA CJK UNIFIED IDEOGRAPH-#2B2AA
2B2AB CJK UNIFIED IDEOGRAPH-#2B2AB
2B2AC CJK UNIFIED IDEOGRAPH-#2B2AC
2B2AD CJK UNIFIED IDEOGRAPH-#2B2AD
2B2AE CJK UNIFIED IDEOGRAPH-#2B2AE
2B2AF CJK UNIFIED IDEOGRAPH-#2B2AF
2B2B0 CJK UNIFIED IDEOGRAPH-#2B2B0
2B2B1 CJK UNIFIED IDEOGRAPH-#2B2B1
2B2B2 CJK UNIFIED IDEOGRAPH-#2B2B2
2B2B3 CJK UNIFIED IDEOGRAPH-#2B2B3
2B2B4 CJK UNIFIED IDEOGRAPH-#2B2B4
2B2B5 CJK UNIFIED IDEOGRAPH-#2B2B5
2B2B6 CJK UNIFIED IDEOGRAPH-#2B2B6
2B2B7 CJK UNIFIED IDEOGRAPH-#2B2B7
2B2B8 CJK UNIFIED IDEOGRAPH-#2B2B8
2B2B9 CJK UNIFIED IDEOGRAPH-#2B2B9
2B2BA CJK UNIFIED IDEOGRAPH-#2B2BA
2B2BB CJK UNIFIED IDEOGRAPH-#2B2BB
2B2BC CJK UNIFIED IDEOGRAPH-#2B2BC
2B2BD CJK UNIFIED IDEOGRAPH-#2B2BD
2B2BE CJK UNIFIED IDEOGRAPH-#2B2BE
2B2BF CJK UNIFIED IDEOGRAPH-#2B2BF
2B2C0 CJK UNIFIED IDEOGRAPH-#2B2C0
2B2C1 CJK UNIFIED IDEOGRAPH-#2B2C1
2B2C2 CJK UNIFIED IDEOGRAPH-#2B2C2
2B2C3 CJK UNIFIED IDEOGRAPH-#2B2C3
2B2C4 CJK UNIFIED IDEOGRAPH-#2B2C4
2B2C5 CJK UNIFIED IDEOGRAPH-#2B2C5
2B2C6 CJK UNIFIED IDEOGRAPH-#2B2C6
2B2C7 CJK UNIFIED IDEOGRAPH-#2B2C7
2B2C8 CJK UNIFIED IDEOGRAPH-#2B2C8
2B2C9 CJK UNIFIED IDEOGRAPH-#2B2C9
2B2CA CJK UNIFIED IDEOGRAPH-#2B2CA
2B2CB CJK UNIFIED IDEOGRAPH-#2B2CB
2B2CC CJK UNIFIED IDEOGRAPH-#2B2CC
2B2CD CJK UNIFIED IDEOGRAPH-#2B2CD
2B2CE CJK UNIFIED IDEOGRAPH-#2B2CE
2B2CF CJK UNIFIED IDEOGRAPH-#2B2CF
2B2D0 CJK UNIFIED IDEOGRAPH-#2B2D0, Def{to wriggle; to work through, as smoke through a crevice}
2B2D1 CJK UNIFIED IDEOGRAPH-#2B2D1
2B2D2 CJK UNIFIED IDEOGRAPH-#2B2D2
2B2D3 CJK UNIFIED IDEOGRAPH-#2B2D3
2B2D4 CJK UNIFIED IDEOGRAPH-#2B2D4
2B2D5 CJK UNIFIED IDEOGRAPH-#2B2D5
2B2D6 CJK UNIFIED IDEOGRAPH-#2B2D6
2B2D7 CJK UNIFIED IDEOGRAPH-#2B2D7
2B2D8 CJK UNIFIED IDEOGRAPH-#2B2D8
2B2D9 CJK UNIFIED IDEOGRAPH-#2B2D9
2B2DA CJK UNIFIED IDEOGRAPH-#2B2DA
2B2DB CJK UNIFIED IDEOGRAPH-#2B2DB
2B2DC CJK UNIFIED IDEOGRAPH-#2B2DC
2B2DD CJK UNIFIED IDEOGRAPH-#2B2DD
2B2DE CJK UNIFIED IDEOGRAPH-#2B2DE
2B2DF CJK UNIFIED IDEOGRAPH-#2B2DF
2B2E0 CJK UNIFIED IDEOGRAPH-#2B2E0
2B2E1 CJK UNIFIED IDEOGRAPH-#2B2E1
2B2E2 CJK UNIFIED IDEOGRAPH-#2B2E2
2B2E3 CJK UNIFIED IDEOGRAPH-#2B2E3
2B2E4 CJK UNIFIED IDEOGRAPH-#2B2E4
2B2E5 CJK UNIFIED IDEOGRAPH-#2B2E5
2B2E6 CJK UNIFIED IDEOGRAPH-#2B2E6
2B2E7 CJK UNIFIED IDEOGRAPH-#2B2E7
2B2E8 CJK UNIFIED IDEOGRAPH-#2B2E8
2B2E9 CJK UNIFIED IDEOGRAPH-#2B2E9
2B2EA CJK UNIFIED IDEOGRAPH-#2B2EA
2B2EB CJK UNIFIED IDEOGRAPH-#2B2EB
2B2EC CJK UNIFIED IDEOGRAPH-#2B2EC
2B2ED CJK UNIFIED IDEOGRAPH-#2B2ED
2B2EE CJK UNIFIED IDEOGRAPH-#2B2EE
2B2EF CJK UNIFIED IDEOGRAPH-#2B2EF
2B2F0 CJK UNIFIED IDEOGRAPH-#2B2F0
2B2F1 CJK UNIFIED IDEOGRAPH-#2B2F1
2B2F2 CJK UNIFIED IDEOGRAPH-#2B2F2
2B2F3 CJK UNIFIED IDEOGRAPH-#2B2F3
2B2F4 CJK UNIFIED IDEOGRAPH-#2B2F4
2B2F5 CJK UNIFIED IDEOGRAPH-#2B2F5
2B2F6 CJK UNIFIED IDEOGRAPH-#2B2F6
2B2F7 CJK UNIFIED IDEOGRAPH-#2B2F7
2B2F8 CJK UNIFIED IDEOGRAPH-#2B2F8
2B2F9 CJK UNIFIED IDEOGRAPH-#2B2F9
2B2FA CJK UNIFIED IDEOGRAPH-#2B2FA
2B2FB CJK UNIFIED IDEOGRAPH-#2B2FB
2B2FC CJK UNIFIED IDEOGRAPH-#2B2FC
2B2FD CJK UNIFIED IDEOGRAPH-#2B2FD
2B2FE CJK UNIFIED IDEOGRAPH-#2B2FE
2B2FF CJK UNIFIED IDEOGRAPH-#2B2FF
2B300 CJK UNIFIED IDEOGRAPH-#2B300, Def{a pleat, fold, tuck, crease}
2B301 CJK UNIFIED IDEOGRAPH-#2B301
2B302 CJK UNIFIED IDEOGRAPH-#2B302
2B303 CJK UNIFIED IDEOGRAPH-#2B303
2B304 CJK UNIFIED IDEOGRAPH-#2B304
2B305 CJK UNIFIED IDEOGRAPH-#2B305
2B306 CJK UNIFIED IDEOGRAPH-#2B306
2B307 CJK UNIFIED IDEOGRAPH-#2B307
2B308 CJK UNIFIED IDEOGRAPH-#2B308
2B309 CJK UNIFIED IDEOGRAPH-#2B309
2B30A CJK UNIFIED IDEOGRAPH-#2B30A
2B30B CJK UNIFIED IDEOGRAPH-#2B30B
2B30C CJK UNIFIED IDEOGRAPH-#2B30C
2B30D CJK UNIFIED IDEOGRAPH-#2B30D
2B30E CJK UNIFIED IDEOGRAPH-#2B30E
2B30F CJK UNIFIED IDEOGRAPH-#2B30F
2B310 CJK UNIFIED IDEOGRAPH-#2B310
2B311 CJK UNIFIED IDEOGRAPH-#2B311
2B312 CJK UNIFIED IDEOGRAPH-#2B312
2B313 CJK UNIFIED IDEOGRAPH-#2B313
2B314 CJK UNIFIED IDEOGRAPH-#2B314
2B315 CJK UNIFIED IDEOGRAPH-#2B315
2B316 CJK UNIFIED IDEOGRAPH-#2B316
2B317 CJK UNIFIED IDEOGRAPH-#2B317
2B318 CJK UNIFIED IDEOGRAPH-#2B318
2B319 CJK UNIFIED IDEOGRAPH-#2B319
2B31A CJK UNIFIED IDEOGRAPH-#2B31A
2B31B CJK UNIFIED IDEOGRAPH-#2B31B
2B31C CJK UNIFIED IDEOGRAPH-#2B31C
2B31D CJK UNIFIED IDEOGRAPH-#2B31D
2B31E CJK UNIFIED IDEOGRAPH-#2B31E
2B31F CJK UNIFIED IDEOGRAPH-#2B31F
2B320 CJK UNIFIED IDEOGRAPH-#2B320
2B321 CJK UNIFIED IDEOGRAPH-#2B321
2B322 CJK UNIFIED IDEOGRAPH-#2B322
2B323 CJK UNIFIED IDEOGRAPH-#2B323
2B324 CJK UNIFIED IDEOGRAPH-#2B324
2B325 CJK UNIFIED IDEOGRAPH-#2B325
2B326 CJK UNIFIED IDEOGRAPH-#2B326
2B327 CJK UNIFIED IDEOGRAPH-#2B327
2B328 CJK UNIFIED IDEOGRAPH-#2B328, Def{to explain in detail}
2B329 CJK UNIFIED IDEOGRAPH-#2B329
2B32A CJK UNIFIED IDEOGRAPH-#2B32A
2B32B CJK UNIFIED IDEOGRAPH-#2B32B
2B32C CJK UNIFIED IDEOGRAPH-#2B32C
2B32D CJK UNIFIED IDEOGRAPH-#2B32D
2B32E CJK UNIFIED IDEOGRAPH-#2B32E
2B32F CJK UNIFIED IDEOGRAPH-#2B32F
2B330 CJK UNIFIED IDEOGRAPH-#2B330
2B331 CJK UNIFIED IDEOGRAPH-#2B331
2B332 CJK UNIFIED IDEOGRAPH-#2B332
2B333 CJK UNIFIED IDEOGRAPH-#2B333
2B334 CJK UNIFIED IDEOGRAPH-#2B334
2B335 CJK UNIFIED IDEOGRAPH-#2B335
2B336 CJK UNIFIED IDEOGRAPH-#2B336
2B337 CJK UNIFIED IDEOGRAPH-#2B337
2B338 CJK UNIFIED IDEOGRAPH-#2B338
2B339 CJK UNIFIED IDEOGRAPH-#2B339
2B33A CJK UNIFIED IDEOGRAPH-#2B33A
2B33B CJK UNIFIED IDEOGRAPH-#2B33B
2B33C CJK UNIFIED IDEOGRAPH-#2B33C
2B33D CJK UNIFIED IDEOGRAPH-#2B33D
2B33E CJK UNIFIED IDEOGRAPH-#2B33E
2B33F CJK UNIFIED IDEOGRAPH-#2B33F
2B340 CJK UNIFIED IDEOGRAPH-#2B340
2B341 CJK UNIFIED IDEOGRAPH-#2B341
2B342 CJK UNIFIED IDEOGRAPH-#2B342
2B343 CJK UNIFIED IDEOGRAPH-#2B343
2B344 CJK UNIFIED IDEOGRAPH-#2B344
2B345 CJK UNIFIED IDEOGRAPH-#2B345
2B346 CJK UNIFIED IDEOGRAPH-#2B346
2B347 CJK UNIFIED IDEOGRAPH-#2B347
2B348 CJK UNIFIED IDEOGRAPH-#2B348
2B349 CJK UNIFIED IDEOGRAPH-#2B349
2B34A CJK UNIFIED IDEOGRAPH-#2B34A
2B34B CJK UNIFIED IDEOGRAPH-#2B34B
2B34C CJK UNIFIED IDEOGRAPH-#2B34C
2B34D CJK UNIFIED IDEOGRAPH-#2B34D
2B34E CJK UNIFIED IDEOGRAPH-#2B34E
2B34F CJK UNIFIED IDEOGRAPH-#2B34F
2B350 CJK UNIFIED IDEOGRAPH-#2B350
2B351 CJK UNIFIED IDEOGRAPH-#2B351
2B352 CJK UNIFIED IDEOGRAPH-#2B352
2B353 CJK UNIFIED IDEOGRAPH-#2B353
2B354 CJK UNIFIED IDEOGRAPH-#2B354
2B355 CJK UNIFIED IDEOGRAPH-#2B355
2B356 CJK UNIFIED IDEOGRAPH-#2B356
2B357 CJK UNIFIED IDEOGRAPH-#2B357
2B358 CJK UNIFIED IDEOGRAPH-#2B358
2B359 CJK UNIFIED IDEOGRAPH-#2B359, Def{arrogant, overbearing, mean; to deceive, cheat}
2B35A CJK UNIFIED IDEOGRAPH-#2B35A
2B35B CJK UNIFIED IDEOGRAPH-#2B35B
2B35C CJK UNIFIED IDEOGRAPH-#2B35C
2B35D CJK UNIFIED IDEOGRAPH-#2B35D
2B35E CJK UNIFIED IDEOGRAPH-#2B35E
2B35F CJK UNIFIED IDEOGRAPH-#2B35F
2B360 CJK UNIFIED IDEOGRAPH-#2B360
2B361 CJK UNIFIED IDEOGRAPH-#2B361
2B362 CJK UNIFIED IDEOGRAPH-#2B362, Def{wrangling; to quarrel}
2B363 CJK UNIFIED IDEOGRAPH-#2B363
2B364 CJK UNIFIED IDEOGRAPH-#2B364
2B365 CJK UNIFIED IDEOGRAPH-#2B365
2B366 CJK UNIFIED IDEOGRAPH-#2B366
2B367 CJK UNIFIED IDEOGRAPH-#2B367
2B368 CJK UNIFIED IDEOGRAPH-#2B368
2B369 CJK UNIFIED IDEOGRAPH-#2B369
2B36A CJK UNIFIED IDEOGRAPH-#2B36A
2B36B CJK UNIFIED IDEOGRAPH-#2B36B
2B36C CJK UNIFIED IDEOGRAPH-#2B36C
2B36D CJK UNIFIED IDEOGRAPH-#2B36D
2B36E CJK UNIFIED IDEOGRAPH-#2B36E
2B36F CJK UNIFIED IDEOGRAPH-#2B36F
2B370 CJK UNIFIED IDEOGRAPH-#2B370, Def{apprehensive}
2B371 CJK UNIFIED IDEOGRAPH-#2B371
2B372 CJK UNIFIED IDEOGRAPH-#2B372, Def{scold, censure; lead people toward virtuous ways; small, little}
2B373 CJK UNIFIED IDEOGRAPH-#2B373
2B374 CJK UNIFIED IDEOGRAPH-#2B374
2B375 CJK UNIFIED IDEOGRAPH-#2B375
2B376 CJK UNIFIED IDEOGRAPH-#2B376
2B377 CJK UNIFIED IDEOGRAPH-#2B377
2B378 CJK UNIFIED IDEOGRAPH-#2B378
2B379 CJK UNIFIED IDEOGRAPH-#2B379
2B37A CJK UNIFIED IDEOGRAPH-#2B37A
2B37B CJK UNIFIED IDEOGRAPH-#2B37B
2B37C CJK UNIFIED IDEOGRAPH-#2B37C
2B37D CJK UNIFIED IDEOGRAPH-#2B37D
2B37E CJK UNIFIED IDEOGRAPH-#2B37E
2B37F CJK UNIFIED IDEOGRAPH-#2B37F
2B380 CJK UNIFIED IDEOGRAPH-#2B380
2B381 CJK UNIFIED IDEOGRAPH-#2B381
2B382 CJK UNIFIED IDEOGRAPH-#2B382
2B383 CJK UNIFIED IDEOGRAPH-#2B383
2B384 CJK UNIFIED IDEOGRAPH-#2B384
2B385 CJK UNIFIED IDEOGRAPH-#2B385
2B386 CJK UNIFIED IDEOGRAPH-#2B386
2B387 CJK UNIFIED IDEOGRAPH-#2B387
2B388 CJK UNIFIED IDEOGRAPH-#2B388
2B389 CJK UNIFIED IDEOGRAPH-#2B389
2B38A CJK UNIFIED IDEOGRAPH-#2B38A
2B38B CJK UNIFIED IDEOGRAPH-#2B38B
2B38C CJK UNIFIED IDEOGRAPH-#2B38C
2B38D CJK UNIFIED IDEOGRAPH-#2B38D
2B38E CJK UNIFIED IDEOGRAPH-#2B38E
2B38F CJK UNIFIED IDEOGRAPH-#2B38F
2B390 CJK UNIFIED IDEOGRAPH-#2B390
2B391 CJK UNIFIED IDEOGRAPH-#2B391
2B392 CJK UNIFIED IDEOGRAPH-#2B392
2B393 CJK UNIFIED IDEOGRAPH-#2B393
2B394 CJK UNIFIED IDEOGRAPH-#2B394
2B395 CJK UNIFIED IDEOGRAPH-#2B395
2B396 CJK UNIFIED IDEOGRAPH-#2B396
2B397 CJK UNIFIED IDEOGRAPH-#2B397
2B398 CJK UNIFIED IDEOGRAPH-#2B398
2B399 CJK UNIFIED IDEOGRAPH-#2B399
2B39A CJK UNIFIED IDEOGRAPH-#2B39A
2B39B CJK UNIFIED IDEOGRAPH-#2B39B
2B39C CJK UNIFIED IDEOGRAPH-#2B39C
2B39D CJK UNIFIED IDEOGRAPH-#2B39D
2B39E CJK UNIFIED IDEOGRAPH-#2B39E
2B39F CJK UNIFIED IDEOGRAPH-#2B39F
2B3A0 CJK UNIFIED IDEOGRAPH-#2B3A0
2B3A1 CJK UNIFIED IDEOGRAPH-#2B3A1
2B3A2 CJK UNIFIED IDEOGRAPH-#2B3A2
2B3A3 CJK UNIFIED IDEOGRAPH-#2B3A3
2B3A4 CJK UNIFIED IDEOGRAPH-#2B3A4
2B3A5 CJK UNIFIED IDEOGRAPH-#2B3A5
2B3A6 CJK UNIFIED IDEOGRAPH-#2B3A6
2B3A7 CJK UNIFIED IDEOGRAPH-#2B3A7
2B3A8 CJK UNIFIED IDEOGRAPH-#2B3A8
2B3A9 CJK UNIFIED IDEOGRAPH-#2B3A9
2B3AA CJK UNIFIED IDEOGRAPH-#2B3AA
2B3AB CJK UNIFIED IDEOGRAPH-#2B3AB
2B3AC CJK UNIFIED IDEOGRAPH-#2B3AC
2B3AD CJK UNIFIED IDEOGRAPH-#2B3AD
2B3AE CJK UNIFIED IDEOGRAPH-#2B3AE
2B3AF CJK UNIFIED IDEOGRAPH-#2B3AF
2B3B0 CJK UNIFIED IDEOGRAPH-#2B3B0
2B3B1 CJK UNIFIED IDEOGRAPH-#2B3B1
2B3B2 CJK UNIFIED IDEOGRAPH-#2B3B2
2B3B3 CJK UNIFIED IDEOGRAPH-#2B3B3
2B3B4 CJK UNIFIED IDEOGRAPH-#2B3B4
2B3B5 CJK UNIFIED IDEOGRAPH-#2B3B5
2B3B6 CJK UNIFIED IDEOGRAPH-#2B3B6
2B3B7 CJK UNIFIED IDEOGRAPH-#2B3B7
2B3B8 CJK UNIFIED IDEOGRAPH-#2B3B8
2B3B9 CJK UNIFIED IDEOGRAPH-#2B3B9
2B3BA CJK UNIFIED IDEOGRAPH-#2B3BA
2B3BB CJK UNIFIED IDEOGRAPH-#2B3BB
2B3BC CJK UNIFIED IDEOGRAPH-#2B3BC
2B3BD CJK UNIFIED IDEOGRAPH-#2B3BD
2B3BE CJK UNIFIED IDEOGRAPH-#2B3BE
2B3BF CJK UNIFIED IDEOGRAPH-#2B3BF
2B3C0 CJK UNIFIED IDEOGRAPH-#2B3C0
2B3C1 CJK UNIFIED IDEOGRAPH-#2B3C1
2B3C2 CJK UNIFIED IDEOGRAPH-#2B3C2
2B3C3 CJK UNIFIED IDEOGRAPH-#2B3C3
2B3C4 CJK UNIFIED IDEOGRAPH-#2B3C4
2B3C5 CJK UNIFIED IDEOGRAPH-#2B3C5
2B3C6 CJK UNIFIED IDEOGRAPH-#2B3C6
2B3C7 CJK UNIFIED IDEOGRAPH-#2B3C7
2B3C8 CJK UNIFIED IDEOGRAPH-#2B3C8
2B3C9 CJK UNIFIED IDEOGRAPH-#2B3C9
2B3CA CJK UNIFIED IDEOGRAPH-#2B3CA
2B3CB CJK UNIFIED IDEOGRAPH-#2B3CB, Def{to raise the feet; to cross the legs; brave; sandals}
2B3CC CJK UNIFIED IDEOGRAPH-#2B3CC
2B3CD CJK UNIFIED IDEOGRAPH-#2B3CD
2B3CE CJK UNIFIED IDEOGRAPH-#2B3CE
2B3CF CJK UNIFIED IDEOGRAPH-#2B3CF
2B3D0 CJK UNIFIED IDEOGRAPH-#2B3D0
2B3D1 CJK UNIFIED IDEOGRAPH-#2B3D1
2B3D2 CJK UNIFIED IDEOGRAPH-#2B3D2
2B3D3 CJK UNIFIED IDEOGRAPH-#2B3D3
2B3D4 CJK UNIFIED IDEOGRAPH-#2B3D4
2B3D5 CJK UNIFIED IDEOGRAPH-#2B3D5
2B3D6 CJK UNIFIED IDEOGRAPH-#2B3D6
2B3D7 CJK UNIFIED IDEOGRAPH-#2B3D7
2B3D8 CJK UNIFIED IDEOGRAPH-#2B3D8
2B3D9 CJK UNIFIED IDEOGRAPH-#2B3D9
2B3DA CJK UNIFIED IDEOGRAPH-#2B3DA
2B3DB CJK UNIFIED IDEOGRAPH-#2B3DB
2B3DC CJK UNIFIED IDEOGRAPH-#2B3DC
2B3DD CJK UNIFIED IDEOGRAPH-#2B3DD
2B3DE CJK UNIFIED IDEOGRAPH-#2B3DE
2B3DF CJK UNIFIED IDEOGRAPH-#2B3DF
2B3E0 CJK UNIFIED IDEOGRAPH-#2B3E0
2B3E1 CJK UNIFIED IDEOGRAPH-#2B3E1
2B3E2 CJK UNIFIED IDEOGRAPH-#2B3E2
2B3E3 CJK UNIFIED IDEOGRAPH-#2B3E3
2B3E4 CJK UNIFIED IDEOGRAPH-#2B3E4
2B3E5 CJK UNIFIED IDEOGRAPH-#2B3E5
2B3E6 CJK UNIFIED IDEOGRAPH-#2B3E6
2B3E7 CJK UNIFIED IDEOGRAPH-#2B3E7
2B3E8 CJK UNIFIED IDEOGRAPH-#2B3E8
2B3E9 CJK UNIFIED IDEOGRAPH-#2B3E9
2B3EA CJK UNIFIED IDEOGRAPH-#2B3EA
2B3EB CJK UNIFIED IDEOGRAPH-#2B3EB
2B3EC CJK UNIFIED IDEOGRAPH-#2B3EC
2B3ED CJK UNIFIED IDEOGRAPH-#2B3ED
2B3EE CJK UNIFIED IDEOGRAPH-#2B3EE
2B3EF CJK UNIFIED IDEOGRAPH-#2B3EF
2B3F0 CJK UNIFIED IDEOGRAPH-#2B3F0
2B3F1 CJK UNIFIED IDEOGRAPH-#2B3F1
2B3F2 CJK UNIFIED IDEOGRAPH-#2B3F2
2B3F3 CJK UNIFIED IDEOGRAPH-#2B3F3
2B3F4 CJK UNIFIED IDEOGRAPH-#2B3F4
2B3F5 CJK UNIFIED IDEOGRAPH-#2B3F5
2B3F6 CJK UNIFIED IDEOGRAPH-#2B3F6
2B3F7 CJK UNIFIED IDEOGRAPH-#2B3F7
2B3F8 CJK UNIFIED IDEOGRAPH-#2B3F8
2B3F9 CJK UNIFIED IDEOGRAPH-#2B3F9
2B3FA CJK UNIFIED IDEOGRAPH-#2B3FA
2B3FB CJK UNIFIED IDEOGRAPH-#2B3FB
2B3FC CJK UNIFIED IDEOGRAPH-#2B3FC
2B3FD CJK UNIFIED IDEOGRAPH-#2B3FD
2B3FE CJK UNIFIED IDEOGRAPH-#2B3FE
2B3FF CJK UNIFIED IDEOGRAPH-#2B3FF
2B400 CJK UNIFIED IDEOGRAPH-#2B400
2B401 CJK UNIFIED IDEOGRAPH-#2B401
2B402 CJK UNIFIED IDEOGRAPH-#2B402
2B403 CJK UNIFIED IDEOGRAPH-#2B403
2B404 CJK UNIFIED IDEOGRAPH-#2B404, Def{cross-bar at the end of the poles of a cart}
2B405 CJK UNIFIED IDEOGRAPH-#2B405
2B406 CJK UNIFIED IDEOGRAPH-#2B406, Def{to gallop; a mule}
2B407 CJK UNIFIED IDEOGRAPH-#2B407
2B408 CJK UNIFIED IDEOGRAPH-#2B408
2B409 CJK UNIFIED IDEOGRAPH-#2B409, Def{wooden cross-piece on front inside of carriage box}
2B40A CJK UNIFIED IDEOGRAPH-#2B40A
2B40B CJK UNIFIED IDEOGRAPH-#2B40B
2B40C CJK UNIFIED IDEOGRAPH-#2B40C
2B40D CJK UNIFIED IDEOGRAPH-#2B40D
2B40E CJK UNIFIED IDEOGRAPH-#2B40E
2B40F CJK UNIFIED IDEOGRAPH-#2B40F
2B410 CJK UNIFIED IDEOGRAPH-#2B410, Def{the cross-bar at the end of a carriage pole; linchpin of a large carriage}
2B411 CJK UNIFIED IDEOGRAPH-#2B411
2B412 CJK UNIFIED IDEOGRAPH-#2B412
2B413 CJK UNIFIED IDEOGRAPH-#2B413, Def{outer rim of a wheel, felly}
2B414 CJK UNIFIED IDEOGRAPH-#2B414
2B415 CJK UNIFIED IDEOGRAPH-#2B415
2B416 CJK UNIFIED IDEOGRAPH-#2B416
2B417 CJK UNIFIED IDEOGRAPH-#2B417
2B418 CJK UNIFIED IDEOGRAPH-#2B418
2B419 CJK UNIFIED IDEOGRAPH-#2B419
2B41A CJK UNIFIED IDEOGRAPH-#2B41A
2B41B CJK UNIFIED IDEOGRAPH-#2B41B
2B41C CJK UNIFIED IDEOGRAPH-#2B41C
2B41D CJK UNIFIED IDEOGRAPH-#2B41D
2B41E CJK UNIFIED IDEOGRAPH-#2B41E
2B41F CJK UNIFIED IDEOGRAPH-#2B41F
2B420 CJK UNIFIED IDEOGRAPH-#2B420
2B421 CJK UNIFIED IDEOGRAPH-#2B421
2B422 CJK UNIFIED IDEOGRAPH-#2B422
2B423 CJK UNIFIED IDEOGRAPH-#2B423
2B424 CJK UNIFIED IDEOGRAPH-#2B424
2B425 CJK UNIFIED IDEOGRAPH-#2B425
2B426 CJK UNIFIED IDEOGRAPH-#2B426
2B427 CJK UNIFIED IDEOGRAPH-#2B427
2B428 CJK UNIFIED IDEOGRAPH-#2B428
2B429 CJK UNIFIED IDEOGRAPH-#2B429
2B42A CJK UNIFIED IDEOGRAPH-#2B42A
2B42B CJK UNIFIED IDEOGRAPH-#2B42B
2B42C CJK UNIFIED IDEOGRAPH-#2B42C
2B42D CJK UNIFIED IDEOGRAPH-#2B42D
2B42E CJK UNIFIED IDEOGRAPH-#2B42E
2B42F CJK UNIFIED IDEOGRAPH-#2B42F
2B430 CJK UNIFIED IDEOGRAPH-#2B430
2B431 CJK UNIFIED IDEOGRAPH-#2B431
2B432 CJK UNIFIED IDEOGRAPH-#2B432
2B433 CJK UNIFIED IDEOGRAPH-#2B433
2B434 CJK UNIFIED IDEOGRAPH-#2B434
2B435 CJK UNIFIED IDEOGRAPH-#2B435
2B436 CJK UNIFIED IDEOGRAPH-#2B436
2B437 CJK UNIFIED IDEOGRAPH-#2B437
2B438 CJK UNIFIED IDEOGRAPH-#2B438
2B439 CJK UNIFIED IDEOGRAPH-#2B439
2B43A CJK UNIFIED IDEOGRAPH-#2B43A
2B43B CJK UNIFIED IDEOGRAPH-#2B43B
2B43C CJK UNIFIED IDEOGRAPH-#2B43C
2B43D CJK UNIFIED IDEOGRAPH-#2B43D
2B43E CJK UNIFIED IDEOGRAPH-#2B43E
2B43F CJK UNIFIED IDEOGRAPH-#2B43F
2B440 CJK UNIFIED IDEOGRAPH-#2B440
2B441 CJK UNIFIED IDEOGRAPH-#2B441
2B442 CJK UNIFIED IDEOGRAPH-#2B442
2B443 CJK UNIFIED IDEOGRAPH-#2B443
2B444 CJK UNIFIED IDEOGRAPH-#2B444
2B445 CJK UNIFIED IDEOGRAPH-#2B445
2B446 CJK UNIFIED IDEOGRAPH-#2B446
2B447 CJK UNIFIED IDEOGRAPH-#2B447
2B448 CJK UNIFIED IDEOGRAPH-#2B448
2B449 CJK UNIFIED IDEOGRAPH-#2B449
2B44A CJK UNIFIED IDEOGRAPH-#2B44A
2B44B CJK UNIFIED IDEOGRAPH-#2B44B
2B44C CJK UNIFIED IDEOGRAPH-#2B44C
2B44D CJK UNIFIED IDEOGRAPH-#2B44D
2B44E CJK UNIFIED IDEOGRAPH-#2B44E
2B44F CJK UNIFIED IDEOGRAPH-#2B44F
2B450 CJK UNIFIED IDEOGRAPH-#2B450
2B451 CJK UNIFIED IDEOGRAPH-#2B451
2B452 CJK UNIFIED IDEOGRAPH-#2B452
2B453 CJK UNIFIED IDEOGRAPH-#2B453
2B454 CJK UNIFIED IDEOGRAPH-#2B454
2B455 CJK UNIFIED IDEOGRAPH-#2B455
2B456 CJK UNIFIED IDEOGRAPH-#2B456
2B457 CJK UNIFIED IDEOGRAPH-#2B457
2B458 CJK UNIFIED IDEOGRAPH-#2B458
2B459 CJK UNIFIED IDEOGRAPH-#2B459
2B45A CJK UNIFIED IDEOGRAPH-#2B45A
2B45B CJK UNIFIED IDEOGRAPH-#2B45B
2B45C CJK UNIFIED IDEOGRAPH-#2B45C
2B45D CJK UNIFIED IDEOGRAPH-#2B45D
2B45E CJK UNIFIED IDEOGRAPH-#2B45E
2B45F CJK UNIFIED IDEOGRAPH-#2B45F
2B460 CJK UNIFIED IDEOGRAPH-#2B460
2B461 CJK UNIFIED IDEOGRAPH-#2B461
2B462 CJK UNIFIED IDEOGRAPH-#2B462
2B463 CJK UNIFIED IDEOGRAPH-#2B463
2B464 CJK UNIFIED IDEOGRAPH-#2B464
2B465 CJK UNIFIED IDEOGRAPH-#2B465
2B466 CJK UNIFIED IDEOGRAPH-#2B466
2B467 CJK UNIFIED IDEOGRAPH-#2B467
2B468 CJK UNIFIED IDEOGRAPH-#2B468
2B469 CJK UNIFIED IDEOGRAPH-#2B469
2B46A CJK UNIFIED IDEOGRAPH-#2B46A
2B46B CJK UNIFIED IDEOGRAPH-#2B46B
2B46C CJK UNIFIED IDEOGRAPH-#2B46C
2B46D CJK UNIFIED IDEOGRAPH-#2B46D
2B46E CJK UNIFIED IDEOGRAPH-#2B46E
2B46F CJK UNIFIED IDEOGRAPH-#2B46F
2B470 CJK UNIFIED IDEOGRAPH-#2B470
2B471 CJK UNIFIED IDEOGRAPH-#2B471
2B472 CJK UNIFIED IDEOGRAPH-#2B472
2B473 CJK UNIFIED IDEOGRAPH-#2B473
2B474 CJK UNIFIED IDEOGRAPH-#2B474
2B475 CJK UNIFIED IDEOGRAPH-#2B475
2B476 CJK UNIFIED IDEOGRAPH-#2B476
2B477 CJK UNIFIED IDEOGRAPH-#2B477
2B478 CJK UNIFIED IDEOGRAPH-#2B478
2B479 CJK UNIFIED IDEOGRAPH-#2B479
2B47A CJK UNIFIED IDEOGRAPH-#2B47A
2B47B CJK UNIFIED IDEOGRAPH-#2B47B
2B47C CJK UNIFIED IDEOGRAPH-#2B47C
2B47D CJK UNIFIED IDEOGRAPH-#2B47D
2B47E CJK UNIFIED IDEOGRAPH-#2B47E
2B47F CJK UNIFIED IDEOGRAPH-#2B47F
2B480 CJK UNIFIED IDEOGRAPH-#2B480
2B481 CJK UNIFIED IDEOGRAPH-#2B481
2B482 CJK UNIFIED IDEOGRAPH-#2B482
2B483 CJK UNIFIED IDEOGRAPH-#2B483
2B484 CJK UNIFIED IDEOGRAPH-#2B484
2B485 CJK UNIFIED IDEOGRAPH-#2B485
2B486 CJK UNIFIED IDEOGRAPH-#2B486
2B487 CJK UNIFIED IDEOGRAPH-#2B487
2B488 CJK UNIFIED IDEOGRAPH-#2B488
2B489 CJK UNIFIED IDEOGRAPH-#2B489
2B48A CJK UNIFIED IDEOGRAPH-#2B48A
2B48B CJK UNIFIED IDEOGRAPH-#2B48B
2B48C CJK UNIFIED IDEOGRAPH-#2B48C
2B48D CJK UNIFIED IDEOGRAPH-#2B48D
2B48E CJK UNIFIED IDEOGRAPH-#2B48E
2B48F CJK UNIFIED IDEOGRAPH-#2B48F
2B490 CJK UNIFIED IDEOGRAPH-#2B490
2B491 CJK UNIFIED IDEOGRAPH-#2B491
2B492 CJK UNIFIED IDEOGRAPH-#2B492
2B493 CJK UNIFIED IDEOGRAPH-#2B493
2B494 CJK UNIFIED IDEOGRAPH-#2B494
2B495 CJK UNIFIED IDEOGRAPH-#2B495
2B496 CJK UNIFIED IDEOGRAPH-#2B496
2B497 CJK UNIFIED IDEOGRAPH-#2B497
2B498 CJK UNIFIED IDEOGRAPH-#2B498
2B499 CJK UNIFIED IDEOGRAPH-#2B499
2B49A CJK UNIFIED IDEOGRAPH-#2B49A
2B49B CJK UNIFIED IDEOGRAPH-#2B49B
2B49C CJK UNIFIED IDEOGRAPH-#2B49C
2B49D CJK UNIFIED IDEOGRAPH-#2B49D
2B49E CJK UNIFIED IDEOGRAPH-#2B49E
2B49F CJK UNIFIED IDEOGRAPH-#2B49F
2B4A0 CJK UNIFIED IDEOGRAPH-#2B4A0
2B4A1 CJK UNIFIED IDEOGRAPH-#2B4A1
2B4A2 CJK UNIFIED IDEOGRAPH-#2B4A2
2B4A3 CJK UNIFIED IDEOGRAPH-#2B4A3
2B4A4 CJK UNIFIED IDEOGRAPH-#2B4A4
2B4A5 CJK UNIFIED IDEOGRAPH-#2B4A5
2B4A6 CJK UNIFIED IDEOGRAPH-#2B4A6
2B4A7 CJK UNIFIED IDEOGRAPH-#2B4A7
2B4A8 CJK UNIFIED IDEOGRAPH-#2B4A8
2B4A9 CJK UNIFIED IDEOGRAPH-#2B4A9
2B4AA CJK UNIFIED IDEOGRAPH-#2B4AA
2B4AB CJK UNIFIED IDEOGRAPH-#2B4AB
2B4AC CJK UNIFIED IDEOGRAPH-#2B4AC
2B4AD CJK UNIFIED IDEOGRAPH-#2B4AD
2B4AE CJK UNIFIED IDEOGRAPH-#2B4AE
2B4AF CJK UNIFIED IDEOGRAPH-#2B4AF
2B4B0 CJK UNIFIED IDEOGRAPH-#2B4B0
2B4B1 CJK UNIFIED IDEOGRAPH-#2B4B1
2B4B2 CJK UNIFIED IDEOGRAPH-#2B4B2
2B4B3 CJK UNIFIED IDEOGRAPH-#2B4B3
2B4B4 CJK UNIFIED IDEOGRAPH-#2B4B4
2B4B5 CJK UNIFIED IDEOGRAPH-#2B4B5
2B4B6 CJK UNIFIED IDEOGRAPH-#2B4B6, Def{armor}
2B4B7 CJK UNIFIED IDEOGRAPH-#2B4B7
2B4B8 CJK UNIFIED IDEOGRAPH-#2B4B8
2B4B9 CJK UNIFIED IDEOGRAPH-#2B4B9
2B4BA CJK UNIFIED IDEOGRAPH-#2B4BA
2B4BB CJK UNIFIED IDEOGRAPH-#2B4BB
2B4BC CJK UNIFIED IDEOGRAPH-#2B4BC
2B4BD CJK UNIFIED IDEOGRAPH-#2B4BD
2B4BE CJK UNIFIED IDEOGRAPH-#2B4BE
2B4BF CJK UNIFIED IDEOGRAPH-#2B4BF
2B4C0 CJK UNIFIED IDEOGRAPH-#2B4C0
2B4C1 CJK UNIFIED IDEOGRAPH-#2B4C1
2B4C2 CJK UNIFIED IDEOGRAPH-#2B4C2
2B4C3 CJK UNIFIED IDEOGRAPH-#2B4C3
2B4C4 CJK UNIFIED IDEOGRAPH-#2B4C4
2B4C5 CJK UNIFIED IDEOGRAPH-#2B4C5
2B4C6 CJK UNIFIED IDEOGRAPH-#2B4C6
2B4C7 CJK UNIFIED IDEOGRAPH-#2B4C7
2B4C8 CJK UNIFIED IDEOGRAPH-#2B4C8
2B4C9 CJK UNIFIED IDEOGRAPH-#2B4C9
2B4CA CJK UNIFIED IDEOGRAPH-#2B4CA
2B4CB CJK UNIFIED IDEOGRAPH-#2B4CB
2B4CC CJK UNIFIED IDEOGRAPH-#2B4CC
2B4CD CJK UNIFIED IDEOGRAPH-#2B4CD
2B4CE CJK UNIFIED IDEOGRAPH-#2B4CE
2B4CF CJK UNIFIED IDEOGRAPH-#2B4CF
2B4D0 CJK UNIFIED IDEOGRAPH-#2B4D0
2B4D1 CJK UNIFIED IDEOGRAPH-#2B4D1
2B4D2 CJK UNIFIED IDEOGRAPH-#2B4D2
2B4D3 CJK UNIFIED IDEOGRAPH-#2B4D3
2B4D4 CJK UNIFIED IDEOGRAPH-#2B4D4
2B4D5 CJK UNIFIED IDEOGRAPH-#2B4D5
2B4D6 CJK UNIFIED IDEOGRAPH-#2B4D6
2B4D7 CJK UNIFIED IDEOGRAPH-#2B4D7
2B4D8 CJK UNIFIED IDEOGRAPH-#2B4D8
2B4D9 CJK UNIFIED IDEOGRAPH-#2B4D9
2B4DA CJK UNIFIED IDEOGRAPH-#2B4DA
2B4DB CJK UNIFIED IDEOGRAPH-#2B4DB
2B4DC CJK UNIFIED IDEOGRAPH-#2B4DC
2B4DD CJK UNIFIED IDEOGRAPH-#2B4DD
2B4DE CJK UNIFIED IDEOGRAPH-#2B4DE
2B4DF CJK UNIFIED IDEOGRAPH-#2B4DF
2B4E0 CJK UNIFIED IDEOGRAPH-#2B4E0
2B4E1 CJK UNIFIED IDEOGRAPH-#2B4E1
2B4E2 CJK UNIFIED IDEOGRAPH-#2B4E2
2B4E3 CJK UNIFIED IDEOGRAPH-#2B4E3
2B4E4 CJK UNIFIED IDEOGRAPH-#2B4E4
2B4E5 CJK UNIFIED IDEOGRAPH-#2B4E5
2B4E6 CJK UNIFIED IDEOGRAPH-#2B4E6
2B4E7 CJK UNIFIED IDEOGRAPH-#2B4E7, Def{an ax, hatchet}
2B4E8 CJK UNIFIED IDEOGRAPH-#2B4E8
2B4E9 CJK UNIFIED IDEOGRAPH-#2B4E9, Def{a short spear}
2B4EA CJK UNIFIED IDEOGRAPH-#2B4EA
2B4EB CJK UNIFIED IDEOGRAPH-#2B4EB
2B4EC CJK UNIFIED IDEOGRAPH-#2B4EC
2B4ED CJK UNIFIED IDEOGRAPH-#2B4ED
2B4EE CJK UNIFIED IDEOGRAPH-#2B4EE
2B4EF CJK UNIFIED IDEOGRAPH-#2B4EF
2B4F0 CJK UNIFIED IDEOGRAPH-#2B4F0
2B4F1 CJK UNIFIED IDEOGRAPH-#2B4F1
2B4F2 CJK UNIFIED IDEOGRAPH-#2B4F2
2B4F3 CJK UNIFIED IDEOGRAPH-#2B4F3
2B4F4 CJK UNIFIED IDEOGRAPH-#2B4F4
2B4F5 CJK UNIFIED IDEOGRAPH-#2B4F5
2B4F6 CJK UNIFIED IDEOGRAPH-#2B4F6
2B4F7 CJK UNIFIED IDEOGRAPH-#2B4F7
2B4F8 CJK UNIFIED IDEOGRAPH-#2B4F8
2B4F9 CJK UNIFIED IDEOGRAPH-#2B4F9
2B4FA CJK UNIFIED IDEOGRAPH-#2B4FA
2B4FB CJK UNIFIED IDEOGRAPH-#2B4FB
2B4FC CJK UNIFIED IDEOGRAPH-#2B4FC
2B4FD CJK UNIFIED IDEOGRAPH-#2B4FD
2B4FE CJK UNIFIED IDEOGRAPH-#2B4FE
2B4FF CJK UNIFIED IDEOGRAPH-#2B4FF
2B500 CJK UNIFIED IDEOGRAPH-#2B500
2B501 CJK UNIFIED IDEOGRAPH-#2B501
2B502 CJK UNIFIED IDEOGRAPH-#2B502
2B503 CJK UNIFIED IDEOGRAPH-#2B503
2B504 CJK UNIFIED IDEOGRAPH-#2B504
2B505 CJK UNIFIED IDEOGRAPH-#2B505
2B506 CJK UNIFIED IDEOGRAPH-#2B506
2B507 CJK UNIFIED IDEOGRAPH-#2B507
2B508 CJK UNIFIED IDEOGRAPH-#2B508
2B509 CJK UNIFIED IDEOGRAPH-#2B509
2B50A CJK UNIFIED IDEOGRAPH-#2B50A
2B50B CJK UNIFIED IDEOGRAPH-#2B50B
2B50C CJK UNIFIED IDEOGRAPH-#2B50C
2B50D CJK UNIFIED IDEOGRAPH-#2B50D
2B50E CJK UNIFIED IDEOGRAPH-#2B50E, Def{hasp of a lock}
2B50F CJK UNIFIED IDEOGRAPH-#2B50F
2B510 CJK UNIFIED IDEOGRAPH-#2B510
2B511 CJK UNIFIED IDEOGRAPH-#2B511
2B512 CJK UNIFIED IDEOGRAPH-#2B512
2B513 CJK UNIFIED IDEOGRAPH-#2B513
2B514 CJK UNIFIED IDEOGRAPH-#2B514
2B515 CJK UNIFIED IDEOGRAPH-#2B515
2B516 CJK UNIFIED IDEOGRAPH-#2B516
2B517 CJK UNIFIED IDEOGRAPH-#2B517
2B518 CJK UNIFIED IDEOGRAPH-#2B518
2B519 CJK UNIFIED IDEOGRAPH-#2B519
2B51A CJK UNIFIED IDEOGRAPH-#2B51A
2B51B CJK UNIFIED IDEOGRAPH-#2B51B
2B51C CJK UNIFIED IDEOGRAPH-#2B51C
2B51D CJK UNIFIED IDEOGRAPH-#2B51D
2B51E CJK UNIFIED IDEOGRAPH-#2B51E
2B51F CJK UNIFIED IDEOGRAPH-#2B51F
2B520 CJK UNIFIED IDEOGRAPH-#2B520
2B521 CJK UNIFIED IDEOGRAPH-#2B521
2B522 CJK UNIFIED IDEOGRAPH-#2B522
2B523 CJK UNIFIED IDEOGRAPH-#2B523
2B524 CJK UNIFIED IDEOGRAPH-#2B524
2B525 CJK UNIFIED IDEOGRAPH-#2B525
2B526 CJK UNIFIED IDEOGRAPH-#2B526
2B527 CJK UNIFIED IDEOGRAPH-#2B527
2B528 CJK UNIFIED IDEOGRAPH-#2B528
2B529 CJK UNIFIED IDEOGRAPH-#2B529
2B52A CJK UNIFIED IDEOGRAPH-#2B52A
2B52B CJK UNIFIED IDEOGRAPH-#2B52B
2B52C CJK UNIFIED IDEOGRAPH-#2B52C
2B52D CJK UNIFIED IDEOGRAPH-#2B52D
2B52E CJK UNIFIED IDEOGRAPH-#2B52E
2B52F CJK UNIFIED IDEOGRAPH-#2B52F
2B530 CJK UNIFIED IDEOGRAPH-#2B530
2B531 CJK UNIFIED IDEOGRAPH-#2B531
2B532 CJK UNIFIED IDEOGRAPH-#2B532
2B533 CJK UNIFIED IDEOGRAPH-#2B533
2B534 CJK UNIFIED IDEOGRAPH-#2B534
2B535 CJK UNIFIED IDEOGRAPH-#2B535
2B536 CJK UNIFIED IDEOGRAPH-#2B536
2B537 CJK UNIFIED IDEOGRAPH-#2B537
2B538 CJK UNIFIED IDEOGRAPH-#2B538
2B539 CJK UNIFIED IDEOGRAPH-#2B539
2B53A CJK UNIFIED IDEOGRAPH-#2B53A
2B53B CJK UNIFIED IDEOGRAPH-#2B53B
2B53C CJK UNIFIED IDEOGRAPH-#2B53C
2B53D CJK UNIFIED IDEOGRAPH-#2B53D
2B53E CJK UNIFIED IDEOGRAPH-#2B53E
2B53F CJK UNIFIED IDEOGRAPH-#2B53F
2B540 CJK UNIFIED IDEOGRAPH-#2B540
2B541 CJK UNIFIED IDEOGRAPH-#2B541
2B542 CJK UNIFIED IDEOGRAPH-#2B542
2B543 CJK UNIFIED IDEOGRAPH-#2B543
2B544 CJK UNIFIED IDEOGRAPH-#2B544
2B545 CJK UNIFIED IDEOGRAPH-#2B545
2B546 CJK UNIFIED IDEOGRAPH-#2B546
2B547 CJK UNIFIED IDEOGRAPH-#2B547
2B548 CJK UNIFIED IDEOGRAPH-#2B548
2B549 CJK UNIFIED IDEOGRAPH-#2B549
2B54A CJK UNIFIED IDEOGRAPH-#2B54A
2B54B CJK UNIFIED IDEOGRAPH-#2B54B
2B54C CJK UNIFIED IDEOGRAPH-#2B54C
2B54D CJK UNIFIED IDEOGRAPH-#2B54D
2B54E CJK UNIFIED IDEOGRAPH-#2B54E
2B54F CJK UNIFIED IDEOGRAPH-#2B54F
2B550 CJK UNIFIED IDEOGRAPH-#2B550
2B551 CJK UNIFIED IDEOGRAPH-#2B551
2B552 CJK UNIFIED IDEOGRAPH-#2B552
2B553 CJK UNIFIED IDEOGRAPH-#2B553
2B554 CJK UNIFIED IDEOGRAPH-#2B554
2B555 CJK UNIFIED IDEOGRAPH-#2B555
2B556 CJK UNIFIED IDEOGRAPH-#2B556
2B557 CJK UNIFIED IDEOGRAPH-#2B557
2B558 CJK UNIFIED IDEOGRAPH-#2B558
2B559 CJK UNIFIED IDEOGRAPH-#2B559
2B55A CJK UNIFIED IDEOGRAPH-#2B55A
2B55B CJK UNIFIED IDEOGRAPH-#2B55B
2B55C CJK UNIFIED IDEOGRAPH-#2B55C
2B55D CJK UNIFIED IDEOGRAPH-#2B55D
2B55E CJK UNIFIED IDEOGRAPH-#2B55E
2B55F CJK UNIFIED IDEOGRAPH-#2B55F
2B560 CJK UNIFIED IDEOGRAPH-#2B560
2B561 CJK UNIFIED IDEOGRAPH-#2B561
2B562 CJK UNIFIED IDEOGRAPH-#2B562
2B563 CJK UNIFIED IDEOGRAPH-#2B563
2B564 CJK UNIFIED IDEOGRAPH-#2B564
2B565 CJK UNIFIED IDEOGRAPH-#2B565
2B566 CJK UNIFIED IDEOGRAPH-#2B566
2B567 CJK UNIFIED IDEOGRAPH-#2B567
2B568 CJK UNIFIED IDEOGRAPH-#2B568
2B569 CJK UNIFIED IDEOGRAPH-#2B569
2B56A CJK UNIFIED IDEOGRAPH-#2B56A
2B56B CJK UNIFIED IDEOGRAPH-#2B56B
2B56C CJK UNIFIED IDEOGRAPH-#2B56C
2B56D CJK UNIFIED IDEOGRAPH-#2B56D
2B56E CJK UNIFIED IDEOGRAPH-#2B56E
2B56F CJK UNIFIED IDEOGRAPH-#2B56F
2B570 CJK UNIFIED IDEOGRAPH-#2B570
2B571 CJK UNIFIED IDEOGRAPH-#2B571
2B572 CJK UNIFIED IDEOGRAPH-#2B572
2B573 CJK UNIFIED IDEOGRAPH-#2B573
2B574 CJK UNIFIED IDEOGRAPH-#2B574
2B575 CJK UNIFIED IDEOGRAPH-#2B575
2B576 CJK UNIFIED IDEOGRAPH-#2B576
2B577 CJK UNIFIED IDEOGRAPH-#2B577
2B578 CJK UNIFIED IDEOGRAPH-#2B578
2B579 CJK UNIFIED IDEOGRAPH-#2B579
2B57A CJK UNIFIED IDEOGRAPH-#2B57A
2B57B CJK UNIFIED IDEOGRAPH-#2B57B
2B57C CJK UNIFIED IDEOGRAPH-#2B57C
2B57D CJK UNIFIED IDEOGRAPH-#2B57D
2B57E CJK UNIFIED IDEOGRAPH-#2B57E
2B57F CJK UNIFIED IDEOGRAPH-#2B57F
2B580 CJK UNIFIED IDEOGRAPH-#2B580
2B581 CJK UNIFIED IDEOGRAPH-#2B581
2B582 CJK UNIFIED IDEOGRAPH-#2B582
2B583 CJK UNIFIED IDEOGRAPH-#2B583
2B584 CJK UNIFIED IDEOGRAPH-#2B584
2B585 CJK UNIFIED IDEOGRAPH-#2B585
2B586 CJK UNIFIED IDEOGRAPH-#2B586
2B587 CJK UNIFIED IDEOGRAPH-#2B587
2B588 CJK UNIFIED IDEOGRAPH-#2B588
2B589 CJK UNIFIED IDEOGRAPH-#2B589
2B58A CJK UNIFIED IDEOGRAPH-#2B58A
2B58B CJK UNIFIED IDEOGRAPH-#2B58B
2B58C CJK UNIFIED IDEOGRAPH-#2B58C
2B58D CJK UNIFIED IDEOGRAPH-#2B58D
2B58E CJK UNIFIED IDEOGRAPH-#2B58E
2B58F CJK UNIFIED IDEOGRAPH-#2B58F
2B590 CJK UNIFIED IDEOGRAPH-#2B590
2B591 CJK UNIFIED IDEOGRAPH-#2B591
2B592 CJK UNIFIED IDEOGRAPH-#2B592
2B593 CJK UNIFIED IDEOGRAPH-#2B593
2B594 CJK UNIFIED IDEOGRAPH-#2B594
2B595 CJK UNIFIED IDEOGRAPH-#2B595
2B596 CJK UNIFIED IDEOGRAPH-#2B596
2B597 CJK UNIFIED IDEOGRAPH-#2B597
2B598 CJK UNIFIED IDEOGRAPH-#2B598
2B599 CJK UNIFIED IDEOGRAPH-#2B599
2B59A CJK UNIFIED IDEOGRAPH-#2B59A
2B59B CJK UNIFIED IDEOGRAPH-#2B59B
2B59C CJK UNIFIED IDEOGRAPH-#2B59C
2B59D CJK UNIFIED IDEOGRAPH-#2B59D
2B59E CJK UNIFIED IDEOGRAPH-#2B59E
2B59F CJK UNIFIED IDEOGRAPH-#2B59F
2B5A0 CJK UNIFIED IDEOGRAPH-#2B5A0
2B5A1 CJK UNIFIED IDEOGRAPH-#2B5A1
2B5A2 CJK UNIFIED IDEOGRAPH-#2B5A2
2B5A3 CJK UNIFIED IDEOGRAPH-#2B5A3
2B5A4 CJK UNIFIED IDEOGRAPH-#2B5A4
2B5A5 CJK UNIFIED IDEOGRAPH-#2B5A5
2B5A6 CJK UNIFIED IDEOGRAPH-#2B5A6
2B5A7 CJK UNIFIED IDEOGRAPH-#2B5A7
2B5A8 CJK UNIFIED IDEOGRAPH-#2B5A8
2B5A9 CJK UNIFIED IDEOGRAPH-#2B5A9
2B5AA CJK UNIFIED IDEOGRAPH-#2B5AA
2B5AB CJK UNIFIED IDEOGRAPH-#2B5AB
2B5AC CJK UNIFIED IDEOGRAPH-#2B5AC
2B5AD CJK UNIFIED IDEOGRAPH-#2B5AD
2B5AE CJK UNIFIED IDEOGRAPH-#2B5AE
2B5AF CJK UNIFIED IDEOGRAPH-#2B5AF
2B5B0 CJK UNIFIED IDEOGRAPH-#2B5B0
2B5B1 CJK UNIFIED IDEOGRAPH-#2B5B1
2B5B2 CJK UNIFIED IDEOGRAPH-#2B5B2
2B5B3 CJK UNIFIED IDEOGRAPH-#2B5B3
2B5B4 CJK UNIFIED IDEOGRAPH-#2B5B4
2B5B5 CJK UNIFIED IDEOGRAPH-#2B5B5
2B5B6 CJK UNIFIED IDEOGRAPH-#2B5B6
2B5B7 CJK UNIFIED IDEOGRAPH-#2B5B7
2B5B8 CJK UNIFIED IDEOGRAPH-#2B5B8
2B5B9 CJK UNIFIED IDEOGRAPH-#2B5B9
2B5BA CJK UNIFIED IDEOGRAPH-#2B5BA
2B5BB CJK UNIFIED IDEOGRAPH-#2B5BB
2B5BC CJK UNIFIED IDEOGRAPH-#2B5BC
2B5BD CJK UNIFIED IDEOGRAPH-#2B5BD
2B5BE CJK UNIFIED IDEOGRAPH-#2B5BE
2B5BF CJK UNIFIED IDEOGRAPH-#2B5BF
2B5C0 CJK UNIFIED IDEOGRAPH-#2B5C0
2B5C1 CJK UNIFIED IDEOGRAPH-#2B5C1
2B5C2 CJK UNIFIED IDEOGRAPH-#2B5C2
2B5C3 CJK UNIFIED IDEOGRAPH-#2B5C3
2B5C4 CJK UNIFIED IDEOGRAPH-#2B5C4
2B5C5 CJK UNIFIED IDEOGRAPH-#2B5C5
2B5C6 CJK UNIFIED IDEOGRAPH-#2B5C6
2B5C7 CJK UNIFIED IDEOGRAPH-#2B5C7
2B5C8 CJK UNIFIED IDEOGRAPH-#2B5C8
2B5C9 CJK UNIFIED IDEOGRAPH-#2B5C9
2B5CA CJK UNIFIED IDEOGRAPH-#2B5CA
2B5CB CJK UNIFIED IDEOGRAPH-#2B5CB
2B5CC CJK UNIFIED IDEOGRAPH-#2B5CC
2B5CD CJK UNIFIED IDEOGRAPH-#2B5CD
2B5CE CJK UNIFIED IDEOGRAPH-#2B5CE
2B5CF CJK UNIFIED IDEOGRAPH-#2B5CF
2B5D0 CJK UNIFIED IDEOGRAPH-#2B5D0
2B5D1 CJK UNIFIED IDEOGRAPH-#2B5D1
2B5D2 CJK UNIFIED IDEOGRAPH-#2B5D2
2B5D3 CJK UNIFIED IDEOGRAPH-#2B5D3
2B5D4 CJK UNIFIED IDEOGRAPH-#2B5D4
2B5D5 CJK UNIFIED IDEOGRAPH-#2B5D5
2B5D6 CJK UNIFIED IDEOGRAPH-#2B5D6
2B5D7 CJK UNIFIED IDEOGRAPH-#2B5D7
2B5D8 CJK UNIFIED IDEOGRAPH-#2B5D8
2B5D9 CJK UNIFIED IDEOGRAPH-#2B5D9
2B5DA CJK UNIFIED IDEOGRAPH-#2B5DA
2B5DB CJK UNIFIED IDEOGRAPH-#2B5DB
2B5DC CJK UNIFIED IDEOGRAPH-#2B5DC
2B5DD CJK UNIFIED IDEOGRAPH-#2B5DD
2B5DE CJK UNIFIED IDEOGRAPH-#2B5DE
2B5DF CJK UNIFIED IDEOGRAPH-#2B5DF
2B5E0 CJK UNIFIED IDEOGRAPH-#2B5E0, Def{an icicle}
2B5E1 CJK UNIFIED IDEOGRAPH-#2B5E1
2B5E2 CJK UNIFIED IDEOGRAPH-#2B5E2
2B5E3 CJK UNIFIED IDEOGRAPH-#2B5E3
2B5E4 CJK UNIFIED IDEOGRAPH-#2B5E4
2B5E5 CJK UNIFIED IDEOGRAPH-#2B5E5
2B5E6 CJK UNIFIED IDEOGRAPH-#2B5E6, Def{eat; dinner time; sunset}
2B5E7 CJK UNIFIED IDEOGRAPH-#2B5E7, Def{a pot of cooked rice}
2B5E8 CJK UNIFIED IDEOGRAPH-#2B5E8
2B5E9 CJK UNIFIED IDEOGRAPH-#2B5E9
2B5EA CJK UNIFIED IDEOGRAPH-#2B5EA
2B5EB CJK UNIFIED IDEOGRAPH-#2B5EB
2B5EC CJK UNIFIED IDEOGRAPH-#2B5EC
2B5ED CJK UNIFIED IDEOGRAPH-#2B5ED
2B5EE CJK UNIFIED IDEOGRAPH-#2B5EE, Def{to eat; dinner-time, sunset}
2B5EF CJK UNIFIED IDEOGRAPH-#2B5EF
2B5F0 CJK UNIFIED IDEOGRAPH-#2B5F0
2B5F1 CJK UNIFIED IDEOGRAPH-#2B5F1
2B5F2 CJK UNIFIED IDEOGRAPH-#2B5F2
2B5F3 CJK UNIFIED IDEOGRAPH-#2B5F3
2B5F4 CJK UNIFIED IDEOGRAPH-#2B5F4, Def{gruel}
2B5F5 CJK UNIFIED IDEOGRAPH-#2B5F5
2B5F6 CJK UNIFIED IDEOGRAPH-#2B5F6
2B5F7 CJK UNIFIED IDEOGRAPH-#2B5F7
2B5F8 CJK UNIFIED IDEOGRAPH-#2B5F8
2B5F9 CJK UNIFIED IDEOGRAPH-#2B5F9
2B5FA CJK UNIFIED IDEOGRAPH-#2B5FA
2B5FB CJK UNIFIED IDEOGRAPH-#2B5FB
2B5FC CJK UNIFIED IDEOGRAPH-#2B5FC
2B5FD CJK UNIFIED IDEOGRAPH-#2B5FD
2B5FE CJK UNIFIED IDEOGRAPH-#2B5FE
2B5FF CJK UNIFIED IDEOGRAPH-#2B5FF
2B600 CJK UNIFIED IDEOGRAPH-#2B600
2B601 CJK UNIFIED IDEOGRAPH-#2B601
2B602 CJK UNIFIED IDEOGRAPH-#2B602
2B603 CJK UNIFIED IDEOGRAPH-#2B603
2B604 CJK UNIFIED IDEOGRAPH-#2B604
2B605 CJK UNIFIED IDEOGRAPH-#2B605
2B606 CJK UNIFIED IDEOGRAPH-#2B606
2B607 CJK UNIFIED IDEOGRAPH-#2B607
2B608 CJK UNIFIED IDEOGRAPH-#2B608
2B609 CJK UNIFIED IDEOGRAPH-#2B609
2B60A CJK UNIFIED IDEOGRAPH-#2B60A
2B60B CJK UNIFIED IDEOGRAPH-#2B60B
2B60C CJK UNIFIED IDEOGRAPH-#2B60C
2B60D CJK UNIFIED IDEOGRAPH-#2B60D
2B60E CJK UNIFIED IDEOGRAPH-#2B60E
2B60F CJK UNIFIED IDEOGRAPH-#2B60F
2B610 CJK UNIFIED IDEOGRAPH-#2B610
2B611 CJK UNIFIED IDEOGRAPH-#2B611
2B612 CJK UNIFIED IDEOGRAPH-#2B612
2B613 CJK UNIFIED IDEOGRAPH-#2B613
2B614 CJK UNIFIED IDEOGRAPH-#2B614
2B615 CJK UNIFIED IDEOGRAPH-#2B615
2B616 CJK UNIFIED IDEOGRAPH-#2B616
2B617 CJK UNIFIED IDEOGRAPH-#2B617
2B618 CJK UNIFIED IDEOGRAPH-#2B618
2B619 CJK UNIFIED IDEOGRAPH-#2B619
2B61A CJK UNIFIED IDEOGRAPH-#2B61A
2B61B CJK UNIFIED IDEOGRAPH-#2B61B
2B61C CJK UNIFIED IDEOGRAPH-#2B61C
2B61D CJK UNIFIED IDEOGRAPH-#2B61D, Def{gallop}
2B61E CJK UNIFIED IDEOGRAPH-#2B61E
2B61F CJK UNIFIED IDEOGRAPH-#2B61F
2B620 CJK UNIFIED IDEOGRAPH-#2B620
2B621 CJK UNIFIED IDEOGRAPH-#2B621
2B622 CJK UNIFIED IDEOGRAPH-#2B622
2B623 CJK UNIFIED IDEOGRAPH-#2B623, Def{a fierce horse; to rage, run wild}
2B624 CJK UNIFIED IDEOGRAPH-#2B624, Def{stupid; foolish}
2B625 CJK UNIFIED IDEOGRAPH-#2B625
2B626 CJK UNIFIED IDEOGRAPH-#2B626
2B627 CJK UNIFIED IDEOGRAPH-#2B627
2B628 CJK UNIFIED IDEOGRAPH-#2B628, Def{a horse, mule}
2B629 CJK UNIFIED IDEOGRAPH-#2B629
2B62A CJK UNIFIED IDEOGRAPH-#2B62A
2B62B CJK UNIFIED IDEOGRAPH-#2B62B
2B62C CJK UNIFIED IDEOGRAPH-#2B62C
2B62D CJK UNIFIED IDEOGRAPH-#2B62D
2B62E CJK UNIFIED IDEOGRAPH-#2B62E
2B62F CJK UNIFIED IDEOGRAPH-#2B62F
2B630 CJK UNIFIED IDEOGRAPH-#2B630
2B631 CJK UNIFIED IDEOGRAPH-#2B631
2B632 CJK UNIFIED IDEOGRAPH-#2B632
2B633 CJK UNIFIED IDEOGRAPH-#2B633
2B634 CJK UNIFIED IDEOGRAPH-#2B634
2B635 CJK UNIFIED IDEOGRAPH-#2B635
2B636 CJK UNIFIED IDEOGRAPH-#2B636
2B637 CJK UNIFIED IDEOGRAPH-#2B637
2B638 CJK UNIFIED IDEOGRAPH-#2B638
2B639 CJK UNIFIED IDEOGRAPH-#2B639
2B63A CJK UNIFIED IDEOGRAPH-#2B63A
2B63B CJK UNIFIED IDEOGRAPH-#2B63B
2B63C CJK UNIFIED IDEOGRAPH-#2B63C
2B63D CJK UNIFIED IDEOGRAPH-#2B63D
2B63E CJK UNIFIED IDEOGRAPH-#2B63E
2B63F CJK UNIFIED IDEOGRAPH-#2B63F
2B640 CJK UNIFIED IDEOGRAPH-#2B640
2B641 CJK UNIFIED IDEOGRAPH-#2B641
2B642 CJK UNIFIED IDEOGRAPH-#2B642
2B643 CJK UNIFIED IDEOGRAPH-#2B643
2B644 CJK UNIFIED IDEOGRAPH-#2B644
2B645 CJK UNIFIED IDEOGRAPH-#2B645
2B646 CJK UNIFIED IDEOGRAPH-#2B646
2B647 CJK UNIFIED IDEOGRAPH-#2B647
2B648 CJK UNIFIED IDEOGRAPH-#2B648
2B649 CJK UNIFIED IDEOGRAPH-#2B649
2B64A CJK UNIFIED IDEOGRAPH-#2B64A
2B64B CJK UNIFIED IDEOGRAPH-#2B64B
2B64C CJK UNIFIED IDEOGRAPH-#2B64C
2B64D CJK UNIFIED IDEOGRAPH-#2B64D
2B64E CJK UNIFIED IDEOGRAPH-#2B64E
2B64F CJK UNIFIED IDEOGRAPH-#2B64F
2B650 CJK UNIFIED IDEOGRAPH-#2B650
2B651 CJK UNIFIED IDEOGRAPH-#2B651
2B652 CJK UNIFIED IDEOGRAPH-#2B652
2B653 CJK UNIFIED IDEOGRAPH-#2B653
2B654 CJK UNIFIED IDEOGRAPH-#2B654
2B655 CJK UNIFIED IDEOGRAPH-#2B655
2B656 CJK UNIFIED IDEOGRAPH-#2B656
2B657 CJK UNIFIED IDEOGRAPH-#2B657
2B658 CJK UNIFIED IDEOGRAPH-#2B658
2B659 CJK UNIFIED IDEOGRAPH-#2B659
2B65A CJK UNIFIED IDEOGRAPH-#2B65A
2B65B CJK UNIFIED IDEOGRAPH-#2B65B
2B65C CJK UNIFIED IDEOGRAPH-#2B65C
2B65D CJK UNIFIED IDEOGRAPH-#2B65D
2B65E CJK UNIFIED IDEOGRAPH-#2B65E
2B65F CJK UNIFIED IDEOGRAPH-#2B65F
2B660 CJK UNIFIED IDEOGRAPH-#2B660
2B661 CJK UNIFIED IDEOGRAPH-#2B661
2B662 CJK UNIFIED IDEOGRAPH-#2B662
2B663 CJK UNIFIED IDEOGRAPH-#2B663
2B664 CJK UNIFIED IDEOGRAPH-#2B664
2B665 CJK UNIFIED IDEOGRAPH-#2B665
2B666 CJK UNIFIED IDEOGRAPH-#2B666
2B667 CJK UNIFIED IDEOGRAPH-#2B667
2B668 CJK UNIFIED IDEOGRAPH-#2B668
2B669 CJK UNIFIED IDEOGRAPH-#2B669
2B66A CJK UNIFIED IDEOGRAPH-#2B66A
2B66B CJK UNIFIED IDEOGRAPH-#2B66B
2B66C CJK UNIFIED IDEOGRAPH-#2B66C
2B66D CJK UNIFIED IDEOGRAPH-#2B66D
2B66E CJK UNIFIED IDEOGRAPH-#2B66E
2B66F CJK UNIFIED IDEOGRAPH-#2B66F
2B670 CJK UNIFIED IDEOGRAPH-#2B670
2B671 CJK UNIFIED IDEOGRAPH-#2B671
2B672 CJK UNIFIED IDEOGRAPH-#2B672
2B673 CJK UNIFIED IDEOGRAPH-#2B673
2B674 CJK UNIFIED IDEOGRAPH-#2B674
2B675 CJK UNIFIED IDEOGRAPH-#2B675
2B676 CJK UNIFIED IDEOGRAPH-#2B676
2B677 CJK UNIFIED IDEOGRAPH-#2B677
2B678 CJK UNIFIED IDEOGRAPH-#2B678
2B679 CJK UNIFIED IDEOGRAPH-#2B679
2B67A CJK UNIFIED IDEOGRAPH-#2B67A
2B67B CJK UNIFIED IDEOGRAPH-#2B67B
2B67C CJK UNIFIED IDEOGRAPH-#2B67C
2B67D CJK UNIFIED IDEOGRAPH-#2B67D
2B67E CJK UNIFIED IDEOGRAPH-#2B67E
2B67F CJK UNIFIED IDEOGRAPH-#2B67F
2B680 CJK UNIFIED IDEOGRAPH-#2B680
2B681 CJK UNIFIED IDEOGRAPH-#2B681
2B682 CJK UNIFIED IDEOGRAPH-#2B682
2B683 CJK UNIFIED IDEOGRAPH-#2B683
2B684 CJK UNIFIED IDEOGRAPH-#2B684
2B685 CJK UNIFIED IDEOGRAPH-#2B685
2B686 CJK UNIFIED IDEOGRAPH-#2B686
2B687 CJK UNIFIED IDEOGRAPH-#2B687
2B688 CJK UNIFIED IDEOGRAPH-#2B688, Def{silver carp (Hypophthalmichthys molitrix); bream}
2B689 CJK UNIFIED IDEOGRAPH-#2B689, Def{a ray, skate}
2B68A CJK UNIFIED IDEOGRAPH-#2B68A
2B68B CJK UNIFIED IDEOGRAPH-#2B68B
2B68C CJK UNIFIED IDEOGRAPH-#2B68C
2B68D CJK UNIFIED IDEOGRAPH-#2B68D
2B68E CJK UNIFIED IDEOGRAPH-#2B68E
2B68F CJK UNIFIED IDEOGRAPH-#2B68F
2B690 CJK UNIFIED IDEOGRAPH-#2B690
2B691 CJK UNIFIED IDEOGRAPH-#2B691
2B692 CJK UNIFIED IDEOGRAPH-#2B692, Def{curtained carriage used by women}
2B693 CJK UNIFIED IDEOGRAPH-#2B693
2B694 CJK UNIFIED IDEOGRAPH-#2B694, Def{a small sturgeon found in the Yangzi; catfish}
2B695 CJK UNIFIED IDEOGRAPH-#2B695, Def{a yellowtail (fish)}
2B696 CJK UNIFIED IDEOGRAPH-#2B696
2B697 CJK UNIFIED IDEOGRAPH-#2B697
2B698 CJK UNIFIED IDEOGRAPH-#2B698
2B699 CJK UNIFIED IDEOGRAPH-#2B699, Def{the skate or ray}
2B69A CJK UNIFIED IDEOGRAPH-#2B69A
2B69B CJK UNIFIED IDEOGRAPH-#2B69B
2B69C CJK UNIFIED IDEOGRAPH-#2B69C
2B69D CJK UNIFIED IDEOGRAPH-#2B69D
2B69E CJK UNIFIED IDEOGRAPH-#2B69E
2B69F CJK UNIFIED IDEOGRAPH-#2B69F
2B6A0 CJK UNIFIED IDEOGRAPH-#2B6A0
2B6A1 CJK UNIFIED IDEOGRAPH-#2B6A1
2B6A2 CJK UNIFIED IDEOGRAPH-#2B6A2
2B6A3 CJK UNIFIED IDEOGRAPH-#2B6A3
2B6A4 CJK UNIFIED IDEOGRAPH-#2B6A4
2B6A5 CJK UNIFIED IDEOGRAPH-#2B6A5
2B6A6 CJK UNIFIED IDEOGRAPH-#2B6A6
2B6A7 CJK UNIFIED IDEOGRAPH-#2B6A7
2B6A8 CJK UNIFIED IDEOGRAPH-#2B6A8
2B6A9 CJK UNIFIED IDEOGRAPH-#2B6A9
2B6AA CJK UNIFIED IDEOGRAPH-#2B6AA
2B6AB CJK UNIFIED IDEOGRAPH-#2B6AB
2B6AC CJK UNIFIED IDEOGRAPH-#2B6AC
2B6AD CJK UNIFIED IDEOGRAPH-#2B6AD
2B6AE CJK UNIFIED IDEOGRAPH-#2B6AE
2B6AF CJK UNIFIED IDEOGRAPH-#2B6AF
2B6B0 CJK UNIFIED IDEOGRAPH-#2B6B0
2B6B1 CJK UNIFIED IDEOGRAPH-#2B6B1
2B6B2 CJK UNIFIED IDEOGRAPH-#2B6B2
2B6B3 CJK UNIFIED IDEOGRAPH-#2B6B3
2B6B4 CJK UNIFIED IDEOGRAPH-#2B6B4
2B6B5 CJK UNIFIED IDEOGRAPH-#2B6B5
2B6B6 CJK UNIFIED IDEOGRAPH-#2B6B6
2B6B7 CJK UNIFIED IDEOGRAPH-#2B6B7
2B6B8 CJK UNIFIED IDEOGRAPH-#2B6B8
2B6B9 CJK UNIFIED IDEOGRAPH-#2B6B9
2B6BA CJK UNIFIED IDEOGRAPH-#2B6BA
2B6BB CJK UNIFIED IDEOGRAPH-#2B6BB
2B6BC CJK UNIFIED IDEOGRAPH-#2B6BC
2B6BD CJK UNIFIED IDEOGRAPH-#2B6BD
2B6BE CJK UNIFIED IDEOGRAPH-#2B6BE
2B6BF CJK UNIFIED IDEOGRAPH-#2B6BF
2B6C0 CJK UNIFIED IDEOGRAPH-#2B6C0
2B6C1 CJK UNIFIED IDEOGRAPH-#2B6C1
2B6C2 CJK UNIFIED IDEOGRAPH-#2B6C2
2B6C3 CJK UNIFIED IDEOGRAPH-#2B6C3
2B6C4 CJK UNIFIED IDEOGRAPH-#2B6C4
2B6C5 CJK UNIFIED IDEOGRAPH-#2B6C5
2B6C6 CJK UNIFIED IDEOGRAPH-#2B6C6
2B6C7 CJK UNIFIED IDEOGRAPH-#2B6C7
2B6C8 CJK UNIFIED IDEOGRAPH-#2B6C8
2B6C9 CJK UNIFIED IDEOGRAPH-#2B6C9
2B6CA CJK UNIFIED IDEOGRAPH-#2B6CA
2B6CB CJK UNIFIED IDEOGRAPH-#2B6CB
2B6CC CJK UNIFIED IDEOGRAPH-#2B6CC
2B6CD CJK UNIFIED IDEOGRAPH-#2B6CD
2B6CE CJK UNIFIED IDEOGRAPH-#2B6CE
2B6CF CJK UNIFIED IDEOGRAPH-#2B6CF
2B6D0 CJK UNIFIED IDEOGRAPH-#2B6D0
2B6D1 CJK UNIFIED IDEOGRAPH-#2B6D1
2B6D2 CJK UNIFIED IDEOGRAPH-#2B6D2
2B6D3 CJK UNIFIED IDEOGRAPH-#2B6D3
2B6D4 CJK UNIFIED IDEOGRAPH-#2B6D4
2B6D5 CJK UNIFIED IDEOGRAPH-#2B6D5
2B6D6 CJK UNIFIED IDEOGRAPH-#2B6D6
2B6D7 CJK UNIFIED IDEOGRAPH-#2B6D7
2B6D8 CJK UNIFIED IDEOGRAPH-#2B6D8
2B6D9 CJK UNIFIED IDEOGRAPH-#2B6D9
2B6DA CJK UNIFIED IDEOGRAPH-#2B6DA
2B6DB CJK UNIFIED IDEOGRAPH-#2B6DB, Def{jay (Garrulus lidthi)}
2B6DC CJK UNIFIED IDEOGRAPH-#2B6DC
2B6DD CJK UNIFIED IDEOGRAPH-#2B6DD
2B6DE CJK UNIFIED IDEOGRAPH-#2B6DE, Def{a shrike, butcherbird}
2B6DF CJK UNIFIED IDEOGRAPH-#2B6DF
2B6E0 CJK UNIFIED IDEOGRAPH-#2B6E0
2B6E1 CJK UNIFIED IDEOGRAPH-#2B6E1
2B6E2 CJK UNIFIED IDEOGRAPH-#2B6E2, Def{(archaic) a wren}
2B6E3 CJK UNIFIED IDEOGRAPH-#2B6E3
2B6E4 CJK UNIFIED IDEOGRAPH-#2B6E4
2B6E5 CJK UNIFIED IDEOGRAPH-#2B6E5
2B6E6 CJK UNIFIED IDEOGRAPH-#2B6E6
2B6E7 CJK UNIFIED IDEOGRAPH-#2B6E7
2B6E8 CJK UNIFIED IDEOGRAPH-#2B6E8
2B6E9 CJK UNIFIED IDEOGRAPH-#2B6E9
2B6EA CJK UNIFIED IDEOGRAPH-#2B6EA
2B6EB CJK UNIFIED IDEOGRAPH-#2B6EB
2B6EC CJK UNIFIED IDEOGRAPH-#2B6EC
2B6ED CJK UNIFIED IDEOGRAPH-#2B6ED
2B6EE CJK UNIFIED IDEOGRAPH-#2B6EE
2B6EF CJK UNIFIED IDEOGRAPH-#2B6EF
2B6F0 CJK UNIFIED IDEOGRAPH-#2B6F0
2B6F1 CJK UNIFIED IDEOGRAPH-#2B6F1
2B6F2 CJK UNIFIED IDEOGRAPH-#2B6F2
2B6F3 CJK UNIFIED IDEOGRAPH-#2B6F3
2B6F4 CJK UNIFIED IDEOGRAPH-#2B6F4
2B6F5 CJK UNIFIED IDEOGRAPH-#2B6F5
2B6F6 CJK UNIFIED IDEOGRAPH-#2B6F6, Def{a duck-like bird}
2B6F7 CJK UNIFIED IDEOGRAPH-#2B6F7
2B6F8 CJK UNIFIED IDEOGRAPH-#2B6F8, Def{a kind of hawk; cuckoo}
2B6F9 CJK UNIFIED IDEOGRAPH-#2B6F9
2B6FA CJK UNIFIED IDEOGRAPH-#2B6FA
2B6FB CJK UNIFIED IDEOGRAPH-#2B6FB
2B6FC CJK UNIFIED IDEOGRAPH-#2B6FC
2B6FD CJK UNIFIED IDEOGRAPH-#2B6FD
2B6FE CJK UNIFIED IDEOGRAPH-#2B6FE
2B6FF CJK UNIFIED IDEOGRAPH-#2B6FF
2B700 CJK UNIFIED IDEOGRAPH-#2B700
2B701 CJK UNIFIED IDEOGRAPH-#2B701
2B702 CJK UNIFIED IDEOGRAPH-#2B702
2B703 CJK UNIFIED IDEOGRAPH-#2B703
2B704 CJK UNIFIED IDEOGRAPH-#2B704
2B705 CJK UNIFIED IDEOGRAPH-#2B705
2B706 CJK UNIFIED IDEOGRAPH-#2B706
2B707 CJK UNIFIED IDEOGRAPH-#2B707
2B708 CJK UNIFIED IDEOGRAPH-#2B708
2B709 CJK UNIFIED IDEOGRAPH-#2B709
2B70A CJK UNIFIED IDEOGRAPH-#2B70A
2B70B CJK UNIFIED IDEOGRAPH-#2B70B
2B70C CJK UNIFIED IDEOGRAPH-#2B70C
2B70D CJK UNIFIED IDEOGRAPH-#2B70D
2B70E CJK UNIFIED IDEOGRAPH-#2B70E
2B70F CJK UNIFIED IDEOGRAPH-#2B70F
2B710 CJK UNIFIED IDEOGRAPH-#2B710
2B711 CJK UNIFIED IDEOGRAPH-#2B711
2B712 CJK UNIFIED IDEOGRAPH-#2B712
2B713 CJK UNIFIED IDEOGRAPH-#2B713
2B714 CJK UNIFIED IDEOGRAPH-#2B714
2B715 CJK UNIFIED IDEOGRAPH-#2B715
2B716 CJK UNIFIED IDEOGRAPH-#2B716
2B717 CJK UNIFIED IDEOGRAPH-#2B717
2B718 CJK UNIFIED IDEOGRAPH-#2B718
2B719 CJK UNIFIED IDEOGRAPH-#2B719
2B71A CJK UNIFIED IDEOGRAPH-#2B71A
2B71B CJK UNIFIED IDEOGRAPH-#2B71B
2B71C CJK UNIFIED IDEOGRAPH-#2B71C
2B71D CJK UNIFIED IDEOGRAPH-#2B71D
2B71E CJK UNIFIED IDEOGRAPH-#2B71E
2B71F CJK UNIFIED IDEOGRAPH-#2B71F
2B720 CJK UNIFIED IDEOGRAPH-#2B720
2B721 CJK UNIFIED IDEOGRAPH-#2B721
2B722 CJK UNIFIED IDEOGRAPH-#2B722
2B723 CJK UNIFIED IDEOGRAPH-#2B723
2B724 CJK UNIFIED IDEOGRAPH-#2B724
2B725 CJK UNIFIED IDEOGRAPH-#2B725
2B726 CJK UNIFIED IDEOGRAPH-#2B726
2B727 CJK UNIFIED IDEOGRAPH-#2B727
2B728 CJK UNIFIED IDEOGRAPH-#2B728
2B729 CJK UNIFIED IDEOGRAPH-#2B729
2B72A CJK UNIFIED IDEOGRAPH-#2B72A
2B72B CJK UNIFIED IDEOGRAPH-#2B72B
2B72C CJK UNIFIED IDEOGRAPH-#2B72C
2B72D CJK UNIFIED IDEOGRAPH-#2B72D
2B72E CJK UNIFIED IDEOGRAPH-#2B72E
2B72F CJK UNIFIED IDEOGRAPH-#2B72F
2B730 CJK UNIFIED IDEOGRAPH-#2B730
2B731 CJK UNIFIED IDEOGRAPH-#2B731
2B732 CJK UNIFIED IDEOGRAPH-#2B732
2B733 CJK UNIFIED IDEOGRAPH-#2B733
2B734 CJK UNIFIED IDEOGRAPH-#2B734
2B740 CJK UNIFIED IDEOGRAPH-#2B740
2B741 CJK UNIFIED IDEOGRAPH-#2B741
2B742 CJK UNIFIED IDEOGRAPH-#2B742
2B743 CJK UNIFIED IDEOGRAPH-#2B743
2B744 CJK UNIFIED IDEOGRAPH-#2B744
2B745 CJK UNIFIED IDEOGRAPH-#2B745
2B746 CJK UNIFIED IDEOGRAPH-#2B746
2B747 CJK UNIFIED IDEOGRAPH-#2B747
2B748 CJK UNIFIED IDEOGRAPH-#2B748
2B749 CJK UNIFIED IDEOGRAPH-#2B749
2B74A CJK UNIFIED IDEOGRAPH-#2B74A
2B74B CJK UNIFIED IDEOGRAPH-#2B74B
2B74C CJK UNIFIED IDEOGRAPH-#2B74C
2B74D CJK UNIFIED IDEOGRAPH-#2B74D
2B74E CJK UNIFIED IDEOGRAPH-#2B74E
2B74F CJK UNIFIED IDEOGRAPH-#2B74F
2B750 CJK UNIFIED IDEOGRAPH-#2B750
2B751 CJK UNIFIED IDEOGRAPH-#2B751, IRGKangXi=0149.111
2B752 CJK UNIFIED IDEOGRAPH-#2B752
2B753 CJK UNIFIED IDEOGRAPH-#2B753, IRGKangXi=0157.041
2B754 CJK UNIFIED IDEOGRAPH-#2B754
2B755 CJK UNIFIED IDEOGRAPH-#2B755
2B756 CJK UNIFIED IDEOGRAPH-#2B756
2B757 CJK UNIFIED IDEOGRAPH-#2B757
2B758 CJK UNIFIED IDEOGRAPH-#2B758
2B759 CJK UNIFIED IDEOGRAPH-#2B759
2B75A CJK UNIFIED IDEOGRAPH-#2B75A, IRGKangXi=0206.201
2B75B CJK UNIFIED IDEOGRAPH-#2B75B
2B75C CJK UNIFIED IDEOGRAPH-#2B75C, IRGKangXi=0212.191
2B75D CJK UNIFIED IDEOGRAPH-#2B75D
2B75E CJK UNIFIED IDEOGRAPH-#2B75E
2B75F CJK UNIFIED IDEOGRAPH-#2B75F
2B760 CJK UNIFIED IDEOGRAPH-#2B760
2B761 CJK UNIFIED IDEOGRAPH-#2B761
2B762 CJK UNIFIED IDEOGRAPH-#2B762
2B763 CJK UNIFIED IDEOGRAPH-#2B763
2B764 CJK UNIFIED IDEOGRAPH-#2B764
2B765 CJK UNIFIED IDEOGRAPH-#2B765, IRGKangXi=0254.101
2B766 CJK UNIFIED IDEOGRAPH-#2B766
2B767 CJK UNIFIED IDEOGRAPH-#2B767
2B768 CJK UNIFIED IDEOGRAPH-#2B768
2B769 CJK UNIFIED IDEOGRAPH-#2B769
2B76A CJK UNIFIED IDEOGRAPH-#2B76A
2B76B CJK UNIFIED IDEOGRAPH-#2B76B
2B76C CJK UNIFIED IDEOGRAPH-#2B76C
2B76D CJK UNIFIED IDEOGRAPH-#2B76D
2B76E CJK UNIFIED IDEOGRAPH-#2B76E
2B76F CJK UNIFIED IDEOGRAPH-#2B76F
2B770 CJK UNIFIED IDEOGRAPH-#2B770
2B771 CJK UNIFIED IDEOGRAPH-#2B771
2B772 CJK UNIFIED IDEOGRAPH-#2B772
2B773 CJK UNIFIED IDEOGRAPH-#2B773
2B774 CJK UNIFIED IDEOGRAPH-#2B774
2B775 CJK UNIFIED IDEOGRAPH-#2B775
2B776 CJK UNIFIED IDEOGRAPH-#2B776
2B777 CJK UNIFIED IDEOGRAPH-#2B777, IRGKangXi=0348.081
2B778 CJK UNIFIED IDEOGRAPH-#2B778
2B779 CJK UNIFIED IDEOGRAPH-#2B779
2B77A CJK UNIFIED IDEOGRAPH-#2B77A
2B77B CJK UNIFIED IDEOGRAPH-#2B77B
2B77C CJK UNIFIED IDEOGRAPH-#2B77C, IRGKangXi=0445.341
2B77D CJK UNIFIED IDEOGRAPH-#2B77D
2B77E CJK UNIFIED IDEOGRAPH-#2B77E
2B77F CJK UNIFIED IDEOGRAPH-#2B77F
2B780 CJK UNIFIED IDEOGRAPH-#2B780
2B781 CJK UNIFIED IDEOGRAPH-#2B781
2B782 CJK UNIFIED IDEOGRAPH-#2B782, IRGKangXi=0494.181
2B783 CJK UNIFIED IDEOGRAPH-#2B783
2B784 CJK UNIFIED IDEOGRAPH-#2B784
2B785 CJK UNIFIED IDEOGRAPH-#2B785
2B786 CJK UNIFIED IDEOGRAPH-#2B786
2B787 CJK UNIFIED IDEOGRAPH-#2B787
2B788 CJK UNIFIED IDEOGRAPH-#2B788
2B789 CJK UNIFIED IDEOGRAPH-#2B789
2B78A CJK UNIFIED IDEOGRAPH-#2B78A
2B78B CJK UNIFIED IDEOGRAPH-#2B78B, IRGKangXi=0546.251
2B78C CJK UNIFIED IDEOGRAPH-#2B78C
2B78D CJK UNIFIED IDEOGRAPH-#2B78D
2B78E CJK UNIFIED IDEOGRAPH-#2B78E
2B78F CJK UNIFIED IDEOGRAPH-#2B78F
2B790 CJK UNIFIED IDEOGRAPH-#2B790
2B791 CJK UNIFIED IDEOGRAPH-#2B791
2B792 CJK UNIFIED IDEOGRAPH-#2B792
2B793 CJK UNIFIED IDEOGRAPH-#2B793
2B794 CJK UNIFIED IDEOGRAPH-#2B794, IRGKangXi=0583.141
2B795 CJK UNIFIED IDEOGRAPH-#2B795
2B796 CJK UNIFIED IDEOGRAPH-#2B796
2B797 CJK UNIFIED IDEOGRAPH-#2B797
2B798 CJK UNIFIED IDEOGRAPH-#2B798
2B799 CJK UNIFIED IDEOGRAPH-#2B799
2B79A CJK UNIFIED IDEOGRAPH-#2B79A
2B79B CJK UNIFIED IDEOGRAPH-#2B79B
2B79C CJK UNIFIED IDEOGRAPH-#2B79C
2B79D CJK UNIFIED IDEOGRAPH-#2B79D
2B79E CJK UNIFIED IDEOGRAPH-#2B79E
2B79F CJK UNIFIED IDEOGRAPH-#2B79F
2B7A0 CJK UNIFIED IDEOGRAPH-#2B7A0
2B7A1 CJK UNIFIED IDEOGRAPH-#2B7A1
2B7A2 CJK UNIFIED IDEOGRAPH-#2B7A2
2B7A3 CJK UNIFIED IDEOGRAPH-#2B7A3
2B7A4 CJK UNIFIED IDEOGRAPH-#2B7A4
2B7A5 CJK UNIFIED IDEOGRAPH-#2B7A5
2B7A6 CJK UNIFIED IDEOGRAPH-#2B7A6
2B7A7 CJK UNIFIED IDEOGRAPH-#2B7A7
2B7A8 CJK UNIFIED IDEOGRAPH-#2B7A8
2B7A9 CJK UNIFIED IDEOGRAPH-#2B7A9
2B7AA CJK UNIFIED IDEOGRAPH-#2B7AA
2B7AB CJK UNIFIED IDEOGRAPH-#2B7AB
2B7AC CJK UNIFIED IDEOGRAPH-#2B7AC, IRGKangXi=0772.111
2B7AD CJK UNIFIED IDEOGRAPH-#2B7AD
2B7AE CJK UNIFIED IDEOGRAPH-#2B7AE
2B7AF CJK UNIFIED IDEOGRAPH-#2B7AF, IRGKangXi=0792.401
2B7B0 CJK UNIFIED IDEOGRAPH-#2B7B0
2B7B1 CJK UNIFIED IDEOGRAPH-#2B7B1
2B7B2 CJK UNIFIED IDEOGRAPH-#2B7B2
2B7B3 CJK UNIFIED IDEOGRAPH-#2B7B3
2B7B4 CJK UNIFIED IDEOGRAPH-#2B7B4
2B7B5 CJK UNIFIED IDEOGRAPH-#2B7B5
2B7B6 CJK UNIFIED IDEOGRAPH-#2B7B6
2B7B7 CJK UNIFIED IDEOGRAPH-#2B7B7
2B7B8 CJK UNIFIED IDEOGRAPH-#2B7B8
2B7B9 CJK UNIFIED IDEOGRAPH-#2B7B9
2B7BA CJK UNIFIED IDEOGRAPH-#2B7BA
2B7BB CJK UNIFIED IDEOGRAPH-#2B7BB
2B7BC CJK UNIFIED IDEOGRAPH-#2B7BC
2B7BD CJK UNIFIED IDEOGRAPH-#2B7BD, IRGKangXi=0893.291
2B7BE CJK UNIFIED IDEOGRAPH-#2B7BE
2B7BF CJK UNIFIED IDEOGRAPH-#2B7BF
2B7C0 CJK UNIFIED IDEOGRAPH-#2B7C0
2B7C1 CJK UNIFIED IDEOGRAPH-#2B7C1
2B7C2 CJK UNIFIED IDEOGRAPH-#2B7C2
2B7C3 CJK UNIFIED IDEOGRAPH-#2B7C3
2B7C4 CJK UNIFIED IDEOGRAPH-#2B7C4
2B7C5 CJK UNIFIED IDEOGRAPH-#2B7C5
2B7C6 CJK UNIFIED IDEOGRAPH-#2B7C6
2B7C7 CJK UNIFIED IDEOGRAPH-#2B7C7
2B7C8 CJK UNIFIED IDEOGRAPH-#2B7C8
2B7C9 CJK UNIFIED IDEOGRAPH-#2B7C9, IRGKangXi=0965.111
2B7CA CJK UNIFIED IDEOGRAPH-#2B7CA
2B7CB CJK UNIFIED IDEOGRAPH-#2B7CB
2B7CC CJK UNIFIED IDEOGRAPH-#2B7CC
2B7CD CJK UNIFIED IDEOGRAPH-#2B7CD
2B7CE CJK UNIFIED IDEOGRAPH-#2B7CE
2B7CF CJK UNIFIED IDEOGRAPH-#2B7CF
2B7D0 CJK UNIFIED IDEOGRAPH-#2B7D0
2B7D1 CJK UNIFIED IDEOGRAPH-#2B7D1
2B7D2 CJK UNIFIED IDEOGRAPH-#2B7D2, IRGKangXi=1042.261
2B7D3 CJK UNIFIED IDEOGRAPH-#2B7D3
2B7D4 CJK UNIFIED IDEOGRAPH-#2B7D4
2B7D5 CJK UNIFIED IDEOGRAPH-#2B7D5
2B7D6 CJK UNIFIED IDEOGRAPH-#2B7D6
2B7D7 CJK UNIFIED IDEOGRAPH-#2B7D7
2B7D8 CJK UNIFIED IDEOGRAPH-#2B7D8
2B7D9 CJK UNIFIED IDEOGRAPH-#2B7D9
2B7DA CJK UNIFIED IDEOGRAPH-#2B7DA
2B7DB CJK UNIFIED IDEOGRAPH-#2B7DB
2B7DC CJK UNIFIED IDEOGRAPH-#2B7DC
2B7DD CJK UNIFIED IDEOGRAPH-#2B7DD
2B7DE CJK UNIFIED IDEOGRAPH-#2B7DE
2B7DF CJK UNIFIED IDEOGRAPH-#2B7DF
2B7E0 CJK UNIFIED IDEOGRAPH-#2B7E0
2B7E1 CJK UNIFIED IDEOGRAPH-#2B7E1
2B7E2 CJK UNIFIED IDEOGRAPH-#2B7E2
2B7E3 CJK UNIFIED IDEOGRAPH-#2B7E3
2B7E4 CJK UNIFIED IDEOGRAPH-#2B7E4
2B7E5 CJK UNIFIED IDEOGRAPH-#2B7E5
2B7E6 CJK UNIFIED IDEOGRAPH-#2B7E6
2B7E7 CJK UNIFIED IDEOGRAPH-#2B7E7
2B7E8 CJK UNIFIED IDEOGRAPH-#2B7E8
2B7E9 CJK UNIFIED IDEOGRAPH-#2B7E9
2B7EA CJK UNIFIED IDEOGRAPH-#2B7EA
2B7EB CJK UNIFIED IDEOGRAPH-#2B7EB
2B7EC CJK UNIFIED IDEOGRAPH-#2B7EC
2B7ED CJK UNIFIED IDEOGRAPH-#2B7ED
2B7EE CJK UNIFIED IDEOGRAPH-#2B7EE
2B7EF CJK UNIFIED IDEOGRAPH-#2B7EF
2B7F0 CJK UNIFIED IDEOGRAPH-#2B7F0, IRGKangXi=1305.211
2B7F1 CJK UNIFIED IDEOGRAPH-#2B7F1
2B7F2 CJK UNIFIED IDEOGRAPH-#2B7F2
2B7F3 CJK UNIFIED IDEOGRAPH-#2B7F3
2B7F4 CJK UNIFIED IDEOGRAPH-#2B7F4
2B7F5 CJK UNIFIED IDEOGRAPH-#2B7F5
2B7F6 CJK UNIFIED IDEOGRAPH-#2B7F6
2B7F7 CJK UNIFIED IDEOGRAPH-#2B7F7
2B7F8 CJK UNIFIED IDEOGRAPH-#2B7F8
2B7F9 CJK UNIFIED IDEOGRAPH-#2B7F9
2B7FA CJK UNIFIED IDEOGRAPH-#2B7FA
2B7FB CJK UNIFIED IDEOGRAPH-#2B7FB
2B7FC CJK UNIFIED IDEOGRAPH-#2B7FC
2B7FD CJK UNIFIED IDEOGRAPH-#2B7FD
2B7FE CJK UNIFIED IDEOGRAPH-#2B7FE
2B7FF CJK UNIFIED IDEOGRAPH-#2B7FF
2B800 CJK UNIFIED IDEOGRAPH-#2B800
2B801 CJK UNIFIED IDEOGRAPH-#2B801
2B802 CJK UNIFIED IDEOGRAPH-#2B802
2B803 CJK UNIFIED IDEOGRAPH-#2B803
2B804 CJK UNIFIED IDEOGRAPH-#2B804
2B805 CJK UNIFIED IDEOGRAPH-#2B805
2B806 CJK UNIFIED IDEOGRAPH-#2B806
2B807 CJK UNIFIED IDEOGRAPH-#2B807
2B808 CJK UNIFIED IDEOGRAPH-#2B808
2B809 CJK UNIFIED IDEOGRAPH-#2B809
2B80A CJK UNIFIED IDEOGRAPH-#2B80A
2B80B CJK UNIFIED IDEOGRAPH-#2B80B
2B80C CJK UNIFIED IDEOGRAPH-#2B80C
2B80D CJK UNIFIED IDEOGRAPH-#2B80D, IRGKangXi=1476.251
2B80E CJK UNIFIED IDEOGRAPH-#2B80E
2B80F CJK UNIFIED IDEOGRAPH-#2B80F
2B810 CJK UNIFIED IDEOGRAPH-#2B810
2B811 CJK UNIFIED IDEOGRAPH-#2B811
2B812 CJK UNIFIED IDEOGRAPH-#2B812
2B813 CJK UNIFIED IDEOGRAPH-#2B813
2B814 CJK UNIFIED IDEOGRAPH-#2B814
2B815 CJK UNIFIED IDEOGRAPH-#2B815
2B816 CJK UNIFIED IDEOGRAPH-#2B816
2B817 CJK UNIFIED IDEOGRAPH-#2B817, IRGKangXi=1507.181
2B818 CJK UNIFIED IDEOGRAPH-#2B818
2B819 CJK UNIFIED IDEOGRAPH-#2B819
2B81A CJK UNIFIED IDEOGRAPH-#2B81A, IRGKangXi=1533.281
2B81B CJK UNIFIED IDEOGRAPH-#2B81B
2B81C CJK UNIFIED IDEOGRAPH-#2B81C
2B81D CJK UNIFIED IDEOGRAPH-#2B81D
2B820 CJK UNIFIED IDEOGRAPH-#2B820
2B821 CJK UNIFIED IDEOGRAPH-#2B821
2B822 CJK UNIFIED IDEOGRAPH-#2B822
2B823 CJK UNIFIED IDEOGRAPH-#2B823
2B824 CJK UNIFIED IDEOGRAPH-#2B824
2B825 CJK UNIFIED IDEOGRAPH-#2B825
2B826 CJK UNIFIED IDEOGRAPH-#2B826
2B827 CJK UNIFIED IDEOGRAPH-#2B827
2B828 CJK UNIFIED IDEOGRAPH-#2B828
2B829 CJK UNIFIED IDEOGRAPH-#2B829
2B82A CJK UNIFIED IDEOGRAPH-#2B82A
2B82B CJK UNIFIED IDEOGRAPH-#2B82B
2B82C CJK UNIFIED IDEOGRAPH-#2B82C
2B82D CJK UNIFIED IDEOGRAPH-#2B82D
2B82E CJK UNIFIED IDEOGRAPH-#2B82E
2B82F CJK UNIFIED IDEOGRAPH-#2B82F
2B830 CJK UNIFIED IDEOGRAPH-#2B830
2B831 CJK UNIFIED IDEOGRAPH-#2B831
2B832 CJK UNIFIED IDEOGRAPH-#2B832
2B833 CJK UNIFIED IDEOGRAPH-#2B833
2B834 CJK UNIFIED IDEOGRAPH-#2B834
2B835 CJK UNIFIED IDEOGRAPH-#2B835
2B836 CJK UNIFIED IDEOGRAPH-#2B836
2B837 CJK UNIFIED IDEOGRAPH-#2B837
2B838 CJK UNIFIED IDEOGRAPH-#2B838
2B839 CJK UNIFIED IDEOGRAPH-#2B839
2B83A CJK UNIFIED IDEOGRAPH-#2B83A
2B83B CJK UNIFIED IDEOGRAPH-#2B83B
2B83C CJK UNIFIED IDEOGRAPH-#2B83C
2B83D CJK UNIFIED IDEOGRAPH-#2B83D
2B83E CJK UNIFIED IDEOGRAPH-#2B83E
2B83F CJK UNIFIED IDEOGRAPH-#2B83F
2B840 CJK UNIFIED IDEOGRAPH-#2B840
2B841 CJK UNIFIED IDEOGRAPH-#2B841
2B842 CJK UNIFIED IDEOGRAPH-#2B842
2B843 CJK UNIFIED IDEOGRAPH-#2B843
2B844 CJK UNIFIED IDEOGRAPH-#2B844
2B845 CJK UNIFIED IDEOGRAPH-#2B845
2B846 CJK UNIFIED IDEOGRAPH-#2B846
2B847 CJK UNIFIED IDEOGRAPH-#2B847
2B848 CJK UNIFIED IDEOGRAPH-#2B848
2B849 CJK UNIFIED IDEOGRAPH-#2B849
2B84A CJK UNIFIED IDEOGRAPH-#2B84A
2B84B CJK UNIFIED IDEOGRAPH-#2B84B
2B84C CJK UNIFIED IDEOGRAPH-#2B84C
2B84D CJK UNIFIED IDEOGRAPH-#2B84D
2B84E CJK UNIFIED IDEOGRAPH-#2B84E
2B84F CJK UNIFIED IDEOGRAPH-#2B84F
2B850 CJK UNIFIED IDEOGRAPH-#2B850
2B851 CJK UNIFIED IDEOGRAPH-#2B851
2B852 CJK UNIFIED IDEOGRAPH-#2B852
2B853 CJK UNIFIED IDEOGRAPH-#2B853
2B854 CJK UNIFIED IDEOGRAPH-#2B854
2B855 CJK UNIFIED IDEOGRAPH-#2B855
2B856 CJK UNIFIED IDEOGRAPH-#2B856
2B857 CJK UNIFIED IDEOGRAPH-#2B857
2B858 CJK UNIFIED IDEOGRAPH-#2B858
2B859 CJK UNIFIED IDEOGRAPH-#2B859
2B85A CJK UNIFIED IDEOGRAPH-#2B85A
2B85B CJK UNIFIED IDEOGRAPH-#2B85B
2B85C CJK UNIFIED IDEOGRAPH-#2B85C
2B85D CJK UNIFIED IDEOGRAPH-#2B85D
2B85E CJK UNIFIED IDEOGRAPH-#2B85E
2B85F CJK UNIFIED IDEOGRAPH-#2B85F
2B860 CJK UNIFIED IDEOGRAPH-#2B860
2B861 CJK UNIFIED IDEOGRAPH-#2B861
2B862 CJK UNIFIED IDEOGRAPH-#2B862
2B863 CJK UNIFIED IDEOGRAPH-#2B863
2B864 CJK UNIFIED IDEOGRAPH-#2B864
2B865 CJK UNIFIED IDEOGRAPH-#2B865
2B866 CJK UNIFIED IDEOGRAPH-#2B866
2B867 CJK UNIFIED IDEOGRAPH-#2B867
2B868 CJK UNIFIED IDEOGRAPH-#2B868
2B869 CJK UNIFIED IDEOGRAPH-#2B869
2B86A CJK UNIFIED IDEOGRAPH-#2B86A
2B86B CJK UNIFIED IDEOGRAPH-#2B86B
2B86C CJK UNIFIED IDEOGRAPH-#2B86C
2B86D CJK UNIFIED IDEOGRAPH-#2B86D
2B86E CJK UNIFIED IDEOGRAPH-#2B86E
2B86F CJK UNIFIED IDEOGRAPH-#2B86F
2B870 CJK UNIFIED IDEOGRAPH-#2B870
2B871 CJK UNIFIED IDEOGRAPH-#2B871
2B872 CJK UNIFIED IDEOGRAPH-#2B872
2B873 CJK UNIFIED IDEOGRAPH-#2B873
2B874 CJK UNIFIED IDEOGRAPH-#2B874
2B875 CJK UNIFIED IDEOGRAPH-#2B875
2B876 CJK UNIFIED IDEOGRAPH-#2B876
2B877 CJK UNIFIED IDEOGRAPH-#2B877
2B878 CJK UNIFIED IDEOGRAPH-#2B878
2B879 CJK UNIFIED IDEOGRAPH-#2B879
2B87A CJK UNIFIED IDEOGRAPH-#2B87A
2B87B CJK UNIFIED IDEOGRAPH-#2B87B
2B87C CJK UNIFIED IDEOGRAPH-#2B87C
2B87D CJK UNIFIED IDEOGRAPH-#2B87D
2B87E CJK UNIFIED IDEOGRAPH-#2B87E
2B87F CJK UNIFIED IDEOGRAPH-#2B87F
2B880 CJK UNIFIED IDEOGRAPH-#2B880
2B881 CJK UNIFIED IDEOGRAPH-#2B881
2B882 CJK UNIFIED IDEOGRAPH-#2B882
2B883 CJK UNIFIED IDEOGRAPH-#2B883
2B884 CJK UNIFIED IDEOGRAPH-#2B884
2B885 CJK UNIFIED IDEOGRAPH-#2B885
2B886 CJK UNIFIED IDEOGRAPH-#2B886
2B887 CJK UNIFIED IDEOGRAPH-#2B887
2B888 CJK UNIFIED IDEOGRAPH-#2B888
2B889 CJK UNIFIED IDEOGRAPH-#2B889
2B88A CJK UNIFIED IDEOGRAPH-#2B88A
2B88B CJK UNIFIED IDEOGRAPH-#2B88B
2B88C CJK UNIFIED IDEOGRAPH-#2B88C
2B88D CJK UNIFIED IDEOGRAPH-#2B88D
2B88E CJK UNIFIED IDEOGRAPH-#2B88E
2B88F CJK UNIFIED IDEOGRAPH-#2B88F
2B890 CJK UNIFIED IDEOGRAPH-#2B890
2B891 CJK UNIFIED IDEOGRAPH-#2B891
2B892 CJK UNIFIED IDEOGRAPH-#2B892
2B893 CJK UNIFIED IDEOGRAPH-#2B893
2B894 CJK UNIFIED IDEOGRAPH-#2B894
2B895 CJK UNIFIED IDEOGRAPH-#2B895
2B896 CJK UNIFIED IDEOGRAPH-#2B896
2B897 CJK UNIFIED IDEOGRAPH-#2B897
2B898 CJK UNIFIED IDEOGRAPH-#2B898
2B899 CJK UNIFIED IDEOGRAPH-#2B899
2B89A CJK UNIFIED IDEOGRAPH-#2B89A
2B89B CJK UNIFIED IDEOGRAPH-#2B89B
2B89C CJK UNIFIED IDEOGRAPH-#2B89C
2B89D CJK UNIFIED IDEOGRAPH-#2B89D
2B89E CJK UNIFIED IDEOGRAPH-#2B89E
2B89F CJK UNIFIED IDEOGRAPH-#2B89F
2B8A0 CJK UNIFIED IDEOGRAPH-#2B8A0
2B8A1 CJK UNIFIED IDEOGRAPH-#2B8A1
2B8A2 CJK UNIFIED IDEOGRAPH-#2B8A2
2B8A3 CJK UNIFIED IDEOGRAPH-#2B8A3
2B8A4 CJK UNIFIED IDEOGRAPH-#2B8A4
2B8A5 CJK UNIFIED IDEOGRAPH-#2B8A5
2B8A6 CJK UNIFIED IDEOGRAPH-#2B8A6
2B8A7 CJK UNIFIED IDEOGRAPH-#2B8A7
2B8A8 CJK UNIFIED IDEOGRAPH-#2B8A8
2B8A9 CJK UNIFIED IDEOGRAPH-#2B8A9
2B8AA CJK UNIFIED IDEOGRAPH-#2B8AA
2B8AB CJK UNIFIED IDEOGRAPH-#2B8AB
2B8AC CJK UNIFIED IDEOGRAPH-#2B8AC
2B8AD CJK UNIFIED IDEOGRAPH-#2B8AD
2B8AE CJK UNIFIED IDEOGRAPH-#2B8AE
2B8AF CJK UNIFIED IDEOGRAPH-#2B8AF
2B8B0 CJK UNIFIED IDEOGRAPH-#2B8B0
2B8B1 CJK UNIFIED IDEOGRAPH-#2B8B1
2B8B2 CJK UNIFIED IDEOGRAPH-#2B8B2
2B8B3 CJK UNIFIED IDEOGRAPH-#2B8B3
2B8B4 CJK UNIFIED IDEOGRAPH-#2B8B4
2B8B5 CJK UNIFIED IDEOGRAPH-#2B8B5
2B8B6 CJK UNIFIED IDEOGRAPH-#2B8B6
2B8B7 CJK UNIFIED IDEOGRAPH-#2B8B7
2B8B8 CJK UNIFIED IDEOGRAPH-#2B8B8
2B8B9 CJK UNIFIED IDEOGRAPH-#2B8B9
2B8BA CJK UNIFIED IDEOGRAPH-#2B8BA
2B8BB CJK UNIFIED IDEOGRAPH-#2B8BB
2B8BC CJK UNIFIED IDEOGRAPH-#2B8BC
2B8BD CJK UNIFIED IDEOGRAPH-#2B8BD
2B8BE CJK UNIFIED IDEOGRAPH-#2B8BE
2B8BF CJK UNIFIED IDEOGRAPH-#2B8BF
2B8C0 CJK UNIFIED IDEOGRAPH-#2B8C0
2B8C1 CJK UNIFIED IDEOGRAPH-#2B8C1
2B8C2 CJK UNIFIED IDEOGRAPH-#2B8C2
2B8C3 CJK UNIFIED IDEOGRAPH-#2B8C3
2B8C4 CJK UNIFIED IDEOGRAPH-#2B8C4
2B8C5 CJK UNIFIED IDEOGRAPH-#2B8C5
2B8C6 CJK UNIFIED IDEOGRAPH-#2B8C6
2B8C7 CJK UNIFIED IDEOGRAPH-#2B8C7
2B8C8 CJK UNIFIED IDEOGRAPH-#2B8C8
2B8C9 CJK UNIFIED IDEOGRAPH-#2B8C9
2B8CA CJK UNIFIED IDEOGRAPH-#2B8CA
2B8CB CJK UNIFIED IDEOGRAPH-#2B8CB
2B8CC CJK UNIFIED IDEOGRAPH-#2B8CC
2B8CD CJK UNIFIED IDEOGRAPH-#2B8CD
2B8CE CJK UNIFIED IDEOGRAPH-#2B8CE
2B8CF CJK UNIFIED IDEOGRAPH-#2B8CF
2B8D0 CJK UNIFIED IDEOGRAPH-#2B8D0
2B8D1 CJK UNIFIED IDEOGRAPH-#2B8D1
2B8D2 CJK UNIFIED IDEOGRAPH-#2B8D2
2B8D3 CJK UNIFIED IDEOGRAPH-#2B8D3
2B8D4 CJK UNIFIED IDEOGRAPH-#2B8D4
2B8D5 CJK UNIFIED IDEOGRAPH-#2B8D5
2B8D6 CJK UNIFIED IDEOGRAPH-#2B8D6
2B8D7 CJK UNIFIED IDEOGRAPH-#2B8D7
2B8D8 CJK UNIFIED IDEOGRAPH-#2B8D8
2B8D9 CJK UNIFIED IDEOGRAPH-#2B8D9
2B8DA CJK UNIFIED IDEOGRAPH-#2B8DA
2B8DB CJK UNIFIED IDEOGRAPH-#2B8DB
2B8DC CJK UNIFIED IDEOGRAPH-#2B8DC
2B8DD CJK UNIFIED IDEOGRAPH-#2B8DD
2B8DE CJK UNIFIED IDEOGRAPH-#2B8DE
2B8DF CJK UNIFIED IDEOGRAPH-#2B8DF
2B8E0 CJK UNIFIED IDEOGRAPH-#2B8E0
2B8E1 CJK UNIFIED IDEOGRAPH-#2B8E1
2B8E2 CJK UNIFIED IDEOGRAPH-#2B8E2
2B8E3 CJK UNIFIED IDEOGRAPH-#2B8E3
2B8E4 CJK UNIFIED IDEOGRAPH-#2B8E4
2B8E5 CJK UNIFIED IDEOGRAPH-#2B8E5
2B8E6 CJK UNIFIED IDEOGRAPH-#2B8E6
2B8E7 CJK UNIFIED IDEOGRAPH-#2B8E7
2B8E8 CJK UNIFIED IDEOGRAPH-#2B8E8
2B8E9 CJK UNIFIED IDEOGRAPH-#2B8E9
2B8EA CJK UNIFIED IDEOGRAPH-#2B8EA
2B8EB CJK UNIFIED IDEOGRAPH-#2B8EB
2B8EC CJK UNIFIED IDEOGRAPH-#2B8EC
2B8ED CJK UNIFIED IDEOGRAPH-#2B8ED
2B8EE CJK UNIFIED IDEOGRAPH-#2B8EE
2B8EF CJK UNIFIED IDEOGRAPH-#2B8EF
2B8F0 CJK UNIFIED IDEOGRAPH-#2B8F0
2B8F1 CJK UNIFIED IDEOGRAPH-#2B8F1
2B8F2 CJK UNIFIED IDEOGRAPH-#2B8F2
2B8F3 CJK UNIFIED IDEOGRAPH-#2B8F3
2B8F4 CJK UNIFIED IDEOGRAPH-#2B8F4
2B8F5 CJK UNIFIED IDEOGRAPH-#2B8F5
2B8F6 CJK UNIFIED IDEOGRAPH-#2B8F6
2B8F7 CJK UNIFIED IDEOGRAPH-#2B8F7
2B8F8 CJK UNIFIED IDEOGRAPH-#2B8F8
2B8F9 CJK UNIFIED IDEOGRAPH-#2B8F9
2B8FA CJK UNIFIED IDEOGRAPH-#2B8FA
2B8FB CJK UNIFIED IDEOGRAPH-#2B8FB
2B8FC CJK UNIFIED IDEOGRAPH-#2B8FC
2B8FD CJK UNIFIED IDEOGRAPH-#2B8FD
2B8FE CJK UNIFIED IDEOGRAPH-#2B8FE
2B8FF CJK UNIFIED IDEOGRAPH-#2B8FF
2B900 CJK UNIFIED IDEOGRAPH-#2B900
2B901 CJK UNIFIED IDEOGRAPH-#2B901
2B902 CJK UNIFIED IDEOGRAPH-#2B902
2B903 CJK UNIFIED IDEOGRAPH-#2B903
2B904 CJK UNIFIED IDEOGRAPH-#2B904
2B905 CJK UNIFIED IDEOGRAPH-#2B905
2B906 CJK UNIFIED IDEOGRAPH-#2B906
2B907 CJK UNIFIED IDEOGRAPH-#2B907
2B908 CJK UNIFIED IDEOGRAPH-#2B908
2B909 CJK UNIFIED IDEOGRAPH-#2B909
2B90A CJK UNIFIED IDEOGRAPH-#2B90A
2B90B CJK UNIFIED IDEOGRAPH-#2B90B
2B90C CJK UNIFIED IDEOGRAPH-#2B90C
2B90D CJK UNIFIED IDEOGRAPH-#2B90D
2B90E CJK UNIFIED IDEOGRAPH-#2B90E
2B90F CJK UNIFIED IDEOGRAPH-#2B90F
2B910 CJK UNIFIED IDEOGRAPH-#2B910
2B911 CJK UNIFIED IDEOGRAPH-#2B911
2B912 CJK UNIFIED IDEOGRAPH-#2B912
2B913 CJK UNIFIED IDEOGRAPH-#2B913
2B914 CJK UNIFIED IDEOGRAPH-#2B914
2B915 CJK UNIFIED IDEOGRAPH-#2B915
2B916 CJK UNIFIED IDEOGRAPH-#2B916
2B917 CJK UNIFIED IDEOGRAPH-#2B917
2B918 CJK UNIFIED IDEOGRAPH-#2B918
2B919 CJK UNIFIED IDEOGRAPH-#2B919
2B91A CJK UNIFIED IDEOGRAPH-#2B91A
2B91B CJK UNIFIED IDEOGRAPH-#2B91B
2B91C CJK UNIFIED IDEOGRAPH-#2B91C
2B91D CJK UNIFIED IDEOGRAPH-#2B91D
2B91E CJK UNIFIED IDEOGRAPH-#2B91E
2B91F CJK UNIFIED IDEOGRAPH-#2B91F
2B920 CJK UNIFIED IDEOGRAPH-#2B920
2B921 CJK UNIFIED IDEOGRAPH-#2B921
2B922 CJK UNIFIED IDEOGRAPH-#2B922
2B923 CJK UNIFIED IDEOGRAPH-#2B923
2B924 CJK UNIFIED IDEOGRAPH-#2B924
2B925 CJK UNIFIED IDEOGRAPH-#2B925
2B926 CJK UNIFIED IDEOGRAPH-#2B926
2B927 CJK UNIFIED IDEOGRAPH-#2B927
2B928 CJK UNIFIED IDEOGRAPH-#2B928
2B929 CJK UNIFIED IDEOGRAPH-#2B929
2B92A CJK UNIFIED IDEOGRAPH-#2B92A
2B92B CJK UNIFIED IDEOGRAPH-#2B92B
2B92C CJK UNIFIED IDEOGRAPH-#2B92C
2B92D CJK UNIFIED IDEOGRAPH-#2B92D
2B92E CJK UNIFIED IDEOGRAPH-#2B92E
2B92F CJK UNIFIED IDEOGRAPH-#2B92F
2B930 CJK UNIFIED IDEOGRAPH-#2B930
2B931 CJK UNIFIED IDEOGRAPH-#2B931
2B932 CJK UNIFIED IDEOGRAPH-#2B932
2B933 CJK UNIFIED IDEOGRAPH-#2B933
2B934 CJK UNIFIED IDEOGRAPH-#2B934
2B935 CJK UNIFIED IDEOGRAPH-#2B935
2B936 CJK UNIFIED IDEOGRAPH-#2B936
2B937 CJK UNIFIED IDEOGRAPH-#2B937
2B938 CJK UNIFIED IDEOGRAPH-#2B938
2B939 CJK UNIFIED IDEOGRAPH-#2B939
2B93A CJK UNIFIED IDEOGRAPH-#2B93A
2B93B CJK UNIFIED IDEOGRAPH-#2B93B
2B93C CJK UNIFIED IDEOGRAPH-#2B93C
2B93D CJK UNIFIED IDEOGRAPH-#2B93D
2B93E CJK UNIFIED IDEOGRAPH-#2B93E
2B93F CJK UNIFIED IDEOGRAPH-#2B93F
2B940 CJK UNIFIED IDEOGRAPH-#2B940
2B941 CJK UNIFIED IDEOGRAPH-#2B941
2B942 CJK UNIFIED IDEOGRAPH-#2B942
2B943 CJK UNIFIED IDEOGRAPH-#2B943
2B944 CJK UNIFIED IDEOGRAPH-#2B944
2B945 CJK UNIFIED IDEOGRAPH-#2B945
2B946 CJK UNIFIED IDEOGRAPH-#2B946
2B947 CJK UNIFIED IDEOGRAPH-#2B947
2B948 CJK UNIFIED IDEOGRAPH-#2B948
2B949 CJK UNIFIED IDEOGRAPH-#2B949
2B94A CJK UNIFIED IDEOGRAPH-#2B94A
2B94B CJK UNIFIED IDEOGRAPH-#2B94B
2B94C CJK UNIFIED IDEOGRAPH-#2B94C
2B94D CJK UNIFIED IDEOGRAPH-#2B94D
2B94E CJK UNIFIED IDEOGRAPH-#2B94E
2B94F CJK UNIFIED IDEOGRAPH-#2B94F
2B950 CJK UNIFIED IDEOGRAPH-#2B950
2B951 CJK UNIFIED IDEOGRAPH-#2B951
2B952 CJK UNIFIED IDEOGRAPH-#2B952
2B953 CJK UNIFIED IDEOGRAPH-#2B953
2B954 CJK UNIFIED IDEOGRAPH-#2B954
2B955 CJK UNIFIED IDEOGRAPH-#2B955
2B956 CJK UNIFIED IDEOGRAPH-#2B956
2B957 CJK UNIFIED IDEOGRAPH-#2B957
2B958 CJK UNIFIED IDEOGRAPH-#2B958
2B959 CJK UNIFIED IDEOGRAPH-#2B959
2B95A CJK UNIFIED IDEOGRAPH-#2B95A
2B95B CJK UNIFIED IDEOGRAPH-#2B95B
2B95C CJK UNIFIED IDEOGRAPH-#2B95C
2B95D CJK UNIFIED IDEOGRAPH-#2B95D
2B95E CJK UNIFIED IDEOGRAPH-#2B95E
2B95F CJK UNIFIED IDEOGRAPH-#2B95F
2B960 CJK UNIFIED IDEOGRAPH-#2B960
2B961 CJK UNIFIED IDEOGRAPH-#2B961
2B962 CJK UNIFIED IDEOGRAPH-#2B962
2B963 CJK UNIFIED IDEOGRAPH-#2B963
2B964 CJK UNIFIED IDEOGRAPH-#2B964
2B965 CJK UNIFIED IDEOGRAPH-#2B965
2B966 CJK UNIFIED IDEOGRAPH-#2B966
2B967 CJK UNIFIED IDEOGRAPH-#2B967
2B968 CJK UNIFIED IDEOGRAPH-#2B968
2B969 CJK UNIFIED IDEOGRAPH-#2B969
2B96A CJK UNIFIED IDEOGRAPH-#2B96A
2B96B CJK UNIFIED IDEOGRAPH-#2B96B
2B96C CJK UNIFIED IDEOGRAPH-#2B96C
2B96D CJK UNIFIED IDEOGRAPH-#2B96D
2B96E CJK UNIFIED IDEOGRAPH-#2B96E
2B96F CJK UNIFIED IDEOGRAPH-#2B96F
2B970 CJK UNIFIED IDEOGRAPH-#2B970
2B971 CJK UNIFIED IDEOGRAPH-#2B971
2B972 CJK UNIFIED IDEOGRAPH-#2B972
2B973 CJK UNIFIED IDEOGRAPH-#2B973
2B974 CJK UNIFIED IDEOGRAPH-#2B974
2B975 CJK UNIFIED IDEOGRAPH-#2B975
2B976 CJK UNIFIED IDEOGRAPH-#2B976
2B977 CJK UNIFIED IDEOGRAPH-#2B977
2B978 CJK UNIFIED IDEOGRAPH-#2B978
2B979 CJK UNIFIED IDEOGRAPH-#2B979
2B97A CJK UNIFIED IDEOGRAPH-#2B97A
2B97B CJK UNIFIED IDEOGRAPH-#2B97B
2B97C CJK UNIFIED IDEOGRAPH-#2B97C
2B97D CJK UNIFIED IDEOGRAPH-#2B97D
2B97E CJK UNIFIED IDEOGRAPH-#2B97E
2B97F CJK UNIFIED IDEOGRAPH-#2B97F
2B980 CJK UNIFIED IDEOGRAPH-#2B980
2B981 CJK UNIFIED IDEOGRAPH-#2B981
2B982 CJK UNIFIED IDEOGRAPH-#2B982
2B983 CJK UNIFIED IDEOGRAPH-#2B983
2B984 CJK UNIFIED IDEOGRAPH-#2B984
2B985 CJK UNIFIED IDEOGRAPH-#2B985
2B986 CJK UNIFIED IDEOGRAPH-#2B986
2B987 CJK UNIFIED IDEOGRAPH-#2B987
2B988 CJK UNIFIED IDEOGRAPH-#2B988
2B989 CJK UNIFIED IDEOGRAPH-#2B989
2B98A CJK UNIFIED IDEOGRAPH-#2B98A
2B98B CJK UNIFIED IDEOGRAPH-#2B98B
2B98C CJK UNIFIED IDEOGRAPH-#2B98C
2B98D CJK UNIFIED IDEOGRAPH-#2B98D
2B98E CJK UNIFIED IDEOGRAPH-#2B98E
2B98F CJK UNIFIED IDEOGRAPH-#2B98F
2B990 CJK UNIFIED IDEOGRAPH-#2B990
2B991 CJK UNIFIED IDEOGRAPH-#2B991
2B992 CJK UNIFIED IDEOGRAPH-#2B992
2B993 CJK UNIFIED IDEOGRAPH-#2B993
2B994 CJK UNIFIED IDEOGRAPH-#2B994
2B995 CJK UNIFIED IDEOGRAPH-#2B995
2B996 CJK UNIFIED IDEOGRAPH-#2B996
2B997 CJK UNIFIED IDEOGRAPH-#2B997
2B998 CJK UNIFIED IDEOGRAPH-#2B998
2B999 CJK UNIFIED IDEOGRAPH-#2B999
2B99A CJK UNIFIED IDEOGRAPH-#2B99A
2B99B CJK UNIFIED IDEOGRAPH-#2B99B
2B99C CJK UNIFIED IDEOGRAPH-#2B99C
2B99D CJK UNIFIED IDEOGRAPH-#2B99D
2B99E CJK UNIFIED IDEOGRAPH-#2B99E
2B99F CJK UNIFIED IDEOGRAPH-#2B99F
2B9A0 CJK UNIFIED IDEOGRAPH-#2B9A0
2B9A1 CJK UNIFIED IDEOGRAPH-#2B9A1
2B9A2 CJK UNIFIED IDEOGRAPH-#2B9A2
2B9A3 CJK UNIFIED IDEOGRAPH-#2B9A3
2B9A4 CJK UNIFIED IDEOGRAPH-#2B9A4
2B9A5 CJK UNIFIED IDEOGRAPH-#2B9A5
2B9A6 CJK UNIFIED IDEOGRAPH-#2B9A6
2B9A7 CJK UNIFIED IDEOGRAPH-#2B9A7
2B9A8 CJK UNIFIED IDEOGRAPH-#2B9A8
2B9A9 CJK UNIFIED IDEOGRAPH-#2B9A9
2B9AA CJK UNIFIED IDEOGRAPH-#2B9AA
2B9AB CJK UNIFIED IDEOGRAPH-#2B9AB
2B9AC CJK UNIFIED IDEOGRAPH-#2B9AC
2B9AD CJK UNIFIED IDEOGRAPH-#2B9AD
2B9AE CJK UNIFIED IDEOGRAPH-#2B9AE
2B9AF CJK UNIFIED IDEOGRAPH-#2B9AF
2B9B0 CJK UNIFIED IDEOGRAPH-#2B9B0
2B9B1 CJK UNIFIED IDEOGRAPH-#2B9B1
2B9B2 CJK UNIFIED IDEOGRAPH-#2B9B2
2B9B3 CJK UNIFIED IDEOGRAPH-#2B9B3
2B9B4 CJK UNIFIED IDEOGRAPH-#2B9B4
2B9B5 CJK UNIFIED IDEOGRAPH-#2B9B5
2B9B6 CJK UNIFIED IDEOGRAPH-#2B9B6
2B9B7 CJK UNIFIED IDEOGRAPH-#2B9B7
2B9B8 CJK UNIFIED IDEOGRAPH-#2B9B8
2B9B9 CJK UNIFIED IDEOGRAPH-#2B9B9
2B9BA CJK UNIFIED IDEOGRAPH-#2B9BA
2B9BB CJK UNIFIED IDEOGRAPH-#2B9BB
2B9BC CJK UNIFIED IDEOGRAPH-#2B9BC
2B9BD CJK UNIFIED IDEOGRAPH-#2B9BD
2B9BE CJK UNIFIED IDEOGRAPH-#2B9BE
2B9BF CJK UNIFIED IDEOGRAPH-#2B9BF
2B9C0 CJK UNIFIED IDEOGRAPH-#2B9C0
2B9C1 CJK UNIFIED IDEOGRAPH-#2B9C1
2B9C2 CJK UNIFIED IDEOGRAPH-#2B9C2
2B9C3 CJK UNIFIED IDEOGRAPH-#2B9C3
2B9C4 CJK UNIFIED IDEOGRAPH-#2B9C4
2B9C5 CJK UNIFIED IDEOGRAPH-#2B9C5
2B9C6 CJK UNIFIED IDEOGRAPH-#2B9C6
2B9C7 CJK UNIFIED IDEOGRAPH-#2B9C7
2B9C8 CJK UNIFIED IDEOGRAPH-#2B9C8
2B9C9 CJK UNIFIED IDEOGRAPH-#2B9C9
2B9CA CJK UNIFIED IDEOGRAPH-#2B9CA
2B9CB CJK UNIFIED IDEOGRAPH-#2B9CB
2B9CC CJK UNIFIED IDEOGRAPH-#2B9CC
2B9CD CJK UNIFIED IDEOGRAPH-#2B9CD
2B9CE CJK UNIFIED IDEOGRAPH-#2B9CE
2B9CF CJK UNIFIED IDEOGRAPH-#2B9CF
2B9D0 CJK UNIFIED IDEOGRAPH-#2B9D0
2B9D1 CJK UNIFIED IDEOGRAPH-#2B9D1
2B9D2 CJK UNIFIED IDEOGRAPH-#2B9D2
2B9D3 CJK UNIFIED IDEOGRAPH-#2B9D3
2B9D4 CJK UNIFIED IDEOGRAPH-#2B9D4
2B9D5 CJK UNIFIED IDEOGRAPH-#2B9D5
2B9D6 CJK UNIFIED IDEOGRAPH-#2B9D6
2B9D7 CJK UNIFIED IDEOGRAPH-#2B9D7
2B9D8 CJK UNIFIED IDEOGRAPH-#2B9D8
2B9D9 CJK UNIFIED IDEOGRAPH-#2B9D9
2B9DA CJK UNIFIED IDEOGRAPH-#2B9DA
2B9DB CJK UNIFIED IDEOGRAPH-#2B9DB
2B9DC CJK UNIFIED IDEOGRAPH-#2B9DC
2B9DD CJK UNIFIED IDEOGRAPH-#2B9DD
2B9DE CJK UNIFIED IDEOGRAPH-#2B9DE
2B9DF CJK UNIFIED IDEOGRAPH-#2B9DF
2B9E0 CJK UNIFIED IDEOGRAPH-#2B9E0
2B9E1 CJK UNIFIED IDEOGRAPH-#2B9E1
2B9E2 CJK UNIFIED IDEOGRAPH-#2B9E2
2B9E3 CJK UNIFIED IDEOGRAPH-#2B9E3
2B9E4 CJK UNIFIED IDEOGRAPH-#2B9E4
2B9E5 CJK UNIFIED IDEOGRAPH-#2B9E5
2B9E6 CJK UNIFIED IDEOGRAPH-#2B9E6
2B9E7 CJK UNIFIED IDEOGRAPH-#2B9E7
2B9E8 CJK UNIFIED IDEOGRAPH-#2B9E8
2B9E9 CJK UNIFIED IDEOGRAPH-#2B9E9
2B9EA CJK UNIFIED IDEOGRAPH-#2B9EA
2B9EB CJK UNIFIED IDEOGRAPH-#2B9EB
2B9EC CJK UNIFIED IDEOGRAPH-#2B9EC
2B9ED CJK UNIFIED IDEOGRAPH-#2B9ED
2B9EE CJK UNIFIED IDEOGRAPH-#2B9EE
2B9EF CJK UNIFIED IDEOGRAPH-#2B9EF
2B9F0 CJK UNIFIED IDEOGRAPH-#2B9F0
2B9F1 CJK UNIFIED IDEOGRAPH-#2B9F1
2B9F2 CJK UNIFIED IDEOGRAPH-#2B9F2
2B9F3 CJK UNIFIED IDEOGRAPH-#2B9F3
2B9F4 CJK UNIFIED IDEOGRAPH-#2B9F4
2B9F5 CJK UNIFIED IDEOGRAPH-#2B9F5
2B9F6 CJK UNIFIED IDEOGRAPH-#2B9F6
2B9F7 CJK UNIFIED IDEOGRAPH-#2B9F7
2B9F8 CJK UNIFIED IDEOGRAPH-#2B9F8
2B9F9 CJK UNIFIED IDEOGRAPH-#2B9F9
2B9FA CJK UNIFIED IDEOGRAPH-#2B9FA
2B9FB CJK UNIFIED IDEOGRAPH-#2B9FB
2B9FC CJK UNIFIED IDEOGRAPH-#2B9FC
2B9FD CJK UNIFIED IDEOGRAPH-#2B9FD
2B9FE CJK UNIFIED IDEOGRAPH-#2B9FE
2B9FF CJK UNIFIED IDEOGRAPH-#2B9FF
2BA00 CJK UNIFIED IDEOGRAPH-#2BA00
2BA01 CJK UNIFIED IDEOGRAPH-#2BA01
2BA02 CJK UNIFIED IDEOGRAPH-#2BA02
2BA03 CJK UNIFIED IDEOGRAPH-#2BA03
2BA04 CJK UNIFIED IDEOGRAPH-#2BA04
2BA05 CJK UNIFIED IDEOGRAPH-#2BA05
2BA06 CJK UNIFIED IDEOGRAPH-#2BA06
2BA07 CJK UNIFIED IDEOGRAPH-#2BA07
2BA08 CJK UNIFIED IDEOGRAPH-#2BA08
2BA09 CJK UNIFIED IDEOGRAPH-#2BA09
2BA0A CJK UNIFIED IDEOGRAPH-#2BA0A
2BA0B CJK UNIFIED IDEOGRAPH-#2BA0B
2BA0C CJK UNIFIED IDEOGRAPH-#2BA0C
2BA0D CJK UNIFIED IDEOGRAPH-#2BA0D
2BA0E CJK UNIFIED IDEOGRAPH-#2BA0E
2BA0F CJK UNIFIED IDEOGRAPH-#2BA0F
2BA10 CJK UNIFIED IDEOGRAPH-#2BA10
2BA11 CJK UNIFIED IDEOGRAPH-#2BA11
2BA12 CJK UNIFIED IDEOGRAPH-#2BA12
2BA13 CJK UNIFIED IDEOGRAPH-#2BA13
2BA14 CJK UNIFIED IDEOGRAPH-#2BA14
2BA15 CJK UNIFIED IDEOGRAPH-#2BA15
2BA16 CJK UNIFIED IDEOGRAPH-#2BA16
2BA17 CJK UNIFIED IDEOGRAPH-#2BA17
2BA18 CJK UNIFIED IDEOGRAPH-#2BA18
2BA19 CJK UNIFIED IDEOGRAPH-#2BA19
2BA1A CJK UNIFIED IDEOGRAPH-#2BA1A
2BA1B CJK UNIFIED IDEOGRAPH-#2BA1B
2BA1C CJK UNIFIED IDEOGRAPH-#2BA1C
2BA1D CJK UNIFIED IDEOGRAPH-#2BA1D
2BA1E CJK UNIFIED IDEOGRAPH-#2BA1E
2BA1F CJK UNIFIED IDEOGRAPH-#2BA1F
2BA20 CJK UNIFIED IDEOGRAPH-#2BA20
2BA21 CJK UNIFIED IDEOGRAPH-#2BA21
2BA22 CJK UNIFIED IDEOGRAPH-#2BA22
2BA23 CJK UNIFIED IDEOGRAPH-#2BA23
2BA24 CJK UNIFIED IDEOGRAPH-#2BA24
2BA25 CJK UNIFIED IDEOGRAPH-#2BA25
2BA26 CJK UNIFIED IDEOGRAPH-#2BA26
2BA27 CJK UNIFIED IDEOGRAPH-#2BA27
2BA28 CJK UNIFIED IDEOGRAPH-#2BA28
2BA29 CJK UNIFIED IDEOGRAPH-#2BA29
2BA2A CJK UNIFIED IDEOGRAPH-#2BA2A
2BA2B CJK UNIFIED IDEOGRAPH-#2BA2B
2BA2C CJK UNIFIED IDEOGRAPH-#2BA2C
2BA2D CJK UNIFIED IDEOGRAPH-#2BA2D
2BA2E CJK UNIFIED IDEOGRAPH-#2BA2E
2BA2F CJK UNIFIED IDEOGRAPH-#2BA2F
2BA30 CJK UNIFIED IDEOGRAPH-#2BA30
2BA31 CJK UNIFIED IDEOGRAPH-#2BA31
2BA32 CJK UNIFIED IDEOGRAPH-#2BA32
2BA33 CJK UNIFIED IDEOGRAPH-#2BA33
2BA34 CJK UNIFIED IDEOGRAPH-#2BA34
2BA35 CJK UNIFIED IDEOGRAPH-#2BA35
2BA36 CJK UNIFIED IDEOGRAPH-#2BA36
2BA37 CJK UNIFIED IDEOGRAPH-#2BA37
2BA38 CJK UNIFIED IDEOGRAPH-#2BA38
2BA39 CJK UNIFIED IDEOGRAPH-#2BA39
2BA3A CJK UNIFIED IDEOGRAPH-#2BA3A
2BA3B CJK UNIFIED IDEOGRAPH-#2BA3B
2BA3C CJK UNIFIED IDEOGRAPH-#2BA3C
2BA3D CJK UNIFIED IDEOGRAPH-#2BA3D
2BA3E CJK UNIFIED IDEOGRAPH-#2BA3E
2BA3F CJK UNIFIED IDEOGRAPH-#2BA3F
2BA40 CJK UNIFIED IDEOGRAPH-#2BA40
2BA41 CJK UNIFIED IDEOGRAPH-#2BA41
2BA42 CJK UNIFIED IDEOGRAPH-#2BA42
2BA43 CJK UNIFIED IDEOGRAPH-#2BA43
2BA44 CJK UNIFIED IDEOGRAPH-#2BA44
2BA45 CJK UNIFIED IDEOGRAPH-#2BA45
2BA46 CJK UNIFIED IDEOGRAPH-#2BA46
2BA47 CJK UNIFIED IDEOGRAPH-#2BA47
2BA48 CJK UNIFIED IDEOGRAPH-#2BA48
2BA49 CJK UNIFIED IDEOGRAPH-#2BA49
2BA4A CJK UNIFIED IDEOGRAPH-#2BA4A
2BA4B CJK UNIFIED IDEOGRAPH-#2BA4B
2BA4C CJK UNIFIED IDEOGRAPH-#2BA4C
2BA4D CJK UNIFIED IDEOGRAPH-#2BA4D
2BA4E CJK UNIFIED IDEOGRAPH-#2BA4E
2BA4F CJK UNIFIED IDEOGRAPH-#2BA4F
2BA50 CJK UNIFIED IDEOGRAPH-#2BA50
2BA51 CJK UNIFIED IDEOGRAPH-#2BA51
2BA52 CJK UNIFIED IDEOGRAPH-#2BA52
2BA53 CJK UNIFIED IDEOGRAPH-#2BA53
2BA54 CJK UNIFIED IDEOGRAPH-#2BA54
2BA55 CJK UNIFIED IDEOGRAPH-#2BA55
2BA56 CJK UNIFIED IDEOGRAPH-#2BA56
2BA57 CJK UNIFIED IDEOGRAPH-#2BA57
2BA58 CJK UNIFIED IDEOGRAPH-#2BA58
2BA59 CJK UNIFIED IDEOGRAPH-#2BA59
2BA5A CJK UNIFIED IDEOGRAPH-#2BA5A
2BA5B CJK UNIFIED IDEOGRAPH-#2BA5B
2BA5C CJK UNIFIED IDEOGRAPH-#2BA5C
2BA5D CJK UNIFIED IDEOGRAPH-#2BA5D
2BA5E CJK UNIFIED IDEOGRAPH-#2BA5E
2BA5F CJK UNIFIED IDEOGRAPH-#2BA5F
2BA60 CJK UNIFIED IDEOGRAPH-#2BA60
2BA61 CJK UNIFIED IDEOGRAPH-#2BA61
2BA62 CJK UNIFIED IDEOGRAPH-#2BA62
2BA63 CJK UNIFIED IDEOGRAPH-#2BA63
2BA64 CJK UNIFIED IDEOGRAPH-#2BA64
2BA65 CJK UNIFIED IDEOGRAPH-#2BA65
2BA66 CJK UNIFIED IDEOGRAPH-#2BA66
2BA67 CJK UNIFIED IDEOGRAPH-#2BA67
2BA68 CJK UNIFIED IDEOGRAPH-#2BA68
2BA69 CJK UNIFIED IDEOGRAPH-#2BA69
2BA6A CJK UNIFIED IDEOGRAPH-#2BA6A
2BA6B CJK UNIFIED IDEOGRAPH-#2BA6B
2BA6C CJK UNIFIED IDEOGRAPH-#2BA6C
2BA6D CJK UNIFIED IDEOGRAPH-#2BA6D
2BA6E CJK UNIFIED IDEOGRAPH-#2BA6E
2BA6F CJK UNIFIED IDEOGRAPH-#2BA6F
2BA70 CJK UNIFIED IDEOGRAPH-#2BA70
2BA71 CJK UNIFIED IDEOGRAPH-#2BA71
2BA72 CJK UNIFIED IDEOGRAPH-#2BA72
2BA73 CJK UNIFIED IDEOGRAPH-#2BA73
2BA74 CJK UNIFIED IDEOGRAPH-#2BA74
2BA75 CJK UNIFIED IDEOGRAPH-#2BA75
2BA76 CJK UNIFIED IDEOGRAPH-#2BA76
2BA77 CJK UNIFIED IDEOGRAPH-#2BA77
2BA78 CJK UNIFIED IDEOGRAPH-#2BA78
2BA79 CJK UNIFIED IDEOGRAPH-#2BA79
2BA7A CJK UNIFIED IDEOGRAPH-#2BA7A
2BA7B CJK UNIFIED IDEOGRAPH-#2BA7B
2BA7C CJK UNIFIED IDEOGRAPH-#2BA7C
2BA7D CJK UNIFIED IDEOGRAPH-#2BA7D
2BA7E CJK UNIFIED IDEOGRAPH-#2BA7E
2BA7F CJK UNIFIED IDEOGRAPH-#2BA7F
2BA80 CJK UNIFIED IDEOGRAPH-#2BA80
2BA81 CJK UNIFIED IDEOGRAPH-#2BA81
2BA82 CJK UNIFIED IDEOGRAPH-#2BA82
2BA83 CJK UNIFIED IDEOGRAPH-#2BA83
2BA84 CJK UNIFIED IDEOGRAPH-#2BA84
2BA85 CJK UNIFIED IDEOGRAPH-#2BA85
2BA86 CJK UNIFIED IDEOGRAPH-#2BA86
2BA87 CJK UNIFIED IDEOGRAPH-#2BA87
2BA88 CJK UNIFIED IDEOGRAPH-#2BA88
2BA89 CJK UNIFIED IDEOGRAPH-#2BA89
2BA8A CJK UNIFIED IDEOGRAPH-#2BA8A
2BA8B CJK UNIFIED IDEOGRAPH-#2BA8B
2BA8C CJK UNIFIED IDEOGRAPH-#2BA8C
2BA8D CJK UNIFIED IDEOGRAPH-#2BA8D
2BA8E CJK UNIFIED IDEOGRAPH-#2BA8E
2BA8F CJK UNIFIED IDEOGRAPH-#2BA8F
2BA90 CJK UNIFIED IDEOGRAPH-#2BA90
2BA91 CJK UNIFIED IDEOGRAPH-#2BA91
2BA92 CJK UNIFIED IDEOGRAPH-#2BA92
2BA93 CJK UNIFIED IDEOGRAPH-#2BA93
2BA94 CJK UNIFIED IDEOGRAPH-#2BA94
2BA95 CJK UNIFIED IDEOGRAPH-#2BA95
2BA96 CJK UNIFIED IDEOGRAPH-#2BA96
2BA97 CJK UNIFIED IDEOGRAPH-#2BA97
2BA98 CJK UNIFIED IDEOGRAPH-#2BA98
2BA99 CJK UNIFIED IDEOGRAPH-#2BA99
2BA9A CJK UNIFIED IDEOGRAPH-#2BA9A
2BA9B CJK UNIFIED IDEOGRAPH-#2BA9B
2BA9C CJK UNIFIED IDEOGRAPH-#2BA9C
2BA9D CJK UNIFIED IDEOGRAPH-#2BA9D
2BA9E CJK UNIFIED IDEOGRAPH-#2BA9E
2BA9F CJK UNIFIED IDEOGRAPH-#2BA9F
2BAA0 CJK UNIFIED IDEOGRAPH-#2BAA0
2BAA1 CJK UNIFIED IDEOGRAPH-#2BAA1
2BAA2 CJK UNIFIED IDEOGRAPH-#2BAA2
2BAA3 CJK UNIFIED IDEOGRAPH-#2BAA3
2BAA4 CJK UNIFIED IDEOGRAPH-#2BAA4
2BAA5 CJK UNIFIED IDEOGRAPH-#2BAA5
2BAA6 CJK UNIFIED IDEOGRAPH-#2BAA6
2BAA7 CJK UNIFIED IDEOGRAPH-#2BAA7
2BAA8 CJK UNIFIED IDEOGRAPH-#2BAA8
2BAA9 CJK UNIFIED IDEOGRAPH-#2BAA9
2BAAA CJK UNIFIED IDEOGRAPH-#2BAAA
2BAAB CJK UNIFIED IDEOGRAPH-#2BAAB
2BAAC CJK UNIFIED IDEOGRAPH-#2BAAC
2BAAD CJK UNIFIED IDEOGRAPH-#2BAAD
2BAAE CJK UNIFIED IDEOGRAPH-#2BAAE
2BAAF CJK UNIFIED IDEOGRAPH-#2BAAF
2BAB0 CJK UNIFIED IDEOGRAPH-#2BAB0
2BAB1 CJK UNIFIED IDEOGRAPH-#2BAB1
2BAB2 CJK UNIFIED IDEOGRAPH-#2BAB2
2BAB3 CJK UNIFIED IDEOGRAPH-#2BAB3
2BAB4 CJK UNIFIED IDEOGRAPH-#2BAB4
2BAB5 CJK UNIFIED IDEOGRAPH-#2BAB5
2BAB6 CJK UNIFIED IDEOGRAPH-#2BAB6
2BAB7 CJK UNIFIED IDEOGRAPH-#2BAB7
2BAB8 CJK UNIFIED IDEOGRAPH-#2BAB8
2BAB9 CJK UNIFIED IDEOGRAPH-#2BAB9
2BABA CJK UNIFIED IDEOGRAPH-#2BABA
2BABB CJK UNIFIED IDEOGRAPH-#2BABB
2BABC CJK UNIFIED IDEOGRAPH-#2BABC
2BABD CJK UNIFIED IDEOGRAPH-#2BABD
2BABE CJK UNIFIED IDEOGRAPH-#2BABE
2BABF CJK UNIFIED IDEOGRAPH-#2BABF
2BAC0 CJK UNIFIED IDEOGRAPH-#2BAC0
2BAC1 CJK UNIFIED IDEOGRAPH-#2BAC1
2BAC2 CJK UNIFIED IDEOGRAPH-#2BAC2
2BAC3 CJK UNIFIED IDEOGRAPH-#2BAC3
2BAC4 CJK UNIFIED IDEOGRAPH-#2BAC4
2BAC5 CJK UNIFIED IDEOGRAPH-#2BAC5
2BAC6 CJK UNIFIED IDEOGRAPH-#2BAC6
2BAC7 CJK UNIFIED IDEOGRAPH-#2BAC7
2BAC8 CJK UNIFIED IDEOGRAPH-#2BAC8
2BAC9 CJK UNIFIED IDEOGRAPH-#2BAC9
2BACA CJK UNIFIED IDEOGRAPH-#2BACA
2BACB CJK UNIFIED IDEOGRAPH-#2BACB
2BACC CJK UNIFIED IDEOGRAPH-#2BACC
2BACD CJK UNIFIED IDEOGRAPH-#2BACD
2BACE CJK UNIFIED IDEOGRAPH-#2BACE
2BACF CJK UNIFIED IDEOGRAPH-#2BACF
2BAD0 CJK UNIFIED IDEOGRAPH-#2BAD0
2BAD1 CJK UNIFIED IDEOGRAPH-#2BAD1
2BAD2 CJK UNIFIED IDEOGRAPH-#2BAD2
2BAD3 CJK UNIFIED IDEOGRAPH-#2BAD3
2BAD4 CJK UNIFIED IDEOGRAPH-#2BAD4
2BAD5 CJK UNIFIED IDEOGRAPH-#2BAD5
2BAD6 CJK UNIFIED IDEOGRAPH-#2BAD6
2BAD7 CJK UNIFIED IDEOGRAPH-#2BAD7
2BAD8 CJK UNIFIED IDEOGRAPH-#2BAD8
2BAD9 CJK UNIFIED IDEOGRAPH-#2BAD9
2BADA CJK UNIFIED IDEOGRAPH-#2BADA
2BADB CJK UNIFIED IDEOGRAPH-#2BADB
2BADC CJK UNIFIED IDEOGRAPH-#2BADC
2BADD CJK UNIFIED IDEOGRAPH-#2BADD
2BADE CJK UNIFIED IDEOGRAPH-#2BADE
2BADF CJK UNIFIED IDEOGRAPH-#2BADF
2BAE0 CJK UNIFIED IDEOGRAPH-#2BAE0
2BAE1 CJK UNIFIED IDEOGRAPH-#2BAE1
2BAE2 CJK UNIFIED IDEOGRAPH-#2BAE2
2BAE3 CJK UNIFIED IDEOGRAPH-#2BAE3
2BAE4 CJK UNIFIED IDEOGRAPH-#2BAE4
2BAE5 CJK UNIFIED IDEOGRAPH-#2BAE5
2BAE6 CJK UNIFIED IDEOGRAPH-#2BAE6
2BAE7 CJK UNIFIED IDEOGRAPH-#2BAE7
2BAE8 CJK UNIFIED IDEOGRAPH-#2BAE8
2BAE9 CJK UNIFIED IDEOGRAPH-#2BAE9
2BAEA CJK UNIFIED IDEOGRAPH-#2BAEA
2BAEB CJK UNIFIED IDEOGRAPH-#2BAEB
2BAEC CJK UNIFIED IDEOGRAPH-#2BAEC
2BAED CJK UNIFIED IDEOGRAPH-#2BAED
2BAEE CJK UNIFIED IDEOGRAPH-#2BAEE
2BAEF CJK UNIFIED IDEOGRAPH-#2BAEF
2BAF0 CJK UNIFIED IDEOGRAPH-#2BAF0
2BAF1 CJK UNIFIED IDEOGRAPH-#2BAF1
2BAF2 CJK UNIFIED IDEOGRAPH-#2BAF2
2BAF3 CJK UNIFIED IDEOGRAPH-#2BAF3
2BAF4 CJK UNIFIED IDEOGRAPH-#2BAF4
2BAF5 CJK UNIFIED IDEOGRAPH-#2BAF5
2BAF6 CJK UNIFIED IDEOGRAPH-#2BAF6
2BAF7 CJK UNIFIED IDEOGRAPH-#2BAF7
2BAF8 CJK UNIFIED IDEOGRAPH-#2BAF8
2BAF9 CJK UNIFIED IDEOGRAPH-#2BAF9
2BAFA CJK UNIFIED IDEOGRAPH-#2BAFA
2BAFB CJK UNIFIED IDEOGRAPH-#2BAFB
2BAFC CJK UNIFIED IDEOGRAPH-#2BAFC
2BAFD CJK UNIFIED IDEOGRAPH-#2BAFD
2BAFE CJK UNIFIED IDEOGRAPH-#2BAFE
2BAFF CJK UNIFIED IDEOGRAPH-#2BAFF
2BB00 CJK UNIFIED IDEOGRAPH-#2BB00
2BB01 CJK UNIFIED IDEOGRAPH-#2BB01
2BB02 CJK UNIFIED IDEOGRAPH-#2BB02
2BB03 CJK UNIFIED IDEOGRAPH-#2BB03
2BB04 CJK UNIFIED IDEOGRAPH-#2BB04
2BB05 CJK UNIFIED IDEOGRAPH-#2BB05
2BB06 CJK UNIFIED IDEOGRAPH-#2BB06
2BB07 CJK UNIFIED IDEOGRAPH-#2BB07
2BB08 CJK UNIFIED IDEOGRAPH-#2BB08
2BB09 CJK UNIFIED IDEOGRAPH-#2BB09
2BB0A CJK UNIFIED IDEOGRAPH-#2BB0A
2BB0B CJK UNIFIED IDEOGRAPH-#2BB0B
2BB0C CJK UNIFIED IDEOGRAPH-#2BB0C
2BB0D CJK UNIFIED IDEOGRAPH-#2BB0D
2BB0E CJK UNIFIED IDEOGRAPH-#2BB0E
2BB0F CJK UNIFIED IDEOGRAPH-#2BB0F
2BB10 CJK UNIFIED IDEOGRAPH-#2BB10
2BB11 CJK UNIFIED IDEOGRAPH-#2BB11
2BB12 CJK UNIFIED IDEOGRAPH-#2BB12
2BB13 CJK UNIFIED IDEOGRAPH-#2BB13
2BB14 CJK UNIFIED IDEOGRAPH-#2BB14
2BB15 CJK UNIFIED IDEOGRAPH-#2BB15
2BB16 CJK UNIFIED IDEOGRAPH-#2BB16
2BB17 CJK UNIFIED IDEOGRAPH-#2BB17
2BB18 CJK UNIFIED IDEOGRAPH-#2BB18
2BB19 CJK UNIFIED IDEOGRAPH-#2BB19
2BB1A CJK UNIFIED IDEOGRAPH-#2BB1A
2BB1B CJK UNIFIED IDEOGRAPH-#2BB1B
2BB1C CJK UNIFIED IDEOGRAPH-#2BB1C
2BB1D CJK UNIFIED IDEOGRAPH-#2BB1D
2BB1E CJK UNIFIED IDEOGRAPH-#2BB1E
2BB1F CJK UNIFIED IDEOGRAPH-#2BB1F
2BB20 CJK UNIFIED IDEOGRAPH-#2BB20
2BB21 CJK UNIFIED IDEOGRAPH-#2BB21
2BB22 CJK UNIFIED IDEOGRAPH-#2BB22
2BB23 CJK UNIFIED IDEOGRAPH-#2BB23
2BB24 CJK UNIFIED IDEOGRAPH-#2BB24
2BB25 CJK UNIFIED IDEOGRAPH-#2BB25
2BB26 CJK UNIFIED IDEOGRAPH-#2BB26
2BB27 CJK UNIFIED IDEOGRAPH-#2BB27
2BB28 CJK UNIFIED IDEOGRAPH-#2BB28
2BB29 CJK UNIFIED IDEOGRAPH-#2BB29
2BB2A CJK UNIFIED IDEOGRAPH-#2BB2A
2BB2B CJK UNIFIED IDEOGRAPH-#2BB2B
2BB2C CJK UNIFIED IDEOGRAPH-#2BB2C
2BB2D CJK UNIFIED IDEOGRAPH-#2BB2D
2BB2E CJK UNIFIED IDEOGRAPH-#2BB2E
2BB2F CJK UNIFIED IDEOGRAPH-#2BB2F
2BB30 CJK UNIFIED IDEOGRAPH-#2BB30
2BB31 CJK UNIFIED IDEOGRAPH-#2BB31
2BB32 CJK UNIFIED IDEOGRAPH-#2BB32
2BB33 CJK UNIFIED IDEOGRAPH-#2BB33
2BB34 CJK UNIFIED IDEOGRAPH-#2BB34
2BB35 CJK UNIFIED IDEOGRAPH-#2BB35
2BB36 CJK UNIFIED IDEOGRAPH-#2BB36
2BB37 CJK UNIFIED IDEOGRAPH-#2BB37
2BB38 CJK UNIFIED IDEOGRAPH-#2BB38
2BB39 CJK UNIFIED IDEOGRAPH-#2BB39
2BB3A CJK UNIFIED IDEOGRAPH-#2BB3A
2BB3B CJK UNIFIED IDEOGRAPH-#2BB3B
2BB3C CJK UNIFIED IDEOGRAPH-#2BB3C
2BB3D CJK UNIFIED IDEOGRAPH-#2BB3D
2BB3E CJK UNIFIED IDEOGRAPH-#2BB3E
2BB3F CJK UNIFIED IDEOGRAPH-#2BB3F
2BB40 CJK UNIFIED IDEOGRAPH-#2BB40
2BB41 CJK UNIFIED IDEOGRAPH-#2BB41
2BB42 CJK UNIFIED IDEOGRAPH-#2BB42
2BB43 CJK UNIFIED IDEOGRAPH-#2BB43
2BB44 CJK UNIFIED IDEOGRAPH-#2BB44
2BB45 CJK UNIFIED IDEOGRAPH-#2BB45
2BB46 CJK UNIFIED IDEOGRAPH-#2BB46
2BB47 CJK UNIFIED IDEOGRAPH-#2BB47
2BB48 CJK UNIFIED IDEOGRAPH-#2BB48
2BB49 CJK UNIFIED IDEOGRAPH-#2BB49
2BB4A CJK UNIFIED IDEOGRAPH-#2BB4A
2BB4B CJK UNIFIED IDEOGRAPH-#2BB4B
2BB4C CJK UNIFIED IDEOGRAPH-#2BB4C
2BB4D CJK UNIFIED IDEOGRAPH-#2BB4D
2BB4E CJK UNIFIED IDEOGRAPH-#2BB4E
2BB4F CJK UNIFIED IDEOGRAPH-#2BB4F
2BB50 CJK UNIFIED IDEOGRAPH-#2BB50
2BB51 CJK UNIFIED IDEOGRAPH-#2BB51
2BB52 CJK UNIFIED IDEOGRAPH-#2BB52
2BB53 CJK UNIFIED IDEOGRAPH-#2BB53
2BB54 CJK UNIFIED IDEOGRAPH-#2BB54
2BB55 CJK UNIFIED IDEOGRAPH-#2BB55
2BB56 CJK UNIFIED IDEOGRAPH-#2BB56
2BB57 CJK UNIFIED IDEOGRAPH-#2BB57
2BB58 CJK UNIFIED IDEOGRAPH-#2BB58
2BB59 CJK UNIFIED IDEOGRAPH-#2BB59
2BB5A CJK UNIFIED IDEOGRAPH-#2BB5A
2BB5B CJK UNIFIED IDEOGRAPH-#2BB5B
2BB5C CJK UNIFIED IDEOGRAPH-#2BB5C
2BB5D CJK UNIFIED IDEOGRAPH-#2BB5D
2BB5E CJK UNIFIED IDEOGRAPH-#2BB5E
2BB5F CJK UNIFIED IDEOGRAPH-#2BB5F
2BB60 CJK UNIFIED IDEOGRAPH-#2BB60
2BB61 CJK UNIFIED IDEOGRAPH-#2BB61
2BB62 CJK UNIFIED IDEOGRAPH-#2BB62
2BB63 CJK UNIFIED IDEOGRAPH-#2BB63
2BB64 CJK UNIFIED IDEOGRAPH-#2BB64
2BB65 CJK UNIFIED IDEOGRAPH-#2BB65
2BB66 CJK UNIFIED IDEOGRAPH-#2BB66
2BB67 CJK UNIFIED IDEOGRAPH-#2BB67
2BB68 CJK UNIFIED IDEOGRAPH-#2BB68
2BB69 CJK UNIFIED IDEOGRAPH-#2BB69
2BB6A CJK UNIFIED IDEOGRAPH-#2BB6A
2BB6B CJK UNIFIED IDEOGRAPH-#2BB6B
2BB6C CJK UNIFIED IDEOGRAPH-#2BB6C
2BB6D CJK UNIFIED IDEOGRAPH-#2BB6D
2BB6E CJK UNIFIED IDEOGRAPH-#2BB6E
2BB6F CJK UNIFIED IDEOGRAPH-#2BB6F
2BB70 CJK UNIFIED IDEOGRAPH-#2BB70
2BB71 CJK UNIFIED IDEOGRAPH-#2BB71
2BB72 CJK UNIFIED IDEOGRAPH-#2BB72
2BB73 CJK UNIFIED IDEOGRAPH-#2BB73
2BB74 CJK UNIFIED IDEOGRAPH-#2BB74
2BB75 CJK UNIFIED IDEOGRAPH-#2BB75
2BB76 CJK UNIFIED IDEOGRAPH-#2BB76
2BB77 CJK UNIFIED IDEOGRAPH-#2BB77
2BB78 CJK UNIFIED IDEOGRAPH-#2BB78
2BB79 CJK UNIFIED IDEOGRAPH-#2BB79
2BB7A CJK UNIFIED IDEOGRAPH-#2BB7A
2BB7B CJK UNIFIED IDEOGRAPH-#2BB7B
2BB7C CJK UNIFIED IDEOGRAPH-#2BB7C
2BB7D CJK UNIFIED IDEOGRAPH-#2BB7D
2BB7E CJK UNIFIED IDEOGRAPH-#2BB7E
2BB7F CJK UNIFIED IDEOGRAPH-#2BB7F
2BB80 CJK UNIFIED IDEOGRAPH-#2BB80
2BB81 CJK UNIFIED IDEOGRAPH-#2BB81
2BB82 CJK UNIFIED IDEOGRAPH-#2BB82
2BB83 CJK UNIFIED IDEOGRAPH-#2BB83
2BB84 CJK UNIFIED IDEOGRAPH-#2BB84
2BB85 CJK UNIFIED IDEOGRAPH-#2BB85
2BB86 CJK UNIFIED IDEOGRAPH-#2BB86
2BB87 CJK UNIFIED IDEOGRAPH-#2BB87
2BB88 CJK UNIFIED IDEOGRAPH-#2BB88
2BB89 CJK UNIFIED IDEOGRAPH-#2BB89
2BB8A CJK UNIFIED IDEOGRAPH-#2BB8A
2BB8B CJK UNIFIED IDEOGRAPH-#2BB8B
2BB8C CJK UNIFIED IDEOGRAPH-#2BB8C
2BB8D CJK UNIFIED IDEOGRAPH-#2BB8D
2BB8E CJK UNIFIED IDEOGRAPH-#2BB8E
2BB8F CJK UNIFIED IDEOGRAPH-#2BB8F
2BB90 CJK UNIFIED IDEOGRAPH-#2BB90
2BB91 CJK UNIFIED IDEOGRAPH-#2BB91
2BB92 CJK UNIFIED IDEOGRAPH-#2BB92
2BB93 CJK UNIFIED IDEOGRAPH-#2BB93
2BB94 CJK UNIFIED IDEOGRAPH-#2BB94
2BB95 CJK UNIFIED IDEOGRAPH-#2BB95
2BB96 CJK UNIFIED IDEOGRAPH-#2BB96
2BB97 CJK UNIFIED IDEOGRAPH-#2BB97
2BB98 CJK UNIFIED IDEOGRAPH-#2BB98
2BB99 CJK UNIFIED IDEOGRAPH-#2BB99
2BB9A CJK UNIFIED IDEOGRAPH-#2BB9A
2BB9B CJK UNIFIED IDEOGRAPH-#2BB9B
2BB9C CJK UNIFIED IDEOGRAPH-#2BB9C
2BB9D CJK UNIFIED IDEOGRAPH-#2BB9D
2BB9E CJK UNIFIED IDEOGRAPH-#2BB9E
2BB9F CJK UNIFIED IDEOGRAPH-#2BB9F
2BBA0 CJK UNIFIED IDEOGRAPH-#2BBA0
2BBA1 CJK UNIFIED IDEOGRAPH-#2BBA1
2BBA2 CJK UNIFIED IDEOGRAPH-#2BBA2
2BBA3 CJK UNIFIED IDEOGRAPH-#2BBA3
2BBA4 CJK UNIFIED IDEOGRAPH-#2BBA4
2BBA5 CJK UNIFIED IDEOGRAPH-#2BBA5
2BBA6 CJK UNIFIED IDEOGRAPH-#2BBA6
2BBA7 CJK UNIFIED IDEOGRAPH-#2BBA7
2BBA8 CJK UNIFIED IDEOGRAPH-#2BBA8
2BBA9 CJK UNIFIED IDEOGRAPH-#2BBA9
2BBAA CJK UNIFIED IDEOGRAPH-#2BBAA
2BBAB CJK UNIFIED IDEOGRAPH-#2BBAB
2BBAC CJK UNIFIED IDEOGRAPH-#2BBAC
2BBAD CJK UNIFIED IDEOGRAPH-#2BBAD
2BBAE CJK UNIFIED IDEOGRAPH-#2BBAE
2BBAF CJK UNIFIED IDEOGRAPH-#2BBAF
2BBB0 CJK UNIFIED IDEOGRAPH-#2BBB0
2BBB1 CJK UNIFIED IDEOGRAPH-#2BBB1
2BBB2 CJK UNIFIED IDEOGRAPH-#2BBB2
2BBB3 CJK UNIFIED IDEOGRAPH-#2BBB3
2BBB4 CJK UNIFIED IDEOGRAPH-#2BBB4
2BBB5 CJK UNIFIED IDEOGRAPH-#2BBB5
2BBB6 CJK UNIFIED IDEOGRAPH-#2BBB6
2BBB7 CJK UNIFIED IDEOGRAPH-#2BBB7
2BBB8 CJK UNIFIED IDEOGRAPH-#2BBB8
2BBB9 CJK UNIFIED IDEOGRAPH-#2BBB9
2BBBA CJK UNIFIED IDEOGRAPH-#2BBBA
2BBBB CJK UNIFIED IDEOGRAPH-#2BBBB
2BBBC CJK UNIFIED IDEOGRAPH-#2BBBC
2BBBD CJK UNIFIED IDEOGRAPH-#2BBBD
2BBBE CJK UNIFIED IDEOGRAPH-#2BBBE
2BBBF CJK UNIFIED IDEOGRAPH-#2BBBF
2BBC0 CJK UNIFIED IDEOGRAPH-#2BBC0
2BBC1 CJK UNIFIED IDEOGRAPH-#2BBC1
2BBC2 CJK UNIFIED IDEOGRAPH-#2BBC2
2BBC3 CJK UNIFIED IDEOGRAPH-#2BBC3
2BBC4 CJK UNIFIED IDEOGRAPH-#2BBC4
2BBC5 CJK UNIFIED IDEOGRAPH-#2BBC5
2BBC6 CJK UNIFIED IDEOGRAPH-#2BBC6
2BBC7 CJK UNIFIED IDEOGRAPH-#2BBC7
2BBC8 CJK UNIFIED IDEOGRAPH-#2BBC8
2BBC9 CJK UNIFIED IDEOGRAPH-#2BBC9
2BBCA CJK UNIFIED IDEOGRAPH-#2BBCA
2BBCB CJK UNIFIED IDEOGRAPH-#2BBCB
2BBCC CJK UNIFIED IDEOGRAPH-#2BBCC
2BBCD CJK UNIFIED IDEOGRAPH-#2BBCD
2BBCE CJK UNIFIED IDEOGRAPH-#2BBCE
2BBCF CJK UNIFIED IDEOGRAPH-#2BBCF
2BBD0 CJK UNIFIED IDEOGRAPH-#2BBD0
2BBD1 CJK UNIFIED IDEOGRAPH-#2BBD1
2BBD2 CJK UNIFIED IDEOGRAPH-#2BBD2
2BBD3 CJK UNIFIED IDEOGRAPH-#2BBD3
2BBD4 CJK UNIFIED IDEOGRAPH-#2BBD4
2BBD5 CJK UNIFIED IDEOGRAPH-#2BBD5
2BBD6 CJK UNIFIED IDEOGRAPH-#2BBD6
2BBD7 CJK UNIFIED IDEOGRAPH-#2BBD7
2BBD8 CJK UNIFIED IDEOGRAPH-#2BBD8
2BBD9 CJK UNIFIED IDEOGRAPH-#2BBD9
2BBDA CJK UNIFIED IDEOGRAPH-#2BBDA
2BBDB CJK UNIFIED IDEOGRAPH-#2BBDB
2BBDC CJK UNIFIED IDEOGRAPH-#2BBDC
2BBDD CJK UNIFIED IDEOGRAPH-#2BBDD
2BBDE CJK UNIFIED IDEOGRAPH-#2BBDE
2BBDF CJK UNIFIED IDEOGRAPH-#2BBDF
2BBE0 CJK UNIFIED IDEOGRAPH-#2BBE0
2BBE1 CJK UNIFIED IDEOGRAPH-#2BBE1
2BBE2 CJK UNIFIED IDEOGRAPH-#2BBE2
2BBE3 CJK UNIFIED IDEOGRAPH-#2BBE3
2BBE4 CJK UNIFIED IDEOGRAPH-#2BBE4
2BBE5 CJK UNIFIED IDEOGRAPH-#2BBE5
2BBE6 CJK UNIFIED IDEOGRAPH-#2BBE6
2BBE7 CJK UNIFIED IDEOGRAPH-#2BBE7
2BBE8 CJK UNIFIED IDEOGRAPH-#2BBE8
2BBE9 CJK UNIFIED IDEOGRAPH-#2BBE9
2BBEA CJK UNIFIED IDEOGRAPH-#2BBEA
2BBEB CJK UNIFIED IDEOGRAPH-#2BBEB
2BBEC CJK UNIFIED IDEOGRAPH-#2BBEC
2BBED CJK UNIFIED IDEOGRAPH-#2BBED
2BBEE CJK UNIFIED IDEOGRAPH-#2BBEE
2BBEF CJK UNIFIED IDEOGRAPH-#2BBEF
2BBF0 CJK UNIFIED IDEOGRAPH-#2BBF0
2BBF1 CJK UNIFIED IDEOGRAPH-#2BBF1
2BBF2 CJK UNIFIED IDEOGRAPH-#2BBF2
2BBF3 CJK UNIFIED IDEOGRAPH-#2BBF3
2BBF4 CJK UNIFIED IDEOGRAPH-#2BBF4
2BBF5 CJK UNIFIED IDEOGRAPH-#2BBF5
2BBF6 CJK UNIFIED IDEOGRAPH-#2BBF6
2BBF7 CJK UNIFIED IDEOGRAPH-#2BBF7
2BBF8 CJK UNIFIED IDEOGRAPH-#2BBF8
2BBF9 CJK UNIFIED IDEOGRAPH-#2BBF9
2BBFA CJK UNIFIED IDEOGRAPH-#2BBFA
2BBFB CJK UNIFIED IDEOGRAPH-#2BBFB
2BBFC CJK UNIFIED IDEOGRAPH-#2BBFC
2BBFD CJK UNIFIED IDEOGRAPH-#2BBFD
2BBFE CJK UNIFIED IDEOGRAPH-#2BBFE
2BBFF CJK UNIFIED IDEOGRAPH-#2BBFF
2BC00 CJK UNIFIED IDEOGRAPH-#2BC00
2BC01 CJK UNIFIED IDEOGRAPH-#2BC01
2BC02 CJK UNIFIED IDEOGRAPH-#2BC02
2BC03 CJK UNIFIED IDEOGRAPH-#2BC03
2BC04 CJK UNIFIED IDEOGRAPH-#2BC04
2BC05 CJK UNIFIED IDEOGRAPH-#2BC05
2BC06 CJK UNIFIED IDEOGRAPH-#2BC06
2BC07 CJK UNIFIED IDEOGRAPH-#2BC07
2BC08 CJK UNIFIED IDEOGRAPH-#2BC08
2BC09 CJK UNIFIED IDEOGRAPH-#2BC09
2BC0A CJK UNIFIED IDEOGRAPH-#2BC0A
2BC0B CJK UNIFIED IDEOGRAPH-#2BC0B
2BC0C CJK UNIFIED IDEOGRAPH-#2BC0C
2BC0D CJK UNIFIED IDEOGRAPH-#2BC0D
2BC0E CJK UNIFIED IDEOGRAPH-#2BC0E
2BC0F CJK UNIFIED IDEOGRAPH-#2BC0F
2BC10 CJK UNIFIED IDEOGRAPH-#2BC10
2BC11 CJK UNIFIED IDEOGRAPH-#2BC11
2BC12 CJK UNIFIED IDEOGRAPH-#2BC12
2BC13 CJK UNIFIED IDEOGRAPH-#2BC13
2BC14 CJK UNIFIED IDEOGRAPH-#2BC14
2BC15 CJK UNIFIED IDEOGRAPH-#2BC15
2BC16 CJK UNIFIED IDEOGRAPH-#2BC16
2BC17 CJK UNIFIED IDEOGRAPH-#2BC17
2BC18 CJK UNIFIED IDEOGRAPH-#2BC18
2BC19 CJK UNIFIED IDEOGRAPH-#2BC19
2BC1A CJK UNIFIED IDEOGRAPH-#2BC1A
2BC1B CJK UNIFIED IDEOGRAPH-#2BC1B
2BC1C CJK UNIFIED IDEOGRAPH-#2BC1C
2BC1D CJK UNIFIED IDEOGRAPH-#2BC1D
2BC1E CJK UNIFIED IDEOGRAPH-#2BC1E
2BC1F CJK UNIFIED IDEOGRAPH-#2BC1F
2BC20 CJK UNIFIED IDEOGRAPH-#2BC20
2BC21 CJK UNIFIED IDEOGRAPH-#2BC21
2BC22 CJK UNIFIED IDEOGRAPH-#2BC22
2BC23 CJK UNIFIED IDEOGRAPH-#2BC23
2BC24 CJK UNIFIED IDEOGRAPH-#2BC24
2BC25 CJK UNIFIED IDEOGRAPH-#2BC25
2BC26 CJK UNIFIED IDEOGRAPH-#2BC26
2BC27 CJK UNIFIED IDEOGRAPH-#2BC27
2BC28 CJK UNIFIED IDEOGRAPH-#2BC28
2BC29 CJK UNIFIED IDEOGRAPH-#2BC29
2BC2A CJK UNIFIED IDEOGRAPH-#2BC2A
2BC2B CJK UNIFIED IDEOGRAPH-#2BC2B
2BC2C CJK UNIFIED IDEOGRAPH-#2BC2C
2BC2D CJK UNIFIED IDEOGRAPH-#2BC2D
2BC2E CJK UNIFIED IDEOGRAPH-#2BC2E
2BC2F CJK UNIFIED IDEOGRAPH-#2BC2F
2BC30 CJK UNIFIED IDEOGRAPH-#2BC30
2BC31 CJK UNIFIED IDEOGRAPH-#2BC31
2BC32 CJK UNIFIED IDEOGRAPH-#2BC32
2BC33 CJK UNIFIED IDEOGRAPH-#2BC33
2BC34 CJK UNIFIED IDEOGRAPH-#2BC34
2BC35 CJK UNIFIED IDEOGRAPH-#2BC35
2BC36 CJK UNIFIED IDEOGRAPH-#2BC36
2BC37 CJK UNIFIED IDEOGRAPH-#2BC37
2BC38 CJK UNIFIED IDEOGRAPH-#2BC38
2BC39 CJK UNIFIED IDEOGRAPH-#2BC39
2BC3A CJK UNIFIED IDEOGRAPH-#2BC3A
2BC3B CJK UNIFIED IDEOGRAPH-#2BC3B
2BC3C CJK UNIFIED IDEOGRAPH-#2BC3C
2BC3D CJK UNIFIED IDEOGRAPH-#2BC3D
2BC3E CJK UNIFIED IDEOGRAPH-#2BC3E
2BC3F CJK UNIFIED IDEOGRAPH-#2BC3F
2BC40 CJK UNIFIED IDEOGRAPH-#2BC40
2BC41 CJK UNIFIED IDEOGRAPH-#2BC41
2BC42 CJK UNIFIED IDEOGRAPH-#2BC42
2BC43 CJK UNIFIED IDEOGRAPH-#2BC43
2BC44 CJK UNIFIED IDEOGRAPH-#2BC44
2BC45 CJK UNIFIED IDEOGRAPH-#2BC45
2BC46 CJK UNIFIED IDEOGRAPH-#2BC46
2BC47 CJK UNIFIED IDEOGRAPH-#2BC47
2BC48 CJK UNIFIED IDEOGRAPH-#2BC48
2BC49 CJK UNIFIED IDEOGRAPH-#2BC49
2BC4A CJK UNIFIED IDEOGRAPH-#2BC4A
2BC4B CJK UNIFIED IDEOGRAPH-#2BC4B
2BC4C CJK UNIFIED IDEOGRAPH-#2BC4C
2BC4D CJK UNIFIED IDEOGRAPH-#2BC4D
2BC4E CJK UNIFIED IDEOGRAPH-#2BC4E
2BC4F CJK UNIFIED IDEOGRAPH-#2BC4F
2BC50 CJK UNIFIED IDEOGRAPH-#2BC50
2BC51 CJK UNIFIED IDEOGRAPH-#2BC51
2BC52 CJK UNIFIED IDEOGRAPH-#2BC52
2BC53 CJK UNIFIED IDEOGRAPH-#2BC53
2BC54 CJK UNIFIED IDEOGRAPH-#2BC54
2BC55 CJK UNIFIED IDEOGRAPH-#2BC55
2BC56 CJK UNIFIED IDEOGRAPH-#2BC56
2BC57 CJK UNIFIED IDEOGRAPH-#2BC57
2BC58 CJK UNIFIED IDEOGRAPH-#2BC58
2BC59 CJK UNIFIED IDEOGRAPH-#2BC59
2BC5A CJK UNIFIED IDEOGRAPH-#2BC5A
2BC5B CJK UNIFIED IDEOGRAPH-#2BC5B
2BC5C CJK UNIFIED IDEOGRAPH-#2BC5C
2BC5D CJK UNIFIED IDEOGRAPH-#2BC5D
2BC5E CJK UNIFIED IDEOGRAPH-#2BC5E
2BC5F CJK UNIFIED IDEOGRAPH-#2BC5F
2BC60 CJK UNIFIED IDEOGRAPH-#2BC60
2BC61 CJK UNIFIED IDEOGRAPH-#2BC61
2BC62 CJK UNIFIED IDEOGRAPH-#2BC62
2BC63 CJK UNIFIED IDEOGRAPH-#2BC63
2BC64 CJK UNIFIED IDEOGRAPH-#2BC64
2BC65 CJK UNIFIED IDEOGRAPH-#2BC65
2BC66 CJK UNIFIED IDEOGRAPH-#2BC66
2BC67 CJK UNIFIED IDEOGRAPH-#2BC67
2BC68 CJK UNIFIED IDEOGRAPH-#2BC68
2BC69 CJK UNIFIED IDEOGRAPH-#2BC69
2BC6A CJK UNIFIED IDEOGRAPH-#2BC6A
2BC6B CJK UNIFIED IDEOGRAPH-#2BC6B
2BC6C CJK UNIFIED IDEOGRAPH-#2BC6C
2BC6D CJK UNIFIED IDEOGRAPH-#2BC6D
2BC6E CJK UNIFIED IDEOGRAPH-#2BC6E
2BC6F CJK UNIFIED IDEOGRAPH-#2BC6F
2BC70 CJK UNIFIED IDEOGRAPH-#2BC70
2BC71 CJK UNIFIED IDEOGRAPH-#2BC71
2BC72 CJK UNIFIED IDEOGRAPH-#2BC72
2BC73 CJK UNIFIED IDEOGRAPH-#2BC73
2BC74 CJK UNIFIED IDEOGRAPH-#2BC74
2BC75 CJK UNIFIED IDEOGRAPH-#2BC75
2BC76 CJK UNIFIED IDEOGRAPH-#2BC76
2BC77 CJK UNIFIED IDEOGRAPH-#2BC77
2BC78 CJK UNIFIED IDEOGRAPH-#2BC78
2BC79 CJK UNIFIED IDEOGRAPH-#2BC79
2BC7A CJK UNIFIED IDEOGRAPH-#2BC7A
2BC7B CJK UNIFIED IDEOGRAPH-#2BC7B
2BC7C CJK UNIFIED IDEOGRAPH-#2BC7C
2BC7D CJK UNIFIED IDEOGRAPH-#2BC7D
2BC7E CJK UNIFIED IDEOGRAPH-#2BC7E
2BC7F CJK UNIFIED IDEOGRAPH-#2BC7F
2BC80 CJK UNIFIED IDEOGRAPH-#2BC80
2BC81 CJK UNIFIED IDEOGRAPH-#2BC81
2BC82 CJK UNIFIED IDEOGRAPH-#2BC82
2BC83 CJK UNIFIED IDEOGRAPH-#2BC83
2BC84 CJK UNIFIED IDEOGRAPH-#2BC84
2BC85 CJK UNIFIED IDEOGRAPH-#2BC85
2BC86 CJK UNIFIED IDEOGRAPH-#2BC86
2BC87 CJK UNIFIED IDEOGRAPH-#2BC87
2BC88 CJK UNIFIED IDEOGRAPH-#2BC88
2BC89 CJK UNIFIED IDEOGRAPH-#2BC89
2BC8A CJK UNIFIED IDEOGRAPH-#2BC8A
2BC8B CJK UNIFIED IDEOGRAPH-#2BC8B
2BC8C CJK UNIFIED IDEOGRAPH-#2BC8C
2BC8D CJK UNIFIED IDEOGRAPH-#2BC8D
2BC8E CJK UNIFIED IDEOGRAPH-#2BC8E
2BC8F CJK UNIFIED IDEOGRAPH-#2BC8F
2BC90 CJK UNIFIED IDEOGRAPH-#2BC90
2BC91 CJK UNIFIED IDEOGRAPH-#2BC91
2BC92 CJK UNIFIED IDEOGRAPH-#2BC92
2BC93 CJK UNIFIED IDEOGRAPH-#2BC93
2BC94 CJK UNIFIED IDEOGRAPH-#2BC94
2BC95 CJK UNIFIED IDEOGRAPH-#2BC95
2BC96 CJK UNIFIED IDEOGRAPH-#2BC96
2BC97 CJK UNIFIED IDEOGRAPH-#2BC97
2BC98 CJK UNIFIED IDEOGRAPH-#2BC98
2BC99 CJK UNIFIED IDEOGRAPH-#2BC99
2BC9A CJK UNIFIED IDEOGRAPH-#2BC9A
2BC9B CJK UNIFIED IDEOGRAPH-#2BC9B
2BC9C CJK UNIFIED IDEOGRAPH-#2BC9C
2BC9D CJK UNIFIED IDEOGRAPH-#2BC9D
2BC9E CJK UNIFIED IDEOGRAPH-#2BC9E
2BC9F CJK UNIFIED IDEOGRAPH-#2BC9F
2BCA0 CJK UNIFIED IDEOGRAPH-#2BCA0
2BCA1 CJK UNIFIED IDEOGRAPH-#2BCA1
2BCA2 CJK UNIFIED IDEOGRAPH-#2BCA2
2BCA3 CJK UNIFIED IDEOGRAPH-#2BCA3
2BCA4 CJK UNIFIED IDEOGRAPH-#2BCA4
2BCA5 CJK UNIFIED IDEOGRAPH-#2BCA5
2BCA6 CJK UNIFIED IDEOGRAPH-#2BCA6
2BCA7 CJK UNIFIED IDEOGRAPH-#2BCA7
2BCA8 CJK UNIFIED IDEOGRAPH-#2BCA8
2BCA9 CJK UNIFIED IDEOGRAPH-#2BCA9
2BCAA CJK UNIFIED IDEOGRAPH-#2BCAA
2BCAB CJK UNIFIED IDEOGRAPH-#2BCAB
2BCAC CJK UNIFIED IDEOGRAPH-#2BCAC
2BCAD CJK UNIFIED IDEOGRAPH-#2BCAD
2BCAE CJK UNIFIED IDEOGRAPH-#2BCAE
2BCAF CJK UNIFIED IDEOGRAPH-#2BCAF
2BCB0 CJK UNIFIED IDEOGRAPH-#2BCB0
2BCB1 CJK UNIFIED IDEOGRAPH-#2BCB1
2BCB2 CJK UNIFIED IDEOGRAPH-#2BCB2
2BCB3 CJK UNIFIED IDEOGRAPH-#2BCB3
2BCB4 CJK UNIFIED IDEOGRAPH-#2BCB4
2BCB5 CJK UNIFIED IDEOGRAPH-#2BCB5
2BCB6 CJK UNIFIED IDEOGRAPH-#2BCB6
2BCB7 CJK UNIFIED IDEOGRAPH-#2BCB7
2BCB8 CJK UNIFIED IDEOGRAPH-#2BCB8
2BCB9 CJK UNIFIED IDEOGRAPH-#2BCB9
2BCBA CJK UNIFIED IDEOGRAPH-#2BCBA
2BCBB CJK UNIFIED IDEOGRAPH-#2BCBB
2BCBC CJK UNIFIED IDEOGRAPH-#2BCBC
2BCBD CJK UNIFIED IDEOGRAPH-#2BCBD
2BCBE CJK UNIFIED IDEOGRAPH-#2BCBE
2BCBF CJK UNIFIED IDEOGRAPH-#2BCBF
2BCC0 CJK UNIFIED IDEOGRAPH-#2BCC0
2BCC1 CJK UNIFIED IDEOGRAPH-#2BCC1
2BCC2 CJK UNIFIED IDEOGRAPH-#2BCC2
2BCC3 CJK UNIFIED IDEOGRAPH-#2BCC3
2BCC4 CJK UNIFIED IDEOGRAPH-#2BCC4
2BCC5 CJK UNIFIED IDEOGRAPH-#2BCC5
2BCC6 CJK UNIFIED IDEOGRAPH-#2BCC6
2BCC7 CJK UNIFIED IDEOGRAPH-#2BCC7
2BCC8 CJK UNIFIED IDEOGRAPH-#2BCC8
2BCC9 CJK UNIFIED IDEOGRAPH-#2BCC9
2BCCA CJK UNIFIED IDEOGRAPH-#2BCCA
2BCCB CJK UNIFIED IDEOGRAPH-#2BCCB
2BCCC CJK UNIFIED IDEOGRAPH-#2BCCC
2BCCD CJK UNIFIED IDEOGRAPH-#2BCCD
2BCCE CJK UNIFIED IDEOGRAPH-#2BCCE
2BCCF CJK UNIFIED IDEOGRAPH-#2BCCF
2BCD0 CJK UNIFIED IDEOGRAPH-#2BCD0
2BCD1 CJK UNIFIED IDEOGRAPH-#2BCD1
2BCD2 CJK UNIFIED IDEOGRAPH-#2BCD2
2BCD3 CJK UNIFIED IDEOGRAPH-#2BCD3
2BCD4 CJK UNIFIED IDEOGRAPH-#2BCD4
2BCD5 CJK UNIFIED IDEOGRAPH-#2BCD5
2BCD6 CJK UNIFIED IDEOGRAPH-#2BCD6
2BCD7 CJK UNIFIED IDEOGRAPH-#2BCD7
2BCD8 CJK UNIFIED IDEOGRAPH-#2BCD8
2BCD9 CJK UNIFIED IDEOGRAPH-#2BCD9
2BCDA CJK UNIFIED IDEOGRAPH-#2BCDA
2BCDB CJK UNIFIED IDEOGRAPH-#2BCDB
2BCDC CJK UNIFIED IDEOGRAPH-#2BCDC
2BCDD CJK UNIFIED IDEOGRAPH-#2BCDD
2BCDE CJK UNIFIED IDEOGRAPH-#2BCDE
2BCDF CJK UNIFIED IDEOGRAPH-#2BCDF
2BCE0 CJK UNIFIED IDEOGRAPH-#2BCE0
2BCE1 CJK UNIFIED IDEOGRAPH-#2BCE1
2BCE2 CJK UNIFIED IDEOGRAPH-#2BCE2
2BCE3 CJK UNIFIED IDEOGRAPH-#2BCE3
2BCE4 CJK UNIFIED IDEOGRAPH-#2BCE4
2BCE5 CJK UNIFIED IDEOGRAPH-#2BCE5
2BCE6 CJK UNIFIED IDEOGRAPH-#2BCE6
2BCE7 CJK UNIFIED IDEOGRAPH-#2BCE7
2BCE8 CJK UNIFIED IDEOGRAPH-#2BCE8
2BCE9 CJK UNIFIED IDEOGRAPH-#2BCE9
2BCEA CJK UNIFIED IDEOGRAPH-#2BCEA
2BCEB CJK UNIFIED IDEOGRAPH-#2BCEB
2BCEC CJK UNIFIED IDEOGRAPH-#2BCEC
2BCED CJK UNIFIED IDEOGRAPH-#2BCED
2BCEE CJK UNIFIED IDEOGRAPH-#2BCEE
2BCEF CJK UNIFIED IDEOGRAPH-#2BCEF
2BCF0 CJK UNIFIED IDEOGRAPH-#2BCF0
2BCF1 CJK UNIFIED IDEOGRAPH-#2BCF1
2BCF2 CJK UNIFIED IDEOGRAPH-#2BCF2
2BCF3 CJK UNIFIED IDEOGRAPH-#2BCF3
2BCF4 CJK UNIFIED IDEOGRAPH-#2BCF4
2BCF5 CJK UNIFIED IDEOGRAPH-#2BCF5
2BCF6 CJK UNIFIED IDEOGRAPH-#2BCF6
2BCF7 CJK UNIFIED IDEOGRAPH-#2BCF7
2BCF8 CJK UNIFIED IDEOGRAPH-#2BCF8
2BCF9 CJK UNIFIED IDEOGRAPH-#2BCF9
2BCFA CJK UNIFIED IDEOGRAPH-#2BCFA
2BCFB CJK UNIFIED IDEOGRAPH-#2BCFB
2BCFC CJK UNIFIED IDEOGRAPH-#2BCFC
2BCFD CJK UNIFIED IDEOGRAPH-#2BCFD
2BCFE CJK UNIFIED IDEOGRAPH-#2BCFE
2BCFF CJK UNIFIED IDEOGRAPH-#2BCFF
2BD00 CJK UNIFIED IDEOGRAPH-#2BD00
2BD01 CJK UNIFIED IDEOGRAPH-#2BD01
2BD02 CJK UNIFIED IDEOGRAPH-#2BD02
2BD03 CJK UNIFIED IDEOGRAPH-#2BD03
2BD04 CJK UNIFIED IDEOGRAPH-#2BD04
2BD05 CJK UNIFIED IDEOGRAPH-#2BD05
2BD06 CJK UNIFIED IDEOGRAPH-#2BD06
2BD07 CJK UNIFIED IDEOGRAPH-#2BD07
2BD08 CJK UNIFIED IDEOGRAPH-#2BD08
2BD09 CJK UNIFIED IDEOGRAPH-#2BD09
2BD0A CJK UNIFIED IDEOGRAPH-#2BD0A
2BD0B CJK UNIFIED IDEOGRAPH-#2BD0B
2BD0C CJK UNIFIED IDEOGRAPH-#2BD0C
2BD0D CJK UNIFIED IDEOGRAPH-#2BD0D
2BD0E CJK UNIFIED IDEOGRAPH-#2BD0E
2BD0F CJK UNIFIED IDEOGRAPH-#2BD0F
2BD10 CJK UNIFIED IDEOGRAPH-#2BD10
2BD11 CJK UNIFIED IDEOGRAPH-#2BD11
2BD12 CJK UNIFIED IDEOGRAPH-#2BD12
2BD13 CJK UNIFIED IDEOGRAPH-#2BD13
2BD14 CJK UNIFIED IDEOGRAPH-#2BD14
2BD15 CJK UNIFIED IDEOGRAPH-#2BD15
2BD16 CJK UNIFIED IDEOGRAPH-#2BD16
2BD17 CJK UNIFIED IDEOGRAPH-#2BD17
2BD18 CJK UNIFIED IDEOGRAPH-#2BD18
2BD19 CJK UNIFIED IDEOGRAPH-#2BD19
2BD1A CJK UNIFIED IDEOGRAPH-#2BD1A
2BD1B CJK UNIFIED IDEOGRAPH-#2BD1B
2BD1C CJK UNIFIED IDEOGRAPH-#2BD1C
2BD1D CJK UNIFIED IDEOGRAPH-#2BD1D
2BD1E CJK UNIFIED IDEOGRAPH-#2BD1E
2BD1F CJK UNIFIED IDEOGRAPH-#2BD1F
2BD20 CJK UNIFIED IDEOGRAPH-#2BD20
2BD21 CJK UNIFIED IDEOGRAPH-#2BD21
2BD22 CJK UNIFIED IDEOGRAPH-#2BD22
2BD23 CJK UNIFIED IDEOGRAPH-#2BD23
2BD24 CJK UNIFIED IDEOGRAPH-#2BD24
2BD25 CJK UNIFIED IDEOGRAPH-#2BD25
2BD26 CJK UNIFIED IDEOGRAPH-#2BD26
2BD27 CJK UNIFIED IDEOGRAPH-#2BD27
2BD28 CJK UNIFIED IDEOGRAPH-#2BD28
2BD29 CJK UNIFIED IDEOGRAPH-#2BD29
2BD2A CJK UNIFIED IDEOGRAPH-#2BD2A
2BD2B CJK UNIFIED IDEOGRAPH-#2BD2B
2BD2C CJK UNIFIED IDEOGRAPH-#2BD2C
2BD2D CJK UNIFIED IDEOGRAPH-#2BD2D
2BD2E CJK UNIFIED IDEOGRAPH-#2BD2E
2BD2F CJK UNIFIED IDEOGRAPH-#2BD2F
2BD30 CJK UNIFIED IDEOGRAPH-#2BD30
2BD31 CJK UNIFIED IDEOGRAPH-#2BD31
2BD32 CJK UNIFIED IDEOGRAPH-#2BD32
2BD33 CJK UNIFIED IDEOGRAPH-#2BD33
2BD34 CJK UNIFIED IDEOGRAPH-#2BD34
2BD35 CJK UNIFIED IDEOGRAPH-#2BD35
2BD36 CJK UNIFIED IDEOGRAPH-#2BD36
2BD37 CJK UNIFIED IDEOGRAPH-#2BD37
2BD38 CJK UNIFIED IDEOGRAPH-#2BD38
2BD39 CJK UNIFIED IDEOGRAPH-#2BD39
2BD3A CJK UNIFIED IDEOGRAPH-#2BD3A
2BD3B CJK UNIFIED IDEOGRAPH-#2BD3B
2BD3C CJK UNIFIED IDEOGRAPH-#2BD3C
2BD3D CJK UNIFIED IDEOGRAPH-#2BD3D
2BD3E CJK UNIFIED IDEOGRAPH-#2BD3E
2BD3F CJK UNIFIED IDEOGRAPH-#2BD3F
2BD40 CJK UNIFIED IDEOGRAPH-#2BD40
2BD41 CJK UNIFIED IDEOGRAPH-#2BD41
2BD42 CJK UNIFIED IDEOGRAPH-#2BD42
2BD43 CJK UNIFIED IDEOGRAPH-#2BD43
2BD44 CJK UNIFIED IDEOGRAPH-#2BD44
2BD45 CJK UNIFIED IDEOGRAPH-#2BD45
2BD46 CJK UNIFIED IDEOGRAPH-#2BD46
2BD47 CJK UNIFIED IDEOGRAPH-#2BD47
2BD48 CJK UNIFIED IDEOGRAPH-#2BD48
2BD49 CJK UNIFIED IDEOGRAPH-#2BD49
2BD4A CJK UNIFIED IDEOGRAPH-#2BD4A
2BD4B CJK UNIFIED IDEOGRAPH-#2BD4B
2BD4C CJK UNIFIED IDEOGRAPH-#2BD4C
2BD4D CJK UNIFIED IDEOGRAPH-#2BD4D
2BD4E CJK UNIFIED IDEOGRAPH-#2BD4E
2BD4F CJK UNIFIED IDEOGRAPH-#2BD4F
2BD50 CJK UNIFIED IDEOGRAPH-#2BD50
2BD51 CJK UNIFIED IDEOGRAPH-#2BD51
2BD52 CJK UNIFIED IDEOGRAPH-#2BD52
2BD53 CJK UNIFIED IDEOGRAPH-#2BD53
2BD54 CJK UNIFIED IDEOGRAPH-#2BD54
2BD55 CJK UNIFIED IDEOGRAPH-#2BD55
2BD56 CJK UNIFIED IDEOGRAPH-#2BD56
2BD57 CJK UNIFIED IDEOGRAPH-#2BD57
2BD58 CJK UNIFIED IDEOGRAPH-#2BD58
2BD59 CJK UNIFIED IDEOGRAPH-#2BD59
2BD5A CJK UNIFIED IDEOGRAPH-#2BD5A
2BD5B CJK UNIFIED IDEOGRAPH-#2BD5B
2BD5C CJK UNIFIED IDEOGRAPH-#2BD5C
2BD5D CJK UNIFIED IDEOGRAPH-#2BD5D
2BD5E CJK UNIFIED IDEOGRAPH-#2BD5E
2BD5F CJK UNIFIED IDEOGRAPH-#2BD5F
2BD60 CJK UNIFIED IDEOGRAPH-#2BD60
2BD61 CJK UNIFIED IDEOGRAPH-#2BD61
2BD62 CJK UNIFIED IDEOGRAPH-#2BD62
2BD63 CJK UNIFIED IDEOGRAPH-#2BD63
2BD64 CJK UNIFIED IDEOGRAPH-#2BD64
2BD65 CJK UNIFIED IDEOGRAPH-#2BD65
2BD66 CJK UNIFIED IDEOGRAPH-#2BD66
2BD67 CJK UNIFIED IDEOGRAPH-#2BD67
2BD68 CJK UNIFIED IDEOGRAPH-#2BD68
2BD69 CJK UNIFIED IDEOGRAPH-#2BD69
2BD6A CJK UNIFIED IDEOGRAPH-#2BD6A
2BD6B CJK UNIFIED IDEOGRAPH-#2BD6B
2BD6C CJK UNIFIED IDEOGRAPH-#2BD6C
2BD6D CJK UNIFIED IDEOGRAPH-#2BD6D
2BD6E CJK UNIFIED IDEOGRAPH-#2BD6E
2BD6F CJK UNIFIED IDEOGRAPH-#2BD6F
2BD70 CJK UNIFIED IDEOGRAPH-#2BD70
2BD71 CJK UNIFIED IDEOGRAPH-#2BD71
2BD72 CJK UNIFIED IDEOGRAPH-#2BD72
2BD73 CJK UNIFIED IDEOGRAPH-#2BD73
2BD74 CJK UNIFIED IDEOGRAPH-#2BD74
2BD75 CJK UNIFIED IDEOGRAPH-#2BD75
2BD76 CJK UNIFIED IDEOGRAPH-#2BD76
2BD77 CJK UNIFIED IDEOGRAPH-#2BD77
2BD78 CJK UNIFIED IDEOGRAPH-#2BD78
2BD79 CJK UNIFIED IDEOGRAPH-#2BD79
2BD7A CJK UNIFIED IDEOGRAPH-#2BD7A
2BD7B CJK UNIFIED IDEOGRAPH-#2BD7B
2BD7C CJK UNIFIED IDEOGRAPH-#2BD7C
2BD7D CJK UNIFIED IDEOGRAPH-#2BD7D
2BD7E CJK UNIFIED IDEOGRAPH-#2BD7E
2BD7F CJK UNIFIED IDEOGRAPH-#2BD7F
2BD80 CJK UNIFIED IDEOGRAPH-#2BD80
2BD81 CJK UNIFIED IDEOGRAPH-#2BD81
2BD82 CJK UNIFIED IDEOGRAPH-#2BD82
2BD83 CJK UNIFIED IDEOGRAPH-#2BD83
2BD84 CJK UNIFIED IDEOGRAPH-#2BD84
2BD85 CJK UNIFIED IDEOGRAPH-#2BD85
2BD86 CJK UNIFIED IDEOGRAPH-#2BD86
2BD87 CJK UNIFIED IDEOGRAPH-#2BD87
2BD88 CJK UNIFIED IDEOGRAPH-#2BD88
2BD89 CJK UNIFIED IDEOGRAPH-#2BD89
2BD8A CJK UNIFIED IDEOGRAPH-#2BD8A
2BD8B CJK UNIFIED IDEOGRAPH-#2BD8B
2BD8C CJK UNIFIED IDEOGRAPH-#2BD8C
2BD8D CJK UNIFIED IDEOGRAPH-#2BD8D
2BD8E CJK UNIFIED IDEOGRAPH-#2BD8E
2BD8F CJK UNIFIED IDEOGRAPH-#2BD8F
2BD90 CJK UNIFIED IDEOGRAPH-#2BD90
2BD91 CJK UNIFIED IDEOGRAPH-#2BD91
2BD92 CJK UNIFIED IDEOGRAPH-#2BD92
2BD93 CJK UNIFIED IDEOGRAPH-#2BD93
2BD94 CJK UNIFIED IDEOGRAPH-#2BD94
2BD95 CJK UNIFIED IDEOGRAPH-#2BD95
2BD96 CJK UNIFIED IDEOGRAPH-#2BD96
2BD97 CJK UNIFIED IDEOGRAPH-#2BD97
2BD98 CJK UNIFIED IDEOGRAPH-#2BD98
2BD99 CJK UNIFIED IDEOGRAPH-#2BD99
2BD9A CJK UNIFIED IDEOGRAPH-#2BD9A
2BD9B CJK UNIFIED IDEOGRAPH-#2BD9B
2BD9C CJK UNIFIED IDEOGRAPH-#2BD9C
2BD9D CJK UNIFIED IDEOGRAPH-#2BD9D
2BD9E CJK UNIFIED IDEOGRAPH-#2BD9E
2BD9F CJK UNIFIED IDEOGRAPH-#2BD9F
2BDA0 CJK UNIFIED IDEOGRAPH-#2BDA0
2BDA1 CJK UNIFIED IDEOGRAPH-#2BDA1
2BDA2 CJK UNIFIED IDEOGRAPH-#2BDA2
2BDA3 CJK UNIFIED IDEOGRAPH-#2BDA3
2BDA4 CJK UNIFIED IDEOGRAPH-#2BDA4
2BDA5 CJK UNIFIED IDEOGRAPH-#2BDA5
2BDA6 CJK UNIFIED IDEOGRAPH-#2BDA6
2BDA7 CJK UNIFIED IDEOGRAPH-#2BDA7
2BDA8 CJK UNIFIED IDEOGRAPH-#2BDA8
2BDA9 CJK UNIFIED IDEOGRAPH-#2BDA9
2BDAA CJK UNIFIED IDEOGRAPH-#2BDAA
2BDAB CJK UNIFIED IDEOGRAPH-#2BDAB
2BDAC CJK UNIFIED IDEOGRAPH-#2BDAC
2BDAD CJK UNIFIED IDEOGRAPH-#2BDAD
2BDAE CJK UNIFIED IDEOGRAPH-#2BDAE
2BDAF CJK UNIFIED IDEOGRAPH-#2BDAF
2BDB0 CJK UNIFIED IDEOGRAPH-#2BDB0
2BDB1 CJK UNIFIED IDEOGRAPH-#2BDB1
2BDB2 CJK UNIFIED IDEOGRAPH-#2BDB2
2BDB3 CJK UNIFIED IDEOGRAPH-#2BDB3
2BDB4 CJK UNIFIED IDEOGRAPH-#2BDB4
2BDB5 CJK UNIFIED IDEOGRAPH-#2BDB5
2BDB6 CJK UNIFIED IDEOGRAPH-#2BDB6
2BDB7 CJK UNIFIED IDEOGRAPH-#2BDB7
2BDB8 CJK UNIFIED IDEOGRAPH-#2BDB8
2BDB9 CJK UNIFIED IDEOGRAPH-#2BDB9
2BDBA CJK UNIFIED IDEOGRAPH-#2BDBA
2BDBB CJK UNIFIED IDEOGRAPH-#2BDBB
2BDBC CJK UNIFIED IDEOGRAPH-#2BDBC
2BDBD CJK UNIFIED IDEOGRAPH-#2BDBD
2BDBE CJK UNIFIED IDEOGRAPH-#2BDBE
2BDBF CJK UNIFIED IDEOGRAPH-#2BDBF
2BDC0 CJK UNIFIED IDEOGRAPH-#2BDC0
2BDC1 CJK UNIFIED IDEOGRAPH-#2BDC1
2BDC2 CJK UNIFIED IDEOGRAPH-#2BDC2
2BDC3 CJK UNIFIED IDEOGRAPH-#2BDC3
2BDC4 CJK UNIFIED IDEOGRAPH-#2BDC4
2BDC5 CJK UNIFIED IDEOGRAPH-#2BDC5
2BDC6 CJK UNIFIED IDEOGRAPH-#2BDC6
2BDC7 CJK UNIFIED IDEOGRAPH-#2BDC7
2BDC8 CJK UNIFIED IDEOGRAPH-#2BDC8
2BDC9 CJK UNIFIED IDEOGRAPH-#2BDC9
2BDCA CJK UNIFIED IDEOGRAPH-#2BDCA
2BDCB CJK UNIFIED IDEOGRAPH-#2BDCB
2BDCC CJK UNIFIED IDEOGRAPH-#2BDCC
2BDCD CJK UNIFIED IDEOGRAPH-#2BDCD
2BDCE CJK UNIFIED IDEOGRAPH-#2BDCE
2BDCF CJK UNIFIED IDEOGRAPH-#2BDCF
2BDD0 CJK UNIFIED IDEOGRAPH-#2BDD0
2BDD1 CJK UNIFIED IDEOGRAPH-#2BDD1
2BDD2 CJK UNIFIED IDEOGRAPH-#2BDD2
2BDD3 CJK UNIFIED IDEOGRAPH-#2BDD3
2BDD4 CJK UNIFIED IDEOGRAPH-#2BDD4
2BDD5 CJK UNIFIED IDEOGRAPH-#2BDD5
2BDD6 CJK UNIFIED IDEOGRAPH-#2BDD6
2BDD7 CJK UNIFIED IDEOGRAPH-#2BDD7
2BDD8 CJK UNIFIED IDEOGRAPH-#2BDD8
2BDD9 CJK UNIFIED IDEOGRAPH-#2BDD9
2BDDA CJK UNIFIED IDEOGRAPH-#2BDDA
2BDDB CJK UNIFIED IDEOGRAPH-#2BDDB
2BDDC CJK UNIFIED IDEOGRAPH-#2BDDC
2BDDD CJK UNIFIED IDEOGRAPH-#2BDDD
2BDDE CJK UNIFIED IDEOGRAPH-#2BDDE
2BDDF CJK UNIFIED IDEOGRAPH-#2BDDF
2BDE0 CJK UNIFIED IDEOGRAPH-#2BDE0
2BDE1 CJK UNIFIED IDEOGRAPH-#2BDE1
2BDE2 CJK UNIFIED IDEOGRAPH-#2BDE2
2BDE3 CJK UNIFIED IDEOGRAPH-#2BDE3
2BDE4 CJK UNIFIED IDEOGRAPH-#2BDE4
2BDE5 CJK UNIFIED IDEOGRAPH-#2BDE5
2BDE6 CJK UNIFIED IDEOGRAPH-#2BDE6
2BDE7 CJK UNIFIED IDEOGRAPH-#2BDE7
2BDE8 CJK UNIFIED IDEOGRAPH-#2BDE8
2BDE9 CJK UNIFIED IDEOGRAPH-#2BDE9
2BDEA CJK UNIFIED IDEOGRAPH-#2BDEA
2BDEB CJK UNIFIED IDEOGRAPH-#2BDEB
2BDEC CJK UNIFIED IDEOGRAPH-#2BDEC
2BDED CJK UNIFIED IDEOGRAPH-#2BDED
2BDEE CJK UNIFIED IDEOGRAPH-#2BDEE
2BDEF CJK UNIFIED IDEOGRAPH-#2BDEF
2BDF0 CJK UNIFIED IDEOGRAPH-#2BDF0
2BDF1 CJK UNIFIED IDEOGRAPH-#2BDF1
2BDF2 CJK UNIFIED IDEOGRAPH-#2BDF2
2BDF3 CJK UNIFIED IDEOGRAPH-#2BDF3
2BDF4 CJK UNIFIED IDEOGRAPH-#2BDF4
2BDF5 CJK UNIFIED IDEOGRAPH-#2BDF5
2BDF6 CJK UNIFIED IDEOGRAPH-#2BDF6
2BDF7 CJK UNIFIED IDEOGRAPH-#2BDF7
2BDF8 CJK UNIFIED IDEOGRAPH-#2BDF8
2BDF9 CJK UNIFIED IDEOGRAPH-#2BDF9
2BDFA CJK UNIFIED IDEOGRAPH-#2BDFA
2BDFB CJK UNIFIED IDEOGRAPH-#2BDFB
2BDFC CJK UNIFIED IDEOGRAPH-#2BDFC
2BDFD CJK UNIFIED IDEOGRAPH-#2BDFD
2BDFE CJK UNIFIED IDEOGRAPH-#2BDFE
2BDFF CJK UNIFIED IDEOGRAPH-#2BDFF
2BE00 CJK UNIFIED IDEOGRAPH-#2BE00
2BE01 CJK UNIFIED IDEOGRAPH-#2BE01
2BE02 CJK UNIFIED IDEOGRAPH-#2BE02
2BE03 CJK UNIFIED IDEOGRAPH-#2BE03
2BE04 CJK UNIFIED IDEOGRAPH-#2BE04
2BE05 CJK UNIFIED IDEOGRAPH-#2BE05
2BE06 CJK UNIFIED IDEOGRAPH-#2BE06
2BE07 CJK UNIFIED IDEOGRAPH-#2BE07
2BE08 CJK UNIFIED IDEOGRAPH-#2BE08
2BE09 CJK UNIFIED IDEOGRAPH-#2BE09
2BE0A CJK UNIFIED IDEOGRAPH-#2BE0A
2BE0B CJK UNIFIED IDEOGRAPH-#2BE0B
2BE0C CJK UNIFIED IDEOGRAPH-#2BE0C
2BE0D CJK UNIFIED IDEOGRAPH-#2BE0D
2BE0E CJK UNIFIED IDEOGRAPH-#2BE0E
2BE0F CJK UNIFIED IDEOGRAPH-#2BE0F
2BE10 CJK UNIFIED IDEOGRAPH-#2BE10
2BE11 CJK UNIFIED IDEOGRAPH-#2BE11
2BE12 CJK UNIFIED IDEOGRAPH-#2BE12
2BE13 CJK UNIFIED IDEOGRAPH-#2BE13
2BE14 CJK UNIFIED IDEOGRAPH-#2BE14
2BE15 CJK UNIFIED IDEOGRAPH-#2BE15
2BE16 CJK UNIFIED IDEOGRAPH-#2BE16
2BE17 CJK UNIFIED IDEOGRAPH-#2BE17
2BE18 CJK UNIFIED IDEOGRAPH-#2BE18
2BE19 CJK UNIFIED IDEOGRAPH-#2BE19
2BE1A CJK UNIFIED IDEOGRAPH-#2BE1A
2BE1B CJK UNIFIED IDEOGRAPH-#2BE1B
2BE1C CJK UNIFIED IDEOGRAPH-#2BE1C
2BE1D CJK UNIFIED IDEOGRAPH-#2BE1D
2BE1E CJK UNIFIED IDEOGRAPH-#2BE1E
2BE1F CJK UNIFIED IDEOGRAPH-#2BE1F
2BE20 CJK UNIFIED IDEOGRAPH-#2BE20
2BE21 CJK UNIFIED IDEOGRAPH-#2BE21
2BE22 CJK UNIFIED IDEOGRAPH-#2BE22
2BE23 CJK UNIFIED IDEOGRAPH-#2BE23
2BE24 CJK UNIFIED IDEOGRAPH-#2BE24
2BE25 CJK UNIFIED IDEOGRAPH-#2BE25
2BE26 CJK UNIFIED IDEOGRAPH-#2BE26
2BE27 CJK UNIFIED IDEOGRAPH-#2BE27
2BE28 CJK UNIFIED IDEOGRAPH-#2BE28
2BE29 CJK UNIFIED IDEOGRAPH-#2BE29
2BE2A CJK UNIFIED IDEOGRAPH-#2BE2A
2BE2B CJK UNIFIED IDEOGRAPH-#2BE2B
2BE2C CJK UNIFIED IDEOGRAPH-#2BE2C
2BE2D CJK UNIFIED IDEOGRAPH-#2BE2D
2BE2E CJK UNIFIED IDEOGRAPH-#2BE2E
2BE2F CJK UNIFIED IDEOGRAPH-#2BE2F
2BE30 CJK UNIFIED IDEOGRAPH-#2BE30
2BE31 CJK UNIFIED IDEOGRAPH-#2BE31
2BE32 CJK UNIFIED IDEOGRAPH-#2BE32
2BE33 CJK UNIFIED IDEOGRAPH-#2BE33
2BE34 CJK UNIFIED IDEOGRAPH-#2BE34
2BE35 CJK UNIFIED IDEOGRAPH-#2BE35
2BE36 CJK UNIFIED IDEOGRAPH-#2BE36
2BE37 CJK UNIFIED IDEOGRAPH-#2BE37
2BE38 CJK UNIFIED IDEOGRAPH-#2BE38
2BE39 CJK UNIFIED IDEOGRAPH-#2BE39
2BE3A CJK UNIFIED IDEOGRAPH-#2BE3A
2BE3B CJK UNIFIED IDEOGRAPH-#2BE3B
2BE3C CJK UNIFIED IDEOGRAPH-#2BE3C
2BE3D CJK UNIFIED IDEOGRAPH-#2BE3D
2BE3E CJK UNIFIED IDEOGRAPH-#2BE3E
2BE3F CJK UNIFIED IDEOGRAPH-#2BE3F
2BE40 CJK UNIFIED IDEOGRAPH-#2BE40
2BE41 CJK UNIFIED IDEOGRAPH-#2BE41
2BE42 CJK UNIFIED IDEOGRAPH-#2BE42
2BE43 CJK UNIFIED IDEOGRAPH-#2BE43
2BE44 CJK UNIFIED IDEOGRAPH-#2BE44
2BE45 CJK UNIFIED IDEOGRAPH-#2BE45
2BE46 CJK UNIFIED IDEOGRAPH-#2BE46
2BE47 CJK UNIFIED IDEOGRAPH-#2BE47
2BE48 CJK UNIFIED IDEOGRAPH-#2BE48
2BE49 CJK UNIFIED IDEOGRAPH-#2BE49
2BE4A CJK UNIFIED IDEOGRAPH-#2BE4A
2BE4B CJK UNIFIED IDEOGRAPH-#2BE4B
2BE4C CJK UNIFIED IDEOGRAPH-#2BE4C
2BE4D CJK UNIFIED IDEOGRAPH-#2BE4D
2BE4E CJK UNIFIED IDEOGRAPH-#2BE4E
2BE4F CJK UNIFIED IDEOGRAPH-#2BE4F
2BE50 CJK UNIFIED IDEOGRAPH-#2BE50
2BE51 CJK UNIFIED IDEOGRAPH-#2BE51
2BE52 CJK UNIFIED IDEOGRAPH-#2BE52
2BE53 CJK UNIFIED IDEOGRAPH-#2BE53
2BE54 CJK UNIFIED IDEOGRAPH-#2BE54
2BE55 CJK UNIFIED IDEOGRAPH-#2BE55
2BE56 CJK UNIFIED IDEOGRAPH-#2BE56
2BE57 CJK UNIFIED IDEOGRAPH-#2BE57
2BE58 CJK UNIFIED IDEOGRAPH-#2BE58
2BE59 CJK UNIFIED IDEOGRAPH-#2BE59
2BE5A CJK UNIFIED IDEOGRAPH-#2BE5A
2BE5B CJK UNIFIED IDEOGRAPH-#2BE5B
2BE5C CJK UNIFIED IDEOGRAPH-#2BE5C
2BE5D CJK UNIFIED IDEOGRAPH-#2BE5D
2BE5E CJK UNIFIED IDEOGRAPH-#2BE5E
2BE5F CJK UNIFIED IDEOGRAPH-#2BE5F
2BE60 CJK UNIFIED IDEOGRAPH-#2BE60
2BE61 CJK UNIFIED IDEOGRAPH-#2BE61
2BE62 CJK UNIFIED IDEOGRAPH-#2BE62
2BE63 CJK UNIFIED IDEOGRAPH-#2BE63
2BE64 CJK UNIFIED IDEOGRAPH-#2BE64
2BE65 CJK UNIFIED IDEOGRAPH-#2BE65
2BE66 CJK UNIFIED IDEOGRAPH-#2BE66
2BE67 CJK UNIFIED IDEOGRAPH-#2BE67
2BE68 CJK UNIFIED IDEOGRAPH-#2BE68
2BE69 CJK UNIFIED IDEOGRAPH-#2BE69
2BE6A CJK UNIFIED IDEOGRAPH-#2BE6A
2BE6B CJK UNIFIED IDEOGRAPH-#2BE6B
2BE6C CJK UNIFIED IDEOGRAPH-#2BE6C
2BE6D CJK UNIFIED IDEOGRAPH-#2BE6D
2BE6E CJK UNIFIED IDEOGRAPH-#2BE6E
2BE6F CJK UNIFIED IDEOGRAPH-#2BE6F
2BE70 CJK UNIFIED IDEOGRAPH-#2BE70
2BE71 CJK UNIFIED IDEOGRAPH-#2BE71
2BE72 CJK UNIFIED IDEOGRAPH-#2BE72
2BE73 CJK UNIFIED IDEOGRAPH-#2BE73
2BE74 CJK UNIFIED IDEOGRAPH-#2BE74
2BE75 CJK UNIFIED IDEOGRAPH-#2BE75
2BE76 CJK UNIFIED IDEOGRAPH-#2BE76
2BE77 CJK UNIFIED IDEOGRAPH-#2BE77
2BE78 CJK UNIFIED IDEOGRAPH-#2BE78
2BE79 CJK UNIFIED IDEOGRAPH-#2BE79
2BE7A CJK UNIFIED IDEOGRAPH-#2BE7A
2BE7B CJK UNIFIED IDEOGRAPH-#2BE7B
2BE7C CJK UNIFIED IDEOGRAPH-#2BE7C
2BE7D CJK UNIFIED IDEOGRAPH-#2BE7D
2BE7E CJK UNIFIED IDEOGRAPH-#2BE7E
2BE7F CJK UNIFIED IDEOGRAPH-#2BE7F
2BE80 CJK UNIFIED IDEOGRAPH-#2BE80
2BE81 CJK UNIFIED IDEOGRAPH-#2BE81
2BE82 CJK UNIFIED IDEOGRAPH-#2BE82
2BE83 CJK UNIFIED IDEOGRAPH-#2BE83
2BE84 CJK UNIFIED IDEOGRAPH-#2BE84
2BE85 CJK UNIFIED IDEOGRAPH-#2BE85
2BE86 CJK UNIFIED IDEOGRAPH-#2BE86
2BE87 CJK UNIFIED IDEOGRAPH-#2BE87
2BE88 CJK UNIFIED IDEOGRAPH-#2BE88
2BE89 CJK UNIFIED IDEOGRAPH-#2BE89
2BE8A CJK UNIFIED IDEOGRAPH-#2BE8A
2BE8B CJK UNIFIED IDEOGRAPH-#2BE8B
2BE8C CJK UNIFIED IDEOGRAPH-#2BE8C
2BE8D CJK UNIFIED IDEOGRAPH-#2BE8D
2BE8E CJK UNIFIED IDEOGRAPH-#2BE8E
2BE8F CJK UNIFIED IDEOGRAPH-#2BE8F
2BE90 CJK UNIFIED IDEOGRAPH-#2BE90
2BE91 CJK UNIFIED IDEOGRAPH-#2BE91
2BE92 CJK UNIFIED IDEOGRAPH-#2BE92
2BE93 CJK UNIFIED IDEOGRAPH-#2BE93
2BE94 CJK UNIFIED IDEOGRAPH-#2BE94
2BE95 CJK UNIFIED IDEOGRAPH-#2BE95
2BE96 CJK UNIFIED IDEOGRAPH-#2BE96
2BE97 CJK UNIFIED IDEOGRAPH-#2BE97
2BE98 CJK UNIFIED IDEOGRAPH-#2BE98
2BE99 CJK UNIFIED IDEOGRAPH-#2BE99
2BE9A CJK UNIFIED IDEOGRAPH-#2BE9A
2BE9B CJK UNIFIED IDEOGRAPH-#2BE9B
2BE9C CJK UNIFIED IDEOGRAPH-#2BE9C
2BE9D CJK UNIFIED IDEOGRAPH-#2BE9D
2BE9E CJK UNIFIED IDEOGRAPH-#2BE9E
2BE9F CJK UNIFIED IDEOGRAPH-#2BE9F
2BEA0 CJK UNIFIED IDEOGRAPH-#2BEA0
2BEA1 CJK UNIFIED IDEOGRAPH-#2BEA1
2BEA2 CJK UNIFIED IDEOGRAPH-#2BEA2
2BEA3 CJK UNIFIED IDEOGRAPH-#2BEA3
2BEA4 CJK UNIFIED IDEOGRAPH-#2BEA4
2BEA5 CJK UNIFIED IDEOGRAPH-#2BEA5
2BEA6 CJK UNIFIED IDEOGRAPH-#2BEA6
2BEA7 CJK UNIFIED IDEOGRAPH-#2BEA7
2BEA8 CJK UNIFIED IDEOGRAPH-#2BEA8
2BEA9 CJK UNIFIED IDEOGRAPH-#2BEA9
2BEAA CJK UNIFIED IDEOGRAPH-#2BEAA
2BEAB CJK UNIFIED IDEOGRAPH-#2BEAB
2BEAC CJK UNIFIED IDEOGRAPH-#2BEAC
2BEAD CJK UNIFIED IDEOGRAPH-#2BEAD
2BEAE CJK UNIFIED IDEOGRAPH-#2BEAE
2BEAF CJK UNIFIED IDEOGRAPH-#2BEAF
2BEB0 CJK UNIFIED IDEOGRAPH-#2BEB0
2BEB1 CJK UNIFIED IDEOGRAPH-#2BEB1
2BEB2 CJK UNIFIED IDEOGRAPH-#2BEB2
2BEB3 CJK UNIFIED IDEOGRAPH-#2BEB3
2BEB4 CJK UNIFIED IDEOGRAPH-#2BEB4
2BEB5 CJK UNIFIED IDEOGRAPH-#2BEB5
2BEB6 CJK UNIFIED IDEOGRAPH-#2BEB6
2BEB7 CJK UNIFIED IDEOGRAPH-#2BEB7
2BEB8 CJK UNIFIED IDEOGRAPH-#2BEB8
2BEB9 CJK UNIFIED IDEOGRAPH-#2BEB9
2BEBA CJK UNIFIED IDEOGRAPH-#2BEBA
2BEBB CJK UNIFIED IDEOGRAPH-#2BEBB
2BEBC CJK UNIFIED IDEOGRAPH-#2BEBC
2BEBD CJK UNIFIED IDEOGRAPH-#2BEBD
2BEBE CJK UNIFIED IDEOGRAPH-#2BEBE
2BEBF CJK UNIFIED IDEOGRAPH-#2BEBF
2BEC0 CJK UNIFIED IDEOGRAPH-#2BEC0
2BEC1 CJK UNIFIED IDEOGRAPH-#2BEC1
2BEC2 CJK UNIFIED IDEOGRAPH-#2BEC2
2BEC3 CJK UNIFIED IDEOGRAPH-#2BEC3
2BEC4 CJK UNIFIED IDEOGRAPH-#2BEC4
2BEC5 CJK UNIFIED IDEOGRAPH-#2BEC5
2BEC6 CJK UNIFIED IDEOGRAPH-#2BEC6
2BEC7 CJK UNIFIED IDEOGRAPH-#2BEC7
2BEC8 CJK UNIFIED IDEOGRAPH-#2BEC8
2BEC9 CJK UNIFIED IDEOGRAPH-#2BEC9
2BECA CJK UNIFIED IDEOGRAPH-#2BECA
2BECB CJK UNIFIED IDEOGRAPH-#2BECB
2BECC CJK UNIFIED IDEOGRAPH-#2BECC
2BECD CJK UNIFIED IDEOGRAPH-#2BECD
2BECE CJK UNIFIED IDEOGRAPH-#2BECE
2BECF CJK UNIFIED IDEOGRAPH-#2BECF
2BED0 CJK UNIFIED IDEOGRAPH-#2BED0
2BED1 CJK UNIFIED IDEOGRAPH-#2BED1
2BED2 CJK UNIFIED IDEOGRAPH-#2BED2
2BED3 CJK UNIFIED IDEOGRAPH-#2BED3
2BED4 CJK UNIFIED IDEOGRAPH-#2BED4
2BED5 CJK UNIFIED IDEOGRAPH-#2BED5
2BED6 CJK UNIFIED IDEOGRAPH-#2BED6
2BED7 CJK UNIFIED IDEOGRAPH-#2BED7
2BED8 CJK UNIFIED IDEOGRAPH-#2BED8
2BED9 CJK UNIFIED IDEOGRAPH-#2BED9
2BEDA CJK UNIFIED IDEOGRAPH-#2BEDA
2BEDB CJK UNIFIED IDEOGRAPH-#2BEDB
2BEDC CJK UNIFIED IDEOGRAPH-#2BEDC
2BEDD CJK UNIFIED IDEOGRAPH-#2BEDD
2BEDE CJK UNIFIED IDEOGRAPH-#2BEDE
2BEDF CJK UNIFIED IDEOGRAPH-#2BEDF
2BEE0 CJK UNIFIED IDEOGRAPH-#2BEE0
2BEE1 CJK UNIFIED IDEOGRAPH-#2BEE1
2BEE2 CJK UNIFIED IDEOGRAPH-#2BEE2
2BEE3 CJK UNIFIED IDEOGRAPH-#2BEE3
2BEE4 CJK UNIFIED IDEOGRAPH-#2BEE4
2BEE5 CJK UNIFIED IDEOGRAPH-#2BEE5
2BEE6 CJK UNIFIED IDEOGRAPH-#2BEE6
2BEE7 CJK UNIFIED IDEOGRAPH-#2BEE7
2BEE8 CJK UNIFIED IDEOGRAPH-#2BEE8
2BEE9 CJK UNIFIED IDEOGRAPH-#2BEE9
2BEEA CJK UNIFIED IDEOGRAPH-#2BEEA
2BEEB CJK UNIFIED IDEOGRAPH-#2BEEB
2BEEC CJK UNIFIED IDEOGRAPH-#2BEEC
2BEED CJK UNIFIED IDEOGRAPH-#2BEED
2BEEE CJK UNIFIED IDEOGRAPH-#2BEEE
2BEEF CJK UNIFIED IDEOGRAPH-#2BEEF
2BEF0 CJK UNIFIED IDEOGRAPH-#2BEF0
2BEF1 CJK UNIFIED IDEOGRAPH-#2BEF1
2BEF2 CJK UNIFIED IDEOGRAPH-#2BEF2
2BEF3 CJK UNIFIED IDEOGRAPH-#2BEF3
2BEF4 CJK UNIFIED IDEOGRAPH-#2BEF4
2BEF5 CJK UNIFIED IDEOGRAPH-#2BEF5
2BEF6 CJK UNIFIED IDEOGRAPH-#2BEF6
2BEF7 CJK UNIFIED IDEOGRAPH-#2BEF7
2BEF8 CJK UNIFIED IDEOGRAPH-#2BEF8
2BEF9 CJK UNIFIED IDEOGRAPH-#2BEF9
2BEFA CJK UNIFIED IDEOGRAPH-#2BEFA
2BEFB CJK UNIFIED IDEOGRAPH-#2BEFB
2BEFC CJK UNIFIED IDEOGRAPH-#2BEFC
2BEFD CJK UNIFIED IDEOGRAPH-#2BEFD
2BEFE CJK UNIFIED IDEOGRAPH-#2BEFE
2BEFF CJK UNIFIED IDEOGRAPH-#2BEFF
2BF00 CJK UNIFIED IDEOGRAPH-#2BF00
2BF01 CJK UNIFIED IDEOGRAPH-#2BF01
2BF02 CJK UNIFIED IDEOGRAPH-#2BF02
2BF03 CJK UNIFIED IDEOGRAPH-#2BF03
2BF04 CJK UNIFIED IDEOGRAPH-#2BF04
2BF05 CJK UNIFIED IDEOGRAPH-#2BF05
2BF06 CJK UNIFIED IDEOGRAPH-#2BF06
2BF07 CJK UNIFIED IDEOGRAPH-#2BF07
2BF08 CJK UNIFIED IDEOGRAPH-#2BF08
2BF09 CJK UNIFIED IDEOGRAPH-#2BF09
2BF0A CJK UNIFIED IDEOGRAPH-#2BF0A
2BF0B CJK UNIFIED IDEOGRAPH-#2BF0B
2BF0C CJK UNIFIED IDEOGRAPH-#2BF0C
2BF0D CJK UNIFIED IDEOGRAPH-#2BF0D
2BF0E CJK UNIFIED IDEOGRAPH-#2BF0E
2BF0F CJK UNIFIED IDEOGRAPH-#2BF0F
2BF10 CJK UNIFIED IDEOGRAPH-#2BF10
2BF11 CJK UNIFIED IDEOGRAPH-#2BF11
2BF12 CJK UNIFIED IDEOGRAPH-#2BF12
2BF13 CJK UNIFIED IDEOGRAPH-#2BF13
2BF14 CJK UNIFIED IDEOGRAPH-#2BF14
2BF15 CJK UNIFIED IDEOGRAPH-#2BF15
2BF16 CJK UNIFIED IDEOGRAPH-#2BF16
2BF17 CJK UNIFIED IDEOGRAPH-#2BF17
2BF18 CJK UNIFIED IDEOGRAPH-#2BF18
2BF19 CJK UNIFIED IDEOGRAPH-#2BF19
2BF1A CJK UNIFIED IDEOGRAPH-#2BF1A
2BF1B CJK UNIFIED IDEOGRAPH-#2BF1B
2BF1C CJK UNIFIED IDEOGRAPH-#2BF1C
2BF1D CJK UNIFIED IDEOGRAPH-#2BF1D
2BF1E CJK UNIFIED IDEOGRAPH-#2BF1E
2BF1F CJK UNIFIED IDEOGRAPH-#2BF1F
2BF20 CJK UNIFIED IDEOGRAPH-#2BF20
2BF21 CJK UNIFIED IDEOGRAPH-#2BF21
2BF22 CJK UNIFIED IDEOGRAPH-#2BF22
2BF23 CJK UNIFIED IDEOGRAPH-#2BF23
2BF24 CJK UNIFIED IDEOGRAPH-#2BF24
2BF25 CJK UNIFIED IDEOGRAPH-#2BF25
2BF26 CJK UNIFIED IDEOGRAPH-#2BF26
2BF27 CJK UNIFIED IDEOGRAPH-#2BF27
2BF28 CJK UNIFIED IDEOGRAPH-#2BF28
2BF29 CJK UNIFIED IDEOGRAPH-#2BF29
2BF2A CJK UNIFIED IDEOGRAPH-#2BF2A
2BF2B CJK UNIFIED IDEOGRAPH-#2BF2B
2BF2C CJK UNIFIED IDEOGRAPH-#2BF2C
2BF2D CJK UNIFIED IDEOGRAPH-#2BF2D
2BF2E CJK UNIFIED IDEOGRAPH-#2BF2E
2BF2F CJK UNIFIED IDEOGRAPH-#2BF2F
2BF30 CJK UNIFIED IDEOGRAPH-#2BF30
2BF31 CJK UNIFIED IDEOGRAPH-#2BF31
2BF32 CJK UNIFIED IDEOGRAPH-#2BF32
2BF33 CJK UNIFIED IDEOGRAPH-#2BF33
2BF34 CJK UNIFIED IDEOGRAPH-#2BF34
2BF35 CJK UNIFIED IDEOGRAPH-#2BF35
2BF36 CJK UNIFIED IDEOGRAPH-#2BF36
2BF37 CJK UNIFIED IDEOGRAPH-#2BF37
2BF38 CJK UNIFIED IDEOGRAPH-#2BF38
2BF39 CJK UNIFIED IDEOGRAPH-#2BF39
2BF3A CJK UNIFIED IDEOGRAPH-#2BF3A
2BF3B CJK UNIFIED IDEOGRAPH-#2BF3B
2BF3C CJK UNIFIED IDEOGRAPH-#2BF3C
2BF3D CJK UNIFIED IDEOGRAPH-#2BF3D
2BF3E CJK UNIFIED IDEOGRAPH-#2BF3E
2BF3F CJK UNIFIED IDEOGRAPH-#2BF3F
2BF40 CJK UNIFIED IDEOGRAPH-#2BF40
2BF41 CJK UNIFIED IDEOGRAPH-#2BF41
2BF42 CJK UNIFIED IDEOGRAPH-#2BF42
2BF43 CJK UNIFIED IDEOGRAPH-#2BF43
2BF44 CJK UNIFIED IDEOGRAPH-#2BF44
2BF45 CJK UNIFIED IDEOGRAPH-#2BF45
2BF46 CJK UNIFIED IDEOGRAPH-#2BF46
2BF47 CJK UNIFIED IDEOGRAPH-#2BF47
2BF48 CJK UNIFIED IDEOGRAPH-#2BF48
2BF49 CJK UNIFIED IDEOGRAPH-#2BF49
2BF4A CJK UNIFIED IDEOGRAPH-#2BF4A
2BF4B CJK UNIFIED IDEOGRAPH-#2BF4B
2BF4C CJK UNIFIED IDEOGRAPH-#2BF4C
2BF4D CJK UNIFIED IDEOGRAPH-#2BF4D
2BF4E CJK UNIFIED IDEOGRAPH-#2BF4E
2BF4F CJK UNIFIED IDEOGRAPH-#2BF4F
2BF50 CJK UNIFIED IDEOGRAPH-#2BF50
2BF51 CJK UNIFIED IDEOGRAPH-#2BF51
2BF52 CJK UNIFIED IDEOGRAPH-#2BF52
2BF53 CJK UNIFIED IDEOGRAPH-#2BF53
2BF54 CJK UNIFIED IDEOGRAPH-#2BF54
2BF55 CJK UNIFIED IDEOGRAPH-#2BF55
2BF56 CJK UNIFIED IDEOGRAPH-#2BF56
2BF57 CJK UNIFIED IDEOGRAPH-#2BF57
2BF58 CJK UNIFIED IDEOGRAPH-#2BF58
2BF59 CJK UNIFIED IDEOGRAPH-#2BF59
2BF5A CJK UNIFIED IDEOGRAPH-#2BF5A
2BF5B CJK UNIFIED IDEOGRAPH-#2BF5B
2BF5C CJK UNIFIED IDEOGRAPH-#2BF5C
2BF5D CJK UNIFIED IDEOGRAPH-#2BF5D
2BF5E CJK UNIFIED IDEOGRAPH-#2BF5E
2BF5F CJK UNIFIED IDEOGRAPH-#2BF5F
2BF60 CJK UNIFIED IDEOGRAPH-#2BF60
2BF61 CJK UNIFIED IDEOGRAPH-#2BF61
2BF62 CJK UNIFIED IDEOGRAPH-#2BF62
2BF63 CJK UNIFIED IDEOGRAPH-#2BF63
2BF64 CJK UNIFIED IDEOGRAPH-#2BF64
2BF65 CJK UNIFIED IDEOGRAPH-#2BF65
2BF66 CJK UNIFIED IDEOGRAPH-#2BF66
2BF67 CJK UNIFIED IDEOGRAPH-#2BF67
2BF68 CJK UNIFIED IDEOGRAPH-#2BF68
2BF69 CJK UNIFIED IDEOGRAPH-#2BF69
2BF6A CJK UNIFIED IDEOGRAPH-#2BF6A
2BF6B CJK UNIFIED IDEOGRAPH-#2BF6B
2BF6C CJK UNIFIED IDEOGRAPH-#2BF6C
2BF6D CJK UNIFIED IDEOGRAPH-#2BF6D
2BF6E CJK UNIFIED IDEOGRAPH-#2BF6E
2BF6F CJK UNIFIED IDEOGRAPH-#2BF6F
2BF70 CJK UNIFIED IDEOGRAPH-#2BF70
2BF71 CJK UNIFIED IDEOGRAPH-#2BF71
2BF72 CJK UNIFIED IDEOGRAPH-#2BF72
2BF73 CJK UNIFIED IDEOGRAPH-#2BF73
2BF74 CJK UNIFIED IDEOGRAPH-#2BF74
2BF75 CJK UNIFIED IDEOGRAPH-#2BF75
2BF76 CJK UNIFIED IDEOGRAPH-#2BF76
2BF77 CJK UNIFIED IDEOGRAPH-#2BF77
2BF78 CJK UNIFIED IDEOGRAPH-#2BF78
2BF79 CJK UNIFIED IDEOGRAPH-#2BF79
2BF7A CJK UNIFIED IDEOGRAPH-#2BF7A
2BF7B CJK UNIFIED IDEOGRAPH-#2BF7B
2BF7C CJK UNIFIED IDEOGRAPH-#2BF7C
2BF7D CJK UNIFIED IDEOGRAPH-#2BF7D
2BF7E CJK UNIFIED IDEOGRAPH-#2BF7E
2BF7F CJK UNIFIED IDEOGRAPH-#2BF7F
2BF80 CJK UNIFIED IDEOGRAPH-#2BF80
2BF81 CJK UNIFIED IDEOGRAPH-#2BF81
2BF82 CJK UNIFIED IDEOGRAPH-#2BF82
2BF83 CJK UNIFIED IDEOGRAPH-#2BF83
2BF84 CJK UNIFIED IDEOGRAPH-#2BF84
2BF85 CJK UNIFIED IDEOGRAPH-#2BF85
2BF86 CJK UNIFIED IDEOGRAPH-#2BF86
2BF87 CJK UNIFIED IDEOGRAPH-#2BF87
2BF88 CJK UNIFIED IDEOGRAPH-#2BF88
2BF89 CJK UNIFIED IDEOGRAPH-#2BF89
2BF8A CJK UNIFIED IDEOGRAPH-#2BF8A
2BF8B CJK UNIFIED IDEOGRAPH-#2BF8B
2BF8C CJK UNIFIED IDEOGRAPH-#2BF8C
2BF8D CJK UNIFIED IDEOGRAPH-#2BF8D
2BF8E CJK UNIFIED IDEOGRAPH-#2BF8E
2BF8F CJK UNIFIED IDEOGRAPH-#2BF8F
2BF90 CJK UNIFIED IDEOGRAPH-#2BF90
2BF91 CJK UNIFIED IDEOGRAPH-#2BF91
2BF92 CJK UNIFIED IDEOGRAPH-#2BF92
2BF93 CJK UNIFIED IDEOGRAPH-#2BF93
2BF94 CJK UNIFIED IDEOGRAPH-#2BF94
2BF95 CJK UNIFIED IDEOGRAPH-#2BF95
2BF96 CJK UNIFIED IDEOGRAPH-#2BF96
2BF97 CJK UNIFIED IDEOGRAPH-#2BF97
2BF98 CJK UNIFIED IDEOGRAPH-#2BF98
2BF99 CJK UNIFIED IDEOGRAPH-#2BF99
2BF9A CJK UNIFIED IDEOGRAPH-#2BF9A
2BF9B CJK UNIFIED IDEOGRAPH-#2BF9B
2BF9C CJK UNIFIED IDEOGRAPH-#2BF9C
2BF9D CJK UNIFIED IDEOGRAPH-#2BF9D
2BF9E CJK UNIFIED IDEOGRAPH-#2BF9E
2BF9F CJK UNIFIED IDEOGRAPH-#2BF9F
2BFA0 CJK UNIFIED IDEOGRAPH-#2BFA0
2BFA1 CJK UNIFIED IDEOGRAPH-#2BFA1
2BFA2 CJK UNIFIED IDEOGRAPH-#2BFA2
2BFA3 CJK UNIFIED IDEOGRAPH-#2BFA3
2BFA4 CJK UNIFIED IDEOGRAPH-#2BFA4
2BFA5 CJK UNIFIED IDEOGRAPH-#2BFA5
2BFA6 CJK UNIFIED IDEOGRAPH-#2BFA6
2BFA7 CJK UNIFIED IDEOGRAPH-#2BFA7
2BFA8 CJK UNIFIED IDEOGRAPH-#2BFA8
2BFA9 CJK UNIFIED IDEOGRAPH-#2BFA9
2BFAA CJK UNIFIED IDEOGRAPH-#2BFAA
2BFAB CJK UNIFIED IDEOGRAPH-#2BFAB
2BFAC CJK UNIFIED IDEOGRAPH-#2BFAC
2BFAD CJK UNIFIED IDEOGRAPH-#2BFAD
2BFAE CJK UNIFIED IDEOGRAPH-#2BFAE
2BFAF CJK UNIFIED IDEOGRAPH-#2BFAF
2BFB0 CJK UNIFIED IDEOGRAPH-#2BFB0
2BFB1 CJK UNIFIED IDEOGRAPH-#2BFB1
2BFB2 CJK UNIFIED IDEOGRAPH-#2BFB2
2BFB3 CJK UNIFIED IDEOGRAPH-#2BFB3
2BFB4 CJK UNIFIED IDEOGRAPH-#2BFB4
2BFB5 CJK UNIFIED IDEOGRAPH-#2BFB5
2BFB6 CJK UNIFIED IDEOGRAPH-#2BFB6
2BFB7 CJK UNIFIED IDEOGRAPH-#2BFB7
2BFB8 CJK UNIFIED IDEOGRAPH-#2BFB8
2BFB9 CJK UNIFIED IDEOGRAPH-#2BFB9
2BFBA CJK UNIFIED IDEOGRAPH-#2BFBA
2BFBB CJK UNIFIED IDEOGRAPH-#2BFBB
2BFBC CJK UNIFIED IDEOGRAPH-#2BFBC
2BFBD CJK UNIFIED IDEOGRAPH-#2BFBD
2BFBE CJK UNIFIED IDEOGRAPH-#2BFBE
2BFBF CJK UNIFIED IDEOGRAPH-#2BFBF
2BFC0 CJK UNIFIED IDEOGRAPH-#2BFC0
2BFC1 CJK UNIFIED IDEOGRAPH-#2BFC1
2BFC2 CJK UNIFIED IDEOGRAPH-#2BFC2
2BFC3 CJK UNIFIED IDEOGRAPH-#2BFC3
2BFC4 CJK UNIFIED IDEOGRAPH-#2BFC4
2BFC5 CJK UNIFIED IDEOGRAPH-#2BFC5
2BFC6 CJK UNIFIED IDEOGRAPH-#2BFC6
2BFC7 CJK UNIFIED IDEOGRAPH-#2BFC7
2BFC8 CJK UNIFIED IDEOGRAPH-#2BFC8
2BFC9 CJK UNIFIED IDEOGRAPH-#2BFC9
2BFCA CJK UNIFIED IDEOGRAPH-#2BFCA
2BFCB CJK UNIFIED IDEOGRAPH-#2BFCB
2BFCC CJK UNIFIED IDEOGRAPH-#2BFCC
2BFCD CJK UNIFIED IDEOGRAPH-#2BFCD
2BFCE CJK UNIFIED IDEOGRAPH-#2BFCE
2BFCF CJK UNIFIED IDEOGRAPH-#2BFCF
2BFD0 CJK UNIFIED IDEOGRAPH-#2BFD0
2BFD1 CJK UNIFIED IDEOGRAPH-#2BFD1
2BFD2 CJK UNIFIED IDEOGRAPH-#2BFD2
2BFD3 CJK UNIFIED IDEOGRAPH-#2BFD3
2BFD4 CJK UNIFIED IDEOGRAPH-#2BFD4
2BFD5 CJK UNIFIED IDEOGRAPH-#2BFD5
2BFD6 CJK UNIFIED IDEOGRAPH-#2BFD6
2BFD7 CJK UNIFIED IDEOGRAPH-#2BFD7
2BFD8 CJK UNIFIED IDEOGRAPH-#2BFD8
2BFD9 CJK UNIFIED IDEOGRAPH-#2BFD9
2BFDA CJK UNIFIED IDEOGRAPH-#2BFDA
2BFDB CJK UNIFIED IDEOGRAPH-#2BFDB
2BFDC CJK UNIFIED IDEOGRAPH-#2BFDC
2BFDD CJK UNIFIED IDEOGRAPH-#2BFDD
2BFDE CJK UNIFIED IDEOGRAPH-#2BFDE
2BFDF CJK UNIFIED IDEOGRAPH-#2BFDF
2BFE0 CJK UNIFIED IDEOGRAPH-#2BFE0
2BFE1 CJK UNIFIED IDEOGRAPH-#2BFE1
2BFE2 CJK UNIFIED IDEOGRAPH-#2BFE2
2BFE3 CJK UNIFIED IDEOGRAPH-#2BFE3
2BFE4 CJK UNIFIED IDEOGRAPH-#2BFE4
2BFE5 CJK UNIFIED IDEOGRAPH-#2BFE5
2BFE6 CJK UNIFIED IDEOGRAPH-#2BFE6
2BFE7 CJK UNIFIED IDEOGRAPH-#2BFE7
2BFE8 CJK UNIFIED IDEOGRAPH-#2BFE8
2BFE9 CJK UNIFIED IDEOGRAPH-#2BFE9
2BFEA CJK UNIFIED IDEOGRAPH-#2BFEA
2BFEB CJK UNIFIED IDEOGRAPH-#2BFEB
2BFEC CJK UNIFIED IDEOGRAPH-#2BFEC
2BFED CJK UNIFIED IDEOGRAPH-#2BFED
2BFEE CJK UNIFIED IDEOGRAPH-#2BFEE
2BFEF CJK UNIFIED IDEOGRAPH-#2BFEF
2BFF0 CJK UNIFIED IDEOGRAPH-#2BFF0
2BFF1 CJK UNIFIED IDEOGRAPH-#2BFF1
2BFF2 CJK UNIFIED IDEOGRAPH-#2BFF2
2BFF3 CJK UNIFIED IDEOGRAPH-#2BFF3
2BFF4 CJK UNIFIED IDEOGRAPH-#2BFF4
2BFF5 CJK UNIFIED IDEOGRAPH-#2BFF5
2BFF6 CJK UNIFIED IDEOGRAPH-#2BFF6
2BFF7 CJK UNIFIED IDEOGRAPH-#2BFF7
2BFF8 CJK UNIFIED IDEOGRAPH-#2BFF8
2BFF9 CJK UNIFIED IDEOGRAPH-#2BFF9
2BFFA CJK UNIFIED IDEOGRAPH-#2BFFA
2BFFB CJK UNIFIED IDEOGRAPH-#2BFFB
2BFFC CJK UNIFIED IDEOGRAPH-#2BFFC
2BFFD CJK UNIFIED IDEOGRAPH-#2BFFD
2BFFE CJK UNIFIED IDEOGRAPH-#2BFFE
2BFFF CJK UNIFIED IDEOGRAPH-#2BFFF
2C000 CJK UNIFIED IDEOGRAPH-#2C000
2C001 CJK UNIFIED IDEOGRAPH-#2C001
2C002 CJK UNIFIED IDEOGRAPH-#2C002
2C003 CJK UNIFIED IDEOGRAPH-#2C003
2C004 CJK UNIFIED IDEOGRAPH-#2C004
2C005 CJK UNIFIED IDEOGRAPH-#2C005
2C006 CJK UNIFIED IDEOGRAPH-#2C006
2C007 CJK UNIFIED IDEOGRAPH-#2C007
2C008 CJK UNIFIED IDEOGRAPH-#2C008
2C009 CJK UNIFIED IDEOGRAPH-#2C009
2C00A CJK UNIFIED IDEOGRAPH-#2C00A
2C00B CJK UNIFIED IDEOGRAPH-#2C00B
2C00C CJK UNIFIED IDEOGRAPH-#2C00C
2C00D CJK UNIFIED IDEOGRAPH-#2C00D
2C00E CJK UNIFIED IDEOGRAPH-#2C00E
2C00F CJK UNIFIED IDEOGRAPH-#2C00F
2C010 CJK UNIFIED IDEOGRAPH-#2C010
2C011 CJK UNIFIED IDEOGRAPH-#2C011
2C012 CJK UNIFIED IDEOGRAPH-#2C012
2C013 CJK UNIFIED IDEOGRAPH-#2C013
2C014 CJK UNIFIED IDEOGRAPH-#2C014
2C015 CJK UNIFIED IDEOGRAPH-#2C015
2C016 CJK UNIFIED IDEOGRAPH-#2C016
2C017 CJK UNIFIED IDEOGRAPH-#2C017
2C018 CJK UNIFIED IDEOGRAPH-#2C018
2C019 CJK UNIFIED IDEOGRAPH-#2C019
2C01A CJK UNIFIED IDEOGRAPH-#2C01A
2C01B CJK UNIFIED IDEOGRAPH-#2C01B
2C01C CJK UNIFIED IDEOGRAPH-#2C01C
2C01D CJK UNIFIED IDEOGRAPH-#2C01D
2C01E CJK UNIFIED IDEOGRAPH-#2C01E
2C01F CJK UNIFIED IDEOGRAPH-#2C01F
2C020 CJK UNIFIED IDEOGRAPH-#2C020
2C021 CJK UNIFIED IDEOGRAPH-#2C021
2C022 CJK UNIFIED IDEOGRAPH-#2C022
2C023 CJK UNIFIED IDEOGRAPH-#2C023
2C024 CJK UNIFIED IDEOGRAPH-#2C024
2C025 CJK UNIFIED IDEOGRAPH-#2C025
2C026 CJK UNIFIED IDEOGRAPH-#2C026
2C027 CJK UNIFIED IDEOGRAPH-#2C027
2C028 CJK UNIFIED IDEOGRAPH-#2C028
2C029 CJK UNIFIED IDEOGRAPH-#2C029
2C02A CJK UNIFIED IDEOGRAPH-#2C02A
2C02B CJK UNIFIED IDEOGRAPH-#2C02B
2C02C CJK UNIFIED IDEOGRAPH-#2C02C
2C02D CJK UNIFIED IDEOGRAPH-#2C02D
2C02E CJK UNIFIED IDEOGRAPH-#2C02E
2C02F CJK UNIFIED IDEOGRAPH-#2C02F
2C030 CJK UNIFIED IDEOGRAPH-#2C030
2C031 CJK UNIFIED IDEOGRAPH-#2C031
2C032 CJK UNIFIED IDEOGRAPH-#2C032
2C033 CJK UNIFIED IDEOGRAPH-#2C033
2C034 CJK UNIFIED IDEOGRAPH-#2C034
2C035 CJK UNIFIED IDEOGRAPH-#2C035
2C036 CJK UNIFIED IDEOGRAPH-#2C036
2C037 CJK UNIFIED IDEOGRAPH-#2C037
2C038 CJK UNIFIED IDEOGRAPH-#2C038
2C039 CJK UNIFIED IDEOGRAPH-#2C039
2C03A CJK UNIFIED IDEOGRAPH-#2C03A
2C03B CJK UNIFIED IDEOGRAPH-#2C03B
2C03C CJK UNIFIED IDEOGRAPH-#2C03C
2C03D CJK UNIFIED IDEOGRAPH-#2C03D
2C03E CJK UNIFIED IDEOGRAPH-#2C03E
2C03F CJK UNIFIED IDEOGRAPH-#2C03F
2C040 CJK UNIFIED IDEOGRAPH-#2C040
2C041 CJK UNIFIED IDEOGRAPH-#2C041
2C042 CJK UNIFIED IDEOGRAPH-#2C042
2C043 CJK UNIFIED IDEOGRAPH-#2C043
2C044 CJK UNIFIED IDEOGRAPH-#2C044
2C045 CJK UNIFIED IDEOGRAPH-#2C045
2C046 CJK UNIFIED IDEOGRAPH-#2C046
2C047 CJK UNIFIED IDEOGRAPH-#2C047
2C048 CJK UNIFIED IDEOGRAPH-#2C048
2C049 CJK UNIFIED IDEOGRAPH-#2C049
2C04A CJK UNIFIED IDEOGRAPH-#2C04A
2C04B CJK UNIFIED IDEOGRAPH-#2C04B
2C04C CJK UNIFIED IDEOGRAPH-#2C04C
2C04D CJK UNIFIED IDEOGRAPH-#2C04D
2C04E CJK UNIFIED IDEOGRAPH-#2C04E
2C04F CJK UNIFIED IDEOGRAPH-#2C04F
2C050 CJK UNIFIED IDEOGRAPH-#2C050
2C051 CJK UNIFIED IDEOGRAPH-#2C051
2C052 CJK UNIFIED IDEOGRAPH-#2C052
2C053 CJK UNIFIED IDEOGRAPH-#2C053
2C054 CJK UNIFIED IDEOGRAPH-#2C054
2C055 CJK UNIFIED IDEOGRAPH-#2C055
2C056 CJK UNIFIED IDEOGRAPH-#2C056
2C057 CJK UNIFIED IDEOGRAPH-#2C057
2C058 CJK UNIFIED IDEOGRAPH-#2C058
2C059 CJK UNIFIED IDEOGRAPH-#2C059
2C05A CJK UNIFIED IDEOGRAPH-#2C05A
2C05B CJK UNIFIED IDEOGRAPH-#2C05B
2C05C CJK UNIFIED IDEOGRAPH-#2C05C
2C05D CJK UNIFIED IDEOGRAPH-#2C05D
2C05E CJK UNIFIED IDEOGRAPH-#2C05E
2C05F CJK UNIFIED IDEOGRAPH-#2C05F
2C060 CJK UNIFIED IDEOGRAPH-#2C060
2C061 CJK UNIFIED IDEOGRAPH-#2C061
2C062 CJK UNIFIED IDEOGRAPH-#2C062
2C063 CJK UNIFIED IDEOGRAPH-#2C063
2C064 CJK UNIFIED IDEOGRAPH-#2C064
2C065 CJK UNIFIED IDEOGRAPH-#2C065
2C066 CJK UNIFIED IDEOGRAPH-#2C066
2C067 CJK UNIFIED IDEOGRAPH-#2C067
2C068 CJK UNIFIED IDEOGRAPH-#2C068
2C069 CJK UNIFIED IDEOGRAPH-#2C069
2C06A CJK UNIFIED IDEOGRAPH-#2C06A
2C06B CJK UNIFIED IDEOGRAPH-#2C06B
2C06C CJK UNIFIED IDEOGRAPH-#2C06C
2C06D CJK UNIFIED IDEOGRAPH-#2C06D
2C06E CJK UNIFIED IDEOGRAPH-#2C06E
2C06F CJK UNIFIED IDEOGRAPH-#2C06F
2C070 CJK UNIFIED IDEOGRAPH-#2C070
2C071 CJK UNIFIED IDEOGRAPH-#2C071
2C072 CJK UNIFIED IDEOGRAPH-#2C072
2C073 CJK UNIFIED IDEOGRAPH-#2C073
2C074 CJK UNIFIED IDEOGRAPH-#2C074
2C075 CJK UNIFIED IDEOGRAPH-#2C075
2C076 CJK UNIFIED IDEOGRAPH-#2C076
2C077 CJK UNIFIED IDEOGRAPH-#2C077
2C078 CJK UNIFIED IDEOGRAPH-#2C078
2C079 CJK UNIFIED IDEOGRAPH-#2C079
2C07A CJK UNIFIED IDEOGRAPH-#2C07A
2C07B CJK UNIFIED IDEOGRAPH-#2C07B
2C07C CJK UNIFIED IDEOGRAPH-#2C07C
2C07D CJK UNIFIED IDEOGRAPH-#2C07D
2C07E CJK UNIFIED IDEOGRAPH-#2C07E
2C07F CJK UNIFIED IDEOGRAPH-#2C07F
2C080 CJK UNIFIED IDEOGRAPH-#2C080
2C081 CJK UNIFIED IDEOGRAPH-#2C081
2C082 CJK UNIFIED IDEOGRAPH-#2C082
2C083 CJK UNIFIED IDEOGRAPH-#2C083
2C084 CJK UNIFIED IDEOGRAPH-#2C084
2C085 CJK UNIFIED IDEOGRAPH-#2C085
2C086 CJK UNIFIED IDEOGRAPH-#2C086
2C087 CJK UNIFIED IDEOGRAPH-#2C087
2C088 CJK UNIFIED IDEOGRAPH-#2C088
2C089 CJK UNIFIED IDEOGRAPH-#2C089
2C08A CJK UNIFIED IDEOGRAPH-#2C08A
2C08B CJK UNIFIED IDEOGRAPH-#2C08B
2C08C CJK UNIFIED IDEOGRAPH-#2C08C
2C08D CJK UNIFIED IDEOGRAPH-#2C08D
2C08E CJK UNIFIED IDEOGRAPH-#2C08E
2C08F CJK UNIFIED IDEOGRAPH-#2C08F
2C090 CJK UNIFIED IDEOGRAPH-#2C090
2C091 CJK UNIFIED IDEOGRAPH-#2C091
2C092 CJK UNIFIED IDEOGRAPH-#2C092
2C093 CJK UNIFIED IDEOGRAPH-#2C093
2C094 CJK UNIFIED IDEOGRAPH-#2C094
2C095 CJK UNIFIED IDEOGRAPH-#2C095
2C096 CJK UNIFIED IDEOGRAPH-#2C096
2C097 CJK UNIFIED IDEOGRAPH-#2C097
2C098 CJK UNIFIED IDEOGRAPH-#2C098
2C099 CJK UNIFIED IDEOGRAPH-#2C099
2C09A CJK UNIFIED IDEOGRAPH-#2C09A
2C09B CJK UNIFIED IDEOGRAPH-#2C09B
2C09C CJK UNIFIED IDEOGRAPH-#2C09C
2C09D CJK UNIFIED IDEOGRAPH-#2C09D
2C09E CJK UNIFIED IDEOGRAPH-#2C09E
2C09F CJK UNIFIED IDEOGRAPH-#2C09F
2C0A0 CJK UNIFIED IDEOGRAPH-#2C0A0
2C0A1 CJK UNIFIED IDEOGRAPH-#2C0A1
2C0A2 CJK UNIFIED IDEOGRAPH-#2C0A2
2C0A3 CJK UNIFIED IDEOGRAPH-#2C0A3
2C0A4 CJK UNIFIED IDEOGRAPH-#2C0A4
2C0A5 CJK UNIFIED IDEOGRAPH-#2C0A5
2C0A6 CJK UNIFIED IDEOGRAPH-#2C0A6
2C0A7 CJK UNIFIED IDEOGRAPH-#2C0A7
2C0A8 CJK UNIFIED IDEOGRAPH-#2C0A8
2C0A9 CJK UNIFIED IDEOGRAPH-#2C0A9
2C0AA CJK UNIFIED IDEOGRAPH-#2C0AA
2C0AB CJK UNIFIED IDEOGRAPH-#2C0AB
2C0AC CJK UNIFIED IDEOGRAPH-#2C0AC
2C0AD CJK UNIFIED IDEOGRAPH-#2C0AD
2C0AE CJK UNIFIED IDEOGRAPH-#2C0AE
2C0AF CJK UNIFIED IDEOGRAPH-#2C0AF
2C0B0 CJK UNIFIED IDEOGRAPH-#2C0B0
2C0B1 CJK UNIFIED IDEOGRAPH-#2C0B1
2C0B2 CJK UNIFIED IDEOGRAPH-#2C0B2
2C0B3 CJK UNIFIED IDEOGRAPH-#2C0B3
2C0B4 CJK UNIFIED IDEOGRAPH-#2C0B4
2C0B5 CJK UNIFIED IDEOGRAPH-#2C0B5
2C0B6 CJK UNIFIED IDEOGRAPH-#2C0B6
2C0B7 CJK UNIFIED IDEOGRAPH-#2C0B7
2C0B8 CJK UNIFIED IDEOGRAPH-#2C0B8
2C0B9 CJK UNIFIED IDEOGRAPH-#2C0B9
2C0BA CJK UNIFIED IDEOGRAPH-#2C0BA
2C0BB CJK UNIFIED IDEOGRAPH-#2C0BB
2C0BC CJK UNIFIED IDEOGRAPH-#2C0BC
2C0BD CJK UNIFIED IDEOGRAPH-#2C0BD
2C0BE CJK UNIFIED IDEOGRAPH-#2C0BE
2C0BF CJK UNIFIED IDEOGRAPH-#2C0BF
2C0C0 CJK UNIFIED IDEOGRAPH-#2C0C0
2C0C1 CJK UNIFIED IDEOGRAPH-#2C0C1
2C0C2 CJK UNIFIED IDEOGRAPH-#2C0C2
2C0C3 CJK UNIFIED IDEOGRAPH-#2C0C3
2C0C4 CJK UNIFIED IDEOGRAPH-#2C0C4
2C0C5 CJK UNIFIED IDEOGRAPH-#2C0C5
2C0C6 CJK UNIFIED IDEOGRAPH-#2C0C6
2C0C7 CJK UNIFIED IDEOGRAPH-#2C0C7
2C0C8 CJK UNIFIED IDEOGRAPH-#2C0C8
2C0C9 CJK UNIFIED IDEOGRAPH-#2C0C9
2C0CA CJK UNIFIED IDEOGRAPH-#2C0CA
2C0CB CJK UNIFIED IDEOGRAPH-#2C0CB
2C0CC CJK UNIFIED IDEOGRAPH-#2C0CC
2C0CD CJK UNIFIED IDEOGRAPH-#2C0CD
2C0CE CJK UNIFIED IDEOGRAPH-#2C0CE
2C0CF CJK UNIFIED IDEOGRAPH-#2C0CF
2C0D0 CJK UNIFIED IDEOGRAPH-#2C0D0
2C0D1 CJK UNIFIED IDEOGRAPH-#2C0D1
2C0D2 CJK UNIFIED IDEOGRAPH-#2C0D2
2C0D3 CJK UNIFIED IDEOGRAPH-#2C0D3
2C0D4 CJK UNIFIED IDEOGRAPH-#2C0D4
2C0D5 CJK UNIFIED IDEOGRAPH-#2C0D5
2C0D6 CJK UNIFIED IDEOGRAPH-#2C0D6
2C0D7 CJK UNIFIED IDEOGRAPH-#2C0D7
2C0D8 CJK UNIFIED IDEOGRAPH-#2C0D8
2C0D9 CJK UNIFIED IDEOGRAPH-#2C0D9
2C0DA CJK UNIFIED IDEOGRAPH-#2C0DA
2C0DB CJK UNIFIED IDEOGRAPH-#2C0DB
2C0DC CJK UNIFIED IDEOGRAPH-#2C0DC
2C0DD CJK UNIFIED IDEOGRAPH-#2C0DD
2C0DE CJK UNIFIED IDEOGRAPH-#2C0DE
2C0DF CJK UNIFIED IDEOGRAPH-#2C0DF
2C0E0 CJK UNIFIED IDEOGRAPH-#2C0E0
2C0E1 CJK UNIFIED IDEOGRAPH-#2C0E1
2C0E2 CJK UNIFIED IDEOGRAPH-#2C0E2
2C0E3 CJK UNIFIED IDEOGRAPH-#2C0E3
2C0E4 CJK UNIFIED IDEOGRAPH-#2C0E4
2C0E5 CJK UNIFIED IDEOGRAPH-#2C0E5
2C0E6 CJK UNIFIED IDEOGRAPH-#2C0E6
2C0E7 CJK UNIFIED IDEOGRAPH-#2C0E7
2C0E8 CJK UNIFIED IDEOGRAPH-#2C0E8
2C0E9 CJK UNIFIED IDEOGRAPH-#2C0E9
2C0EA CJK UNIFIED IDEOGRAPH-#2C0EA
2C0EB CJK UNIFIED IDEOGRAPH-#2C0EB
2C0EC CJK UNIFIED IDEOGRAPH-#2C0EC
2C0ED CJK UNIFIED IDEOGRAPH-#2C0ED
2C0EE CJK UNIFIED IDEOGRAPH-#2C0EE
2C0EF CJK UNIFIED IDEOGRAPH-#2C0EF
2C0F0 CJK UNIFIED IDEOGRAPH-#2C0F0
2C0F1 CJK UNIFIED IDEOGRAPH-#2C0F1
2C0F2 CJK UNIFIED IDEOGRAPH-#2C0F2
2C0F3 CJK UNIFIED IDEOGRAPH-#2C0F3
2C0F4 CJK UNIFIED IDEOGRAPH-#2C0F4
2C0F5 CJK UNIFIED IDEOGRAPH-#2C0F5
2C0F6 CJK UNIFIED IDEOGRAPH-#2C0F6
2C0F7 CJK UNIFIED IDEOGRAPH-#2C0F7
2C0F8 CJK UNIFIED IDEOGRAPH-#2C0F8
2C0F9 CJK UNIFIED IDEOGRAPH-#2C0F9
2C0FA CJK UNIFIED IDEOGRAPH-#2C0FA
2C0FB CJK UNIFIED IDEOGRAPH-#2C0FB
2C0FC CJK UNIFIED IDEOGRAPH-#2C0FC
2C0FD CJK UNIFIED IDEOGRAPH-#2C0FD
2C0FE CJK UNIFIED IDEOGRAPH-#2C0FE
2C0FF CJK UNIFIED IDEOGRAPH-#2C0FF
2C100 CJK UNIFIED IDEOGRAPH-#2C100
2C101 CJK UNIFIED IDEOGRAPH-#2C101
2C102 CJK UNIFIED IDEOGRAPH-#2C102
2C103 CJK UNIFIED IDEOGRAPH-#2C103
2C104 CJK UNIFIED IDEOGRAPH-#2C104
2C105 CJK UNIFIED IDEOGRAPH-#2C105
2C106 CJK UNIFIED IDEOGRAPH-#2C106
2C107 CJK UNIFIED IDEOGRAPH-#2C107
2C108 CJK UNIFIED IDEOGRAPH-#2C108
2C109 CJK UNIFIED IDEOGRAPH-#2C109
2C10A CJK UNIFIED IDEOGRAPH-#2C10A
2C10B CJK UNIFIED IDEOGRAPH-#2C10B
2C10C CJK UNIFIED IDEOGRAPH-#2C10C
2C10D CJK UNIFIED IDEOGRAPH-#2C10D
2C10E CJK UNIFIED IDEOGRAPH-#2C10E
2C10F CJK UNIFIED IDEOGRAPH-#2C10F
2C110 CJK UNIFIED IDEOGRAPH-#2C110
2C111 CJK UNIFIED IDEOGRAPH-#2C111
2C112 CJK UNIFIED IDEOGRAPH-#2C112
2C113 CJK UNIFIED IDEOGRAPH-#2C113
2C114 CJK UNIFIED IDEOGRAPH-#2C114
2C115 CJK UNIFIED IDEOGRAPH-#2C115
2C116 CJK UNIFIED IDEOGRAPH-#2C116
2C117 CJK UNIFIED IDEOGRAPH-#2C117
2C118 CJK UNIFIED IDEOGRAPH-#2C118
2C119 CJK UNIFIED IDEOGRAPH-#2C119
2C11A CJK UNIFIED IDEOGRAPH-#2C11A
2C11B CJK UNIFIED IDEOGRAPH-#2C11B
2C11C CJK UNIFIED IDEOGRAPH-#2C11C
2C11D CJK UNIFIED IDEOGRAPH-#2C11D
2C11E CJK UNIFIED IDEOGRAPH-#2C11E
2C11F CJK UNIFIED IDEOGRAPH-#2C11F
2C120 CJK UNIFIED IDEOGRAPH-#2C120
2C121 CJK UNIFIED IDEOGRAPH-#2C121
2C122 CJK UNIFIED IDEOGRAPH-#2C122
2C123 CJK UNIFIED IDEOGRAPH-#2C123
2C124 CJK UNIFIED IDEOGRAPH-#2C124
2C125 CJK UNIFIED IDEOGRAPH-#2C125
2C126 CJK UNIFIED IDEOGRAPH-#2C126
2C127 CJK UNIFIED IDEOGRAPH-#2C127
2C128 CJK UNIFIED IDEOGRAPH-#2C128
2C129 CJK UNIFIED IDEOGRAPH-#2C129
2C12A CJK UNIFIED IDEOGRAPH-#2C12A
2C12B CJK UNIFIED IDEOGRAPH-#2C12B
2C12C CJK UNIFIED IDEOGRAPH-#2C12C
2C12D CJK UNIFIED IDEOGRAPH-#2C12D
2C12E CJK UNIFIED IDEOGRAPH-#2C12E
2C12F CJK UNIFIED IDEOGRAPH-#2C12F
2C130 CJK UNIFIED IDEOGRAPH-#2C130
2C131 CJK UNIFIED IDEOGRAPH-#2C131
2C132 CJK UNIFIED IDEOGRAPH-#2C132
2C133 CJK UNIFIED IDEOGRAPH-#2C133
2C134 CJK UNIFIED IDEOGRAPH-#2C134
2C135 CJK UNIFIED IDEOGRAPH-#2C135
2C136 CJK UNIFIED IDEOGRAPH-#2C136
2C137 CJK UNIFIED IDEOGRAPH-#2C137
2C138 CJK UNIFIED IDEOGRAPH-#2C138
2C139 CJK UNIFIED IDEOGRAPH-#2C139
2C13A CJK UNIFIED IDEOGRAPH-#2C13A
2C13B CJK UNIFIED IDEOGRAPH-#2C13B
2C13C CJK UNIFIED IDEOGRAPH-#2C13C
2C13D CJK UNIFIED IDEOGRAPH-#2C13D
2C13E CJK UNIFIED IDEOGRAPH-#2C13E
2C13F CJK UNIFIED IDEOGRAPH-#2C13F
2C140 CJK UNIFIED IDEOGRAPH-#2C140
2C141 CJK UNIFIED IDEOGRAPH-#2C141
2C142 CJK UNIFIED IDEOGRAPH-#2C142
2C143 CJK UNIFIED IDEOGRAPH-#2C143
2C144 CJK UNIFIED IDEOGRAPH-#2C144
2C145 CJK UNIFIED IDEOGRAPH-#2C145
2C146 CJK UNIFIED IDEOGRAPH-#2C146
2C147 CJK UNIFIED IDEOGRAPH-#2C147
2C148 CJK UNIFIED IDEOGRAPH-#2C148
2C149 CJK UNIFIED IDEOGRAPH-#2C149
2C14A CJK UNIFIED IDEOGRAPH-#2C14A
2C14B CJK UNIFIED IDEOGRAPH-#2C14B
2C14C CJK UNIFIED IDEOGRAPH-#2C14C
2C14D CJK UNIFIED IDEOGRAPH-#2C14D
2C14E CJK UNIFIED IDEOGRAPH-#2C14E
2C14F CJK UNIFIED IDEOGRAPH-#2C14F
2C150 CJK UNIFIED IDEOGRAPH-#2C150
2C151 CJK UNIFIED IDEOGRAPH-#2C151
2C152 CJK UNIFIED IDEOGRAPH-#2C152
2C153 CJK UNIFIED IDEOGRAPH-#2C153
2C154 CJK UNIFIED IDEOGRAPH-#2C154
2C155 CJK UNIFIED IDEOGRAPH-#2C155
2C156 CJK UNIFIED IDEOGRAPH-#2C156
2C157 CJK UNIFIED IDEOGRAPH-#2C157
2C158 CJK UNIFIED IDEOGRAPH-#2C158
2C159 CJK UNIFIED IDEOGRAPH-#2C159
2C15A CJK UNIFIED IDEOGRAPH-#2C15A
2C15B CJK UNIFIED IDEOGRAPH-#2C15B
2C15C CJK UNIFIED IDEOGRAPH-#2C15C
2C15D CJK UNIFIED IDEOGRAPH-#2C15D
2C15E CJK UNIFIED IDEOGRAPH-#2C15E
2C15F CJK UNIFIED IDEOGRAPH-#2C15F
2C160 CJK UNIFIED IDEOGRAPH-#2C160
2C161 CJK UNIFIED IDEOGRAPH-#2C161
2C162 CJK UNIFIED IDEOGRAPH-#2C162
2C163 CJK UNIFIED IDEOGRAPH-#2C163
2C164 CJK UNIFIED IDEOGRAPH-#2C164
2C165 CJK UNIFIED IDEOGRAPH-#2C165
2C166 CJK UNIFIED IDEOGRAPH-#2C166
2C167 CJK UNIFIED IDEOGRAPH-#2C167
2C168 CJK UNIFIED IDEOGRAPH-#2C168
2C169 CJK UNIFIED IDEOGRAPH-#2C169
2C16A CJK UNIFIED IDEOGRAPH-#2C16A
2C16B CJK UNIFIED IDEOGRAPH-#2C16B
2C16C CJK UNIFIED IDEOGRAPH-#2C16C
2C16D CJK UNIFIED IDEOGRAPH-#2C16D
2C16E CJK UNIFIED IDEOGRAPH-#2C16E
2C16F CJK UNIFIED IDEOGRAPH-#2C16F
2C170 CJK UNIFIED IDEOGRAPH-#2C170
2C171 CJK UNIFIED IDEOGRAPH-#2C171
2C172 CJK UNIFIED IDEOGRAPH-#2C172
2C173 CJK UNIFIED IDEOGRAPH-#2C173
2C174 CJK UNIFIED IDEOGRAPH-#2C174
2C175 CJK UNIFIED IDEOGRAPH-#2C175
2C176 CJK UNIFIED IDEOGRAPH-#2C176
2C177 CJK UNIFIED IDEOGRAPH-#2C177
2C178 CJK UNIFIED IDEOGRAPH-#2C178
2C179 CJK UNIFIED IDEOGRAPH-#2C179
2C17A CJK UNIFIED IDEOGRAPH-#2C17A
2C17B CJK UNIFIED IDEOGRAPH-#2C17B
2C17C CJK UNIFIED IDEOGRAPH-#2C17C
2C17D CJK UNIFIED IDEOGRAPH-#2C17D
2C17E CJK UNIFIED IDEOGRAPH-#2C17E
2C17F CJK UNIFIED IDEOGRAPH-#2C17F
2C180 CJK UNIFIED IDEOGRAPH-#2C180
2C181 CJK UNIFIED IDEOGRAPH-#2C181
2C182 CJK UNIFIED IDEOGRAPH-#2C182
2C183 CJK UNIFIED IDEOGRAPH-#2C183
2C184 CJK UNIFIED IDEOGRAPH-#2C184
2C185 CJK UNIFIED IDEOGRAPH-#2C185
2C186 CJK UNIFIED IDEOGRAPH-#2C186
2C187 CJK UNIFIED IDEOGRAPH-#2C187
2C188 CJK UNIFIED IDEOGRAPH-#2C188
2C189 CJK UNIFIED IDEOGRAPH-#2C189
2C18A CJK UNIFIED IDEOGRAPH-#2C18A
2C18B CJK UNIFIED IDEOGRAPH-#2C18B
2C18C CJK UNIFIED IDEOGRAPH-#2C18C
2C18D CJK UNIFIED IDEOGRAPH-#2C18D
2C18E CJK UNIFIED IDEOGRAPH-#2C18E
2C18F CJK UNIFIED IDEOGRAPH-#2C18F
2C190 CJK UNIFIED IDEOGRAPH-#2C190
2C191 CJK UNIFIED IDEOGRAPH-#2C191
2C192 CJK UNIFIED IDEOGRAPH-#2C192
2C193 CJK UNIFIED IDEOGRAPH-#2C193
2C194 CJK UNIFIED IDEOGRAPH-#2C194
2C195 CJK UNIFIED IDEOGRAPH-#2C195
2C196 CJK UNIFIED IDEOGRAPH-#2C196
2C197 CJK UNIFIED IDEOGRAPH-#2C197
2C198 CJK UNIFIED IDEOGRAPH-#2C198
2C199 CJK UNIFIED IDEOGRAPH-#2C199
2C19A CJK UNIFIED IDEOGRAPH-#2C19A
2C19B CJK UNIFIED IDEOGRAPH-#2C19B
2C19C CJK UNIFIED IDEOGRAPH-#2C19C
2C19D CJK UNIFIED IDEOGRAPH-#2C19D
2C19E CJK UNIFIED IDEOGRAPH-#2C19E
2C19F CJK UNIFIED IDEOGRAPH-#2C19F
2C1A0 CJK UNIFIED IDEOGRAPH-#2C1A0
2C1A1 CJK UNIFIED IDEOGRAPH-#2C1A1
2C1A2 CJK UNIFIED IDEOGRAPH-#2C1A2
2C1A3 CJK UNIFIED IDEOGRAPH-#2C1A3
2C1A4 CJK UNIFIED IDEOGRAPH-#2C1A4
2C1A5 CJK UNIFIED IDEOGRAPH-#2C1A5
2C1A6 CJK UNIFIED IDEOGRAPH-#2C1A6
2C1A7 CJK UNIFIED IDEOGRAPH-#2C1A7
2C1A8 CJK UNIFIED IDEOGRAPH-#2C1A8
2C1A9 CJK UNIFIED IDEOGRAPH-#2C1A9
2C1AA CJK UNIFIED IDEOGRAPH-#2C1AA
2C1AB CJK UNIFIED IDEOGRAPH-#2C1AB
2C1AC CJK UNIFIED IDEOGRAPH-#2C1AC
2C1AD CJK UNIFIED IDEOGRAPH-#2C1AD
2C1AE CJK UNIFIED IDEOGRAPH-#2C1AE
2C1AF CJK UNIFIED IDEOGRAPH-#2C1AF
2C1B0 CJK UNIFIED IDEOGRAPH-#2C1B0
2C1B1 CJK UNIFIED IDEOGRAPH-#2C1B1
2C1B2 CJK UNIFIED IDEOGRAPH-#2C1B2
2C1B3 CJK UNIFIED IDEOGRAPH-#2C1B3
2C1B4 CJK UNIFIED IDEOGRAPH-#2C1B4
2C1B5 CJK UNIFIED IDEOGRAPH-#2C1B5
2C1B6 CJK UNIFIED IDEOGRAPH-#2C1B6
2C1B7 CJK UNIFIED IDEOGRAPH-#2C1B7
2C1B8 CJK UNIFIED IDEOGRAPH-#2C1B8
2C1B9 CJK UNIFIED IDEOGRAPH-#2C1B9
2C1BA CJK UNIFIED IDEOGRAPH-#2C1BA
2C1BB CJK UNIFIED IDEOGRAPH-#2C1BB
2C1BC CJK UNIFIED IDEOGRAPH-#2C1BC
2C1BD CJK UNIFIED IDEOGRAPH-#2C1BD
2C1BE CJK UNIFIED IDEOGRAPH-#2C1BE
2C1BF CJK UNIFIED IDEOGRAPH-#2C1BF
2C1C0 CJK UNIFIED IDEOGRAPH-#2C1C0
2C1C1 CJK UNIFIED IDEOGRAPH-#2C1C1
2C1C2 CJK UNIFIED IDEOGRAPH-#2C1C2
2C1C3 CJK UNIFIED IDEOGRAPH-#2C1C3
2C1C4 CJK UNIFIED IDEOGRAPH-#2C1C4
2C1C5 CJK UNIFIED IDEOGRAPH-#2C1C5
2C1C6 CJK UNIFIED IDEOGRAPH-#2C1C6
2C1C7 CJK UNIFIED IDEOGRAPH-#2C1C7
2C1C8 CJK UNIFIED IDEOGRAPH-#2C1C8
2C1C9 CJK UNIFIED IDEOGRAPH-#2C1C9
2C1CA CJK UNIFIED IDEOGRAPH-#2C1CA
2C1CB CJK UNIFIED IDEOGRAPH-#2C1CB
2C1CC CJK UNIFIED IDEOGRAPH-#2C1CC
2C1CD CJK UNIFIED IDEOGRAPH-#2C1CD
2C1CE CJK UNIFIED IDEOGRAPH-#2C1CE
2C1CF CJK UNIFIED IDEOGRAPH-#2C1CF
2C1D0 CJK UNIFIED IDEOGRAPH-#2C1D0
2C1D1 CJK UNIFIED IDEOGRAPH-#2C1D1
2C1D2 CJK UNIFIED IDEOGRAPH-#2C1D2
2C1D3 CJK UNIFIED IDEOGRAPH-#2C1D3
2C1D4 CJK UNIFIED IDEOGRAPH-#2C1D4
2C1D5 CJK UNIFIED IDEOGRAPH-#2C1D5
2C1D6 CJK UNIFIED IDEOGRAPH-#2C1D6
2C1D7 CJK UNIFIED IDEOGRAPH-#2C1D7
2C1D8 CJK UNIFIED IDEOGRAPH-#2C1D8
2C1D9 CJK UNIFIED IDEOGRAPH-#2C1D9
2C1DA CJK UNIFIED IDEOGRAPH-#2C1DA
2C1DB CJK UNIFIED IDEOGRAPH-#2C1DB
2C1DC CJK UNIFIED IDEOGRAPH-#2C1DC
2C1DD CJK UNIFIED IDEOGRAPH-#2C1DD
2C1DE CJK UNIFIED IDEOGRAPH-#2C1DE
2C1DF CJK UNIFIED IDEOGRAPH-#2C1DF
2C1E0 CJK UNIFIED IDEOGRAPH-#2C1E0
2C1E1 CJK UNIFIED IDEOGRAPH-#2C1E1
2C1E2 CJK UNIFIED IDEOGRAPH-#2C1E2
2C1E3 CJK UNIFIED IDEOGRAPH-#2C1E3
2C1E4 CJK UNIFIED IDEOGRAPH-#2C1E4
2C1E5 CJK UNIFIED IDEOGRAPH-#2C1E5
2C1E6 CJK UNIFIED IDEOGRAPH-#2C1E6
2C1E7 CJK UNIFIED IDEOGRAPH-#2C1E7
2C1E8 CJK UNIFIED IDEOGRAPH-#2C1E8
2C1E9 CJK UNIFIED IDEOGRAPH-#2C1E9
2C1EA CJK UNIFIED IDEOGRAPH-#2C1EA
2C1EB CJK UNIFIED IDEOGRAPH-#2C1EB
2C1EC CJK UNIFIED IDEOGRAPH-#2C1EC
2C1ED CJK UNIFIED IDEOGRAPH-#2C1ED
2C1EE CJK UNIFIED IDEOGRAPH-#2C1EE
2C1EF CJK UNIFIED IDEOGRAPH-#2C1EF
2C1F0 CJK UNIFIED IDEOGRAPH-#2C1F0
2C1F1 CJK UNIFIED IDEOGRAPH-#2C1F1
2C1F2 CJK UNIFIED IDEOGRAPH-#2C1F2
2C1F3 CJK UNIFIED IDEOGRAPH-#2C1F3
2C1F4 CJK UNIFIED IDEOGRAPH-#2C1F4
2C1F5 CJK UNIFIED IDEOGRAPH-#2C1F5
2C1F6 CJK UNIFIED IDEOGRAPH-#2C1F6
2C1F7 CJK UNIFIED IDEOGRAPH-#2C1F7
2C1F8 CJK UNIFIED IDEOGRAPH-#2C1F8
2C1F9 CJK UNIFIED IDEOGRAPH-#2C1F9
2C1FA CJK UNIFIED IDEOGRAPH-#2C1FA
2C1FB CJK UNIFIED IDEOGRAPH-#2C1FB
2C1FC CJK UNIFIED IDEOGRAPH-#2C1FC
2C1FD CJK UNIFIED IDEOGRAPH-#2C1FD
2C1FE CJK UNIFIED IDEOGRAPH-#2C1FE
2C1FF CJK UNIFIED IDEOGRAPH-#2C1FF
2C200 CJK UNIFIED IDEOGRAPH-#2C200
2C201 CJK UNIFIED IDEOGRAPH-#2C201
2C202 CJK UNIFIED IDEOGRAPH-#2C202
2C203 CJK UNIFIED IDEOGRAPH-#2C203
2C204 CJK UNIFIED IDEOGRAPH-#2C204
2C205 CJK UNIFIED IDEOGRAPH-#2C205
2C206 CJK UNIFIED IDEOGRAPH-#2C206
2C207 CJK UNIFIED IDEOGRAPH-#2C207
2C208 CJK UNIFIED IDEOGRAPH-#2C208
2C209 CJK UNIFIED IDEOGRAPH-#2C209
2C20A CJK UNIFIED IDEOGRAPH-#2C20A
2C20B CJK UNIFIED IDEOGRAPH-#2C20B
2C20C CJK UNIFIED IDEOGRAPH-#2C20C
2C20D CJK UNIFIED IDEOGRAPH-#2C20D
2C20E CJK UNIFIED IDEOGRAPH-#2C20E
2C20F CJK UNIFIED IDEOGRAPH-#2C20F
2C210 CJK UNIFIED IDEOGRAPH-#2C210
2C211 CJK UNIFIED IDEOGRAPH-#2C211
2C212 CJK UNIFIED IDEOGRAPH-#2C212
2C213 CJK UNIFIED IDEOGRAPH-#2C213
2C214 CJK UNIFIED IDEOGRAPH-#2C214
2C215 CJK UNIFIED IDEOGRAPH-#2C215
2C216 CJK UNIFIED IDEOGRAPH-#2C216
2C217 CJK UNIFIED IDEOGRAPH-#2C217
2C218 CJK UNIFIED IDEOGRAPH-#2C218
2C219 CJK UNIFIED IDEOGRAPH-#2C219
2C21A CJK UNIFIED IDEOGRAPH-#2C21A
2C21B CJK UNIFIED IDEOGRAPH-#2C21B
2C21C CJK UNIFIED IDEOGRAPH-#2C21C
2C21D CJK UNIFIED IDEOGRAPH-#2C21D
2C21E CJK UNIFIED IDEOGRAPH-#2C21E
2C21F CJK UNIFIED IDEOGRAPH-#2C21F
2C220 CJK UNIFIED IDEOGRAPH-#2C220
2C221 CJK UNIFIED IDEOGRAPH-#2C221
2C222 CJK UNIFIED IDEOGRAPH-#2C222
2C223 CJK UNIFIED IDEOGRAPH-#2C223
2C224 CJK UNIFIED IDEOGRAPH-#2C224
2C225 CJK UNIFIED IDEOGRAPH-#2C225
2C226 CJK UNIFIED IDEOGRAPH-#2C226
2C227 CJK UNIFIED IDEOGRAPH-#2C227
2C228 CJK UNIFIED IDEOGRAPH-#2C228
2C229 CJK UNIFIED IDEOGRAPH-#2C229
2C22A CJK UNIFIED IDEOGRAPH-#2C22A
2C22B CJK UNIFIED IDEOGRAPH-#2C22B
2C22C CJK UNIFIED IDEOGRAPH-#2C22C
2C22D CJK UNIFIED IDEOGRAPH-#2C22D
2C22E CJK UNIFIED IDEOGRAPH-#2C22E
2C22F CJK UNIFIED IDEOGRAPH-#2C22F
2C230 CJK UNIFIED IDEOGRAPH-#2C230
2C231 CJK UNIFIED IDEOGRAPH-#2C231
2C232 CJK UNIFIED IDEOGRAPH-#2C232
2C233 CJK UNIFIED IDEOGRAPH-#2C233
2C234 CJK UNIFIED IDEOGRAPH-#2C234
2C235 CJK UNIFIED IDEOGRAPH-#2C235
2C236 CJK UNIFIED IDEOGRAPH-#2C236
2C237 CJK UNIFIED IDEOGRAPH-#2C237
2C238 CJK UNIFIED IDEOGRAPH-#2C238
2C239 CJK UNIFIED IDEOGRAPH-#2C239
2C23A CJK UNIFIED IDEOGRAPH-#2C23A
2C23B CJK UNIFIED IDEOGRAPH-#2C23B
2C23C CJK UNIFIED IDEOGRAPH-#2C23C
2C23D CJK UNIFIED IDEOGRAPH-#2C23D
2C23E CJK UNIFIED IDEOGRAPH-#2C23E
2C23F CJK UNIFIED IDEOGRAPH-#2C23F
2C240 CJK UNIFIED IDEOGRAPH-#2C240
2C241 CJK UNIFIED IDEOGRAPH-#2C241
2C242 CJK UNIFIED IDEOGRAPH-#2C242
2C243 CJK UNIFIED IDEOGRAPH-#2C243
2C244 CJK UNIFIED IDEOGRAPH-#2C244
2C245 CJK UNIFIED IDEOGRAPH-#2C245
2C246 CJK UNIFIED IDEOGRAPH-#2C246
2C247 CJK UNIFIED IDEOGRAPH-#2C247
2C248 CJK UNIFIED IDEOGRAPH-#2C248
2C249 CJK UNIFIED IDEOGRAPH-#2C249
2C24A CJK UNIFIED IDEOGRAPH-#2C24A
2C24B CJK UNIFIED IDEOGRAPH-#2C24B
2C24C CJK UNIFIED IDEOGRAPH-#2C24C
2C24D CJK UNIFIED IDEOGRAPH-#2C24D
2C24E CJK UNIFIED IDEOGRAPH-#2C24E
2C24F CJK UNIFIED IDEOGRAPH-#2C24F
2C250 CJK UNIFIED IDEOGRAPH-#2C250
2C251 CJK UNIFIED IDEOGRAPH-#2C251
2C252 CJK UNIFIED IDEOGRAPH-#2C252
2C253 CJK UNIFIED IDEOGRAPH-#2C253
2C254 CJK UNIFIED IDEOGRAPH-#2C254
2C255 CJK UNIFIED IDEOGRAPH-#2C255
2C256 CJK UNIFIED IDEOGRAPH-#2C256
2C257 CJK UNIFIED IDEOGRAPH-#2C257
2C258 CJK UNIFIED IDEOGRAPH-#2C258
2C259 CJK UNIFIED IDEOGRAPH-#2C259
2C25A CJK UNIFIED IDEOGRAPH-#2C25A
2C25B CJK UNIFIED IDEOGRAPH-#2C25B
2C25C CJK UNIFIED IDEOGRAPH-#2C25C
2C25D CJK UNIFIED IDEOGRAPH-#2C25D
2C25E CJK UNIFIED IDEOGRAPH-#2C25E
2C25F CJK UNIFIED IDEOGRAPH-#2C25F
2C260 CJK UNIFIED IDEOGRAPH-#2C260
2C261 CJK UNIFIED IDEOGRAPH-#2C261
2C262 CJK UNIFIED IDEOGRAPH-#2C262
2C263 CJK UNIFIED IDEOGRAPH-#2C263
2C264 CJK UNIFIED IDEOGRAPH-#2C264
2C265 CJK UNIFIED IDEOGRAPH-#2C265
2C266 CJK UNIFIED IDEOGRAPH-#2C266
2C267 CJK UNIFIED IDEOGRAPH-#2C267
2C268 CJK UNIFIED IDEOGRAPH-#2C268
2C269 CJK UNIFIED IDEOGRAPH-#2C269
2C26A CJK UNIFIED IDEOGRAPH-#2C26A
2C26B CJK UNIFIED IDEOGRAPH-#2C26B
2C26C CJK UNIFIED IDEOGRAPH-#2C26C
2C26D CJK UNIFIED IDEOGRAPH-#2C26D
2C26E CJK UNIFIED IDEOGRAPH-#2C26E
2C26F CJK UNIFIED IDEOGRAPH-#2C26F
2C270 CJK UNIFIED IDEOGRAPH-#2C270
2C271 CJK UNIFIED IDEOGRAPH-#2C271
2C272 CJK UNIFIED IDEOGRAPH-#2C272
2C273 CJK UNIFIED IDEOGRAPH-#2C273
2C274 CJK UNIFIED IDEOGRAPH-#2C274
2C275 CJK UNIFIED IDEOGRAPH-#2C275
2C276 CJK UNIFIED IDEOGRAPH-#2C276
2C277 CJK UNIFIED IDEOGRAPH-#2C277
2C278 CJK UNIFIED IDEOGRAPH-#2C278
2C279 CJK UNIFIED IDEOGRAPH-#2C279
2C27A CJK UNIFIED IDEOGRAPH-#2C27A
2C27B CJK UNIFIED IDEOGRAPH-#2C27B
2C27C CJK UNIFIED IDEOGRAPH-#2C27C
2C27D CJK UNIFIED IDEOGRAPH-#2C27D
2C27E CJK UNIFIED IDEOGRAPH-#2C27E
2C27F CJK UNIFIED IDEOGRAPH-#2C27F
2C280 CJK UNIFIED IDEOGRAPH-#2C280
2C281 CJK UNIFIED IDEOGRAPH-#2C281
2C282 CJK UNIFIED IDEOGRAPH-#2C282
2C283 CJK UNIFIED IDEOGRAPH-#2C283
2C284 CJK UNIFIED IDEOGRAPH-#2C284
2C285 CJK UNIFIED IDEOGRAPH-#2C285
2C286 CJK UNIFIED IDEOGRAPH-#2C286
2C287 CJK UNIFIED IDEOGRAPH-#2C287
2C288 CJK UNIFIED IDEOGRAPH-#2C288
2C289 CJK UNIFIED IDEOGRAPH-#2C289
2C28A CJK UNIFIED IDEOGRAPH-#2C28A
2C28B CJK UNIFIED IDEOGRAPH-#2C28B
2C28C CJK UNIFIED IDEOGRAPH-#2C28C
2C28D CJK UNIFIED IDEOGRAPH-#2C28D
2C28E CJK UNIFIED IDEOGRAPH-#2C28E
2C28F CJK UNIFIED IDEOGRAPH-#2C28F
2C290 CJK UNIFIED IDEOGRAPH-#2C290
2C291 CJK UNIFIED IDEOGRAPH-#2C291
2C292 CJK UNIFIED IDEOGRAPH-#2C292
2C293 CJK UNIFIED IDEOGRAPH-#2C293
2C294 CJK UNIFIED IDEOGRAPH-#2C294
2C295 CJK UNIFIED IDEOGRAPH-#2C295
2C296 CJK UNIFIED IDEOGRAPH-#2C296
2C297 CJK UNIFIED IDEOGRAPH-#2C297
2C298 CJK UNIFIED IDEOGRAPH-#2C298
2C299 CJK UNIFIED IDEOGRAPH-#2C299
2C29A CJK UNIFIED IDEOGRAPH-#2C29A
2C29B CJK UNIFIED IDEOGRAPH-#2C29B
2C29C CJK UNIFIED IDEOGRAPH-#2C29C
2C29D CJK UNIFIED IDEOGRAPH-#2C29D
2C29E CJK UNIFIED IDEOGRAPH-#2C29E
2C29F CJK UNIFIED IDEOGRAPH-#2C29F
2C2A0 CJK UNIFIED IDEOGRAPH-#2C2A0
2C2A1 CJK UNIFIED IDEOGRAPH-#2C2A1
2C2A2 CJK UNIFIED IDEOGRAPH-#2C2A2
2C2A3 CJK UNIFIED IDEOGRAPH-#2C2A3
2C2A4 CJK UNIFIED IDEOGRAPH-#2C2A4
2C2A5 CJK UNIFIED IDEOGRAPH-#2C2A5
2C2A6 CJK UNIFIED IDEOGRAPH-#2C2A6
2C2A7 CJK UNIFIED IDEOGRAPH-#2C2A7
2C2A8 CJK UNIFIED IDEOGRAPH-#2C2A8
2C2A9 CJK UNIFIED IDEOGRAPH-#2C2A9
2C2AA CJK UNIFIED IDEOGRAPH-#2C2AA
2C2AB CJK UNIFIED IDEOGRAPH-#2C2AB
2C2AC CJK UNIFIED IDEOGRAPH-#2C2AC
2C2AD CJK UNIFIED IDEOGRAPH-#2C2AD
2C2AE CJK UNIFIED IDEOGRAPH-#2C2AE
2C2AF CJK UNIFIED IDEOGRAPH-#2C2AF
2C2B0 CJK UNIFIED IDEOGRAPH-#2C2B0
2C2B1 CJK UNIFIED IDEOGRAPH-#2C2B1
2C2B2 CJK UNIFIED IDEOGRAPH-#2C2B2
2C2B3 CJK UNIFIED IDEOGRAPH-#2C2B3
2C2B4 CJK UNIFIED IDEOGRAPH-#2C2B4
2C2B5 CJK UNIFIED IDEOGRAPH-#2C2B5
2C2B6 CJK UNIFIED IDEOGRAPH-#2C2B6
2C2B7 CJK UNIFIED IDEOGRAPH-#2C2B7
2C2B8 CJK UNIFIED IDEOGRAPH-#2C2B8
2C2B9 CJK UNIFIED IDEOGRAPH-#2C2B9
2C2BA CJK UNIFIED IDEOGRAPH-#2C2BA
2C2BB CJK UNIFIED IDEOGRAPH-#2C2BB
2C2BC CJK UNIFIED IDEOGRAPH-#2C2BC
2C2BD CJK UNIFIED IDEOGRAPH-#2C2BD
2C2BE CJK UNIFIED IDEOGRAPH-#2C2BE
2C2BF CJK UNIFIED IDEOGRAPH-#2C2BF
2C2C0 CJK UNIFIED IDEOGRAPH-#2C2C0
2C2C1 CJK UNIFIED IDEOGRAPH-#2C2C1
2C2C2 CJK UNIFIED IDEOGRAPH-#2C2C2
2C2C3 CJK UNIFIED IDEOGRAPH-#2C2C3
2C2C4 CJK UNIFIED IDEOGRAPH-#2C2C4
2C2C5 CJK UNIFIED IDEOGRAPH-#2C2C5
2C2C6 CJK UNIFIED IDEOGRAPH-#2C2C6
2C2C7 CJK UNIFIED IDEOGRAPH-#2C2C7
2C2C8 CJK UNIFIED IDEOGRAPH-#2C2C8
2C2C9 CJK UNIFIED IDEOGRAPH-#2C2C9
2C2CA CJK UNIFIED IDEOGRAPH-#2C2CA
2C2CB CJK UNIFIED IDEOGRAPH-#2C2CB
2C2CC CJK UNIFIED IDEOGRAPH-#2C2CC
2C2CD CJK UNIFIED IDEOGRAPH-#2C2CD
2C2CE CJK UNIFIED IDEOGRAPH-#2C2CE
2C2CF CJK UNIFIED IDEOGRAPH-#2C2CF
2C2D0 CJK UNIFIED IDEOGRAPH-#2C2D0
2C2D1 CJK UNIFIED IDEOGRAPH-#2C2D1
2C2D2 CJK UNIFIED IDEOGRAPH-#2C2D2
2C2D3 CJK UNIFIED IDEOGRAPH-#2C2D3
2C2D4 CJK UNIFIED IDEOGRAPH-#2C2D4
2C2D5 CJK UNIFIED IDEOGRAPH-#2C2D5
2C2D6 CJK UNIFIED IDEOGRAPH-#2C2D6
2C2D7 CJK UNIFIED IDEOGRAPH-#2C2D7
2C2D8 CJK UNIFIED IDEOGRAPH-#2C2D8
2C2D9 CJK UNIFIED IDEOGRAPH-#2C2D9
2C2DA CJK UNIFIED IDEOGRAPH-#2C2DA
2C2DB CJK UNIFIED IDEOGRAPH-#2C2DB
2C2DC CJK UNIFIED IDEOGRAPH-#2C2DC
2C2DD CJK UNIFIED IDEOGRAPH-#2C2DD
2C2DE CJK UNIFIED IDEOGRAPH-#2C2DE
2C2DF CJK UNIFIED IDEOGRAPH-#2C2DF
2C2E0 CJK UNIFIED IDEOGRAPH-#2C2E0
2C2E1 CJK UNIFIED IDEOGRAPH-#2C2E1
2C2E2 CJK UNIFIED IDEOGRAPH-#2C2E2
2C2E3 CJK UNIFIED IDEOGRAPH-#2C2E3
2C2E4 CJK UNIFIED IDEOGRAPH-#2C2E4
2C2E5 CJK UNIFIED IDEOGRAPH-#2C2E5
2C2E6 CJK UNIFIED IDEOGRAPH-#2C2E6
2C2E7 CJK UNIFIED IDEOGRAPH-#2C2E7
2C2E8 CJK UNIFIED IDEOGRAPH-#2C2E8
2C2E9 CJK UNIFIED IDEOGRAPH-#2C2E9
2C2EA CJK UNIFIED IDEOGRAPH-#2C2EA
2C2EB CJK UNIFIED IDEOGRAPH-#2C2EB
2C2EC CJK UNIFIED IDEOGRAPH-#2C2EC
2C2ED CJK UNIFIED IDEOGRAPH-#2C2ED
2C2EE CJK UNIFIED IDEOGRAPH-#2C2EE
2C2EF CJK UNIFIED IDEOGRAPH-#2C2EF
2C2F0 CJK UNIFIED IDEOGRAPH-#2C2F0
2C2F1 CJK UNIFIED IDEOGRAPH-#2C2F1
2C2F2 CJK UNIFIED IDEOGRAPH-#2C2F2
2C2F3 CJK UNIFIED IDEOGRAPH-#2C2F3
2C2F4 CJK UNIFIED IDEOGRAPH-#2C2F4
2C2F5 CJK UNIFIED IDEOGRAPH-#2C2F5
2C2F6 CJK UNIFIED IDEOGRAPH-#2C2F6
2C2F7 CJK UNIFIED IDEOGRAPH-#2C2F7
2C2F8 CJK UNIFIED IDEOGRAPH-#2C2F8
2C2F9 CJK UNIFIED IDEOGRAPH-#2C2F9
2C2FA CJK UNIFIED IDEOGRAPH-#2C2FA
2C2FB CJK UNIFIED IDEOGRAPH-#2C2FB
2C2FC CJK UNIFIED IDEOGRAPH-#2C2FC
2C2FD CJK UNIFIED IDEOGRAPH-#2C2FD
2C2FE CJK UNIFIED IDEOGRAPH-#2C2FE
2C2FF CJK UNIFIED IDEOGRAPH-#2C2FF
2C300 CJK UNIFIED IDEOGRAPH-#2C300
2C301 CJK UNIFIED IDEOGRAPH-#2C301
2C302 CJK UNIFIED IDEOGRAPH-#2C302
2C303 CJK UNIFIED IDEOGRAPH-#2C303
2C304 CJK UNIFIED IDEOGRAPH-#2C304
2C305 CJK UNIFIED IDEOGRAPH-#2C305
2C306 CJK UNIFIED IDEOGRAPH-#2C306
2C307 CJK UNIFIED IDEOGRAPH-#2C307
2C308 CJK UNIFIED IDEOGRAPH-#2C308
2C309 CJK UNIFIED IDEOGRAPH-#2C309
2C30A CJK UNIFIED IDEOGRAPH-#2C30A
2C30B CJK UNIFIED IDEOGRAPH-#2C30B
2C30C CJK UNIFIED IDEOGRAPH-#2C30C
2C30D CJK UNIFIED IDEOGRAPH-#2C30D
2C30E CJK UNIFIED IDEOGRAPH-#2C30E
2C30F CJK UNIFIED IDEOGRAPH-#2C30F
2C310 CJK UNIFIED IDEOGRAPH-#2C310
2C311 CJK UNIFIED IDEOGRAPH-#2C311
2C312 CJK UNIFIED IDEOGRAPH-#2C312
2C313 CJK UNIFIED IDEOGRAPH-#2C313
2C314 CJK UNIFIED IDEOGRAPH-#2C314
2C315 CJK UNIFIED IDEOGRAPH-#2C315
2C316 CJK UNIFIED IDEOGRAPH-#2C316
2C317 CJK UNIFIED IDEOGRAPH-#2C317
2C318 CJK UNIFIED IDEOGRAPH-#2C318
2C319 CJK UNIFIED IDEOGRAPH-#2C319
2C31A CJK UNIFIED IDEOGRAPH-#2C31A
2C31B CJK UNIFIED IDEOGRAPH-#2C31B
2C31C CJK UNIFIED IDEOGRAPH-#2C31C
2C31D CJK UNIFIED IDEOGRAPH-#2C31D
2C31E CJK UNIFIED IDEOGRAPH-#2C31E
2C31F CJK UNIFIED IDEOGRAPH-#2C31F
2C320 CJK UNIFIED IDEOGRAPH-#2C320
2C321 CJK UNIFIED IDEOGRAPH-#2C321
2C322 CJK UNIFIED IDEOGRAPH-#2C322
2C323 CJK UNIFIED IDEOGRAPH-#2C323
2C324 CJK UNIFIED IDEOGRAPH-#2C324
2C325 CJK UNIFIED IDEOGRAPH-#2C325
2C326 CJK UNIFIED IDEOGRAPH-#2C326
2C327 CJK UNIFIED IDEOGRAPH-#2C327
2C328 CJK UNIFIED IDEOGRAPH-#2C328
2C329 CJK UNIFIED IDEOGRAPH-#2C329
2C32A CJK UNIFIED IDEOGRAPH-#2C32A
2C32B CJK UNIFIED IDEOGRAPH-#2C32B
2C32C CJK UNIFIED IDEOGRAPH-#2C32C
2C32D CJK UNIFIED IDEOGRAPH-#2C32D
2C32E CJK UNIFIED IDEOGRAPH-#2C32E
2C32F CJK UNIFIED IDEOGRAPH-#2C32F
2C330 CJK UNIFIED IDEOGRAPH-#2C330
2C331 CJK UNIFIED IDEOGRAPH-#2C331
2C332 CJK UNIFIED IDEOGRAPH-#2C332
2C333 CJK UNIFIED IDEOGRAPH-#2C333
2C334 CJK UNIFIED IDEOGRAPH-#2C334
2C335 CJK UNIFIED IDEOGRAPH-#2C335
2C336 CJK UNIFIED IDEOGRAPH-#2C336
2C337 CJK UNIFIED IDEOGRAPH-#2C337
2C338 CJK UNIFIED IDEOGRAPH-#2C338
2C339 CJK UNIFIED IDEOGRAPH-#2C339
2C33A CJK UNIFIED IDEOGRAPH-#2C33A
2C33B CJK UNIFIED IDEOGRAPH-#2C33B
2C33C CJK UNIFIED IDEOGRAPH-#2C33C
2C33D CJK UNIFIED IDEOGRAPH-#2C33D
2C33E CJK UNIFIED IDEOGRAPH-#2C33E
2C33F CJK UNIFIED IDEOGRAPH-#2C33F
2C340 CJK UNIFIED IDEOGRAPH-#2C340
2C341 CJK UNIFIED IDEOGRAPH-#2C341
2C342 CJK UNIFIED IDEOGRAPH-#2C342
2C343 CJK UNIFIED IDEOGRAPH-#2C343
2C344 CJK UNIFIED IDEOGRAPH-#2C344
2C345 CJK UNIFIED IDEOGRAPH-#2C345
2C346 CJK UNIFIED IDEOGRAPH-#2C346
2C347 CJK UNIFIED IDEOGRAPH-#2C347
2C348 CJK UNIFIED IDEOGRAPH-#2C348
2C349 CJK UNIFIED IDEOGRAPH-#2C349
2C34A CJK UNIFIED IDEOGRAPH-#2C34A
2C34B CJK UNIFIED IDEOGRAPH-#2C34B
2C34C CJK UNIFIED IDEOGRAPH-#2C34C
2C34D CJK UNIFIED IDEOGRAPH-#2C34D
2C34E CJK UNIFIED IDEOGRAPH-#2C34E
2C34F CJK UNIFIED IDEOGRAPH-#2C34F
2C350 CJK UNIFIED IDEOGRAPH-#2C350
2C351 CJK UNIFIED IDEOGRAPH-#2C351
2C352 CJK UNIFIED IDEOGRAPH-#2C352
2C353 CJK UNIFIED IDEOGRAPH-#2C353
2C354 CJK UNIFIED IDEOGRAPH-#2C354
2C355 CJK UNIFIED IDEOGRAPH-#2C355
2C356 CJK UNIFIED IDEOGRAPH-#2C356
2C357 CJK UNIFIED IDEOGRAPH-#2C357
2C358 CJK UNIFIED IDEOGRAPH-#2C358
2C359 CJK UNIFIED IDEOGRAPH-#2C359
2C35A CJK UNIFIED IDEOGRAPH-#2C35A
2C35B CJK UNIFIED IDEOGRAPH-#2C35B
2C35C CJK UNIFIED IDEOGRAPH-#2C35C
2C35D CJK UNIFIED IDEOGRAPH-#2C35D
2C35E CJK UNIFIED IDEOGRAPH-#2C35E
2C35F CJK UNIFIED IDEOGRAPH-#2C35F
2C360 CJK UNIFIED IDEOGRAPH-#2C360
2C361 CJK UNIFIED IDEOGRAPH-#2C361
2C362 CJK UNIFIED IDEOGRAPH-#2C362
2C363 CJK UNIFIED IDEOGRAPH-#2C363
2C364 CJK UNIFIED IDEOGRAPH-#2C364
2C365 CJK UNIFIED IDEOGRAPH-#2C365
2C366 CJK UNIFIED IDEOGRAPH-#2C366
2C367 CJK UNIFIED IDEOGRAPH-#2C367
2C368 CJK UNIFIED IDEOGRAPH-#2C368
2C369 CJK UNIFIED IDEOGRAPH-#2C369
2C36A CJK UNIFIED IDEOGRAPH-#2C36A
2C36B CJK UNIFIED IDEOGRAPH-#2C36B
2C36C CJK UNIFIED IDEOGRAPH-#2C36C
2C36D CJK UNIFIED IDEOGRAPH-#2C36D
2C36E CJK UNIFIED IDEOGRAPH-#2C36E
2C36F CJK UNIFIED IDEOGRAPH-#2C36F
2C370 CJK UNIFIED IDEOGRAPH-#2C370
2C371 CJK UNIFIED IDEOGRAPH-#2C371
2C372 CJK UNIFIED IDEOGRAPH-#2C372
2C373 CJK UNIFIED IDEOGRAPH-#2C373
2C374 CJK UNIFIED IDEOGRAPH-#2C374
2C375 CJK UNIFIED IDEOGRAPH-#2C375
2C376 CJK UNIFIED IDEOGRAPH-#2C376
2C377 CJK UNIFIED IDEOGRAPH-#2C377
2C378 CJK UNIFIED IDEOGRAPH-#2C378
2C379 CJK UNIFIED IDEOGRAPH-#2C379
2C37A CJK UNIFIED IDEOGRAPH-#2C37A
2C37B CJK UNIFIED IDEOGRAPH-#2C37B
2C37C CJK UNIFIED IDEOGRAPH-#2C37C
2C37D CJK UNIFIED IDEOGRAPH-#2C37D
2C37E CJK UNIFIED IDEOGRAPH-#2C37E
2C37F CJK UNIFIED IDEOGRAPH-#2C37F
2C380 CJK UNIFIED IDEOGRAPH-#2C380
2C381 CJK UNIFIED IDEOGRAPH-#2C381
2C382 CJK UNIFIED IDEOGRAPH-#2C382
2C383 CJK UNIFIED IDEOGRAPH-#2C383
2C384 CJK UNIFIED IDEOGRAPH-#2C384
2C385 CJK UNIFIED IDEOGRAPH-#2C385
2C386 CJK UNIFIED IDEOGRAPH-#2C386
2C387 CJK UNIFIED IDEOGRAPH-#2C387
2C388 CJK UNIFIED IDEOGRAPH-#2C388
2C389 CJK UNIFIED IDEOGRAPH-#2C389
2C38A CJK UNIFIED IDEOGRAPH-#2C38A
2C38B CJK UNIFIED IDEOGRAPH-#2C38B
2C38C CJK UNIFIED IDEOGRAPH-#2C38C
2C38D CJK UNIFIED IDEOGRAPH-#2C38D
2C38E CJK UNIFIED IDEOGRAPH-#2C38E
2C38F CJK UNIFIED IDEOGRAPH-#2C38F
2C390 CJK UNIFIED IDEOGRAPH-#2C390
2C391 CJK UNIFIED IDEOGRAPH-#2C391
2C392 CJK UNIFIED IDEOGRAPH-#2C392
2C393 CJK UNIFIED IDEOGRAPH-#2C393
2C394 CJK UNIFIED IDEOGRAPH-#2C394
2C395 CJK UNIFIED IDEOGRAPH-#2C395
2C396 CJK UNIFIED IDEOGRAPH-#2C396
2C397 CJK UNIFIED IDEOGRAPH-#2C397
2C398 CJK UNIFIED IDEOGRAPH-#2C398
2C399 CJK UNIFIED IDEOGRAPH-#2C399
2C39A CJK UNIFIED IDEOGRAPH-#2C39A
2C39B CJK UNIFIED IDEOGRAPH-#2C39B
2C39C CJK UNIFIED IDEOGRAPH-#2C39C
2C39D CJK UNIFIED IDEOGRAPH-#2C39D
2C39E CJK UNIFIED IDEOGRAPH-#2C39E
2C39F CJK UNIFIED IDEOGRAPH-#2C39F
2C3A0 CJK UNIFIED IDEOGRAPH-#2C3A0
2C3A1 CJK UNIFIED IDEOGRAPH-#2C3A1
2C3A2 CJK UNIFIED IDEOGRAPH-#2C3A2
2C3A3 CJK UNIFIED IDEOGRAPH-#2C3A3
2C3A4 CJK UNIFIED IDEOGRAPH-#2C3A4
2C3A5 CJK UNIFIED IDEOGRAPH-#2C3A5
2C3A6 CJK UNIFIED IDEOGRAPH-#2C3A6
2C3A7 CJK UNIFIED IDEOGRAPH-#2C3A7
2C3A8 CJK UNIFIED IDEOGRAPH-#2C3A8
2C3A9 CJK UNIFIED IDEOGRAPH-#2C3A9
2C3AA CJK UNIFIED IDEOGRAPH-#2C3AA
2C3AB CJK UNIFIED IDEOGRAPH-#2C3AB
2C3AC CJK UNIFIED IDEOGRAPH-#2C3AC
2C3AD CJK UNIFIED IDEOGRAPH-#2C3AD
2C3AE CJK UNIFIED IDEOGRAPH-#2C3AE
2C3AF CJK UNIFIED IDEOGRAPH-#2C3AF
2C3B0 CJK UNIFIED IDEOGRAPH-#2C3B0
2C3B1 CJK UNIFIED IDEOGRAPH-#2C3B1
2C3B2 CJK UNIFIED IDEOGRAPH-#2C3B2
2C3B3 CJK UNIFIED IDEOGRAPH-#2C3B3
2C3B4 CJK UNIFIED IDEOGRAPH-#2C3B4
2C3B5 CJK UNIFIED IDEOGRAPH-#2C3B5
2C3B6 CJK UNIFIED IDEOGRAPH-#2C3B6
2C3B7 CJK UNIFIED IDEOGRAPH-#2C3B7
2C3B8 CJK UNIFIED IDEOGRAPH-#2C3B8
2C3B9 CJK UNIFIED IDEOGRAPH-#2C3B9
2C3BA CJK UNIFIED IDEOGRAPH-#2C3BA
2C3BB CJK UNIFIED IDEOGRAPH-#2C3BB
2C3BC CJK UNIFIED IDEOGRAPH-#2C3BC
2C3BD CJK UNIFIED IDEOGRAPH-#2C3BD
2C3BE CJK UNIFIED IDEOGRAPH-#2C3BE
2C3BF CJK UNIFIED IDEOGRAPH-#2C3BF
2C3C0 CJK UNIFIED IDEOGRAPH-#2C3C0
2C3C1 CJK UNIFIED IDEOGRAPH-#2C3C1
2C3C2 CJK UNIFIED IDEOGRAPH-#2C3C2
2C3C3 CJK UNIFIED IDEOGRAPH-#2C3C3
2C3C4 CJK UNIFIED IDEOGRAPH-#2C3C4
2C3C5 CJK UNIFIED IDEOGRAPH-#2C3C5
2C3C6 CJK UNIFIED IDEOGRAPH-#2C3C6
2C3C7 CJK UNIFIED IDEOGRAPH-#2C3C7
2C3C8 CJK UNIFIED IDEOGRAPH-#2C3C8
2C3C9 CJK UNIFIED IDEOGRAPH-#2C3C9
2C3CA CJK UNIFIED IDEOGRAPH-#2C3CA
2C3CB CJK UNIFIED IDEOGRAPH-#2C3CB
2C3CC CJK UNIFIED IDEOGRAPH-#2C3CC
2C3CD CJK UNIFIED IDEOGRAPH-#2C3CD
2C3CE CJK UNIFIED IDEOGRAPH-#2C3CE
2C3CF CJK UNIFIED IDEOGRAPH-#2C3CF
2C3D0 CJK UNIFIED IDEOGRAPH-#2C3D0
2C3D1 CJK UNIFIED IDEOGRAPH-#2C3D1
2C3D2 CJK UNIFIED IDEOGRAPH-#2C3D2
2C3D3 CJK UNIFIED IDEOGRAPH-#2C3D3
2C3D4 CJK UNIFIED IDEOGRAPH-#2C3D4
2C3D5 CJK UNIFIED IDEOGRAPH-#2C3D5
2C3D6 CJK UNIFIED IDEOGRAPH-#2C3D6
2C3D7 CJK UNIFIED IDEOGRAPH-#2C3D7
2C3D8 CJK UNIFIED IDEOGRAPH-#2C3D8
2C3D9 CJK UNIFIED IDEOGRAPH-#2C3D9
2C3DA CJK UNIFIED IDEOGRAPH-#2C3DA
2C3DB CJK UNIFIED IDEOGRAPH-#2C3DB
2C3DC CJK UNIFIED IDEOGRAPH-#2C3DC
2C3DD CJK UNIFIED IDEOGRAPH-#2C3DD
2C3DE CJK UNIFIED IDEOGRAPH-#2C3DE
2C3DF CJK UNIFIED IDEOGRAPH-#2C3DF
2C3E0 CJK UNIFIED IDEOGRAPH-#2C3E0
2C3E1 CJK UNIFIED IDEOGRAPH-#2C3E1
2C3E2 CJK UNIFIED IDEOGRAPH-#2C3E2
2C3E3 CJK UNIFIED IDEOGRAPH-#2C3E3
2C3E4 CJK UNIFIED IDEOGRAPH-#2C3E4
2C3E5 CJK UNIFIED IDEOGRAPH-#2C3E5
2C3E6 CJK UNIFIED IDEOGRAPH-#2C3E6
2C3E7 CJK UNIFIED IDEOGRAPH-#2C3E7
2C3E8 CJK UNIFIED IDEOGRAPH-#2C3E8
2C3E9 CJK UNIFIED IDEOGRAPH-#2C3E9
2C3EA CJK UNIFIED IDEOGRAPH-#2C3EA
2C3EB CJK UNIFIED IDEOGRAPH-#2C3EB
2C3EC CJK UNIFIED IDEOGRAPH-#2C3EC
2C3ED CJK UNIFIED IDEOGRAPH-#2C3ED
2C3EE CJK UNIFIED IDEOGRAPH-#2C3EE
2C3EF CJK UNIFIED IDEOGRAPH-#2C3EF
2C3F0 CJK UNIFIED IDEOGRAPH-#2C3F0
2C3F1 CJK UNIFIED IDEOGRAPH-#2C3F1
2C3F2 CJK UNIFIED IDEOGRAPH-#2C3F2
2C3F3 CJK UNIFIED IDEOGRAPH-#2C3F3
2C3F4 CJK UNIFIED IDEOGRAPH-#2C3F4
2C3F5 CJK UNIFIED IDEOGRAPH-#2C3F5
2C3F6 CJK UNIFIED IDEOGRAPH-#2C3F6
2C3F7 CJK UNIFIED IDEOGRAPH-#2C3F7
2C3F8 CJK UNIFIED IDEOGRAPH-#2C3F8
2C3F9 CJK UNIFIED IDEOGRAPH-#2C3F9
2C3FA CJK UNIFIED IDEOGRAPH-#2C3FA
2C3FB CJK UNIFIED IDEOGRAPH-#2C3FB
2C3FC CJK UNIFIED IDEOGRAPH-#2C3FC
2C3FD CJK UNIFIED IDEOGRAPH-#2C3FD
2C3FE CJK UNIFIED IDEOGRAPH-#2C3FE
2C3FF CJK UNIFIED IDEOGRAPH-#2C3FF
2C400 CJK UNIFIED IDEOGRAPH-#2C400
2C401 CJK UNIFIED IDEOGRAPH-#2C401
2C402 CJK UNIFIED IDEOGRAPH-#2C402
2C403 CJK UNIFIED IDEOGRAPH-#2C403
2C404 CJK UNIFIED IDEOGRAPH-#2C404
2C405 CJK UNIFIED IDEOGRAPH-#2C405
2C406 CJK UNIFIED IDEOGRAPH-#2C406
2C407 CJK UNIFIED IDEOGRAPH-#2C407
2C408 CJK UNIFIED IDEOGRAPH-#2C408
2C409 CJK UNIFIED IDEOGRAPH-#2C409
2C40A CJK UNIFIED IDEOGRAPH-#2C40A
2C40B CJK UNIFIED IDEOGRAPH-#2C40B
2C40C CJK UNIFIED IDEOGRAPH-#2C40C
2C40D CJK UNIFIED IDEOGRAPH-#2C40D
2C40E CJK UNIFIED IDEOGRAPH-#2C40E
2C40F CJK UNIFIED IDEOGRAPH-#2C40F
2C410 CJK UNIFIED IDEOGRAPH-#2C410
2C411 CJK UNIFIED IDEOGRAPH-#2C411
2C412 CJK UNIFIED IDEOGRAPH-#2C412
2C413 CJK UNIFIED IDEOGRAPH-#2C413
2C414 CJK UNIFIED IDEOGRAPH-#2C414
2C415 CJK UNIFIED IDEOGRAPH-#2C415
2C416 CJK UNIFIED IDEOGRAPH-#2C416
2C417 CJK UNIFIED IDEOGRAPH-#2C417
2C418 CJK UNIFIED IDEOGRAPH-#2C418
2C419 CJK UNIFIED IDEOGRAPH-#2C419
2C41A CJK UNIFIED IDEOGRAPH-#2C41A
2C41B CJK UNIFIED IDEOGRAPH-#2C41B
2C41C CJK UNIFIED IDEOGRAPH-#2C41C
2C41D CJK UNIFIED IDEOGRAPH-#2C41D
2C41E CJK UNIFIED IDEOGRAPH-#2C41E
2C41F CJK UNIFIED IDEOGRAPH-#2C41F
2C420 CJK UNIFIED IDEOGRAPH-#2C420
2C421 CJK UNIFIED IDEOGRAPH-#2C421
2C422 CJK UNIFIED IDEOGRAPH-#2C422
2C423 CJK UNIFIED IDEOGRAPH-#2C423
2C424 CJK UNIFIED IDEOGRAPH-#2C424
2C425 CJK UNIFIED IDEOGRAPH-#2C425
2C426 CJK UNIFIED IDEOGRAPH-#2C426
2C427 CJK UNIFIED IDEOGRAPH-#2C427
2C428 CJK UNIFIED IDEOGRAPH-#2C428
2C429 CJK UNIFIED IDEOGRAPH-#2C429
2C42A CJK UNIFIED IDEOGRAPH-#2C42A
2C42B CJK UNIFIED IDEOGRAPH-#2C42B
2C42C CJK UNIFIED IDEOGRAPH-#2C42C
2C42D CJK UNIFIED IDEOGRAPH-#2C42D
2C42E CJK UNIFIED IDEOGRAPH-#2C42E
2C42F CJK UNIFIED IDEOGRAPH-#2C42F
2C430 CJK UNIFIED IDEOGRAPH-#2C430
2C431 CJK UNIFIED IDEOGRAPH-#2C431
2C432 CJK UNIFIED IDEOGRAPH-#2C432
2C433 CJK UNIFIED IDEOGRAPH-#2C433
2C434 CJK UNIFIED IDEOGRAPH-#2C434
2C435 CJK UNIFIED IDEOGRAPH-#2C435
2C436 CJK UNIFIED IDEOGRAPH-#2C436
2C437 CJK UNIFIED IDEOGRAPH-#2C437
2C438 CJK UNIFIED IDEOGRAPH-#2C438
2C439 CJK UNIFIED IDEOGRAPH-#2C439
2C43A CJK UNIFIED IDEOGRAPH-#2C43A
2C43B CJK UNIFIED IDEOGRAPH-#2C43B
2C43C CJK UNIFIED IDEOGRAPH-#2C43C
2C43D CJK UNIFIED IDEOGRAPH-#2C43D
2C43E CJK UNIFIED IDEOGRAPH-#2C43E
2C43F CJK UNIFIED IDEOGRAPH-#2C43F
2C440 CJK UNIFIED IDEOGRAPH-#2C440
2C441 CJK UNIFIED IDEOGRAPH-#2C441
2C442 CJK UNIFIED IDEOGRAPH-#2C442
2C443 CJK UNIFIED IDEOGRAPH-#2C443
2C444 CJK UNIFIED IDEOGRAPH-#2C444
2C445 CJK UNIFIED IDEOGRAPH-#2C445
2C446 CJK UNIFIED IDEOGRAPH-#2C446
2C447 CJK UNIFIED IDEOGRAPH-#2C447
2C448 CJK UNIFIED IDEOGRAPH-#2C448
2C449 CJK UNIFIED IDEOGRAPH-#2C449
2C44A CJK UNIFIED IDEOGRAPH-#2C44A
2C44B CJK UNIFIED IDEOGRAPH-#2C44B
2C44C CJK UNIFIED IDEOGRAPH-#2C44C
2C44D CJK UNIFIED IDEOGRAPH-#2C44D
2C44E CJK UNIFIED IDEOGRAPH-#2C44E
2C44F CJK UNIFIED IDEOGRAPH-#2C44F
2C450 CJK UNIFIED IDEOGRAPH-#2C450
2C451 CJK UNIFIED IDEOGRAPH-#2C451
2C452 CJK UNIFIED IDEOGRAPH-#2C452
2C453 CJK UNIFIED IDEOGRAPH-#2C453
2C454 CJK UNIFIED IDEOGRAPH-#2C454
2C455 CJK UNIFIED IDEOGRAPH-#2C455
2C456 CJK UNIFIED IDEOGRAPH-#2C456
2C457 CJK UNIFIED IDEOGRAPH-#2C457
2C458 CJK UNIFIED IDEOGRAPH-#2C458
2C459 CJK UNIFIED IDEOGRAPH-#2C459
2C45A CJK UNIFIED IDEOGRAPH-#2C45A
2C45B CJK UNIFIED IDEOGRAPH-#2C45B
2C45C CJK UNIFIED IDEOGRAPH-#2C45C
2C45D CJK UNIFIED IDEOGRAPH-#2C45D
2C45E CJK UNIFIED IDEOGRAPH-#2C45E
2C45F CJK UNIFIED IDEOGRAPH-#2C45F
2C460 CJK UNIFIED IDEOGRAPH-#2C460
2C461 CJK UNIFIED IDEOGRAPH-#2C461
2C462 CJK UNIFIED IDEOGRAPH-#2C462
2C463 CJK UNIFIED IDEOGRAPH-#2C463
2C464 CJK UNIFIED IDEOGRAPH-#2C464
2C465 CJK UNIFIED IDEOGRAPH-#2C465
2C466 CJK UNIFIED IDEOGRAPH-#2C466
2C467 CJK UNIFIED IDEOGRAPH-#2C467
2C468 CJK UNIFIED IDEOGRAPH-#2C468
2C469 CJK UNIFIED IDEOGRAPH-#2C469
2C46A CJK UNIFIED IDEOGRAPH-#2C46A
2C46B CJK UNIFIED IDEOGRAPH-#2C46B
2C46C CJK UNIFIED IDEOGRAPH-#2C46C
2C46D CJK UNIFIED IDEOGRAPH-#2C46D
2C46E CJK UNIFIED IDEOGRAPH-#2C46E
2C46F CJK UNIFIED IDEOGRAPH-#2C46F
2C470 CJK UNIFIED IDEOGRAPH-#2C470
2C471 CJK UNIFIED IDEOGRAPH-#2C471
2C472 CJK UNIFIED IDEOGRAPH-#2C472
2C473 CJK UNIFIED IDEOGRAPH-#2C473
2C474 CJK UNIFIED IDEOGRAPH-#2C474
2C475 CJK UNIFIED IDEOGRAPH-#2C475
2C476 CJK UNIFIED IDEOGRAPH-#2C476
2C477 CJK UNIFIED IDEOGRAPH-#2C477
2C478 CJK UNIFIED IDEOGRAPH-#2C478
2C479 CJK UNIFIED IDEOGRAPH-#2C479
2C47A CJK UNIFIED IDEOGRAPH-#2C47A
2C47B CJK UNIFIED IDEOGRAPH-#2C47B
2C47C CJK UNIFIED IDEOGRAPH-#2C47C
2C47D CJK UNIFIED IDEOGRAPH-#2C47D
2C47E CJK UNIFIED IDEOGRAPH-#2C47E
2C47F CJK UNIFIED IDEOGRAPH-#2C47F
2C480 CJK UNIFIED IDEOGRAPH-#2C480
2C481 CJK UNIFIED IDEOGRAPH-#2C481
2C482 CJK UNIFIED IDEOGRAPH-#2C482
2C483 CJK UNIFIED IDEOGRAPH-#2C483
2C484 CJK UNIFIED IDEOGRAPH-#2C484
2C485 CJK UNIFIED IDEOGRAPH-#2C485
2C486 CJK UNIFIED IDEOGRAPH-#2C486
2C487 CJK UNIFIED IDEOGRAPH-#2C487
2C488 CJK UNIFIED IDEOGRAPH-#2C488
2C489 CJK UNIFIED IDEOGRAPH-#2C489
2C48A CJK UNIFIED IDEOGRAPH-#2C48A
2C48B CJK UNIFIED IDEOGRAPH-#2C48B
2C48C CJK UNIFIED IDEOGRAPH-#2C48C
2C48D CJK UNIFIED IDEOGRAPH-#2C48D
2C48E CJK UNIFIED IDEOGRAPH-#2C48E
2C48F CJK UNIFIED IDEOGRAPH-#2C48F
2C490 CJK UNIFIED IDEOGRAPH-#2C490
2C491 CJK UNIFIED IDEOGRAPH-#2C491
2C492 CJK UNIFIED IDEOGRAPH-#2C492
2C493 CJK UNIFIED IDEOGRAPH-#2C493
2C494 CJK UNIFIED IDEOGRAPH-#2C494, Def{for something hard or bulging to press against the body and cause it discomfort}
2C495 CJK UNIFIED IDEOGRAPH-#2C495
2C496 CJK UNIFIED IDEOGRAPH-#2C496
2C497 CJK UNIFIED IDEOGRAPH-#2C497
2C498 CJK UNIFIED IDEOGRAPH-#2C498
2C499 CJK UNIFIED IDEOGRAPH-#2C499
2C49A CJK UNIFIED IDEOGRAPH-#2C49A
2C49B CJK UNIFIED IDEOGRAPH-#2C49B
2C49C CJK UNIFIED IDEOGRAPH-#2C49C
2C49D CJK UNIFIED IDEOGRAPH-#2C49D
2C49E CJK UNIFIED IDEOGRAPH-#2C49E
2C49F CJK UNIFIED IDEOGRAPH-#2C49F
2C4A0 CJK UNIFIED IDEOGRAPH-#2C4A0
2C4A1 CJK UNIFIED IDEOGRAPH-#2C4A1
2C4A2 CJK UNIFIED IDEOGRAPH-#2C4A2
2C4A3 CJK UNIFIED IDEOGRAPH-#2C4A3
2C4A4 CJK UNIFIED IDEOGRAPH-#2C4A4
2C4A5 CJK UNIFIED IDEOGRAPH-#2C4A5
2C4A6 CJK UNIFIED IDEOGRAPH-#2C4A6
2C4A7 CJK UNIFIED IDEOGRAPH-#2C4A7
2C4A8 CJK UNIFIED IDEOGRAPH-#2C4A8
2C4A9 CJK UNIFIED IDEOGRAPH-#2C4A9
2C4AA CJK UNIFIED IDEOGRAPH-#2C4AA
2C4AB CJK UNIFIED IDEOGRAPH-#2C4AB
2C4AC CJK UNIFIED IDEOGRAPH-#2C4AC
2C4AD CJK UNIFIED IDEOGRAPH-#2C4AD
2C4AE CJK UNIFIED IDEOGRAPH-#2C4AE
2C4AF CJK UNIFIED IDEOGRAPH-#2C4AF
2C4B0 CJK UNIFIED IDEOGRAPH-#2C4B0
2C4B1 CJK UNIFIED IDEOGRAPH-#2C4B1
2C4B2 CJK UNIFIED IDEOGRAPH-#2C4B2
2C4B3 CJK UNIFIED IDEOGRAPH-#2C4B3
2C4B4 CJK UNIFIED IDEOGRAPH-#2C4B4
2C4B5 CJK UNIFIED IDEOGRAPH-#2C4B5
2C4B6 CJK UNIFIED IDEOGRAPH-#2C4B6
2C4B7 CJK UNIFIED IDEOGRAPH-#2C4B7
2C4B8 CJK UNIFIED IDEOGRAPH-#2C4B8
2C4B9 CJK UNIFIED IDEOGRAPH-#2C4B9
2C4BA CJK UNIFIED IDEOGRAPH-#2C4BA
2C4BB CJK UNIFIED IDEOGRAPH-#2C4BB
2C4BC CJK UNIFIED IDEOGRAPH-#2C4BC
2C4BD CJK UNIFIED IDEOGRAPH-#2C4BD
2C4BE CJK UNIFIED IDEOGRAPH-#2C4BE
2C4BF CJK UNIFIED IDEOGRAPH-#2C4BF
2C4C0 CJK UNIFIED IDEOGRAPH-#2C4C0
2C4C1 CJK UNIFIED IDEOGRAPH-#2C4C1
2C4C2 CJK UNIFIED IDEOGRAPH-#2C4C2
2C4C3 CJK UNIFIED IDEOGRAPH-#2C4C3
2C4C4 CJK UNIFIED IDEOGRAPH-#2C4C4
2C4C5 CJK UNIFIED IDEOGRAPH-#2C4C5
2C4C6 CJK UNIFIED IDEOGRAPH-#2C4C6
2C4C7 CJK UNIFIED IDEOGRAPH-#2C4C7
2C4C8 CJK UNIFIED IDEOGRAPH-#2C4C8
2C4C9 CJK UNIFIED IDEOGRAPH-#2C4C9
2C4CA CJK UNIFIED IDEOGRAPH-#2C4CA
2C4CB CJK UNIFIED IDEOGRAPH-#2C4CB
2C4CC CJK UNIFIED IDEOGRAPH-#2C4CC
2C4CD CJK UNIFIED IDEOGRAPH-#2C4CD
2C4CE CJK UNIFIED IDEOGRAPH-#2C4CE
2C4CF CJK UNIFIED IDEOGRAPH-#2C4CF
2C4D0 CJK UNIFIED IDEOGRAPH-#2C4D0
2C4D1 CJK UNIFIED IDEOGRAPH-#2C4D1
2C4D2 CJK UNIFIED IDEOGRAPH-#2C4D2
2C4D3 CJK UNIFIED IDEOGRAPH-#2C4D3
2C4D4 CJK UNIFIED IDEOGRAPH-#2C4D4
2C4D5 CJK UNIFIED IDEOGRAPH-#2C4D5
2C4D6 CJK UNIFIED IDEOGRAPH-#2C4D6
2C4D7 CJK UNIFIED IDEOGRAPH-#2C4D7
2C4D8 CJK UNIFIED IDEOGRAPH-#2C4D8
2C4D9 CJK UNIFIED IDEOGRAPH-#2C4D9
2C4DA CJK UNIFIED IDEOGRAPH-#2C4DA
2C4DB CJK UNIFIED IDEOGRAPH-#2C4DB
2C4DC CJK UNIFIED IDEOGRAPH-#2C4DC
2C4DD CJK UNIFIED IDEOGRAPH-#2C4DD
2C4DE CJK UNIFIED IDEOGRAPH-#2C4DE
2C4DF CJK UNIFIED IDEOGRAPH-#2C4DF
2C4E0 CJK UNIFIED IDEOGRAPH-#2C4E0
2C4E1 CJK UNIFIED IDEOGRAPH-#2C4E1
2C4E2 CJK UNIFIED IDEOGRAPH-#2C4E2
2C4E3 CJK UNIFIED IDEOGRAPH-#2C4E3
2C4E4 CJK UNIFIED IDEOGRAPH-#2C4E4
2C4E5 CJK UNIFIED IDEOGRAPH-#2C4E5
2C4E6 CJK UNIFIED IDEOGRAPH-#2C4E6
2C4E7 CJK UNIFIED IDEOGRAPH-#2C4E7
2C4E8 CJK UNIFIED IDEOGRAPH-#2C4E8
2C4E9 CJK UNIFIED IDEOGRAPH-#2C4E9
2C4EA CJK UNIFIED IDEOGRAPH-#2C4EA
2C4EB CJK UNIFIED IDEOGRAPH-#2C4EB
2C4EC CJK UNIFIED IDEOGRAPH-#2C4EC
2C4ED CJK UNIFIED IDEOGRAPH-#2C4ED
2C4EE CJK UNIFIED IDEOGRAPH-#2C4EE
2C4EF CJK UNIFIED IDEOGRAPH-#2C4EF
2C4F0 CJK UNIFIED IDEOGRAPH-#2C4F0
2C4F1 CJK UNIFIED IDEOGRAPH-#2C4F1
2C4F2 CJK UNIFIED IDEOGRAPH-#2C4F2
2C4F3 CJK UNIFIED IDEOGRAPH-#2C4F3
2C4F4 CJK UNIFIED IDEOGRAPH-#2C4F4
2C4F5 CJK UNIFIED IDEOGRAPH-#2C4F5
2C4F6 CJK UNIFIED IDEOGRAPH-#2C4F6
2C4F7 CJK UNIFIED IDEOGRAPH-#2C4F7
2C4F8 CJK UNIFIED IDEOGRAPH-#2C4F8
2C4F9 CJK UNIFIED IDEOGRAPH-#2C4F9
2C4FA CJK UNIFIED IDEOGRAPH-#2C4FA
2C4FB CJK UNIFIED IDEOGRAPH-#2C4FB
2C4FC CJK UNIFIED IDEOGRAPH-#2C4FC
2C4FD CJK UNIFIED IDEOGRAPH-#2C4FD
2C4FE CJK UNIFIED IDEOGRAPH-#2C4FE
2C4FF CJK UNIFIED IDEOGRAPH-#2C4FF
2C500 CJK UNIFIED IDEOGRAPH-#2C500
2C501 CJK UNIFIED IDEOGRAPH-#2C501
2C502 CJK UNIFIED IDEOGRAPH-#2C502
2C503 CJK UNIFIED IDEOGRAPH-#2C503
2C504 CJK UNIFIED IDEOGRAPH-#2C504
2C505 CJK UNIFIED IDEOGRAPH-#2C505
2C506 CJK UNIFIED IDEOGRAPH-#2C506
2C507 CJK UNIFIED IDEOGRAPH-#2C507
2C508 CJK UNIFIED IDEOGRAPH-#2C508
2C509 CJK UNIFIED IDEOGRAPH-#2C509
2C50A CJK UNIFIED IDEOGRAPH-#2C50A
2C50B CJK UNIFIED IDEOGRAPH-#2C50B
2C50C CJK UNIFIED IDEOGRAPH-#2C50C
2C50D CJK UNIFIED IDEOGRAPH-#2C50D
2C50E CJK UNIFIED IDEOGRAPH-#2C50E
2C50F CJK UNIFIED IDEOGRAPH-#2C50F
2C510 CJK UNIFIED IDEOGRAPH-#2C510
2C511 CJK UNIFIED IDEOGRAPH-#2C511
2C512 CJK UNIFIED IDEOGRAPH-#2C512
2C513 CJK UNIFIED IDEOGRAPH-#2C513
2C514 CJK UNIFIED IDEOGRAPH-#2C514
2C515 CJK UNIFIED IDEOGRAPH-#2C515
2C516 CJK UNIFIED IDEOGRAPH-#2C516
2C517 CJK UNIFIED IDEOGRAPH-#2C517
2C518 CJK UNIFIED IDEOGRAPH-#2C518
2C519 CJK UNIFIED IDEOGRAPH-#2C519
2C51A CJK UNIFIED IDEOGRAPH-#2C51A
2C51B CJK UNIFIED IDEOGRAPH-#2C51B
2C51C CJK UNIFIED IDEOGRAPH-#2C51C
2C51D CJK UNIFIED IDEOGRAPH-#2C51D
2C51E CJK UNIFIED IDEOGRAPH-#2C51E
2C51F CJK UNIFIED IDEOGRAPH-#2C51F
2C520 CJK UNIFIED IDEOGRAPH-#2C520
2C521 CJK UNIFIED IDEOGRAPH-#2C521
2C522 CJK UNIFIED IDEOGRAPH-#2C522
2C523 CJK UNIFIED IDEOGRAPH-#2C523
2C524 CJK UNIFIED IDEOGRAPH-#2C524
2C525 CJK UNIFIED IDEOGRAPH-#2C525
2C526 CJK UNIFIED IDEOGRAPH-#2C526
2C527 CJK UNIFIED IDEOGRAPH-#2C527
2C528 CJK UNIFIED IDEOGRAPH-#2C528
2C529 CJK UNIFIED IDEOGRAPH-#2C529
2C52A CJK UNIFIED IDEOGRAPH-#2C52A
2C52B CJK UNIFIED IDEOGRAPH-#2C52B
2C52C CJK UNIFIED IDEOGRAPH-#2C52C
2C52D CJK UNIFIED IDEOGRAPH-#2C52D
2C52E CJK UNIFIED IDEOGRAPH-#2C52E
2C52F CJK UNIFIED IDEOGRAPH-#2C52F
2C530 CJK UNIFIED IDEOGRAPH-#2C530
2C531 CJK UNIFIED IDEOGRAPH-#2C531
2C532 CJK UNIFIED IDEOGRAPH-#2C532
2C533 CJK UNIFIED IDEOGRAPH-#2C533
2C534 CJK UNIFIED IDEOGRAPH-#2C534
2C535 CJK UNIFIED IDEOGRAPH-#2C535
2C536 CJK UNIFIED IDEOGRAPH-#2C536
2C537 CJK UNIFIED IDEOGRAPH-#2C537
2C538 CJK UNIFIED IDEOGRAPH-#2C538
2C539 CJK UNIFIED IDEOGRAPH-#2C539
2C53A CJK UNIFIED IDEOGRAPH-#2C53A
2C53B CJK UNIFIED IDEOGRAPH-#2C53B
2C53C CJK UNIFIED IDEOGRAPH-#2C53C
2C53D CJK UNIFIED IDEOGRAPH-#2C53D
2C53E CJK UNIFIED IDEOGRAPH-#2C53E
2C53F CJK UNIFIED IDEOGRAPH-#2C53F
2C540 CJK UNIFIED IDEOGRAPH-#2C540
2C541 CJK UNIFIED IDEOGRAPH-#2C541
2C542 CJK UNIFIED IDEOGRAPH-#2C542
2C543 CJK UNIFIED IDEOGRAPH-#2C543
2C544 CJK UNIFIED IDEOGRAPH-#2C544
2C545 CJK UNIFIED IDEOGRAPH-#2C545
2C546 CJK UNIFIED IDEOGRAPH-#2C546
2C547 CJK UNIFIED IDEOGRAPH-#2C547
2C548 CJK UNIFIED IDEOGRAPH-#2C548
2C549 CJK UNIFIED IDEOGRAPH-#2C549
2C54A CJK UNIFIED IDEOGRAPH-#2C54A
2C54B CJK UNIFIED IDEOGRAPH-#2C54B
2C54C CJK UNIFIED IDEOGRAPH-#2C54C
2C54D CJK UNIFIED IDEOGRAPH-#2C54D
2C54E CJK UNIFIED IDEOGRAPH-#2C54E
2C54F CJK UNIFIED IDEOGRAPH-#2C54F
2C550 CJK UNIFIED IDEOGRAPH-#2C550
2C551 CJK UNIFIED IDEOGRAPH-#2C551
2C552 CJK UNIFIED IDEOGRAPH-#2C552
2C553 CJK UNIFIED IDEOGRAPH-#2C553
2C554 CJK UNIFIED IDEOGRAPH-#2C554
2C555 CJK UNIFIED IDEOGRAPH-#2C555
2C556 CJK UNIFIED IDEOGRAPH-#2C556
2C557 CJK UNIFIED IDEOGRAPH-#2C557
2C558 CJK UNIFIED IDEOGRAPH-#2C558
2C559 CJK UNIFIED IDEOGRAPH-#2C559
2C55A CJK UNIFIED IDEOGRAPH-#2C55A
2C55B CJK UNIFIED IDEOGRAPH-#2C55B
2C55C CJK UNIFIED IDEOGRAPH-#2C55C
2C55D CJK UNIFIED IDEOGRAPH-#2C55D
2C55E CJK UNIFIED IDEOGRAPH-#2C55E
2C55F CJK UNIFIED IDEOGRAPH-#2C55F
2C560 CJK UNIFIED IDEOGRAPH-#2C560
2C561 CJK UNIFIED IDEOGRAPH-#2C561
2C562 CJK UNIFIED IDEOGRAPH-#2C562
2C563 CJK UNIFIED IDEOGRAPH-#2C563
2C564 CJK UNIFIED IDEOGRAPH-#2C564
2C565 CJK UNIFIED IDEOGRAPH-#2C565
2C566 CJK UNIFIED IDEOGRAPH-#2C566
2C567 CJK UNIFIED IDEOGRAPH-#2C567
2C568 CJK UNIFIED IDEOGRAPH-#2C568
2C569 CJK UNIFIED IDEOGRAPH-#2C569
2C56A CJK UNIFIED IDEOGRAPH-#2C56A
2C56B CJK UNIFIED IDEOGRAPH-#2C56B
2C56C CJK UNIFIED IDEOGRAPH-#2C56C
2C56D CJK UNIFIED IDEOGRAPH-#2C56D
2C56E CJK UNIFIED IDEOGRAPH-#2C56E
2C56F CJK UNIFIED IDEOGRAPH-#2C56F
2C570 CJK UNIFIED IDEOGRAPH-#2C570
2C571 CJK UNIFIED IDEOGRAPH-#2C571
2C572 CJK UNIFIED IDEOGRAPH-#2C572
2C573 CJK UNIFIED IDEOGRAPH-#2C573
2C574 CJK UNIFIED IDEOGRAPH-#2C574
2C575 CJK UNIFIED IDEOGRAPH-#2C575
2C576 CJK UNIFIED IDEOGRAPH-#2C576
2C577 CJK UNIFIED IDEOGRAPH-#2C577
2C578 CJK UNIFIED IDEOGRAPH-#2C578
2C579 CJK UNIFIED IDEOGRAPH-#2C579
2C57A CJK UNIFIED IDEOGRAPH-#2C57A
2C57B CJK UNIFIED IDEOGRAPH-#2C57B
2C57C CJK UNIFIED IDEOGRAPH-#2C57C
2C57D CJK UNIFIED IDEOGRAPH-#2C57D
2C57E CJK UNIFIED IDEOGRAPH-#2C57E
2C57F CJK UNIFIED IDEOGRAPH-#2C57F
2C580 CJK UNIFIED IDEOGRAPH-#2C580
2C581 CJK UNIFIED IDEOGRAPH-#2C581
2C582 CJK UNIFIED IDEOGRAPH-#2C582
2C583 CJK UNIFIED IDEOGRAPH-#2C583
2C584 CJK UNIFIED IDEOGRAPH-#2C584
2C585 CJK UNIFIED IDEOGRAPH-#2C585
2C586 CJK UNIFIED IDEOGRAPH-#2C586
2C587 CJK UNIFIED IDEOGRAPH-#2C587
2C588 CJK UNIFIED IDEOGRAPH-#2C588
2C589 CJK UNIFIED IDEOGRAPH-#2C589
2C58A CJK UNIFIED IDEOGRAPH-#2C58A
2C58B CJK UNIFIED IDEOGRAPH-#2C58B
2C58C CJK UNIFIED IDEOGRAPH-#2C58C
2C58D CJK UNIFIED IDEOGRAPH-#2C58D
2C58E CJK UNIFIED IDEOGRAPH-#2C58E
2C58F CJK UNIFIED IDEOGRAPH-#2C58F
2C590 CJK UNIFIED IDEOGRAPH-#2C590
2C591 CJK UNIFIED IDEOGRAPH-#2C591
2C592 CJK UNIFIED IDEOGRAPH-#2C592
2C593 CJK UNIFIED IDEOGRAPH-#2C593
2C594 CJK UNIFIED IDEOGRAPH-#2C594
2C595 CJK UNIFIED IDEOGRAPH-#2C595
2C596 CJK UNIFIED IDEOGRAPH-#2C596
2C597 CJK UNIFIED IDEOGRAPH-#2C597
2C598 CJK UNIFIED IDEOGRAPH-#2C598
2C599 CJK UNIFIED IDEOGRAPH-#2C599
2C59A CJK UNIFIED IDEOGRAPH-#2C59A
2C59B CJK UNIFIED IDEOGRAPH-#2C59B
2C59C CJK UNIFIED IDEOGRAPH-#2C59C
2C59D CJK UNIFIED IDEOGRAPH-#2C59D
2C59E CJK UNIFIED IDEOGRAPH-#2C59E
2C59F CJK UNIFIED IDEOGRAPH-#2C59F
2C5A0 CJK UNIFIED IDEOGRAPH-#2C5A0
2C5A1 CJK UNIFIED IDEOGRAPH-#2C5A1
2C5A2 CJK UNIFIED IDEOGRAPH-#2C5A2
2C5A3 CJK UNIFIED IDEOGRAPH-#2C5A3
2C5A4 CJK UNIFIED IDEOGRAPH-#2C5A4
2C5A5 CJK UNIFIED IDEOGRAPH-#2C5A5
2C5A6 CJK UNIFIED IDEOGRAPH-#2C5A6
2C5A7 CJK UNIFIED IDEOGRAPH-#2C5A7
2C5A8 CJK UNIFIED IDEOGRAPH-#2C5A8
2C5A9 CJK UNIFIED IDEOGRAPH-#2C5A9
2C5AA CJK UNIFIED IDEOGRAPH-#2C5AA
2C5AB CJK UNIFIED IDEOGRAPH-#2C5AB
2C5AC CJK UNIFIED IDEOGRAPH-#2C5AC
2C5AD CJK UNIFIED IDEOGRAPH-#2C5AD
2C5AE CJK UNIFIED IDEOGRAPH-#2C5AE
2C5AF CJK UNIFIED IDEOGRAPH-#2C5AF
2C5B0 CJK UNIFIED IDEOGRAPH-#2C5B0
2C5B1 CJK UNIFIED IDEOGRAPH-#2C5B1
2C5B2 CJK UNIFIED IDEOGRAPH-#2C5B2
2C5B3 CJK UNIFIED IDEOGRAPH-#2C5B3
2C5B4 CJK UNIFIED IDEOGRAPH-#2C5B4
2C5B5 CJK UNIFIED IDEOGRAPH-#2C5B5
2C5B6 CJK UNIFIED IDEOGRAPH-#2C5B6
2C5B7 CJK UNIFIED IDEOGRAPH-#2C5B7
2C5B8 CJK UNIFIED IDEOGRAPH-#2C5B8
2C5B9 CJK UNIFIED IDEOGRAPH-#2C5B9
2C5BA CJK UNIFIED IDEOGRAPH-#2C5BA
2C5BB CJK UNIFIED IDEOGRAPH-#2C5BB
2C5BC CJK UNIFIED IDEOGRAPH-#2C5BC
2C5BD CJK UNIFIED IDEOGRAPH-#2C5BD
2C5BE CJK UNIFIED IDEOGRAPH-#2C5BE
2C5BF CJK UNIFIED IDEOGRAPH-#2C5BF
2C5C0 CJK UNIFIED IDEOGRAPH-#2C5C0
2C5C1 CJK UNIFIED IDEOGRAPH-#2C5C1
2C5C2 CJK UNIFIED IDEOGRAPH-#2C5C2
2C5C3 CJK UNIFIED IDEOGRAPH-#2C5C3
2C5C4 CJK UNIFIED IDEOGRAPH-#2C5C4
2C5C5 CJK UNIFIED IDEOGRAPH-#2C5C5
2C5C6 CJK UNIFIED IDEOGRAPH-#2C5C6
2C5C7 CJK UNIFIED IDEOGRAPH-#2C5C7
2C5C8 CJK UNIFIED IDEOGRAPH-#2C5C8
2C5C9 CJK UNIFIED IDEOGRAPH-#2C5C9
2C5CA CJK UNIFIED IDEOGRAPH-#2C5CA
2C5CB CJK UNIFIED IDEOGRAPH-#2C5CB
2C5CC CJK UNIFIED IDEOGRAPH-#2C5CC
2C5CD CJK UNIFIED IDEOGRAPH-#2C5CD
2C5CE CJK UNIFIED IDEOGRAPH-#2C5CE
2C5CF CJK UNIFIED IDEOGRAPH-#2C5CF
2C5D0 CJK UNIFIED IDEOGRAPH-#2C5D0
2C5D1 CJK UNIFIED IDEOGRAPH-#2C5D1
2C5D2 CJK UNIFIED IDEOGRAPH-#2C5D2
2C5D3 CJK UNIFIED IDEOGRAPH-#2C5D3
2C5D4 CJK UNIFIED IDEOGRAPH-#2C5D4
2C5D5 CJK UNIFIED IDEOGRAPH-#2C5D5
2C5D6 CJK UNIFIED IDEOGRAPH-#2C5D6
2C5D7 CJK UNIFIED IDEOGRAPH-#2C5D7
2C5D8 CJK UNIFIED IDEOGRAPH-#2C5D8
2C5D9 CJK UNIFIED IDEOGRAPH-#2C5D9
2C5DA CJK UNIFIED IDEOGRAPH-#2C5DA
2C5DB CJK UNIFIED IDEOGRAPH-#2C5DB
2C5DC CJK UNIFIED IDEOGRAPH-#2C5DC
2C5DD CJK UNIFIED IDEOGRAPH-#2C5DD
2C5DE CJK UNIFIED IDEOGRAPH-#2C5DE
2C5DF CJK UNIFIED IDEOGRAPH-#2C5DF
2C5E0 CJK UNIFIED IDEOGRAPH-#2C5E0
2C5E1 CJK UNIFIED IDEOGRAPH-#2C5E1
2C5E2 CJK UNIFIED IDEOGRAPH-#2C5E2
2C5E3 CJK UNIFIED IDEOGRAPH-#2C5E3
2C5E4 CJK UNIFIED IDEOGRAPH-#2C5E4
2C5E5 CJK UNIFIED IDEOGRAPH-#2C5E5
2C5E6 CJK UNIFIED IDEOGRAPH-#2C5E6
2C5E7 CJK UNIFIED IDEOGRAPH-#2C5E7
2C5E8 CJK UNIFIED IDEOGRAPH-#2C5E8
2C5E9 CJK UNIFIED IDEOGRAPH-#2C5E9
2C5EA CJK UNIFIED IDEOGRAPH-#2C5EA
2C5EB CJK UNIFIED IDEOGRAPH-#2C5EB
2C5EC CJK UNIFIED IDEOGRAPH-#2C5EC
2C5ED CJK UNIFIED IDEOGRAPH-#2C5ED
2C5EE CJK UNIFIED IDEOGRAPH-#2C5EE
2C5EF CJK UNIFIED IDEOGRAPH-#2C5EF
2C5F0 CJK UNIFIED IDEOGRAPH-#2C5F0
2C5F1 CJK UNIFIED IDEOGRAPH-#2C5F1
2C5F2 CJK UNIFIED IDEOGRAPH-#2C5F2
2C5F3 CJK UNIFIED IDEOGRAPH-#2C5F3
2C5F4 CJK UNIFIED IDEOGRAPH-#2C5F4
2C5F5 CJK UNIFIED IDEOGRAPH-#2C5F5
2C5F6 CJK UNIFIED IDEOGRAPH-#2C5F6
2C5F7 CJK UNIFIED IDEOGRAPH-#2C5F7
2C5F8 CJK UNIFIED IDEOGRAPH-#2C5F8
2C5F9 CJK UNIFIED IDEOGRAPH-#2C5F9
2C5FA CJK UNIFIED IDEOGRAPH-#2C5FA
2C5FB CJK UNIFIED IDEOGRAPH-#2C5FB
2C5FC CJK UNIFIED IDEOGRAPH-#2C5FC
2C5FD CJK UNIFIED IDEOGRAPH-#2C5FD
2C5FE CJK UNIFIED IDEOGRAPH-#2C5FE
2C5FF CJK UNIFIED IDEOGRAPH-#2C5FF
2C600 CJK UNIFIED IDEOGRAPH-#2C600
2C601 CJK UNIFIED IDEOGRAPH-#2C601
2C602 CJK UNIFIED IDEOGRAPH-#2C602
2C603 CJK UNIFIED IDEOGRAPH-#2C603
2C604 CJK UNIFIED IDEOGRAPH-#2C604
2C605 CJK UNIFIED IDEOGRAPH-#2C605
2C606 CJK UNIFIED IDEOGRAPH-#2C606
2C607 CJK UNIFIED IDEOGRAPH-#2C607
2C608 CJK UNIFIED IDEOGRAPH-#2C608
2C609 CJK UNIFIED IDEOGRAPH-#2C609
2C60A CJK UNIFIED IDEOGRAPH-#2C60A
2C60B CJK UNIFIED IDEOGRAPH-#2C60B
2C60C CJK UNIFIED IDEOGRAPH-#2C60C
2C60D CJK UNIFIED IDEOGRAPH-#2C60D
2C60E CJK UNIFIED IDEOGRAPH-#2C60E
2C60F CJK UNIFIED IDEOGRAPH-#2C60F
2C610 CJK UNIFIED IDEOGRAPH-#2C610
2C611 CJK UNIFIED IDEOGRAPH-#2C611
2C612 CJK UNIFIED IDEOGRAPH-#2C612
2C613 CJK UNIFIED IDEOGRAPH-#2C613
2C614 CJK UNIFIED IDEOGRAPH-#2C614
2C615 CJK UNIFIED IDEOGRAPH-#2C615
2C616 CJK UNIFIED IDEOGRAPH-#2C616
2C617 CJK UNIFIED IDEOGRAPH-#2C617
2C618 CJK UNIFIED IDEOGRAPH-#2C618
2C619 CJK UNIFIED IDEOGRAPH-#2C619
2C61A CJK UNIFIED IDEOGRAPH-#2C61A
2C61B CJK UNIFIED IDEOGRAPH-#2C61B
2C61C CJK UNIFIED IDEOGRAPH-#2C61C
2C61D CJK UNIFIED IDEOGRAPH-#2C61D
2C61E CJK UNIFIED IDEOGRAPH-#2C61E
2C61F CJK UNIFIED IDEOGRAPH-#2C61F
2C620 CJK UNIFIED IDEOGRAPH-#2C620
2C621 CJK UNIFIED IDEOGRAPH-#2C621
2C622 CJK UNIFIED IDEOGRAPH-#2C622
2C623 CJK UNIFIED IDEOGRAPH-#2C623
2C624 CJK UNIFIED IDEOGRAPH-#2C624
2C625 CJK UNIFIED IDEOGRAPH-#2C625
2C626 CJK UNIFIED IDEOGRAPH-#2C626
2C627 CJK UNIFIED IDEOGRAPH-#2C627
2C628 CJK UNIFIED IDEOGRAPH-#2C628
2C629 CJK UNIFIED IDEOGRAPH-#2C629
2C62A CJK UNIFIED IDEOGRAPH-#2C62A
2C62B CJK UNIFIED IDEOGRAPH-#2C62B
2C62C CJK UNIFIED IDEOGRAPH-#2C62C
2C62D CJK UNIFIED IDEOGRAPH-#2C62D
2C62E CJK UNIFIED IDEOGRAPH-#2C62E
2C62F CJK UNIFIED IDEOGRAPH-#2C62F
2C630 CJK UNIFIED IDEOGRAPH-#2C630
2C631 CJK UNIFIED IDEOGRAPH-#2C631
2C632 CJK UNIFIED IDEOGRAPH-#2C632
2C633 CJK UNIFIED IDEOGRAPH-#2C633
2C634 CJK UNIFIED IDEOGRAPH-#2C634
2C635 CJK UNIFIED IDEOGRAPH-#2C635
2C636 CJK UNIFIED IDEOGRAPH-#2C636
2C637 CJK UNIFIED IDEOGRAPH-#2C637
2C638 CJK UNIFIED IDEOGRAPH-#2C638
2C639 CJK UNIFIED IDEOGRAPH-#2C639
2C63A CJK UNIFIED IDEOGRAPH-#2C63A
2C63B CJK UNIFIED IDEOGRAPH-#2C63B
2C63C CJK UNIFIED IDEOGRAPH-#2C63C
2C63D CJK UNIFIED IDEOGRAPH-#2C63D
2C63E CJK UNIFIED IDEOGRAPH-#2C63E
2C63F CJK UNIFIED IDEOGRAPH-#2C63F
2C640 CJK UNIFIED IDEOGRAPH-#2C640
2C641 CJK UNIFIED IDEOGRAPH-#2C641
2C642 CJK UNIFIED IDEOGRAPH-#2C642
2C643 CJK UNIFIED IDEOGRAPH-#2C643
2C644 CJK UNIFIED IDEOGRAPH-#2C644
2C645 CJK UNIFIED IDEOGRAPH-#2C645
2C646 CJK UNIFIED IDEOGRAPH-#2C646
2C647 CJK UNIFIED IDEOGRAPH-#2C647
2C648 CJK UNIFIED IDEOGRAPH-#2C648
2C649 CJK UNIFIED IDEOGRAPH-#2C649
2C64A CJK UNIFIED IDEOGRAPH-#2C64A
2C64B CJK UNIFIED IDEOGRAPH-#2C64B
2C64C CJK UNIFIED IDEOGRAPH-#2C64C
2C64D CJK UNIFIED IDEOGRAPH-#2C64D
2C64E CJK UNIFIED IDEOGRAPH-#2C64E
2C64F CJK UNIFIED IDEOGRAPH-#2C64F
2C650 CJK UNIFIED IDEOGRAPH-#2C650
2C651 CJK UNIFIED IDEOGRAPH-#2C651
2C652 CJK UNIFIED IDEOGRAPH-#2C652
2C653 CJK UNIFIED IDEOGRAPH-#2C653
2C654 CJK UNIFIED IDEOGRAPH-#2C654
2C655 CJK UNIFIED IDEOGRAPH-#2C655
2C656 CJK UNIFIED IDEOGRAPH-#2C656
2C657 CJK UNIFIED IDEOGRAPH-#2C657
2C658 CJK UNIFIED IDEOGRAPH-#2C658
2C659 CJK UNIFIED IDEOGRAPH-#2C659
2C65A CJK UNIFIED IDEOGRAPH-#2C65A
2C65B CJK UNIFIED IDEOGRAPH-#2C65B
2C65C CJK UNIFIED IDEOGRAPH-#2C65C
2C65D CJK UNIFIED IDEOGRAPH-#2C65D
2C65E CJK UNIFIED IDEOGRAPH-#2C65E
2C65F CJK UNIFIED IDEOGRAPH-#2C65F
2C660 CJK UNIFIED IDEOGRAPH-#2C660
2C661 CJK UNIFIED IDEOGRAPH-#2C661
2C662 CJK UNIFIED IDEOGRAPH-#2C662
2C663 CJK UNIFIED IDEOGRAPH-#2C663
2C664 CJK UNIFIED IDEOGRAPH-#2C664
2C665 CJK UNIFIED IDEOGRAPH-#2C665
2C666 CJK UNIFIED IDEOGRAPH-#2C666
2C667 CJK UNIFIED IDEOGRAPH-#2C667
2C668 CJK UNIFIED IDEOGRAPH-#2C668
2C669 CJK UNIFIED IDEOGRAPH-#2C669
2C66A CJK UNIFIED IDEOGRAPH-#2C66A
2C66B CJK UNIFIED IDEOGRAPH-#2C66B
2C66C CJK UNIFIED IDEOGRAPH-#2C66C
2C66D CJK UNIFIED IDEOGRAPH-#2C66D
2C66E CJK UNIFIED IDEOGRAPH-#2C66E
2C66F CJK UNIFIED IDEOGRAPH-#2C66F
2C670 CJK UNIFIED IDEOGRAPH-#2C670
2C671 CJK UNIFIED IDEOGRAPH-#2C671
2C672 CJK UNIFIED IDEOGRAPH-#2C672
2C673 CJK UNIFIED IDEOGRAPH-#2C673
2C674 CJK UNIFIED IDEOGRAPH-#2C674
2C675 CJK UNIFIED IDEOGRAPH-#2C675
2C676 CJK UNIFIED IDEOGRAPH-#2C676
2C677 CJK UNIFIED IDEOGRAPH-#2C677
2C678 CJK UNIFIED IDEOGRAPH-#2C678
2C679 CJK UNIFIED IDEOGRAPH-#2C679
2C67A CJK UNIFIED IDEOGRAPH-#2C67A
2C67B CJK UNIFIED IDEOGRAPH-#2C67B
2C67C CJK UNIFIED IDEOGRAPH-#2C67C
2C67D CJK UNIFIED IDEOGRAPH-#2C67D
2C67E CJK UNIFIED IDEOGRAPH-#2C67E
2C67F CJK UNIFIED IDEOGRAPH-#2C67F
2C680 CJK UNIFIED IDEOGRAPH-#2C680
2C681 CJK UNIFIED IDEOGRAPH-#2C681
2C682 CJK UNIFIED IDEOGRAPH-#2C682
2C683 CJK UNIFIED IDEOGRAPH-#2C683
2C684 CJK UNIFIED IDEOGRAPH-#2C684
2C685 CJK UNIFIED IDEOGRAPH-#2C685
2C686 CJK UNIFIED IDEOGRAPH-#2C686
2C687 CJK UNIFIED IDEOGRAPH-#2C687
2C688 CJK UNIFIED IDEOGRAPH-#2C688
2C689 CJK UNIFIED IDEOGRAPH-#2C689
2C68A CJK UNIFIED IDEOGRAPH-#2C68A
2C68B CJK UNIFIED IDEOGRAPH-#2C68B
2C68C CJK UNIFIED IDEOGRAPH-#2C68C
2C68D CJK UNIFIED IDEOGRAPH-#2C68D
2C68E CJK UNIFIED IDEOGRAPH-#2C68E
2C68F CJK UNIFIED IDEOGRAPH-#2C68F
2C690 CJK UNIFIED IDEOGRAPH-#2C690
2C691 CJK UNIFIED IDEOGRAPH-#2C691
2C692 CJK UNIFIED IDEOGRAPH-#2C692
2C693 CJK UNIFIED IDEOGRAPH-#2C693
2C694 CJK UNIFIED IDEOGRAPH-#2C694
2C695 CJK UNIFIED IDEOGRAPH-#2C695
2C696 CJK UNIFIED IDEOGRAPH-#2C696
2C697 CJK UNIFIED IDEOGRAPH-#2C697
2C698 CJK UNIFIED IDEOGRAPH-#2C698
2C699 CJK UNIFIED IDEOGRAPH-#2C699
2C69A CJK UNIFIED IDEOGRAPH-#2C69A
2C69B CJK UNIFIED IDEOGRAPH-#2C69B
2C69C CJK UNIFIED IDEOGRAPH-#2C69C
2C69D CJK UNIFIED IDEOGRAPH-#2C69D
2C69E CJK UNIFIED IDEOGRAPH-#2C69E
2C69F CJK UNIFIED IDEOGRAPH-#2C69F
2C6A0 CJK UNIFIED IDEOGRAPH-#2C6A0
2C6A1 CJK UNIFIED IDEOGRAPH-#2C6A1
2C6A2 CJK UNIFIED IDEOGRAPH-#2C6A2
2C6A3 CJK UNIFIED IDEOGRAPH-#2C6A3
2C6A4 CJK UNIFIED IDEOGRAPH-#2C6A4
2C6A5 CJK UNIFIED IDEOGRAPH-#2C6A5
2C6A6 CJK UNIFIED IDEOGRAPH-#2C6A6
2C6A7 CJK UNIFIED IDEOGRAPH-#2C6A7
2C6A8 CJK UNIFIED IDEOGRAPH-#2C6A8
2C6A9 CJK UNIFIED IDEOGRAPH-#2C6A9
2C6AA CJK UNIFIED IDEOGRAPH-#2C6AA
2C6AB CJK UNIFIED IDEOGRAPH-#2C6AB
2C6AC CJK UNIFIED IDEOGRAPH-#2C6AC
2C6AD CJK UNIFIED IDEOGRAPH-#2C6AD
2C6AE CJK UNIFIED IDEOGRAPH-#2C6AE
2C6AF CJK UNIFIED IDEOGRAPH-#2C6AF
2C6B0 CJK UNIFIED IDEOGRAPH-#2C6B0
2C6B1 CJK UNIFIED IDEOGRAPH-#2C6B1
2C6B2 CJK UNIFIED IDEOGRAPH-#2C6B2
2C6B3 CJK UNIFIED IDEOGRAPH-#2C6B3
2C6B4 CJK UNIFIED IDEOGRAPH-#2C6B4
2C6B5 CJK UNIFIED IDEOGRAPH-#2C6B5
2C6B6 CJK UNIFIED IDEOGRAPH-#2C6B6
2C6B7 CJK UNIFIED IDEOGRAPH-#2C6B7
2C6B8 CJK UNIFIED IDEOGRAPH-#2C6B8
2C6B9 CJK UNIFIED IDEOGRAPH-#2C6B9
2C6BA CJK UNIFIED IDEOGRAPH-#2C6BA
2C6BB CJK UNIFIED IDEOGRAPH-#2C6BB
2C6BC CJK UNIFIED IDEOGRAPH-#2C6BC
2C6BD CJK UNIFIED IDEOGRAPH-#2C6BD
2C6BE CJK UNIFIED IDEOGRAPH-#2C6BE
2C6BF CJK UNIFIED IDEOGRAPH-#2C6BF
2C6C0 CJK UNIFIED IDEOGRAPH-#2C6C0
2C6C1 CJK UNIFIED IDEOGRAPH-#2C6C1
2C6C2 CJK UNIFIED IDEOGRAPH-#2C6C2
2C6C3 CJK UNIFIED IDEOGRAPH-#2C6C3
2C6C4 CJK UNIFIED IDEOGRAPH-#2C6C4
2C6C5 CJK UNIFIED IDEOGRAPH-#2C6C5
2C6C6 CJK UNIFIED IDEOGRAPH-#2C6C6
2C6C7 CJK UNIFIED IDEOGRAPH-#2C6C7
2C6C8 CJK UNIFIED IDEOGRAPH-#2C6C8
2C6C9 CJK UNIFIED IDEOGRAPH-#2C6C9
2C6CA CJK UNIFIED IDEOGRAPH-#2C6CA
2C6CB CJK UNIFIED IDEOGRAPH-#2C6CB
2C6CC CJK UNIFIED IDEOGRAPH-#2C6CC
2C6CD CJK UNIFIED IDEOGRAPH-#2C6CD
2C6CE CJK UNIFIED IDEOGRAPH-#2C6CE
2C6CF CJK UNIFIED IDEOGRAPH-#2C6CF
2C6D0 CJK UNIFIED IDEOGRAPH-#2C6D0
2C6D1 CJK UNIFIED IDEOGRAPH-#2C6D1
2C6D2 CJK UNIFIED IDEOGRAPH-#2C6D2
2C6D3 CJK UNIFIED IDEOGRAPH-#2C6D3
2C6D4 CJK UNIFIED IDEOGRAPH-#2C6D4
2C6D5 CJK UNIFIED IDEOGRAPH-#2C6D5
2C6D6 CJK UNIFIED IDEOGRAPH-#2C6D6
2C6D7 CJK UNIFIED IDEOGRAPH-#2C6D7
2C6D8 CJK UNIFIED IDEOGRAPH-#2C6D8
2C6D9 CJK UNIFIED IDEOGRAPH-#2C6D9
2C6DA CJK UNIFIED IDEOGRAPH-#2C6DA
2C6DB CJK UNIFIED IDEOGRAPH-#2C6DB
2C6DC CJK UNIFIED IDEOGRAPH-#2C6DC
2C6DD CJK UNIFIED IDEOGRAPH-#2C6DD
2C6DE CJK UNIFIED IDEOGRAPH-#2C6DE
2C6DF CJK UNIFIED IDEOGRAPH-#2C6DF
2C6E0 CJK UNIFIED IDEOGRAPH-#2C6E0
2C6E1 CJK UNIFIED IDEOGRAPH-#2C6E1
2C6E2 CJK UNIFIED IDEOGRAPH-#2C6E2
2C6E3 CJK UNIFIED IDEOGRAPH-#2C6E3
2C6E4 CJK UNIFIED IDEOGRAPH-#2C6E4
2C6E5 CJK UNIFIED IDEOGRAPH-#2C6E5
2C6E6 CJK UNIFIED IDEOGRAPH-#2C6E6
2C6E7 CJK UNIFIED IDEOGRAPH-#2C6E7
2C6E8 CJK UNIFIED IDEOGRAPH-#2C6E8
2C6E9 CJK UNIFIED IDEOGRAPH-#2C6E9
2C6EA CJK UNIFIED IDEOGRAPH-#2C6EA
2C6EB CJK UNIFIED IDEOGRAPH-#2C6EB
2C6EC CJK UNIFIED IDEOGRAPH-#2C6EC
2C6ED CJK UNIFIED IDEOGRAPH-#2C6ED
2C6EE CJK UNIFIED IDEOGRAPH-#2C6EE
2C6EF CJK UNIFIED IDEOGRAPH-#2C6EF
2C6F0 CJK UNIFIED IDEOGRAPH-#2C6F0
2C6F1 CJK UNIFIED IDEOGRAPH-#2C6F1
2C6F2 CJK UNIFIED IDEOGRAPH-#2C6F2
2C6F3 CJK UNIFIED IDEOGRAPH-#2C6F3
2C6F4 CJK UNIFIED IDEOGRAPH-#2C6F4
2C6F5 CJK UNIFIED IDEOGRAPH-#2C6F5
2C6F6 CJK UNIFIED IDEOGRAPH-#2C6F6
2C6F7 CJK UNIFIED IDEOGRAPH-#2C6F7
2C6F8 CJK UNIFIED IDEOGRAPH-#2C6F8
2C6F9 CJK UNIFIED IDEOGRAPH-#2C6F9
2C6FA CJK UNIFIED IDEOGRAPH-#2C6FA
2C6FB CJK UNIFIED IDEOGRAPH-#2C6FB
2C6FC CJK UNIFIED IDEOGRAPH-#2C6FC
2C6FD CJK UNIFIED IDEOGRAPH-#2C6FD
2C6FE CJK UNIFIED IDEOGRAPH-#2C6FE
2C6FF CJK UNIFIED IDEOGRAPH-#2C6FF
2C700 CJK UNIFIED IDEOGRAPH-#2C700
2C701 CJK UNIFIED IDEOGRAPH-#2C701
2C702 CJK UNIFIED IDEOGRAPH-#2C702
2C703 CJK UNIFIED IDEOGRAPH-#2C703
2C704 CJK UNIFIED IDEOGRAPH-#2C704
2C705 CJK UNIFIED IDEOGRAPH-#2C705
2C706 CJK UNIFIED IDEOGRAPH-#2C706
2C707 CJK UNIFIED IDEOGRAPH-#2C707
2C708 CJK UNIFIED IDEOGRAPH-#2C708
2C709 CJK UNIFIED IDEOGRAPH-#2C709
2C70A CJK UNIFIED IDEOGRAPH-#2C70A
2C70B CJK UNIFIED IDEOGRAPH-#2C70B
2C70C CJK UNIFIED IDEOGRAPH-#2C70C
2C70D CJK UNIFIED IDEOGRAPH-#2C70D
2C70E CJK UNIFIED IDEOGRAPH-#2C70E
2C70F CJK UNIFIED IDEOGRAPH-#2C70F
2C710 CJK UNIFIED IDEOGRAPH-#2C710
2C711 CJK UNIFIED IDEOGRAPH-#2C711
2C712 CJK UNIFIED IDEOGRAPH-#2C712
2C713 CJK UNIFIED IDEOGRAPH-#2C713
2C714 CJK UNIFIED IDEOGRAPH-#2C714
2C715 CJK UNIFIED IDEOGRAPH-#2C715
2C716 CJK UNIFIED IDEOGRAPH-#2C716
2C717 CJK UNIFIED IDEOGRAPH-#2C717
2C718 CJK UNIFIED IDEOGRAPH-#2C718
2C719 CJK UNIFIED IDEOGRAPH-#2C719
2C71A CJK UNIFIED IDEOGRAPH-#2C71A
2C71B CJK UNIFIED IDEOGRAPH-#2C71B
2C71C CJK UNIFIED IDEOGRAPH-#2C71C
2C71D CJK UNIFIED IDEOGRAPH-#2C71D
2C71E CJK UNIFIED IDEOGRAPH-#2C71E
2C71F CJK UNIFIED IDEOGRAPH-#2C71F
2C720 CJK UNIFIED IDEOGRAPH-#2C720
2C721 CJK UNIFIED IDEOGRAPH-#2C721
2C722 CJK UNIFIED IDEOGRAPH-#2C722
2C723 CJK UNIFIED IDEOGRAPH-#2C723
2C724 CJK UNIFIED IDEOGRAPH-#2C724
2C725 CJK UNIFIED IDEOGRAPH-#2C725
2C726 CJK UNIFIED IDEOGRAPH-#2C726
2C727 CJK UNIFIED IDEOGRAPH-#2C727
2C728 CJK UNIFIED IDEOGRAPH-#2C728
2C729 CJK UNIFIED IDEOGRAPH-#2C729
2C72A CJK UNIFIED IDEOGRAPH-#2C72A
2C72B CJK UNIFIED IDEOGRAPH-#2C72B
2C72C CJK UNIFIED IDEOGRAPH-#2C72C
2C72D CJK UNIFIED IDEOGRAPH-#2C72D
2C72E CJK UNIFIED IDEOGRAPH-#2C72E
2C72F CJK UNIFIED IDEOGRAPH-#2C72F
2C730 CJK UNIFIED IDEOGRAPH-#2C730
2C731 CJK UNIFIED IDEOGRAPH-#2C731
2C732 CJK UNIFIED IDEOGRAPH-#2C732
2C733 CJK UNIFIED IDEOGRAPH-#2C733
2C734 CJK UNIFIED IDEOGRAPH-#2C734
2C735 CJK UNIFIED IDEOGRAPH-#2C735
2C736 CJK UNIFIED IDEOGRAPH-#2C736
2C737 CJK UNIFIED IDEOGRAPH-#2C737
2C738 CJK UNIFIED IDEOGRAPH-#2C738
2C739 CJK UNIFIED IDEOGRAPH-#2C739
2C73A CJK UNIFIED IDEOGRAPH-#2C73A
2C73B CJK UNIFIED IDEOGRAPH-#2C73B
2C73C CJK UNIFIED IDEOGRAPH-#2C73C
2C73D CJK UNIFIED IDEOGRAPH-#2C73D
2C73E CJK UNIFIED IDEOGRAPH-#2C73E
2C73F CJK UNIFIED IDEOGRAPH-#2C73F
2C740 CJK UNIFIED IDEOGRAPH-#2C740
2C741 CJK UNIFIED IDEOGRAPH-#2C741
2C742 CJK UNIFIED IDEOGRAPH-#2C742
2C743 CJK UNIFIED IDEOGRAPH-#2C743
2C744 CJK UNIFIED IDEOGRAPH-#2C744
2C745 CJK UNIFIED IDEOGRAPH-#2C745
2C746 CJK UNIFIED IDEOGRAPH-#2C746
2C747 CJK UNIFIED IDEOGRAPH-#2C747
2C748 CJK UNIFIED IDEOGRAPH-#2C748
2C749 CJK UNIFIED IDEOGRAPH-#2C749
2C74A CJK UNIFIED IDEOGRAPH-#2C74A
2C74B CJK UNIFIED IDEOGRAPH-#2C74B
2C74C CJK UNIFIED IDEOGRAPH-#2C74C
2C74D CJK UNIFIED IDEOGRAPH-#2C74D
2C74E CJK UNIFIED IDEOGRAPH-#2C74E
2C74F CJK UNIFIED IDEOGRAPH-#2C74F
2C750 CJK UNIFIED IDEOGRAPH-#2C750
2C751 CJK UNIFIED IDEOGRAPH-#2C751
2C752 CJK UNIFIED IDEOGRAPH-#2C752
2C753 CJK UNIFIED IDEOGRAPH-#2C753
2C754 CJK UNIFIED IDEOGRAPH-#2C754
2C755 CJK UNIFIED IDEOGRAPH-#2C755
2C756 CJK UNIFIED IDEOGRAPH-#2C756
2C757 CJK UNIFIED IDEOGRAPH-#2C757
2C758 CJK UNIFIED IDEOGRAPH-#2C758
2C759 CJK UNIFIED IDEOGRAPH-#2C759
2C75A CJK UNIFIED IDEOGRAPH-#2C75A
2C75B CJK UNIFIED IDEOGRAPH-#2C75B
2C75C CJK UNIFIED IDEOGRAPH-#2C75C
2C75D CJK UNIFIED IDEOGRAPH-#2C75D
2C75E CJK UNIFIED IDEOGRAPH-#2C75E
2C75F CJK UNIFIED IDEOGRAPH-#2C75F
2C760 CJK UNIFIED IDEOGRAPH-#2C760
2C761 CJK UNIFIED IDEOGRAPH-#2C761
2C762 CJK UNIFIED IDEOGRAPH-#2C762
2C763 CJK UNIFIED IDEOGRAPH-#2C763
2C764 CJK UNIFIED IDEOGRAPH-#2C764
2C765 CJK UNIFIED IDEOGRAPH-#2C765
2C766 CJK UNIFIED IDEOGRAPH-#2C766
2C767 CJK UNIFIED IDEOGRAPH-#2C767
2C768 CJK UNIFIED IDEOGRAPH-#2C768
2C769 CJK UNIFIED IDEOGRAPH-#2C769
2C76A CJK UNIFIED IDEOGRAPH-#2C76A
2C76B CJK UNIFIED IDEOGRAPH-#2C76B
2C76C CJK UNIFIED IDEOGRAPH-#2C76C
2C76D CJK UNIFIED IDEOGRAPH-#2C76D
2C76E CJK UNIFIED IDEOGRAPH-#2C76E
2C76F CJK UNIFIED IDEOGRAPH-#2C76F
2C770 CJK UNIFIED IDEOGRAPH-#2C770
2C771 CJK UNIFIED IDEOGRAPH-#2C771
2C772 CJK UNIFIED IDEOGRAPH-#2C772
2C773 CJK UNIFIED IDEOGRAPH-#2C773
2C774 CJK UNIFIED IDEOGRAPH-#2C774
2C775 CJK UNIFIED IDEOGRAPH-#2C775
2C776 CJK UNIFIED IDEOGRAPH-#2C776
2C777 CJK UNIFIED IDEOGRAPH-#2C777
2C778 CJK UNIFIED IDEOGRAPH-#2C778
2C779 CJK UNIFIED IDEOGRAPH-#2C779
2C77A CJK UNIFIED IDEOGRAPH-#2C77A
2C77B CJK UNIFIED IDEOGRAPH-#2C77B
2C77C CJK UNIFIED IDEOGRAPH-#2C77C
2C77D CJK UNIFIED IDEOGRAPH-#2C77D
2C77E CJK UNIFIED IDEOGRAPH-#2C77E
2C77F CJK UNIFIED IDEOGRAPH-#2C77F
2C780 CJK UNIFIED IDEOGRAPH-#2C780
2C781 CJK UNIFIED IDEOGRAPH-#2C781
2C782 CJK UNIFIED IDEOGRAPH-#2C782
2C783 CJK UNIFIED IDEOGRAPH-#2C783
2C784 CJK UNIFIED IDEOGRAPH-#2C784
2C785 CJK UNIFIED IDEOGRAPH-#2C785
2C786 CJK UNIFIED IDEOGRAPH-#2C786
2C787 CJK UNIFIED IDEOGRAPH-#2C787
2C788 CJK UNIFIED IDEOGRAPH-#2C788
2C789 CJK UNIFIED IDEOGRAPH-#2C789
2C78A CJK UNIFIED IDEOGRAPH-#2C78A
2C78B CJK UNIFIED IDEOGRAPH-#2C78B
2C78C CJK UNIFIED IDEOGRAPH-#2C78C
2C78D CJK UNIFIED IDEOGRAPH-#2C78D
2C78E CJK UNIFIED IDEOGRAPH-#2C78E
2C78F CJK UNIFIED IDEOGRAPH-#2C78F
2C790 CJK UNIFIED IDEOGRAPH-#2C790
2C791 CJK UNIFIED IDEOGRAPH-#2C791
2C792 CJK UNIFIED IDEOGRAPH-#2C792
2C793 CJK UNIFIED IDEOGRAPH-#2C793
2C794 CJK UNIFIED IDEOGRAPH-#2C794
2C795 CJK UNIFIED IDEOGRAPH-#2C795
2C796 CJK UNIFIED IDEOGRAPH-#2C796
2C797 CJK UNIFIED IDEOGRAPH-#2C797
2C798 CJK UNIFIED IDEOGRAPH-#2C798
2C799 CJK UNIFIED IDEOGRAPH-#2C799
2C79A CJK UNIFIED IDEOGRAPH-#2C79A
2C79B CJK UNIFIED IDEOGRAPH-#2C79B
2C79C CJK UNIFIED IDEOGRAPH-#2C79C
2C79D CJK UNIFIED IDEOGRAPH-#2C79D
2C79E CJK UNIFIED IDEOGRAPH-#2C79E
2C79F CJK UNIFIED IDEOGRAPH-#2C79F
2C7A0 CJK UNIFIED IDEOGRAPH-#2C7A0
2C7A1 CJK UNIFIED IDEOGRAPH-#2C7A1
2C7A2 CJK UNIFIED IDEOGRAPH-#2C7A2
2C7A3 CJK UNIFIED IDEOGRAPH-#2C7A3
2C7A4 CJK UNIFIED IDEOGRAPH-#2C7A4
2C7A5 CJK UNIFIED IDEOGRAPH-#2C7A5
2C7A6 CJK UNIFIED IDEOGRAPH-#2C7A6
2C7A7 CJK UNIFIED IDEOGRAPH-#2C7A7
2C7A8 CJK UNIFIED IDEOGRAPH-#2C7A8
2C7A9 CJK UNIFIED IDEOGRAPH-#2C7A9
2C7AA CJK UNIFIED IDEOGRAPH-#2C7AA
2C7AB CJK UNIFIED IDEOGRAPH-#2C7AB
2C7AC CJK UNIFIED IDEOGRAPH-#2C7AC
2C7AD CJK UNIFIED IDEOGRAPH-#2C7AD
2C7AE CJK UNIFIED IDEOGRAPH-#2C7AE
2C7AF CJK UNIFIED IDEOGRAPH-#2C7AF
2C7B0 CJK UNIFIED IDEOGRAPH-#2C7B0
2C7B1 CJK UNIFIED IDEOGRAPH-#2C7B1
2C7B2 CJK UNIFIED IDEOGRAPH-#2C7B2
2C7B3 CJK UNIFIED IDEOGRAPH-#2C7B3
2C7B4 CJK UNIFIED IDEOGRAPH-#2C7B4
2C7B5 CJK UNIFIED IDEOGRAPH-#2C7B5
2C7B6 CJK UNIFIED IDEOGRAPH-#2C7B6
2C7B7 CJK UNIFIED IDEOGRAPH-#2C7B7
2C7B8 CJK UNIFIED IDEOGRAPH-#2C7B8
2C7B9 CJK UNIFIED IDEOGRAPH-#2C7B9
2C7BA CJK UNIFIED IDEOGRAPH-#2C7BA
2C7BB CJK UNIFIED IDEOGRAPH-#2C7BB
2C7BC CJK UNIFIED IDEOGRAPH-#2C7BC
2C7BD CJK UNIFIED IDEOGRAPH-#2C7BD
2C7BE CJK UNIFIED IDEOGRAPH-#2C7BE
2C7BF CJK UNIFIED IDEOGRAPH-#2C7BF
2C7C0 CJK UNIFIED IDEOGRAPH-#2C7C0
2C7C1 CJK UNIFIED IDEOGRAPH-#2C7C1
2C7C2 CJK UNIFIED IDEOGRAPH-#2C7C2
2C7C3 CJK UNIFIED IDEOGRAPH-#2C7C3
2C7C4 CJK UNIFIED IDEOGRAPH-#2C7C4
2C7C5 CJK UNIFIED IDEOGRAPH-#2C7C5
2C7C6 CJK UNIFIED IDEOGRAPH-#2C7C6
2C7C7 CJK UNIFIED IDEOGRAPH-#2C7C7
2C7C8 CJK UNIFIED IDEOGRAPH-#2C7C8
2C7C9 CJK UNIFIED IDEOGRAPH-#2C7C9
2C7CA CJK UNIFIED IDEOGRAPH-#2C7CA
2C7CB CJK UNIFIED IDEOGRAPH-#2C7CB
2C7CC CJK UNIFIED IDEOGRAPH-#2C7CC
2C7CD CJK UNIFIED IDEOGRAPH-#2C7CD
2C7CE CJK UNIFIED IDEOGRAPH-#2C7CE
2C7CF CJK UNIFIED IDEOGRAPH-#2C7CF
2C7D0 CJK UNIFIED IDEOGRAPH-#2C7D0
2C7D1 CJK UNIFIED IDEOGRAPH-#2C7D1
2C7D2 CJK UNIFIED IDEOGRAPH-#2C7D2
2C7D3 CJK UNIFIED IDEOGRAPH-#2C7D3
2C7D4 CJK UNIFIED IDEOGRAPH-#2C7D4
2C7D5 CJK UNIFIED IDEOGRAPH-#2C7D5
2C7D6 CJK UNIFIED IDEOGRAPH-#2C7D6
2C7D7 CJK UNIFIED IDEOGRAPH-#2C7D7
2C7D8 CJK UNIFIED IDEOGRAPH-#2C7D8
2C7D9 CJK UNIFIED IDEOGRAPH-#2C7D9
2C7DA CJK UNIFIED IDEOGRAPH-#2C7DA
2C7DB CJK UNIFIED IDEOGRAPH-#2C7DB
2C7DC CJK UNIFIED IDEOGRAPH-#2C7DC
2C7DD CJK UNIFIED IDEOGRAPH-#2C7DD
2C7DE CJK UNIFIED IDEOGRAPH-#2C7DE
2C7DF CJK UNIFIED IDEOGRAPH-#2C7DF
2C7E0 CJK UNIFIED IDEOGRAPH-#2C7E0
2C7E1 CJK UNIFIED IDEOGRAPH-#2C7E1
2C7E2 CJK UNIFIED IDEOGRAPH-#2C7E2
2C7E3 CJK UNIFIED IDEOGRAPH-#2C7E3
2C7E4 CJK UNIFIED IDEOGRAPH-#2C7E4
2C7E5 CJK UNIFIED IDEOGRAPH-#2C7E5
2C7E6 CJK UNIFIED IDEOGRAPH-#2C7E6
2C7E7 CJK UNIFIED IDEOGRAPH-#2C7E7
2C7E8 CJK UNIFIED IDEOGRAPH-#2C7E8
2C7E9 CJK UNIFIED IDEOGRAPH-#2C7E9
2C7EA CJK UNIFIED IDEOGRAPH-#2C7EA
2C7EB CJK UNIFIED IDEOGRAPH-#2C7EB
2C7EC CJK UNIFIED IDEOGRAPH-#2C7EC
2C7ED CJK UNIFIED IDEOGRAPH-#2C7ED
2C7EE CJK UNIFIED IDEOGRAPH-#2C7EE
2C7EF CJK UNIFIED IDEOGRAPH-#2C7EF
2C7F0 CJK UNIFIED IDEOGRAPH-#2C7F0
2C7F1 CJK UNIFIED IDEOGRAPH-#2C7F1
2C7F2 CJK UNIFIED IDEOGRAPH-#2C7F2
2C7F3 CJK UNIFIED IDEOGRAPH-#2C7F3
2C7F4 CJK UNIFIED IDEOGRAPH-#2C7F4
2C7F5 CJK UNIFIED IDEOGRAPH-#2C7F5
2C7F6 CJK UNIFIED IDEOGRAPH-#2C7F6
2C7F7 CJK UNIFIED IDEOGRAPH-#2C7F7
2C7F8 CJK UNIFIED IDEOGRAPH-#2C7F8
2C7F9 CJK UNIFIED IDEOGRAPH-#2C7F9
2C7FA CJK UNIFIED IDEOGRAPH-#2C7FA
2C7FB CJK UNIFIED IDEOGRAPH-#2C7FB
2C7FC CJK UNIFIED IDEOGRAPH-#2C7FC
2C7FD CJK UNIFIED IDEOGRAPH-#2C7FD
2C7FE CJK UNIFIED IDEOGRAPH-#2C7FE
2C7FF CJK UNIFIED IDEOGRAPH-#2C7FF
2C800 CJK UNIFIED IDEOGRAPH-#2C800
2C801 CJK UNIFIED IDEOGRAPH-#2C801
2C802 CJK UNIFIED IDEOGRAPH-#2C802
2C803 CJK UNIFIED IDEOGRAPH-#2C803
2C804 CJK UNIFIED IDEOGRAPH-#2C804
2C805 CJK UNIFIED IDEOGRAPH-#2C805
2C806 CJK UNIFIED IDEOGRAPH-#2C806
2C807 CJK UNIFIED IDEOGRAPH-#2C807
2C808 CJK UNIFIED IDEOGRAPH-#2C808
2C809 CJK UNIFIED IDEOGRAPH-#2C809
2C80A CJK UNIFIED IDEOGRAPH-#2C80A
2C80B CJK UNIFIED IDEOGRAPH-#2C80B
2C80C CJK UNIFIED IDEOGRAPH-#2C80C
2C80D CJK UNIFIED IDEOGRAPH-#2C80D
2C80E CJK UNIFIED IDEOGRAPH-#2C80E
2C80F CJK UNIFIED IDEOGRAPH-#2C80F
2C810 CJK UNIFIED IDEOGRAPH-#2C810
2C811 CJK UNIFIED IDEOGRAPH-#2C811
2C812 CJK UNIFIED IDEOGRAPH-#2C812
2C813 CJK UNIFIED IDEOGRAPH-#2C813
2C814 CJK UNIFIED IDEOGRAPH-#2C814
2C815 CJK UNIFIED IDEOGRAPH-#2C815
2C816 CJK UNIFIED IDEOGRAPH-#2C816
2C817 CJK UNIFIED IDEOGRAPH-#2C817
2C818 CJK UNIFIED IDEOGRAPH-#2C818
2C819 CJK UNIFIED IDEOGRAPH-#2C819
2C81A CJK UNIFIED IDEOGRAPH-#2C81A
2C81B CJK UNIFIED IDEOGRAPH-#2C81B
2C81C CJK UNIFIED IDEOGRAPH-#2C81C
2C81D CJK UNIFIED IDEOGRAPH-#2C81D
2C81E CJK UNIFIED IDEOGRAPH-#2C81E
2C81F CJK UNIFIED IDEOGRAPH-#2C81F
2C820 CJK UNIFIED IDEOGRAPH-#2C820
2C821 CJK UNIFIED IDEOGRAPH-#2C821
2C822 CJK UNIFIED IDEOGRAPH-#2C822
2C823 CJK UNIFIED IDEOGRAPH-#2C823
2C824 CJK UNIFIED IDEOGRAPH-#2C824
2C825 CJK UNIFIED IDEOGRAPH-#2C825
2C826 CJK UNIFIED IDEOGRAPH-#2C826
2C827 CJK UNIFIED IDEOGRAPH-#2C827
2C828 CJK UNIFIED IDEOGRAPH-#2C828
2C829 CJK UNIFIED IDEOGRAPH-#2C829
2C82A CJK UNIFIED IDEOGRAPH-#2C82A
2C82B CJK UNIFIED IDEOGRAPH-#2C82B
2C82C CJK UNIFIED IDEOGRAPH-#2C82C
2C82D CJK UNIFIED IDEOGRAPH-#2C82D
2C82E CJK UNIFIED IDEOGRAPH-#2C82E
2C82F CJK UNIFIED IDEOGRAPH-#2C82F
2C830 CJK UNIFIED IDEOGRAPH-#2C830
2C831 CJK UNIFIED IDEOGRAPH-#2C831
2C832 CJK UNIFIED IDEOGRAPH-#2C832
2C833 CJK UNIFIED IDEOGRAPH-#2C833
2C834 CJK UNIFIED IDEOGRAPH-#2C834
2C835 CJK UNIFIED IDEOGRAPH-#2C835
2C836 CJK UNIFIED IDEOGRAPH-#2C836
2C837 CJK UNIFIED IDEOGRAPH-#2C837
2C838 CJK UNIFIED IDEOGRAPH-#2C838
2C839 CJK UNIFIED IDEOGRAPH-#2C839
2C83A CJK UNIFIED IDEOGRAPH-#2C83A
2C83B CJK UNIFIED IDEOGRAPH-#2C83B
2C83C CJK UNIFIED IDEOGRAPH-#2C83C
2C83D CJK UNIFIED IDEOGRAPH-#2C83D
2C83E CJK UNIFIED IDEOGRAPH-#2C83E
2C83F CJK UNIFIED IDEOGRAPH-#2C83F
2C840 CJK UNIFIED IDEOGRAPH-#2C840
2C841 CJK UNIFIED IDEOGRAPH-#2C841
2C842 CJK UNIFIED IDEOGRAPH-#2C842
2C843 CJK UNIFIED IDEOGRAPH-#2C843
2C844 CJK UNIFIED IDEOGRAPH-#2C844
2C845 CJK UNIFIED IDEOGRAPH-#2C845
2C846 CJK UNIFIED IDEOGRAPH-#2C846
2C847 CJK UNIFIED IDEOGRAPH-#2C847
2C848 CJK UNIFIED IDEOGRAPH-#2C848
2C849 CJK UNIFIED IDEOGRAPH-#2C849
2C84A CJK UNIFIED IDEOGRAPH-#2C84A
2C84B CJK UNIFIED IDEOGRAPH-#2C84B
2C84C CJK UNIFIED IDEOGRAPH-#2C84C
2C84D CJK UNIFIED IDEOGRAPH-#2C84D
2C84E CJK UNIFIED IDEOGRAPH-#2C84E
2C84F CJK UNIFIED IDEOGRAPH-#2C84F
2C850 CJK UNIFIED IDEOGRAPH-#2C850
2C851 CJK UNIFIED IDEOGRAPH-#2C851
2C852 CJK UNIFIED IDEOGRAPH-#2C852
2C853 CJK UNIFIED IDEOGRAPH-#2C853
2C854 CJK UNIFIED IDEOGRAPH-#2C854
2C855 CJK UNIFIED IDEOGRAPH-#2C855
2C856 CJK UNIFIED IDEOGRAPH-#2C856
2C857 CJK UNIFIED IDEOGRAPH-#2C857
2C858 CJK UNIFIED IDEOGRAPH-#2C858
2C859 CJK UNIFIED IDEOGRAPH-#2C859
2C85A CJK UNIFIED IDEOGRAPH-#2C85A
2C85B CJK UNIFIED IDEOGRAPH-#2C85B
2C85C CJK UNIFIED IDEOGRAPH-#2C85C
2C85D CJK UNIFIED IDEOGRAPH-#2C85D
2C85E CJK UNIFIED IDEOGRAPH-#2C85E
2C85F CJK UNIFIED IDEOGRAPH-#2C85F
2C860 CJK UNIFIED IDEOGRAPH-#2C860
2C861 CJK UNIFIED IDEOGRAPH-#2C861
2C862 CJK UNIFIED IDEOGRAPH-#2C862
2C863 CJK UNIFIED IDEOGRAPH-#2C863
2C864 CJK UNIFIED IDEOGRAPH-#2C864
2C865 CJK UNIFIED IDEOGRAPH-#2C865
2C866 CJK UNIFIED IDEOGRAPH-#2C866
2C867 CJK UNIFIED IDEOGRAPH-#2C867
2C868 CJK UNIFIED IDEOGRAPH-#2C868
2C869 CJK UNIFIED IDEOGRAPH-#2C869
2C86A CJK UNIFIED IDEOGRAPH-#2C86A
2C86B CJK UNIFIED IDEOGRAPH-#2C86B
2C86C CJK UNIFIED IDEOGRAPH-#2C86C
2C86D CJK UNIFIED IDEOGRAPH-#2C86D
2C86E CJK UNIFIED IDEOGRAPH-#2C86E
2C86F CJK UNIFIED IDEOGRAPH-#2C86F
2C870 CJK UNIFIED IDEOGRAPH-#2C870
2C871 CJK UNIFIED IDEOGRAPH-#2C871
2C872 CJK UNIFIED IDEOGRAPH-#2C872
2C873 CJK UNIFIED IDEOGRAPH-#2C873
2C874 CJK UNIFIED IDEOGRAPH-#2C874
2C875 CJK UNIFIED IDEOGRAPH-#2C875
2C876 CJK UNIFIED IDEOGRAPH-#2C876
2C877 CJK UNIFIED IDEOGRAPH-#2C877
2C878 CJK UNIFIED IDEOGRAPH-#2C878
2C879 CJK UNIFIED IDEOGRAPH-#2C879
2C87A CJK UNIFIED IDEOGRAPH-#2C87A
2C87B CJK UNIFIED IDEOGRAPH-#2C87B
2C87C CJK UNIFIED IDEOGRAPH-#2C87C
2C87D CJK UNIFIED IDEOGRAPH-#2C87D
2C87E CJK UNIFIED IDEOGRAPH-#2C87E
2C87F CJK UNIFIED IDEOGRAPH-#2C87F
2C880 CJK UNIFIED IDEOGRAPH-#2C880
2C881 CJK UNIFIED IDEOGRAPH-#2C881
2C882 CJK UNIFIED IDEOGRAPH-#2C882
2C883 CJK UNIFIED IDEOGRAPH-#2C883
2C884 CJK UNIFIED IDEOGRAPH-#2C884
2C885 CJK UNIFIED IDEOGRAPH-#2C885
2C886 CJK UNIFIED IDEOGRAPH-#2C886
2C887 CJK UNIFIED IDEOGRAPH-#2C887
2C888 CJK UNIFIED IDEOGRAPH-#2C888
2C889 CJK UNIFIED IDEOGRAPH-#2C889
2C88A CJK UNIFIED IDEOGRAPH-#2C88A
2C88B CJK UNIFIED IDEOGRAPH-#2C88B
2C88C CJK UNIFIED IDEOGRAPH-#2C88C
2C88D CJK UNIFIED IDEOGRAPH-#2C88D
2C88E CJK UNIFIED IDEOGRAPH-#2C88E
2C88F CJK UNIFIED IDEOGRAPH-#2C88F
2C890 CJK UNIFIED IDEOGRAPH-#2C890
2C891 CJK UNIFIED IDEOGRAPH-#2C891
2C892 CJK UNIFIED IDEOGRAPH-#2C892
2C893 CJK UNIFIED IDEOGRAPH-#2C893
2C894 CJK UNIFIED IDEOGRAPH-#2C894
2C895 CJK UNIFIED IDEOGRAPH-#2C895
2C896 CJK UNIFIED IDEOGRAPH-#2C896
2C897 CJK UNIFIED IDEOGRAPH-#2C897
2C898 CJK UNIFIED IDEOGRAPH-#2C898
2C899 CJK UNIFIED IDEOGRAPH-#2C899
2C89A CJK UNIFIED IDEOGRAPH-#2C89A
2C89B CJK UNIFIED IDEOGRAPH-#2C89B
2C89C CJK UNIFIED IDEOGRAPH-#2C89C
2C89D CJK UNIFIED IDEOGRAPH-#2C89D
2C89E CJK UNIFIED IDEOGRAPH-#2C89E
2C89F CJK UNIFIED IDEOGRAPH-#2C89F
2C8A0 CJK UNIFIED IDEOGRAPH-#2C8A0
2C8A1 CJK UNIFIED IDEOGRAPH-#2C8A1
2C8A2 CJK UNIFIED IDEOGRAPH-#2C8A2
2C8A3 CJK UNIFIED IDEOGRAPH-#2C8A3
2C8A4 CJK UNIFIED IDEOGRAPH-#2C8A4
2C8A5 CJK UNIFIED IDEOGRAPH-#2C8A5
2C8A6 CJK UNIFIED IDEOGRAPH-#2C8A6
2C8A7 CJK UNIFIED IDEOGRAPH-#2C8A7
2C8A8 CJK UNIFIED IDEOGRAPH-#2C8A8
2C8A9 CJK UNIFIED IDEOGRAPH-#2C8A9
2C8AA CJK UNIFIED IDEOGRAPH-#2C8AA
2C8AB CJK UNIFIED IDEOGRAPH-#2C8AB
2C8AC CJK UNIFIED IDEOGRAPH-#2C8AC
2C8AD CJK UNIFIED IDEOGRAPH-#2C8AD
2C8AE CJK UNIFIED IDEOGRAPH-#2C8AE
2C8AF CJK UNIFIED IDEOGRAPH-#2C8AF
2C8B0 CJK UNIFIED IDEOGRAPH-#2C8B0
2C8B1 CJK UNIFIED IDEOGRAPH-#2C8B1
2C8B2 CJK UNIFIED IDEOGRAPH-#2C8B2
2C8B3 CJK UNIFIED IDEOGRAPH-#2C8B3
2C8B4 CJK UNIFIED IDEOGRAPH-#2C8B4
2C8B5 CJK UNIFIED IDEOGRAPH-#2C8B5
2C8B6 CJK UNIFIED IDEOGRAPH-#2C8B6
2C8B7 CJK UNIFIED IDEOGRAPH-#2C8B7
2C8B8 CJK UNIFIED IDEOGRAPH-#2C8B8
2C8B9 CJK UNIFIED IDEOGRAPH-#2C8B9
2C8BA CJK UNIFIED IDEOGRAPH-#2C8BA
2C8BB CJK UNIFIED IDEOGRAPH-#2C8BB
2C8BC CJK UNIFIED IDEOGRAPH-#2C8BC
2C8BD CJK UNIFIED IDEOGRAPH-#2C8BD
2C8BE CJK UNIFIED IDEOGRAPH-#2C8BE
2C8BF CJK UNIFIED IDEOGRAPH-#2C8BF
2C8C0 CJK UNIFIED IDEOGRAPH-#2C8C0
2C8C1 CJK UNIFIED IDEOGRAPH-#2C8C1
2C8C2 CJK UNIFIED IDEOGRAPH-#2C8C2
2C8C3 CJK UNIFIED IDEOGRAPH-#2C8C3
2C8C4 CJK UNIFIED IDEOGRAPH-#2C8C4
2C8C5 CJK UNIFIED IDEOGRAPH-#2C8C5
2C8C6 CJK UNIFIED IDEOGRAPH-#2C8C6
2C8C7 CJK UNIFIED IDEOGRAPH-#2C8C7
2C8C8 CJK UNIFIED IDEOGRAPH-#2C8C8
2C8C9 CJK UNIFIED IDEOGRAPH-#2C8C9
2C8CA CJK UNIFIED IDEOGRAPH-#2C8CA
2C8CB CJK UNIFIED IDEOGRAPH-#2C8CB
2C8CC CJK UNIFIED IDEOGRAPH-#2C8CC
2C8CD CJK UNIFIED IDEOGRAPH-#2C8CD
2C8CE CJK UNIFIED IDEOGRAPH-#2C8CE
2C8CF CJK UNIFIED IDEOGRAPH-#2C8CF
2C8D0 CJK UNIFIED IDEOGRAPH-#2C8D0
2C8D1 CJK UNIFIED IDEOGRAPH-#2C8D1
2C8D2 CJK UNIFIED IDEOGRAPH-#2C8D2
2C8D3 CJK UNIFIED IDEOGRAPH-#2C8D3
2C8D4 CJK UNIFIED IDEOGRAPH-#2C8D4
2C8D5 CJK UNIFIED IDEOGRAPH-#2C8D5
2C8D6 CJK UNIFIED IDEOGRAPH-#2C8D6
2C8D7 CJK UNIFIED IDEOGRAPH-#2C8D7
2C8D8 CJK UNIFIED IDEOGRAPH-#2C8D8
2C8D9 CJK UNIFIED IDEOGRAPH-#2C8D9
2C8DA CJK UNIFIED IDEOGRAPH-#2C8DA
2C8DB CJK UNIFIED IDEOGRAPH-#2C8DB
2C8DC CJK UNIFIED IDEOGRAPH-#2C8DC
2C8DD CJK UNIFIED IDEOGRAPH-#2C8DD
2C8DE CJK UNIFIED IDEOGRAPH-#2C8DE
2C8DF CJK UNIFIED IDEOGRAPH-#2C8DF
2C8E0 CJK UNIFIED IDEOGRAPH-#2C8E0
2C8E1 CJK UNIFIED IDEOGRAPH-#2C8E1
2C8E2 CJK UNIFIED IDEOGRAPH-#2C8E2
2C8E3 CJK UNIFIED IDEOGRAPH-#2C8E3
2C8E4 CJK UNIFIED IDEOGRAPH-#2C8E4
2C8E5 CJK UNIFIED IDEOGRAPH-#2C8E5
2C8E6 CJK UNIFIED IDEOGRAPH-#2C8E6
2C8E7 CJK UNIFIED IDEOGRAPH-#2C8E7
2C8E8 CJK UNIFIED IDEOGRAPH-#2C8E8
2C8E9 CJK UNIFIED IDEOGRAPH-#2C8E9
2C8EA CJK UNIFIED IDEOGRAPH-#2C8EA
2C8EB CJK UNIFIED IDEOGRAPH-#2C8EB
2C8EC CJK UNIFIED IDEOGRAPH-#2C8EC
2C8ED CJK UNIFIED IDEOGRAPH-#2C8ED
2C8EE CJK UNIFIED IDEOGRAPH-#2C8EE
2C8EF CJK UNIFIED IDEOGRAPH-#2C8EF
2C8F0 CJK UNIFIED IDEOGRAPH-#2C8F0
2C8F1 CJK UNIFIED IDEOGRAPH-#2C8F1
2C8F2 CJK UNIFIED IDEOGRAPH-#2C8F2
2C8F3 CJK UNIFIED IDEOGRAPH-#2C8F3
2C8F4 CJK UNIFIED IDEOGRAPH-#2C8F4
2C8F5 CJK UNIFIED IDEOGRAPH-#2C8F5
2C8F6 CJK UNIFIED IDEOGRAPH-#2C8F6
2C8F7 CJK UNIFIED IDEOGRAPH-#2C8F7
2C8F8 CJK UNIFIED IDEOGRAPH-#2C8F8
2C8F9 CJK UNIFIED IDEOGRAPH-#2C8F9
2C8FA CJK UNIFIED IDEOGRAPH-#2C8FA
2C8FB CJK UNIFIED IDEOGRAPH-#2C8FB
2C8FC CJK UNIFIED IDEOGRAPH-#2C8FC
2C8FD CJK UNIFIED IDEOGRAPH-#2C8FD
2C8FE CJK UNIFIED IDEOGRAPH-#2C8FE
2C8FF CJK UNIFIED IDEOGRAPH-#2C8FF
2C900 CJK UNIFIED IDEOGRAPH-#2C900
2C901 CJK UNIFIED IDEOGRAPH-#2C901
2C902 CJK UNIFIED IDEOGRAPH-#2C902
2C903 CJK UNIFIED IDEOGRAPH-#2C903
2C904 CJK UNIFIED IDEOGRAPH-#2C904
2C905 CJK UNIFIED IDEOGRAPH-#2C905
2C906 CJK UNIFIED IDEOGRAPH-#2C906
2C907 CJK UNIFIED IDEOGRAPH-#2C907
2C908 CJK UNIFIED IDEOGRAPH-#2C908
2C909 CJK UNIFIED IDEOGRAPH-#2C909
2C90A CJK UNIFIED IDEOGRAPH-#2C90A
2C90B CJK UNIFIED IDEOGRAPH-#2C90B
2C90C CJK UNIFIED IDEOGRAPH-#2C90C
2C90D CJK UNIFIED IDEOGRAPH-#2C90D
2C90E CJK UNIFIED IDEOGRAPH-#2C90E
2C90F CJK UNIFIED IDEOGRAPH-#2C90F
2C910 CJK UNIFIED IDEOGRAPH-#2C910
2C911 CJK UNIFIED IDEOGRAPH-#2C911
2C912 CJK UNIFIED IDEOGRAPH-#2C912
2C913 CJK UNIFIED IDEOGRAPH-#2C913
2C914 CJK UNIFIED IDEOGRAPH-#2C914
2C915 CJK UNIFIED IDEOGRAPH-#2C915
2C916 CJK UNIFIED IDEOGRAPH-#2C916
2C917 CJK UNIFIED IDEOGRAPH-#2C917
2C918 CJK UNIFIED IDEOGRAPH-#2C918
2C919 CJK UNIFIED IDEOGRAPH-#2C919
2C91A CJK UNIFIED IDEOGRAPH-#2C91A
2C91B CJK UNIFIED IDEOGRAPH-#2C91B
2C91C CJK UNIFIED IDEOGRAPH-#2C91C
2C91D CJK UNIFIED IDEOGRAPH-#2C91D
2C91E CJK UNIFIED IDEOGRAPH-#2C91E
2C91F CJK UNIFIED IDEOGRAPH-#2C91F
2C920 CJK UNIFIED IDEOGRAPH-#2C920
2C921 CJK UNIFIED IDEOGRAPH-#2C921
2C922 CJK UNIFIED IDEOGRAPH-#2C922
2C923 CJK UNIFIED IDEOGRAPH-#2C923
2C924 CJK UNIFIED IDEOGRAPH-#2C924
2C925 CJK UNIFIED IDEOGRAPH-#2C925
2C926 CJK UNIFIED IDEOGRAPH-#2C926
2C927 CJK UNIFIED IDEOGRAPH-#2C927
2C928 CJK UNIFIED IDEOGRAPH-#2C928
2C929 CJK UNIFIED IDEOGRAPH-#2C929
2C92A CJK UNIFIED IDEOGRAPH-#2C92A
2C92B CJK UNIFIED IDEOGRAPH-#2C92B
2C92C CJK UNIFIED IDEOGRAPH-#2C92C
2C92D CJK UNIFIED IDEOGRAPH-#2C92D
2C92E CJK UNIFIED IDEOGRAPH-#2C92E
2C92F CJK UNIFIED IDEOGRAPH-#2C92F
2C930 CJK UNIFIED IDEOGRAPH-#2C930
2C931 CJK UNIFIED IDEOGRAPH-#2C931
2C932 CJK UNIFIED IDEOGRAPH-#2C932
2C933 CJK UNIFIED IDEOGRAPH-#2C933
2C934 CJK UNIFIED IDEOGRAPH-#2C934
2C935 CJK UNIFIED IDEOGRAPH-#2C935
2C936 CJK UNIFIED IDEOGRAPH-#2C936
2C937 CJK UNIFIED IDEOGRAPH-#2C937
2C938 CJK UNIFIED IDEOGRAPH-#2C938
2C939 CJK UNIFIED IDEOGRAPH-#2C939
2C93A CJK UNIFIED IDEOGRAPH-#2C93A
2C93B CJK UNIFIED IDEOGRAPH-#2C93B
2C93C CJK UNIFIED IDEOGRAPH-#2C93C
2C93D CJK UNIFIED IDEOGRAPH-#2C93D
2C93E CJK UNIFIED IDEOGRAPH-#2C93E
2C93F CJK UNIFIED IDEOGRAPH-#2C93F
2C940 CJK UNIFIED IDEOGRAPH-#2C940
2C941 CJK UNIFIED IDEOGRAPH-#2C941
2C942 CJK UNIFIED IDEOGRAPH-#2C942
2C943 CJK UNIFIED IDEOGRAPH-#2C943
2C944 CJK UNIFIED IDEOGRAPH-#2C944
2C945 CJK UNIFIED IDEOGRAPH-#2C945
2C946 CJK UNIFIED IDEOGRAPH-#2C946
2C947 CJK UNIFIED IDEOGRAPH-#2C947
2C948 CJK UNIFIED IDEOGRAPH-#2C948
2C949 CJK UNIFIED IDEOGRAPH-#2C949
2C94A CJK UNIFIED IDEOGRAPH-#2C94A
2C94B CJK UNIFIED IDEOGRAPH-#2C94B
2C94C CJK UNIFIED IDEOGRAPH-#2C94C
2C94D CJK UNIFIED IDEOGRAPH-#2C94D
2C94E CJK UNIFIED IDEOGRAPH-#2C94E
2C94F CJK UNIFIED IDEOGRAPH-#2C94F
2C950 CJK UNIFIED IDEOGRAPH-#2C950
2C951 CJK UNIFIED IDEOGRAPH-#2C951
2C952 CJK UNIFIED IDEOGRAPH-#2C952
2C953 CJK UNIFIED IDEOGRAPH-#2C953
2C954 CJK UNIFIED IDEOGRAPH-#2C954
2C955 CJK UNIFIED IDEOGRAPH-#2C955
2C956 CJK UNIFIED IDEOGRAPH-#2C956
2C957 CJK UNIFIED IDEOGRAPH-#2C957
2C958 CJK UNIFIED IDEOGRAPH-#2C958
2C959 CJK UNIFIED IDEOGRAPH-#2C959
2C95A CJK UNIFIED IDEOGRAPH-#2C95A
2C95B CJK UNIFIED IDEOGRAPH-#2C95B
2C95C CJK UNIFIED IDEOGRAPH-#2C95C
2C95D CJK UNIFIED IDEOGRAPH-#2C95D
2C95E CJK UNIFIED IDEOGRAPH-#2C95E
2C95F CJK UNIFIED IDEOGRAPH-#2C95F
2C960 CJK UNIFIED IDEOGRAPH-#2C960
2C961 CJK UNIFIED IDEOGRAPH-#2C961
2C962 CJK UNIFIED IDEOGRAPH-#2C962
2C963 CJK UNIFIED IDEOGRAPH-#2C963
2C964 CJK UNIFIED IDEOGRAPH-#2C964
2C965 CJK UNIFIED IDEOGRAPH-#2C965
2C966 CJK UNIFIED IDEOGRAPH-#2C966
2C967 CJK UNIFIED IDEOGRAPH-#2C967
2C968 CJK UNIFIED IDEOGRAPH-#2C968
2C969 CJK UNIFIED IDEOGRAPH-#2C969
2C96A CJK UNIFIED IDEOGRAPH-#2C96A
2C96B CJK UNIFIED IDEOGRAPH-#2C96B
2C96C CJK UNIFIED IDEOGRAPH-#2C96C
2C96D CJK UNIFIED IDEOGRAPH-#2C96D
2C96E CJK UNIFIED IDEOGRAPH-#2C96E
2C96F CJK UNIFIED IDEOGRAPH-#2C96F
2C970 CJK UNIFIED IDEOGRAPH-#2C970
2C971 CJK UNIFIED IDEOGRAPH-#2C971
2C972 CJK UNIFIED IDEOGRAPH-#2C972
2C973 CJK UNIFIED IDEOGRAPH-#2C973
2C974 CJK UNIFIED IDEOGRAPH-#2C974
2C975 CJK UNIFIED IDEOGRAPH-#2C975
2C976 CJK UNIFIED IDEOGRAPH-#2C976
2C977 CJK UNIFIED IDEOGRAPH-#2C977
2C978 CJK UNIFIED IDEOGRAPH-#2C978
2C979 CJK UNIFIED IDEOGRAPH-#2C979
2C97A CJK UNIFIED IDEOGRAPH-#2C97A
2C97B CJK UNIFIED IDEOGRAPH-#2C97B
2C97C CJK UNIFIED IDEOGRAPH-#2C97C
2C97D CJK UNIFIED IDEOGRAPH-#2C97D
2C97E CJK UNIFIED IDEOGRAPH-#2C97E
2C97F CJK UNIFIED IDEOGRAPH-#2C97F
2C980 CJK UNIFIED IDEOGRAPH-#2C980
2C981 CJK UNIFIED IDEOGRAPH-#2C981
2C982 CJK UNIFIED IDEOGRAPH-#2C982
2C983 CJK UNIFIED IDEOGRAPH-#2C983
2C984 CJK UNIFIED IDEOGRAPH-#2C984
2C985 CJK UNIFIED IDEOGRAPH-#2C985
2C986 CJK UNIFIED IDEOGRAPH-#2C986
2C987 CJK UNIFIED IDEOGRAPH-#2C987
2C988 CJK UNIFIED IDEOGRAPH-#2C988
2C989 CJK UNIFIED IDEOGRAPH-#2C989
2C98A CJK UNIFIED IDEOGRAPH-#2C98A
2C98B CJK UNIFIED IDEOGRAPH-#2C98B
2C98C CJK UNIFIED IDEOGRAPH-#2C98C
2C98D CJK UNIFIED IDEOGRAPH-#2C98D
2C98E CJK UNIFIED IDEOGRAPH-#2C98E
2C98F CJK UNIFIED IDEOGRAPH-#2C98F
2C990 CJK UNIFIED IDEOGRAPH-#2C990
2C991 CJK UNIFIED IDEOGRAPH-#2C991
2C992 CJK UNIFIED IDEOGRAPH-#2C992
2C993 CJK UNIFIED IDEOGRAPH-#2C993
2C994 CJK UNIFIED IDEOGRAPH-#2C994
2C995 CJK UNIFIED IDEOGRAPH-#2C995
2C996 CJK UNIFIED IDEOGRAPH-#2C996
2C997 CJK UNIFIED IDEOGRAPH-#2C997
2C998 CJK UNIFIED IDEOGRAPH-#2C998
2C999 CJK UNIFIED IDEOGRAPH-#2C999
2C99A CJK UNIFIED IDEOGRAPH-#2C99A
2C99B CJK UNIFIED IDEOGRAPH-#2C99B
2C99C CJK UNIFIED IDEOGRAPH-#2C99C
2C99D CJK UNIFIED IDEOGRAPH-#2C99D
2C99E CJK UNIFIED IDEOGRAPH-#2C99E
2C99F CJK UNIFIED IDEOGRAPH-#2C99F
2C9A0 CJK UNIFIED IDEOGRAPH-#2C9A0
2C9A1 CJK UNIFIED IDEOGRAPH-#2C9A1
2C9A2 CJK UNIFIED IDEOGRAPH-#2C9A2
2C9A3 CJK UNIFIED IDEOGRAPH-#2C9A3
2C9A4 CJK UNIFIED IDEOGRAPH-#2C9A4
2C9A5 CJK UNIFIED IDEOGRAPH-#2C9A5
2C9A6 CJK UNIFIED IDEOGRAPH-#2C9A6
2C9A7 CJK UNIFIED IDEOGRAPH-#2C9A7
2C9A8 CJK UNIFIED IDEOGRAPH-#2C9A8
2C9A9 CJK UNIFIED IDEOGRAPH-#2C9A9
2C9AA CJK UNIFIED IDEOGRAPH-#2C9AA
2C9AB CJK UNIFIED IDEOGRAPH-#2C9AB
2C9AC CJK UNIFIED IDEOGRAPH-#2C9AC
2C9AD CJK UNIFIED IDEOGRAPH-#2C9AD
2C9AE CJK UNIFIED IDEOGRAPH-#2C9AE
2C9AF CJK UNIFIED IDEOGRAPH-#2C9AF
2C9B0 CJK UNIFIED IDEOGRAPH-#2C9B0
2C9B1 CJK UNIFIED IDEOGRAPH-#2C9B1
2C9B2 CJK UNIFIED IDEOGRAPH-#2C9B2
2C9B3 CJK UNIFIED IDEOGRAPH-#2C9B3
2C9B4 CJK UNIFIED IDEOGRAPH-#2C9B4
2C9B5 CJK UNIFIED IDEOGRAPH-#2C9B5
2C9B6 CJK UNIFIED IDEOGRAPH-#2C9B6
2C9B7 CJK UNIFIED IDEOGRAPH-#2C9B7
2C9B8 CJK UNIFIED IDEOGRAPH-#2C9B8
2C9B9 CJK UNIFIED IDEOGRAPH-#2C9B9
2C9BA CJK UNIFIED IDEOGRAPH-#2C9BA
2C9BB CJK UNIFIED IDEOGRAPH-#2C9BB
2C9BC CJK UNIFIED IDEOGRAPH-#2C9BC
2C9BD CJK UNIFIED IDEOGRAPH-#2C9BD
2C9BE CJK UNIFIED IDEOGRAPH-#2C9BE
2C9BF CJK UNIFIED IDEOGRAPH-#2C9BF
2C9C0 CJK UNIFIED IDEOGRAPH-#2C9C0
2C9C1 CJK UNIFIED IDEOGRAPH-#2C9C1
2C9C2 CJK UNIFIED IDEOGRAPH-#2C9C2
2C9C3 CJK UNIFIED IDEOGRAPH-#2C9C3
2C9C4 CJK UNIFIED IDEOGRAPH-#2C9C4
2C9C5 CJK UNIFIED IDEOGRAPH-#2C9C5
2C9C6 CJK UNIFIED IDEOGRAPH-#2C9C6
2C9C7 CJK UNIFIED IDEOGRAPH-#2C9C7
2C9C8 CJK UNIFIED IDEOGRAPH-#2C9C8
2C9C9 CJK UNIFIED IDEOGRAPH-#2C9C9
2C9CA CJK UNIFIED IDEOGRAPH-#2C9CA
2C9CB CJK UNIFIED IDEOGRAPH-#2C9CB
2C9CC CJK UNIFIED IDEOGRAPH-#2C9CC
2C9CD CJK UNIFIED IDEOGRAPH-#2C9CD
2C9CE CJK UNIFIED IDEOGRAPH-#2C9CE
2C9CF CJK UNIFIED IDEOGRAPH-#2C9CF
2C9D0 CJK UNIFIED IDEOGRAPH-#2C9D0
2C9D1 CJK UNIFIED IDEOGRAPH-#2C9D1
2C9D2 CJK UNIFIED IDEOGRAPH-#2C9D2
2C9D3 CJK UNIFIED IDEOGRAPH-#2C9D3
2C9D4 CJK UNIFIED IDEOGRAPH-#2C9D4
2C9D5 CJK UNIFIED IDEOGRAPH-#2C9D5
2C9D6 CJK UNIFIED IDEOGRAPH-#2C9D6
2C9D7 CJK UNIFIED IDEOGRAPH-#2C9D7
2C9D8 CJK UNIFIED IDEOGRAPH-#2C9D8
2C9D9 CJK UNIFIED IDEOGRAPH-#2C9D9
2C9DA CJK UNIFIED IDEOGRAPH-#2C9DA
2C9DB CJK UNIFIED IDEOGRAPH-#2C9DB
2C9DC CJK UNIFIED IDEOGRAPH-#2C9DC
2C9DD CJK UNIFIED IDEOGRAPH-#2C9DD
2C9DE CJK UNIFIED IDEOGRAPH-#2C9DE
2C9DF CJK UNIFIED IDEOGRAPH-#2C9DF
2C9E0 CJK UNIFIED IDEOGRAPH-#2C9E0
2C9E1 CJK UNIFIED IDEOGRAPH-#2C9E1
2C9E2 CJK UNIFIED IDEOGRAPH-#2C9E2
2C9E3 CJK UNIFIED IDEOGRAPH-#2C9E3
2C9E4 CJK UNIFIED IDEOGRAPH-#2C9E4
2C9E5 CJK UNIFIED IDEOGRAPH-#2C9E5
2C9E6 CJK UNIFIED IDEOGRAPH-#2C9E6
2C9E7 CJK UNIFIED IDEOGRAPH-#2C9E7
2C9E8 CJK UNIFIED IDEOGRAPH-#2C9E8
2C9E9 CJK UNIFIED IDEOGRAPH-#2C9E9
2C9EA CJK UNIFIED IDEOGRAPH-#2C9EA
2C9EB CJK UNIFIED IDEOGRAPH-#2C9EB
2C9EC CJK UNIFIED IDEOGRAPH-#2C9EC
2C9ED CJK UNIFIED IDEOGRAPH-#2C9ED
2C9EE CJK UNIFIED IDEOGRAPH-#2C9EE
2C9EF CJK UNIFIED IDEOGRAPH-#2C9EF
2C9F0 CJK UNIFIED IDEOGRAPH-#2C9F0
2C9F1 CJK UNIFIED IDEOGRAPH-#2C9F1
2C9F2 CJK UNIFIED IDEOGRAPH-#2C9F2
2C9F3 CJK UNIFIED IDEOGRAPH-#2C9F3
2C9F4 CJK UNIFIED IDEOGRAPH-#2C9F4
2C9F5 CJK UNIFIED IDEOGRAPH-#2C9F5
2C9F6 CJK UNIFIED IDEOGRAPH-#2C9F6
2C9F7 CJK UNIFIED IDEOGRAPH-#2C9F7
2C9F8 CJK UNIFIED IDEOGRAPH-#2C9F8
2C9F9 CJK UNIFIED IDEOGRAPH-#2C9F9
2C9FA CJK UNIFIED IDEOGRAPH-#2C9FA
2C9FB CJK UNIFIED IDEOGRAPH-#2C9FB
2C9FC CJK UNIFIED IDEOGRAPH-#2C9FC
2C9FD CJK UNIFIED IDEOGRAPH-#2C9FD
2C9FE CJK UNIFIED IDEOGRAPH-#2C9FE
2C9FF CJK UNIFIED IDEOGRAPH-#2C9FF
2CA00 CJK UNIFIED IDEOGRAPH-#2CA00
2CA01 CJK UNIFIED IDEOGRAPH-#2CA01
2CA02 CJK UNIFIED IDEOGRAPH-#2CA02
2CA03 CJK UNIFIED IDEOGRAPH-#2CA03
2CA04 CJK UNIFIED IDEOGRAPH-#2CA04
2CA05 CJK UNIFIED IDEOGRAPH-#2CA05
2CA06 CJK UNIFIED IDEOGRAPH-#2CA06
2CA07 CJK UNIFIED IDEOGRAPH-#2CA07
2CA08 CJK UNIFIED IDEOGRAPH-#2CA08
2CA09 CJK UNIFIED IDEOGRAPH-#2CA09
2CA0A CJK UNIFIED IDEOGRAPH-#2CA0A
2CA0B CJK UNIFIED IDEOGRAPH-#2CA0B
2CA0C CJK UNIFIED IDEOGRAPH-#2CA0C
2CA0D CJK UNIFIED IDEOGRAPH-#2CA0D
2CA0E CJK UNIFIED IDEOGRAPH-#2CA0E
2CA0F CJK UNIFIED IDEOGRAPH-#2CA0F
2CA10 CJK UNIFIED IDEOGRAPH-#2CA10
2CA11 CJK UNIFIED IDEOGRAPH-#2CA11
2CA12 CJK UNIFIED IDEOGRAPH-#2CA12
2CA13 CJK UNIFIED IDEOGRAPH-#2CA13
2CA14 CJK UNIFIED IDEOGRAPH-#2CA14
2CA15 CJK UNIFIED IDEOGRAPH-#2CA15
2CA16 CJK UNIFIED IDEOGRAPH-#2CA16
2CA17 CJK UNIFIED IDEOGRAPH-#2CA17
2CA18 CJK UNIFIED IDEOGRAPH-#2CA18
2CA19 CJK UNIFIED IDEOGRAPH-#2CA19
2CA1A CJK UNIFIED IDEOGRAPH-#2CA1A
2CA1B CJK UNIFIED IDEOGRAPH-#2CA1B
2CA1C CJK UNIFIED IDEOGRAPH-#2CA1C
2CA1D CJK UNIFIED IDEOGRAPH-#2CA1D
2CA1E CJK UNIFIED IDEOGRAPH-#2CA1E
2CA1F CJK UNIFIED IDEOGRAPH-#2CA1F
2CA20 CJK UNIFIED IDEOGRAPH-#2CA20
2CA21 CJK UNIFIED IDEOGRAPH-#2CA21
2CA22 CJK UNIFIED IDEOGRAPH-#2CA22
2CA23 CJK UNIFIED IDEOGRAPH-#2CA23
2CA24 CJK UNIFIED IDEOGRAPH-#2CA24
2CA25 CJK UNIFIED IDEOGRAPH-#2CA25
2CA26 CJK UNIFIED IDEOGRAPH-#2CA26
2CA27 CJK UNIFIED IDEOGRAPH-#2CA27
2CA28 CJK UNIFIED IDEOGRAPH-#2CA28
2CA29 CJK UNIFIED IDEOGRAPH-#2CA29
2CA2A CJK UNIFIED IDEOGRAPH-#2CA2A
2CA2B CJK UNIFIED IDEOGRAPH-#2CA2B
2CA2C CJK UNIFIED IDEOGRAPH-#2CA2C
2CA2D CJK UNIFIED IDEOGRAPH-#2CA2D
2CA2E CJK UNIFIED IDEOGRAPH-#2CA2E
2CA2F CJK UNIFIED IDEOGRAPH-#2CA2F
2CA30 CJK UNIFIED IDEOGRAPH-#2CA30
2CA31 CJK UNIFIED IDEOGRAPH-#2CA31
2CA32 CJK UNIFIED IDEOGRAPH-#2CA32
2CA33 CJK UNIFIED IDEOGRAPH-#2CA33
2CA34 CJK UNIFIED IDEOGRAPH-#2CA34
2CA35 CJK UNIFIED IDEOGRAPH-#2CA35
2CA36 CJK UNIFIED IDEOGRAPH-#2CA36
2CA37 CJK UNIFIED IDEOGRAPH-#2CA37
2CA38 CJK UNIFIED IDEOGRAPH-#2CA38
2CA39 CJK UNIFIED IDEOGRAPH-#2CA39
2CA3A CJK UNIFIED IDEOGRAPH-#2CA3A
2CA3B CJK UNIFIED IDEOGRAPH-#2CA3B
2CA3C CJK UNIFIED IDEOGRAPH-#2CA3C
2CA3D CJK UNIFIED IDEOGRAPH-#2CA3D
2CA3E CJK UNIFIED IDEOGRAPH-#2CA3E
2CA3F CJK UNIFIED IDEOGRAPH-#2CA3F
2CA40 CJK UNIFIED IDEOGRAPH-#2CA40
2CA41 CJK UNIFIED IDEOGRAPH-#2CA41
2CA42 CJK UNIFIED IDEOGRAPH-#2CA42
2CA43 CJK UNIFIED IDEOGRAPH-#2CA43
2CA44 CJK UNIFIED IDEOGRAPH-#2CA44
2CA45 CJK UNIFIED IDEOGRAPH-#2CA45
2CA46 CJK UNIFIED IDEOGRAPH-#2CA46
2CA47 CJK UNIFIED IDEOGRAPH-#2CA47
2CA48 CJK UNIFIED IDEOGRAPH-#2CA48
2CA49 CJK UNIFIED IDEOGRAPH-#2CA49
2CA4A CJK UNIFIED IDEOGRAPH-#2CA4A
2CA4B CJK UNIFIED IDEOGRAPH-#2CA4B
2CA4C CJK UNIFIED IDEOGRAPH-#2CA4C
2CA4D CJK UNIFIED IDEOGRAPH-#2CA4D
2CA4E CJK UNIFIED IDEOGRAPH-#2CA4E
2CA4F CJK UNIFIED IDEOGRAPH-#2CA4F
2CA50 CJK UNIFIED IDEOGRAPH-#2CA50
2CA51 CJK UNIFIED IDEOGRAPH-#2CA51
2CA52 CJK UNIFIED IDEOGRAPH-#2CA52
2CA53 CJK UNIFIED IDEOGRAPH-#2CA53
2CA54 CJK UNIFIED IDEOGRAPH-#2CA54
2CA55 CJK UNIFIED IDEOGRAPH-#2CA55
2CA56 CJK UNIFIED IDEOGRAPH-#2CA56
2CA57 CJK UNIFIED IDEOGRAPH-#2CA57
2CA58 CJK UNIFIED IDEOGRAPH-#2CA58
2CA59 CJK UNIFIED IDEOGRAPH-#2CA59
2CA5A CJK UNIFIED IDEOGRAPH-#2CA5A
2CA5B CJK UNIFIED IDEOGRAPH-#2CA5B
2CA5C CJK UNIFIED IDEOGRAPH-#2CA5C
2CA5D CJK UNIFIED IDEOGRAPH-#2CA5D
2CA5E CJK UNIFIED IDEOGRAPH-#2CA5E
2CA5F CJK UNIFIED IDEOGRAPH-#2CA5F
2CA60 CJK UNIFIED IDEOGRAPH-#2CA60
2CA61 CJK UNIFIED IDEOGRAPH-#2CA61
2CA62 CJK UNIFIED IDEOGRAPH-#2CA62
2CA63 CJK UNIFIED IDEOGRAPH-#2CA63
2CA64 CJK UNIFIED IDEOGRAPH-#2CA64
2CA65 CJK UNIFIED IDEOGRAPH-#2CA65
2CA66 CJK UNIFIED IDEOGRAPH-#2CA66
2CA67 CJK UNIFIED IDEOGRAPH-#2CA67
2CA68 CJK UNIFIED IDEOGRAPH-#2CA68
2CA69 CJK UNIFIED IDEOGRAPH-#2CA69
2CA6A CJK UNIFIED IDEOGRAPH-#2CA6A
2CA6B CJK UNIFIED IDEOGRAPH-#2CA6B
2CA6C CJK UNIFIED IDEOGRAPH-#2CA6C
2CA6D CJK UNIFIED IDEOGRAPH-#2CA6D
2CA6E CJK UNIFIED IDEOGRAPH-#2CA6E
2CA6F CJK UNIFIED IDEOGRAPH-#2CA6F
2CA70 CJK UNIFIED IDEOGRAPH-#2CA70
2CA71 CJK UNIFIED IDEOGRAPH-#2CA71
2CA72 CJK UNIFIED IDEOGRAPH-#2CA72
2CA73 CJK UNIFIED IDEOGRAPH-#2CA73
2CA74 CJK UNIFIED IDEOGRAPH-#2CA74
2CA75 CJK UNIFIED IDEOGRAPH-#2CA75
2CA76 CJK UNIFIED IDEOGRAPH-#2CA76
2CA77 CJK UNIFIED IDEOGRAPH-#2CA77
2CA78 CJK UNIFIED IDEOGRAPH-#2CA78
2CA79 CJK UNIFIED IDEOGRAPH-#2CA79
2CA7A CJK UNIFIED IDEOGRAPH-#2CA7A
2CA7B CJK UNIFIED IDEOGRAPH-#2CA7B
2CA7C CJK UNIFIED IDEOGRAPH-#2CA7C
2CA7D CJK UNIFIED IDEOGRAPH-#2CA7D
2CA7E CJK UNIFIED IDEOGRAPH-#2CA7E
2CA7F CJK UNIFIED IDEOGRAPH-#2CA7F
2CA80 CJK UNIFIED IDEOGRAPH-#2CA80
2CA81 CJK UNIFIED IDEOGRAPH-#2CA81
2CA82 CJK UNIFIED IDEOGRAPH-#2CA82
2CA83 CJK UNIFIED IDEOGRAPH-#2CA83
2CA84 CJK UNIFIED IDEOGRAPH-#2CA84
2CA85 CJK UNIFIED IDEOGRAPH-#2CA85
2CA86 CJK UNIFIED IDEOGRAPH-#2CA86
2CA87 CJK UNIFIED IDEOGRAPH-#2CA87
2CA88 CJK UNIFIED IDEOGRAPH-#2CA88
2CA89 CJK UNIFIED IDEOGRAPH-#2CA89
2CA8A CJK UNIFIED IDEOGRAPH-#2CA8A
2CA8B CJK UNIFIED IDEOGRAPH-#2CA8B
2CA8C CJK UNIFIED IDEOGRAPH-#2CA8C
2CA8D CJK UNIFIED IDEOGRAPH-#2CA8D
2CA8E CJK UNIFIED IDEOGRAPH-#2CA8E
2CA8F CJK UNIFIED IDEOGRAPH-#2CA8F
2CA90 CJK UNIFIED IDEOGRAPH-#2CA90
2CA91 CJK UNIFIED IDEOGRAPH-#2CA91
2CA92 CJK UNIFIED IDEOGRAPH-#2CA92
2CA93 CJK UNIFIED IDEOGRAPH-#2CA93
2CA94 CJK UNIFIED IDEOGRAPH-#2CA94
2CA95 CJK UNIFIED IDEOGRAPH-#2CA95
2CA96 CJK UNIFIED IDEOGRAPH-#2CA96
2CA97 CJK UNIFIED IDEOGRAPH-#2CA97
2CA98 CJK UNIFIED IDEOGRAPH-#2CA98
2CA99 CJK UNIFIED IDEOGRAPH-#2CA99
2CA9A CJK UNIFIED IDEOGRAPH-#2CA9A
2CA9B CJK UNIFIED IDEOGRAPH-#2CA9B
2CA9C CJK UNIFIED IDEOGRAPH-#2CA9C
2CA9D CJK UNIFIED IDEOGRAPH-#2CA9D
2CA9E CJK UNIFIED IDEOGRAPH-#2CA9E
2CA9F CJK UNIFIED IDEOGRAPH-#2CA9F
2CAA0 CJK UNIFIED IDEOGRAPH-#2CAA0
2CAA1 CJK UNIFIED IDEOGRAPH-#2CAA1
2CAA2 CJK UNIFIED IDEOGRAPH-#2CAA2
2CAA3 CJK UNIFIED IDEOGRAPH-#2CAA3
2CAA4 CJK UNIFIED IDEOGRAPH-#2CAA4
2CAA5 CJK UNIFIED IDEOGRAPH-#2CAA5
2CAA6 CJK UNIFIED IDEOGRAPH-#2CAA6
2CAA7 CJK UNIFIED IDEOGRAPH-#2CAA7
2CAA8 CJK UNIFIED IDEOGRAPH-#2CAA8
2CAA9 CJK UNIFIED IDEOGRAPH-#2CAA9
2CAAA CJK UNIFIED IDEOGRAPH-#2CAAA
2CAAB CJK UNIFIED IDEOGRAPH-#2CAAB
2CAAC CJK UNIFIED IDEOGRAPH-#2CAAC
2CAAD CJK UNIFIED IDEOGRAPH-#2CAAD
2CAAE CJK UNIFIED IDEOGRAPH-#2CAAE
2CAAF CJK UNIFIED IDEOGRAPH-#2CAAF
2CAB0 CJK UNIFIED IDEOGRAPH-#2CAB0
2CAB1 CJK UNIFIED IDEOGRAPH-#2CAB1
2CAB2 CJK UNIFIED IDEOGRAPH-#2CAB2
2CAB3 CJK UNIFIED IDEOGRAPH-#2CAB3
2CAB4 CJK UNIFIED IDEOGRAPH-#2CAB4
2CAB5 CJK UNIFIED IDEOGRAPH-#2CAB5
2CAB6 CJK UNIFIED IDEOGRAPH-#2CAB6
2CAB7 CJK UNIFIED IDEOGRAPH-#2CAB7
2CAB8 CJK UNIFIED IDEOGRAPH-#2CAB8
2CAB9 CJK UNIFIED IDEOGRAPH-#2CAB9
2CABA CJK UNIFIED IDEOGRAPH-#2CABA
2CABB CJK UNIFIED IDEOGRAPH-#2CABB
2CABC CJK UNIFIED IDEOGRAPH-#2CABC
2CABD CJK UNIFIED IDEOGRAPH-#2CABD
2CABE CJK UNIFIED IDEOGRAPH-#2CABE
2CABF CJK UNIFIED IDEOGRAPH-#2CABF, Def{a square meter; one hundredth of a 公畝}
2CAC0 CJK UNIFIED IDEOGRAPH-#2CAC0
2CAC1 CJK UNIFIED IDEOGRAPH-#2CAC1
2CAC2 CJK UNIFIED IDEOGRAPH-#2CAC2
2CAC3 CJK UNIFIED IDEOGRAPH-#2CAC3
2CAC4 CJK UNIFIED IDEOGRAPH-#2CAC4
2CAC5 CJK UNIFIED IDEOGRAPH-#2CAC5
2CAC6 CJK UNIFIED IDEOGRAPH-#2CAC6
2CAC7 CJK UNIFIED IDEOGRAPH-#2CAC7
2CAC8 CJK UNIFIED IDEOGRAPH-#2CAC8
2CAC9 CJK UNIFIED IDEOGRAPH-#2CAC9
2CACA CJK UNIFIED IDEOGRAPH-#2CACA
2CACB CJK UNIFIED IDEOGRAPH-#2CACB
2CACC CJK UNIFIED IDEOGRAPH-#2CACC
2CACD CJK UNIFIED IDEOGRAPH-#2CACD
2CACE CJK UNIFIED IDEOGRAPH-#2CACE
2CACF CJK UNIFIED IDEOGRAPH-#2CACF
2CAD0 CJK UNIFIED IDEOGRAPH-#2CAD0
2CAD1 CJK UNIFIED IDEOGRAPH-#2CAD1
2CAD2 CJK UNIFIED IDEOGRAPH-#2CAD2
2CAD3 CJK UNIFIED IDEOGRAPH-#2CAD3
2CAD4 CJK UNIFIED IDEOGRAPH-#2CAD4
2CAD5 CJK UNIFIED IDEOGRAPH-#2CAD5
2CAD6 CJK UNIFIED IDEOGRAPH-#2CAD6
2CAD7 CJK UNIFIED IDEOGRAPH-#2CAD7
2CAD8 CJK UNIFIED IDEOGRAPH-#2CAD8
2CAD9 CJK UNIFIED IDEOGRAPH-#2CAD9
2CADA CJK UNIFIED IDEOGRAPH-#2CADA
2CADB CJK UNIFIED IDEOGRAPH-#2CADB
2CADC CJK UNIFIED IDEOGRAPH-#2CADC
2CADD CJK UNIFIED IDEOGRAPH-#2CADD
2CADE CJK UNIFIED IDEOGRAPH-#2CADE
2CADF CJK UNIFIED IDEOGRAPH-#2CADF
2CAE0 CJK UNIFIED IDEOGRAPH-#2CAE0
2CAE1 CJK UNIFIED IDEOGRAPH-#2CAE1
2CAE2 CJK UNIFIED IDEOGRAPH-#2CAE2
2CAE3 CJK UNIFIED IDEOGRAPH-#2CAE3
2CAE4 CJK UNIFIED IDEOGRAPH-#2CAE4
2CAE5 CJK UNIFIED IDEOGRAPH-#2CAE5
2CAE6 CJK UNIFIED IDEOGRAPH-#2CAE6
2CAE7 CJK UNIFIED IDEOGRAPH-#2CAE7
2CAE8 CJK UNIFIED IDEOGRAPH-#2CAE8
2CAE9 CJK UNIFIED IDEOGRAPH-#2CAE9
2CAEA CJK UNIFIED IDEOGRAPH-#2CAEA
2CAEB CJK UNIFIED IDEOGRAPH-#2CAEB
2CAEC CJK UNIFIED IDEOGRAPH-#2CAEC
2CAED CJK UNIFIED IDEOGRAPH-#2CAED
2CAEE CJK UNIFIED IDEOGRAPH-#2CAEE
2CAEF CJK UNIFIED IDEOGRAPH-#2CAEF
2CAF0 CJK UNIFIED IDEOGRAPH-#2CAF0
2CAF1 CJK UNIFIED IDEOGRAPH-#2CAF1
2CAF2 CJK UNIFIED IDEOGRAPH-#2CAF2
2CAF3 CJK UNIFIED IDEOGRAPH-#2CAF3
2CAF4 CJK UNIFIED IDEOGRAPH-#2CAF4
2CAF5 CJK UNIFIED IDEOGRAPH-#2CAF5
2CAF6 CJK UNIFIED IDEOGRAPH-#2CAF6
2CAF7 CJK UNIFIED IDEOGRAPH-#2CAF7
2CAF8 CJK UNIFIED IDEOGRAPH-#2CAF8
2CAF9 CJK UNIFIED IDEOGRAPH-#2CAF9
2CAFA CJK UNIFIED IDEOGRAPH-#2CAFA
2CAFB CJK UNIFIED IDEOGRAPH-#2CAFB
2CAFC CJK UNIFIED IDEOGRAPH-#2CAFC
2CAFD CJK UNIFIED IDEOGRAPH-#2CAFD
2CAFE CJK UNIFIED IDEOGRAPH-#2CAFE
2CAFF CJK UNIFIED IDEOGRAPH-#2CAFF
2CB00 CJK UNIFIED IDEOGRAPH-#2CB00
2CB01 CJK UNIFIED IDEOGRAPH-#2CB01
2CB02 CJK UNIFIED IDEOGRAPH-#2CB02
2CB03 CJK UNIFIED IDEOGRAPH-#2CB03
2CB04 CJK UNIFIED IDEOGRAPH-#2CB04
2CB05 CJK UNIFIED IDEOGRAPH-#2CB05
2CB06 CJK UNIFIED IDEOGRAPH-#2CB06
2CB07 CJK UNIFIED IDEOGRAPH-#2CB07
2CB08 CJK UNIFIED IDEOGRAPH-#2CB08
2CB09 CJK UNIFIED IDEOGRAPH-#2CB09
2CB0A CJK UNIFIED IDEOGRAPH-#2CB0A
2CB0B CJK UNIFIED IDEOGRAPH-#2CB0B
2CB0C CJK UNIFIED IDEOGRAPH-#2CB0C
2CB0D CJK UNIFIED IDEOGRAPH-#2CB0D
2CB0E CJK UNIFIED IDEOGRAPH-#2CB0E
2CB0F CJK UNIFIED IDEOGRAPH-#2CB0F
2CB10 CJK UNIFIED IDEOGRAPH-#2CB10
2CB11 CJK UNIFIED IDEOGRAPH-#2CB11
2CB12 CJK UNIFIED IDEOGRAPH-#2CB12
2CB13 CJK UNIFIED IDEOGRAPH-#2CB13
2CB14 CJK UNIFIED IDEOGRAPH-#2CB14
2CB15 CJK UNIFIED IDEOGRAPH-#2CB15
2CB16 CJK UNIFIED IDEOGRAPH-#2CB16
2CB17 CJK UNIFIED IDEOGRAPH-#2CB17
2CB18 CJK UNIFIED IDEOGRAPH-#2CB18
2CB19 CJK UNIFIED IDEOGRAPH-#2CB19
2CB1A CJK UNIFIED IDEOGRAPH-#2CB1A
2CB1B CJK UNIFIED IDEOGRAPH-#2CB1B
2CB1C CJK UNIFIED IDEOGRAPH-#2CB1C
2CB1D CJK UNIFIED IDEOGRAPH-#2CB1D
2CB1E CJK UNIFIED IDEOGRAPH-#2CB1E
2CB1F CJK UNIFIED IDEOGRAPH-#2CB1F
2CB20 CJK UNIFIED IDEOGRAPH-#2CB20
2CB21 CJK UNIFIED IDEOGRAPH-#2CB21
2CB22 CJK UNIFIED IDEOGRAPH-#2CB22
2CB23 CJK UNIFIED IDEOGRAPH-#2CB23
2CB24 CJK UNIFIED IDEOGRAPH-#2CB24
2CB25 CJK UNIFIED IDEOGRAPH-#2CB25
2CB26 CJK UNIFIED IDEOGRAPH-#2CB26
2CB27 CJK UNIFIED IDEOGRAPH-#2CB27
2CB28 CJK UNIFIED IDEOGRAPH-#2CB28
2CB29 CJK UNIFIED IDEOGRAPH-#2CB29
2CB2A CJK UNIFIED IDEOGRAPH-#2CB2A
2CB2B CJK UNIFIED IDEOGRAPH-#2CB2B
2CB2C CJK UNIFIED IDEOGRAPH-#2CB2C
2CB2D CJK UNIFIED IDEOGRAPH-#2CB2D
2CB2E CJK UNIFIED IDEOGRAPH-#2CB2E
2CB2F CJK UNIFIED IDEOGRAPH-#2CB2F
2CB30 CJK UNIFIED IDEOGRAPH-#2CB30
2CB31 CJK UNIFIED IDEOGRAPH-#2CB31
2CB32 CJK UNIFIED IDEOGRAPH-#2CB32
2CB33 CJK UNIFIED IDEOGRAPH-#2CB33
2CB34 CJK UNIFIED IDEOGRAPH-#2CB34
2CB35 CJK UNIFIED IDEOGRAPH-#2CB35
2CB36 CJK UNIFIED IDEOGRAPH-#2CB36
2CB37 CJK UNIFIED IDEOGRAPH-#2CB37
2CB38 CJK UNIFIED IDEOGRAPH-#2CB38
2CB39 CJK UNIFIED IDEOGRAPH-#2CB39
2CB3A CJK UNIFIED IDEOGRAPH-#2CB3A
2CB3B CJK UNIFIED IDEOGRAPH-#2CB3B
2CB3C CJK UNIFIED IDEOGRAPH-#2CB3C
2CB3D CJK UNIFIED IDEOGRAPH-#2CB3D
2CB3E CJK UNIFIED IDEOGRAPH-#2CB3E
2CB3F CJK UNIFIED IDEOGRAPH-#2CB3F
2CB40 CJK UNIFIED IDEOGRAPH-#2CB40
2CB41 CJK UNIFIED IDEOGRAPH-#2CB41
2CB42 CJK UNIFIED IDEOGRAPH-#2CB42
2CB43 CJK UNIFIED IDEOGRAPH-#2CB43
2CB44 CJK UNIFIED IDEOGRAPH-#2CB44
2CB45 CJK UNIFIED IDEOGRAPH-#2CB45
2CB46 CJK UNIFIED IDEOGRAPH-#2CB46
2CB47 CJK UNIFIED IDEOGRAPH-#2CB47
2CB48 CJK UNIFIED IDEOGRAPH-#2CB48
2CB49 CJK UNIFIED IDEOGRAPH-#2CB49
2CB4A CJK UNIFIED IDEOGRAPH-#2CB4A
2CB4B CJK UNIFIED IDEOGRAPH-#2CB4B
2CB4C CJK UNIFIED IDEOGRAPH-#2CB4C
2CB4D CJK UNIFIED IDEOGRAPH-#2CB4D
2CB4E CJK UNIFIED IDEOGRAPH-#2CB4E
2CB4F CJK UNIFIED IDEOGRAPH-#2CB4F
2CB50 CJK UNIFIED IDEOGRAPH-#2CB50
2CB51 CJK UNIFIED IDEOGRAPH-#2CB51
2CB52 CJK UNIFIED IDEOGRAPH-#2CB52
2CB53 CJK UNIFIED IDEOGRAPH-#2CB53
2CB54 CJK UNIFIED IDEOGRAPH-#2CB54
2CB55 CJK UNIFIED IDEOGRAPH-#2CB55
2CB56 CJK UNIFIED IDEOGRAPH-#2CB56
2CB57 CJK UNIFIED IDEOGRAPH-#2CB57
2CB58 CJK UNIFIED IDEOGRAPH-#2CB58
2CB59 CJK UNIFIED IDEOGRAPH-#2CB59
2CB5A CJK UNIFIED IDEOGRAPH-#2CB5A
2CB5B CJK UNIFIED IDEOGRAPH-#2CB5B
2CB5C CJK UNIFIED IDEOGRAPH-#2CB5C
2CB5D CJK UNIFIED IDEOGRAPH-#2CB5D
2CB5E CJK UNIFIED IDEOGRAPH-#2CB5E
2CB5F CJK UNIFIED IDEOGRAPH-#2CB5F
2CB60 CJK UNIFIED IDEOGRAPH-#2CB60
2CB61 CJK UNIFIED IDEOGRAPH-#2CB61
2CB62 CJK UNIFIED IDEOGRAPH-#2CB62
2CB63 CJK UNIFIED IDEOGRAPH-#2CB63
2CB64 CJK UNIFIED IDEOGRAPH-#2CB64
2CB65 CJK UNIFIED IDEOGRAPH-#2CB65
2CB66 CJK UNIFIED IDEOGRAPH-#2CB66
2CB67 CJK UNIFIED IDEOGRAPH-#2CB67
2CB68 CJK UNIFIED IDEOGRAPH-#2CB68
2CB69 CJK UNIFIED IDEOGRAPH-#2CB69
2CB6A CJK UNIFIED IDEOGRAPH-#2CB6A
2CB6B CJK UNIFIED IDEOGRAPH-#2CB6B
2CB6C CJK UNIFIED IDEOGRAPH-#2CB6C
2CB6D CJK UNIFIED IDEOGRAPH-#2CB6D
2CB6E CJK UNIFIED IDEOGRAPH-#2CB6E
2CB6F CJK UNIFIED IDEOGRAPH-#2CB6F
2CB70 CJK UNIFIED IDEOGRAPH-#2CB70
2CB71 CJK UNIFIED IDEOGRAPH-#2CB71
2CB72 CJK UNIFIED IDEOGRAPH-#2CB72
2CB73 CJK UNIFIED IDEOGRAPH-#2CB73
2CB74 CJK UNIFIED IDEOGRAPH-#2CB74
2CB75 CJK UNIFIED IDEOGRAPH-#2CB75
2CB76 CJK UNIFIED IDEOGRAPH-#2CB76
2CB77 CJK UNIFIED IDEOGRAPH-#2CB77
2CB78 CJK UNIFIED IDEOGRAPH-#2CB78
2CB79 CJK UNIFIED IDEOGRAPH-#2CB79
2CB7A CJK UNIFIED IDEOGRAPH-#2CB7A
2CB7B CJK UNIFIED IDEOGRAPH-#2CB7B
2CB7C CJK UNIFIED IDEOGRAPH-#2CB7C
2CB7D CJK UNIFIED IDEOGRAPH-#2CB7D
2CB7E CJK UNIFIED IDEOGRAPH-#2CB7E
2CB7F CJK UNIFIED IDEOGRAPH-#2CB7F
2CB80 CJK UNIFIED IDEOGRAPH-#2CB80
2CB81 CJK UNIFIED IDEOGRAPH-#2CB81
2CB82 CJK UNIFIED IDEOGRAPH-#2CB82
2CB83 CJK UNIFIED IDEOGRAPH-#2CB83
2CB84 CJK UNIFIED IDEOGRAPH-#2CB84
2CB85 CJK UNIFIED IDEOGRAPH-#2CB85
2CB86 CJK UNIFIED IDEOGRAPH-#2CB86
2CB87 CJK UNIFIED IDEOGRAPH-#2CB87
2CB88 CJK UNIFIED IDEOGRAPH-#2CB88
2CB89 CJK UNIFIED IDEOGRAPH-#2CB89
2CB8A CJK UNIFIED IDEOGRAPH-#2CB8A
2CB8B CJK UNIFIED IDEOGRAPH-#2CB8B
2CB8C CJK UNIFIED IDEOGRAPH-#2CB8C
2CB8D CJK UNIFIED IDEOGRAPH-#2CB8D
2CB8E CJK UNIFIED IDEOGRAPH-#2CB8E
2CB8F CJK UNIFIED IDEOGRAPH-#2CB8F
2CB90 CJK UNIFIED IDEOGRAPH-#2CB90
2CB91 CJK UNIFIED IDEOGRAPH-#2CB91
2CB92 CJK UNIFIED IDEOGRAPH-#2CB92
2CB93 CJK UNIFIED IDEOGRAPH-#2CB93
2CB94 CJK UNIFIED IDEOGRAPH-#2CB94
2CB95 CJK UNIFIED IDEOGRAPH-#2CB95
2CB96 CJK UNIFIED IDEOGRAPH-#2CB96
2CB97 CJK UNIFIED IDEOGRAPH-#2CB97
2CB98 CJK UNIFIED IDEOGRAPH-#2CB98
2CB99 CJK UNIFIED IDEOGRAPH-#2CB99
2CB9A CJK UNIFIED IDEOGRAPH-#2CB9A
2CB9B CJK UNIFIED IDEOGRAPH-#2CB9B
2CB9C CJK UNIFIED IDEOGRAPH-#2CB9C
2CB9D CJK UNIFIED IDEOGRAPH-#2CB9D
2CB9E CJK UNIFIED IDEOGRAPH-#2CB9E
2CB9F CJK UNIFIED IDEOGRAPH-#2CB9F
2CBA0 CJK UNIFIED IDEOGRAPH-#2CBA0
2CBA1 CJK UNIFIED IDEOGRAPH-#2CBA1
2CBA2 CJK UNIFIED IDEOGRAPH-#2CBA2
2CBA3 CJK UNIFIED IDEOGRAPH-#2CBA3
2CBA4 CJK UNIFIED IDEOGRAPH-#2CBA4
2CBA5 CJK UNIFIED IDEOGRAPH-#2CBA5
2CBA6 CJK UNIFIED IDEOGRAPH-#2CBA6
2CBA7 CJK UNIFIED IDEOGRAPH-#2CBA7
2CBA8 CJK UNIFIED IDEOGRAPH-#2CBA8
2CBA9 CJK UNIFIED IDEOGRAPH-#2CBA9
2CBAA CJK UNIFIED IDEOGRAPH-#2CBAA
2CBAB CJK UNIFIED IDEOGRAPH-#2CBAB
2CBAC CJK UNIFIED IDEOGRAPH-#2CBAC
2CBAD CJK UNIFIED IDEOGRAPH-#2CBAD
2CBAE CJK UNIFIED IDEOGRAPH-#2CBAE
2CBAF CJK UNIFIED IDEOGRAPH-#2CBAF
2CBB0 CJK UNIFIED IDEOGRAPH-#2CBB0
2CBB1 CJK UNIFIED IDEOGRAPH-#2CBB1
2CBB2 CJK UNIFIED IDEOGRAPH-#2CBB2
2CBB3 CJK UNIFIED IDEOGRAPH-#2CBB3
2CBB4 CJK UNIFIED IDEOGRAPH-#2CBB4
2CBB5 CJK UNIFIED IDEOGRAPH-#2CBB5
2CBB6 CJK UNIFIED IDEOGRAPH-#2CBB6
2CBB7 CJK UNIFIED IDEOGRAPH-#2CBB7
2CBB8 CJK UNIFIED IDEOGRAPH-#2CBB8
2CBB9 CJK UNIFIED IDEOGRAPH-#2CBB9
2CBBA CJK UNIFIED IDEOGRAPH-#2CBBA
2CBBB CJK UNIFIED IDEOGRAPH-#2CBBB
2CBBC CJK UNIFIED IDEOGRAPH-#2CBBC
2CBBD CJK UNIFIED IDEOGRAPH-#2CBBD
2CBBE CJK UNIFIED IDEOGRAPH-#2CBBE
2CBBF CJK UNIFIED IDEOGRAPH-#2CBBF
2CBC0 CJK UNIFIED IDEOGRAPH-#2CBC0
2CBC1 CJK UNIFIED IDEOGRAPH-#2CBC1
2CBC2 CJK UNIFIED IDEOGRAPH-#2CBC2
2CBC3 CJK UNIFIED IDEOGRAPH-#2CBC3
2CBC4 CJK UNIFIED IDEOGRAPH-#2CBC4
2CBC5 CJK UNIFIED IDEOGRAPH-#2CBC5
2CBC6 CJK UNIFIED IDEOGRAPH-#2CBC6
2CBC7 CJK UNIFIED IDEOGRAPH-#2CBC7
2CBC8 CJK UNIFIED IDEOGRAPH-#2CBC8
2CBC9 CJK UNIFIED IDEOGRAPH-#2CBC9
2CBCA CJK UNIFIED IDEOGRAPH-#2CBCA
2CBCB CJK UNIFIED IDEOGRAPH-#2CBCB
2CBCC CJK UNIFIED IDEOGRAPH-#2CBCC
2CBCD CJK UNIFIED IDEOGRAPH-#2CBCD
2CBCE CJK UNIFIED IDEOGRAPH-#2CBCE
2CBCF CJK UNIFIED IDEOGRAPH-#2CBCF
2CBD0 CJK UNIFIED IDEOGRAPH-#2CBD0
2CBD1 CJK UNIFIED IDEOGRAPH-#2CBD1
2CBD2 CJK UNIFIED IDEOGRAPH-#2CBD2
2CBD3 CJK UNIFIED IDEOGRAPH-#2CBD3
2CBD4 CJK UNIFIED IDEOGRAPH-#2CBD4
2CBD5 CJK UNIFIED IDEOGRAPH-#2CBD5
2CBD6 CJK UNIFIED IDEOGRAPH-#2CBD6
2CBD7 CJK UNIFIED IDEOGRAPH-#2CBD7
2CBD8 CJK UNIFIED IDEOGRAPH-#2CBD8
2CBD9 CJK UNIFIED IDEOGRAPH-#2CBD9
2CBDA CJK UNIFIED IDEOGRAPH-#2CBDA
2CBDB CJK UNIFIED IDEOGRAPH-#2CBDB
2CBDC CJK UNIFIED IDEOGRAPH-#2CBDC
2CBDD CJK UNIFIED IDEOGRAPH-#2CBDD
2CBDE CJK UNIFIED IDEOGRAPH-#2CBDE
2CBDF CJK UNIFIED IDEOGRAPH-#2CBDF
2CBE0 CJK UNIFIED IDEOGRAPH-#2CBE0
2CBE1 CJK UNIFIED IDEOGRAPH-#2CBE1
2CBE2 CJK UNIFIED IDEOGRAPH-#2CBE2
2CBE3 CJK UNIFIED IDEOGRAPH-#2CBE3
2CBE4 CJK UNIFIED IDEOGRAPH-#2CBE4
2CBE5 CJK UNIFIED IDEOGRAPH-#2CBE5
2CBE6 CJK UNIFIED IDEOGRAPH-#2CBE6
2CBE7 CJK UNIFIED IDEOGRAPH-#2CBE7
2CBE8 CJK UNIFIED IDEOGRAPH-#2CBE8
2CBE9 CJK UNIFIED IDEOGRAPH-#2CBE9
2CBEA CJK UNIFIED IDEOGRAPH-#2CBEA
2CBEB CJK UNIFIED IDEOGRAPH-#2CBEB
2CBEC CJK UNIFIED IDEOGRAPH-#2CBEC
2CBED CJK UNIFIED IDEOGRAPH-#2CBED
2CBEE CJK UNIFIED IDEOGRAPH-#2CBEE
2CBEF CJK UNIFIED IDEOGRAPH-#2CBEF
2CBF0 CJK UNIFIED IDEOGRAPH-#2CBF0
2CBF1 CJK UNIFIED IDEOGRAPH-#2CBF1
2CBF2 CJK UNIFIED IDEOGRAPH-#2CBF2
2CBF3 CJK UNIFIED IDEOGRAPH-#2CBF3
2CBF4 CJK UNIFIED IDEOGRAPH-#2CBF4
2CBF5 CJK UNIFIED IDEOGRAPH-#2CBF5
2CBF6 CJK UNIFIED IDEOGRAPH-#2CBF6
2CBF7 CJK UNIFIED IDEOGRAPH-#2CBF7
2CBF8 CJK UNIFIED IDEOGRAPH-#2CBF8
2CBF9 CJK UNIFIED IDEOGRAPH-#2CBF9
2CBFA CJK UNIFIED IDEOGRAPH-#2CBFA
2CBFB CJK UNIFIED IDEOGRAPH-#2CBFB
2CBFC CJK UNIFIED IDEOGRAPH-#2CBFC
2CBFD CJK UNIFIED IDEOGRAPH-#2CBFD
2CBFE CJK UNIFIED IDEOGRAPH-#2CBFE
2CBFF CJK UNIFIED IDEOGRAPH-#2CBFF
2CC00 CJK UNIFIED IDEOGRAPH-#2CC00
2CC01 CJK UNIFIED IDEOGRAPH-#2CC01
2CC02 CJK UNIFIED IDEOGRAPH-#2CC02
2CC03 CJK UNIFIED IDEOGRAPH-#2CC03
2CC04 CJK UNIFIED IDEOGRAPH-#2CC04
2CC05 CJK UNIFIED IDEOGRAPH-#2CC05
2CC06 CJK UNIFIED IDEOGRAPH-#2CC06
2CC07 CJK UNIFIED IDEOGRAPH-#2CC07
2CC08 CJK UNIFIED IDEOGRAPH-#2CC08
2CC09 CJK UNIFIED IDEOGRAPH-#2CC09
2CC0A CJK UNIFIED IDEOGRAPH-#2CC0A
2CC0B CJK UNIFIED IDEOGRAPH-#2CC0B
2CC0C CJK UNIFIED IDEOGRAPH-#2CC0C
2CC0D CJK UNIFIED IDEOGRAPH-#2CC0D
2CC0E CJK UNIFIED IDEOGRAPH-#2CC0E
2CC0F CJK UNIFIED IDEOGRAPH-#2CC0F
2CC10 CJK UNIFIED IDEOGRAPH-#2CC10
2CC11 CJK UNIFIED IDEOGRAPH-#2CC11
2CC12 CJK UNIFIED IDEOGRAPH-#2CC12
2CC13 CJK UNIFIED IDEOGRAPH-#2CC13
2CC14 CJK UNIFIED IDEOGRAPH-#2CC14
2CC15 CJK UNIFIED IDEOGRAPH-#2CC15
2CC16 CJK UNIFIED IDEOGRAPH-#2CC16
2CC17 CJK UNIFIED IDEOGRAPH-#2CC17
2CC18 CJK UNIFIED IDEOGRAPH-#2CC18
2CC19 CJK UNIFIED IDEOGRAPH-#2CC19
2CC1A CJK UNIFIED IDEOGRAPH-#2CC1A
2CC1B CJK UNIFIED IDEOGRAPH-#2CC1B
2CC1C CJK UNIFIED IDEOGRAPH-#2CC1C
2CC1D CJK UNIFIED IDEOGRAPH-#2CC1D
2CC1E CJK UNIFIED IDEOGRAPH-#2CC1E
2CC1F CJK UNIFIED IDEOGRAPH-#2CC1F
2CC20 CJK UNIFIED IDEOGRAPH-#2CC20
2CC21 CJK UNIFIED IDEOGRAPH-#2CC21
2CC22 CJK UNIFIED IDEOGRAPH-#2CC22
2CC23 CJK UNIFIED IDEOGRAPH-#2CC23
2CC24 CJK UNIFIED IDEOGRAPH-#2CC24
2CC25 CJK UNIFIED IDEOGRAPH-#2CC25
2CC26 CJK UNIFIED IDEOGRAPH-#2CC26
2CC27 CJK UNIFIED IDEOGRAPH-#2CC27
2CC28 CJK UNIFIED IDEOGRAPH-#2CC28
2CC29 CJK UNIFIED IDEOGRAPH-#2CC29
2CC2A CJK UNIFIED IDEOGRAPH-#2CC2A
2CC2B CJK UNIFIED IDEOGRAPH-#2CC2B
2CC2C CJK UNIFIED IDEOGRAPH-#2CC2C
2CC2D CJK UNIFIED IDEOGRAPH-#2CC2D
2CC2E CJK UNIFIED IDEOGRAPH-#2CC2E
2CC2F CJK UNIFIED IDEOGRAPH-#2CC2F
2CC30 CJK UNIFIED IDEOGRAPH-#2CC30
2CC31 CJK UNIFIED IDEOGRAPH-#2CC31
2CC32 CJK UNIFIED IDEOGRAPH-#2CC32
2CC33 CJK UNIFIED IDEOGRAPH-#2CC33
2CC34 CJK UNIFIED IDEOGRAPH-#2CC34
2CC35 CJK UNIFIED IDEOGRAPH-#2CC35
2CC36 CJK UNIFIED IDEOGRAPH-#2CC36
2CC37 CJK UNIFIED IDEOGRAPH-#2CC37
2CC38 CJK UNIFIED IDEOGRAPH-#2CC38
2CC39 CJK UNIFIED IDEOGRAPH-#2CC39
2CC3A CJK UNIFIED IDEOGRAPH-#2CC3A
2CC3B CJK UNIFIED IDEOGRAPH-#2CC3B
2CC3C CJK UNIFIED IDEOGRAPH-#2CC3C
2CC3D CJK UNIFIED IDEOGRAPH-#2CC3D
2CC3E CJK UNIFIED IDEOGRAPH-#2CC3E
2CC3F CJK UNIFIED IDEOGRAPH-#2CC3F
2CC40 CJK UNIFIED IDEOGRAPH-#2CC40
2CC41 CJK UNIFIED IDEOGRAPH-#2CC41
2CC42 CJK UNIFIED IDEOGRAPH-#2CC42
2CC43 CJK UNIFIED IDEOGRAPH-#2CC43
2CC44 CJK UNIFIED IDEOGRAPH-#2CC44
2CC45 CJK UNIFIED IDEOGRAPH-#2CC45
2CC46 CJK UNIFIED IDEOGRAPH-#2CC46
2CC47 CJK UNIFIED IDEOGRAPH-#2CC47
2CC48 CJK UNIFIED IDEOGRAPH-#2CC48
2CC49 CJK UNIFIED IDEOGRAPH-#2CC49
2CC4A CJK UNIFIED IDEOGRAPH-#2CC4A
2CC4B CJK UNIFIED IDEOGRAPH-#2CC4B
2CC4C CJK UNIFIED IDEOGRAPH-#2CC4C
2CC4D CJK UNIFIED IDEOGRAPH-#2CC4D
2CC4E CJK UNIFIED IDEOGRAPH-#2CC4E
2CC4F CJK UNIFIED IDEOGRAPH-#2CC4F
2CC50 CJK UNIFIED IDEOGRAPH-#2CC50
2CC51 CJK UNIFIED IDEOGRAPH-#2CC51
2CC52 CJK UNIFIED IDEOGRAPH-#2CC52
2CC53 CJK UNIFIED IDEOGRAPH-#2CC53
2CC54 CJK UNIFIED IDEOGRAPH-#2CC54
2CC55 CJK UNIFIED IDEOGRAPH-#2CC55
2CC56 CJK UNIFIED IDEOGRAPH-#2CC56
2CC57 CJK UNIFIED IDEOGRAPH-#2CC57
2CC58 CJK UNIFIED IDEOGRAPH-#2CC58
2CC59 CJK UNIFIED IDEOGRAPH-#2CC59
2CC5A CJK UNIFIED IDEOGRAPH-#2CC5A
2CC5B CJK UNIFIED IDEOGRAPH-#2CC5B
2CC5C CJK UNIFIED IDEOGRAPH-#2CC5C
2CC5D CJK UNIFIED IDEOGRAPH-#2CC5D
2CC5E CJK UNIFIED IDEOGRAPH-#2CC5E
2CC5F CJK UNIFIED IDEOGRAPH-#2CC5F
2CC60 CJK UNIFIED IDEOGRAPH-#2CC60
2CC61 CJK UNIFIED IDEOGRAPH-#2CC61
2CC62 CJK UNIFIED IDEOGRAPH-#2CC62
2CC63 CJK UNIFIED IDEOGRAPH-#2CC63
2CC64 CJK UNIFIED IDEOGRAPH-#2CC64
2CC65 CJK UNIFIED IDEOGRAPH-#2CC65
2CC66 CJK UNIFIED IDEOGRAPH-#2CC66
2CC67 CJK UNIFIED IDEOGRAPH-#2CC67
2CC68 CJK UNIFIED IDEOGRAPH-#2CC68
2CC69 CJK UNIFIED IDEOGRAPH-#2CC69
2CC6A CJK UNIFIED IDEOGRAPH-#2CC6A
2CC6B CJK UNIFIED IDEOGRAPH-#2CC6B
2CC6C CJK UNIFIED IDEOGRAPH-#2CC6C
2CC6D CJK UNIFIED IDEOGRAPH-#2CC6D
2CC6E CJK UNIFIED IDEOGRAPH-#2CC6E
2CC6F CJK UNIFIED IDEOGRAPH-#2CC6F
2CC70 CJK UNIFIED IDEOGRAPH-#2CC70
2CC71 CJK UNIFIED IDEOGRAPH-#2CC71
2CC72 CJK UNIFIED IDEOGRAPH-#2CC72
2CC73 CJK UNIFIED IDEOGRAPH-#2CC73
2CC74 CJK UNIFIED IDEOGRAPH-#2CC74
2CC75 CJK UNIFIED IDEOGRAPH-#2CC75
2CC76 CJK UNIFIED IDEOGRAPH-#2CC76
2CC77 CJK UNIFIED IDEOGRAPH-#2CC77
2CC78 CJK UNIFIED IDEOGRAPH-#2CC78
2CC79 CJK UNIFIED IDEOGRAPH-#2CC79
2CC7A CJK UNIFIED IDEOGRAPH-#2CC7A
2CC7B CJK UNIFIED IDEOGRAPH-#2CC7B
2CC7C CJK UNIFIED IDEOGRAPH-#2CC7C
2CC7D CJK UNIFIED IDEOGRAPH-#2CC7D
2CC7E CJK UNIFIED IDEOGRAPH-#2CC7E
2CC7F CJK UNIFIED IDEOGRAPH-#2CC7F
2CC80 CJK UNIFIED IDEOGRAPH-#2CC80
2CC81 CJK UNIFIED IDEOGRAPH-#2CC81
2CC82 CJK UNIFIED IDEOGRAPH-#2CC82
2CC83 CJK UNIFIED IDEOGRAPH-#2CC83
2CC84 CJK UNIFIED IDEOGRAPH-#2CC84
2CC85 CJK UNIFIED IDEOGRAPH-#2CC85
2CC86 CJK UNIFIED IDEOGRAPH-#2CC86
2CC87 CJK UNIFIED IDEOGRAPH-#2CC87
2CC88 CJK UNIFIED IDEOGRAPH-#2CC88
2CC89 CJK UNIFIED IDEOGRAPH-#2CC89
2CC8A CJK UNIFIED IDEOGRAPH-#2CC8A
2CC8B CJK UNIFIED IDEOGRAPH-#2CC8B
2CC8C CJK UNIFIED IDEOGRAPH-#2CC8C
2CC8D CJK UNIFIED IDEOGRAPH-#2CC8D
2CC8E CJK UNIFIED IDEOGRAPH-#2CC8E
2CC8F CJK UNIFIED IDEOGRAPH-#2CC8F
2CC90 CJK UNIFIED IDEOGRAPH-#2CC90
2CC91 CJK UNIFIED IDEOGRAPH-#2CC91
2CC92 CJK UNIFIED IDEOGRAPH-#2CC92
2CC93 CJK UNIFIED IDEOGRAPH-#2CC93
2CC94 CJK UNIFIED IDEOGRAPH-#2CC94
2CC95 CJK UNIFIED IDEOGRAPH-#2CC95
2CC96 CJK UNIFIED IDEOGRAPH-#2CC96
2CC97 CJK UNIFIED IDEOGRAPH-#2CC97
2CC98 CJK UNIFIED IDEOGRAPH-#2CC98
2CC99 CJK UNIFIED IDEOGRAPH-#2CC99
2CC9A CJK UNIFIED IDEOGRAPH-#2CC9A
2CC9B CJK UNIFIED IDEOGRAPH-#2CC9B
2CC9C CJK UNIFIED IDEOGRAPH-#2CC9C
2CC9D CJK UNIFIED IDEOGRAPH-#2CC9D
2CC9E CJK UNIFIED IDEOGRAPH-#2CC9E
2CC9F CJK UNIFIED IDEOGRAPH-#2CC9F
2CCA0 CJK UNIFIED IDEOGRAPH-#2CCA0
2CCA1 CJK UNIFIED IDEOGRAPH-#2CCA1
2CCA2 CJK UNIFIED IDEOGRAPH-#2CCA2
2CCA3 CJK UNIFIED IDEOGRAPH-#2CCA3
2CCA4 CJK UNIFIED IDEOGRAPH-#2CCA4
2CCA5 CJK UNIFIED IDEOGRAPH-#2CCA5
2CCA6 CJK UNIFIED IDEOGRAPH-#2CCA6
2CCA7 CJK UNIFIED IDEOGRAPH-#2CCA7
2CCA8 CJK UNIFIED IDEOGRAPH-#2CCA8
2CCA9 CJK UNIFIED IDEOGRAPH-#2CCA9
2CCAA CJK UNIFIED IDEOGRAPH-#2CCAA
2CCAB CJK UNIFIED IDEOGRAPH-#2CCAB
2CCAC CJK UNIFIED IDEOGRAPH-#2CCAC
2CCAD CJK UNIFIED IDEOGRAPH-#2CCAD
2CCAE CJK UNIFIED IDEOGRAPH-#2CCAE
2CCAF CJK UNIFIED IDEOGRAPH-#2CCAF
2CCB0 CJK UNIFIED IDEOGRAPH-#2CCB0
2CCB1 CJK UNIFIED IDEOGRAPH-#2CCB1
2CCB2 CJK UNIFIED IDEOGRAPH-#2CCB2
2CCB3 CJK UNIFIED IDEOGRAPH-#2CCB3
2CCB4 CJK UNIFIED IDEOGRAPH-#2CCB4
2CCB5 CJK UNIFIED IDEOGRAPH-#2CCB5
2CCB6 CJK UNIFIED IDEOGRAPH-#2CCB6
2CCB7 CJK UNIFIED IDEOGRAPH-#2CCB7
2CCB8 CJK UNIFIED IDEOGRAPH-#2CCB8
2CCB9 CJK UNIFIED IDEOGRAPH-#2CCB9
2CCBA CJK UNIFIED IDEOGRAPH-#2CCBA
2CCBB CJK UNIFIED IDEOGRAPH-#2CCBB
2CCBC CJK UNIFIED IDEOGRAPH-#2CCBC
2CCBD CJK UNIFIED IDEOGRAPH-#2CCBD
2CCBE CJK UNIFIED IDEOGRAPH-#2CCBE
2CCBF CJK UNIFIED IDEOGRAPH-#2CCBF
2CCC0 CJK UNIFIED IDEOGRAPH-#2CCC0
2CCC1 CJK UNIFIED IDEOGRAPH-#2CCC1
2CCC2 CJK UNIFIED IDEOGRAPH-#2CCC2
2CCC3 CJK UNIFIED IDEOGRAPH-#2CCC3
2CCC4 CJK UNIFIED IDEOGRAPH-#2CCC4
2CCC5 CJK UNIFIED IDEOGRAPH-#2CCC5
2CCC6 CJK UNIFIED IDEOGRAPH-#2CCC6
2CCC7 CJK UNIFIED IDEOGRAPH-#2CCC7
2CCC8 CJK UNIFIED IDEOGRAPH-#2CCC8
2CCC9 CJK UNIFIED IDEOGRAPH-#2CCC9
2CCCA CJK UNIFIED IDEOGRAPH-#2CCCA
2CCCB CJK UNIFIED IDEOGRAPH-#2CCCB
2CCCC CJK UNIFIED IDEOGRAPH-#2CCCC
2CCCD CJK UNIFIED IDEOGRAPH-#2CCCD
2CCCE CJK UNIFIED IDEOGRAPH-#2CCCE
2CCCF CJK UNIFIED IDEOGRAPH-#2CCCF
2CCD0 CJK UNIFIED IDEOGRAPH-#2CCD0
2CCD1 CJK UNIFIED IDEOGRAPH-#2CCD1
2CCD2 CJK UNIFIED IDEOGRAPH-#2CCD2
2CCD3 CJK UNIFIED IDEOGRAPH-#2CCD3
2CCD4 CJK UNIFIED IDEOGRAPH-#2CCD4
2CCD5 CJK UNIFIED IDEOGRAPH-#2CCD5
2CCD6 CJK UNIFIED IDEOGRAPH-#2CCD6
2CCD7 CJK UNIFIED IDEOGRAPH-#2CCD7
2CCD8 CJK UNIFIED IDEOGRAPH-#2CCD8
2CCD9 CJK UNIFIED IDEOGRAPH-#2CCD9
2CCDA CJK UNIFIED IDEOGRAPH-#2CCDA
2CCDB CJK UNIFIED IDEOGRAPH-#2CCDB
2CCDC CJK UNIFIED IDEOGRAPH-#2CCDC
2CCDD CJK UNIFIED IDEOGRAPH-#2CCDD
2CCDE CJK UNIFIED IDEOGRAPH-#2CCDE
2CCDF CJK UNIFIED IDEOGRAPH-#2CCDF
2CCE0 CJK UNIFIED IDEOGRAPH-#2CCE0
2CCE1 CJK UNIFIED IDEOGRAPH-#2CCE1
2CCE2 CJK UNIFIED IDEOGRAPH-#2CCE2
2CCE3 CJK UNIFIED IDEOGRAPH-#2CCE3
2CCE4 CJK UNIFIED IDEOGRAPH-#2CCE4
2CCE5 CJK UNIFIED IDEOGRAPH-#2CCE5
2CCE6 CJK UNIFIED IDEOGRAPH-#2CCE6
2CCE7 CJK UNIFIED IDEOGRAPH-#2CCE7
2CCE8 CJK UNIFIED IDEOGRAPH-#2CCE8
2CCE9 CJK UNIFIED IDEOGRAPH-#2CCE9
2CCEA CJK UNIFIED IDEOGRAPH-#2CCEA
2CCEB CJK UNIFIED IDEOGRAPH-#2CCEB
2CCEC CJK UNIFIED IDEOGRAPH-#2CCEC
2CCED CJK UNIFIED IDEOGRAPH-#2CCED
2CCEE CJK UNIFIED IDEOGRAPH-#2CCEE
2CCEF CJK UNIFIED IDEOGRAPH-#2CCEF
2CCF0 CJK UNIFIED IDEOGRAPH-#2CCF0
2CCF1 CJK UNIFIED IDEOGRAPH-#2CCF1
2CCF2 CJK UNIFIED IDEOGRAPH-#2CCF2
2CCF3 CJK UNIFIED IDEOGRAPH-#2CCF3
2CCF4 CJK UNIFIED IDEOGRAPH-#2CCF4
2CCF5 CJK UNIFIED IDEOGRAPH-#2CCF5
2CCF6 CJK UNIFIED IDEOGRAPH-#2CCF6
2CCF7 CJK UNIFIED IDEOGRAPH-#2CCF7
2CCF8 CJK UNIFIED IDEOGRAPH-#2CCF8
2CCF9 CJK UNIFIED IDEOGRAPH-#2CCF9
2CCFA CJK UNIFIED IDEOGRAPH-#2CCFA
2CCFB CJK UNIFIED IDEOGRAPH-#2CCFB
2CCFC CJK UNIFIED IDEOGRAPH-#2CCFC
2CCFD CJK UNIFIED IDEOGRAPH-#2CCFD
2CCFE CJK UNIFIED IDEOGRAPH-#2CCFE
2CCFF CJK UNIFIED IDEOGRAPH-#2CCFF
2CD00 CJK UNIFIED IDEOGRAPH-#2CD00
2CD01 CJK UNIFIED IDEOGRAPH-#2CD01
2CD02 CJK UNIFIED IDEOGRAPH-#2CD02
2CD03 CJK UNIFIED IDEOGRAPH-#2CD03
2CD04 CJK UNIFIED IDEOGRAPH-#2CD04
2CD05 CJK UNIFIED IDEOGRAPH-#2CD05
2CD06 CJK UNIFIED IDEOGRAPH-#2CD06
2CD07 CJK UNIFIED IDEOGRAPH-#2CD07
2CD08 CJK UNIFIED IDEOGRAPH-#2CD08
2CD09 CJK UNIFIED IDEOGRAPH-#2CD09
2CD0A CJK UNIFIED IDEOGRAPH-#2CD0A
2CD0B CJK UNIFIED IDEOGRAPH-#2CD0B
2CD0C CJK UNIFIED IDEOGRAPH-#2CD0C
2CD0D CJK UNIFIED IDEOGRAPH-#2CD0D
2CD0E CJK UNIFIED IDEOGRAPH-#2CD0E
2CD0F CJK UNIFIED IDEOGRAPH-#2CD0F
2CD10 CJK UNIFIED IDEOGRAPH-#2CD10
2CD11 CJK UNIFIED IDEOGRAPH-#2CD11
2CD12 CJK UNIFIED IDEOGRAPH-#2CD12
2CD13 CJK UNIFIED IDEOGRAPH-#2CD13
2CD14 CJK UNIFIED IDEOGRAPH-#2CD14
2CD15 CJK UNIFIED IDEOGRAPH-#2CD15
2CD16 CJK UNIFIED IDEOGRAPH-#2CD16
2CD17 CJK UNIFIED IDEOGRAPH-#2CD17
2CD18 CJK UNIFIED IDEOGRAPH-#2CD18
2CD19 CJK UNIFIED IDEOGRAPH-#2CD19
2CD1A CJK UNIFIED IDEOGRAPH-#2CD1A
2CD1B CJK UNIFIED IDEOGRAPH-#2CD1B
2CD1C CJK UNIFIED IDEOGRAPH-#2CD1C
2CD1D CJK UNIFIED IDEOGRAPH-#2CD1D
2CD1E CJK UNIFIED IDEOGRAPH-#2CD1E
2CD1F CJK UNIFIED IDEOGRAPH-#2CD1F
2CD20 CJK UNIFIED IDEOGRAPH-#2CD20
2CD21 CJK UNIFIED IDEOGRAPH-#2CD21
2CD22 CJK UNIFIED IDEOGRAPH-#2CD22
2CD23 CJK UNIFIED IDEOGRAPH-#2CD23
2CD24 CJK UNIFIED IDEOGRAPH-#2CD24
2CD25 CJK UNIFIED IDEOGRAPH-#2CD25
2CD26 CJK UNIFIED IDEOGRAPH-#2CD26
2CD27 CJK UNIFIED IDEOGRAPH-#2CD27
2CD28 CJK UNIFIED IDEOGRAPH-#2CD28
2CD29 CJK UNIFIED IDEOGRAPH-#2CD29
2CD2A CJK UNIFIED IDEOGRAPH-#2CD2A
2CD2B CJK UNIFIED IDEOGRAPH-#2CD2B
2CD2C CJK UNIFIED IDEOGRAPH-#2CD2C
2CD2D CJK UNIFIED IDEOGRAPH-#2CD2D
2CD2E CJK UNIFIED IDEOGRAPH-#2CD2E
2CD2F CJK UNIFIED IDEOGRAPH-#2CD2F
2CD30 CJK UNIFIED IDEOGRAPH-#2CD30
2CD31 CJK UNIFIED IDEOGRAPH-#2CD31
2CD32 CJK UNIFIED IDEOGRAPH-#2CD32
2CD33 CJK UNIFIED IDEOGRAPH-#2CD33
2CD34 CJK UNIFIED IDEOGRAPH-#2CD34
2CD35 CJK UNIFIED IDEOGRAPH-#2CD35
2CD36 CJK UNIFIED IDEOGRAPH-#2CD36
2CD37 CJK UNIFIED IDEOGRAPH-#2CD37
2CD38 CJK UNIFIED IDEOGRAPH-#2CD38
2CD39 CJK UNIFIED IDEOGRAPH-#2CD39
2CD3A CJK UNIFIED IDEOGRAPH-#2CD3A
2CD3B CJK UNIFIED IDEOGRAPH-#2CD3B
2CD3C CJK UNIFIED IDEOGRAPH-#2CD3C
2CD3D CJK UNIFIED IDEOGRAPH-#2CD3D
2CD3E CJK UNIFIED IDEOGRAPH-#2CD3E
2CD3F CJK UNIFIED IDEOGRAPH-#2CD3F
2CD40 CJK UNIFIED IDEOGRAPH-#2CD40
2CD41 CJK UNIFIED IDEOGRAPH-#2CD41
2CD42 CJK UNIFIED IDEOGRAPH-#2CD42
2CD43 CJK UNIFIED IDEOGRAPH-#2CD43
2CD44 CJK UNIFIED IDEOGRAPH-#2CD44
2CD45 CJK UNIFIED IDEOGRAPH-#2CD45
2CD46 CJK UNIFIED IDEOGRAPH-#2CD46
2CD47 CJK UNIFIED IDEOGRAPH-#2CD47
2CD48 CJK UNIFIED IDEOGRAPH-#2CD48
2CD49 CJK UNIFIED IDEOGRAPH-#2CD49
2CD4A CJK UNIFIED IDEOGRAPH-#2CD4A
2CD4B CJK UNIFIED IDEOGRAPH-#2CD4B
2CD4C CJK UNIFIED IDEOGRAPH-#2CD4C
2CD4D CJK UNIFIED IDEOGRAPH-#2CD4D
2CD4E CJK UNIFIED IDEOGRAPH-#2CD4E
2CD4F CJK UNIFIED IDEOGRAPH-#2CD4F
2CD50 CJK UNIFIED IDEOGRAPH-#2CD50
2CD51 CJK UNIFIED IDEOGRAPH-#2CD51
2CD52 CJK UNIFIED IDEOGRAPH-#2CD52
2CD53 CJK UNIFIED IDEOGRAPH-#2CD53
2CD54 CJK UNIFIED IDEOGRAPH-#2CD54
2CD55 CJK UNIFIED IDEOGRAPH-#2CD55
2CD56 CJK UNIFIED IDEOGRAPH-#2CD56
2CD57 CJK UNIFIED IDEOGRAPH-#2CD57
2CD58 CJK UNIFIED IDEOGRAPH-#2CD58
2CD59 CJK UNIFIED IDEOGRAPH-#2CD59
2CD5A CJK UNIFIED IDEOGRAPH-#2CD5A
2CD5B CJK UNIFIED IDEOGRAPH-#2CD5B
2CD5C CJK UNIFIED IDEOGRAPH-#2CD5C
2CD5D CJK UNIFIED IDEOGRAPH-#2CD5D
2CD5E CJK UNIFIED IDEOGRAPH-#2CD5E
2CD5F CJK UNIFIED IDEOGRAPH-#2CD5F
2CD60 CJK UNIFIED IDEOGRAPH-#2CD60
2CD61 CJK UNIFIED IDEOGRAPH-#2CD61
2CD62 CJK UNIFIED IDEOGRAPH-#2CD62
2CD63 CJK UNIFIED IDEOGRAPH-#2CD63
2CD64 CJK UNIFIED IDEOGRAPH-#2CD64
2CD65 CJK UNIFIED IDEOGRAPH-#2CD65
2CD66 CJK UNIFIED IDEOGRAPH-#2CD66
2CD67 CJK UNIFIED IDEOGRAPH-#2CD67
2CD68 CJK UNIFIED IDEOGRAPH-#2CD68
2CD69 CJK UNIFIED IDEOGRAPH-#2CD69
2CD6A CJK UNIFIED IDEOGRAPH-#2CD6A
2CD6B CJK UNIFIED IDEOGRAPH-#2CD6B
2CD6C CJK UNIFIED IDEOGRAPH-#2CD6C
2CD6D CJK UNIFIED IDEOGRAPH-#2CD6D
2CD6E CJK UNIFIED IDEOGRAPH-#2CD6E
2CD6F CJK UNIFIED IDEOGRAPH-#2CD6F
2CD70 CJK UNIFIED IDEOGRAPH-#2CD70
2CD71 CJK UNIFIED IDEOGRAPH-#2CD71
2CD72 CJK UNIFIED IDEOGRAPH-#2CD72
2CD73 CJK UNIFIED IDEOGRAPH-#2CD73
2CD74 CJK UNIFIED IDEOGRAPH-#2CD74
2CD75 CJK UNIFIED IDEOGRAPH-#2CD75
2CD76 CJK UNIFIED IDEOGRAPH-#2CD76
2CD77 CJK UNIFIED IDEOGRAPH-#2CD77
2CD78 CJK UNIFIED IDEOGRAPH-#2CD78
2CD79 CJK UNIFIED IDEOGRAPH-#2CD79
2CD7A CJK UNIFIED IDEOGRAPH-#2CD7A
2CD7B CJK UNIFIED IDEOGRAPH-#2CD7B
2CD7C CJK UNIFIED IDEOGRAPH-#2CD7C
2CD7D CJK UNIFIED IDEOGRAPH-#2CD7D
2CD7E CJK UNIFIED IDEOGRAPH-#2CD7E
2CD7F CJK UNIFIED IDEOGRAPH-#2CD7F
2CD80 CJK UNIFIED IDEOGRAPH-#2CD80
2CD81 CJK UNIFIED IDEOGRAPH-#2CD81
2CD82 CJK UNIFIED IDEOGRAPH-#2CD82
2CD83 CJK UNIFIED IDEOGRAPH-#2CD83
2CD84 CJK UNIFIED IDEOGRAPH-#2CD84
2CD85 CJK UNIFIED IDEOGRAPH-#2CD85
2CD86 CJK UNIFIED IDEOGRAPH-#2CD86
2CD87 CJK UNIFIED IDEOGRAPH-#2CD87
2CD88 CJK UNIFIED IDEOGRAPH-#2CD88
2CD89 CJK UNIFIED IDEOGRAPH-#2CD89
2CD8A CJK UNIFIED IDEOGRAPH-#2CD8A
2CD8B CJK UNIFIED IDEOGRAPH-#2CD8B
2CD8C CJK UNIFIED IDEOGRAPH-#2CD8C
2CD8D CJK UNIFIED IDEOGRAPH-#2CD8D
2CD8E CJK UNIFIED IDEOGRAPH-#2CD8E
2CD8F CJK UNIFIED IDEOGRAPH-#2CD8F
2CD90 CJK UNIFIED IDEOGRAPH-#2CD90
2CD91 CJK UNIFIED IDEOGRAPH-#2CD91
2CD92 CJK UNIFIED IDEOGRAPH-#2CD92
2CD93 CJK UNIFIED IDEOGRAPH-#2CD93
2CD94 CJK UNIFIED IDEOGRAPH-#2CD94
2CD95 CJK UNIFIED IDEOGRAPH-#2CD95
2CD96 CJK UNIFIED IDEOGRAPH-#2CD96
2CD97 CJK UNIFIED IDEOGRAPH-#2CD97
2CD98 CJK UNIFIED IDEOGRAPH-#2CD98
2CD99 CJK UNIFIED IDEOGRAPH-#2CD99
2CD9A CJK UNIFIED IDEOGRAPH-#2CD9A
2CD9B CJK UNIFIED IDEOGRAPH-#2CD9B
2CD9C CJK UNIFIED IDEOGRAPH-#2CD9C
2CD9D CJK UNIFIED IDEOGRAPH-#2CD9D
2CD9E CJK UNIFIED IDEOGRAPH-#2CD9E
2CD9F CJK UNIFIED IDEOGRAPH-#2CD9F
2CDA0 CJK UNIFIED IDEOGRAPH-#2CDA0
2CDA1 CJK UNIFIED IDEOGRAPH-#2CDA1
2CDA2 CJK UNIFIED IDEOGRAPH-#2CDA2
2CDA3 CJK UNIFIED IDEOGRAPH-#2CDA3
2CDA4 CJK UNIFIED IDEOGRAPH-#2CDA4
2CDA5 CJK UNIFIED IDEOGRAPH-#2CDA5
2CDA6 CJK UNIFIED IDEOGRAPH-#2CDA6
2CDA7 CJK UNIFIED IDEOGRAPH-#2CDA7
2CDA8 CJK UNIFIED IDEOGRAPH-#2CDA8
2CDA9 CJK UNIFIED IDEOGRAPH-#2CDA9
2CDAA CJK UNIFIED IDEOGRAPH-#2CDAA
2CDAB CJK UNIFIED IDEOGRAPH-#2CDAB
2CDAC CJK UNIFIED IDEOGRAPH-#2CDAC
2CDAD CJK UNIFIED IDEOGRAPH-#2CDAD
2CDAE CJK UNIFIED IDEOGRAPH-#2CDAE
2CDAF CJK UNIFIED IDEOGRAPH-#2CDAF
2CDB0 CJK UNIFIED IDEOGRAPH-#2CDB0
2CDB1 CJK UNIFIED IDEOGRAPH-#2CDB1
2CDB2 CJK UNIFIED IDEOGRAPH-#2CDB2
2CDB3 CJK UNIFIED IDEOGRAPH-#2CDB3
2CDB4 CJK UNIFIED IDEOGRAPH-#2CDB4
2CDB5 CJK UNIFIED IDEOGRAPH-#2CDB5
2CDB6 CJK UNIFIED IDEOGRAPH-#2CDB6
2CDB7 CJK UNIFIED IDEOGRAPH-#2CDB7
2CDB8 CJK UNIFIED IDEOGRAPH-#2CDB8
2CDB9 CJK UNIFIED IDEOGRAPH-#2CDB9
2CDBA CJK UNIFIED IDEOGRAPH-#2CDBA
2CDBB CJK UNIFIED IDEOGRAPH-#2CDBB
2CDBC CJK UNIFIED IDEOGRAPH-#2CDBC
2CDBD CJK UNIFIED IDEOGRAPH-#2CDBD
2CDBE CJK UNIFIED IDEOGRAPH-#2CDBE
2CDBF CJK UNIFIED IDEOGRAPH-#2CDBF
2CDC0 CJK UNIFIED IDEOGRAPH-#2CDC0
2CDC1 CJK UNIFIED IDEOGRAPH-#2CDC1
2CDC2 CJK UNIFIED IDEOGRAPH-#2CDC2
2CDC3 CJK UNIFIED IDEOGRAPH-#2CDC3
2CDC4 CJK UNIFIED IDEOGRAPH-#2CDC4
2CDC5 CJK UNIFIED IDEOGRAPH-#2CDC5
2CDC6 CJK UNIFIED IDEOGRAPH-#2CDC6
2CDC7 CJK UNIFIED IDEOGRAPH-#2CDC7
2CDC8 CJK UNIFIED IDEOGRAPH-#2CDC8
2CDC9 CJK UNIFIED IDEOGRAPH-#2CDC9
2CDCA CJK UNIFIED IDEOGRAPH-#2CDCA
2CDCB CJK UNIFIED IDEOGRAPH-#2CDCB
2CDCC CJK UNIFIED IDEOGRAPH-#2CDCC
2CDCD CJK UNIFIED IDEOGRAPH-#2CDCD
2CDCE CJK UNIFIED IDEOGRAPH-#2CDCE
2CDCF CJK UNIFIED IDEOGRAPH-#2CDCF
2CDD0 CJK UNIFIED IDEOGRAPH-#2CDD0
2CDD1 CJK UNIFIED IDEOGRAPH-#2CDD1
2CDD2 CJK UNIFIED IDEOGRAPH-#2CDD2
2CDD3 CJK UNIFIED IDEOGRAPH-#2CDD3
2CDD4 CJK UNIFIED IDEOGRAPH-#2CDD4
2CDD5 CJK UNIFIED IDEOGRAPH-#2CDD5
2CDD6 CJK UNIFIED IDEOGRAPH-#2CDD6
2CDD7 CJK UNIFIED IDEOGRAPH-#2CDD7
2CDD8 CJK UNIFIED IDEOGRAPH-#2CDD8
2CDD9 CJK UNIFIED IDEOGRAPH-#2CDD9
2CDDA CJK UNIFIED IDEOGRAPH-#2CDDA
2CDDB CJK UNIFIED IDEOGRAPH-#2CDDB
2CDDC CJK UNIFIED IDEOGRAPH-#2CDDC
2CDDD CJK UNIFIED IDEOGRAPH-#2CDDD
2CDDE CJK UNIFIED IDEOGRAPH-#2CDDE
2CDDF CJK UNIFIED IDEOGRAPH-#2CDDF
2CDE0 CJK UNIFIED IDEOGRAPH-#2CDE0
2CDE1 CJK UNIFIED IDEOGRAPH-#2CDE1
2CDE2 CJK UNIFIED IDEOGRAPH-#2CDE2
2CDE3 CJK UNIFIED IDEOGRAPH-#2CDE3
2CDE4 CJK UNIFIED IDEOGRAPH-#2CDE4
2CDE5 CJK UNIFIED IDEOGRAPH-#2CDE5
2CDE6 CJK UNIFIED IDEOGRAPH-#2CDE6
2CDE7 CJK UNIFIED IDEOGRAPH-#2CDE7
2CDE8 CJK UNIFIED IDEOGRAPH-#2CDE8
2CDE9 CJK UNIFIED IDEOGRAPH-#2CDE9
2CDEA CJK UNIFIED IDEOGRAPH-#2CDEA
2CDEB CJK UNIFIED IDEOGRAPH-#2CDEB
2CDEC CJK UNIFIED IDEOGRAPH-#2CDEC
2CDED CJK UNIFIED IDEOGRAPH-#2CDED
2CDEE CJK UNIFIED IDEOGRAPH-#2CDEE
2CDEF CJK UNIFIED IDEOGRAPH-#2CDEF
2CDF0 CJK UNIFIED IDEOGRAPH-#2CDF0
2CDF1 CJK UNIFIED IDEOGRAPH-#2CDF1
2CDF2 CJK UNIFIED IDEOGRAPH-#2CDF2
2CDF3 CJK UNIFIED IDEOGRAPH-#2CDF3
2CDF4 CJK UNIFIED IDEOGRAPH-#2CDF4
2CDF5 CJK UNIFIED IDEOGRAPH-#2CDF5
2CDF6 CJK UNIFIED IDEOGRAPH-#2CDF6
2CDF7 CJK UNIFIED IDEOGRAPH-#2CDF7
2CDF8 CJK UNIFIED IDEOGRAPH-#2CDF8
2CDF9 CJK UNIFIED IDEOGRAPH-#2CDF9
2CDFA CJK UNIFIED IDEOGRAPH-#2CDFA
2CDFB CJK UNIFIED IDEOGRAPH-#2CDFB
2CDFC CJK UNIFIED IDEOGRAPH-#2CDFC
2CDFD CJK UNIFIED IDEOGRAPH-#2CDFD
2CDFE CJK UNIFIED IDEOGRAPH-#2CDFE
2CDFF CJK UNIFIED IDEOGRAPH-#2CDFF
2CE00 CJK UNIFIED IDEOGRAPH-#2CE00
2CE01 CJK UNIFIED IDEOGRAPH-#2CE01
2CE02 CJK UNIFIED IDEOGRAPH-#2CE02
2CE03 CJK UNIFIED IDEOGRAPH-#2CE03
2CE04 CJK UNIFIED IDEOGRAPH-#2CE04
2CE05 CJK UNIFIED IDEOGRAPH-#2CE05
2CE06 CJK UNIFIED IDEOGRAPH-#2CE06
2CE07 CJK UNIFIED IDEOGRAPH-#2CE07
2CE08 CJK UNIFIED IDEOGRAPH-#2CE08
2CE09 CJK UNIFIED IDEOGRAPH-#2CE09
2CE0A CJK UNIFIED IDEOGRAPH-#2CE0A
2CE0B CJK UNIFIED IDEOGRAPH-#2CE0B
2CE0C CJK UNIFIED IDEOGRAPH-#2CE0C
2CE0D CJK UNIFIED IDEOGRAPH-#2CE0D
2CE0E CJK UNIFIED IDEOGRAPH-#2CE0E
2CE0F CJK UNIFIED IDEOGRAPH-#2CE0F
2CE10 CJK UNIFIED IDEOGRAPH-#2CE10
2CE11 CJK UNIFIED IDEOGRAPH-#2CE11
2CE12 CJK UNIFIED IDEOGRAPH-#2CE12
2CE13 CJK UNIFIED IDEOGRAPH-#2CE13
2CE14 CJK UNIFIED IDEOGRAPH-#2CE14
2CE15 CJK UNIFIED IDEOGRAPH-#2CE15
2CE16 CJK UNIFIED IDEOGRAPH-#2CE16
2CE17 CJK UNIFIED IDEOGRAPH-#2CE17
2CE18 CJK UNIFIED IDEOGRAPH-#2CE18
2CE19 CJK UNIFIED IDEOGRAPH-#2CE19
2CE1A CJK UNIFIED IDEOGRAPH-#2CE1A
2CE1B CJK UNIFIED IDEOGRAPH-#2CE1B
2CE1C CJK UNIFIED IDEOGRAPH-#2CE1C
2CE1D CJK UNIFIED IDEOGRAPH-#2CE1D
2CE1E CJK UNIFIED IDEOGRAPH-#2CE1E
2CE1F CJK UNIFIED IDEOGRAPH-#2CE1F
2CE20 CJK UNIFIED IDEOGRAPH-#2CE20
2CE21 CJK UNIFIED IDEOGRAPH-#2CE21
2CE22 CJK UNIFIED IDEOGRAPH-#2CE22
2CE23 CJK UNIFIED IDEOGRAPH-#2CE23
2CE24 CJK UNIFIED IDEOGRAPH-#2CE24
2CE25 CJK UNIFIED IDEOGRAPH-#2CE25
2CE26 CJK UNIFIED IDEOGRAPH-#2CE26
2CE27 CJK UNIFIED IDEOGRAPH-#2CE27
2CE28 CJK UNIFIED IDEOGRAPH-#2CE28
2CE29 CJK UNIFIED IDEOGRAPH-#2CE29
2CE2A CJK UNIFIED IDEOGRAPH-#2CE2A
2CE2B CJK UNIFIED IDEOGRAPH-#2CE2B
2CE2C CJK UNIFIED IDEOGRAPH-#2CE2C
2CE2D CJK UNIFIED IDEOGRAPH-#2CE2D
2CE2E CJK UNIFIED IDEOGRAPH-#2CE2E
2CE2F CJK UNIFIED IDEOGRAPH-#2CE2F
2CE30 CJK UNIFIED IDEOGRAPH-#2CE30
2CE31 CJK UNIFIED IDEOGRAPH-#2CE31
2CE32 CJK UNIFIED IDEOGRAPH-#2CE32
2CE33 CJK UNIFIED IDEOGRAPH-#2CE33
2CE34 CJK UNIFIED IDEOGRAPH-#2CE34
2CE35 CJK UNIFIED IDEOGRAPH-#2CE35
2CE36 CJK UNIFIED IDEOGRAPH-#2CE36
2CE37 CJK UNIFIED IDEOGRAPH-#2CE37
2CE38 CJK UNIFIED IDEOGRAPH-#2CE38
2CE39 CJK UNIFIED IDEOGRAPH-#2CE39
2CE3A CJK UNIFIED IDEOGRAPH-#2CE3A
2CE3B CJK UNIFIED IDEOGRAPH-#2CE3B
2CE3C CJK UNIFIED IDEOGRAPH-#2CE3C
2CE3D CJK UNIFIED IDEOGRAPH-#2CE3D
2CE3E CJK UNIFIED IDEOGRAPH-#2CE3E
2CE3F CJK UNIFIED IDEOGRAPH-#2CE3F
2CE40 CJK UNIFIED IDEOGRAPH-#2CE40
2CE41 CJK UNIFIED IDEOGRAPH-#2CE41
2CE42 CJK UNIFIED IDEOGRAPH-#2CE42
2CE43 CJK UNIFIED IDEOGRAPH-#2CE43
2CE44 CJK UNIFIED IDEOGRAPH-#2CE44
2CE45 CJK UNIFIED IDEOGRAPH-#2CE45
2CE46 CJK UNIFIED IDEOGRAPH-#2CE46
2CE47 CJK UNIFIED IDEOGRAPH-#2CE47
2CE48 CJK UNIFIED IDEOGRAPH-#2CE48
2CE49 CJK UNIFIED IDEOGRAPH-#2CE49
2CE4A CJK UNIFIED IDEOGRAPH-#2CE4A
2CE4B CJK UNIFIED IDEOGRAPH-#2CE4B
2CE4C CJK UNIFIED IDEOGRAPH-#2CE4C
2CE4D CJK UNIFIED IDEOGRAPH-#2CE4D
2CE4E CJK UNIFIED IDEOGRAPH-#2CE4E
2CE4F CJK UNIFIED IDEOGRAPH-#2CE4F
2CE50 CJK UNIFIED IDEOGRAPH-#2CE50
2CE51 CJK UNIFIED IDEOGRAPH-#2CE51
2CE52 CJK UNIFIED IDEOGRAPH-#2CE52
2CE53 CJK UNIFIED IDEOGRAPH-#2CE53
2CE54 CJK UNIFIED IDEOGRAPH-#2CE54
2CE55 CJK UNIFIED IDEOGRAPH-#2CE55
2CE56 CJK UNIFIED IDEOGRAPH-#2CE56
2CE57 CJK UNIFIED IDEOGRAPH-#2CE57
2CE58 CJK UNIFIED IDEOGRAPH-#2CE58
2CE59 CJK UNIFIED IDEOGRAPH-#2CE59
2CE5A CJK UNIFIED IDEOGRAPH-#2CE5A
2CE5B CJK UNIFIED IDEOGRAPH-#2CE5B
2CE5C CJK UNIFIED IDEOGRAPH-#2CE5C
2CE5D CJK UNIFIED IDEOGRAPH-#2CE5D
2CE5E CJK UNIFIED IDEOGRAPH-#2CE5E
2CE5F CJK UNIFIED IDEOGRAPH-#2CE5F
2CE60 CJK UNIFIED IDEOGRAPH-#2CE60
2CE61 CJK UNIFIED IDEOGRAPH-#2CE61
2CE62 CJK UNIFIED IDEOGRAPH-#2CE62
2CE63 CJK UNIFIED IDEOGRAPH-#2CE63
2CE64 CJK UNIFIED IDEOGRAPH-#2CE64
2CE65 CJK UNIFIED IDEOGRAPH-#2CE65
2CE66 CJK UNIFIED IDEOGRAPH-#2CE66
2CE67 CJK UNIFIED IDEOGRAPH-#2CE67
2CE68 CJK UNIFIED IDEOGRAPH-#2CE68
2CE69 CJK UNIFIED IDEOGRAPH-#2CE69
2CE6A CJK UNIFIED IDEOGRAPH-#2CE6A
2CE6B CJK UNIFIED IDEOGRAPH-#2CE6B
2CE6C CJK UNIFIED IDEOGRAPH-#2CE6C
2CE6D CJK UNIFIED IDEOGRAPH-#2CE6D
2CE6E CJK UNIFIED IDEOGRAPH-#2CE6E
2CE6F CJK UNIFIED IDEOGRAPH-#2CE6F
2CE70 CJK UNIFIED IDEOGRAPH-#2CE70
2CE71 CJK UNIFIED IDEOGRAPH-#2CE71
2CE72 CJK UNIFIED IDEOGRAPH-#2CE72
2CE73 CJK UNIFIED IDEOGRAPH-#2CE73
2CE74 CJK UNIFIED IDEOGRAPH-#2CE74
2CE75 CJK UNIFIED IDEOGRAPH-#2CE75
2CE76 CJK UNIFIED IDEOGRAPH-#2CE76
2CE77 CJK UNIFIED IDEOGRAPH-#2CE77
2CE78 CJK UNIFIED IDEOGRAPH-#2CE78
2CE79 CJK UNIFIED IDEOGRAPH-#2CE79
2CE7A CJK UNIFIED IDEOGRAPH-#2CE7A
2CE7B CJK UNIFIED IDEOGRAPH-#2CE7B
2CE7C CJK UNIFIED IDEOGRAPH-#2CE7C
2CE7D CJK UNIFIED IDEOGRAPH-#2CE7D
2CE7E CJK UNIFIED IDEOGRAPH-#2CE7E
2CE7F CJK UNIFIED IDEOGRAPH-#2CE7F
2CE80 CJK UNIFIED IDEOGRAPH-#2CE80
2CE81 CJK UNIFIED IDEOGRAPH-#2CE81
2CE82 CJK UNIFIED IDEOGRAPH-#2CE82
2CE83 CJK UNIFIED IDEOGRAPH-#2CE83
2CE84 CJK UNIFIED IDEOGRAPH-#2CE84
2CE85 CJK UNIFIED IDEOGRAPH-#2CE85
2CE86 CJK UNIFIED IDEOGRAPH-#2CE86
2CE87 CJK UNIFIED IDEOGRAPH-#2CE87
2CE88 CJK UNIFIED IDEOGRAPH-#2CE88
2CE89 CJK UNIFIED IDEOGRAPH-#2CE89
2CE8A CJK UNIFIED IDEOGRAPH-#2CE8A
2CE8B CJK UNIFIED IDEOGRAPH-#2CE8B
2CE8C CJK UNIFIED IDEOGRAPH-#2CE8C
2CE8D CJK UNIFIED IDEOGRAPH-#2CE8D
2CE8E CJK UNIFIED IDEOGRAPH-#2CE8E
2CE8F CJK UNIFIED IDEOGRAPH-#2CE8F
2CE90 CJK UNIFIED IDEOGRAPH-#2CE90
2CE91 CJK UNIFIED IDEOGRAPH-#2CE91
2CE92 CJK UNIFIED IDEOGRAPH-#2CE92
2CE93 CJK UNIFIED IDEOGRAPH-#2CE93
2CE94 CJK UNIFIED IDEOGRAPH-#2CE94
2CE95 CJK UNIFIED IDEOGRAPH-#2CE95
2CE96 CJK UNIFIED IDEOGRAPH-#2CE96
2CE97 CJK UNIFIED IDEOGRAPH-#2CE97
2CE98 CJK UNIFIED IDEOGRAPH-#2CE98
2CE99 CJK UNIFIED IDEOGRAPH-#2CE99
2CE9A CJK UNIFIED IDEOGRAPH-#2CE9A
2CE9B CJK UNIFIED IDEOGRAPH-#2CE9B
2CE9C CJK UNIFIED IDEOGRAPH-#2CE9C
2CE9D CJK UNIFIED IDEOGRAPH-#2CE9D
2CE9E CJK UNIFIED IDEOGRAPH-#2CE9E
2CE9F CJK UNIFIED IDEOGRAPH-#2CE9F
2CEA0 CJK UNIFIED IDEOGRAPH-#2CEA0
2CEA1 CJK UNIFIED IDEOGRAPH-#2CEA1
2CEB0 CJK UNIFIED IDEOGRAPH-#2CEB0
2CEB1 CJK UNIFIED IDEOGRAPH-#2CEB1
2CEB2 CJK UNIFIED IDEOGRAPH-#2CEB2
2CEB3 CJK UNIFIED IDEOGRAPH-#2CEB3
2CEB4 CJK UNIFIED IDEOGRAPH-#2CEB4
2CEB5 CJK UNIFIED IDEOGRAPH-#2CEB5
2CEB6 CJK UNIFIED IDEOGRAPH-#2CEB6
2CEB7 CJK UNIFIED IDEOGRAPH-#2CEB7
2CEB8 CJK UNIFIED IDEOGRAPH-#2CEB8
2CEB9 CJK UNIFIED IDEOGRAPH-#2CEB9
2CEBA CJK UNIFIED IDEOGRAPH-#2CEBA
2CEBB CJK UNIFIED IDEOGRAPH-#2CEBB
2CEBC CJK UNIFIED IDEOGRAPH-#2CEBC
2CEBD CJK UNIFIED IDEOGRAPH-#2CEBD
2CEBE CJK UNIFIED IDEOGRAPH-#2CEBE
2CEBF CJK UNIFIED IDEOGRAPH-#2CEBF
2CEC0 CJK UNIFIED IDEOGRAPH-#2CEC0
2CEC1 CJK UNIFIED IDEOGRAPH-#2CEC1
2CEC2 CJK UNIFIED IDEOGRAPH-#2CEC2
2CEC3 CJK UNIFIED IDEOGRAPH-#2CEC3
2CEC4 CJK UNIFIED IDEOGRAPH-#2CEC4
2CEC5 CJK UNIFIED IDEOGRAPH-#2CEC5
2CEC6 CJK UNIFIED IDEOGRAPH-#2CEC6
2CEC7 CJK UNIFIED IDEOGRAPH-#2CEC7
2CEC8 CJK UNIFIED IDEOGRAPH-#2CEC8
2CEC9 CJK UNIFIED IDEOGRAPH-#2CEC9
2CECA CJK UNIFIED IDEOGRAPH-#2CECA
2CECB CJK UNIFIED IDEOGRAPH-#2CECB
2CECC CJK UNIFIED IDEOGRAPH-#2CECC
2CECD CJK UNIFIED IDEOGRAPH-#2CECD
2CECE CJK UNIFIED IDEOGRAPH-#2CECE
2CECF CJK UNIFIED IDEOGRAPH-#2CECF
2CED0 CJK UNIFIED IDEOGRAPH-#2CED0
2CED1 CJK UNIFIED IDEOGRAPH-#2CED1
2CED2 CJK UNIFIED IDEOGRAPH-#2CED2
2CED3 CJK UNIFIED IDEOGRAPH-#2CED3
2CED4 CJK UNIFIED IDEOGRAPH-#2CED4
2CED5 CJK UNIFIED IDEOGRAPH-#2CED5
2CED6 CJK UNIFIED IDEOGRAPH-#2CED6
2CED7 CJK UNIFIED IDEOGRAPH-#2CED7
2CED8 CJK UNIFIED IDEOGRAPH-#2CED8
2CED9 CJK UNIFIED IDEOGRAPH-#2CED9
2CEDA CJK UNIFIED IDEOGRAPH-#2CEDA
2CEDB CJK UNIFIED IDEOGRAPH-#2CEDB
2CEDC CJK UNIFIED IDEOGRAPH-#2CEDC
2CEDD CJK UNIFIED IDEOGRAPH-#2CEDD
2CEDE CJK UNIFIED IDEOGRAPH-#2CEDE
2CEDF CJK UNIFIED IDEOGRAPH-#2CEDF
2CEE0 CJK UNIFIED IDEOGRAPH-#2CEE0
2CEE1 CJK UNIFIED IDEOGRAPH-#2CEE1
2CEE2 CJK UNIFIED IDEOGRAPH-#2CEE2
2CEE3 CJK UNIFIED IDEOGRAPH-#2CEE3
2CEE4 CJK UNIFIED IDEOGRAPH-#2CEE4
2CEE5 CJK UNIFIED IDEOGRAPH-#2CEE5
2CEE6 CJK UNIFIED IDEOGRAPH-#2CEE6
2CEE7 CJK UNIFIED IDEOGRAPH-#2CEE7
2CEE8 CJK UNIFIED IDEOGRAPH-#2CEE8
2CEE9 CJK UNIFIED IDEOGRAPH-#2CEE9
2CEEA CJK UNIFIED IDEOGRAPH-#2CEEA
2CEEB CJK UNIFIED IDEOGRAPH-#2CEEB
2CEEC CJK UNIFIED IDEOGRAPH-#2CEEC
2CEED CJK UNIFIED IDEOGRAPH-#2CEED
2CEEE CJK UNIFIED IDEOGRAPH-#2CEEE
2CEEF CJK UNIFIED IDEOGRAPH-#2CEEF
2CEF0 CJK UNIFIED IDEOGRAPH-#2CEF0
2CEF1 CJK UNIFIED IDEOGRAPH-#2CEF1
2CEF2 CJK UNIFIED IDEOGRAPH-#2CEF2
2CEF3 CJK UNIFIED IDEOGRAPH-#2CEF3
2CEF4 CJK UNIFIED IDEOGRAPH-#2CEF4
2CEF5 CJK UNIFIED IDEOGRAPH-#2CEF5
2CEF6 CJK UNIFIED IDEOGRAPH-#2CEF6
2CEF7 CJK UNIFIED IDEOGRAPH-#2CEF7
2CEF8 CJK UNIFIED IDEOGRAPH-#2CEF8
2CEF9 CJK UNIFIED IDEOGRAPH-#2CEF9
2CEFA CJK UNIFIED IDEOGRAPH-#2CEFA
2CEFB CJK UNIFIED IDEOGRAPH-#2CEFB
2CEFC CJK UNIFIED IDEOGRAPH-#2CEFC
2CEFD CJK UNIFIED IDEOGRAPH-#2CEFD
2CEFE CJK UNIFIED IDEOGRAPH-#2CEFE
2CEFF CJK UNIFIED IDEOGRAPH-#2CEFF
2CF00 CJK UNIFIED IDEOGRAPH-#2CF00
2CF01 CJK UNIFIED IDEOGRAPH-#2CF01
2CF02 CJK UNIFIED IDEOGRAPH-#2CF02
2CF03 CJK UNIFIED IDEOGRAPH-#2CF03
2CF04 CJK UNIFIED IDEOGRAPH-#2CF04
2CF05 CJK UNIFIED IDEOGRAPH-#2CF05
2CF06 CJK UNIFIED IDEOGRAPH-#2CF06
2CF07 CJK UNIFIED IDEOGRAPH-#2CF07
2CF08 CJK UNIFIED IDEOGRAPH-#2CF08
2CF09 CJK UNIFIED IDEOGRAPH-#2CF09
2CF0A CJK UNIFIED IDEOGRAPH-#2CF0A
2CF0B CJK UNIFIED IDEOGRAPH-#2CF0B
2CF0C CJK UNIFIED IDEOGRAPH-#2CF0C
2CF0D CJK UNIFIED IDEOGRAPH-#2CF0D
2CF0E CJK UNIFIED IDEOGRAPH-#2CF0E
2CF0F CJK UNIFIED IDEOGRAPH-#2CF0F
2CF10 CJK UNIFIED IDEOGRAPH-#2CF10
2CF11 CJK UNIFIED IDEOGRAPH-#2CF11
2CF12 CJK UNIFIED IDEOGRAPH-#2CF12
2CF13 CJK UNIFIED IDEOGRAPH-#2CF13
2CF14 CJK UNIFIED IDEOGRAPH-#2CF14
2CF15 CJK UNIFIED IDEOGRAPH-#2CF15
2CF16 CJK UNIFIED IDEOGRAPH-#2CF16
2CF17 CJK UNIFIED IDEOGRAPH-#2CF17
2CF18 CJK UNIFIED IDEOGRAPH-#2CF18
2CF19 CJK UNIFIED IDEOGRAPH-#2CF19
2CF1A CJK UNIFIED IDEOGRAPH-#2CF1A
2CF1B CJK UNIFIED IDEOGRAPH-#2CF1B
2CF1C CJK UNIFIED IDEOGRAPH-#2CF1C
2CF1D CJK UNIFIED IDEOGRAPH-#2CF1D
2CF1E CJK UNIFIED IDEOGRAPH-#2CF1E
2CF1F CJK UNIFIED IDEOGRAPH-#2CF1F
2CF20 CJK UNIFIED IDEOGRAPH-#2CF20
2CF21 CJK UNIFIED IDEOGRAPH-#2CF21
2CF22 CJK UNIFIED IDEOGRAPH-#2CF22
2CF23 CJK UNIFIED IDEOGRAPH-#2CF23
2CF24 CJK UNIFIED IDEOGRAPH-#2CF24
2CF25 CJK UNIFIED IDEOGRAPH-#2CF25
2CF26 CJK UNIFIED IDEOGRAPH-#2CF26
2CF27 CJK UNIFIED IDEOGRAPH-#2CF27
2CF28 CJK UNIFIED IDEOGRAPH-#2CF28
2CF29 CJK UNIFIED IDEOGRAPH-#2CF29
2CF2A CJK UNIFIED IDEOGRAPH-#2CF2A
2CF2B CJK UNIFIED IDEOGRAPH-#2CF2B
2CF2C CJK UNIFIED IDEOGRAPH-#2CF2C
2CF2D CJK UNIFIED IDEOGRAPH-#2CF2D
2CF2E CJK UNIFIED IDEOGRAPH-#2CF2E
2CF2F CJK UNIFIED IDEOGRAPH-#2CF2F
2CF30 CJK UNIFIED IDEOGRAPH-#2CF30
2CF31 CJK UNIFIED IDEOGRAPH-#2CF31
2CF32 CJK UNIFIED IDEOGRAPH-#2CF32
2CF33 CJK UNIFIED IDEOGRAPH-#2CF33
2CF34 CJK UNIFIED IDEOGRAPH-#2CF34
2CF35 CJK UNIFIED IDEOGRAPH-#2CF35
2CF36 CJK UNIFIED IDEOGRAPH-#2CF36
2CF37 CJK UNIFIED IDEOGRAPH-#2CF37
2CF38 CJK UNIFIED IDEOGRAPH-#2CF38
2CF39 CJK UNIFIED IDEOGRAPH-#2CF39
2CF3A CJK UNIFIED IDEOGRAPH-#2CF3A
2CF3B CJK UNIFIED IDEOGRAPH-#2CF3B
2CF3C CJK UNIFIED IDEOGRAPH-#2CF3C
2CF3D CJK UNIFIED IDEOGRAPH-#2CF3D
2CF3E CJK UNIFIED IDEOGRAPH-#2CF3E
2CF3F CJK UNIFIED IDEOGRAPH-#2CF3F
2CF40 CJK UNIFIED IDEOGRAPH-#2CF40
2CF41 CJK UNIFIED IDEOGRAPH-#2CF41
2CF42 CJK UNIFIED IDEOGRAPH-#2CF42
2CF43 CJK UNIFIED IDEOGRAPH-#2CF43
2CF44 CJK UNIFIED IDEOGRAPH-#2CF44
2CF45 CJK UNIFIED IDEOGRAPH-#2CF45
2CF46 CJK UNIFIED IDEOGRAPH-#2CF46
2CF47 CJK UNIFIED IDEOGRAPH-#2CF47
2CF48 CJK UNIFIED IDEOGRAPH-#2CF48
2CF49 CJK UNIFIED IDEOGRAPH-#2CF49
2CF4A CJK UNIFIED IDEOGRAPH-#2CF4A
2CF4B CJK UNIFIED IDEOGRAPH-#2CF4B
2CF4C CJK UNIFIED IDEOGRAPH-#2CF4C
2CF4D CJK UNIFIED IDEOGRAPH-#2CF4D
2CF4E CJK UNIFIED IDEOGRAPH-#2CF4E
2CF4F CJK UNIFIED IDEOGRAPH-#2CF4F
2CF50 CJK UNIFIED IDEOGRAPH-#2CF50
2CF51 CJK UNIFIED IDEOGRAPH-#2CF51
2CF52 CJK UNIFIED IDEOGRAPH-#2CF52
2CF53 CJK UNIFIED IDEOGRAPH-#2CF53
2CF54 CJK UNIFIED IDEOGRAPH-#2CF54
2CF55 CJK UNIFIED IDEOGRAPH-#2CF55
2CF56 CJK UNIFIED IDEOGRAPH-#2CF56
2CF57 CJK UNIFIED IDEOGRAPH-#2CF57
2CF58 CJK UNIFIED IDEOGRAPH-#2CF58
2CF59 CJK UNIFIED IDEOGRAPH-#2CF59
2CF5A CJK UNIFIED IDEOGRAPH-#2CF5A
2CF5B CJK UNIFIED IDEOGRAPH-#2CF5B
2CF5C CJK UNIFIED IDEOGRAPH-#2CF5C
2CF5D CJK UNIFIED IDEOGRAPH-#2CF5D
2CF5E CJK UNIFIED IDEOGRAPH-#2CF5E
2CF5F CJK UNIFIED IDEOGRAPH-#2CF5F
2CF60 CJK UNIFIED IDEOGRAPH-#2CF60
2CF61 CJK UNIFIED IDEOGRAPH-#2CF61
2CF62 CJK UNIFIED IDEOGRAPH-#2CF62
2CF63 CJK UNIFIED IDEOGRAPH-#2CF63
2CF64 CJK UNIFIED IDEOGRAPH-#2CF64
2CF65 CJK UNIFIED IDEOGRAPH-#2CF65
2CF66 CJK UNIFIED IDEOGRAPH-#2CF66
2CF67 CJK UNIFIED IDEOGRAPH-#2CF67
2CF68 CJK UNIFIED IDEOGRAPH-#2CF68
2CF69 CJK UNIFIED IDEOGRAPH-#2CF69
2CF6A CJK UNIFIED IDEOGRAPH-#2CF6A
2CF6B CJK UNIFIED IDEOGRAPH-#2CF6B
2CF6C CJK UNIFIED IDEOGRAPH-#2CF6C
2CF6D CJK UNIFIED IDEOGRAPH-#2CF6D
2CF6E CJK UNIFIED IDEOGRAPH-#2CF6E
2CF6F CJK UNIFIED IDEOGRAPH-#2CF6F
2CF70 CJK UNIFIED IDEOGRAPH-#2CF70
2CF71 CJK UNIFIED IDEOGRAPH-#2CF71
2CF72 CJK UNIFIED IDEOGRAPH-#2CF72
2CF73 CJK UNIFIED IDEOGRAPH-#2CF73
2CF74 CJK UNIFIED IDEOGRAPH-#2CF74
2CF75 CJK UNIFIED IDEOGRAPH-#2CF75
2CF76 CJK UNIFIED IDEOGRAPH-#2CF76
2CF77 CJK UNIFIED IDEOGRAPH-#2CF77
2CF78 CJK UNIFIED IDEOGRAPH-#2CF78
2CF79 CJK UNIFIED IDEOGRAPH-#2CF79
2CF7A CJK UNIFIED IDEOGRAPH-#2CF7A
2CF7B CJK UNIFIED IDEOGRAPH-#2CF7B
2CF7C CJK UNIFIED IDEOGRAPH-#2CF7C
2CF7D CJK UNIFIED IDEOGRAPH-#2CF7D
2CF7E CJK UNIFIED IDEOGRAPH-#2CF7E
2CF7F CJK UNIFIED IDEOGRAPH-#2CF7F
2CF80 CJK UNIFIED IDEOGRAPH-#2CF80
2CF81 CJK UNIFIED IDEOGRAPH-#2CF81
2CF82 CJK UNIFIED IDEOGRAPH-#2CF82
2CF83 CJK UNIFIED IDEOGRAPH-#2CF83
2CF84 CJK UNIFIED IDEOGRAPH-#2CF84
2CF85 CJK UNIFIED IDEOGRAPH-#2CF85
2CF86 CJK UNIFIED IDEOGRAPH-#2CF86
2CF87 CJK UNIFIED IDEOGRAPH-#2CF87
2CF88 CJK UNIFIED IDEOGRAPH-#2CF88
2CF89 CJK UNIFIED IDEOGRAPH-#2CF89
2CF8A CJK UNIFIED IDEOGRAPH-#2CF8A
2CF8B CJK UNIFIED IDEOGRAPH-#2CF8B
2CF8C CJK UNIFIED IDEOGRAPH-#2CF8C
2CF8D CJK UNIFIED IDEOGRAPH-#2CF8D
2CF8E CJK UNIFIED IDEOGRAPH-#2CF8E
2CF8F CJK UNIFIED IDEOGRAPH-#2CF8F
2CF90 CJK UNIFIED IDEOGRAPH-#2CF90
2CF91 CJK UNIFIED IDEOGRAPH-#2CF91
2CF92 CJK UNIFIED IDEOGRAPH-#2CF92
2CF93 CJK UNIFIED IDEOGRAPH-#2CF93
2CF94 CJK UNIFIED IDEOGRAPH-#2CF94
2CF95 CJK UNIFIED IDEOGRAPH-#2CF95
2CF96 CJK UNIFIED IDEOGRAPH-#2CF96
2CF97 CJK UNIFIED IDEOGRAPH-#2CF97
2CF98 CJK UNIFIED IDEOGRAPH-#2CF98
2CF99 CJK UNIFIED IDEOGRAPH-#2CF99
2CF9A CJK UNIFIED IDEOGRAPH-#2CF9A
2CF9B CJK UNIFIED IDEOGRAPH-#2CF9B
2CF9C CJK UNIFIED IDEOGRAPH-#2CF9C
2CF9D CJK UNIFIED IDEOGRAPH-#2CF9D
2CF9E CJK UNIFIED IDEOGRAPH-#2CF9E
2CF9F CJK UNIFIED IDEOGRAPH-#2CF9F
2CFA0 CJK UNIFIED IDEOGRAPH-#2CFA0
2CFA1 CJK UNIFIED IDEOGRAPH-#2CFA1
2CFA2 CJK UNIFIED IDEOGRAPH-#2CFA2
2CFA3 CJK UNIFIED IDEOGRAPH-#2CFA3
2CFA4 CJK UNIFIED IDEOGRAPH-#2CFA4
2CFA5 CJK UNIFIED IDEOGRAPH-#2CFA5
2CFA6 CJK UNIFIED IDEOGRAPH-#2CFA6
2CFA7 CJK UNIFIED IDEOGRAPH-#2CFA7
2CFA8 CJK UNIFIED IDEOGRAPH-#2CFA8
2CFA9 CJK UNIFIED IDEOGRAPH-#2CFA9
2CFAA CJK UNIFIED IDEOGRAPH-#2CFAA
2CFAB CJK UNIFIED IDEOGRAPH-#2CFAB
2CFAC CJK UNIFIED IDEOGRAPH-#2CFAC
2CFAD CJK UNIFIED IDEOGRAPH-#2CFAD
2CFAE CJK UNIFIED IDEOGRAPH-#2CFAE
2CFAF CJK UNIFIED IDEOGRAPH-#2CFAF
2CFB0 CJK UNIFIED IDEOGRAPH-#2CFB0
2CFB1 CJK UNIFIED IDEOGRAPH-#2CFB1
2CFB2 CJK UNIFIED IDEOGRAPH-#2CFB2
2CFB3 CJK UNIFIED IDEOGRAPH-#2CFB3
2CFB4 CJK UNIFIED IDEOGRAPH-#2CFB4
2CFB5 CJK UNIFIED IDEOGRAPH-#2CFB5
2CFB6 CJK UNIFIED IDEOGRAPH-#2CFB6
2CFB7 CJK UNIFIED IDEOGRAPH-#2CFB7
2CFB8 CJK UNIFIED IDEOGRAPH-#2CFB8
2CFB9 CJK UNIFIED IDEOGRAPH-#2CFB9
2CFBA CJK UNIFIED IDEOGRAPH-#2CFBA
2CFBB CJK UNIFIED IDEOGRAPH-#2CFBB
2CFBC CJK UNIFIED IDEOGRAPH-#2CFBC
2CFBD CJK UNIFIED IDEOGRAPH-#2CFBD
2CFBE CJK UNIFIED IDEOGRAPH-#2CFBE
2CFBF CJK UNIFIED IDEOGRAPH-#2CFBF
2CFC0 CJK UNIFIED IDEOGRAPH-#2CFC0
2CFC1 CJK UNIFIED IDEOGRAPH-#2CFC1
2CFC2 CJK UNIFIED IDEOGRAPH-#2CFC2
2CFC3 CJK UNIFIED IDEOGRAPH-#2CFC3
2CFC4 CJK UNIFIED IDEOGRAPH-#2CFC4
2CFC5 CJK UNIFIED IDEOGRAPH-#2CFC5
2CFC6 CJK UNIFIED IDEOGRAPH-#2CFC6
2CFC7 CJK UNIFIED IDEOGRAPH-#2CFC7
2CFC8 CJK UNIFIED IDEOGRAPH-#2CFC8
2CFC9 CJK UNIFIED IDEOGRAPH-#2CFC9
2CFCA CJK UNIFIED IDEOGRAPH-#2CFCA
2CFCB CJK UNIFIED IDEOGRAPH-#2CFCB
2CFCC CJK UNIFIED IDEOGRAPH-#2CFCC
2CFCD CJK UNIFIED IDEOGRAPH-#2CFCD
2CFCE CJK UNIFIED IDEOGRAPH-#2CFCE
2CFCF CJK UNIFIED IDEOGRAPH-#2CFCF
2CFD0 CJK UNIFIED IDEOGRAPH-#2CFD0
2CFD1 CJK UNIFIED IDEOGRAPH-#2CFD1
2CFD2 CJK UNIFIED IDEOGRAPH-#2CFD2
2CFD3 CJK UNIFIED IDEOGRAPH-#2CFD3
2CFD4 CJK UNIFIED IDEOGRAPH-#2CFD4
2CFD5 CJK UNIFIED IDEOGRAPH-#2CFD5
2CFD6 CJK UNIFIED IDEOGRAPH-#2CFD6
2CFD7 CJK UNIFIED IDEOGRAPH-#2CFD7
2CFD8 CJK UNIFIED IDEOGRAPH-#2CFD8
2CFD9 CJK UNIFIED IDEOGRAPH-#2CFD9
2CFDA CJK UNIFIED IDEOGRAPH-#2CFDA
2CFDB CJK UNIFIED IDEOGRAPH-#2CFDB
2CFDC CJK UNIFIED IDEOGRAPH-#2CFDC
2CFDD CJK UNIFIED IDEOGRAPH-#2CFDD
2CFDE CJK UNIFIED IDEOGRAPH-#2CFDE
2CFDF CJK UNIFIED IDEOGRAPH-#2CFDF
2CFE0 CJK UNIFIED IDEOGRAPH-#2CFE0
2CFE1 CJK UNIFIED IDEOGRAPH-#2CFE1
2CFE2 CJK UNIFIED IDEOGRAPH-#2CFE2
2CFE3 CJK UNIFIED IDEOGRAPH-#2CFE3
2CFE4 CJK UNIFIED IDEOGRAPH-#2CFE4
2CFE5 CJK UNIFIED IDEOGRAPH-#2CFE5
2CFE6 CJK UNIFIED IDEOGRAPH-#2CFE6
2CFE7 CJK UNIFIED IDEOGRAPH-#2CFE7
2CFE8 CJK UNIFIED IDEOGRAPH-#2CFE8
2CFE9 CJK UNIFIED IDEOGRAPH-#2CFE9
2CFEA CJK UNIFIED IDEOGRAPH-#2CFEA
2CFEB CJK UNIFIED IDEOGRAPH-#2CFEB
2CFEC CJK UNIFIED IDEOGRAPH-#2CFEC
2CFED CJK UNIFIED IDEOGRAPH-#2CFED
2CFEE CJK UNIFIED IDEOGRAPH-#2CFEE
2CFEF CJK UNIFIED IDEOGRAPH-#2CFEF
2CFF0 CJK UNIFIED IDEOGRAPH-#2CFF0
2CFF1 CJK UNIFIED IDEOGRAPH-#2CFF1
2CFF2 CJK UNIFIED IDEOGRAPH-#2CFF2
2CFF3 CJK UNIFIED IDEOGRAPH-#2CFF3
2CFF4 CJK UNIFIED IDEOGRAPH-#2CFF4
2CFF5 CJK UNIFIED IDEOGRAPH-#2CFF5
2CFF6 CJK UNIFIED IDEOGRAPH-#2CFF6
2CFF7 CJK UNIFIED IDEOGRAPH-#2CFF7
2CFF8 CJK UNIFIED IDEOGRAPH-#2CFF8
2CFF9 CJK UNIFIED IDEOGRAPH-#2CFF9
2CFFA CJK UNIFIED IDEOGRAPH-#2CFFA
2CFFB CJK UNIFIED IDEOGRAPH-#2CFFB
2CFFC CJK UNIFIED IDEOGRAPH-#2CFFC
2CFFD CJK UNIFIED IDEOGRAPH-#2CFFD
2CFFE CJK UNIFIED IDEOGRAPH-#2CFFE
2CFFF CJK UNIFIED IDEOGRAPH-#2CFFF
2D000 CJK UNIFIED IDEOGRAPH-#2D000
2D001 CJK UNIFIED IDEOGRAPH-#2D001
2D002 CJK UNIFIED IDEOGRAPH-#2D002
2D003 CJK UNIFIED IDEOGRAPH-#2D003
2D004 CJK UNIFIED IDEOGRAPH-#2D004
2D005 CJK UNIFIED IDEOGRAPH-#2D005
2D006 CJK UNIFIED IDEOGRAPH-#2D006
2D007 CJK UNIFIED IDEOGRAPH-#2D007
2D008 CJK UNIFIED IDEOGRAPH-#2D008
2D009 CJK UNIFIED IDEOGRAPH-#2D009
2D00A CJK UNIFIED IDEOGRAPH-#2D00A
2D00B CJK UNIFIED IDEOGRAPH-#2D00B
2D00C CJK UNIFIED IDEOGRAPH-#2D00C
2D00D CJK UNIFIED IDEOGRAPH-#2D00D
2D00E CJK UNIFIED IDEOGRAPH-#2D00E
2D00F CJK UNIFIED IDEOGRAPH-#2D00F
2D010 CJK UNIFIED IDEOGRAPH-#2D010
2D011 CJK UNIFIED IDEOGRAPH-#2D011
2D012 CJK UNIFIED IDEOGRAPH-#2D012
2D013 CJK UNIFIED IDEOGRAPH-#2D013
2D014 CJK UNIFIED IDEOGRAPH-#2D014
2D015 CJK UNIFIED IDEOGRAPH-#2D015
2D016 CJK UNIFIED IDEOGRAPH-#2D016
2D017 CJK UNIFIED IDEOGRAPH-#2D017
2D018 CJK UNIFIED IDEOGRAPH-#2D018
2D019 CJK UNIFIED IDEOGRAPH-#2D019
2D01A CJK UNIFIED IDEOGRAPH-#2D01A
2D01B CJK UNIFIED IDEOGRAPH-#2D01B
2D01C CJK UNIFIED IDEOGRAPH-#2D01C
2D01D CJK UNIFIED IDEOGRAPH-#2D01D
2D01E CJK UNIFIED IDEOGRAPH-#2D01E
2D01F CJK UNIFIED IDEOGRAPH-#2D01F
2D020 CJK UNIFIED IDEOGRAPH-#2D020
2D021 CJK UNIFIED IDEOGRAPH-#2D021
2D022 CJK UNIFIED IDEOGRAPH-#2D022
2D023 CJK UNIFIED IDEOGRAPH-#2D023
2D024 CJK UNIFIED IDEOGRAPH-#2D024
2D025 CJK UNIFIED IDEOGRAPH-#2D025
2D026 CJK UNIFIED IDEOGRAPH-#2D026
2D027 CJK UNIFIED IDEOGRAPH-#2D027
2D028 CJK UNIFIED IDEOGRAPH-#2D028
2D029 CJK UNIFIED IDEOGRAPH-#2D029
2D02A CJK UNIFIED IDEOGRAPH-#2D02A
2D02B CJK UNIFIED IDEOGRAPH-#2D02B
2D02C CJK UNIFIED IDEOGRAPH-#2D02C
2D02D CJK UNIFIED IDEOGRAPH-#2D02D
2D02E CJK UNIFIED IDEOGRAPH-#2D02E
2D02F CJK UNIFIED IDEOGRAPH-#2D02F
2D030 CJK UNIFIED IDEOGRAPH-#2D030
2D031 CJK UNIFIED IDEOGRAPH-#2D031
2D032 CJK UNIFIED IDEOGRAPH-#2D032
2D033 CJK UNIFIED IDEOGRAPH-#2D033
2D034 CJK UNIFIED IDEOGRAPH-#2D034
2D035 CJK UNIFIED IDEOGRAPH-#2D035
2D036 CJK UNIFIED IDEOGRAPH-#2D036
2D037 CJK UNIFIED IDEOGRAPH-#2D037
2D038 CJK UNIFIED IDEOGRAPH-#2D038
2D039 CJK UNIFIED IDEOGRAPH-#2D039
2D03A CJK UNIFIED IDEOGRAPH-#2D03A
2D03B CJK UNIFIED IDEOGRAPH-#2D03B
2D03C CJK UNIFIED IDEOGRAPH-#2D03C
2D03D CJK UNIFIED IDEOGRAPH-#2D03D
2D03E CJK UNIFIED IDEOGRAPH-#2D03E
2D03F CJK UNIFIED IDEOGRAPH-#2D03F
2D040 CJK UNIFIED IDEOGRAPH-#2D040
2D041 CJK UNIFIED IDEOGRAPH-#2D041
2D042 CJK UNIFIED IDEOGRAPH-#2D042
2D043 CJK UNIFIED IDEOGRAPH-#2D043
2D044 CJK UNIFIED IDEOGRAPH-#2D044
2D045 CJK UNIFIED IDEOGRAPH-#2D045
2D046 CJK UNIFIED IDEOGRAPH-#2D046
2D047 CJK UNIFIED IDEOGRAPH-#2D047
2D048 CJK UNIFIED IDEOGRAPH-#2D048
2D049 CJK UNIFIED IDEOGRAPH-#2D049
2D04A CJK UNIFIED IDEOGRAPH-#2D04A
2D04B CJK UNIFIED IDEOGRAPH-#2D04B
2D04C CJK UNIFIED IDEOGRAPH-#2D04C
2D04D CJK UNIFIED IDEOGRAPH-#2D04D
2D04E CJK UNIFIED IDEOGRAPH-#2D04E
2D04F CJK UNIFIED IDEOGRAPH-#2D04F
2D050 CJK UNIFIED IDEOGRAPH-#2D050
2D051 CJK UNIFIED IDEOGRAPH-#2D051
2D052 CJK UNIFIED IDEOGRAPH-#2D052
2D053 CJK UNIFIED IDEOGRAPH-#2D053
2D054 CJK UNIFIED IDEOGRAPH-#2D054
2D055 CJK UNIFIED IDEOGRAPH-#2D055
2D056 CJK UNIFIED IDEOGRAPH-#2D056
2D057 CJK UNIFIED IDEOGRAPH-#2D057
2D058 CJK UNIFIED IDEOGRAPH-#2D058
2D059 CJK UNIFIED IDEOGRAPH-#2D059
2D05A CJK UNIFIED IDEOGRAPH-#2D05A
2D05B CJK UNIFIED IDEOGRAPH-#2D05B
2D05C CJK UNIFIED IDEOGRAPH-#2D05C
2D05D CJK UNIFIED IDEOGRAPH-#2D05D
2D05E CJK UNIFIED IDEOGRAPH-#2D05E
2D05F CJK UNIFIED IDEOGRAPH-#2D05F
2D060 CJK UNIFIED IDEOGRAPH-#2D060
2D061 CJK UNIFIED IDEOGRAPH-#2D061
2D062 CJK UNIFIED IDEOGRAPH-#2D062
2D063 CJK UNIFIED IDEOGRAPH-#2D063
2D064 CJK UNIFIED IDEOGRAPH-#2D064
2D065 CJK UNIFIED IDEOGRAPH-#2D065
2D066 CJK UNIFIED IDEOGRAPH-#2D066
2D067 CJK UNIFIED IDEOGRAPH-#2D067
2D068 CJK UNIFIED IDEOGRAPH-#2D068
2D069 CJK UNIFIED IDEOGRAPH-#2D069
2D06A CJK UNIFIED IDEOGRAPH-#2D06A
2D06B CJK UNIFIED IDEOGRAPH-#2D06B
2D06C CJK UNIFIED IDEOGRAPH-#2D06C
2D06D CJK UNIFIED IDEOGRAPH-#2D06D
2D06E CJK UNIFIED IDEOGRAPH-#2D06E
2D06F CJK UNIFIED IDEOGRAPH-#2D06F
2D070 CJK UNIFIED IDEOGRAPH-#2D070
2D071 CJK UNIFIED IDEOGRAPH-#2D071
2D072 CJK UNIFIED IDEOGRAPH-#2D072
2D073 CJK UNIFIED IDEOGRAPH-#2D073
2D074 CJK UNIFIED IDEOGRAPH-#2D074
2D075 CJK UNIFIED IDEOGRAPH-#2D075
2D076 CJK UNIFIED IDEOGRAPH-#2D076
2D077 CJK UNIFIED IDEOGRAPH-#2D077
2D078 CJK UNIFIED IDEOGRAPH-#2D078
2D079 CJK UNIFIED IDEOGRAPH-#2D079
2D07A CJK UNIFIED IDEOGRAPH-#2D07A
2D07B CJK UNIFIED IDEOGRAPH-#2D07B
2D07C CJK UNIFIED IDEOGRAPH-#2D07C
2D07D CJK UNIFIED IDEOGRAPH-#2D07D
2D07E CJK UNIFIED IDEOGRAPH-#2D07E
2D07F CJK UNIFIED IDEOGRAPH-#2D07F
2D080 CJK UNIFIED IDEOGRAPH-#2D080
2D081 CJK UNIFIED IDEOGRAPH-#2D081
2D082 CJK UNIFIED IDEOGRAPH-#2D082
2D083 CJK UNIFIED IDEOGRAPH-#2D083
2D084 CJK UNIFIED IDEOGRAPH-#2D084
2D085 CJK UNIFIED IDEOGRAPH-#2D085
2D086 CJK UNIFIED IDEOGRAPH-#2D086
2D087 CJK UNIFIED IDEOGRAPH-#2D087
2D088 CJK UNIFIED IDEOGRAPH-#2D088
2D089 CJK UNIFIED IDEOGRAPH-#2D089
2D08A CJK UNIFIED IDEOGRAPH-#2D08A
2D08B CJK UNIFIED IDEOGRAPH-#2D08B
2D08C CJK UNIFIED IDEOGRAPH-#2D08C
2D08D CJK UNIFIED IDEOGRAPH-#2D08D
2D08E CJK UNIFIED IDEOGRAPH-#2D08E
2D08F CJK UNIFIED IDEOGRAPH-#2D08F
2D090 CJK UNIFIED IDEOGRAPH-#2D090
2D091 CJK UNIFIED IDEOGRAPH-#2D091
2D092 CJK UNIFIED IDEOGRAPH-#2D092
2D093 CJK UNIFIED IDEOGRAPH-#2D093
2D094 CJK UNIFIED IDEOGRAPH-#2D094
2D095 CJK UNIFIED IDEOGRAPH-#2D095
2D096 CJK UNIFIED IDEOGRAPH-#2D096
2D097 CJK UNIFIED IDEOGRAPH-#2D097
2D098 CJK UNIFIED IDEOGRAPH-#2D098
2D099 CJK UNIFIED IDEOGRAPH-#2D099
2D09A CJK UNIFIED IDEOGRAPH-#2D09A
2D09B CJK UNIFIED IDEOGRAPH-#2D09B
2D09C CJK UNIFIED IDEOGRAPH-#2D09C
2D09D CJK UNIFIED IDEOGRAPH-#2D09D
2D09E CJK UNIFIED IDEOGRAPH-#2D09E
2D09F CJK UNIFIED IDEOGRAPH-#2D09F
2D0A0 CJK UNIFIED IDEOGRAPH-#2D0A0
2D0A1 CJK UNIFIED IDEOGRAPH-#2D0A1
2D0A2 CJK UNIFIED IDEOGRAPH-#2D0A2
2D0A3 CJK UNIFIED IDEOGRAPH-#2D0A3
2D0A4 CJK UNIFIED IDEOGRAPH-#2D0A4
2D0A5 CJK UNIFIED IDEOGRAPH-#2D0A5
2D0A6 CJK UNIFIED IDEOGRAPH-#2D0A6
2D0A7 CJK UNIFIED IDEOGRAPH-#2D0A7
2D0A8 CJK UNIFIED IDEOGRAPH-#2D0A8
2D0A9 CJK UNIFIED IDEOGRAPH-#2D0A9
2D0AA CJK UNIFIED IDEOGRAPH-#2D0AA
2D0AB CJK UNIFIED IDEOGRAPH-#2D0AB
2D0AC CJK UNIFIED IDEOGRAPH-#2D0AC
2D0AD CJK UNIFIED IDEOGRAPH-#2D0AD
2D0AE CJK UNIFIED IDEOGRAPH-#2D0AE
2D0AF CJK UNIFIED IDEOGRAPH-#2D0AF
2D0B0 CJK UNIFIED IDEOGRAPH-#2D0B0
2D0B1 CJK UNIFIED IDEOGRAPH-#2D0B1
2D0B2 CJK UNIFIED IDEOGRAPH-#2D0B2
2D0B3 CJK UNIFIED IDEOGRAPH-#2D0B3
2D0B4 CJK UNIFIED IDEOGRAPH-#2D0B4
2D0B5 CJK UNIFIED IDEOGRAPH-#2D0B5
2D0B6 CJK UNIFIED IDEOGRAPH-#2D0B6
2D0B7 CJK UNIFIED IDEOGRAPH-#2D0B7
2D0B8 CJK UNIFIED IDEOGRAPH-#2D0B8
2D0B9 CJK UNIFIED IDEOGRAPH-#2D0B9
2D0BA CJK UNIFIED IDEOGRAPH-#2D0BA
2D0BB CJK UNIFIED IDEOGRAPH-#2D0BB
2D0BC CJK UNIFIED IDEOGRAPH-#2D0BC
2D0BD CJK UNIFIED IDEOGRAPH-#2D0BD
2D0BE CJK UNIFIED IDEOGRAPH-#2D0BE
2D0BF CJK UNIFIED IDEOGRAPH-#2D0BF
2D0C0 CJK UNIFIED IDEOGRAPH-#2D0C0
2D0C1 CJK UNIFIED IDEOGRAPH-#2D0C1
2D0C2 CJK UNIFIED IDEOGRAPH-#2D0C2
2D0C3 CJK UNIFIED IDEOGRAPH-#2D0C3
2D0C4 CJK UNIFIED IDEOGRAPH-#2D0C4
2D0C5 CJK UNIFIED IDEOGRAPH-#2D0C5
2D0C6 CJK UNIFIED IDEOGRAPH-#2D0C6
2D0C7 CJK UNIFIED IDEOGRAPH-#2D0C7
2D0C8 CJK UNIFIED IDEOGRAPH-#2D0C8
2D0C9 CJK UNIFIED IDEOGRAPH-#2D0C9
2D0CA CJK UNIFIED IDEOGRAPH-#2D0CA
2D0CB CJK UNIFIED IDEOGRAPH-#2D0CB
2D0CC CJK UNIFIED IDEOGRAPH-#2D0CC
2D0CD CJK UNIFIED IDEOGRAPH-#2D0CD
2D0CE CJK UNIFIED IDEOGRAPH-#2D0CE
2D0CF CJK UNIFIED IDEOGRAPH-#2D0CF
2D0D0 CJK UNIFIED IDEOGRAPH-#2D0D0
2D0D1 CJK UNIFIED IDEOGRAPH-#2D0D1
2D0D2 CJK UNIFIED IDEOGRAPH-#2D0D2
2D0D3 CJK UNIFIED IDEOGRAPH-#2D0D3
2D0D4 CJK UNIFIED IDEOGRAPH-#2D0D4
2D0D5 CJK UNIFIED IDEOGRAPH-#2D0D5
2D0D6 CJK UNIFIED IDEOGRAPH-#2D0D6
2D0D7 CJK UNIFIED IDEOGRAPH-#2D0D7
2D0D8 CJK UNIFIED IDEOGRAPH-#2D0D8
2D0D9 CJK UNIFIED IDEOGRAPH-#2D0D9
2D0DA CJK UNIFIED IDEOGRAPH-#2D0DA
2D0DB CJK UNIFIED IDEOGRAPH-#2D0DB
2D0DC CJK UNIFIED IDEOGRAPH-#2D0DC
2D0DD CJK UNIFIED IDEOGRAPH-#2D0DD
2D0DE CJK UNIFIED IDEOGRAPH-#2D0DE
2D0DF CJK UNIFIED IDEOGRAPH-#2D0DF
2D0E0 CJK UNIFIED IDEOGRAPH-#2D0E0
2D0E1 CJK UNIFIED IDEOGRAPH-#2D0E1
2D0E2 CJK UNIFIED IDEOGRAPH-#2D0E2
2D0E3 CJK UNIFIED IDEOGRAPH-#2D0E3
2D0E4 CJK UNIFIED IDEOGRAPH-#2D0E4
2D0E5 CJK UNIFIED IDEOGRAPH-#2D0E5
2D0E6 CJK UNIFIED IDEOGRAPH-#2D0E6
2D0E7 CJK UNIFIED IDEOGRAPH-#2D0E7
2D0E8 CJK UNIFIED IDEOGRAPH-#2D0E8
2D0E9 CJK UNIFIED IDEOGRAPH-#2D0E9
2D0EA CJK UNIFIED IDEOGRAPH-#2D0EA
2D0EB CJK UNIFIED IDEOGRAPH-#2D0EB
2D0EC CJK UNIFIED IDEOGRAPH-#2D0EC
2D0ED CJK UNIFIED IDEOGRAPH-#2D0ED
2D0EE CJK UNIFIED IDEOGRAPH-#2D0EE
2D0EF CJK UNIFIED IDEOGRAPH-#2D0EF
2D0F0 CJK UNIFIED IDEOGRAPH-#2D0F0
2D0F1 CJK UNIFIED IDEOGRAPH-#2D0F1
2D0F2 CJK UNIFIED IDEOGRAPH-#2D0F2
2D0F3 CJK UNIFIED IDEOGRAPH-#2D0F3
2D0F4 CJK UNIFIED IDEOGRAPH-#2D0F4
2D0F5 CJK UNIFIED IDEOGRAPH-#2D0F5
2D0F6 CJK UNIFIED IDEOGRAPH-#2D0F6
2D0F7 CJK UNIFIED IDEOGRAPH-#2D0F7
2D0F8 CJK UNIFIED IDEOGRAPH-#2D0F8
2D0F9 CJK UNIFIED IDEOGRAPH-#2D0F9
2D0FA CJK UNIFIED IDEOGRAPH-#2D0FA
2D0FB CJK UNIFIED IDEOGRAPH-#2D0FB
2D0FC CJK UNIFIED IDEOGRAPH-#2D0FC
2D0FD CJK UNIFIED IDEOGRAPH-#2D0FD
2D0FE CJK UNIFIED IDEOGRAPH-#2D0FE
2D0FF CJK UNIFIED IDEOGRAPH-#2D0FF
2D100 CJK UNIFIED IDEOGRAPH-#2D100
2D101 CJK UNIFIED IDEOGRAPH-#2D101
2D102 CJK UNIFIED IDEOGRAPH-#2D102
2D103 CJK UNIFIED IDEOGRAPH-#2D103
2D104 CJK UNIFIED IDEOGRAPH-#2D104
2D105 CJK UNIFIED IDEOGRAPH-#2D105
2D106 CJK UNIFIED IDEOGRAPH-#2D106
2D107 CJK UNIFIED IDEOGRAPH-#2D107
2D108 CJK UNIFIED IDEOGRAPH-#2D108
2D109 CJK UNIFIED IDEOGRAPH-#2D109
2D10A CJK UNIFIED IDEOGRAPH-#2D10A
2D10B CJK UNIFIED IDEOGRAPH-#2D10B
2D10C CJK UNIFIED IDEOGRAPH-#2D10C
2D10D CJK UNIFIED IDEOGRAPH-#2D10D
2D10E CJK UNIFIED IDEOGRAPH-#2D10E
2D10F CJK UNIFIED IDEOGRAPH-#2D10F
2D110 CJK UNIFIED IDEOGRAPH-#2D110
2D111 CJK UNIFIED IDEOGRAPH-#2D111
2D112 CJK UNIFIED IDEOGRAPH-#2D112
2D113 CJK UNIFIED IDEOGRAPH-#2D113
2D114 CJK UNIFIED IDEOGRAPH-#2D114
2D115 CJK UNIFIED IDEOGRAPH-#2D115
2D116 CJK UNIFIED IDEOGRAPH-#2D116
2D117 CJK UNIFIED IDEOGRAPH-#2D117
2D118 CJK UNIFIED IDEOGRAPH-#2D118
2D119 CJK UNIFIED IDEOGRAPH-#2D119
2D11A CJK UNIFIED IDEOGRAPH-#2D11A
2D11B CJK UNIFIED IDEOGRAPH-#2D11B
2D11C CJK UNIFIED IDEOGRAPH-#2D11C
2D11D CJK UNIFIED IDEOGRAPH-#2D11D
2D11E CJK UNIFIED IDEOGRAPH-#2D11E
2D11F CJK UNIFIED IDEOGRAPH-#2D11F
2D120 CJK UNIFIED IDEOGRAPH-#2D120
2D121 CJK UNIFIED IDEOGRAPH-#2D121
2D122 CJK UNIFIED IDEOGRAPH-#2D122
2D123 CJK UNIFIED IDEOGRAPH-#2D123
2D124 CJK UNIFIED IDEOGRAPH-#2D124
2D125 CJK UNIFIED IDEOGRAPH-#2D125
2D126 CJK UNIFIED IDEOGRAPH-#2D126
2D127 CJK UNIFIED IDEOGRAPH-#2D127
2D128 CJK UNIFIED IDEOGRAPH-#2D128
2D129 CJK UNIFIED IDEOGRAPH-#2D129
2D12A CJK UNIFIED IDEOGRAPH-#2D12A
2D12B CJK UNIFIED IDEOGRAPH-#2D12B
2D12C CJK UNIFIED IDEOGRAPH-#2D12C
2D12D CJK UNIFIED IDEOGRAPH-#2D12D
2D12E CJK UNIFIED IDEOGRAPH-#2D12E
2D12F CJK UNIFIED IDEOGRAPH-#2D12F
2D130 CJK UNIFIED IDEOGRAPH-#2D130
2D131 CJK UNIFIED IDEOGRAPH-#2D131
2D132 CJK UNIFIED IDEOGRAPH-#2D132
2D133 CJK UNIFIED IDEOGRAPH-#2D133
2D134 CJK UNIFIED IDEOGRAPH-#2D134
2D135 CJK UNIFIED IDEOGRAPH-#2D135
2D136 CJK UNIFIED IDEOGRAPH-#2D136
2D137 CJK UNIFIED IDEOGRAPH-#2D137
2D138 CJK UNIFIED IDEOGRAPH-#2D138
2D139 CJK UNIFIED IDEOGRAPH-#2D139
2D13A CJK UNIFIED IDEOGRAPH-#2D13A
2D13B CJK UNIFIED IDEOGRAPH-#2D13B
2D13C CJK UNIFIED IDEOGRAPH-#2D13C
2D13D CJK UNIFIED IDEOGRAPH-#2D13D
2D13E CJK UNIFIED IDEOGRAPH-#2D13E
2D13F CJK UNIFIED IDEOGRAPH-#2D13F
2D140 CJK UNIFIED IDEOGRAPH-#2D140
2D141 CJK UNIFIED IDEOGRAPH-#2D141
2D142 CJK UNIFIED IDEOGRAPH-#2D142
2D143 CJK UNIFIED IDEOGRAPH-#2D143
2D144 CJK UNIFIED IDEOGRAPH-#2D144
2D145 CJK UNIFIED IDEOGRAPH-#2D145
2D146 CJK UNIFIED IDEOGRAPH-#2D146
2D147 CJK UNIFIED IDEOGRAPH-#2D147
2D148 CJK UNIFIED IDEOGRAPH-#2D148
2D149 CJK UNIFIED IDEOGRAPH-#2D149
2D14A CJK UNIFIED IDEOGRAPH-#2D14A
2D14B CJK UNIFIED IDEOGRAPH-#2D14B
2D14C CJK UNIFIED IDEOGRAPH-#2D14C
2D14D CJK UNIFIED IDEOGRAPH-#2D14D
2D14E CJK UNIFIED IDEOGRAPH-#2D14E
2D14F CJK UNIFIED IDEOGRAPH-#2D14F
2D150 CJK UNIFIED IDEOGRAPH-#2D150
2D151 CJK UNIFIED IDEOGRAPH-#2D151
2D152 CJK UNIFIED IDEOGRAPH-#2D152
2D153 CJK UNIFIED IDEOGRAPH-#2D153
2D154 CJK UNIFIED IDEOGRAPH-#2D154
2D155 CJK UNIFIED IDEOGRAPH-#2D155
2D156 CJK UNIFIED IDEOGRAPH-#2D156
2D157 CJK UNIFIED IDEOGRAPH-#2D157
2D158 CJK UNIFIED IDEOGRAPH-#2D158
2D159 CJK UNIFIED IDEOGRAPH-#2D159
2D15A CJK UNIFIED IDEOGRAPH-#2D15A
2D15B CJK UNIFIED IDEOGRAPH-#2D15B
2D15C CJK UNIFIED IDEOGRAPH-#2D15C
2D15D CJK UNIFIED IDEOGRAPH-#2D15D
2D15E CJK UNIFIED IDEOGRAPH-#2D15E
2D15F CJK UNIFIED IDEOGRAPH-#2D15F
2D160 CJK UNIFIED IDEOGRAPH-#2D160
2D161 CJK UNIFIED IDEOGRAPH-#2D161
2D162 CJK UNIFIED IDEOGRAPH-#2D162
2D163 CJK UNIFIED IDEOGRAPH-#2D163
2D164 CJK UNIFIED IDEOGRAPH-#2D164
2D165 CJK UNIFIED IDEOGRAPH-#2D165
2D166 CJK UNIFIED IDEOGRAPH-#2D166
2D167 CJK UNIFIED IDEOGRAPH-#2D167
2D168 CJK UNIFIED IDEOGRAPH-#2D168
2D169 CJK UNIFIED IDEOGRAPH-#2D169
2D16A CJK UNIFIED IDEOGRAPH-#2D16A
2D16B CJK UNIFIED IDEOGRAPH-#2D16B
2D16C CJK UNIFIED IDEOGRAPH-#2D16C
2D16D CJK UNIFIED IDEOGRAPH-#2D16D
2D16E CJK UNIFIED IDEOGRAPH-#2D16E
2D16F CJK UNIFIED IDEOGRAPH-#2D16F
2D170 CJK UNIFIED IDEOGRAPH-#2D170
2D171 CJK UNIFIED IDEOGRAPH-#2D171
2D172 CJK UNIFIED IDEOGRAPH-#2D172
2D173 CJK UNIFIED IDEOGRAPH-#2D173
2D174 CJK UNIFIED IDEOGRAPH-#2D174
2D175 CJK UNIFIED IDEOGRAPH-#2D175
2D176 CJK UNIFIED IDEOGRAPH-#2D176
2D177 CJK UNIFIED IDEOGRAPH-#2D177
2D178 CJK UNIFIED IDEOGRAPH-#2D178
2D179 CJK UNIFIED IDEOGRAPH-#2D179
2D17A CJK UNIFIED IDEOGRAPH-#2D17A
2D17B CJK UNIFIED IDEOGRAPH-#2D17B
2D17C CJK UNIFIED IDEOGRAPH-#2D17C
2D17D CJK UNIFIED IDEOGRAPH-#2D17D
2D17E CJK UNIFIED IDEOGRAPH-#2D17E
2D17F CJK UNIFIED IDEOGRAPH-#2D17F
2D180 CJK UNIFIED IDEOGRAPH-#2D180
2D181 CJK UNIFIED IDEOGRAPH-#2D181
2D182 CJK UNIFIED IDEOGRAPH-#2D182
2D183 CJK UNIFIED IDEOGRAPH-#2D183
2D184 CJK UNIFIED IDEOGRAPH-#2D184
2D185 CJK UNIFIED IDEOGRAPH-#2D185
2D186 CJK UNIFIED IDEOGRAPH-#2D186
2D187 CJK UNIFIED IDEOGRAPH-#2D187
2D188 CJK UNIFIED IDEOGRAPH-#2D188
2D189 CJK UNIFIED IDEOGRAPH-#2D189
2D18A CJK UNIFIED IDEOGRAPH-#2D18A
2D18B CJK UNIFIED IDEOGRAPH-#2D18B
2D18C CJK UNIFIED IDEOGRAPH-#2D18C
2D18D CJK UNIFIED IDEOGRAPH-#2D18D
2D18E CJK UNIFIED IDEOGRAPH-#2D18E
2D18F CJK UNIFIED IDEOGRAPH-#2D18F
2D190 CJK UNIFIED IDEOGRAPH-#2D190
2D191 CJK UNIFIED IDEOGRAPH-#2D191
2D192 CJK UNIFIED IDEOGRAPH-#2D192
2D193 CJK UNIFIED IDEOGRAPH-#2D193
2D194 CJK UNIFIED IDEOGRAPH-#2D194
2D195 CJK UNIFIED IDEOGRAPH-#2D195
2D196 CJK UNIFIED IDEOGRAPH-#2D196
2D197 CJK UNIFIED IDEOGRAPH-#2D197
2D198 CJK UNIFIED IDEOGRAPH-#2D198
2D199 CJK UNIFIED IDEOGRAPH-#2D199
2D19A CJK UNIFIED IDEOGRAPH-#2D19A
2D19B CJK UNIFIED IDEOGRAPH-#2D19B
2D19C CJK UNIFIED IDEOGRAPH-#2D19C
2D19D CJK UNIFIED IDEOGRAPH-#2D19D
2D19E CJK UNIFIED IDEOGRAPH-#2D19E
2D19F CJK UNIFIED IDEOGRAPH-#2D19F
2D1A0 CJK UNIFIED IDEOGRAPH-#2D1A0
2D1A1 CJK UNIFIED IDEOGRAPH-#2D1A1
2D1A2 CJK UNIFIED IDEOGRAPH-#2D1A2
2D1A3 CJK UNIFIED IDEOGRAPH-#2D1A3
2D1A4 CJK UNIFIED IDEOGRAPH-#2D1A4
2D1A5 CJK UNIFIED IDEOGRAPH-#2D1A5
2D1A6 CJK UNIFIED IDEOGRAPH-#2D1A6
2D1A7 CJK UNIFIED IDEOGRAPH-#2D1A7
2D1A8 CJK UNIFIED IDEOGRAPH-#2D1A8
2D1A9 CJK UNIFIED IDEOGRAPH-#2D1A9
2D1AA CJK UNIFIED IDEOGRAPH-#2D1AA
2D1AB CJK UNIFIED IDEOGRAPH-#2D1AB
2D1AC CJK UNIFIED IDEOGRAPH-#2D1AC
2D1AD CJK UNIFIED IDEOGRAPH-#2D1AD
2D1AE CJK UNIFIED IDEOGRAPH-#2D1AE
2D1AF CJK UNIFIED IDEOGRAPH-#2D1AF
2D1B0 CJK UNIFIED IDEOGRAPH-#2D1B0
2D1B1 CJK UNIFIED IDEOGRAPH-#2D1B1
2D1B2 CJK UNIFIED IDEOGRAPH-#2D1B2
2D1B3 CJK UNIFIED IDEOGRAPH-#2D1B3
2D1B4 CJK UNIFIED IDEOGRAPH-#2D1B4
2D1B5 CJK UNIFIED IDEOGRAPH-#2D1B5
2D1B6 CJK UNIFIED IDEOGRAPH-#2D1B6
2D1B7 CJK UNIFIED IDEOGRAPH-#2D1B7
2D1B8 CJK UNIFIED IDEOGRAPH-#2D1B8
2D1B9 CJK UNIFIED IDEOGRAPH-#2D1B9
2D1BA CJK UNIFIED IDEOGRAPH-#2D1BA
2D1BB CJK UNIFIED IDEOGRAPH-#2D1BB
2D1BC CJK UNIFIED IDEOGRAPH-#2D1BC
2D1BD CJK UNIFIED IDEOGRAPH-#2D1BD
2D1BE CJK UNIFIED IDEOGRAPH-#2D1BE
2D1BF CJK UNIFIED IDEOGRAPH-#2D1BF
2D1C0 CJK UNIFIED IDEOGRAPH-#2D1C0
2D1C1 CJK UNIFIED IDEOGRAPH-#2D1C1
2D1C2 CJK UNIFIED IDEOGRAPH-#2D1C2
2D1C3 CJK UNIFIED IDEOGRAPH-#2D1C3
2D1C4 CJK UNIFIED IDEOGRAPH-#2D1C4
2D1C5 CJK UNIFIED IDEOGRAPH-#2D1C5
2D1C6 CJK UNIFIED IDEOGRAPH-#2D1C6
2D1C7 CJK UNIFIED IDEOGRAPH-#2D1C7
2D1C8 CJK UNIFIED IDEOGRAPH-#2D1C8
2D1C9 CJK UNIFIED IDEOGRAPH-#2D1C9
2D1CA CJK UNIFIED IDEOGRAPH-#2D1CA
2D1CB CJK UNIFIED IDEOGRAPH-#2D1CB
2D1CC CJK UNIFIED IDEOGRAPH-#2D1CC
2D1CD CJK UNIFIED IDEOGRAPH-#2D1CD
2D1CE CJK UNIFIED IDEOGRAPH-#2D1CE
2D1CF CJK UNIFIED IDEOGRAPH-#2D1CF
2D1D0 CJK UNIFIED IDEOGRAPH-#2D1D0
2D1D1 CJK UNIFIED IDEOGRAPH-#2D1D1
2D1D2 CJK UNIFIED IDEOGRAPH-#2D1D2
2D1D3 CJK UNIFIED IDEOGRAPH-#2D1D3
2D1D4 CJK UNIFIED IDEOGRAPH-#2D1D4
2D1D5 CJK UNIFIED IDEOGRAPH-#2D1D5
2D1D6 CJK UNIFIED IDEOGRAPH-#2D1D6
2D1D7 CJK UNIFIED IDEOGRAPH-#2D1D7
2D1D8 CJK UNIFIED IDEOGRAPH-#2D1D8
2D1D9 CJK UNIFIED IDEOGRAPH-#2D1D9
2D1DA CJK UNIFIED IDEOGRAPH-#2D1DA
2D1DB CJK UNIFIED IDEOGRAPH-#2D1DB
2D1DC CJK UNIFIED IDEOGRAPH-#2D1DC
2D1DD CJK UNIFIED IDEOGRAPH-#2D1DD
2D1DE CJK UNIFIED IDEOGRAPH-#2D1DE
2D1DF CJK UNIFIED IDEOGRAPH-#2D1DF
2D1E0 CJK UNIFIED IDEOGRAPH-#2D1E0
2D1E1 CJK UNIFIED IDEOGRAPH-#2D1E1
2D1E2 CJK UNIFIED IDEOGRAPH-#2D1E2
2D1E3 CJK UNIFIED IDEOGRAPH-#2D1E3
2D1E4 CJK UNIFIED IDEOGRAPH-#2D1E4
2D1E5 CJK UNIFIED IDEOGRAPH-#2D1E5
2D1E6 CJK UNIFIED IDEOGRAPH-#2D1E6
2D1E7 CJK UNIFIED IDEOGRAPH-#2D1E7
2D1E8 CJK UNIFIED IDEOGRAPH-#2D1E8
2D1E9 CJK UNIFIED IDEOGRAPH-#2D1E9
2D1EA CJK UNIFIED IDEOGRAPH-#2D1EA
2D1EB CJK UNIFIED IDEOGRAPH-#2D1EB
2D1EC CJK UNIFIED IDEOGRAPH-#2D1EC
2D1ED CJK UNIFIED IDEOGRAPH-#2D1ED
2D1EE CJK UNIFIED IDEOGRAPH-#2D1EE
2D1EF CJK UNIFIED IDEOGRAPH-#2D1EF
2D1F0 CJK UNIFIED IDEOGRAPH-#2D1F0
2D1F1 CJK UNIFIED IDEOGRAPH-#2D1F1
2D1F2 CJK UNIFIED IDEOGRAPH-#2D1F2
2D1F3 CJK UNIFIED IDEOGRAPH-#2D1F3
2D1F4 CJK UNIFIED IDEOGRAPH-#2D1F4
2D1F5 CJK UNIFIED IDEOGRAPH-#2D1F5
2D1F6 CJK UNIFIED IDEOGRAPH-#2D1F6
2D1F7 CJK UNIFIED IDEOGRAPH-#2D1F7
2D1F8 CJK UNIFIED IDEOGRAPH-#2D1F8
2D1F9 CJK UNIFIED IDEOGRAPH-#2D1F9
2D1FA CJK UNIFIED IDEOGRAPH-#2D1FA
2D1FB CJK UNIFIED IDEOGRAPH-#2D1FB
2D1FC CJK UNIFIED IDEOGRAPH-#2D1FC
2D1FD CJK UNIFIED IDEOGRAPH-#2D1FD
2D1FE CJK UNIFIED IDEOGRAPH-#2D1FE
2D1FF CJK UNIFIED IDEOGRAPH-#2D1FF
2D200 CJK UNIFIED IDEOGRAPH-#2D200
2D201 CJK UNIFIED IDEOGRAPH-#2D201
2D202 CJK UNIFIED IDEOGRAPH-#2D202
2D203 CJK UNIFIED IDEOGRAPH-#2D203
2D204 CJK UNIFIED IDEOGRAPH-#2D204
2D205 CJK UNIFIED IDEOGRAPH-#2D205
2D206 CJK UNIFIED IDEOGRAPH-#2D206
2D207 CJK UNIFIED IDEOGRAPH-#2D207
2D208 CJK UNIFIED IDEOGRAPH-#2D208
2D209 CJK UNIFIED IDEOGRAPH-#2D209
2D20A CJK UNIFIED IDEOGRAPH-#2D20A
2D20B CJK UNIFIED IDEOGRAPH-#2D20B
2D20C CJK UNIFIED IDEOGRAPH-#2D20C
2D20D CJK UNIFIED IDEOGRAPH-#2D20D
2D20E CJK UNIFIED IDEOGRAPH-#2D20E
2D20F CJK UNIFIED IDEOGRAPH-#2D20F
2D210 CJK UNIFIED IDEOGRAPH-#2D210
2D211 CJK UNIFIED IDEOGRAPH-#2D211
2D212 CJK UNIFIED IDEOGRAPH-#2D212
2D213 CJK UNIFIED IDEOGRAPH-#2D213
2D214 CJK UNIFIED IDEOGRAPH-#2D214
2D215 CJK UNIFIED IDEOGRAPH-#2D215
2D216 CJK UNIFIED IDEOGRAPH-#2D216
2D217 CJK UNIFIED IDEOGRAPH-#2D217
2D218 CJK UNIFIED IDEOGRAPH-#2D218
2D219 CJK UNIFIED IDEOGRAPH-#2D219
2D21A CJK UNIFIED IDEOGRAPH-#2D21A
2D21B CJK UNIFIED IDEOGRAPH-#2D21B
2D21C CJK UNIFIED IDEOGRAPH-#2D21C
2D21D CJK UNIFIED IDEOGRAPH-#2D21D
2D21E CJK UNIFIED IDEOGRAPH-#2D21E
2D21F CJK UNIFIED IDEOGRAPH-#2D21F
2D220 CJK UNIFIED IDEOGRAPH-#2D220
2D221 CJK UNIFIED IDEOGRAPH-#2D221
2D222 CJK UNIFIED IDEOGRAPH-#2D222
2D223 CJK UNIFIED IDEOGRAPH-#2D223
2D224 CJK UNIFIED IDEOGRAPH-#2D224
2D225 CJK UNIFIED IDEOGRAPH-#2D225
2D226 CJK UNIFIED IDEOGRAPH-#2D226
2D227 CJK UNIFIED IDEOGRAPH-#2D227
2D228 CJK UNIFIED IDEOGRAPH-#2D228
2D229 CJK UNIFIED IDEOGRAPH-#2D229
2D22A CJK UNIFIED IDEOGRAPH-#2D22A
2D22B CJK UNIFIED IDEOGRAPH-#2D22B
2D22C CJK UNIFIED IDEOGRAPH-#2D22C
2D22D CJK UNIFIED IDEOGRAPH-#2D22D
2D22E CJK UNIFIED IDEOGRAPH-#2D22E
2D22F CJK UNIFIED IDEOGRAPH-#2D22F
2D230 CJK UNIFIED IDEOGRAPH-#2D230
2D231 CJK UNIFIED IDEOGRAPH-#2D231
2D232 CJK UNIFIED IDEOGRAPH-#2D232
2D233 CJK UNIFIED IDEOGRAPH-#2D233
2D234 CJK UNIFIED IDEOGRAPH-#2D234
2D235 CJK UNIFIED IDEOGRAPH-#2D235
2D236 CJK UNIFIED IDEOGRAPH-#2D236
2D237 CJK UNIFIED IDEOGRAPH-#2D237
2D238 CJK UNIFIED IDEOGRAPH-#2D238
2D239 CJK UNIFIED IDEOGRAPH-#2D239
2D23A CJK UNIFIED IDEOGRAPH-#2D23A
2D23B CJK UNIFIED IDEOGRAPH-#2D23B
2D23C CJK UNIFIED IDEOGRAPH-#2D23C
2D23D CJK UNIFIED IDEOGRAPH-#2D23D
2D23E CJK UNIFIED IDEOGRAPH-#2D23E
2D23F CJK UNIFIED IDEOGRAPH-#2D23F
2D240 CJK UNIFIED IDEOGRAPH-#2D240
2D241 CJK UNIFIED IDEOGRAPH-#2D241
2D242 CJK UNIFIED IDEOGRAPH-#2D242
2D243 CJK UNIFIED IDEOGRAPH-#2D243
2D244 CJK UNIFIED IDEOGRAPH-#2D244
2D245 CJK UNIFIED IDEOGRAPH-#2D245
2D246 CJK UNIFIED IDEOGRAPH-#2D246
2D247 CJK UNIFIED IDEOGRAPH-#2D247
2D248 CJK UNIFIED IDEOGRAPH-#2D248
2D249 CJK UNIFIED IDEOGRAPH-#2D249
2D24A CJK UNIFIED IDEOGRAPH-#2D24A
2D24B CJK UNIFIED IDEOGRAPH-#2D24B
2D24C CJK UNIFIED IDEOGRAPH-#2D24C
2D24D CJK UNIFIED IDEOGRAPH-#2D24D
2D24E CJK UNIFIED IDEOGRAPH-#2D24E
2D24F CJK UNIFIED IDEOGRAPH-#2D24F
2D250 CJK UNIFIED IDEOGRAPH-#2D250
2D251 CJK UNIFIED IDEOGRAPH-#2D251
2D252 CJK UNIFIED IDEOGRAPH-#2D252
2D253 CJK UNIFIED IDEOGRAPH-#2D253
2D254 CJK UNIFIED IDEOGRAPH-#2D254
2D255 CJK UNIFIED IDEOGRAPH-#2D255
2D256 CJK UNIFIED IDEOGRAPH-#2D256
2D257 CJK UNIFIED IDEOGRAPH-#2D257
2D258 CJK UNIFIED IDEOGRAPH-#2D258
2D259 CJK UNIFIED IDEOGRAPH-#2D259
2D25A CJK UNIFIED IDEOGRAPH-#2D25A
2D25B CJK UNIFIED IDEOGRAPH-#2D25B
2D25C CJK UNIFIED IDEOGRAPH-#2D25C
2D25D CJK UNIFIED IDEOGRAPH-#2D25D
2D25E CJK UNIFIED IDEOGRAPH-#2D25E
2D25F CJK UNIFIED IDEOGRAPH-#2D25F
2D260 CJK UNIFIED IDEOGRAPH-#2D260
2D261 CJK UNIFIED IDEOGRAPH-#2D261
2D262 CJK UNIFIED IDEOGRAPH-#2D262
2D263 CJK UNIFIED IDEOGRAPH-#2D263
2D264 CJK UNIFIED IDEOGRAPH-#2D264
2D265 CJK UNIFIED IDEOGRAPH-#2D265
2D266 CJK UNIFIED IDEOGRAPH-#2D266
2D267 CJK UNIFIED IDEOGRAPH-#2D267
2D268 CJK UNIFIED IDEOGRAPH-#2D268
2D269 CJK UNIFIED IDEOGRAPH-#2D269
2D26A CJK UNIFIED IDEOGRAPH-#2D26A
2D26B CJK UNIFIED IDEOGRAPH-#2D26B
2D26C CJK UNIFIED IDEOGRAPH-#2D26C
2D26D CJK UNIFIED IDEOGRAPH-#2D26D
2D26E CJK UNIFIED IDEOGRAPH-#2D26E
2D26F CJK UNIFIED IDEOGRAPH-#2D26F
2D270 CJK UNIFIED IDEOGRAPH-#2D270
2D271 CJK UNIFIED IDEOGRAPH-#2D271
2D272 CJK UNIFIED IDEOGRAPH-#2D272
2D273 CJK UNIFIED IDEOGRAPH-#2D273
2D274 CJK UNIFIED IDEOGRAPH-#2D274
2D275 CJK UNIFIED IDEOGRAPH-#2D275
2D276 CJK UNIFIED IDEOGRAPH-#2D276
2D277 CJK UNIFIED IDEOGRAPH-#2D277
2D278 CJK UNIFIED IDEOGRAPH-#2D278
2D279 CJK UNIFIED IDEOGRAPH-#2D279
2D27A CJK UNIFIED IDEOGRAPH-#2D27A
2D27B CJK UNIFIED IDEOGRAPH-#2D27B
2D27C CJK UNIFIED IDEOGRAPH-#2D27C
2D27D CJK UNIFIED IDEOGRAPH-#2D27D
2D27E CJK UNIFIED IDEOGRAPH-#2D27E
2D27F CJK UNIFIED IDEOGRAPH-#2D27F
2D280 CJK UNIFIED IDEOGRAPH-#2D280
2D281 CJK UNIFIED IDEOGRAPH-#2D281
2D282 CJK UNIFIED IDEOGRAPH-#2D282
2D283 CJK UNIFIED IDEOGRAPH-#2D283
2D284 CJK UNIFIED IDEOGRAPH-#2D284
2D285 CJK UNIFIED IDEOGRAPH-#2D285
2D286 CJK UNIFIED IDEOGRAPH-#2D286
2D287 CJK UNIFIED IDEOGRAPH-#2D287
2D288 CJK UNIFIED IDEOGRAPH-#2D288
2D289 CJK UNIFIED IDEOGRAPH-#2D289
2D28A CJK UNIFIED IDEOGRAPH-#2D28A
2D28B CJK UNIFIED IDEOGRAPH-#2D28B
2D28C CJK UNIFIED IDEOGRAPH-#2D28C
2D28D CJK UNIFIED IDEOGRAPH-#2D28D
2D28E CJK UNIFIED IDEOGRAPH-#2D28E
2D28F CJK UNIFIED IDEOGRAPH-#2D28F
2D290 CJK UNIFIED IDEOGRAPH-#2D290
2D291 CJK UNIFIED IDEOGRAPH-#2D291
2D292 CJK UNIFIED IDEOGRAPH-#2D292
2D293 CJK UNIFIED IDEOGRAPH-#2D293
2D294 CJK UNIFIED IDEOGRAPH-#2D294
2D295 CJK UNIFIED IDEOGRAPH-#2D295
2D296 CJK UNIFIED IDEOGRAPH-#2D296
2D297 CJK UNIFIED IDEOGRAPH-#2D297
2D298 CJK UNIFIED IDEOGRAPH-#2D298
2D299 CJK UNIFIED IDEOGRAPH-#2D299
2D29A CJK UNIFIED IDEOGRAPH-#2D29A
2D29B CJK UNIFIED IDEOGRAPH-#2D29B
2D29C CJK UNIFIED IDEOGRAPH-#2D29C
2D29D CJK UNIFIED IDEOGRAPH-#2D29D
2D29E CJK UNIFIED IDEOGRAPH-#2D29E
2D29F CJK UNIFIED IDEOGRAPH-#2D29F
2D2A0 CJK UNIFIED IDEOGRAPH-#2D2A0
2D2A1 CJK UNIFIED IDEOGRAPH-#2D2A1
2D2A2 CJK UNIFIED IDEOGRAPH-#2D2A2
2D2A3 CJK UNIFIED IDEOGRAPH-#2D2A3
2D2A4 CJK UNIFIED IDEOGRAPH-#2D2A4
2D2A5 CJK UNIFIED IDEOGRAPH-#2D2A5
2D2A6 CJK UNIFIED IDEOGRAPH-#2D2A6
2D2A7 CJK UNIFIED IDEOGRAPH-#2D2A7
2D2A8 CJK UNIFIED IDEOGRAPH-#2D2A8
2D2A9 CJK UNIFIED IDEOGRAPH-#2D2A9
2D2AA CJK UNIFIED IDEOGRAPH-#2D2AA
2D2AB CJK UNIFIED IDEOGRAPH-#2D2AB
2D2AC CJK UNIFIED IDEOGRAPH-#2D2AC
2D2AD CJK UNIFIED IDEOGRAPH-#2D2AD
2D2AE CJK UNIFIED IDEOGRAPH-#2D2AE
2D2AF CJK UNIFIED IDEOGRAPH-#2D2AF
2D2B0 CJK UNIFIED IDEOGRAPH-#2D2B0
2D2B1 CJK UNIFIED IDEOGRAPH-#2D2B1
2D2B2 CJK UNIFIED IDEOGRAPH-#2D2B2
2D2B3 CJK UNIFIED IDEOGRAPH-#2D2B3
2D2B4 CJK UNIFIED IDEOGRAPH-#2D2B4
2D2B5 CJK UNIFIED IDEOGRAPH-#2D2B5
2D2B6 CJK UNIFIED IDEOGRAPH-#2D2B6
2D2B7 CJK UNIFIED IDEOGRAPH-#2D2B7
2D2B8 CJK UNIFIED IDEOGRAPH-#2D2B8
2D2B9 CJK UNIFIED IDEOGRAPH-#2D2B9
2D2BA CJK UNIFIED IDEOGRAPH-#2D2BA
2D2BB CJK UNIFIED IDEOGRAPH-#2D2BB
2D2BC CJK UNIFIED IDEOGRAPH-#2D2BC
2D2BD CJK UNIFIED IDEOGRAPH-#2D2BD
2D2BE CJK UNIFIED IDEOGRAPH-#2D2BE
2D2BF CJK UNIFIED IDEOGRAPH-#2D2BF
2D2C0 CJK UNIFIED IDEOGRAPH-#2D2C0
2D2C1 CJK UNIFIED IDEOGRAPH-#2D2C1
2D2C2 CJK UNIFIED IDEOGRAPH-#2D2C2
2D2C3 CJK UNIFIED IDEOGRAPH-#2D2C3
2D2C4 CJK UNIFIED IDEOGRAPH-#2D2C4
2D2C5 CJK UNIFIED IDEOGRAPH-#2D2C5
2D2C6 CJK UNIFIED IDEOGRAPH-#2D2C6
2D2C7 CJK UNIFIED IDEOGRAPH-#2D2C7
2D2C8 CJK UNIFIED IDEOGRAPH-#2D2C8
2D2C9 CJK UNIFIED IDEOGRAPH-#2D2C9
2D2CA CJK UNIFIED IDEOGRAPH-#2D2CA
2D2CB CJK UNIFIED IDEOGRAPH-#2D2CB
2D2CC CJK UNIFIED IDEOGRAPH-#2D2CC
2D2CD CJK UNIFIED IDEOGRAPH-#2D2CD
2D2CE CJK UNIFIED IDEOGRAPH-#2D2CE
2D2CF CJK UNIFIED IDEOGRAPH-#2D2CF
2D2D0 CJK UNIFIED IDEOGRAPH-#2D2D0
2D2D1 CJK UNIFIED IDEOGRAPH-#2D2D1
2D2D2 CJK UNIFIED IDEOGRAPH-#2D2D2
2D2D3 CJK UNIFIED IDEOGRAPH-#2D2D3
2D2D4 CJK UNIFIED IDEOGRAPH-#2D2D4
2D2D5 CJK UNIFIED IDEOGRAPH-#2D2D5
2D2D6 CJK UNIFIED IDEOGRAPH-#2D2D6
2D2D7 CJK UNIFIED IDEOGRAPH-#2D2D7
2D2D8 CJK UNIFIED IDEOGRAPH-#2D2D8
2D2D9 CJK UNIFIED IDEOGRAPH-#2D2D9
2D2DA CJK UNIFIED IDEOGRAPH-#2D2DA
2D2DB CJK UNIFIED IDEOGRAPH-#2D2DB
2D2DC CJK UNIFIED IDEOGRAPH-#2D2DC
2D2DD CJK UNIFIED IDEOGRAPH-#2D2DD
2D2DE CJK UNIFIED IDEOGRAPH-#2D2DE
2D2DF CJK UNIFIED IDEOGRAPH-#2D2DF
2D2E0 CJK UNIFIED IDEOGRAPH-#2D2E0
2D2E1 CJK UNIFIED IDEOGRAPH-#2D2E1
2D2E2 CJK UNIFIED IDEOGRAPH-#2D2E2
2D2E3 CJK UNIFIED IDEOGRAPH-#2D2E3
2D2E4 CJK UNIFIED IDEOGRAPH-#2D2E4
2D2E5 CJK UNIFIED IDEOGRAPH-#2D2E5
2D2E6 CJK UNIFIED IDEOGRAPH-#2D2E6
2D2E7 CJK UNIFIED IDEOGRAPH-#2D2E7
2D2E8 CJK UNIFIED IDEOGRAPH-#2D2E8
2D2E9 CJK UNIFIED IDEOGRAPH-#2D2E9
2D2EA CJK UNIFIED IDEOGRAPH-#2D2EA
2D2EB CJK UNIFIED IDEOGRAPH-#2D2EB
2D2EC CJK UNIFIED IDEOGRAPH-#2D2EC
2D2ED CJK UNIFIED IDEOGRAPH-#2D2ED
2D2EE CJK UNIFIED IDEOGRAPH-#2D2EE
2D2EF CJK UNIFIED IDEOGRAPH-#2D2EF
2D2F0 CJK UNIFIED IDEOGRAPH-#2D2F0
2D2F1 CJK UNIFIED IDEOGRAPH-#2D2F1
2D2F2 CJK UNIFIED IDEOGRAPH-#2D2F2
2D2F3 CJK UNIFIED IDEOGRAPH-#2D2F3
2D2F4 CJK UNIFIED IDEOGRAPH-#2D2F4
2D2F5 CJK UNIFIED IDEOGRAPH-#2D2F5
2D2F6 CJK UNIFIED IDEOGRAPH-#2D2F6
2D2F7 CJK UNIFIED IDEOGRAPH-#2D2F7
2D2F8 CJK UNIFIED IDEOGRAPH-#2D2F8
2D2F9 CJK UNIFIED IDEOGRAPH-#2D2F9
2D2FA CJK UNIFIED IDEOGRAPH-#2D2FA
2D2FB CJK UNIFIED IDEOGRAPH-#2D2FB
2D2FC CJK UNIFIED IDEOGRAPH-#2D2FC
2D2FD CJK UNIFIED IDEOGRAPH-#2D2FD
2D2FE CJK UNIFIED IDEOGRAPH-#2D2FE
2D2FF CJK UNIFIED IDEOGRAPH-#2D2FF
2D300 CJK UNIFIED IDEOGRAPH-#2D300
2D301 CJK UNIFIED IDEOGRAPH-#2D301
2D302 CJK UNIFIED IDEOGRAPH-#2D302
2D303 CJK UNIFIED IDEOGRAPH-#2D303
2D304 CJK UNIFIED IDEOGRAPH-#2D304
2D305 CJK UNIFIED IDEOGRAPH-#2D305
2D306 CJK UNIFIED IDEOGRAPH-#2D306
2D307 CJK UNIFIED IDEOGRAPH-#2D307
2D308 CJK UNIFIED IDEOGRAPH-#2D308
2D309 CJK UNIFIED IDEOGRAPH-#2D309
2D30A CJK UNIFIED IDEOGRAPH-#2D30A
2D30B CJK UNIFIED IDEOGRAPH-#2D30B
2D30C CJK UNIFIED IDEOGRAPH-#2D30C
2D30D CJK UNIFIED IDEOGRAPH-#2D30D
2D30E CJK UNIFIED IDEOGRAPH-#2D30E
2D30F CJK UNIFIED IDEOGRAPH-#2D30F
2D310 CJK UNIFIED IDEOGRAPH-#2D310
2D311 CJK UNIFIED IDEOGRAPH-#2D311
2D312 CJK UNIFIED IDEOGRAPH-#2D312
2D313 CJK UNIFIED IDEOGRAPH-#2D313
2D314 CJK UNIFIED IDEOGRAPH-#2D314
2D315 CJK UNIFIED IDEOGRAPH-#2D315
2D316 CJK UNIFIED IDEOGRAPH-#2D316
2D317 CJK UNIFIED IDEOGRAPH-#2D317
2D318 CJK UNIFIED IDEOGRAPH-#2D318
2D319 CJK UNIFIED IDEOGRAPH-#2D319
2D31A CJK UNIFIED IDEOGRAPH-#2D31A
2D31B CJK UNIFIED IDEOGRAPH-#2D31B
2D31C CJK UNIFIED IDEOGRAPH-#2D31C
2D31D CJK UNIFIED IDEOGRAPH-#2D31D
2D31E CJK UNIFIED IDEOGRAPH-#2D31E
2D31F CJK UNIFIED IDEOGRAPH-#2D31F
2D320 CJK UNIFIED IDEOGRAPH-#2D320
2D321 CJK UNIFIED IDEOGRAPH-#2D321
2D322 CJK UNIFIED IDEOGRAPH-#2D322
2D323 CJK UNIFIED IDEOGRAPH-#2D323
2D324 CJK UNIFIED IDEOGRAPH-#2D324
2D325 CJK UNIFIED IDEOGRAPH-#2D325
2D326 CJK UNIFIED IDEOGRAPH-#2D326
2D327 CJK UNIFIED IDEOGRAPH-#2D327
2D328 CJK UNIFIED IDEOGRAPH-#2D328
2D329 CJK UNIFIED IDEOGRAPH-#2D329
2D32A CJK UNIFIED IDEOGRAPH-#2D32A
2D32B CJK UNIFIED IDEOGRAPH-#2D32B
2D32C CJK UNIFIED IDEOGRAPH-#2D32C
2D32D CJK UNIFIED IDEOGRAPH-#2D32D
2D32E CJK UNIFIED IDEOGRAPH-#2D32E
2D32F CJK UNIFIED IDEOGRAPH-#2D32F
2D330 CJK UNIFIED IDEOGRAPH-#2D330
2D331 CJK UNIFIED IDEOGRAPH-#2D331
2D332 CJK UNIFIED IDEOGRAPH-#2D332
2D333 CJK UNIFIED IDEOGRAPH-#2D333
2D334 CJK UNIFIED IDEOGRAPH-#2D334
2D335 CJK UNIFIED IDEOGRAPH-#2D335
2D336 CJK UNIFIED IDEOGRAPH-#2D336
2D337 CJK UNIFIED IDEOGRAPH-#2D337
2D338 CJK UNIFIED IDEOGRAPH-#2D338
2D339 CJK UNIFIED IDEOGRAPH-#2D339
2D33A CJK UNIFIED IDEOGRAPH-#2D33A
2D33B CJK UNIFIED IDEOGRAPH-#2D33B
2D33C CJK UNIFIED IDEOGRAPH-#2D33C
2D33D CJK UNIFIED IDEOGRAPH-#2D33D
2D33E CJK UNIFIED IDEOGRAPH-#2D33E
2D33F CJK UNIFIED IDEOGRAPH-#2D33F
2D340 CJK UNIFIED IDEOGRAPH-#2D340
2D341 CJK UNIFIED IDEOGRAPH-#2D341
2D342 CJK UNIFIED IDEOGRAPH-#2D342
2D343 CJK UNIFIED IDEOGRAPH-#2D343
2D344 CJK UNIFIED IDEOGRAPH-#2D344
2D345 CJK UNIFIED IDEOGRAPH-#2D345
2D346 CJK UNIFIED IDEOGRAPH-#2D346
2D347 CJK UNIFIED IDEOGRAPH-#2D347
2D348 CJK UNIFIED IDEOGRAPH-#2D348
2D349 CJK UNIFIED IDEOGRAPH-#2D349
2D34A CJK UNIFIED IDEOGRAPH-#2D34A
2D34B CJK UNIFIED IDEOGRAPH-#2D34B
2D34C CJK UNIFIED IDEOGRAPH-#2D34C
2D34D CJK UNIFIED IDEOGRAPH-#2D34D
2D34E CJK UNIFIED IDEOGRAPH-#2D34E
2D34F CJK UNIFIED IDEOGRAPH-#2D34F
2D350 CJK UNIFIED IDEOGRAPH-#2D350
2D351 CJK UNIFIED IDEOGRAPH-#2D351
2D352 CJK UNIFIED IDEOGRAPH-#2D352
2D353 CJK UNIFIED IDEOGRAPH-#2D353
2D354 CJK UNIFIED IDEOGRAPH-#2D354
2D355 CJK UNIFIED IDEOGRAPH-#2D355
2D356 CJK UNIFIED IDEOGRAPH-#2D356
2D357 CJK UNIFIED IDEOGRAPH-#2D357
2D358 CJK UNIFIED IDEOGRAPH-#2D358
2D359 CJK UNIFIED IDEOGRAPH-#2D359
2D35A CJK UNIFIED IDEOGRAPH-#2D35A
2D35B CJK UNIFIED IDEOGRAPH-#2D35B
2D35C CJK UNIFIED IDEOGRAPH-#2D35C
2D35D CJK UNIFIED IDEOGRAPH-#2D35D
2D35E CJK UNIFIED IDEOGRAPH-#2D35E
2D35F CJK UNIFIED IDEOGRAPH-#2D35F
2D360 CJK UNIFIED IDEOGRAPH-#2D360
2D361 CJK UNIFIED IDEOGRAPH-#2D361
2D362 CJK UNIFIED IDEOGRAPH-#2D362
2D363 CJK UNIFIED IDEOGRAPH-#2D363
2D364 CJK UNIFIED IDEOGRAPH-#2D364
2D365 CJK UNIFIED IDEOGRAPH-#2D365
2D366 CJK UNIFIED IDEOGRAPH-#2D366
2D367 CJK UNIFIED IDEOGRAPH-#2D367
2D368 CJK UNIFIED IDEOGRAPH-#2D368
2D369 CJK UNIFIED IDEOGRAPH-#2D369
2D36A CJK UNIFIED IDEOGRAPH-#2D36A
2D36B CJK UNIFIED IDEOGRAPH-#2D36B
2D36C CJK UNIFIED IDEOGRAPH-#2D36C
2D36D CJK UNIFIED IDEOGRAPH-#2D36D
2D36E CJK UNIFIED IDEOGRAPH-#2D36E
2D36F CJK UNIFIED IDEOGRAPH-#2D36F
2D370 CJK UNIFIED IDEOGRAPH-#2D370
2D371 CJK UNIFIED IDEOGRAPH-#2D371
2D372 CJK UNIFIED IDEOGRAPH-#2D372
2D373 CJK UNIFIED IDEOGRAPH-#2D373
2D374 CJK UNIFIED IDEOGRAPH-#2D374
2D375 CJK UNIFIED IDEOGRAPH-#2D375
2D376 CJK UNIFIED IDEOGRAPH-#2D376
2D377 CJK UNIFIED IDEOGRAPH-#2D377
2D378 CJK UNIFIED IDEOGRAPH-#2D378
2D379 CJK UNIFIED IDEOGRAPH-#2D379
2D37A CJK UNIFIED IDEOGRAPH-#2D37A
2D37B CJK UNIFIED IDEOGRAPH-#2D37B
2D37C CJK UNIFIED IDEOGRAPH-#2D37C
2D37D CJK UNIFIED IDEOGRAPH-#2D37D
2D37E CJK UNIFIED IDEOGRAPH-#2D37E
2D37F CJK UNIFIED IDEOGRAPH-#2D37F
2D380 CJK UNIFIED IDEOGRAPH-#2D380
2D381 CJK UNIFIED IDEOGRAPH-#2D381
2D382 CJK UNIFIED IDEOGRAPH-#2D382
2D383 CJK UNIFIED IDEOGRAPH-#2D383
2D384 CJK UNIFIED IDEOGRAPH-#2D384
2D385 CJK UNIFIED IDEOGRAPH-#2D385
2D386 CJK UNIFIED IDEOGRAPH-#2D386
2D387 CJK UNIFIED IDEOGRAPH-#2D387
2D388 CJK UNIFIED IDEOGRAPH-#2D388
2D389 CJK UNIFIED IDEOGRAPH-#2D389
2D38A CJK UNIFIED IDEOGRAPH-#2D38A
2D38B CJK UNIFIED IDEOGRAPH-#2D38B
2D38C CJK UNIFIED IDEOGRAPH-#2D38C
2D38D CJK UNIFIED IDEOGRAPH-#2D38D
2D38E CJK UNIFIED IDEOGRAPH-#2D38E
2D38F CJK UNIFIED IDEOGRAPH-#2D38F
2D390 CJK UNIFIED IDEOGRAPH-#2D390
2D391 CJK UNIFIED IDEOGRAPH-#2D391
2D392 CJK UNIFIED IDEOGRAPH-#2D392
2D393 CJK UNIFIED IDEOGRAPH-#2D393
2D394 CJK UNIFIED IDEOGRAPH-#2D394
2D395 CJK UNIFIED IDEOGRAPH-#2D395
2D396 CJK UNIFIED IDEOGRAPH-#2D396
2D397 CJK UNIFIED IDEOGRAPH-#2D397
2D398 CJK UNIFIED IDEOGRAPH-#2D398
2D399 CJK UNIFIED IDEOGRAPH-#2D399
2D39A CJK UNIFIED IDEOGRAPH-#2D39A
2D39B CJK UNIFIED IDEOGRAPH-#2D39B
2D39C CJK UNIFIED IDEOGRAPH-#2D39C
2D39D CJK UNIFIED IDEOGRAPH-#2D39D
2D39E CJK UNIFIED IDEOGRAPH-#2D39E
2D39F CJK UNIFIED IDEOGRAPH-#2D39F
2D3A0 CJK UNIFIED IDEOGRAPH-#2D3A0
2D3A1 CJK UNIFIED IDEOGRAPH-#2D3A1
2D3A2 CJK UNIFIED IDEOGRAPH-#2D3A2
2D3A3 CJK UNIFIED IDEOGRAPH-#2D3A3
2D3A4 CJK UNIFIED IDEOGRAPH-#2D3A4
2D3A5 CJK UNIFIED IDEOGRAPH-#2D3A5
2D3A6 CJK UNIFIED IDEOGRAPH-#2D3A6
2D3A7 CJK UNIFIED IDEOGRAPH-#2D3A7
2D3A8 CJK UNIFIED IDEOGRAPH-#2D3A8
2D3A9 CJK UNIFIED IDEOGRAPH-#2D3A9
2D3AA CJK UNIFIED IDEOGRAPH-#2D3AA
2D3AB CJK UNIFIED IDEOGRAPH-#2D3AB
2D3AC CJK UNIFIED IDEOGRAPH-#2D3AC
2D3AD CJK UNIFIED IDEOGRAPH-#2D3AD
2D3AE CJK UNIFIED IDEOGRAPH-#2D3AE
2D3AF CJK UNIFIED IDEOGRAPH-#2D3AF
2D3B0 CJK UNIFIED IDEOGRAPH-#2D3B0
2D3B1 CJK UNIFIED IDEOGRAPH-#2D3B1
2D3B2 CJK UNIFIED IDEOGRAPH-#2D3B2
2D3B3 CJK UNIFIED IDEOGRAPH-#2D3B3
2D3B4 CJK UNIFIED IDEOGRAPH-#2D3B4
2D3B5 CJK UNIFIED IDEOGRAPH-#2D3B5
2D3B6 CJK UNIFIED IDEOGRAPH-#2D3B6
2D3B7 CJK UNIFIED IDEOGRAPH-#2D3B7
2D3B8 CJK UNIFIED IDEOGRAPH-#2D3B8
2D3B9 CJK UNIFIED IDEOGRAPH-#2D3B9
2D3BA CJK UNIFIED IDEOGRAPH-#2D3BA
2D3BB CJK UNIFIED IDEOGRAPH-#2D3BB
2D3BC CJK UNIFIED IDEOGRAPH-#2D3BC
2D3BD CJK UNIFIED IDEOGRAPH-#2D3BD
2D3BE CJK UNIFIED IDEOGRAPH-#2D3BE
2D3BF CJK UNIFIED IDEOGRAPH-#2D3BF
2D3C0 CJK UNIFIED IDEOGRAPH-#2D3C0
2D3C1 CJK UNIFIED IDEOGRAPH-#2D3C1
2D3C2 CJK UNIFIED IDEOGRAPH-#2D3C2
2D3C3 CJK UNIFIED IDEOGRAPH-#2D3C3
2D3C4 CJK UNIFIED IDEOGRAPH-#2D3C4
2D3C5 CJK UNIFIED IDEOGRAPH-#2D3C5
2D3C6 CJK UNIFIED IDEOGRAPH-#2D3C6
2D3C7 CJK UNIFIED IDEOGRAPH-#2D3C7
2D3C8 CJK UNIFIED IDEOGRAPH-#2D3C8
2D3C9 CJK UNIFIED IDEOGRAPH-#2D3C9
2D3CA CJK UNIFIED IDEOGRAPH-#2D3CA
2D3CB CJK UNIFIED IDEOGRAPH-#2D3CB
2D3CC CJK UNIFIED IDEOGRAPH-#2D3CC
2D3CD CJK UNIFIED IDEOGRAPH-#2D3CD
2D3CE CJK UNIFIED IDEOGRAPH-#2D3CE
2D3CF CJK UNIFIED IDEOGRAPH-#2D3CF
2D3D0 CJK UNIFIED IDEOGRAPH-#2D3D0
2D3D1 CJK UNIFIED IDEOGRAPH-#2D3D1
2D3D2 CJK UNIFIED IDEOGRAPH-#2D3D2
2D3D3 CJK UNIFIED IDEOGRAPH-#2D3D3
2D3D4 CJK UNIFIED IDEOGRAPH-#2D3D4
2D3D5 CJK UNIFIED IDEOGRAPH-#2D3D5
2D3D6 CJK UNIFIED IDEOGRAPH-#2D3D6
2D3D7 CJK UNIFIED IDEOGRAPH-#2D3D7
2D3D8 CJK UNIFIED IDEOGRAPH-#2D3D8
2D3D9 CJK UNIFIED IDEOGRAPH-#2D3D9
2D3DA CJK UNIFIED IDEOGRAPH-#2D3DA
2D3DB CJK UNIFIED IDEOGRAPH-#2D3DB
2D3DC CJK UNIFIED IDEOGRAPH-#2D3DC
2D3DD CJK UNIFIED IDEOGRAPH-#2D3DD
2D3DE CJK UNIFIED IDEOGRAPH-#2D3DE
2D3DF CJK UNIFIED IDEOGRAPH-#2D3DF
2D3E0 CJK UNIFIED IDEOGRAPH-#2D3E0
2D3E1 CJK UNIFIED IDEOGRAPH-#2D3E1
2D3E2 CJK UNIFIED IDEOGRAPH-#2D3E2
2D3E3 CJK UNIFIED IDEOGRAPH-#2D3E3
2D3E4 CJK UNIFIED IDEOGRAPH-#2D3E4
2D3E5 CJK UNIFIED IDEOGRAPH-#2D3E5
2D3E6 CJK UNIFIED IDEOGRAPH-#2D3E6
2D3E7 CJK UNIFIED IDEOGRAPH-#2D3E7
2D3E8 CJK UNIFIED IDEOGRAPH-#2D3E8
2D3E9 CJK UNIFIED IDEOGRAPH-#2D3E9
2D3EA CJK UNIFIED IDEOGRAPH-#2D3EA
2D3EB CJK UNIFIED IDEOGRAPH-#2D3EB
2D3EC CJK UNIFIED IDEOGRAPH-#2D3EC
2D3ED CJK UNIFIED IDEOGRAPH-#2D3ED
2D3EE CJK UNIFIED IDEOGRAPH-#2D3EE
2D3EF CJK UNIFIED IDEOGRAPH-#2D3EF
2D3F0 CJK UNIFIED IDEOGRAPH-#2D3F0
2D3F1 CJK UNIFIED IDEOGRAPH-#2D3F1
2D3F2 CJK UNIFIED IDEOGRAPH-#2D3F2
2D3F3 CJK UNIFIED IDEOGRAPH-#2D3F3
2D3F4 CJK UNIFIED IDEOGRAPH-#2D3F4
2D3F5 CJK UNIFIED IDEOGRAPH-#2D3F5
2D3F6 CJK UNIFIED IDEOGRAPH-#2D3F6
2D3F7 CJK UNIFIED IDEOGRAPH-#2D3F7
2D3F8 CJK UNIFIED IDEOGRAPH-#2D3F8
2D3F9 CJK UNIFIED IDEOGRAPH-#2D3F9
2D3FA CJK UNIFIED IDEOGRAPH-#2D3FA
2D3FB CJK UNIFIED IDEOGRAPH-#2D3FB
2D3FC CJK UNIFIED IDEOGRAPH-#2D3FC
2D3FD CJK UNIFIED IDEOGRAPH-#2D3FD
2D3FE CJK UNIFIED IDEOGRAPH-#2D3FE
2D3FF CJK UNIFIED IDEOGRAPH-#2D3FF
2D400 CJK UNIFIED IDEOGRAPH-#2D400
2D401 CJK UNIFIED IDEOGRAPH-#2D401
2D402 CJK UNIFIED IDEOGRAPH-#2D402
2D403 CJK UNIFIED IDEOGRAPH-#2D403
2D404 CJK UNIFIED IDEOGRAPH-#2D404
2D405 CJK UNIFIED IDEOGRAPH-#2D405
2D406 CJK UNIFIED IDEOGRAPH-#2D406
2D407 CJK UNIFIED IDEOGRAPH-#2D407
2D408 CJK UNIFIED IDEOGRAPH-#2D408
2D409 CJK UNIFIED IDEOGRAPH-#2D409
2D40A CJK UNIFIED IDEOGRAPH-#2D40A
2D40B CJK UNIFIED IDEOGRAPH-#2D40B
2D40C CJK UNIFIED IDEOGRAPH-#2D40C
2D40D CJK UNIFIED IDEOGRAPH-#2D40D
2D40E CJK UNIFIED IDEOGRAPH-#2D40E
2D40F CJK UNIFIED IDEOGRAPH-#2D40F
2D410 CJK UNIFIED IDEOGRAPH-#2D410
2D411 CJK UNIFIED IDEOGRAPH-#2D411
2D412 CJK UNIFIED IDEOGRAPH-#2D412
2D413 CJK UNIFIED IDEOGRAPH-#2D413
2D414 CJK UNIFIED IDEOGRAPH-#2D414
2D415 CJK UNIFIED IDEOGRAPH-#2D415
2D416 CJK UNIFIED IDEOGRAPH-#2D416
2D417 CJK UNIFIED IDEOGRAPH-#2D417
2D418 CJK UNIFIED IDEOGRAPH-#2D418
2D419 CJK UNIFIED IDEOGRAPH-#2D419
2D41A CJK UNIFIED IDEOGRAPH-#2D41A
2D41B CJK UNIFIED IDEOGRAPH-#2D41B
2D41C CJK UNIFIED IDEOGRAPH-#2D41C
2D41D CJK UNIFIED IDEOGRAPH-#2D41D
2D41E CJK UNIFIED IDEOGRAPH-#2D41E
2D41F CJK UNIFIED IDEOGRAPH-#2D41F
2D420 CJK UNIFIED IDEOGRAPH-#2D420
2D421 CJK UNIFIED IDEOGRAPH-#2D421
2D422 CJK UNIFIED IDEOGRAPH-#2D422
2D423 CJK UNIFIED IDEOGRAPH-#2D423
2D424 CJK UNIFIED IDEOGRAPH-#2D424
2D425 CJK UNIFIED IDEOGRAPH-#2D425
2D426 CJK UNIFIED IDEOGRAPH-#2D426
2D427 CJK UNIFIED IDEOGRAPH-#2D427
2D428 CJK UNIFIED IDEOGRAPH-#2D428
2D429 CJK UNIFIED IDEOGRAPH-#2D429
2D42A CJK UNIFIED IDEOGRAPH-#2D42A
2D42B CJK UNIFIED IDEOGRAPH-#2D42B
2D42C CJK UNIFIED IDEOGRAPH-#2D42C
2D42D CJK UNIFIED IDEOGRAPH-#2D42D
2D42E CJK UNIFIED IDEOGRAPH-#2D42E
2D42F CJK UNIFIED IDEOGRAPH-#2D42F
2D430 CJK UNIFIED IDEOGRAPH-#2D430
2D431 CJK UNIFIED IDEOGRAPH-#2D431
2D432 CJK UNIFIED IDEOGRAPH-#2D432
2D433 CJK UNIFIED IDEOGRAPH-#2D433
2D434 CJK UNIFIED IDEOGRAPH-#2D434
2D435 CJK UNIFIED IDEOGRAPH-#2D435
2D436 CJK UNIFIED IDEOGRAPH-#2D436
2D437 CJK UNIFIED IDEOGRAPH-#2D437
2D438 CJK UNIFIED IDEOGRAPH-#2D438
2D439 CJK UNIFIED IDEOGRAPH-#2D439
2D43A CJK UNIFIED IDEOGRAPH-#2D43A
2D43B CJK UNIFIED IDEOGRAPH-#2D43B
2D43C CJK UNIFIED IDEOGRAPH-#2D43C
2D43D CJK UNIFIED IDEOGRAPH-#2D43D
2D43E CJK UNIFIED IDEOGRAPH-#2D43E
2D43F CJK UNIFIED IDEOGRAPH-#2D43F
2D440 CJK UNIFIED IDEOGRAPH-#2D440
2D441 CJK UNIFIED IDEOGRAPH-#2D441
2D442 CJK UNIFIED IDEOGRAPH-#2D442
2D443 CJK UNIFIED IDEOGRAPH-#2D443
2D444 CJK UNIFIED IDEOGRAPH-#2D444
2D445 CJK UNIFIED IDEOGRAPH-#2D445
2D446 CJK UNIFIED IDEOGRAPH-#2D446
2D447 CJK UNIFIED IDEOGRAPH-#2D447
2D448 CJK UNIFIED IDEOGRAPH-#2D448
2D449 CJK UNIFIED IDEOGRAPH-#2D449
2D44A CJK UNIFIED IDEOGRAPH-#2D44A
2D44B CJK UNIFIED IDEOGRAPH-#2D44B
2D44C CJK UNIFIED IDEOGRAPH-#2D44C
2D44D CJK UNIFIED IDEOGRAPH-#2D44D
2D44E CJK UNIFIED IDEOGRAPH-#2D44E
2D44F CJK UNIFIED IDEOGRAPH-#2D44F
2D450 CJK UNIFIED IDEOGRAPH-#2D450
2D451 CJK UNIFIED IDEOGRAPH-#2D451
2D452 CJK UNIFIED IDEOGRAPH-#2D452
2D453 CJK UNIFIED IDEOGRAPH-#2D453
2D454 CJK UNIFIED IDEOGRAPH-#2D454
2D455 CJK UNIFIED IDEOGRAPH-#2D455
2D456 CJK UNIFIED IDEOGRAPH-#2D456
2D457 CJK UNIFIED IDEOGRAPH-#2D457
2D458 CJK UNIFIED IDEOGRAPH-#2D458
2D459 CJK UNIFIED IDEOGRAPH-#2D459
2D45A CJK UNIFIED IDEOGRAPH-#2D45A
2D45B CJK UNIFIED IDEOGRAPH-#2D45B
2D45C CJK UNIFIED IDEOGRAPH-#2D45C
2D45D CJK UNIFIED IDEOGRAPH-#2D45D
2D45E CJK UNIFIED IDEOGRAPH-#2D45E
2D45F CJK UNIFIED IDEOGRAPH-#2D45F
2D460 CJK UNIFIED IDEOGRAPH-#2D460
2D461 CJK UNIFIED IDEOGRAPH-#2D461
2D462 CJK UNIFIED IDEOGRAPH-#2D462
2D463 CJK UNIFIED IDEOGRAPH-#2D463
2D464 CJK UNIFIED IDEOGRAPH-#2D464
2D465 CJK UNIFIED IDEOGRAPH-#2D465
2D466 CJK UNIFIED IDEOGRAPH-#2D466
2D467 CJK UNIFIED IDEOGRAPH-#2D467
2D468 CJK UNIFIED IDEOGRAPH-#2D468
2D469 CJK UNIFIED IDEOGRAPH-#2D469
2D46A CJK UNIFIED IDEOGRAPH-#2D46A
2D46B CJK UNIFIED IDEOGRAPH-#2D46B
2D46C CJK UNIFIED IDEOGRAPH-#2D46C
2D46D CJK UNIFIED IDEOGRAPH-#2D46D
2D46E CJK UNIFIED IDEOGRAPH-#2D46E
2D46F CJK UNIFIED IDEOGRAPH-#2D46F
2D470 CJK UNIFIED IDEOGRAPH-#2D470
2D471 CJK UNIFIED IDEOGRAPH-#2D471
2D472 CJK UNIFIED IDEOGRAPH-#2D472
2D473 CJK UNIFIED IDEOGRAPH-#2D473
2D474 CJK UNIFIED IDEOGRAPH-#2D474
2D475 CJK UNIFIED IDEOGRAPH-#2D475
2D476 CJK UNIFIED IDEOGRAPH-#2D476
2D477 CJK UNIFIED IDEOGRAPH-#2D477
2D478 CJK UNIFIED IDEOGRAPH-#2D478
2D479 CJK UNIFIED IDEOGRAPH-#2D479
2D47A CJK UNIFIED IDEOGRAPH-#2D47A
2D47B CJK UNIFIED IDEOGRAPH-#2D47B
2D47C CJK UNIFIED IDEOGRAPH-#2D47C
2D47D CJK UNIFIED IDEOGRAPH-#2D47D
2D47E CJK UNIFIED IDEOGRAPH-#2D47E
2D47F CJK UNIFIED IDEOGRAPH-#2D47F
2D480 CJK UNIFIED IDEOGRAPH-#2D480
2D481 CJK UNIFIED IDEOGRAPH-#2D481
2D482 CJK UNIFIED IDEOGRAPH-#2D482
2D483 CJK UNIFIED IDEOGRAPH-#2D483
2D484 CJK UNIFIED IDEOGRAPH-#2D484
2D485 CJK UNIFIED IDEOGRAPH-#2D485
2D486 CJK UNIFIED IDEOGRAPH-#2D486
2D487 CJK UNIFIED IDEOGRAPH-#2D487
2D488 CJK UNIFIED IDEOGRAPH-#2D488
2D489 CJK UNIFIED IDEOGRAPH-#2D489
2D48A CJK UNIFIED IDEOGRAPH-#2D48A
2D48B CJK UNIFIED IDEOGRAPH-#2D48B
2D48C CJK UNIFIED IDEOGRAPH-#2D48C
2D48D CJK UNIFIED IDEOGRAPH-#2D48D
2D48E CJK UNIFIED IDEOGRAPH-#2D48E
2D48F CJK UNIFIED IDEOGRAPH-#2D48F
2D490 CJK UNIFIED IDEOGRAPH-#2D490
2D491 CJK UNIFIED IDEOGRAPH-#2D491
2D492 CJK UNIFIED IDEOGRAPH-#2D492
2D493 CJK UNIFIED IDEOGRAPH-#2D493
2D494 CJK UNIFIED IDEOGRAPH-#2D494
2D495 CJK UNIFIED IDEOGRAPH-#2D495
2D496 CJK UNIFIED IDEOGRAPH-#2D496
2D497 CJK UNIFIED IDEOGRAPH-#2D497
2D498 CJK UNIFIED IDEOGRAPH-#2D498
2D499 CJK UNIFIED IDEOGRAPH-#2D499
2D49A CJK UNIFIED IDEOGRAPH-#2D49A
2D49B CJK UNIFIED IDEOGRAPH-#2D49B
2D49C CJK UNIFIED IDEOGRAPH-#2D49C
2D49D CJK UNIFIED IDEOGRAPH-#2D49D
2D49E CJK UNIFIED IDEOGRAPH-#2D49E
2D49F CJK UNIFIED IDEOGRAPH-#2D49F
2D4A0 CJK UNIFIED IDEOGRAPH-#2D4A0
2D4A1 CJK UNIFIED IDEOGRAPH-#2D4A1
2D4A2 CJK UNIFIED IDEOGRAPH-#2D4A2
2D4A3 CJK UNIFIED IDEOGRAPH-#2D4A3
2D4A4 CJK UNIFIED IDEOGRAPH-#2D4A4
2D4A5 CJK UNIFIED IDEOGRAPH-#2D4A5
2D4A6 CJK UNIFIED IDEOGRAPH-#2D4A6
2D4A7 CJK UNIFIED IDEOGRAPH-#2D4A7
2D4A8 CJK UNIFIED IDEOGRAPH-#2D4A8
2D4A9 CJK UNIFIED IDEOGRAPH-#2D4A9
2D4AA CJK UNIFIED IDEOGRAPH-#2D4AA
2D4AB CJK UNIFIED IDEOGRAPH-#2D4AB
2D4AC CJK UNIFIED IDEOGRAPH-#2D4AC
2D4AD CJK UNIFIED IDEOGRAPH-#2D4AD
2D4AE CJK UNIFIED IDEOGRAPH-#2D4AE
2D4AF CJK UNIFIED IDEOGRAPH-#2D4AF
2D4B0 CJK UNIFIED IDEOGRAPH-#2D4B0
2D4B1 CJK UNIFIED IDEOGRAPH-#2D4B1
2D4B2 CJK UNIFIED IDEOGRAPH-#2D4B2
2D4B3 CJK UNIFIED IDEOGRAPH-#2D4B3
2D4B4 CJK UNIFIED IDEOGRAPH-#2D4B4
2D4B5 CJK UNIFIED IDEOGRAPH-#2D4B5
2D4B6 CJK UNIFIED IDEOGRAPH-#2D4B6
2D4B7 CJK UNIFIED IDEOGRAPH-#2D4B7
2D4B8 CJK UNIFIED IDEOGRAPH-#2D4B8
2D4B9 CJK UNIFIED IDEOGRAPH-#2D4B9
2D4BA CJK UNIFIED IDEOGRAPH-#2D4BA
2D4BB CJK UNIFIED IDEOGRAPH-#2D4BB
2D4BC CJK UNIFIED IDEOGRAPH-#2D4BC
2D4BD CJK UNIFIED IDEOGRAPH-#2D4BD
2D4BE CJK UNIFIED IDEOGRAPH-#2D4BE
2D4BF CJK UNIFIED IDEOGRAPH-#2D4BF
2D4C0 CJK UNIFIED IDEOGRAPH-#2D4C0
2D4C1 CJK UNIFIED IDEOGRAPH-#2D4C1
2D4C2 CJK UNIFIED IDEOGRAPH-#2D4C2
2D4C3 CJK UNIFIED IDEOGRAPH-#2D4C3
2D4C4 CJK UNIFIED IDEOGRAPH-#2D4C4
2D4C5 CJK UNIFIED IDEOGRAPH-#2D4C5
2D4C6 CJK UNIFIED IDEOGRAPH-#2D4C6
2D4C7 CJK UNIFIED IDEOGRAPH-#2D4C7
2D4C8 CJK UNIFIED IDEOGRAPH-#2D4C8
2D4C9 CJK UNIFIED IDEOGRAPH-#2D4C9
2D4CA CJK UNIFIED IDEOGRAPH-#2D4CA
2D4CB CJK UNIFIED IDEOGRAPH-#2D4CB
2D4CC CJK UNIFIED IDEOGRAPH-#2D4CC
2D4CD CJK UNIFIED IDEOGRAPH-#2D4CD
2D4CE CJK UNIFIED IDEOGRAPH-#2D4CE
2D4CF CJK UNIFIED IDEOGRAPH-#2D4CF
2D4D0 CJK UNIFIED IDEOGRAPH-#2D4D0
2D4D1 CJK UNIFIED IDEOGRAPH-#2D4D1
2D4D2 CJK UNIFIED IDEOGRAPH-#2D4D2
2D4D3 CJK UNIFIED IDEOGRAPH-#2D4D3
2D4D4 CJK UNIFIED IDEOGRAPH-#2D4D4
2D4D5 CJK UNIFIED IDEOGRAPH-#2D4D5
2D4D6 CJK UNIFIED IDEOGRAPH-#2D4D6
2D4D7 CJK UNIFIED IDEOGRAPH-#2D4D7
2D4D8 CJK UNIFIED IDEOGRAPH-#2D4D8
2D4D9 CJK UNIFIED IDEOGRAPH-#2D4D9
2D4DA CJK UNIFIED IDEOGRAPH-#2D4DA
2D4DB CJK UNIFIED IDEOGRAPH-#2D4DB
2D4DC CJK UNIFIED IDEOGRAPH-#2D4DC
2D4DD CJK UNIFIED IDEOGRAPH-#2D4DD
2D4DE CJK UNIFIED IDEOGRAPH-#2D4DE
2D4DF CJK UNIFIED IDEOGRAPH-#2D4DF
2D4E0 CJK UNIFIED IDEOGRAPH-#2D4E0
2D4E1 CJK UNIFIED IDEOGRAPH-#2D4E1
2D4E2 CJK UNIFIED IDEOGRAPH-#2D4E2
2D4E3 CJK UNIFIED IDEOGRAPH-#2D4E3
2D4E4 CJK UNIFIED IDEOGRAPH-#2D4E4
2D4E5 CJK UNIFIED IDEOGRAPH-#2D4E5
2D4E6 CJK UNIFIED IDEOGRAPH-#2D4E6
2D4E7 CJK UNIFIED IDEOGRAPH-#2D4E7
2D4E8 CJK UNIFIED IDEOGRAPH-#2D4E8
2D4E9 CJK UNIFIED IDEOGRAPH-#2D4E9
2D4EA CJK UNIFIED IDEOGRAPH-#2D4EA
2D4EB CJK UNIFIED IDEOGRAPH-#2D4EB
2D4EC CJK UNIFIED IDEOGRAPH-#2D4EC
2D4ED CJK UNIFIED IDEOGRAPH-#2D4ED
2D4EE CJK UNIFIED IDEOGRAPH-#2D4EE
2D4EF CJK UNIFIED IDEOGRAPH-#2D4EF
2D4F0 CJK UNIFIED IDEOGRAPH-#2D4F0
2D4F1 CJK UNIFIED IDEOGRAPH-#2D4F1
2D4F2 CJK UNIFIED IDEOGRAPH-#2D4F2
2D4F3 CJK UNIFIED IDEOGRAPH-#2D4F3
2D4F4 CJK UNIFIED IDEOGRAPH-#2D4F4
2D4F5 CJK UNIFIED IDEOGRAPH-#2D4F5
2D4F6 CJK UNIFIED IDEOGRAPH-#2D4F6
2D4F7 CJK UNIFIED IDEOGRAPH-#2D4F7
2D4F8 CJK UNIFIED IDEOGRAPH-#2D4F8
2D4F9 CJK UNIFIED IDEOGRAPH-#2D4F9
2D4FA CJK UNIFIED IDEOGRAPH-#2D4FA
2D4FB CJK UNIFIED IDEOGRAPH-#2D4FB
2D4FC CJK UNIFIED IDEOGRAPH-#2D4FC
2D4FD CJK UNIFIED IDEOGRAPH-#2D4FD
2D4FE CJK UNIFIED IDEOGRAPH-#2D4FE
2D4FF CJK UNIFIED IDEOGRAPH-#2D4FF
2D500 CJK UNIFIED IDEOGRAPH-#2D500
2D501 CJK UNIFIED IDEOGRAPH-#2D501
2D502 CJK UNIFIED IDEOGRAPH-#2D502
2D503 CJK UNIFIED IDEOGRAPH-#2D503
2D504 CJK UNIFIED IDEOGRAPH-#2D504
2D505 CJK UNIFIED IDEOGRAPH-#2D505
2D506 CJK UNIFIED IDEOGRAPH-#2D506
2D507 CJK UNIFIED IDEOGRAPH-#2D507
2D508 CJK UNIFIED IDEOGRAPH-#2D508
2D509 CJK UNIFIED IDEOGRAPH-#2D509
2D50A CJK UNIFIED IDEOGRAPH-#2D50A
2D50B CJK UNIFIED IDEOGRAPH-#2D50B
2D50C CJK UNIFIED IDEOGRAPH-#2D50C
2D50D CJK UNIFIED IDEOGRAPH-#2D50D
2D50E CJK UNIFIED IDEOGRAPH-#2D50E
2D50F CJK UNIFIED IDEOGRAPH-#2D50F
2D510 CJK UNIFIED IDEOGRAPH-#2D510
2D511 CJK UNIFIED IDEOGRAPH-#2D511
2D512 CJK UNIFIED IDEOGRAPH-#2D512
2D513 CJK UNIFIED IDEOGRAPH-#2D513
2D514 CJK UNIFIED IDEOGRAPH-#2D514
2D515 CJK UNIFIED IDEOGRAPH-#2D515
2D516 CJK UNIFIED IDEOGRAPH-#2D516
2D517 CJK UNIFIED IDEOGRAPH-#2D517
2D518 CJK UNIFIED IDEOGRAPH-#2D518
2D519 CJK UNIFIED IDEOGRAPH-#2D519
2D51A CJK UNIFIED IDEOGRAPH-#2D51A
2D51B CJK UNIFIED IDEOGRAPH-#2D51B
2D51C CJK UNIFIED IDEOGRAPH-#2D51C
2D51D CJK UNIFIED IDEOGRAPH-#2D51D
2D51E CJK UNIFIED IDEOGRAPH-#2D51E
2D51F CJK UNIFIED IDEOGRAPH-#2D51F
2D520 CJK UNIFIED IDEOGRAPH-#2D520
2D521 CJK UNIFIED IDEOGRAPH-#2D521
2D522 CJK UNIFIED IDEOGRAPH-#2D522
2D523 CJK UNIFIED IDEOGRAPH-#2D523
2D524 CJK UNIFIED IDEOGRAPH-#2D524
2D525 CJK UNIFIED IDEOGRAPH-#2D525
2D526 CJK UNIFIED IDEOGRAPH-#2D526
2D527 CJK UNIFIED IDEOGRAPH-#2D527
2D528 CJK UNIFIED IDEOGRAPH-#2D528
2D529 CJK UNIFIED IDEOGRAPH-#2D529
2D52A CJK UNIFIED IDEOGRAPH-#2D52A
2D52B CJK UNIFIED IDEOGRAPH-#2D52B
2D52C CJK UNIFIED IDEOGRAPH-#2D52C
2D52D CJK UNIFIED IDEOGRAPH-#2D52D
2D52E CJK UNIFIED IDEOGRAPH-#2D52E
2D52F CJK UNIFIED IDEOGRAPH-#2D52F
2D530 CJK UNIFIED IDEOGRAPH-#2D530
2D531 CJK UNIFIED IDEOGRAPH-#2D531
2D532 CJK UNIFIED IDEOGRAPH-#2D532
2D533 CJK UNIFIED IDEOGRAPH-#2D533
2D534 CJK UNIFIED IDEOGRAPH-#2D534
2D535 CJK UNIFIED IDEOGRAPH-#2D535
2D536 CJK UNIFIED IDEOGRAPH-#2D536
2D537 CJK UNIFIED IDEOGRAPH-#2D537
2D538 CJK UNIFIED IDEOGRAPH-#2D538
2D539 CJK UNIFIED IDEOGRAPH-#2D539
2D53A CJK UNIFIED IDEOGRAPH-#2D53A
2D53B CJK UNIFIED IDEOGRAPH-#2D53B
2D53C CJK UNIFIED IDEOGRAPH-#2D53C
2D53D CJK UNIFIED IDEOGRAPH-#2D53D
2D53E CJK UNIFIED IDEOGRAPH-#2D53E
2D53F CJK UNIFIED IDEOGRAPH-#2D53F
2D540 CJK UNIFIED IDEOGRAPH-#2D540
2D541 CJK UNIFIED IDEOGRAPH-#2D541
2D542 CJK UNIFIED IDEOGRAPH-#2D542
2D543 CJK UNIFIED IDEOGRAPH-#2D543
2D544 CJK UNIFIED IDEOGRAPH-#2D544
2D545 CJK UNIFIED IDEOGRAPH-#2D545
2D546 CJK UNIFIED IDEOGRAPH-#2D546
2D547 CJK UNIFIED IDEOGRAPH-#2D547
2D548 CJK UNIFIED IDEOGRAPH-#2D548
2D549 CJK UNIFIED IDEOGRAPH-#2D549
2D54A CJK UNIFIED IDEOGRAPH-#2D54A
2D54B CJK UNIFIED IDEOGRAPH-#2D54B
2D54C CJK UNIFIED IDEOGRAPH-#2D54C
2D54D CJK UNIFIED IDEOGRAPH-#2D54D
2D54E CJK UNIFIED IDEOGRAPH-#2D54E
2D54F CJK UNIFIED IDEOGRAPH-#2D54F
2D550 CJK UNIFIED IDEOGRAPH-#2D550
2D551 CJK UNIFIED IDEOGRAPH-#2D551
2D552 CJK UNIFIED IDEOGRAPH-#2D552
2D553 CJK UNIFIED IDEOGRAPH-#2D553
2D554 CJK UNIFIED IDEOGRAPH-#2D554
2D555 CJK UNIFIED IDEOGRAPH-#2D555
2D556 CJK UNIFIED IDEOGRAPH-#2D556
2D557 CJK UNIFIED IDEOGRAPH-#2D557
2D558 CJK UNIFIED IDEOGRAPH-#2D558
2D559 CJK UNIFIED IDEOGRAPH-#2D559
2D55A CJK UNIFIED IDEOGRAPH-#2D55A
2D55B CJK UNIFIED IDEOGRAPH-#2D55B
2D55C CJK UNIFIED IDEOGRAPH-#2D55C
2D55D CJK UNIFIED IDEOGRAPH-#2D55D
2D55E CJK UNIFIED IDEOGRAPH-#2D55E
2D55F CJK UNIFIED IDEOGRAPH-#2D55F
2D560 CJK UNIFIED IDEOGRAPH-#2D560
2D561 CJK UNIFIED IDEOGRAPH-#2D561
2D562 CJK UNIFIED IDEOGRAPH-#2D562
2D563 CJK UNIFIED IDEOGRAPH-#2D563
2D564 CJK UNIFIED IDEOGRAPH-#2D564
2D565 CJK UNIFIED IDEOGRAPH-#2D565
2D566 CJK UNIFIED IDEOGRAPH-#2D566
2D567 CJK UNIFIED IDEOGRAPH-#2D567
2D568 CJK UNIFIED IDEOGRAPH-#2D568
2D569 CJK UNIFIED IDEOGRAPH-#2D569
2D56A CJK UNIFIED IDEOGRAPH-#2D56A
2D56B CJK UNIFIED IDEOGRAPH-#2D56B
2D56C CJK UNIFIED IDEOGRAPH-#2D56C
2D56D CJK UNIFIED IDEOGRAPH-#2D56D
2D56E CJK UNIFIED IDEOGRAPH-#2D56E
2D56F CJK UNIFIED IDEOGRAPH-#2D56F
2D570 CJK UNIFIED IDEOGRAPH-#2D570
2D571 CJK UNIFIED IDEOGRAPH-#2D571
2D572 CJK UNIFIED IDEOGRAPH-#2D572
2D573 CJK UNIFIED IDEOGRAPH-#2D573
2D574 CJK UNIFIED IDEOGRAPH-#2D574
2D575 CJK UNIFIED IDEOGRAPH-#2D575
2D576 CJK UNIFIED IDEOGRAPH-#2D576
2D577 CJK UNIFIED IDEOGRAPH-#2D577
2D578 CJK UNIFIED IDEOGRAPH-#2D578
2D579 CJK UNIFIED IDEOGRAPH-#2D579
2D57A CJK UNIFIED IDEOGRAPH-#2D57A
2D57B CJK UNIFIED IDEOGRAPH-#2D57B
2D57C CJK UNIFIED IDEOGRAPH-#2D57C
2D57D CJK UNIFIED IDEOGRAPH-#2D57D
2D57E CJK UNIFIED IDEOGRAPH-#2D57E
2D57F CJK UNIFIED IDEOGRAPH-#2D57F
2D580 CJK UNIFIED IDEOGRAPH-#2D580
2D581 CJK UNIFIED IDEOGRAPH-#2D581
2D582 CJK UNIFIED IDEOGRAPH-#2D582
2D583 CJK UNIFIED IDEOGRAPH-#2D583
2D584 CJK UNIFIED IDEOGRAPH-#2D584
2D585 CJK UNIFIED IDEOGRAPH-#2D585
2D586 CJK UNIFIED IDEOGRAPH-#2D586
2D587 CJK UNIFIED IDEOGRAPH-#2D587
2D588 CJK UNIFIED IDEOGRAPH-#2D588
2D589 CJK UNIFIED IDEOGRAPH-#2D589
2D58A CJK UNIFIED IDEOGRAPH-#2D58A
2D58B CJK UNIFIED IDEOGRAPH-#2D58B
2D58C CJK UNIFIED IDEOGRAPH-#2D58C
2D58D CJK UNIFIED IDEOGRAPH-#2D58D
2D58E CJK UNIFIED IDEOGRAPH-#2D58E
2D58F CJK UNIFIED IDEOGRAPH-#2D58F
2D590 CJK UNIFIED IDEOGRAPH-#2D590
2D591 CJK UNIFIED IDEOGRAPH-#2D591
2D592 CJK UNIFIED IDEOGRAPH-#2D592
2D593 CJK UNIFIED IDEOGRAPH-#2D593
2D594 CJK UNIFIED IDEOGRAPH-#2D594
2D595 CJK UNIFIED IDEOGRAPH-#2D595
2D596 CJK UNIFIED IDEOGRAPH-#2D596
2D597 CJK UNIFIED IDEOGRAPH-#2D597
2D598 CJK UNIFIED IDEOGRAPH-#2D598
2D599 CJK UNIFIED IDEOGRAPH-#2D599
2D59A CJK UNIFIED IDEOGRAPH-#2D59A
2D59B CJK UNIFIED IDEOGRAPH-#2D59B
2D59C CJK UNIFIED IDEOGRAPH-#2D59C
2D59D CJK UNIFIED IDEOGRAPH-#2D59D
2D59E CJK UNIFIED IDEOGRAPH-#2D59E
2D59F CJK UNIFIED IDEOGRAPH-#2D59F
2D5A0 CJK UNIFIED IDEOGRAPH-#2D5A0
2D5A1 CJK UNIFIED IDEOGRAPH-#2D5A1
2D5A2 CJK UNIFIED IDEOGRAPH-#2D5A2
2D5A3 CJK UNIFIED IDEOGRAPH-#2D5A3
2D5A4 CJK UNIFIED IDEOGRAPH-#2D5A4
2D5A5 CJK UNIFIED IDEOGRAPH-#2D5A5
2D5A6 CJK UNIFIED IDEOGRAPH-#2D5A6
2D5A7 CJK UNIFIED IDEOGRAPH-#2D5A7
2D5A8 CJK UNIFIED IDEOGRAPH-#2D5A8
2D5A9 CJK UNIFIED IDEOGRAPH-#2D5A9
2D5AA CJK UNIFIED IDEOGRAPH-#2D5AA
2D5AB CJK UNIFIED IDEOGRAPH-#2D5AB
2D5AC CJK UNIFIED IDEOGRAPH-#2D5AC
2D5AD CJK UNIFIED IDEOGRAPH-#2D5AD
2D5AE CJK UNIFIED IDEOGRAPH-#2D5AE
2D5AF CJK UNIFIED IDEOGRAPH-#2D5AF
2D5B0 CJK UNIFIED IDEOGRAPH-#2D5B0
2D5B1 CJK UNIFIED IDEOGRAPH-#2D5B1
2D5B2 CJK UNIFIED IDEOGRAPH-#2D5B2
2D5B3 CJK UNIFIED IDEOGRAPH-#2D5B3
2D5B4 CJK UNIFIED IDEOGRAPH-#2D5B4
2D5B5 CJK UNIFIED IDEOGRAPH-#2D5B5
2D5B6 CJK UNIFIED IDEOGRAPH-#2D5B6
2D5B7 CJK UNIFIED IDEOGRAPH-#2D5B7
2D5B8 CJK UNIFIED IDEOGRAPH-#2D5B8
2D5B9 CJK UNIFIED IDEOGRAPH-#2D5B9
2D5BA CJK UNIFIED IDEOGRAPH-#2D5BA
2D5BB CJK UNIFIED IDEOGRAPH-#2D5BB
2D5BC CJK UNIFIED IDEOGRAPH-#2D5BC
2D5BD CJK UNIFIED IDEOGRAPH-#2D5BD
2D5BE CJK UNIFIED IDEOGRAPH-#2D5BE
2D5BF CJK UNIFIED IDEOGRAPH-#2D5BF
2D5C0 CJK UNIFIED IDEOGRAPH-#2D5C0
2D5C1 CJK UNIFIED IDEOGRAPH-#2D5C1
2D5C2 CJK UNIFIED IDEOGRAPH-#2D5C2
2D5C3 CJK UNIFIED IDEOGRAPH-#2D5C3
2D5C4 CJK UNIFIED IDEOGRAPH-#2D5C4
2D5C5 CJK UNIFIED IDEOGRAPH-#2D5C5
2D5C6 CJK UNIFIED IDEOGRAPH-#2D5C6
2D5C7 CJK UNIFIED IDEOGRAPH-#2D5C7
2D5C8 CJK UNIFIED IDEOGRAPH-#2D5C8
2D5C9 CJK UNIFIED IDEOGRAPH-#2D5C9
2D5CA CJK UNIFIED IDEOGRAPH-#2D5CA
2D5CB CJK UNIFIED IDEOGRAPH-#2D5CB
2D5CC CJK UNIFIED IDEOGRAPH-#2D5CC
2D5CD CJK UNIFIED IDEOGRAPH-#2D5CD
2D5CE CJK UNIFIED IDEOGRAPH-#2D5CE
2D5CF CJK UNIFIED IDEOGRAPH-#2D5CF
2D5D0 CJK UNIFIED IDEOGRAPH-#2D5D0
2D5D1 CJK UNIFIED IDEOGRAPH-#2D5D1
2D5D2 CJK UNIFIED IDEOGRAPH-#2D5D2
2D5D3 CJK UNIFIED IDEOGRAPH-#2D5D3
2D5D4 CJK UNIFIED IDEOGRAPH-#2D5D4
2D5D5 CJK UNIFIED IDEOGRAPH-#2D5D5
2D5D6 CJK UNIFIED IDEOGRAPH-#2D5D6
2D5D7 CJK UNIFIED IDEOGRAPH-#2D5D7
2D5D8 CJK UNIFIED IDEOGRAPH-#2D5D8
2D5D9 CJK UNIFIED IDEOGRAPH-#2D5D9
2D5DA CJK UNIFIED IDEOGRAPH-#2D5DA
2D5DB CJK UNIFIED IDEOGRAPH-#2D5DB
2D5DC CJK UNIFIED IDEOGRAPH-#2D5DC
2D5DD CJK UNIFIED IDEOGRAPH-#2D5DD
2D5DE CJK UNIFIED IDEOGRAPH-#2D5DE
2D5DF CJK UNIFIED IDEOGRAPH-#2D5DF
2D5E0 CJK UNIFIED IDEOGRAPH-#2D5E0
2D5E1 CJK UNIFIED IDEOGRAPH-#2D5E1
2D5E2 CJK UNIFIED IDEOGRAPH-#2D5E2
2D5E3 CJK UNIFIED IDEOGRAPH-#2D5E3
2D5E4 CJK UNIFIED IDEOGRAPH-#2D5E4
2D5E5 CJK UNIFIED IDEOGRAPH-#2D5E5
2D5E6 CJK UNIFIED IDEOGRAPH-#2D5E6
2D5E7 CJK UNIFIED IDEOGRAPH-#2D5E7
2D5E8 CJK UNIFIED IDEOGRAPH-#2D5E8
2D5E9 CJK UNIFIED IDEOGRAPH-#2D5E9
2D5EA CJK UNIFIED IDEOGRAPH-#2D5EA
2D5EB CJK UNIFIED IDEOGRAPH-#2D5EB
2D5EC CJK UNIFIED IDEOGRAPH-#2D5EC
2D5ED CJK UNIFIED IDEOGRAPH-#2D5ED
2D5EE CJK UNIFIED IDEOGRAPH-#2D5EE
2D5EF CJK UNIFIED IDEOGRAPH-#2D5EF
2D5F0 CJK UNIFIED IDEOGRAPH-#2D5F0
2D5F1 CJK UNIFIED IDEOGRAPH-#2D5F1
2D5F2 CJK UNIFIED IDEOGRAPH-#2D5F2
2D5F3 CJK UNIFIED IDEOGRAPH-#2D5F3
2D5F4 CJK UNIFIED IDEOGRAPH-#2D5F4
2D5F5 CJK UNIFIED IDEOGRAPH-#2D5F5
2D5F6 CJK UNIFIED IDEOGRAPH-#2D5F6
2D5F7 CJK UNIFIED IDEOGRAPH-#2D5F7
2D5F8 CJK UNIFIED IDEOGRAPH-#2D5F8
2D5F9 CJK UNIFIED IDEOGRAPH-#2D5F9
2D5FA CJK UNIFIED IDEOGRAPH-#2D5FA
2D5FB CJK UNIFIED IDEOGRAPH-#2D5FB
2D5FC CJK UNIFIED IDEOGRAPH-#2D5FC
2D5FD CJK UNIFIED IDEOGRAPH-#2D5FD
2D5FE CJK UNIFIED IDEOGRAPH-#2D5FE
2D5FF CJK UNIFIED IDEOGRAPH-#2D5FF
2D600 CJK UNIFIED IDEOGRAPH-#2D600
2D601 CJK UNIFIED IDEOGRAPH-#2D601
2D602 CJK UNIFIED IDEOGRAPH-#2D602
2D603 CJK UNIFIED IDEOGRAPH-#2D603
2D604 CJK UNIFIED IDEOGRAPH-#2D604
2D605 CJK UNIFIED IDEOGRAPH-#2D605
2D606 CJK UNIFIED IDEOGRAPH-#2D606
2D607 CJK UNIFIED IDEOGRAPH-#2D607
2D608 CJK UNIFIED IDEOGRAPH-#2D608
2D609 CJK UNIFIED IDEOGRAPH-#2D609
2D60A CJK UNIFIED IDEOGRAPH-#2D60A
2D60B CJK UNIFIED IDEOGRAPH-#2D60B
2D60C CJK UNIFIED IDEOGRAPH-#2D60C
2D60D CJK UNIFIED IDEOGRAPH-#2D60D
2D60E CJK UNIFIED IDEOGRAPH-#2D60E
2D60F CJK UNIFIED IDEOGRAPH-#2D60F
2D610 CJK UNIFIED IDEOGRAPH-#2D610
2D611 CJK UNIFIED IDEOGRAPH-#2D611
2D612 CJK UNIFIED IDEOGRAPH-#2D612
2D613 CJK UNIFIED IDEOGRAPH-#2D613
2D614 CJK UNIFIED IDEOGRAPH-#2D614
2D615 CJK UNIFIED IDEOGRAPH-#2D615
2D616 CJK UNIFIED IDEOGRAPH-#2D616
2D617 CJK UNIFIED IDEOGRAPH-#2D617
2D618 CJK UNIFIED IDEOGRAPH-#2D618
2D619 CJK UNIFIED IDEOGRAPH-#2D619
2D61A CJK UNIFIED IDEOGRAPH-#2D61A
2D61B CJK UNIFIED IDEOGRAPH-#2D61B
2D61C CJK UNIFIED IDEOGRAPH-#2D61C
2D61D CJK UNIFIED IDEOGRAPH-#2D61D
2D61E CJK UNIFIED IDEOGRAPH-#2D61E
2D61F CJK UNIFIED IDEOGRAPH-#2D61F
2D620 CJK UNIFIED IDEOGRAPH-#2D620
2D621 CJK UNIFIED IDEOGRAPH-#2D621
2D622 CJK UNIFIED IDEOGRAPH-#2D622
2D623 CJK UNIFIED IDEOGRAPH-#2D623
2D624 CJK UNIFIED IDEOGRAPH-#2D624
2D625 CJK UNIFIED IDEOGRAPH-#2D625
2D626 CJK UNIFIED IDEOGRAPH-#2D626
2D627 CJK UNIFIED IDEOGRAPH-#2D627
2D628 CJK UNIFIED IDEOGRAPH-#2D628
2D629 CJK UNIFIED IDEOGRAPH-#2D629
2D62A CJK UNIFIED IDEOGRAPH-#2D62A
2D62B CJK UNIFIED IDEOGRAPH-#2D62B
2D62C CJK UNIFIED IDEOGRAPH-#2D62C
2D62D CJK UNIFIED IDEOGRAPH-#2D62D
2D62E CJK UNIFIED IDEOGRAPH-#2D62E
2D62F CJK UNIFIED IDEOGRAPH-#2D62F
2D630 CJK UNIFIED IDEOGRAPH-#2D630
2D631 CJK UNIFIED IDEOGRAPH-#2D631
2D632 CJK UNIFIED IDEOGRAPH-#2D632
2D633 CJK UNIFIED IDEOGRAPH-#2D633
2D634 CJK UNIFIED IDEOGRAPH-#2D634
2D635 CJK UNIFIED IDEOGRAPH-#2D635
2D636 CJK UNIFIED IDEOGRAPH-#2D636
2D637 CJK UNIFIED IDEOGRAPH-#2D637
2D638 CJK UNIFIED IDEOGRAPH-#2D638
2D639 CJK UNIFIED IDEOGRAPH-#2D639
2D63A CJK UNIFIED IDEOGRAPH-#2D63A
2D63B CJK UNIFIED IDEOGRAPH-#2D63B
2D63C CJK UNIFIED IDEOGRAPH-#2D63C
2D63D CJK UNIFIED IDEOGRAPH-#2D63D
2D63E CJK UNIFIED IDEOGRAPH-#2D63E
2D63F CJK UNIFIED IDEOGRAPH-#2D63F
2D640 CJK UNIFIED IDEOGRAPH-#2D640
2D641 CJK UNIFIED IDEOGRAPH-#2D641
2D642 CJK UNIFIED IDEOGRAPH-#2D642
2D643 CJK UNIFIED IDEOGRAPH-#2D643
2D644 CJK UNIFIED IDEOGRAPH-#2D644
2D645 CJK UNIFIED IDEOGRAPH-#2D645
2D646 CJK UNIFIED IDEOGRAPH-#2D646
2D647 CJK UNIFIED IDEOGRAPH-#2D647
2D648 CJK UNIFIED IDEOGRAPH-#2D648
2D649 CJK UNIFIED IDEOGRAPH-#2D649
2D64A CJK UNIFIED IDEOGRAPH-#2D64A
2D64B CJK UNIFIED IDEOGRAPH-#2D64B
2D64C CJK UNIFIED IDEOGRAPH-#2D64C
2D64D CJK UNIFIED IDEOGRAPH-#2D64D
2D64E CJK UNIFIED IDEOGRAPH-#2D64E
2D64F CJK UNIFIED IDEOGRAPH-#2D64F
2D650 CJK UNIFIED IDEOGRAPH-#2D650
2D651 CJK UNIFIED IDEOGRAPH-#2D651
2D652 CJK UNIFIED IDEOGRAPH-#2D652
2D653 CJK UNIFIED IDEOGRAPH-#2D653
2D654 CJK UNIFIED IDEOGRAPH-#2D654
2D655 CJK UNIFIED IDEOGRAPH-#2D655
2D656 CJK UNIFIED IDEOGRAPH-#2D656
2D657 CJK UNIFIED IDEOGRAPH-#2D657
2D658 CJK UNIFIED IDEOGRAPH-#2D658
2D659 CJK UNIFIED IDEOGRAPH-#2D659
2D65A CJK UNIFIED IDEOGRAPH-#2D65A
2D65B CJK UNIFIED IDEOGRAPH-#2D65B
2D65C CJK UNIFIED IDEOGRAPH-#2D65C
2D65D CJK UNIFIED IDEOGRAPH-#2D65D
2D65E CJK UNIFIED IDEOGRAPH-#2D65E
2D65F CJK UNIFIED IDEOGRAPH-#2D65F
2D660 CJK UNIFIED IDEOGRAPH-#2D660
2D661 CJK UNIFIED IDEOGRAPH-#2D661
2D662 CJK UNIFIED IDEOGRAPH-#2D662
2D663 CJK UNIFIED IDEOGRAPH-#2D663
2D664 CJK UNIFIED IDEOGRAPH-#2D664
2D665 CJK UNIFIED IDEOGRAPH-#2D665
2D666 CJK UNIFIED IDEOGRAPH-#2D666
2D667 CJK UNIFIED IDEOGRAPH-#2D667
2D668 CJK UNIFIED IDEOGRAPH-#2D668
2D669 CJK UNIFIED IDEOGRAPH-#2D669
2D66A CJK UNIFIED IDEOGRAPH-#2D66A
2D66B CJK UNIFIED IDEOGRAPH-#2D66B
2D66C CJK UNIFIED IDEOGRAPH-#2D66C
2D66D CJK UNIFIED IDEOGRAPH-#2D66D
2D66E CJK UNIFIED IDEOGRAPH-#2D66E
2D66F CJK UNIFIED IDEOGRAPH-#2D66F
2D670 CJK UNIFIED IDEOGRAPH-#2D670
2D671 CJK UNIFIED IDEOGRAPH-#2D671
2D672 CJK UNIFIED IDEOGRAPH-#2D672
2D673 CJK UNIFIED IDEOGRAPH-#2D673
2D674 CJK UNIFIED IDEOGRAPH-#2D674
2D675 CJK UNIFIED IDEOGRAPH-#2D675
2D676 CJK UNIFIED IDEOGRAPH-#2D676
2D677 CJK UNIFIED IDEOGRAPH-#2D677
2D678 CJK UNIFIED IDEOGRAPH-#2D678
2D679 CJK UNIFIED IDEOGRAPH-#2D679
2D67A CJK UNIFIED IDEOGRAPH-#2D67A
2D67B CJK UNIFIED IDEOGRAPH-#2D67B
2D67C CJK UNIFIED IDEOGRAPH-#2D67C
2D67D CJK UNIFIED IDEOGRAPH-#2D67D
2D67E CJK UNIFIED IDEOGRAPH-#2D67E
2D67F CJK UNIFIED IDEOGRAPH-#2D67F
2D680 CJK UNIFIED IDEOGRAPH-#2D680
2D681 CJK UNIFIED IDEOGRAPH-#2D681
2D682 CJK UNIFIED IDEOGRAPH-#2D682
2D683 CJK UNIFIED IDEOGRAPH-#2D683
2D684 CJK UNIFIED IDEOGRAPH-#2D684
2D685 CJK UNIFIED IDEOGRAPH-#2D685
2D686 CJK UNIFIED IDEOGRAPH-#2D686
2D687 CJK UNIFIED IDEOGRAPH-#2D687
2D688 CJK UNIFIED IDEOGRAPH-#2D688
2D689 CJK UNIFIED IDEOGRAPH-#2D689
2D68A CJK UNIFIED IDEOGRAPH-#2D68A
2D68B CJK UNIFIED IDEOGRAPH-#2D68B
2D68C CJK UNIFIED IDEOGRAPH-#2D68C
2D68D CJK UNIFIED IDEOGRAPH-#2D68D
2D68E CJK UNIFIED IDEOGRAPH-#2D68E
2D68F CJK UNIFIED IDEOGRAPH-#2D68F
2D690 CJK UNIFIED IDEOGRAPH-#2D690
2D691 CJK UNIFIED IDEOGRAPH-#2D691
2D692 CJK UNIFIED IDEOGRAPH-#2D692
2D693 CJK UNIFIED IDEOGRAPH-#2D693
2D694 CJK UNIFIED IDEOGRAPH-#2D694
2D695 CJK UNIFIED IDEOGRAPH-#2D695
2D696 CJK UNIFIED IDEOGRAPH-#2D696
2D697 CJK UNIFIED IDEOGRAPH-#2D697
2D698 CJK UNIFIED IDEOGRAPH-#2D698
2D699 CJK UNIFIED IDEOGRAPH-#2D699
2D69A CJK UNIFIED IDEOGRAPH-#2D69A
2D69B CJK UNIFIED IDEOGRAPH-#2D69B
2D69C CJK UNIFIED IDEOGRAPH-#2D69C
2D69D CJK UNIFIED IDEOGRAPH-#2D69D
2D69E CJK UNIFIED IDEOGRAPH-#2D69E
2D69F CJK UNIFIED IDEOGRAPH-#2D69F
2D6A0 CJK UNIFIED IDEOGRAPH-#2D6A0
2D6A1 CJK UNIFIED IDEOGRAPH-#2D6A1
2D6A2 CJK UNIFIED IDEOGRAPH-#2D6A2
2D6A3 CJK UNIFIED IDEOGRAPH-#2D6A3
2D6A4 CJK UNIFIED IDEOGRAPH-#2D6A4
2D6A5 CJK UNIFIED IDEOGRAPH-#2D6A5
2D6A6 CJK UNIFIED IDEOGRAPH-#2D6A6
2D6A7 CJK UNIFIED IDEOGRAPH-#2D6A7
2D6A8 CJK UNIFIED IDEOGRAPH-#2D6A8
2D6A9 CJK UNIFIED IDEOGRAPH-#2D6A9
2D6AA CJK UNIFIED IDEOGRAPH-#2D6AA
2D6AB CJK UNIFIED IDEOGRAPH-#2D6AB
2D6AC CJK UNIFIED IDEOGRAPH-#2D6AC
2D6AD CJK UNIFIED IDEOGRAPH-#2D6AD
2D6AE CJK UNIFIED IDEOGRAPH-#2D6AE
2D6AF CJK UNIFIED IDEOGRAPH-#2D6AF
2D6B0 CJK UNIFIED IDEOGRAPH-#2D6B0
2D6B1 CJK UNIFIED IDEOGRAPH-#2D6B1
2D6B2 CJK UNIFIED IDEOGRAPH-#2D6B2
2D6B3 CJK UNIFIED IDEOGRAPH-#2D6B3
2D6B4 CJK UNIFIED IDEOGRAPH-#2D6B4
2D6B5 CJK UNIFIED IDEOGRAPH-#2D6B5
2D6B6 CJK UNIFIED IDEOGRAPH-#2D6B6
2D6B7 CJK UNIFIED IDEOGRAPH-#2D6B7
2D6B8 CJK UNIFIED IDEOGRAPH-#2D6B8
2D6B9 CJK UNIFIED IDEOGRAPH-#2D6B9
2D6BA CJK UNIFIED IDEOGRAPH-#2D6BA
2D6BB CJK UNIFIED IDEOGRAPH-#2D6BB
2D6BC CJK UNIFIED IDEOGRAPH-#2D6BC
2D6BD CJK UNIFIED IDEOGRAPH-#2D6BD
2D6BE CJK UNIFIED IDEOGRAPH-#2D6BE
2D6BF CJK UNIFIED IDEOGRAPH-#2D6BF
2D6C0 CJK UNIFIED IDEOGRAPH-#2D6C0
2D6C1 CJK UNIFIED IDEOGRAPH-#2D6C1
2D6C2 CJK UNIFIED IDEOGRAPH-#2D6C2
2D6C3 CJK UNIFIED IDEOGRAPH-#2D6C3
2D6C4 CJK UNIFIED IDEOGRAPH-#2D6C4
2D6C5 CJK UNIFIED IDEOGRAPH-#2D6C5
2D6C6 CJK UNIFIED IDEOGRAPH-#2D6C6
2D6C7 CJK UNIFIED IDEOGRAPH-#2D6C7
2D6C8 CJK UNIFIED IDEOGRAPH-#2D6C8
2D6C9 CJK UNIFIED IDEOGRAPH-#2D6C9
2D6CA CJK UNIFIED IDEOGRAPH-#2D6CA
2D6CB CJK UNIFIED IDEOGRAPH-#2D6CB
2D6CC CJK UNIFIED IDEOGRAPH-#2D6CC
2D6CD CJK UNIFIED IDEOGRAPH-#2D6CD
2D6CE CJK UNIFIED IDEOGRAPH-#2D6CE
2D6CF CJK UNIFIED IDEOGRAPH-#2D6CF
2D6D0 CJK UNIFIED IDEOGRAPH-#2D6D0
2D6D1 CJK UNIFIED IDEOGRAPH-#2D6D1
2D6D2 CJK UNIFIED IDEOGRAPH-#2D6D2
2D6D3 CJK UNIFIED IDEOGRAPH-#2D6D3
2D6D4 CJK UNIFIED IDEOGRAPH-#2D6D4
2D6D5 CJK UNIFIED IDEOGRAPH-#2D6D5
2D6D6 CJK UNIFIED IDEOGRAPH-#2D6D6
2D6D7 CJK UNIFIED IDEOGRAPH-#2D6D7
2D6D8 CJK UNIFIED IDEOGRAPH-#2D6D8
2D6D9 CJK UNIFIED IDEOGRAPH-#2D6D9
2D6DA CJK UNIFIED IDEOGRAPH-#2D6DA
2D6DB CJK UNIFIED IDEOGRAPH-#2D6DB
2D6DC CJK UNIFIED IDEOGRAPH-#2D6DC
2D6DD CJK UNIFIED IDEOGRAPH-#2D6DD
2D6DE CJK UNIFIED IDEOGRAPH-#2D6DE
2D6DF CJK UNIFIED IDEOGRAPH-#2D6DF
2D6E0 CJK UNIFIED IDEOGRAPH-#2D6E0
2D6E1 CJK UNIFIED IDEOGRAPH-#2D6E1
2D6E2 CJK UNIFIED IDEOGRAPH-#2D6E2
2D6E3 CJK UNIFIED IDEOGRAPH-#2D6E3
2D6E4 CJK UNIFIED IDEOGRAPH-#2D6E4
2D6E5 CJK UNIFIED IDEOGRAPH-#2D6E5
2D6E6 CJK UNIFIED IDEOGRAPH-#2D6E6
2D6E7 CJK UNIFIED IDEOGRAPH-#2D6E7
2D6E8 CJK UNIFIED IDEOGRAPH-#2D6E8
2D6E9 CJK UNIFIED IDEOGRAPH-#2D6E9
2D6EA CJK UNIFIED IDEOGRAPH-#2D6EA
2D6EB CJK UNIFIED IDEOGRAPH-#2D6EB
2D6EC CJK UNIFIED IDEOGRAPH-#2D6EC
2D6ED CJK UNIFIED IDEOGRAPH-#2D6ED
2D6EE CJK UNIFIED IDEOGRAPH-#2D6EE
2D6EF CJK UNIFIED IDEOGRAPH-#2D6EF
2D6F0 CJK UNIFIED IDEOGRAPH-#2D6F0
2D6F1 CJK UNIFIED IDEOGRAPH-#2D6F1
2D6F2 CJK UNIFIED IDEOGRAPH-#2D6F2
2D6F3 CJK UNIFIED IDEOGRAPH-#2D6F3
2D6F4 CJK UNIFIED IDEOGRAPH-#2D6F4
2D6F5 CJK UNIFIED IDEOGRAPH-#2D6F5
2D6F6 CJK UNIFIED IDEOGRAPH-#2D6F6
2D6F7 CJK UNIFIED IDEOGRAPH-#2D6F7
2D6F8 CJK UNIFIED IDEOGRAPH-#2D6F8
2D6F9 CJK UNIFIED IDEOGRAPH-#2D6F9
2D6FA CJK UNIFIED IDEOGRAPH-#2D6FA
2D6FB CJK UNIFIED IDEOGRAPH-#2D6FB
2D6FC CJK UNIFIED IDEOGRAPH-#2D6FC
2D6FD CJK UNIFIED IDEOGRAPH-#2D6FD
2D6FE CJK UNIFIED IDEOGRAPH-#2D6FE
2D6FF CJK UNIFIED IDEOGRAPH-#2D6FF
2D700 CJK UNIFIED IDEOGRAPH-#2D700
2D701 CJK UNIFIED IDEOGRAPH-#2D701
2D702 CJK UNIFIED IDEOGRAPH-#2D702
2D703 CJK UNIFIED IDEOGRAPH-#2D703
2D704 CJK UNIFIED IDEOGRAPH-#2D704
2D705 CJK UNIFIED IDEOGRAPH-#2D705
2D706 CJK UNIFIED IDEOGRAPH-#2D706
2D707 CJK UNIFIED IDEOGRAPH-#2D707
2D708 CJK UNIFIED IDEOGRAPH-#2D708
2D709 CJK UNIFIED IDEOGRAPH-#2D709
2D70A CJK UNIFIED IDEOGRAPH-#2D70A
2D70B CJK UNIFIED IDEOGRAPH-#2D70B
2D70C CJK UNIFIED IDEOGRAPH-#2D70C
2D70D CJK UNIFIED IDEOGRAPH-#2D70D
2D70E CJK UNIFIED IDEOGRAPH-#2D70E
2D70F CJK UNIFIED IDEOGRAPH-#2D70F
2D710 CJK UNIFIED IDEOGRAPH-#2D710
2D711 CJK UNIFIED IDEOGRAPH-#2D711
2D712 CJK UNIFIED IDEOGRAPH-#2D712
2D713 CJK UNIFIED IDEOGRAPH-#2D713
2D714 CJK UNIFIED IDEOGRAPH-#2D714
2D715 CJK UNIFIED IDEOGRAPH-#2D715
2D716 CJK UNIFIED IDEOGRAPH-#2D716
2D717 CJK UNIFIED IDEOGRAPH-#2D717
2D718 CJK UNIFIED IDEOGRAPH-#2D718
2D719 CJK UNIFIED IDEOGRAPH-#2D719
2D71A CJK UNIFIED IDEOGRAPH-#2D71A
2D71B CJK UNIFIED IDEOGRAPH-#2D71B
2D71C CJK UNIFIED IDEOGRAPH-#2D71C
2D71D CJK UNIFIED IDEOGRAPH-#2D71D
2D71E CJK UNIFIED IDEOGRAPH-#2D71E
2D71F CJK UNIFIED IDEOGRAPH-#2D71F
2D720 CJK UNIFIED IDEOGRAPH-#2D720
2D721 CJK UNIFIED IDEOGRAPH-#2D721
2D722 CJK UNIFIED IDEOGRAPH-#2D722
2D723 CJK UNIFIED IDEOGRAPH-#2D723
2D724 CJK UNIFIED IDEOGRAPH-#2D724
2D725 CJK UNIFIED IDEOGRAPH-#2D725
2D726 CJK UNIFIED IDEOGRAPH-#2D726
2D727 CJK UNIFIED IDEOGRAPH-#2D727
2D728 CJK UNIFIED IDEOGRAPH-#2D728
2D729 CJK UNIFIED IDEOGRAPH-#2D729
2D72A CJK UNIFIED IDEOGRAPH-#2D72A
2D72B CJK UNIFIED IDEOGRAPH-#2D72B
2D72C CJK UNIFIED IDEOGRAPH-#2D72C
2D72D CJK UNIFIED IDEOGRAPH-#2D72D
2D72E CJK UNIFIED IDEOGRAPH-#2D72E
2D72F CJK UNIFIED IDEOGRAPH-#2D72F
2D730 CJK UNIFIED IDEOGRAPH-#2D730
2D731 CJK UNIFIED IDEOGRAPH-#2D731
2D732 CJK UNIFIED IDEOGRAPH-#2D732
2D733 CJK UNIFIED IDEOGRAPH-#2D733
2D734 CJK UNIFIED IDEOGRAPH-#2D734
2D735 CJK UNIFIED IDEOGRAPH-#2D735
2D736 CJK UNIFIED IDEOGRAPH-#2D736
2D737 CJK UNIFIED IDEOGRAPH-#2D737
2D738 CJK UNIFIED IDEOGRAPH-#2D738
2D739 CJK UNIFIED IDEOGRAPH-#2D739
2D73A CJK UNIFIED IDEOGRAPH-#2D73A
2D73B CJK UNIFIED IDEOGRAPH-#2D73B
2D73C CJK UNIFIED IDEOGRAPH-#2D73C
2D73D CJK UNIFIED IDEOGRAPH-#2D73D
2D73E CJK UNIFIED IDEOGRAPH-#2D73E
2D73F CJK UNIFIED IDEOGRAPH-#2D73F
2D740 CJK UNIFIED IDEOGRAPH-#2D740
2D741 CJK UNIFIED IDEOGRAPH-#2D741
2D742 CJK UNIFIED IDEOGRAPH-#2D742
2D743 CJK UNIFIED IDEOGRAPH-#2D743
2D744 CJK UNIFIED IDEOGRAPH-#2D744
2D745 CJK UNIFIED IDEOGRAPH-#2D745
2D746 CJK UNIFIED IDEOGRAPH-#2D746
2D747 CJK UNIFIED IDEOGRAPH-#2D747
2D748 CJK UNIFIED IDEOGRAPH-#2D748
2D749 CJK UNIFIED IDEOGRAPH-#2D749
2D74A CJK UNIFIED IDEOGRAPH-#2D74A
2D74B CJK UNIFIED IDEOGRAPH-#2D74B
2D74C CJK UNIFIED IDEOGRAPH-#2D74C
2D74D CJK UNIFIED IDEOGRAPH-#2D74D
2D74E CJK UNIFIED IDEOGRAPH-#2D74E
2D74F CJK UNIFIED IDEOGRAPH-#2D74F
2D750 CJK UNIFIED IDEOGRAPH-#2D750
2D751 CJK UNIFIED IDEOGRAPH-#2D751
2D752 CJK UNIFIED IDEOGRAPH-#2D752
2D753 CJK UNIFIED IDEOGRAPH-#2D753
2D754 CJK UNIFIED IDEOGRAPH-#2D754
2D755 CJK UNIFIED IDEOGRAPH-#2D755
2D756 CJK UNIFIED IDEOGRAPH-#2D756
2D757 CJK UNIFIED IDEOGRAPH-#2D757
2D758 CJK UNIFIED IDEOGRAPH-#2D758
2D759 CJK UNIFIED IDEOGRAPH-#2D759
2D75A CJK UNIFIED IDEOGRAPH-#2D75A
2D75B CJK UNIFIED IDEOGRAPH-#2D75B
2D75C CJK UNIFIED IDEOGRAPH-#2D75C
2D75D CJK UNIFIED IDEOGRAPH-#2D75D
2D75E CJK UNIFIED IDEOGRAPH-#2D75E
2D75F CJK UNIFIED IDEOGRAPH-#2D75F
2D760 CJK UNIFIED IDEOGRAPH-#2D760
2D761 CJK UNIFIED IDEOGRAPH-#2D761
2D762 CJK UNIFIED IDEOGRAPH-#2D762
2D763 CJK UNIFIED IDEOGRAPH-#2D763
2D764 CJK UNIFIED IDEOGRAPH-#2D764
2D765 CJK UNIFIED IDEOGRAPH-#2D765
2D766 CJK UNIFIED IDEOGRAPH-#2D766
2D767 CJK UNIFIED IDEOGRAPH-#2D767
2D768 CJK UNIFIED IDEOGRAPH-#2D768
2D769 CJK UNIFIED IDEOGRAPH-#2D769
2D76A CJK UNIFIED IDEOGRAPH-#2D76A
2D76B CJK UNIFIED IDEOGRAPH-#2D76B
2D76C CJK UNIFIED IDEOGRAPH-#2D76C
2D76D CJK UNIFIED IDEOGRAPH-#2D76D
2D76E CJK UNIFIED IDEOGRAPH-#2D76E
2D76F CJK UNIFIED IDEOGRAPH-#2D76F
2D770 CJK UNIFIED IDEOGRAPH-#2D770
2D771 CJK UNIFIED IDEOGRAPH-#2D771
2D772 CJK UNIFIED IDEOGRAPH-#2D772
2D773 CJK UNIFIED IDEOGRAPH-#2D773
2D774 CJK UNIFIED IDEOGRAPH-#2D774
2D775 CJK UNIFIED IDEOGRAPH-#2D775
2D776 CJK UNIFIED IDEOGRAPH-#2D776
2D777 CJK UNIFIED IDEOGRAPH-#2D777
2D778 CJK UNIFIED IDEOGRAPH-#2D778
2D779 CJK UNIFIED IDEOGRAPH-#2D779
2D77A CJK UNIFIED IDEOGRAPH-#2D77A
2D77B CJK UNIFIED IDEOGRAPH-#2D77B
2D77C CJK UNIFIED IDEOGRAPH-#2D77C
2D77D CJK UNIFIED IDEOGRAPH-#2D77D
2D77E CJK UNIFIED IDEOGRAPH-#2D77E
2D77F CJK UNIFIED IDEOGRAPH-#2D77F
2D780 CJK UNIFIED IDEOGRAPH-#2D780
2D781 CJK UNIFIED IDEOGRAPH-#2D781
2D782 CJK UNIFIED IDEOGRAPH-#2D782
2D783 CJK UNIFIED IDEOGRAPH-#2D783
2D784 CJK UNIFIED IDEOGRAPH-#2D784
2D785 CJK UNIFIED IDEOGRAPH-#2D785
2D786 CJK UNIFIED IDEOGRAPH-#2D786
2D787 CJK UNIFIED IDEOGRAPH-#2D787
2D788 CJK UNIFIED IDEOGRAPH-#2D788
2D789 CJK UNIFIED IDEOGRAPH-#2D789
2D78A CJK UNIFIED IDEOGRAPH-#2D78A
2D78B CJK UNIFIED IDEOGRAPH-#2D78B
2D78C CJK UNIFIED IDEOGRAPH-#2D78C
2D78D CJK UNIFIED IDEOGRAPH-#2D78D
2D78E CJK UNIFIED IDEOGRAPH-#2D78E
2D78F CJK UNIFIED IDEOGRAPH-#2D78F
2D790 CJK UNIFIED IDEOGRAPH-#2D790
2D791 CJK UNIFIED IDEOGRAPH-#2D791
2D792 CJK UNIFIED IDEOGRAPH-#2D792
2D793 CJK UNIFIED IDEOGRAPH-#2D793
2D794 CJK UNIFIED IDEOGRAPH-#2D794
2D795 CJK UNIFIED IDEOGRAPH-#2D795
2D796 CJK UNIFIED IDEOGRAPH-#2D796
2D797 CJK UNIFIED IDEOGRAPH-#2D797
2D798 CJK UNIFIED IDEOGRAPH-#2D798
2D799 CJK UNIFIED IDEOGRAPH-#2D799
2D79A CJK UNIFIED IDEOGRAPH-#2D79A
2D79B CJK UNIFIED IDEOGRAPH-#2D79B
2D79C CJK UNIFIED IDEOGRAPH-#2D79C
2D79D CJK UNIFIED IDEOGRAPH-#2D79D
2D79E CJK UNIFIED IDEOGRAPH-#2D79E
2D79F CJK UNIFIED IDEOGRAPH-#2D79F
2D7A0 CJK UNIFIED IDEOGRAPH-#2D7A0
2D7A1 CJK UNIFIED IDEOGRAPH-#2D7A1
2D7A2 CJK UNIFIED IDEOGRAPH-#2D7A2
2D7A3 CJK UNIFIED IDEOGRAPH-#2D7A3
2D7A4 CJK UNIFIED IDEOGRAPH-#2D7A4
2D7A5 CJK UNIFIED IDEOGRAPH-#2D7A5
2D7A6 CJK UNIFIED IDEOGRAPH-#2D7A6
2D7A7 CJK UNIFIED IDEOGRAPH-#2D7A7
2D7A8 CJK UNIFIED IDEOGRAPH-#2D7A8
2D7A9 CJK UNIFIED IDEOGRAPH-#2D7A9
2D7AA CJK UNIFIED IDEOGRAPH-#2D7AA
2D7AB CJK UNIFIED IDEOGRAPH-#2D7AB
2D7AC CJK UNIFIED IDEOGRAPH-#2D7AC
2D7AD CJK UNIFIED IDEOGRAPH-#2D7AD
2D7AE CJK UNIFIED IDEOGRAPH-#2D7AE
2D7AF CJK UNIFIED IDEOGRAPH-#2D7AF
2D7B0 CJK UNIFIED IDEOGRAPH-#2D7B0
2D7B1 CJK UNIFIED IDEOGRAPH-#2D7B1
2D7B2 CJK UNIFIED IDEOGRAPH-#2D7B2
2D7B3 CJK UNIFIED IDEOGRAPH-#2D7B3
2D7B4 CJK UNIFIED IDEOGRAPH-#2D7B4
2D7B5 CJK UNIFIED IDEOGRAPH-#2D7B5
2D7B6 CJK UNIFIED IDEOGRAPH-#2D7B6
2D7B7 CJK UNIFIED IDEOGRAPH-#2D7B7
2D7B8 CJK UNIFIED IDEOGRAPH-#2D7B8
2D7B9 CJK UNIFIED IDEOGRAPH-#2D7B9
2D7BA CJK UNIFIED IDEOGRAPH-#2D7BA
2D7BB CJK UNIFIED IDEOGRAPH-#2D7BB
2D7BC CJK UNIFIED IDEOGRAPH-#2D7BC
2D7BD CJK UNIFIED IDEOGRAPH-#2D7BD
2D7BE CJK UNIFIED IDEOGRAPH-#2D7BE
2D7BF CJK UNIFIED IDEOGRAPH-#2D7BF
2D7C0 CJK UNIFIED IDEOGRAPH-#2D7C0
2D7C1 CJK UNIFIED IDEOGRAPH-#2D7C1
2D7C2 CJK UNIFIED IDEOGRAPH-#2D7C2
2D7C3 CJK UNIFIED IDEOGRAPH-#2D7C3
2D7C4 CJK UNIFIED IDEOGRAPH-#2D7C4
2D7C5 CJK UNIFIED IDEOGRAPH-#2D7C5
2D7C6 CJK UNIFIED IDEOGRAPH-#2D7C6
2D7C7 CJK UNIFIED IDEOGRAPH-#2D7C7
2D7C8 CJK UNIFIED IDEOGRAPH-#2D7C8
2D7C9 CJK UNIFIED IDEOGRAPH-#2D7C9
2D7CA CJK UNIFIED IDEOGRAPH-#2D7CA
2D7CB CJK UNIFIED IDEOGRAPH-#2D7CB
2D7CC CJK UNIFIED IDEOGRAPH-#2D7CC
2D7CD CJK UNIFIED IDEOGRAPH-#2D7CD
2D7CE CJK UNIFIED IDEOGRAPH-#2D7CE
2D7CF CJK UNIFIED IDEOGRAPH-#2D7CF
2D7D0 CJK UNIFIED IDEOGRAPH-#2D7D0
2D7D1 CJK UNIFIED IDEOGRAPH-#2D7D1
2D7D2 CJK UNIFIED IDEOGRAPH-#2D7D2
2D7D3 CJK UNIFIED IDEOGRAPH-#2D7D3
2D7D4 CJK UNIFIED IDEOGRAPH-#2D7D4
2D7D5 CJK UNIFIED IDEOGRAPH-#2D7D5
2D7D6 CJK UNIFIED IDEOGRAPH-#2D7D6
2D7D7 CJK UNIFIED IDEOGRAPH-#2D7D7
2D7D8 CJK UNIFIED IDEOGRAPH-#2D7D8
2D7D9 CJK UNIFIED IDEOGRAPH-#2D7D9
2D7DA CJK UNIFIED IDEOGRAPH-#2D7DA
2D7DB CJK UNIFIED IDEOGRAPH-#2D7DB
2D7DC CJK UNIFIED IDEOGRAPH-#2D7DC
2D7DD CJK UNIFIED IDEOGRAPH-#2D7DD
2D7DE CJK UNIFIED IDEOGRAPH-#2D7DE
2D7DF CJK UNIFIED IDEOGRAPH-#2D7DF
2D7E0 CJK UNIFIED IDEOGRAPH-#2D7E0
2D7E1 CJK UNIFIED IDEOGRAPH-#2D7E1
2D7E2 CJK UNIFIED IDEOGRAPH-#2D7E2
2D7E3 CJK UNIFIED IDEOGRAPH-#2D7E3
2D7E4 CJK UNIFIED IDEOGRAPH-#2D7E4
2D7E5 CJK UNIFIED IDEOGRAPH-#2D7E5
2D7E6 CJK UNIFIED IDEOGRAPH-#2D7E6
2D7E7 CJK UNIFIED IDEOGRAPH-#2D7E7
2D7E8 CJK UNIFIED IDEOGRAPH-#2D7E8
2D7E9 CJK UNIFIED IDEOGRAPH-#2D7E9
2D7EA CJK UNIFIED IDEOGRAPH-#2D7EA
2D7EB CJK UNIFIED IDEOGRAPH-#2D7EB
2D7EC CJK UNIFIED IDEOGRAPH-#2D7EC
2D7ED CJK UNIFIED IDEOGRAPH-#2D7ED
2D7EE CJK UNIFIED IDEOGRAPH-#2D7EE
2D7EF CJK UNIFIED IDEOGRAPH-#2D7EF
2D7F0 CJK UNIFIED IDEOGRAPH-#2D7F0
2D7F1 CJK UNIFIED IDEOGRAPH-#2D7F1
2D7F2 CJK UNIFIED IDEOGRAPH-#2D7F2
2D7F3 CJK UNIFIED IDEOGRAPH-#2D7F3
2D7F4 CJK UNIFIED IDEOGRAPH-#2D7F4
2D7F5 CJK UNIFIED IDEOGRAPH-#2D7F5
2D7F6 CJK UNIFIED IDEOGRAPH-#2D7F6
2D7F7 CJK UNIFIED IDEOGRAPH-#2D7F7
2D7F8 CJK UNIFIED IDEOGRAPH-#2D7F8
2D7F9 CJK UNIFIED IDEOGRAPH-#2D7F9
2D7FA CJK UNIFIED IDEOGRAPH-#2D7FA
2D7FB CJK UNIFIED IDEOGRAPH-#2D7FB
2D7FC CJK UNIFIED IDEOGRAPH-#2D7FC
2D7FD CJK UNIFIED IDEOGRAPH-#2D7FD
2D7FE CJK UNIFIED IDEOGRAPH-#2D7FE
2D7FF CJK UNIFIED IDEOGRAPH-#2D7FF
2D800 CJK UNIFIED IDEOGRAPH-#2D800
2D801 CJK UNIFIED IDEOGRAPH-#2D801
2D802 CJK UNIFIED IDEOGRAPH-#2D802
2D803 CJK UNIFIED IDEOGRAPH-#2D803
2D804 CJK UNIFIED IDEOGRAPH-#2D804
2D805 CJK UNIFIED IDEOGRAPH-#2D805
2D806 CJK UNIFIED IDEOGRAPH-#2D806
2D807 CJK UNIFIED IDEOGRAPH-#2D807
2D808 CJK UNIFIED IDEOGRAPH-#2D808
2D809 CJK UNIFIED IDEOGRAPH-#2D809
2D80A CJK UNIFIED IDEOGRAPH-#2D80A
2D80B CJK UNIFIED IDEOGRAPH-#2D80B
2D80C CJK UNIFIED IDEOGRAPH-#2D80C
2D80D CJK UNIFIED IDEOGRAPH-#2D80D
2D80E CJK UNIFIED IDEOGRAPH-#2D80E
2D80F CJK UNIFIED IDEOGRAPH-#2D80F
2D810 CJK UNIFIED IDEOGRAPH-#2D810
2D811 CJK UNIFIED IDEOGRAPH-#2D811
2D812 CJK UNIFIED IDEOGRAPH-#2D812
2D813 CJK UNIFIED IDEOGRAPH-#2D813
2D814 CJK UNIFIED IDEOGRAPH-#2D814
2D815 CJK UNIFIED IDEOGRAPH-#2D815
2D816 CJK UNIFIED IDEOGRAPH-#2D816
2D817 CJK UNIFIED IDEOGRAPH-#2D817
2D818 CJK UNIFIED IDEOGRAPH-#2D818
2D819 CJK UNIFIED IDEOGRAPH-#2D819
2D81A CJK UNIFIED IDEOGRAPH-#2D81A
2D81B CJK UNIFIED IDEOGRAPH-#2D81B
2D81C CJK UNIFIED IDEOGRAPH-#2D81C
2D81D CJK UNIFIED IDEOGRAPH-#2D81D
2D81E CJK UNIFIED IDEOGRAPH-#2D81E
2D81F CJK UNIFIED IDEOGRAPH-#2D81F
2D820 CJK UNIFIED IDEOGRAPH-#2D820
2D821 CJK UNIFIED IDEOGRAPH-#2D821
2D822 CJK UNIFIED IDEOGRAPH-#2D822
2D823 CJK UNIFIED IDEOGRAPH-#2D823
2D824 CJK UNIFIED IDEOGRAPH-#2D824
2D825 CJK UNIFIED IDEOGRAPH-#2D825
2D826 CJK UNIFIED IDEOGRAPH-#2D826
2D827 CJK UNIFIED IDEOGRAPH-#2D827
2D828 CJK UNIFIED IDEOGRAPH-#2D828
2D829 CJK UNIFIED IDEOGRAPH-#2D829
2D82A CJK UNIFIED IDEOGRAPH-#2D82A
2D82B CJK UNIFIED IDEOGRAPH-#2D82B
2D82C CJK UNIFIED IDEOGRAPH-#2D82C
2D82D CJK UNIFIED IDEOGRAPH-#2D82D
2D82E CJK UNIFIED IDEOGRAPH-#2D82E
2D82F CJK UNIFIED IDEOGRAPH-#2D82F
2D830 CJK UNIFIED IDEOGRAPH-#2D830
2D831 CJK UNIFIED IDEOGRAPH-#2D831
2D832 CJK UNIFIED IDEOGRAPH-#2D832
2D833 CJK UNIFIED IDEOGRAPH-#2D833
2D834 CJK UNIFIED IDEOGRAPH-#2D834
2D835 CJK UNIFIED IDEOGRAPH-#2D835
2D836 CJK UNIFIED IDEOGRAPH-#2D836
2D837 CJK UNIFIED IDEOGRAPH-#2D837
2D838 CJK UNIFIED IDEOGRAPH-#2D838
2D839 CJK UNIFIED IDEOGRAPH-#2D839
2D83A CJK UNIFIED IDEOGRAPH-#2D83A
2D83B CJK UNIFIED IDEOGRAPH-#2D83B
2D83C CJK UNIFIED IDEOGRAPH-#2D83C
2D83D CJK UNIFIED IDEOGRAPH-#2D83D
2D83E CJK UNIFIED IDEOGRAPH-#2D83E
2D83F CJK UNIFIED IDEOGRAPH-#2D83F
2D840 CJK UNIFIED IDEOGRAPH-#2D840
2D841 CJK UNIFIED IDEOGRAPH-#2D841
2D842 CJK UNIFIED IDEOGRAPH-#2D842
2D843 CJK UNIFIED IDEOGRAPH-#2D843
2D844 CJK UNIFIED IDEOGRAPH-#2D844
2D845 CJK UNIFIED IDEOGRAPH-#2D845
2D846 CJK UNIFIED IDEOGRAPH-#2D846
2D847 CJK UNIFIED IDEOGRAPH-#2D847
2D848 CJK UNIFIED IDEOGRAPH-#2D848
2D849 CJK UNIFIED IDEOGRAPH-#2D849
2D84A CJK UNIFIED IDEOGRAPH-#2D84A
2D84B CJK UNIFIED IDEOGRAPH-#2D84B
2D84C CJK UNIFIED IDEOGRAPH-#2D84C
2D84D CJK UNIFIED IDEOGRAPH-#2D84D
2D84E CJK UNIFIED IDEOGRAPH-#2D84E
2D84F CJK UNIFIED IDEOGRAPH-#2D84F
2D850 CJK UNIFIED IDEOGRAPH-#2D850
2D851 CJK UNIFIED IDEOGRAPH-#2D851
2D852 CJK UNIFIED IDEOGRAPH-#2D852
2D853 CJK UNIFIED IDEOGRAPH-#2D853
2D854 CJK UNIFIED IDEOGRAPH-#2D854
2D855 CJK UNIFIED IDEOGRAPH-#2D855
2D856 CJK UNIFIED IDEOGRAPH-#2D856
2D857 CJK UNIFIED IDEOGRAPH-#2D857
2D858 CJK UNIFIED IDEOGRAPH-#2D858
2D859 CJK UNIFIED IDEOGRAPH-#2D859
2D85A CJK UNIFIED IDEOGRAPH-#2D85A
2D85B CJK UNIFIED IDEOGRAPH-#2D85B
2D85C CJK UNIFIED IDEOGRAPH-#2D85C
2D85D CJK UNIFIED IDEOGRAPH-#2D85D
2D85E CJK UNIFIED IDEOGRAPH-#2D85E
2D85F CJK UNIFIED IDEOGRAPH-#2D85F
2D860 CJK UNIFIED IDEOGRAPH-#2D860
2D861 CJK UNIFIED IDEOGRAPH-#2D861
2D862 CJK UNIFIED IDEOGRAPH-#2D862
2D863 CJK UNIFIED IDEOGRAPH-#2D863
2D864 CJK UNIFIED IDEOGRAPH-#2D864
2D865 CJK UNIFIED IDEOGRAPH-#2D865
2D866 CJK UNIFIED IDEOGRAPH-#2D866
2D867 CJK UNIFIED IDEOGRAPH-#2D867
2D868 CJK UNIFIED IDEOGRAPH-#2D868
2D869 CJK UNIFIED IDEOGRAPH-#2D869
2D86A CJK UNIFIED IDEOGRAPH-#2D86A
2D86B CJK UNIFIED IDEOGRAPH-#2D86B
2D86C CJK UNIFIED IDEOGRAPH-#2D86C
2D86D CJK UNIFIED IDEOGRAPH-#2D86D
2D86E CJK UNIFIED IDEOGRAPH-#2D86E
2D86F CJK UNIFIED IDEOGRAPH-#2D86F
2D870 CJK UNIFIED IDEOGRAPH-#2D870
2D871 CJK UNIFIED IDEOGRAPH-#2D871
2D872 CJK UNIFIED IDEOGRAPH-#2D872
2D873 CJK UNIFIED IDEOGRAPH-#2D873
2D874 CJK UNIFIED IDEOGRAPH-#2D874
2D875 CJK UNIFIED IDEOGRAPH-#2D875
2D876 CJK UNIFIED IDEOGRAPH-#2D876
2D877 CJK UNIFIED IDEOGRAPH-#2D877
2D878 CJK UNIFIED IDEOGRAPH-#2D878
2D879 CJK UNIFIED IDEOGRAPH-#2D879
2D87A CJK UNIFIED IDEOGRAPH-#2D87A
2D87B CJK UNIFIED IDEOGRAPH-#2D87B
2D87C CJK UNIFIED IDEOGRAPH-#2D87C
2D87D CJK UNIFIED IDEOGRAPH-#2D87D
2D87E CJK UNIFIED IDEOGRAPH-#2D87E
2D87F CJK UNIFIED IDEOGRAPH-#2D87F
2D880 CJK UNIFIED IDEOGRAPH-#2D880
2D881 CJK UNIFIED IDEOGRAPH-#2D881
2D882 CJK UNIFIED IDEOGRAPH-#2D882
2D883 CJK UNIFIED IDEOGRAPH-#2D883
2D884 CJK UNIFIED IDEOGRAPH-#2D884
2D885 CJK UNIFIED IDEOGRAPH-#2D885
2D886 CJK UNIFIED IDEOGRAPH-#2D886
2D887 CJK UNIFIED IDEOGRAPH-#2D887
2D888 CJK UNIFIED IDEOGRAPH-#2D888
2D889 CJK UNIFIED IDEOGRAPH-#2D889
2D88A CJK UNIFIED IDEOGRAPH-#2D88A
2D88B CJK UNIFIED IDEOGRAPH-#2D88B
2D88C CJK UNIFIED IDEOGRAPH-#2D88C
2D88D CJK UNIFIED IDEOGRAPH-#2D88D
2D88E CJK UNIFIED IDEOGRAPH-#2D88E
2D88F CJK UNIFIED IDEOGRAPH-#2D88F
2D890 CJK UNIFIED IDEOGRAPH-#2D890
2D891 CJK UNIFIED IDEOGRAPH-#2D891
2D892 CJK UNIFIED IDEOGRAPH-#2D892
2D893 CJK UNIFIED IDEOGRAPH-#2D893
2D894 CJK UNIFIED IDEOGRAPH-#2D894
2D895 CJK UNIFIED IDEOGRAPH-#2D895
2D896 CJK UNIFIED IDEOGRAPH-#2D896
2D897 CJK UNIFIED IDEOGRAPH-#2D897
2D898 CJK UNIFIED IDEOGRAPH-#2D898
2D899 CJK UNIFIED IDEOGRAPH-#2D899
2D89A CJK UNIFIED IDEOGRAPH-#2D89A
2D89B CJK UNIFIED IDEOGRAPH-#2D89B
2D89C CJK UNIFIED IDEOGRAPH-#2D89C
2D89D CJK UNIFIED IDEOGRAPH-#2D89D
2D89E CJK UNIFIED IDEOGRAPH-#2D89E
2D89F CJK UNIFIED IDEOGRAPH-#2D89F
2D8A0 CJK UNIFIED IDEOGRAPH-#2D8A0
2D8A1 CJK UNIFIED IDEOGRAPH-#2D8A1
2D8A2 CJK UNIFIED IDEOGRAPH-#2D8A2
2D8A3 CJK UNIFIED IDEOGRAPH-#2D8A3
2D8A4 CJK UNIFIED IDEOGRAPH-#2D8A4
2D8A5 CJK UNIFIED IDEOGRAPH-#2D8A5
2D8A6 CJK UNIFIED IDEOGRAPH-#2D8A6
2D8A7 CJK UNIFIED IDEOGRAPH-#2D8A7
2D8A8 CJK UNIFIED IDEOGRAPH-#2D8A8
2D8A9 CJK UNIFIED IDEOGRAPH-#2D8A9
2D8AA CJK UNIFIED IDEOGRAPH-#2D8AA
2D8AB CJK UNIFIED IDEOGRAPH-#2D8AB
2D8AC CJK UNIFIED IDEOGRAPH-#2D8AC
2D8AD CJK UNIFIED IDEOGRAPH-#2D8AD
2D8AE CJK UNIFIED IDEOGRAPH-#2D8AE
2D8AF CJK UNIFIED IDEOGRAPH-#2D8AF
2D8B0 CJK UNIFIED IDEOGRAPH-#2D8B0
2D8B1 CJK UNIFIED IDEOGRAPH-#2D8B1
2D8B2 CJK UNIFIED IDEOGRAPH-#2D8B2
2D8B3 CJK UNIFIED IDEOGRAPH-#2D8B3
2D8B4 CJK UNIFIED IDEOGRAPH-#2D8B4
2D8B5 CJK UNIFIED IDEOGRAPH-#2D8B5
2D8B6 CJK UNIFIED IDEOGRAPH-#2D8B6
2D8B7 CJK UNIFIED IDEOGRAPH-#2D8B7
2D8B8 CJK UNIFIED IDEOGRAPH-#2D8B8
2D8B9 CJK UNIFIED IDEOGRAPH-#2D8B9
2D8BA CJK UNIFIED IDEOGRAPH-#2D8BA
2D8BB CJK UNIFIED IDEOGRAPH-#2D8BB
2D8BC CJK UNIFIED IDEOGRAPH-#2D8BC
2D8BD CJK UNIFIED IDEOGRAPH-#2D8BD
2D8BE CJK UNIFIED IDEOGRAPH-#2D8BE
2D8BF CJK UNIFIED IDEOGRAPH-#2D8BF
2D8C0 CJK UNIFIED IDEOGRAPH-#2D8C0
2D8C1 CJK UNIFIED IDEOGRAPH-#2D8C1
2D8C2 CJK UNIFIED IDEOGRAPH-#2D8C2
2D8C3 CJK UNIFIED IDEOGRAPH-#2D8C3
2D8C4 CJK UNIFIED IDEOGRAPH-#2D8C4
2D8C5 CJK UNIFIED IDEOGRAPH-#2D8C5
2D8C6 CJK UNIFIED IDEOGRAPH-#2D8C6
2D8C7 CJK UNIFIED IDEOGRAPH-#2D8C7
2D8C8 CJK UNIFIED IDEOGRAPH-#2D8C8
2D8C9 CJK UNIFIED IDEOGRAPH-#2D8C9
2D8CA CJK UNIFIED IDEOGRAPH-#2D8CA
2D8CB CJK UNIFIED IDEOGRAPH-#2D8CB
2D8CC CJK UNIFIED IDEOGRAPH-#2D8CC
2D8CD CJK UNIFIED IDEOGRAPH-#2D8CD
2D8CE CJK UNIFIED IDEOGRAPH-#2D8CE
2D8CF CJK UNIFIED IDEOGRAPH-#2D8CF
2D8D0 CJK UNIFIED IDEOGRAPH-#2D8D0
2D8D1 CJK UNIFIED IDEOGRAPH-#2D8D1
2D8D2 CJK UNIFIED IDEOGRAPH-#2D8D2
2D8D3 CJK UNIFIED IDEOGRAPH-#2D8D3
2D8D4 CJK UNIFIED IDEOGRAPH-#2D8D4
2D8D5 CJK UNIFIED IDEOGRAPH-#2D8D5
2D8D6 CJK UNIFIED IDEOGRAPH-#2D8D6
2D8D7 CJK UNIFIED IDEOGRAPH-#2D8D7
2D8D8 CJK UNIFIED IDEOGRAPH-#2D8D8
2D8D9 CJK UNIFIED IDEOGRAPH-#2D8D9
2D8DA CJK UNIFIED IDEOGRAPH-#2D8DA
2D8DB CJK UNIFIED IDEOGRAPH-#2D8DB
2D8DC CJK UNIFIED IDEOGRAPH-#2D8DC
2D8DD CJK UNIFIED IDEOGRAPH-#2D8DD
2D8DE CJK UNIFIED IDEOGRAPH-#2D8DE
2D8DF CJK UNIFIED IDEOGRAPH-#2D8DF
2D8E0 CJK UNIFIED IDEOGRAPH-#2D8E0
2D8E1 CJK UNIFIED IDEOGRAPH-#2D8E1
2D8E2 CJK UNIFIED IDEOGRAPH-#2D8E2
2D8E3 CJK UNIFIED IDEOGRAPH-#2D8E3
2D8E4 CJK UNIFIED IDEOGRAPH-#2D8E4
2D8E5 CJK UNIFIED IDEOGRAPH-#2D8E5
2D8E6 CJK UNIFIED IDEOGRAPH-#2D8E6
2D8E7 CJK UNIFIED IDEOGRAPH-#2D8E7
2D8E8 CJK UNIFIED IDEOGRAPH-#2D8E8
2D8E9 CJK UNIFIED IDEOGRAPH-#2D8E9
2D8EA CJK UNIFIED IDEOGRAPH-#2D8EA
2D8EB CJK UNIFIED IDEOGRAPH-#2D8EB
2D8EC CJK UNIFIED IDEOGRAPH-#2D8EC
2D8ED CJK UNIFIED IDEOGRAPH-#2D8ED
2D8EE CJK UNIFIED IDEOGRAPH-#2D8EE
2D8EF CJK UNIFIED IDEOGRAPH-#2D8EF
2D8F0 CJK UNIFIED IDEOGRAPH-#2D8F0
2D8F1 CJK UNIFIED IDEOGRAPH-#2D8F1
2D8F2 CJK UNIFIED IDEOGRAPH-#2D8F2
2D8F3 CJK UNIFIED IDEOGRAPH-#2D8F3
2D8F4 CJK UNIFIED IDEOGRAPH-#2D8F4
2D8F5 CJK UNIFIED IDEOGRAPH-#2D8F5
2D8F6 CJK UNIFIED IDEOGRAPH-#2D8F6
2D8F7 CJK UNIFIED IDEOGRAPH-#2D8F7
2D8F8 CJK UNIFIED IDEOGRAPH-#2D8F8
2D8F9 CJK UNIFIED IDEOGRAPH-#2D8F9
2D8FA CJK UNIFIED IDEOGRAPH-#2D8FA
2D8FB CJK UNIFIED IDEOGRAPH-#2D8FB
2D8FC CJK UNIFIED IDEOGRAPH-#2D8FC
2D8FD CJK UNIFIED IDEOGRAPH-#2D8FD
2D8FE CJK UNIFIED IDEOGRAPH-#2D8FE
2D8FF CJK UNIFIED IDEOGRAPH-#2D8FF
2D900 CJK UNIFIED IDEOGRAPH-#2D900
2D901 CJK UNIFIED IDEOGRAPH-#2D901
2D902 CJK UNIFIED IDEOGRAPH-#2D902
2D903 CJK UNIFIED IDEOGRAPH-#2D903
2D904 CJK UNIFIED IDEOGRAPH-#2D904
2D905 CJK UNIFIED IDEOGRAPH-#2D905
2D906 CJK UNIFIED IDEOGRAPH-#2D906
2D907 CJK UNIFIED IDEOGRAPH-#2D907
2D908 CJK UNIFIED IDEOGRAPH-#2D908
2D909 CJK UNIFIED IDEOGRAPH-#2D909
2D90A CJK UNIFIED IDEOGRAPH-#2D90A
2D90B CJK UNIFIED IDEOGRAPH-#2D90B
2D90C CJK UNIFIED IDEOGRAPH-#2D90C
2D90D CJK UNIFIED IDEOGRAPH-#2D90D
2D90E CJK UNIFIED IDEOGRAPH-#2D90E
2D90F CJK UNIFIED IDEOGRAPH-#2D90F
2D910 CJK UNIFIED IDEOGRAPH-#2D910
2D911 CJK UNIFIED IDEOGRAPH-#2D911
2D912 CJK UNIFIED IDEOGRAPH-#2D912
2D913 CJK UNIFIED IDEOGRAPH-#2D913
2D914 CJK UNIFIED IDEOGRAPH-#2D914
2D915 CJK UNIFIED IDEOGRAPH-#2D915
2D916 CJK UNIFIED IDEOGRAPH-#2D916
2D917 CJK UNIFIED IDEOGRAPH-#2D917
2D918 CJK UNIFIED IDEOGRAPH-#2D918
2D919 CJK UNIFIED IDEOGRAPH-#2D919
2D91A CJK UNIFIED IDEOGRAPH-#2D91A
2D91B CJK UNIFIED IDEOGRAPH-#2D91B
2D91C CJK UNIFIED IDEOGRAPH-#2D91C
2D91D CJK UNIFIED IDEOGRAPH-#2D91D
2D91E CJK UNIFIED IDEOGRAPH-#2D91E
2D91F CJK UNIFIED IDEOGRAPH-#2D91F
2D920 CJK UNIFIED IDEOGRAPH-#2D920
2D921 CJK UNIFIED IDEOGRAPH-#2D921
2D922 CJK UNIFIED IDEOGRAPH-#2D922
2D923 CJK UNIFIED IDEOGRAPH-#2D923
2D924 CJK UNIFIED IDEOGRAPH-#2D924
2D925 CJK UNIFIED IDEOGRAPH-#2D925
2D926 CJK UNIFIED IDEOGRAPH-#2D926
2D927 CJK UNIFIED IDEOGRAPH-#2D927
2D928 CJK UNIFIED IDEOGRAPH-#2D928
2D929 CJK UNIFIED IDEOGRAPH-#2D929
2D92A CJK UNIFIED IDEOGRAPH-#2D92A
2D92B CJK UNIFIED IDEOGRAPH-#2D92B
2D92C CJK UNIFIED IDEOGRAPH-#2D92C
2D92D CJK UNIFIED IDEOGRAPH-#2D92D
2D92E CJK UNIFIED IDEOGRAPH-#2D92E
2D92F CJK UNIFIED IDEOGRAPH-#2D92F
2D930 CJK UNIFIED IDEOGRAPH-#2D930
2D931 CJK UNIFIED IDEOGRAPH-#2D931
2D932 CJK UNIFIED IDEOGRAPH-#2D932
2D933 CJK UNIFIED IDEOGRAPH-#2D933
2D934 CJK UNIFIED IDEOGRAPH-#2D934
2D935 CJK UNIFIED IDEOGRAPH-#2D935
2D936 CJK UNIFIED IDEOGRAPH-#2D936
2D937 CJK UNIFIED IDEOGRAPH-#2D937
2D938 CJK UNIFIED IDEOGRAPH-#2D938
2D939 CJK UNIFIED IDEOGRAPH-#2D939
2D93A CJK UNIFIED IDEOGRAPH-#2D93A
2D93B CJK UNIFIED IDEOGRAPH-#2D93B
2D93C CJK UNIFIED IDEOGRAPH-#2D93C
2D93D CJK UNIFIED IDEOGRAPH-#2D93D
2D93E CJK UNIFIED IDEOGRAPH-#2D93E
2D93F CJK UNIFIED IDEOGRAPH-#2D93F
2D940 CJK UNIFIED IDEOGRAPH-#2D940
2D941 CJK UNIFIED IDEOGRAPH-#2D941
2D942 CJK UNIFIED IDEOGRAPH-#2D942
2D943 CJK UNIFIED IDEOGRAPH-#2D943
2D944 CJK UNIFIED IDEOGRAPH-#2D944
2D945 CJK UNIFIED IDEOGRAPH-#2D945
2D946 CJK UNIFIED IDEOGRAPH-#2D946
2D947 CJK UNIFIED IDEOGRAPH-#2D947
2D948 CJK UNIFIED IDEOGRAPH-#2D948
2D949 CJK UNIFIED IDEOGRAPH-#2D949
2D94A CJK UNIFIED IDEOGRAPH-#2D94A
2D94B CJK UNIFIED IDEOGRAPH-#2D94B
2D94C CJK UNIFIED IDEOGRAPH-#2D94C
2D94D CJK UNIFIED IDEOGRAPH-#2D94D
2D94E CJK UNIFIED IDEOGRAPH-#2D94E
2D94F CJK UNIFIED IDEOGRAPH-#2D94F
2D950 CJK UNIFIED IDEOGRAPH-#2D950
2D951 CJK UNIFIED IDEOGRAPH-#2D951
2D952 CJK UNIFIED IDEOGRAPH-#2D952
2D953 CJK UNIFIED IDEOGRAPH-#2D953
2D954 CJK UNIFIED IDEOGRAPH-#2D954
2D955 CJK UNIFIED IDEOGRAPH-#2D955
2D956 CJK UNIFIED IDEOGRAPH-#2D956
2D957 CJK UNIFIED IDEOGRAPH-#2D957
2D958 CJK UNIFIED IDEOGRAPH-#2D958
2D959 CJK UNIFIED IDEOGRAPH-#2D959
2D95A CJK UNIFIED IDEOGRAPH-#2D95A
2D95B CJK UNIFIED IDEOGRAPH-#2D95B
2D95C CJK UNIFIED IDEOGRAPH-#2D95C
2D95D CJK UNIFIED IDEOGRAPH-#2D95D
2D95E CJK UNIFIED IDEOGRAPH-#2D95E
2D95F CJK UNIFIED IDEOGRAPH-#2D95F
2D960 CJK UNIFIED IDEOGRAPH-#2D960
2D961 CJK UNIFIED IDEOGRAPH-#2D961
2D962 CJK UNIFIED IDEOGRAPH-#2D962
2D963 CJK UNIFIED IDEOGRAPH-#2D963
2D964 CJK UNIFIED IDEOGRAPH-#2D964
2D965 CJK UNIFIED IDEOGRAPH-#2D965
2D966 CJK UNIFIED IDEOGRAPH-#2D966
2D967 CJK UNIFIED IDEOGRAPH-#2D967
2D968 CJK UNIFIED IDEOGRAPH-#2D968
2D969 CJK UNIFIED IDEOGRAPH-#2D969
2D96A CJK UNIFIED IDEOGRAPH-#2D96A
2D96B CJK UNIFIED IDEOGRAPH-#2D96B
2D96C CJK UNIFIED IDEOGRAPH-#2D96C
2D96D CJK UNIFIED IDEOGRAPH-#2D96D
2D96E CJK UNIFIED IDEOGRAPH-#2D96E
2D96F CJK UNIFIED IDEOGRAPH-#2D96F
2D970 CJK UNIFIED IDEOGRAPH-#2D970
2D971 CJK UNIFIED IDEOGRAPH-#2D971
2D972 CJK UNIFIED IDEOGRAPH-#2D972
2D973 CJK UNIFIED IDEOGRAPH-#2D973
2D974 CJK UNIFIED IDEOGRAPH-#2D974
2D975 CJK UNIFIED IDEOGRAPH-#2D975
2D976 CJK UNIFIED IDEOGRAPH-#2D976
2D977 CJK UNIFIED IDEOGRAPH-#2D977
2D978 CJK UNIFIED IDEOGRAPH-#2D978
2D979 CJK UNIFIED IDEOGRAPH-#2D979
2D97A CJK UNIFIED IDEOGRAPH-#2D97A
2D97B CJK UNIFIED IDEOGRAPH-#2D97B
2D97C CJK UNIFIED IDEOGRAPH-#2D97C
2D97D CJK UNIFIED IDEOGRAPH-#2D97D
2D97E CJK UNIFIED IDEOGRAPH-#2D97E
2D97F CJK UNIFIED IDEOGRAPH-#2D97F
2D980 CJK UNIFIED IDEOGRAPH-#2D980
2D981 CJK UNIFIED IDEOGRAPH-#2D981
2D982 CJK UNIFIED IDEOGRAPH-#2D982
2D983 CJK UNIFIED IDEOGRAPH-#2D983
2D984 CJK UNIFIED IDEOGRAPH-#2D984
2D985 CJK UNIFIED IDEOGRAPH-#2D985
2D986 CJK UNIFIED IDEOGRAPH-#2D986
2D987 CJK UNIFIED IDEOGRAPH-#2D987
2D988 CJK UNIFIED IDEOGRAPH-#2D988
2D989 CJK UNIFIED IDEOGRAPH-#2D989
2D98A CJK UNIFIED IDEOGRAPH-#2D98A
2D98B CJK UNIFIED IDEOGRAPH-#2D98B
2D98C CJK UNIFIED IDEOGRAPH-#2D98C
2D98D CJK UNIFIED IDEOGRAPH-#2D98D
2D98E CJK UNIFIED IDEOGRAPH-#2D98E
2D98F CJK UNIFIED IDEOGRAPH-#2D98F
2D990 CJK UNIFIED IDEOGRAPH-#2D990
2D991 CJK UNIFIED IDEOGRAPH-#2D991
2D992 CJK UNIFIED IDEOGRAPH-#2D992
2D993 CJK UNIFIED IDEOGRAPH-#2D993
2D994 CJK UNIFIED IDEOGRAPH-#2D994
2D995 CJK UNIFIED IDEOGRAPH-#2D995
2D996 CJK UNIFIED IDEOGRAPH-#2D996
2D997 CJK UNIFIED IDEOGRAPH-#2D997
2D998 CJK UNIFIED IDEOGRAPH-#2D998
2D999 CJK UNIFIED IDEOGRAPH-#2D999
2D99A CJK UNIFIED IDEOGRAPH-#2D99A
2D99B CJK UNIFIED IDEOGRAPH-#2D99B
2D99C CJK UNIFIED IDEOGRAPH-#2D99C
2D99D CJK UNIFIED IDEOGRAPH-#2D99D
2D99E CJK UNIFIED IDEOGRAPH-#2D99E
2D99F CJK UNIFIED IDEOGRAPH-#2D99F
2D9A0 CJK UNIFIED IDEOGRAPH-#2D9A0
2D9A1 CJK UNIFIED IDEOGRAPH-#2D9A1
2D9A2 CJK UNIFIED IDEOGRAPH-#2D9A2
2D9A3 CJK UNIFIED IDEOGRAPH-#2D9A3
2D9A4 CJK UNIFIED IDEOGRAPH-#2D9A4
2D9A5 CJK UNIFIED IDEOGRAPH-#2D9A5
2D9A6 CJK UNIFIED IDEOGRAPH-#2D9A6
2D9A7 CJK UNIFIED IDEOGRAPH-#2D9A7
2D9A8 CJK UNIFIED IDEOGRAPH-#2D9A8
2D9A9 CJK UNIFIED IDEOGRAPH-#2D9A9
2D9AA CJK UNIFIED IDEOGRAPH-#2D9AA
2D9AB CJK UNIFIED IDEOGRAPH-#2D9AB
2D9AC CJK UNIFIED IDEOGRAPH-#2D9AC
2D9AD CJK UNIFIED IDEOGRAPH-#2D9AD
2D9AE CJK UNIFIED IDEOGRAPH-#2D9AE
2D9AF CJK UNIFIED IDEOGRAPH-#2D9AF
2D9B0 CJK UNIFIED IDEOGRAPH-#2D9B0
2D9B1 CJK UNIFIED IDEOGRAPH-#2D9B1
2D9B2 CJK UNIFIED IDEOGRAPH-#2D9B2
2D9B3 CJK UNIFIED IDEOGRAPH-#2D9B3
2D9B4 CJK UNIFIED IDEOGRAPH-#2D9B4
2D9B5 CJK UNIFIED IDEOGRAPH-#2D9B5
2D9B6 CJK UNIFIED IDEOGRAPH-#2D9B6
2D9B7 CJK UNIFIED IDEOGRAPH-#2D9B7
2D9B8 CJK UNIFIED IDEOGRAPH-#2D9B8
2D9B9 CJK UNIFIED IDEOGRAPH-#2D9B9
2D9BA CJK UNIFIED IDEOGRAPH-#2D9BA
2D9BB CJK UNIFIED IDEOGRAPH-#2D9BB
2D9BC CJK UNIFIED IDEOGRAPH-#2D9BC
2D9BD CJK UNIFIED IDEOGRAPH-#2D9BD
2D9BE CJK UNIFIED IDEOGRAPH-#2D9BE
2D9BF CJK UNIFIED IDEOGRAPH-#2D9BF
2D9C0 CJK UNIFIED IDEOGRAPH-#2D9C0
2D9C1 CJK UNIFIED IDEOGRAPH-#2D9C1
2D9C2 CJK UNIFIED IDEOGRAPH-#2D9C2
2D9C3 CJK UNIFIED IDEOGRAPH-#2D9C3
2D9C4 CJK UNIFIED IDEOGRAPH-#2D9C4
2D9C5 CJK UNIFIED IDEOGRAPH-#2D9C5
2D9C6 CJK UNIFIED IDEOGRAPH-#2D9C6
2D9C7 CJK UNIFIED IDEOGRAPH-#2D9C7
2D9C8 CJK UNIFIED IDEOGRAPH-#2D9C8
2D9C9 CJK UNIFIED IDEOGRAPH-#2D9C9
2D9CA CJK UNIFIED IDEOGRAPH-#2D9CA
2D9CB CJK UNIFIED IDEOGRAPH-#2D9CB
2D9CC CJK UNIFIED IDEOGRAPH-#2D9CC
2D9CD CJK UNIFIED IDEOGRAPH-#2D9CD
2D9CE CJK UNIFIED IDEOGRAPH-#2D9CE
2D9CF CJK UNIFIED IDEOGRAPH-#2D9CF
2D9D0 CJK UNIFIED IDEOGRAPH-#2D9D0
2D9D1 CJK UNIFIED IDEOGRAPH-#2D9D1
2D9D2 CJK UNIFIED IDEOGRAPH-#2D9D2
2D9D3 CJK UNIFIED IDEOGRAPH-#2D9D3
2D9D4 CJK UNIFIED IDEOGRAPH-#2D9D4
2D9D5 CJK UNIFIED IDEOGRAPH-#2D9D5
2D9D6 CJK UNIFIED IDEOGRAPH-#2D9D6
2D9D7 CJK UNIFIED IDEOGRAPH-#2D9D7
2D9D8 CJK UNIFIED IDEOGRAPH-#2D9D8
2D9D9 CJK UNIFIED IDEOGRAPH-#2D9D9
2D9DA CJK UNIFIED IDEOGRAPH-#2D9DA
2D9DB CJK UNIFIED IDEOGRAPH-#2D9DB
2D9DC CJK UNIFIED IDEOGRAPH-#2D9DC
2D9DD CJK UNIFIED IDEOGRAPH-#2D9DD
2D9DE CJK UNIFIED IDEOGRAPH-#2D9DE
2D9DF CJK UNIFIED IDEOGRAPH-#2D9DF
2D9E0 CJK UNIFIED IDEOGRAPH-#2D9E0
2D9E1 CJK UNIFIED IDEOGRAPH-#2D9E1
2D9E2 CJK UNIFIED IDEOGRAPH-#2D9E2
2D9E3 CJK UNIFIED IDEOGRAPH-#2D9E3
2D9E4 CJK UNIFIED IDEOGRAPH-#2D9E4
2D9E5 CJK UNIFIED IDEOGRAPH-#2D9E5
2D9E6 CJK UNIFIED IDEOGRAPH-#2D9E6
2D9E7 CJK UNIFIED IDEOGRAPH-#2D9E7
2D9E8 CJK UNIFIED IDEOGRAPH-#2D9E8
2D9E9 CJK UNIFIED IDEOGRAPH-#2D9E9
2D9EA CJK UNIFIED IDEOGRAPH-#2D9EA
2D9EB CJK UNIFIED IDEOGRAPH-#2D9EB
2D9EC CJK UNIFIED IDEOGRAPH-#2D9EC
2D9ED CJK UNIFIED IDEOGRAPH-#2D9ED
2D9EE CJK UNIFIED IDEOGRAPH-#2D9EE
2D9EF CJK UNIFIED IDEOGRAPH-#2D9EF
2D9F0 CJK UNIFIED IDEOGRAPH-#2D9F0
2D9F1 CJK UNIFIED IDEOGRAPH-#2D9F1
2D9F2 CJK UNIFIED IDEOGRAPH-#2D9F2
2D9F3 CJK UNIFIED IDEOGRAPH-#2D9F3
2D9F4 CJK UNIFIED IDEOGRAPH-#2D9F4
2D9F5 CJK UNIFIED IDEOGRAPH-#2D9F5
2D9F6 CJK UNIFIED IDEOGRAPH-#2D9F6
2D9F7 CJK UNIFIED IDEOGRAPH-#2D9F7
2D9F8 CJK UNIFIED IDEOGRAPH-#2D9F8
2D9F9 CJK UNIFIED IDEOGRAPH-#2D9F9
2D9FA CJK UNIFIED IDEOGRAPH-#2D9FA
2D9FB CJK UNIFIED IDEOGRAPH-#2D9FB
2D9FC CJK UNIFIED IDEOGRAPH-#2D9FC
2D9FD CJK UNIFIED IDEOGRAPH-#2D9FD
2D9FE CJK UNIFIED IDEOGRAPH-#2D9FE
2D9FF CJK UNIFIED IDEOGRAPH-#2D9FF
2DA00 CJK UNIFIED IDEOGRAPH-#2DA00
2DA01 CJK UNIFIED IDEOGRAPH-#2DA01
2DA02 CJK UNIFIED IDEOGRAPH-#2DA02
2DA03 CJK UNIFIED IDEOGRAPH-#2DA03
2DA04 CJK UNIFIED IDEOGRAPH-#2DA04
2DA05 CJK UNIFIED IDEOGRAPH-#2DA05
2DA06 CJK UNIFIED IDEOGRAPH-#2DA06
2DA07 CJK UNIFIED IDEOGRAPH-#2DA07
2DA08 CJK UNIFIED IDEOGRAPH-#2DA08
2DA09 CJK UNIFIED IDEOGRAPH-#2DA09
2DA0A CJK UNIFIED IDEOGRAPH-#2DA0A
2DA0B CJK UNIFIED IDEOGRAPH-#2DA0B
2DA0C CJK UNIFIED IDEOGRAPH-#2DA0C
2DA0D CJK UNIFIED IDEOGRAPH-#2DA0D
2DA0E CJK UNIFIED IDEOGRAPH-#2DA0E
2DA0F CJK UNIFIED IDEOGRAPH-#2DA0F
2DA10 CJK UNIFIED IDEOGRAPH-#2DA10
2DA11 CJK UNIFIED IDEOGRAPH-#2DA11
2DA12 CJK UNIFIED IDEOGRAPH-#2DA12
2DA13 CJK UNIFIED IDEOGRAPH-#2DA13
2DA14 CJK UNIFIED IDEOGRAPH-#2DA14
2DA15 CJK UNIFIED IDEOGRAPH-#2DA15
2DA16 CJK UNIFIED IDEOGRAPH-#2DA16
2DA17 CJK UNIFIED IDEOGRAPH-#2DA17
2DA18 CJK UNIFIED IDEOGRAPH-#2DA18
2DA19 CJK UNIFIED IDEOGRAPH-#2DA19
2DA1A CJK UNIFIED IDEOGRAPH-#2DA1A
2DA1B CJK UNIFIED IDEOGRAPH-#2DA1B
2DA1C CJK UNIFIED IDEOGRAPH-#2DA1C
2DA1D CJK UNIFIED IDEOGRAPH-#2DA1D
2DA1E CJK UNIFIED IDEOGRAPH-#2DA1E
2DA1F CJK UNIFIED IDEOGRAPH-#2DA1F
2DA20 CJK UNIFIED IDEOGRAPH-#2DA20
2DA21 CJK UNIFIED IDEOGRAPH-#2DA21
2DA22 CJK UNIFIED IDEOGRAPH-#2DA22
2DA23 CJK UNIFIED IDEOGRAPH-#2DA23
2DA24 CJK UNIFIED IDEOGRAPH-#2DA24
2DA25 CJK UNIFIED IDEOGRAPH-#2DA25
2DA26 CJK UNIFIED IDEOGRAPH-#2DA26
2DA27 CJK UNIFIED IDEOGRAPH-#2DA27
2DA28 CJK UNIFIED IDEOGRAPH-#2DA28
2DA29 CJK UNIFIED IDEOGRAPH-#2DA29
2DA2A CJK UNIFIED IDEOGRAPH-#2DA2A
2DA2B CJK UNIFIED IDEOGRAPH-#2DA2B
2DA2C CJK UNIFIED IDEOGRAPH-#2DA2C
2DA2D CJK UNIFIED IDEOGRAPH-#2DA2D
2DA2E CJK UNIFIED IDEOGRAPH-#2DA2E
2DA2F CJK UNIFIED IDEOGRAPH-#2DA2F
2DA30 CJK UNIFIED IDEOGRAPH-#2DA30
2DA31 CJK UNIFIED IDEOGRAPH-#2DA31
2DA32 CJK UNIFIED IDEOGRAPH-#2DA32
2DA33 CJK UNIFIED IDEOGRAPH-#2DA33
2DA34 CJK UNIFIED IDEOGRAPH-#2DA34
2DA35 CJK UNIFIED IDEOGRAPH-#2DA35
2DA36 CJK UNIFIED IDEOGRAPH-#2DA36
2DA37 CJK UNIFIED IDEOGRAPH-#2DA37
2DA38 CJK UNIFIED IDEOGRAPH-#2DA38
2DA39 CJK UNIFIED IDEOGRAPH-#2DA39
2DA3A CJK UNIFIED IDEOGRAPH-#2DA3A
2DA3B CJK UNIFIED IDEOGRAPH-#2DA3B
2DA3C CJK UNIFIED IDEOGRAPH-#2DA3C
2DA3D CJK UNIFIED IDEOGRAPH-#2DA3D
2DA3E CJK UNIFIED IDEOGRAPH-#2DA3E
2DA3F CJK UNIFIED IDEOGRAPH-#2DA3F
2DA40 CJK UNIFIED IDEOGRAPH-#2DA40
2DA41 CJK UNIFIED IDEOGRAPH-#2DA41
2DA42 CJK UNIFIED IDEOGRAPH-#2DA42
2DA43 CJK UNIFIED IDEOGRAPH-#2DA43
2DA44 CJK UNIFIED IDEOGRAPH-#2DA44
2DA45 CJK UNIFIED IDEOGRAPH-#2DA45
2DA46 CJK UNIFIED IDEOGRAPH-#2DA46
2DA47 CJK UNIFIED IDEOGRAPH-#2DA47
2DA48 CJK UNIFIED IDEOGRAPH-#2DA48
2DA49 CJK UNIFIED IDEOGRAPH-#2DA49
2DA4A CJK UNIFIED IDEOGRAPH-#2DA4A
2DA4B CJK UNIFIED IDEOGRAPH-#2DA4B
2DA4C CJK UNIFIED IDEOGRAPH-#2DA4C
2DA4D CJK UNIFIED IDEOGRAPH-#2DA4D
2DA4E CJK UNIFIED IDEOGRAPH-#2DA4E
2DA4F CJK UNIFIED IDEOGRAPH-#2DA4F
2DA50 CJK UNIFIED IDEOGRAPH-#2DA50
2DA51 CJK UNIFIED IDEOGRAPH-#2DA51
2DA52 CJK UNIFIED IDEOGRAPH-#2DA52
2DA53 CJK UNIFIED IDEOGRAPH-#2DA53
2DA54 CJK UNIFIED IDEOGRAPH-#2DA54
2DA55 CJK UNIFIED IDEOGRAPH-#2DA55
2DA56 CJK UNIFIED IDEOGRAPH-#2DA56
2DA57 CJK UNIFIED IDEOGRAPH-#2DA57
2DA58 CJK UNIFIED IDEOGRAPH-#2DA58
2DA59 CJK UNIFIED IDEOGRAPH-#2DA59
2DA5A CJK UNIFIED IDEOGRAPH-#2DA5A
2DA5B CJK UNIFIED IDEOGRAPH-#2DA5B
2DA5C CJK UNIFIED IDEOGRAPH-#2DA5C
2DA5D CJK UNIFIED IDEOGRAPH-#2DA5D
2DA5E CJK UNIFIED IDEOGRAPH-#2DA5E
2DA5F CJK UNIFIED IDEOGRAPH-#2DA5F
2DA60 CJK UNIFIED IDEOGRAPH-#2DA60
2DA61 CJK UNIFIED IDEOGRAPH-#2DA61
2DA62 CJK UNIFIED IDEOGRAPH-#2DA62
2DA63 CJK UNIFIED IDEOGRAPH-#2DA63
2DA64 CJK UNIFIED IDEOGRAPH-#2DA64
2DA65 CJK UNIFIED IDEOGRAPH-#2DA65
2DA66 CJK UNIFIED IDEOGRAPH-#2DA66
2DA67 CJK UNIFIED IDEOGRAPH-#2DA67
2DA68 CJK UNIFIED IDEOGRAPH-#2DA68
2DA69 CJK UNIFIED IDEOGRAPH-#2DA69
2DA6A CJK UNIFIED IDEOGRAPH-#2DA6A
2DA6B CJK UNIFIED IDEOGRAPH-#2DA6B
2DA6C CJK UNIFIED IDEOGRAPH-#2DA6C
2DA6D CJK UNIFIED IDEOGRAPH-#2DA6D
2DA6E CJK UNIFIED IDEOGRAPH-#2DA6E
2DA6F CJK UNIFIED IDEOGRAPH-#2DA6F
2DA70 CJK UNIFIED IDEOGRAPH-#2DA70
2DA71 CJK UNIFIED IDEOGRAPH-#2DA71
2DA72 CJK UNIFIED IDEOGRAPH-#2DA72
2DA73 CJK UNIFIED IDEOGRAPH-#2DA73
2DA74 CJK UNIFIED IDEOGRAPH-#2DA74
2DA75 CJK UNIFIED IDEOGRAPH-#2DA75
2DA76 CJK UNIFIED IDEOGRAPH-#2DA76
2DA77 CJK UNIFIED IDEOGRAPH-#2DA77
2DA78 CJK UNIFIED IDEOGRAPH-#2DA78
2DA79 CJK UNIFIED IDEOGRAPH-#2DA79
2DA7A CJK UNIFIED IDEOGRAPH-#2DA7A
2DA7B CJK UNIFIED IDEOGRAPH-#2DA7B
2DA7C CJK UNIFIED IDEOGRAPH-#2DA7C
2DA7D CJK UNIFIED IDEOGRAPH-#2DA7D
2DA7E CJK UNIFIED IDEOGRAPH-#2DA7E
2DA7F CJK UNIFIED IDEOGRAPH-#2DA7F
2DA80 CJK UNIFIED IDEOGRAPH-#2DA80
2DA81 CJK UNIFIED IDEOGRAPH-#2DA81
2DA82 CJK UNIFIED IDEOGRAPH-#2DA82
2DA83 CJK UNIFIED IDEOGRAPH-#2DA83
2DA84 CJK UNIFIED IDEOGRAPH-#2DA84
2DA85 CJK UNIFIED IDEOGRAPH-#2DA85
2DA86 CJK UNIFIED IDEOGRAPH-#2DA86
2DA87 CJK UNIFIED IDEOGRAPH-#2DA87
2DA88 CJK UNIFIED IDEOGRAPH-#2DA88
2DA89 CJK UNIFIED IDEOGRAPH-#2DA89
2DA8A CJK UNIFIED IDEOGRAPH-#2DA8A
2DA8B CJK UNIFIED IDEOGRAPH-#2DA8B
2DA8C CJK UNIFIED IDEOGRAPH-#2DA8C
2DA8D CJK UNIFIED IDEOGRAPH-#2DA8D
2DA8E CJK UNIFIED IDEOGRAPH-#2DA8E
2DA8F CJK UNIFIED IDEOGRAPH-#2DA8F
2DA90 CJK UNIFIED IDEOGRAPH-#2DA90
2DA91 CJK UNIFIED IDEOGRAPH-#2DA91
2DA92 CJK UNIFIED IDEOGRAPH-#2DA92
2DA93 CJK UNIFIED IDEOGRAPH-#2DA93
2DA94 CJK UNIFIED IDEOGRAPH-#2DA94
2DA95 CJK UNIFIED IDEOGRAPH-#2DA95
2DA96 CJK UNIFIED IDEOGRAPH-#2DA96
2DA97 CJK UNIFIED IDEOGRAPH-#2DA97
2DA98 CJK UNIFIED IDEOGRAPH-#2DA98
2DA99 CJK UNIFIED IDEOGRAPH-#2DA99
2DA9A CJK UNIFIED IDEOGRAPH-#2DA9A
2DA9B CJK UNIFIED IDEOGRAPH-#2DA9B
2DA9C CJK UNIFIED IDEOGRAPH-#2DA9C
2DA9D CJK UNIFIED IDEOGRAPH-#2DA9D
2DA9E CJK UNIFIED IDEOGRAPH-#2DA9E
2DA9F CJK UNIFIED IDEOGRAPH-#2DA9F
2DAA0 CJK UNIFIED IDEOGRAPH-#2DAA0
2DAA1 CJK UNIFIED IDEOGRAPH-#2DAA1
2DAA2 CJK UNIFIED IDEOGRAPH-#2DAA2
2DAA3 CJK UNIFIED IDEOGRAPH-#2DAA3
2DAA4 CJK UNIFIED IDEOGRAPH-#2DAA4
2DAA5 CJK UNIFIED IDEOGRAPH-#2DAA5
2DAA6 CJK UNIFIED IDEOGRAPH-#2DAA6
2DAA7 CJK UNIFIED IDEOGRAPH-#2DAA7
2DAA8 CJK UNIFIED IDEOGRAPH-#2DAA8
2DAA9 CJK UNIFIED IDEOGRAPH-#2DAA9
2DAAA CJK UNIFIED IDEOGRAPH-#2DAAA
2DAAB CJK UNIFIED IDEOGRAPH-#2DAAB
2DAAC CJK UNIFIED IDEOGRAPH-#2DAAC
2DAAD CJK UNIFIED IDEOGRAPH-#2DAAD
2DAAE CJK UNIFIED IDEOGRAPH-#2DAAE
2DAAF CJK UNIFIED IDEOGRAPH-#2DAAF
2DAB0 CJK UNIFIED IDEOGRAPH-#2DAB0
2DAB1 CJK UNIFIED IDEOGRAPH-#2DAB1
2DAB2 CJK UNIFIED IDEOGRAPH-#2DAB2
2DAB3 CJK UNIFIED IDEOGRAPH-#2DAB3
2DAB4 CJK UNIFIED IDEOGRAPH-#2DAB4
2DAB5 CJK UNIFIED IDEOGRAPH-#2DAB5
2DAB6 CJK UNIFIED IDEOGRAPH-#2DAB6
2DAB7 CJK UNIFIED IDEOGRAPH-#2DAB7
2DAB8 CJK UNIFIED IDEOGRAPH-#2DAB8
2DAB9 CJK UNIFIED IDEOGRAPH-#2DAB9
2DABA CJK UNIFIED IDEOGRAPH-#2DABA
2DABB CJK UNIFIED IDEOGRAPH-#2DABB
2DABC CJK UNIFIED IDEOGRAPH-#2DABC
2DABD CJK UNIFIED IDEOGRAPH-#2DABD
2DABE CJK UNIFIED IDEOGRAPH-#2DABE
2DABF CJK UNIFIED IDEOGRAPH-#2DABF
2DAC0 CJK UNIFIED IDEOGRAPH-#2DAC0
2DAC1 CJK UNIFIED IDEOGRAPH-#2DAC1
2DAC2 CJK UNIFIED IDEOGRAPH-#2DAC2
2DAC3 CJK UNIFIED IDEOGRAPH-#2DAC3
2DAC4 CJK UNIFIED IDEOGRAPH-#2DAC4
2DAC5 CJK UNIFIED IDEOGRAPH-#2DAC5
2DAC6 CJK UNIFIED IDEOGRAPH-#2DAC6
2DAC7 CJK UNIFIED IDEOGRAPH-#2DAC7
2DAC8 CJK UNIFIED IDEOGRAPH-#2DAC8
2DAC9 CJK UNIFIED IDEOGRAPH-#2DAC9
2DACA CJK UNIFIED IDEOGRAPH-#2DACA
2DACB CJK UNIFIED IDEOGRAPH-#2DACB
2DACC CJK UNIFIED IDEOGRAPH-#2DACC
2DACD CJK UNIFIED IDEOGRAPH-#2DACD
2DACE CJK UNIFIED IDEOGRAPH-#2DACE
2DACF CJK UNIFIED IDEOGRAPH-#2DACF
2DAD0 CJK UNIFIED IDEOGRAPH-#2DAD0
2DAD1 CJK UNIFIED IDEOGRAPH-#2DAD1
2DAD2 CJK UNIFIED IDEOGRAPH-#2DAD2
2DAD3 CJK UNIFIED IDEOGRAPH-#2DAD3
2DAD4 CJK UNIFIED IDEOGRAPH-#2DAD4
2DAD5 CJK UNIFIED IDEOGRAPH-#2DAD5
2DAD6 CJK UNIFIED IDEOGRAPH-#2DAD6
2DAD7 CJK UNIFIED IDEOGRAPH-#2DAD7
2DAD8 CJK UNIFIED IDEOGRAPH-#2DAD8
2DAD9 CJK UNIFIED IDEOGRAPH-#2DAD9
2DADA CJK UNIFIED IDEOGRAPH-#2DADA
2DADB CJK UNIFIED IDEOGRAPH-#2DADB
2DADC CJK UNIFIED IDEOGRAPH-#2DADC
2DADD CJK UNIFIED IDEOGRAPH-#2DADD
2DADE CJK UNIFIED IDEOGRAPH-#2DADE
2DADF CJK UNIFIED IDEOGRAPH-#2DADF
2DAE0 CJK UNIFIED IDEOGRAPH-#2DAE0
2DAE1 CJK UNIFIED IDEOGRAPH-#2DAE1
2DAE2 CJK UNIFIED IDEOGRAPH-#2DAE2
2DAE3 CJK UNIFIED IDEOGRAPH-#2DAE3
2DAE4 CJK UNIFIED IDEOGRAPH-#2DAE4
2DAE5 CJK UNIFIED IDEOGRAPH-#2DAE5
2DAE6 CJK UNIFIED IDEOGRAPH-#2DAE6
2DAE7 CJK UNIFIED IDEOGRAPH-#2DAE7
2DAE8 CJK UNIFIED IDEOGRAPH-#2DAE8
2DAE9 CJK UNIFIED IDEOGRAPH-#2DAE9
2DAEA CJK UNIFIED IDEOGRAPH-#2DAEA
2DAEB CJK UNIFIED IDEOGRAPH-#2DAEB
2DAEC CJK UNIFIED IDEOGRAPH-#2DAEC
2DAED CJK UNIFIED IDEOGRAPH-#2DAED
2DAEE CJK UNIFIED IDEOGRAPH-#2DAEE
2DAEF CJK UNIFIED IDEOGRAPH-#2DAEF
2DAF0 CJK UNIFIED IDEOGRAPH-#2DAF0
2DAF1 CJK UNIFIED IDEOGRAPH-#2DAF1
2DAF2 CJK UNIFIED IDEOGRAPH-#2DAF2
2DAF3 CJK UNIFIED IDEOGRAPH-#2DAF3
2DAF4 CJK UNIFIED IDEOGRAPH-#2DAF4
2DAF5 CJK UNIFIED IDEOGRAPH-#2DAF5
2DAF6 CJK UNIFIED IDEOGRAPH-#2DAF6
2DAF7 CJK UNIFIED IDEOGRAPH-#2DAF7
2DAF8 CJK UNIFIED IDEOGRAPH-#2DAF8
2DAF9 CJK UNIFIED IDEOGRAPH-#2DAF9
2DAFA CJK UNIFIED IDEOGRAPH-#2DAFA
2DAFB CJK UNIFIED IDEOGRAPH-#2DAFB
2DAFC CJK UNIFIED IDEOGRAPH-#2DAFC
2DAFD CJK UNIFIED IDEOGRAPH-#2DAFD
2DAFE CJK UNIFIED IDEOGRAPH-#2DAFE
2DAFF CJK UNIFIED IDEOGRAPH-#2DAFF
2DB00 CJK UNIFIED IDEOGRAPH-#2DB00
2DB01 CJK UNIFIED IDEOGRAPH-#2DB01
2DB02 CJK UNIFIED IDEOGRAPH-#2DB02
2DB03 CJK UNIFIED IDEOGRAPH-#2DB03
2DB04 CJK UNIFIED IDEOGRAPH-#2DB04
2DB05 CJK UNIFIED IDEOGRAPH-#2DB05
2DB06 CJK UNIFIED IDEOGRAPH-#2DB06
2DB07 CJK UNIFIED IDEOGRAPH-#2DB07
2DB08 CJK UNIFIED IDEOGRAPH-#2DB08
2DB09 CJK UNIFIED IDEOGRAPH-#2DB09
2DB0A CJK UNIFIED IDEOGRAPH-#2DB0A
2DB0B CJK UNIFIED IDEOGRAPH-#2DB0B
2DB0C CJK UNIFIED IDEOGRAPH-#2DB0C
2DB0D CJK UNIFIED IDEOGRAPH-#2DB0D
2DB0E CJK UNIFIED IDEOGRAPH-#2DB0E
2DB0F CJK UNIFIED IDEOGRAPH-#2DB0F
2DB10 CJK UNIFIED IDEOGRAPH-#2DB10
2DB11 CJK UNIFIED IDEOGRAPH-#2DB11
2DB12 CJK UNIFIED IDEOGRAPH-#2DB12
2DB13 CJK UNIFIED IDEOGRAPH-#2DB13
2DB14 CJK UNIFIED IDEOGRAPH-#2DB14
2DB15 CJK UNIFIED IDEOGRAPH-#2DB15
2DB16 CJK UNIFIED IDEOGRAPH-#2DB16
2DB17 CJK UNIFIED IDEOGRAPH-#2DB17
2DB18 CJK UNIFIED IDEOGRAPH-#2DB18
2DB19 CJK UNIFIED IDEOGRAPH-#2DB19
2DB1A CJK UNIFIED IDEOGRAPH-#2DB1A
2DB1B CJK UNIFIED IDEOGRAPH-#2DB1B
2DB1C CJK UNIFIED IDEOGRAPH-#2DB1C
2DB1D CJK UNIFIED IDEOGRAPH-#2DB1D
2DB1E CJK UNIFIED IDEOGRAPH-#2DB1E
2DB1F CJK UNIFIED IDEOGRAPH-#2DB1F
2DB20 CJK UNIFIED IDEOGRAPH-#2DB20
2DB21 CJK UNIFIED IDEOGRAPH-#2DB21
2DB22 CJK UNIFIED IDEOGRAPH-#2DB22
2DB23 CJK UNIFIED IDEOGRAPH-#2DB23
2DB24 CJK UNIFIED IDEOGRAPH-#2DB24
2DB25 CJK UNIFIED IDEOGRAPH-#2DB25
2DB26 CJK UNIFIED IDEOGRAPH-#2DB26
2DB27 CJK UNIFIED IDEOGRAPH-#2DB27
2DB28 CJK UNIFIED IDEOGRAPH-#2DB28
2DB29 CJK UNIFIED IDEOGRAPH-#2DB29
2DB2A CJK UNIFIED IDEOGRAPH-#2DB2A
2DB2B CJK UNIFIED IDEOGRAPH-#2DB2B
2DB2C CJK UNIFIED IDEOGRAPH-#2DB2C
2DB2D CJK UNIFIED IDEOGRAPH-#2DB2D
2DB2E CJK UNIFIED IDEOGRAPH-#2DB2E
2DB2F CJK UNIFIED IDEOGRAPH-#2DB2F
2DB30 CJK UNIFIED IDEOGRAPH-#2DB30
2DB31 CJK UNIFIED IDEOGRAPH-#2DB31
2DB32 CJK UNIFIED IDEOGRAPH-#2DB32
2DB33 CJK UNIFIED IDEOGRAPH-#2DB33
2DB34 CJK UNIFIED IDEOGRAPH-#2DB34
2DB35 CJK UNIFIED IDEOGRAPH-#2DB35
2DB36 CJK UNIFIED IDEOGRAPH-#2DB36
2DB37 CJK UNIFIED IDEOGRAPH-#2DB37
2DB38 CJK UNIFIED IDEOGRAPH-#2DB38
2DB39 CJK UNIFIED IDEOGRAPH-#2DB39
2DB3A CJK UNIFIED IDEOGRAPH-#2DB3A
2DB3B CJK UNIFIED IDEOGRAPH-#2DB3B
2DB3C CJK UNIFIED IDEOGRAPH-#2DB3C
2DB3D CJK UNIFIED IDEOGRAPH-#2DB3D
2DB3E CJK UNIFIED IDEOGRAPH-#2DB3E
2DB3F CJK UNIFIED IDEOGRAPH-#2DB3F
2DB40 CJK UNIFIED IDEOGRAPH-#2DB40
2DB41 CJK UNIFIED IDEOGRAPH-#2DB41
2DB42 CJK UNIFIED IDEOGRAPH-#2DB42
2DB43 CJK UNIFIED IDEOGRAPH-#2DB43
2DB44 CJK UNIFIED IDEOGRAPH-#2DB44
2DB45 CJK UNIFIED IDEOGRAPH-#2DB45
2DB46 CJK UNIFIED IDEOGRAPH-#2DB46
2DB47 CJK UNIFIED IDEOGRAPH-#2DB47
2DB48 CJK UNIFIED IDEOGRAPH-#2DB48
2DB49 CJK UNIFIED IDEOGRAPH-#2DB49
2DB4A CJK UNIFIED IDEOGRAPH-#2DB4A
2DB4B CJK UNIFIED IDEOGRAPH-#2DB4B
2DB4C CJK UNIFIED IDEOGRAPH-#2DB4C
2DB4D CJK UNIFIED IDEOGRAPH-#2DB4D
2DB4E CJK UNIFIED IDEOGRAPH-#2DB4E
2DB4F CJK UNIFIED IDEOGRAPH-#2DB4F
2DB50 CJK UNIFIED IDEOGRAPH-#2DB50
2DB51 CJK UNIFIED IDEOGRAPH-#2DB51
2DB52 CJK UNIFIED IDEOGRAPH-#2DB52
2DB53 CJK UNIFIED IDEOGRAPH-#2DB53
2DB54 CJK UNIFIED IDEOGRAPH-#2DB54
2DB55 CJK UNIFIED IDEOGRAPH-#2DB55
2DB56 CJK UNIFIED IDEOGRAPH-#2DB56
2DB57 CJK UNIFIED IDEOGRAPH-#2DB57
2DB58 CJK UNIFIED IDEOGRAPH-#2DB58
2DB59 CJK UNIFIED IDEOGRAPH-#2DB59
2DB5A CJK UNIFIED IDEOGRAPH-#2DB5A
2DB5B CJK UNIFIED IDEOGRAPH-#2DB5B
2DB5C CJK UNIFIED IDEOGRAPH-#2DB5C
2DB5D CJK UNIFIED IDEOGRAPH-#2DB5D
2DB5E CJK UNIFIED IDEOGRAPH-#2DB5E
2DB5F CJK UNIFIED IDEOGRAPH-#2DB5F
2DB60 CJK UNIFIED IDEOGRAPH-#2DB60
2DB61 CJK UNIFIED IDEOGRAPH-#2DB61
2DB62 CJK UNIFIED IDEOGRAPH-#2DB62
2DB63 CJK UNIFIED IDEOGRAPH-#2DB63
2DB64 CJK UNIFIED IDEOGRAPH-#2DB64
2DB65 CJK UNIFIED IDEOGRAPH-#2DB65
2DB66 CJK UNIFIED IDEOGRAPH-#2DB66
2DB67 CJK UNIFIED IDEOGRAPH-#2DB67
2DB68 CJK UNIFIED IDEOGRAPH-#2DB68
2DB69 CJK UNIFIED IDEOGRAPH-#2DB69
2DB6A CJK UNIFIED IDEOGRAPH-#2DB6A
2DB6B CJK UNIFIED IDEOGRAPH-#2DB6B
2DB6C CJK UNIFIED IDEOGRAPH-#2DB6C
2DB6D CJK UNIFIED IDEOGRAPH-#2DB6D
2DB6E CJK UNIFIED IDEOGRAPH-#2DB6E
2DB6F CJK UNIFIED IDEOGRAPH-#2DB6F
2DB70 CJK UNIFIED IDEOGRAPH-#2DB70
2DB71 CJK UNIFIED IDEOGRAPH-#2DB71
2DB72 CJK UNIFIED IDEOGRAPH-#2DB72
2DB73 CJK UNIFIED IDEOGRAPH-#2DB73
2DB74 CJK UNIFIED IDEOGRAPH-#2DB74
2DB75 CJK UNIFIED IDEOGRAPH-#2DB75
2DB76 CJK UNIFIED IDEOGRAPH-#2DB76
2DB77 CJK UNIFIED IDEOGRAPH-#2DB77
2DB78 CJK UNIFIED IDEOGRAPH-#2DB78
2DB79 CJK UNIFIED IDEOGRAPH-#2DB79
2DB7A CJK UNIFIED IDEOGRAPH-#2DB7A
2DB7B CJK UNIFIED IDEOGRAPH-#2DB7B
2DB7C CJK UNIFIED IDEOGRAPH-#2DB7C
2DB7D CJK UNIFIED IDEOGRAPH-#2DB7D
2DB7E CJK UNIFIED IDEOGRAPH-#2DB7E
2DB7F CJK UNIFIED IDEOGRAPH-#2DB7F
2DB80 CJK UNIFIED IDEOGRAPH-#2DB80
2DB81 CJK UNIFIED IDEOGRAPH-#2DB81
2DB82 CJK UNIFIED IDEOGRAPH-#2DB82
2DB83 CJK UNIFIED IDEOGRAPH-#2DB83
2DB84 CJK UNIFIED IDEOGRAPH-#2DB84
2DB85 CJK UNIFIED IDEOGRAPH-#2DB85
2DB86 CJK UNIFIED IDEOGRAPH-#2DB86
2DB87 CJK UNIFIED IDEOGRAPH-#2DB87
2DB88 CJK UNIFIED IDEOGRAPH-#2DB88
2DB89 CJK UNIFIED IDEOGRAPH-#2DB89
2DB8A CJK UNIFIED IDEOGRAPH-#2DB8A
2DB8B CJK UNIFIED IDEOGRAPH-#2DB8B
2DB8C CJK UNIFIED IDEOGRAPH-#2DB8C
2DB8D CJK UNIFIED IDEOGRAPH-#2DB8D
2DB8E CJK UNIFIED IDEOGRAPH-#2DB8E
2DB8F CJK UNIFIED IDEOGRAPH-#2DB8F
2DB90 CJK UNIFIED IDEOGRAPH-#2DB90
2DB91 CJK UNIFIED IDEOGRAPH-#2DB91
2DB92 CJK UNIFIED IDEOGRAPH-#2DB92
2DB93 CJK UNIFIED IDEOGRAPH-#2DB93
2DB94 CJK UNIFIED IDEOGRAPH-#2DB94
2DB95 CJK UNIFIED IDEOGRAPH-#2DB95
2DB96 CJK UNIFIED IDEOGRAPH-#2DB96
2DB97 CJK UNIFIED IDEOGRAPH-#2DB97
2DB98 CJK UNIFIED IDEOGRAPH-#2DB98
2DB99 CJK UNIFIED IDEOGRAPH-#2DB99
2DB9A CJK UNIFIED IDEOGRAPH-#2DB9A
2DB9B CJK UNIFIED IDEOGRAPH-#2DB9B
2DB9C CJK UNIFIED IDEOGRAPH-#2DB9C
2DB9D CJK UNIFIED IDEOGRAPH-#2DB9D
2DB9E CJK UNIFIED IDEOGRAPH-#2DB9E
2DB9F CJK UNIFIED IDEOGRAPH-#2DB9F
2DBA0 CJK UNIFIED IDEOGRAPH-#2DBA0
2DBA1 CJK UNIFIED IDEOGRAPH-#2DBA1
2DBA2 CJK UNIFIED IDEOGRAPH-#2DBA2
2DBA3 CJK UNIFIED IDEOGRAPH-#2DBA3
2DBA4 CJK UNIFIED IDEOGRAPH-#2DBA4
2DBA5 CJK UNIFIED IDEOGRAPH-#2DBA5
2DBA6 CJK UNIFIED IDEOGRAPH-#2DBA6
2DBA7 CJK UNIFIED IDEOGRAPH-#2DBA7
2DBA8 CJK UNIFIED IDEOGRAPH-#2DBA8
2DBA9 CJK UNIFIED IDEOGRAPH-#2DBA9
2DBAA CJK UNIFIED IDEOGRAPH-#2DBAA
2DBAB CJK UNIFIED IDEOGRAPH-#2DBAB
2DBAC CJK UNIFIED IDEOGRAPH-#2DBAC
2DBAD CJK UNIFIED IDEOGRAPH-#2DBAD
2DBAE CJK UNIFIED IDEOGRAPH-#2DBAE
2DBAF CJK UNIFIED IDEOGRAPH-#2DBAF
2DBB0 CJK UNIFIED IDEOGRAPH-#2DBB0
2DBB1 CJK UNIFIED IDEOGRAPH-#2DBB1
2DBB2 CJK UNIFIED IDEOGRAPH-#2DBB2
2DBB3 CJK UNIFIED IDEOGRAPH-#2DBB3
2DBB4 CJK UNIFIED IDEOGRAPH-#2DBB4
2DBB5 CJK UNIFIED IDEOGRAPH-#2DBB5
2DBB6 CJK UNIFIED IDEOGRAPH-#2DBB6
2DBB7 CJK UNIFIED IDEOGRAPH-#2DBB7
2DBB8 CJK UNIFIED IDEOGRAPH-#2DBB8
2DBB9 CJK UNIFIED IDEOGRAPH-#2DBB9
2DBBA CJK UNIFIED IDEOGRAPH-#2DBBA
2DBBB CJK UNIFIED IDEOGRAPH-#2DBBB
2DBBC CJK UNIFIED IDEOGRAPH-#2DBBC
2DBBD CJK UNIFIED IDEOGRAPH-#2DBBD
2DBBE CJK UNIFIED IDEOGRAPH-#2DBBE
2DBBF CJK UNIFIED IDEOGRAPH-#2DBBF
2DBC0 CJK UNIFIED IDEOGRAPH-#2DBC0
2DBC1 CJK UNIFIED IDEOGRAPH-#2DBC1
2DBC2 CJK UNIFIED IDEOGRAPH-#2DBC2
2DBC3 CJK UNIFIED IDEOGRAPH-#2DBC3
2DBC4 CJK UNIFIED IDEOGRAPH-#2DBC4
2DBC5 CJK UNIFIED IDEOGRAPH-#2DBC5
2DBC6 CJK UNIFIED IDEOGRAPH-#2DBC6
2DBC7 CJK UNIFIED IDEOGRAPH-#2DBC7
2DBC8 CJK UNIFIED IDEOGRAPH-#2DBC8
2DBC9 CJK UNIFIED IDEOGRAPH-#2DBC9
2DBCA CJK UNIFIED IDEOGRAPH-#2DBCA
2DBCB CJK UNIFIED IDEOGRAPH-#2DBCB
2DBCC CJK UNIFIED IDEOGRAPH-#2DBCC
2DBCD CJK UNIFIED IDEOGRAPH-#2DBCD
2DBCE CJK UNIFIED IDEOGRAPH-#2DBCE
2DBCF CJK UNIFIED IDEOGRAPH-#2DBCF
2DBD0 CJK UNIFIED IDEOGRAPH-#2DBD0
2DBD1 CJK UNIFIED IDEOGRAPH-#2DBD1
2DBD2 CJK UNIFIED IDEOGRAPH-#2DBD2
2DBD3 CJK UNIFIED IDEOGRAPH-#2DBD3
2DBD4 CJK UNIFIED IDEOGRAPH-#2DBD4
2DBD5 CJK UNIFIED IDEOGRAPH-#2DBD5
2DBD6 CJK UNIFIED IDEOGRAPH-#2DBD6
2DBD7 CJK UNIFIED IDEOGRAPH-#2DBD7
2DBD8 CJK UNIFIED IDEOGRAPH-#2DBD8
2DBD9 CJK UNIFIED IDEOGRAPH-#2DBD9
2DBDA CJK UNIFIED IDEOGRAPH-#2DBDA
2DBDB CJK UNIFIED IDEOGRAPH-#2DBDB
2DBDC CJK UNIFIED IDEOGRAPH-#2DBDC
2DBDD CJK UNIFIED IDEOGRAPH-#2DBDD
2DBDE CJK UNIFIED IDEOGRAPH-#2DBDE
2DBDF CJK UNIFIED IDEOGRAPH-#2DBDF
2DBE0 CJK UNIFIED IDEOGRAPH-#2DBE0
2DBE1 CJK UNIFIED IDEOGRAPH-#2DBE1
2DBE2 CJK UNIFIED IDEOGRAPH-#2DBE2
2DBE3 CJK UNIFIED IDEOGRAPH-#2DBE3
2DBE4 CJK UNIFIED IDEOGRAPH-#2DBE4
2DBE5 CJK UNIFIED IDEOGRAPH-#2DBE5
2DBE6 CJK UNIFIED IDEOGRAPH-#2DBE6
2DBE7 CJK UNIFIED IDEOGRAPH-#2DBE7
2DBE8 CJK UNIFIED IDEOGRAPH-#2DBE8
2DBE9 CJK UNIFIED IDEOGRAPH-#2DBE9
2DBEA CJK UNIFIED IDEOGRAPH-#2DBEA
2DBEB CJK UNIFIED IDEOGRAPH-#2DBEB
2DBEC CJK UNIFIED IDEOGRAPH-#2DBEC
2DBED CJK UNIFIED IDEOGRAPH-#2DBED
2DBEE CJK UNIFIED IDEOGRAPH-#2DBEE
2DBEF CJK UNIFIED IDEOGRAPH-#2DBEF
2DBF0 CJK UNIFIED IDEOGRAPH-#2DBF0
2DBF1 CJK UNIFIED IDEOGRAPH-#2DBF1
2DBF2 CJK UNIFIED IDEOGRAPH-#2DBF2
2DBF3 CJK UNIFIED IDEOGRAPH-#2DBF3
2DBF4 CJK UNIFIED IDEOGRAPH-#2DBF4
2DBF5 CJK UNIFIED IDEOGRAPH-#2DBF5
2DBF6 CJK UNIFIED IDEOGRAPH-#2DBF6
2DBF7 CJK UNIFIED IDEOGRAPH-#2DBF7
2DBF8 CJK UNIFIED IDEOGRAPH-#2DBF8
2DBF9 CJK UNIFIED IDEOGRAPH-#2DBF9
2DBFA CJK UNIFIED IDEOGRAPH-#2DBFA
2DBFB CJK UNIFIED IDEOGRAPH-#2DBFB
2DBFC CJK UNIFIED IDEOGRAPH-#2DBFC
2DBFD CJK UNIFIED IDEOGRAPH-#2DBFD
2DBFE CJK UNIFIED IDEOGRAPH-#2DBFE
2DBFF CJK UNIFIED IDEOGRAPH-#2DBFF
2DC00 CJK UNIFIED IDEOGRAPH-#2DC00
2DC01 CJK UNIFIED IDEOGRAPH-#2DC01
2DC02 CJK UNIFIED IDEOGRAPH-#2DC02
2DC03 CJK UNIFIED IDEOGRAPH-#2DC03
2DC04 CJK UNIFIED IDEOGRAPH-#2DC04
2DC05 CJK UNIFIED IDEOGRAPH-#2DC05
2DC06 CJK UNIFIED IDEOGRAPH-#2DC06
2DC07 CJK UNIFIED IDEOGRAPH-#2DC07
2DC08 CJK UNIFIED IDEOGRAPH-#2DC08
2DC09 CJK UNIFIED IDEOGRAPH-#2DC09
2DC0A CJK UNIFIED IDEOGRAPH-#2DC0A
2DC0B CJK UNIFIED IDEOGRAPH-#2DC0B
2DC0C CJK UNIFIED IDEOGRAPH-#2DC0C
2DC0D CJK UNIFIED IDEOGRAPH-#2DC0D
2DC0E CJK UNIFIED IDEOGRAPH-#2DC0E
2DC0F CJK UNIFIED IDEOGRAPH-#2DC0F
2DC10 CJK UNIFIED IDEOGRAPH-#2DC10
2DC11 CJK UNIFIED IDEOGRAPH-#2DC11
2DC12 CJK UNIFIED IDEOGRAPH-#2DC12
2DC13 CJK UNIFIED IDEOGRAPH-#2DC13
2DC14 CJK UNIFIED IDEOGRAPH-#2DC14
2DC15 CJK UNIFIED IDEOGRAPH-#2DC15
2DC16 CJK UNIFIED IDEOGRAPH-#2DC16
2DC17 CJK UNIFIED IDEOGRAPH-#2DC17
2DC18 CJK UNIFIED IDEOGRAPH-#2DC18
2DC19 CJK UNIFIED IDEOGRAPH-#2DC19
2DC1A CJK UNIFIED IDEOGRAPH-#2DC1A
2DC1B CJK UNIFIED IDEOGRAPH-#2DC1B
2DC1C CJK UNIFIED IDEOGRAPH-#2DC1C
2DC1D CJK UNIFIED IDEOGRAPH-#2DC1D
2DC1E CJK UNIFIED IDEOGRAPH-#2DC1E
2DC1F CJK UNIFIED IDEOGRAPH-#2DC1F
2DC20 CJK UNIFIED IDEOGRAPH-#2DC20
2DC21 CJK UNIFIED IDEOGRAPH-#2DC21
2DC22 CJK UNIFIED IDEOGRAPH-#2DC22
2DC23 CJK UNIFIED IDEOGRAPH-#2DC23
2DC24 CJK UNIFIED IDEOGRAPH-#2DC24
2DC25 CJK UNIFIED IDEOGRAPH-#2DC25
2DC26 CJK UNIFIED IDEOGRAPH-#2DC26
2DC27 CJK UNIFIED IDEOGRAPH-#2DC27
2DC28 CJK UNIFIED IDEOGRAPH-#2DC28
2DC29 CJK UNIFIED IDEOGRAPH-#2DC29
2DC2A CJK UNIFIED IDEOGRAPH-#2DC2A
2DC2B CJK UNIFIED IDEOGRAPH-#2DC2B
2DC2C CJK UNIFIED IDEOGRAPH-#2DC2C
2DC2D CJK UNIFIED IDEOGRAPH-#2DC2D
2DC2E CJK UNIFIED IDEOGRAPH-#2DC2E
2DC2F CJK UNIFIED IDEOGRAPH-#2DC2F
2DC30 CJK UNIFIED IDEOGRAPH-#2DC30
2DC31 CJK UNIFIED IDEOGRAPH-#2DC31
2DC32 CJK UNIFIED IDEOGRAPH-#2DC32
2DC33 CJK UNIFIED IDEOGRAPH-#2DC33
2DC34 CJK UNIFIED IDEOGRAPH-#2DC34
2DC35 CJK UNIFIED IDEOGRAPH-#2DC35
2DC36 CJK UNIFIED IDEOGRAPH-#2DC36
2DC37 CJK UNIFIED IDEOGRAPH-#2DC37
2DC38 CJK UNIFIED IDEOGRAPH-#2DC38
2DC39 CJK UNIFIED IDEOGRAPH-#2DC39
2DC3A CJK UNIFIED IDEOGRAPH-#2DC3A
2DC3B CJK UNIFIED IDEOGRAPH-#2DC3B
2DC3C CJK UNIFIED IDEOGRAPH-#2DC3C
2DC3D CJK UNIFIED IDEOGRAPH-#2DC3D
2DC3E CJK UNIFIED IDEOGRAPH-#2DC3E
2DC3F CJK UNIFIED IDEOGRAPH-#2DC3F
2DC40 CJK UNIFIED IDEOGRAPH-#2DC40
2DC41 CJK UNIFIED IDEOGRAPH-#2DC41
2DC42 CJK UNIFIED IDEOGRAPH-#2DC42
2DC43 CJK UNIFIED IDEOGRAPH-#2DC43
2DC44 CJK UNIFIED IDEOGRAPH-#2DC44
2DC45 CJK UNIFIED IDEOGRAPH-#2DC45
2DC46 CJK UNIFIED IDEOGRAPH-#2DC46
2DC47 CJK UNIFIED IDEOGRAPH-#2DC47
2DC48 CJK UNIFIED IDEOGRAPH-#2DC48
2DC49 CJK UNIFIED IDEOGRAPH-#2DC49
2DC4A CJK UNIFIED IDEOGRAPH-#2DC4A
2DC4B CJK UNIFIED IDEOGRAPH-#2DC4B
2DC4C CJK UNIFIED IDEOGRAPH-#2DC4C
2DC4D CJK UNIFIED IDEOGRAPH-#2DC4D
2DC4E CJK UNIFIED IDEOGRAPH-#2DC4E
2DC4F CJK UNIFIED IDEOGRAPH-#2DC4F
2DC50 CJK UNIFIED IDEOGRAPH-#2DC50
2DC51 CJK UNIFIED IDEOGRAPH-#2DC51
2DC52 CJK UNIFIED IDEOGRAPH-#2DC52
2DC53 CJK UNIFIED IDEOGRAPH-#2DC53
2DC54 CJK UNIFIED IDEOGRAPH-#2DC54
2DC55 CJK UNIFIED IDEOGRAPH-#2DC55
2DC56 CJK UNIFIED IDEOGRAPH-#2DC56
2DC57 CJK UNIFIED IDEOGRAPH-#2DC57
2DC58 CJK UNIFIED IDEOGRAPH-#2DC58
2DC59 CJK UNIFIED IDEOGRAPH-#2DC59
2DC5A CJK UNIFIED IDEOGRAPH-#2DC5A
2DC5B CJK UNIFIED IDEOGRAPH-#2DC5B
2DC5C CJK UNIFIED IDEOGRAPH-#2DC5C
2DC5D CJK UNIFIED IDEOGRAPH-#2DC5D
2DC5E CJK UNIFIED IDEOGRAPH-#2DC5E
2DC5F CJK UNIFIED IDEOGRAPH-#2DC5F
2DC60 CJK UNIFIED IDEOGRAPH-#2DC60
2DC61 CJK UNIFIED IDEOGRAPH-#2DC61
2DC62 CJK UNIFIED IDEOGRAPH-#2DC62
2DC63 CJK UNIFIED IDEOGRAPH-#2DC63
2DC64 CJK UNIFIED IDEOGRAPH-#2DC64
2DC65 CJK UNIFIED IDEOGRAPH-#2DC65
2DC66 CJK UNIFIED IDEOGRAPH-#2DC66
2DC67 CJK UNIFIED IDEOGRAPH-#2DC67
2DC68 CJK UNIFIED IDEOGRAPH-#2DC68
2DC69 CJK UNIFIED IDEOGRAPH-#2DC69
2DC6A CJK UNIFIED IDEOGRAPH-#2DC6A
2DC6B CJK UNIFIED IDEOGRAPH-#2DC6B
2DC6C CJK UNIFIED IDEOGRAPH-#2DC6C
2DC6D CJK UNIFIED IDEOGRAPH-#2DC6D
2DC6E CJK UNIFIED IDEOGRAPH-#2DC6E
2DC6F CJK UNIFIED IDEOGRAPH-#2DC6F
2DC70 CJK UNIFIED IDEOGRAPH-#2DC70
2DC71 CJK UNIFIED IDEOGRAPH-#2DC71
2DC72 CJK UNIFIED IDEOGRAPH-#2DC72
2DC73 CJK UNIFIED IDEOGRAPH-#2DC73
2DC74 CJK UNIFIED IDEOGRAPH-#2DC74
2DC75 CJK UNIFIED IDEOGRAPH-#2DC75
2DC76 CJK UNIFIED IDEOGRAPH-#2DC76
2DC77 CJK UNIFIED IDEOGRAPH-#2DC77
2DC78 CJK UNIFIED IDEOGRAPH-#2DC78
2DC79 CJK UNIFIED IDEOGRAPH-#2DC79
2DC7A CJK UNIFIED IDEOGRAPH-#2DC7A
2DC7B CJK UNIFIED IDEOGRAPH-#2DC7B
2DC7C CJK UNIFIED IDEOGRAPH-#2DC7C
2DC7D CJK UNIFIED IDEOGRAPH-#2DC7D
2DC7E CJK UNIFIED IDEOGRAPH-#2DC7E
2DC7F CJK UNIFIED IDEOGRAPH-#2DC7F
2DC80 CJK UNIFIED IDEOGRAPH-#2DC80
2DC81 CJK UNIFIED IDEOGRAPH-#2DC81
2DC82 CJK UNIFIED IDEOGRAPH-#2DC82
2DC83 CJK UNIFIED IDEOGRAPH-#2DC83
2DC84 CJK UNIFIED IDEOGRAPH-#2DC84
2DC85 CJK UNIFIED IDEOGRAPH-#2DC85
2DC86 CJK UNIFIED IDEOGRAPH-#2DC86
2DC87 CJK UNIFIED IDEOGRAPH-#2DC87
2DC88 CJK UNIFIED IDEOGRAPH-#2DC88
2DC89 CJK UNIFIED IDEOGRAPH-#2DC89
2DC8A CJK UNIFIED IDEOGRAPH-#2DC8A
2DC8B CJK UNIFIED IDEOGRAPH-#2DC8B
2DC8C CJK UNIFIED IDEOGRAPH-#2DC8C
2DC8D CJK UNIFIED IDEOGRAPH-#2DC8D
2DC8E CJK UNIFIED IDEOGRAPH-#2DC8E
2DC8F CJK UNIFIED IDEOGRAPH-#2DC8F
2DC90 CJK UNIFIED IDEOGRAPH-#2DC90
2DC91 CJK UNIFIED IDEOGRAPH-#2DC91
2DC92 CJK UNIFIED IDEOGRAPH-#2DC92
2DC93 CJK UNIFIED IDEOGRAPH-#2DC93
2DC94 CJK UNIFIED IDEOGRAPH-#2DC94
2DC95 CJK UNIFIED IDEOGRAPH-#2DC95
2DC96 CJK UNIFIED IDEOGRAPH-#2DC96
2DC97 CJK UNIFIED IDEOGRAPH-#2DC97
2DC98 CJK UNIFIED IDEOGRAPH-#2DC98
2DC99 CJK UNIFIED IDEOGRAPH-#2DC99
2DC9A CJK UNIFIED IDEOGRAPH-#2DC9A
2DC9B CJK UNIFIED IDEOGRAPH-#2DC9B
2DC9C CJK UNIFIED IDEOGRAPH-#2DC9C
2DC9D CJK UNIFIED IDEOGRAPH-#2DC9D
2DC9E CJK UNIFIED IDEOGRAPH-#2DC9E
2DC9F CJK UNIFIED IDEOGRAPH-#2DC9F
2DCA0 CJK UNIFIED IDEOGRAPH-#2DCA0
2DCA1 CJK UNIFIED IDEOGRAPH-#2DCA1
2DCA2 CJK UNIFIED IDEOGRAPH-#2DCA2
2DCA3 CJK UNIFIED IDEOGRAPH-#2DCA3
2DCA4 CJK UNIFIED IDEOGRAPH-#2DCA4
2DCA5 CJK UNIFIED IDEOGRAPH-#2DCA5
2DCA6 CJK UNIFIED IDEOGRAPH-#2DCA6
2DCA7 CJK UNIFIED IDEOGRAPH-#2DCA7
2DCA8 CJK UNIFIED IDEOGRAPH-#2DCA8
2DCA9 CJK UNIFIED IDEOGRAPH-#2DCA9
2DCAA CJK UNIFIED IDEOGRAPH-#2DCAA
2DCAB CJK UNIFIED IDEOGRAPH-#2DCAB
2DCAC CJK UNIFIED IDEOGRAPH-#2DCAC
2DCAD CJK UNIFIED IDEOGRAPH-#2DCAD
2DCAE CJK UNIFIED IDEOGRAPH-#2DCAE
2DCAF CJK UNIFIED IDEOGRAPH-#2DCAF
2DCB0 CJK UNIFIED IDEOGRAPH-#2DCB0
2DCB1 CJK UNIFIED IDEOGRAPH-#2DCB1
2DCB2 CJK UNIFIED IDEOGRAPH-#2DCB2
2DCB3 CJK UNIFIED IDEOGRAPH-#2DCB3
2DCB4 CJK UNIFIED IDEOGRAPH-#2DCB4
2DCB5 CJK UNIFIED IDEOGRAPH-#2DCB5
2DCB6 CJK UNIFIED IDEOGRAPH-#2DCB6
2DCB7 CJK UNIFIED IDEOGRAPH-#2DCB7
2DCB8 CJK UNIFIED IDEOGRAPH-#2DCB8
2DCB9 CJK UNIFIED IDEOGRAPH-#2DCB9
2DCBA CJK UNIFIED IDEOGRAPH-#2DCBA
2DCBB CJK UNIFIED IDEOGRAPH-#2DCBB
2DCBC CJK UNIFIED IDEOGRAPH-#2DCBC
2DCBD CJK UNIFIED IDEOGRAPH-#2DCBD
2DCBE CJK UNIFIED IDEOGRAPH-#2DCBE
2DCBF CJK UNIFIED IDEOGRAPH-#2DCBF
2DCC0 CJK UNIFIED IDEOGRAPH-#2DCC0
2DCC1 CJK UNIFIED IDEOGRAPH-#2DCC1
2DCC2 CJK UNIFIED IDEOGRAPH-#2DCC2
2DCC3 CJK UNIFIED IDEOGRAPH-#2DCC3
2DCC4 CJK UNIFIED IDEOGRAPH-#2DCC4
2DCC5 CJK UNIFIED IDEOGRAPH-#2DCC5
2DCC6 CJK UNIFIED IDEOGRAPH-#2DCC6
2DCC7 CJK UNIFIED IDEOGRAPH-#2DCC7
2DCC8 CJK UNIFIED IDEOGRAPH-#2DCC8
2DCC9 CJK UNIFIED IDEOGRAPH-#2DCC9
2DCCA CJK UNIFIED IDEOGRAPH-#2DCCA
2DCCB CJK UNIFIED IDEOGRAPH-#2DCCB
2DCCC CJK UNIFIED IDEOGRAPH-#2DCCC
2DCCD CJK UNIFIED IDEOGRAPH-#2DCCD
2DCCE CJK UNIFIED IDEOGRAPH-#2DCCE
2DCCF CJK UNIFIED IDEOGRAPH-#2DCCF
2DCD0 CJK UNIFIED IDEOGRAPH-#2DCD0
2DCD1 CJK UNIFIED IDEOGRAPH-#2DCD1
2DCD2 CJK UNIFIED IDEOGRAPH-#2DCD2
2DCD3 CJK UNIFIED IDEOGRAPH-#2DCD3
2DCD4 CJK UNIFIED IDEOGRAPH-#2DCD4
2DCD5 CJK UNIFIED IDEOGRAPH-#2DCD5
2DCD6 CJK UNIFIED IDEOGRAPH-#2DCD6
2DCD7 CJK UNIFIED IDEOGRAPH-#2DCD7
2DCD8 CJK UNIFIED IDEOGRAPH-#2DCD8
2DCD9 CJK UNIFIED IDEOGRAPH-#2DCD9
2DCDA CJK UNIFIED IDEOGRAPH-#2DCDA
2DCDB CJK UNIFIED IDEOGRAPH-#2DCDB
2DCDC CJK UNIFIED IDEOGRAPH-#2DCDC
2DCDD CJK UNIFIED IDEOGRAPH-#2DCDD
2DCDE CJK UNIFIED IDEOGRAPH-#2DCDE
2DCDF CJK UNIFIED IDEOGRAPH-#2DCDF
2DCE0 CJK UNIFIED IDEOGRAPH-#2DCE0
2DCE1 CJK UNIFIED IDEOGRAPH-#2DCE1
2DCE2 CJK UNIFIED IDEOGRAPH-#2DCE2
2DCE3 CJK UNIFIED IDEOGRAPH-#2DCE3
2DCE4 CJK UNIFIED IDEOGRAPH-#2DCE4
2DCE5 CJK UNIFIED IDEOGRAPH-#2DCE5
2DCE6 CJK UNIFIED IDEOGRAPH-#2DCE6
2DCE7 CJK UNIFIED IDEOGRAPH-#2DCE7
2DCE8 CJK UNIFIED IDEOGRAPH-#2DCE8
2DCE9 CJK UNIFIED IDEOGRAPH-#2DCE9
2DCEA CJK UNIFIED IDEOGRAPH-#2DCEA
2DCEB CJK UNIFIED IDEOGRAPH-#2DCEB
2DCEC CJK UNIFIED IDEOGRAPH-#2DCEC
2DCED CJK UNIFIED IDEOGRAPH-#2DCED
2DCEE CJK UNIFIED IDEOGRAPH-#2DCEE
2DCEF CJK UNIFIED IDEOGRAPH-#2DCEF
2DCF0 CJK UNIFIED IDEOGRAPH-#2DCF0
2DCF1 CJK UNIFIED IDEOGRAPH-#2DCF1
2DCF2 CJK UNIFIED IDEOGRAPH-#2DCF2
2DCF3 CJK UNIFIED IDEOGRAPH-#2DCF3
2DCF4 CJK UNIFIED IDEOGRAPH-#2DCF4
2DCF5 CJK UNIFIED IDEOGRAPH-#2DCF5
2DCF6 CJK UNIFIED IDEOGRAPH-#2DCF6
2DCF7 CJK UNIFIED IDEOGRAPH-#2DCF7
2DCF8 CJK UNIFIED IDEOGRAPH-#2DCF8
2DCF9 CJK UNIFIED IDEOGRAPH-#2DCF9
2DCFA CJK UNIFIED IDEOGRAPH-#2DCFA
2DCFB CJK UNIFIED IDEOGRAPH-#2DCFB
2DCFC CJK UNIFIED IDEOGRAPH-#2DCFC
2DCFD CJK UNIFIED IDEOGRAPH-#2DCFD
2DCFE CJK UNIFIED IDEOGRAPH-#2DCFE
2DCFF CJK UNIFIED IDEOGRAPH-#2DCFF
2DD00 CJK UNIFIED IDEOGRAPH-#2DD00
2DD01 CJK UNIFIED IDEOGRAPH-#2DD01
2DD02 CJK UNIFIED IDEOGRAPH-#2DD02
2DD03 CJK UNIFIED IDEOGRAPH-#2DD03
2DD04 CJK UNIFIED IDEOGRAPH-#2DD04
2DD05 CJK UNIFIED IDEOGRAPH-#2DD05
2DD06 CJK UNIFIED IDEOGRAPH-#2DD06
2DD07 CJK UNIFIED IDEOGRAPH-#2DD07
2DD08 CJK UNIFIED IDEOGRAPH-#2DD08
2DD09 CJK UNIFIED IDEOGRAPH-#2DD09
2DD0A CJK UNIFIED IDEOGRAPH-#2DD0A
2DD0B CJK UNIFIED IDEOGRAPH-#2DD0B
2DD0C CJK UNIFIED IDEOGRAPH-#2DD0C
2DD0D CJK UNIFIED IDEOGRAPH-#2DD0D
2DD0E CJK UNIFIED IDEOGRAPH-#2DD0E
2DD0F CJK UNIFIED IDEOGRAPH-#2DD0F
2DD10 CJK UNIFIED IDEOGRAPH-#2DD10
2DD11 CJK UNIFIED IDEOGRAPH-#2DD11
2DD12 CJK UNIFIED IDEOGRAPH-#2DD12
2DD13 CJK UNIFIED IDEOGRAPH-#2DD13
2DD14 CJK UNIFIED IDEOGRAPH-#2DD14
2DD15 CJK UNIFIED IDEOGRAPH-#2DD15
2DD16 CJK UNIFIED IDEOGRAPH-#2DD16
2DD17 CJK UNIFIED IDEOGRAPH-#2DD17
2DD18 CJK UNIFIED IDEOGRAPH-#2DD18
2DD19 CJK UNIFIED IDEOGRAPH-#2DD19
2DD1A CJK UNIFIED IDEOGRAPH-#2DD1A
2DD1B CJK UNIFIED IDEOGRAPH-#2DD1B
2DD1C CJK UNIFIED IDEOGRAPH-#2DD1C
2DD1D CJK UNIFIED IDEOGRAPH-#2DD1D
2DD1E CJK UNIFIED IDEOGRAPH-#2DD1E
2DD1F CJK UNIFIED IDEOGRAPH-#2DD1F
2DD20 CJK UNIFIED IDEOGRAPH-#2DD20
2DD21 CJK UNIFIED IDEOGRAPH-#2DD21
2DD22 CJK UNIFIED IDEOGRAPH-#2DD22
2DD23 CJK UNIFIED IDEOGRAPH-#2DD23
2DD24 CJK UNIFIED IDEOGRAPH-#2DD24
2DD25 CJK UNIFIED IDEOGRAPH-#2DD25
2DD26 CJK UNIFIED IDEOGRAPH-#2DD26
2DD27 CJK UNIFIED IDEOGRAPH-#2DD27
2DD28 CJK UNIFIED IDEOGRAPH-#2DD28
2DD29 CJK UNIFIED IDEOGRAPH-#2DD29
2DD2A CJK UNIFIED IDEOGRAPH-#2DD2A
2DD2B CJK UNIFIED IDEOGRAPH-#2DD2B
2DD2C CJK UNIFIED IDEOGRAPH-#2DD2C
2DD2D CJK UNIFIED IDEOGRAPH-#2DD2D
2DD2E CJK UNIFIED IDEOGRAPH-#2DD2E
2DD2F CJK UNIFIED IDEOGRAPH-#2DD2F
2DD30 CJK UNIFIED IDEOGRAPH-#2DD30
2DD31 CJK UNIFIED IDEOGRAPH-#2DD31
2DD32 CJK UNIFIED IDEOGRAPH-#2DD32
2DD33 CJK UNIFIED IDEOGRAPH-#2DD33
2DD34 CJK UNIFIED IDEOGRAPH-#2DD34
2DD35 CJK UNIFIED IDEOGRAPH-#2DD35
2DD36 CJK UNIFIED IDEOGRAPH-#2DD36
2DD37 CJK UNIFIED IDEOGRAPH-#2DD37
2DD38 CJK UNIFIED IDEOGRAPH-#2DD38
2DD39 CJK UNIFIED IDEOGRAPH-#2DD39
2DD3A CJK UNIFIED IDEOGRAPH-#2DD3A
2DD3B CJK UNIFIED IDEOGRAPH-#2DD3B
2DD3C CJK UNIFIED IDEOGRAPH-#2DD3C
2DD3D CJK UNIFIED IDEOGRAPH-#2DD3D
2DD3E CJK UNIFIED IDEOGRAPH-#2DD3E
2DD3F CJK UNIFIED IDEOGRAPH-#2DD3F
2DD40 CJK UNIFIED IDEOGRAPH-#2DD40
2DD41 CJK UNIFIED IDEOGRAPH-#2DD41
2DD42 CJK UNIFIED IDEOGRAPH-#2DD42
2DD43 CJK UNIFIED IDEOGRAPH-#2DD43
2DD44 CJK UNIFIED IDEOGRAPH-#2DD44
2DD45 CJK UNIFIED IDEOGRAPH-#2DD45
2DD46 CJK UNIFIED IDEOGRAPH-#2DD46
2DD47 CJK UNIFIED IDEOGRAPH-#2DD47
2DD48 CJK UNIFIED IDEOGRAPH-#2DD48
2DD49 CJK UNIFIED IDEOGRAPH-#2DD49
2DD4A CJK UNIFIED IDEOGRAPH-#2DD4A
2DD4B CJK UNIFIED IDEOGRAPH-#2DD4B
2DD4C CJK UNIFIED IDEOGRAPH-#2DD4C
2DD4D CJK UNIFIED IDEOGRAPH-#2DD4D
2DD4E CJK UNIFIED IDEOGRAPH-#2DD4E
2DD4F CJK UNIFIED IDEOGRAPH-#2DD4F
2DD50 CJK UNIFIED IDEOGRAPH-#2DD50
2DD51 CJK UNIFIED IDEOGRAPH-#2DD51
2DD52 CJK UNIFIED IDEOGRAPH-#2DD52
2DD53 CJK UNIFIED IDEOGRAPH-#2DD53
2DD54 CJK UNIFIED IDEOGRAPH-#2DD54
2DD55 CJK UNIFIED IDEOGRAPH-#2DD55
2DD56 CJK UNIFIED IDEOGRAPH-#2DD56
2DD57 CJK UNIFIED IDEOGRAPH-#2DD57
2DD58 CJK UNIFIED IDEOGRAPH-#2DD58
2DD59 CJK UNIFIED IDEOGRAPH-#2DD59
2DD5A CJK UNIFIED IDEOGRAPH-#2DD5A
2DD5B CJK UNIFIED IDEOGRAPH-#2DD5B
2DD5C CJK UNIFIED IDEOGRAPH-#2DD5C
2DD5D CJK UNIFIED IDEOGRAPH-#2DD5D
2DD5E CJK UNIFIED IDEOGRAPH-#2DD5E
2DD5F CJK UNIFIED IDEOGRAPH-#2DD5F
2DD60 CJK UNIFIED IDEOGRAPH-#2DD60
2DD61 CJK UNIFIED IDEOGRAPH-#2DD61
2DD62 CJK UNIFIED IDEOGRAPH-#2DD62
2DD63 CJK UNIFIED IDEOGRAPH-#2DD63
2DD64 CJK UNIFIED IDEOGRAPH-#2DD64
2DD65 CJK UNIFIED IDEOGRAPH-#2DD65
2DD66 CJK UNIFIED IDEOGRAPH-#2DD66
2DD67 CJK UNIFIED IDEOGRAPH-#2DD67
2DD68 CJK UNIFIED IDEOGRAPH-#2DD68
2DD69 CJK UNIFIED IDEOGRAPH-#2DD69
2DD6A CJK UNIFIED IDEOGRAPH-#2DD6A
2DD6B CJK UNIFIED IDEOGRAPH-#2DD6B
2DD6C CJK UNIFIED IDEOGRAPH-#2DD6C
2DD6D CJK UNIFIED IDEOGRAPH-#2DD6D
2DD6E CJK UNIFIED IDEOGRAPH-#2DD6E
2DD6F CJK UNIFIED IDEOGRAPH-#2DD6F
2DD70 CJK UNIFIED IDEOGRAPH-#2DD70
2DD71 CJK UNIFIED IDEOGRAPH-#2DD71
2DD72 CJK UNIFIED IDEOGRAPH-#2DD72
2DD73 CJK UNIFIED IDEOGRAPH-#2DD73
2DD74 CJK UNIFIED IDEOGRAPH-#2DD74
2DD75 CJK UNIFIED IDEOGRAPH-#2DD75
2DD76 CJK UNIFIED IDEOGRAPH-#2DD76
2DD77 CJK UNIFIED IDEOGRAPH-#2DD77
2DD78 CJK UNIFIED IDEOGRAPH-#2DD78
2DD79 CJK UNIFIED IDEOGRAPH-#2DD79
2DD7A CJK UNIFIED IDEOGRAPH-#2DD7A
2DD7B CJK UNIFIED IDEOGRAPH-#2DD7B
2DD7C CJK UNIFIED IDEOGRAPH-#2DD7C
2DD7D CJK UNIFIED IDEOGRAPH-#2DD7D
2DD7E CJK UNIFIED IDEOGRAPH-#2DD7E
2DD7F CJK UNIFIED IDEOGRAPH-#2DD7F
2DD80 CJK UNIFIED IDEOGRAPH-#2DD80
2DD81 CJK UNIFIED IDEOGRAPH-#2DD81
2DD82 CJK UNIFIED IDEOGRAPH-#2DD82
2DD83 CJK UNIFIED IDEOGRAPH-#2DD83
2DD84 CJK UNIFIED IDEOGRAPH-#2DD84
2DD85 CJK UNIFIED IDEOGRAPH-#2DD85
2DD86 CJK UNIFIED IDEOGRAPH-#2DD86
2DD87 CJK UNIFIED IDEOGRAPH-#2DD87
2DD88 CJK UNIFIED IDEOGRAPH-#2DD88
2DD89 CJK UNIFIED IDEOGRAPH-#2DD89
2DD8A CJK UNIFIED IDEOGRAPH-#2DD8A
2DD8B CJK UNIFIED IDEOGRAPH-#2DD8B
2DD8C CJK UNIFIED IDEOGRAPH-#2DD8C
2DD8D CJK UNIFIED IDEOGRAPH-#2DD8D
2DD8E CJK UNIFIED IDEOGRAPH-#2DD8E
2DD8F CJK UNIFIED IDEOGRAPH-#2DD8F
2DD90 CJK UNIFIED IDEOGRAPH-#2DD90
2DD91 CJK UNIFIED IDEOGRAPH-#2DD91
2DD92 CJK UNIFIED IDEOGRAPH-#2DD92
2DD93 CJK UNIFIED IDEOGRAPH-#2DD93
2DD94 CJK UNIFIED IDEOGRAPH-#2DD94
2DD95 CJK UNIFIED IDEOGRAPH-#2DD95
2DD96 CJK UNIFIED IDEOGRAPH-#2DD96
2DD97 CJK UNIFIED IDEOGRAPH-#2DD97
2DD98 CJK UNIFIED IDEOGRAPH-#2DD98
2DD99 CJK UNIFIED IDEOGRAPH-#2DD99
2DD9A CJK UNIFIED IDEOGRAPH-#2DD9A
2DD9B CJK UNIFIED IDEOGRAPH-#2DD9B
2DD9C CJK UNIFIED IDEOGRAPH-#2DD9C
2DD9D CJK UNIFIED IDEOGRAPH-#2DD9D
2DD9E CJK UNIFIED IDEOGRAPH-#2DD9E
2DD9F CJK UNIFIED IDEOGRAPH-#2DD9F
2DDA0 CJK UNIFIED IDEOGRAPH-#2DDA0
2DDA1 CJK UNIFIED IDEOGRAPH-#2DDA1
2DDA2 CJK UNIFIED IDEOGRAPH-#2DDA2
2DDA3 CJK UNIFIED IDEOGRAPH-#2DDA3
2DDA4 CJK UNIFIED IDEOGRAPH-#2DDA4
2DDA5 CJK UNIFIED IDEOGRAPH-#2DDA5
2DDA6 CJK UNIFIED IDEOGRAPH-#2DDA6
2DDA7 CJK UNIFIED IDEOGRAPH-#2DDA7
2DDA8 CJK UNIFIED IDEOGRAPH-#2DDA8
2DDA9 CJK UNIFIED IDEOGRAPH-#2DDA9
2DDAA CJK UNIFIED IDEOGRAPH-#2DDAA
2DDAB CJK UNIFIED IDEOGRAPH-#2DDAB
2DDAC CJK UNIFIED IDEOGRAPH-#2DDAC
2DDAD CJK UNIFIED IDEOGRAPH-#2DDAD
2DDAE CJK UNIFIED IDEOGRAPH-#2DDAE
2DDAF CJK UNIFIED IDEOGRAPH-#2DDAF
2DDB0 CJK UNIFIED IDEOGRAPH-#2DDB0
2DDB1 CJK UNIFIED IDEOGRAPH-#2DDB1
2DDB2 CJK UNIFIED IDEOGRAPH-#2DDB2
2DDB3 CJK UNIFIED IDEOGRAPH-#2DDB3
2DDB4 CJK UNIFIED IDEOGRAPH-#2DDB4
2DDB5 CJK UNIFIED IDEOGRAPH-#2DDB5
2DDB6 CJK UNIFIED IDEOGRAPH-#2DDB6
2DDB7 CJK UNIFIED IDEOGRAPH-#2DDB7
2DDB8 CJK UNIFIED IDEOGRAPH-#2DDB8
2DDB9 CJK UNIFIED IDEOGRAPH-#2DDB9
2DDBA CJK UNIFIED IDEOGRAPH-#2DDBA
2DDBB CJK UNIFIED IDEOGRAPH-#2DDBB
2DDBC CJK UNIFIED IDEOGRAPH-#2DDBC
2DDBD CJK UNIFIED IDEOGRAPH-#2DDBD
2DDBE CJK UNIFIED IDEOGRAPH-#2DDBE
2DDBF CJK UNIFIED IDEOGRAPH-#2DDBF
2DDC0 CJK UNIFIED IDEOGRAPH-#2DDC0
2DDC1 CJK UNIFIED IDEOGRAPH-#2DDC1
2DDC2 CJK UNIFIED IDEOGRAPH-#2DDC2
2DDC3 CJK UNIFIED IDEOGRAPH-#2DDC3
2DDC4 CJK UNIFIED IDEOGRAPH-#2DDC4
2DDC5 CJK UNIFIED IDEOGRAPH-#2DDC5
2DDC6 CJK UNIFIED IDEOGRAPH-#2DDC6
2DDC7 CJK UNIFIED IDEOGRAPH-#2DDC7
2DDC8 CJK UNIFIED IDEOGRAPH-#2DDC8
2DDC9 CJK UNIFIED IDEOGRAPH-#2DDC9
2DDCA CJK UNIFIED IDEOGRAPH-#2DDCA
2DDCB CJK UNIFIED IDEOGRAPH-#2DDCB
2DDCC CJK UNIFIED IDEOGRAPH-#2DDCC
2DDCD CJK UNIFIED IDEOGRAPH-#2DDCD
2DDCE CJK UNIFIED IDEOGRAPH-#2DDCE
2DDCF CJK UNIFIED IDEOGRAPH-#2DDCF
2DDD0 CJK UNIFIED IDEOGRAPH-#2DDD0
2DDD1 CJK UNIFIED IDEOGRAPH-#2DDD1
2DDD2 CJK UNIFIED IDEOGRAPH-#2DDD2
2DDD3 CJK UNIFIED IDEOGRAPH-#2DDD3
2DDD4 CJK UNIFIED IDEOGRAPH-#2DDD4
2DDD5 CJK UNIFIED IDEOGRAPH-#2DDD5
2DDD6 CJK UNIFIED IDEOGRAPH-#2DDD6
2DDD7 CJK UNIFIED IDEOGRAPH-#2DDD7
2DDD8 CJK UNIFIED IDEOGRAPH-#2DDD8
2DDD9 CJK UNIFIED IDEOGRAPH-#2DDD9
2DDDA CJK UNIFIED IDEOGRAPH-#2DDDA
2DDDB CJK UNIFIED IDEOGRAPH-#2DDDB
2DDDC CJK UNIFIED IDEOGRAPH-#2DDDC
2DDDD CJK UNIFIED IDEOGRAPH-#2DDDD
2DDDE CJK UNIFIED IDEOGRAPH-#2DDDE
2DDDF CJK UNIFIED IDEOGRAPH-#2DDDF
2DDE0 CJK UNIFIED IDEOGRAPH-#2DDE0
2DDE1 CJK UNIFIED IDEOGRAPH-#2DDE1
2DDE2 CJK UNIFIED IDEOGRAPH-#2DDE2
2DDE3 CJK UNIFIED IDEOGRAPH-#2DDE3
2DDE4 CJK UNIFIED IDEOGRAPH-#2DDE4
2DDE5 CJK UNIFIED IDEOGRAPH-#2DDE5
2DDE6 CJK UNIFIED IDEOGRAPH-#2DDE6
2DDE7 CJK UNIFIED IDEOGRAPH-#2DDE7
2DDE8 CJK UNIFIED IDEOGRAPH-#2DDE8
2DDE9 CJK UNIFIED IDEOGRAPH-#2DDE9
2DDEA CJK UNIFIED IDEOGRAPH-#2DDEA
2DDEB CJK UNIFIED IDEOGRAPH-#2DDEB
2DDEC CJK UNIFIED IDEOGRAPH-#2DDEC
2DDED CJK UNIFIED IDEOGRAPH-#2DDED
2DDEE CJK UNIFIED IDEOGRAPH-#2DDEE
2DDEF CJK UNIFIED IDEOGRAPH-#2DDEF
2DDF0 CJK UNIFIED IDEOGRAPH-#2DDF0
2DDF1 CJK UNIFIED IDEOGRAPH-#2DDF1
2DDF2 CJK UNIFIED IDEOGRAPH-#2DDF2
2DDF3 CJK UNIFIED IDEOGRAPH-#2DDF3
2DDF4 CJK UNIFIED IDEOGRAPH-#2DDF4
2DDF5 CJK UNIFIED IDEOGRAPH-#2DDF5
2DDF6 CJK UNIFIED IDEOGRAPH-#2DDF6
2DDF7 CJK UNIFIED IDEOGRAPH-#2DDF7
2DDF8 CJK UNIFIED IDEOGRAPH-#2DDF8
2DDF9 CJK UNIFIED IDEOGRAPH-#2DDF9
2DDFA CJK UNIFIED IDEOGRAPH-#2DDFA
2DDFB CJK UNIFIED IDEOGRAPH-#2DDFB
2DDFC CJK UNIFIED IDEOGRAPH-#2DDFC
2DDFD CJK UNIFIED IDEOGRAPH-#2DDFD
2DDFE CJK UNIFIED IDEOGRAPH-#2DDFE
2DDFF CJK UNIFIED IDEOGRAPH-#2DDFF
2DE00 CJK UNIFIED IDEOGRAPH-#2DE00
2DE01 CJK UNIFIED IDEOGRAPH-#2DE01
2DE02 CJK UNIFIED IDEOGRAPH-#2DE02
2DE03 CJK UNIFIED IDEOGRAPH-#2DE03
2DE04 CJK UNIFIED IDEOGRAPH-#2DE04
2DE05 CJK UNIFIED IDEOGRAPH-#2DE05
2DE06 CJK UNIFIED IDEOGRAPH-#2DE06
2DE07 CJK UNIFIED IDEOGRAPH-#2DE07
2DE08 CJK UNIFIED IDEOGRAPH-#2DE08
2DE09 CJK UNIFIED IDEOGRAPH-#2DE09
2DE0A CJK UNIFIED IDEOGRAPH-#2DE0A
2DE0B CJK UNIFIED IDEOGRAPH-#2DE0B
2DE0C CJK UNIFIED IDEOGRAPH-#2DE0C
2DE0D CJK UNIFIED IDEOGRAPH-#2DE0D
2DE0E CJK UNIFIED IDEOGRAPH-#2DE0E
2DE0F CJK UNIFIED IDEOGRAPH-#2DE0F
2DE10 CJK UNIFIED IDEOGRAPH-#2DE10
2DE11 CJK UNIFIED IDEOGRAPH-#2DE11
2DE12 CJK UNIFIED IDEOGRAPH-#2DE12
2DE13 CJK UNIFIED IDEOGRAPH-#2DE13
2DE14 CJK UNIFIED IDEOGRAPH-#2DE14
2DE15 CJK UNIFIED IDEOGRAPH-#2DE15
2DE16 CJK UNIFIED IDEOGRAPH-#2DE16
2DE17 CJK UNIFIED IDEOGRAPH-#2DE17
2DE18 CJK UNIFIED IDEOGRAPH-#2DE18
2DE19 CJK UNIFIED IDEOGRAPH-#2DE19
2DE1A CJK UNIFIED IDEOGRAPH-#2DE1A
2DE1B CJK UNIFIED IDEOGRAPH-#2DE1B
2DE1C CJK UNIFIED IDEOGRAPH-#2DE1C
2DE1D CJK UNIFIED IDEOGRAPH-#2DE1D
2DE1E CJK UNIFIED IDEOGRAPH-#2DE1E
2DE1F CJK UNIFIED IDEOGRAPH-#2DE1F
2DE20 CJK UNIFIED IDEOGRAPH-#2DE20
2DE21 CJK UNIFIED IDEOGRAPH-#2DE21
2DE22 CJK UNIFIED IDEOGRAPH-#2DE22
2DE23 CJK UNIFIED IDEOGRAPH-#2DE23
2DE24 CJK UNIFIED IDEOGRAPH-#2DE24
2DE25 CJK UNIFIED IDEOGRAPH-#2DE25
2DE26 CJK UNIFIED IDEOGRAPH-#2DE26
2DE27 CJK UNIFIED IDEOGRAPH-#2DE27
2DE28 CJK UNIFIED IDEOGRAPH-#2DE28
2DE29 CJK UNIFIED IDEOGRAPH-#2DE29
2DE2A CJK UNIFIED IDEOGRAPH-#2DE2A
2DE2B CJK UNIFIED IDEOGRAPH-#2DE2B
2DE2C CJK UNIFIED IDEOGRAPH-#2DE2C
2DE2D CJK UNIFIED IDEOGRAPH-#2DE2D
2DE2E CJK UNIFIED IDEOGRAPH-#2DE2E
2DE2F CJK UNIFIED IDEOGRAPH-#2DE2F
2DE30 CJK UNIFIED IDEOGRAPH-#2DE30
2DE31 CJK UNIFIED IDEOGRAPH-#2DE31
2DE32 CJK UNIFIED IDEOGRAPH-#2DE32
2DE33 CJK UNIFIED IDEOGRAPH-#2DE33
2DE34 CJK UNIFIED IDEOGRAPH-#2DE34
2DE35 CJK UNIFIED IDEOGRAPH-#2DE35
2DE36 CJK UNIFIED IDEOGRAPH-#2DE36
2DE37 CJK UNIFIED IDEOGRAPH-#2DE37
2DE38 CJK UNIFIED IDEOGRAPH-#2DE38
2DE39 CJK UNIFIED IDEOGRAPH-#2DE39
2DE3A CJK UNIFIED IDEOGRAPH-#2DE3A
2DE3B CJK UNIFIED IDEOGRAPH-#2DE3B
2DE3C CJK UNIFIED IDEOGRAPH-#2DE3C
2DE3D CJK UNIFIED IDEOGRAPH-#2DE3D
2DE3E CJK UNIFIED IDEOGRAPH-#2DE3E
2DE3F CJK UNIFIED IDEOGRAPH-#2DE3F
2DE40 CJK UNIFIED IDEOGRAPH-#2DE40
2DE41 CJK UNIFIED IDEOGRAPH-#2DE41
2DE42 CJK UNIFIED IDEOGRAPH-#2DE42
2DE43 CJK UNIFIED IDEOGRAPH-#2DE43
2DE44 CJK UNIFIED IDEOGRAPH-#2DE44
2DE45 CJK UNIFIED IDEOGRAPH-#2DE45
2DE46 CJK UNIFIED IDEOGRAPH-#2DE46
2DE47 CJK UNIFIED IDEOGRAPH-#2DE47
2DE48 CJK UNIFIED IDEOGRAPH-#2DE48
2DE49 CJK UNIFIED IDEOGRAPH-#2DE49
2DE4A CJK UNIFIED IDEOGRAPH-#2DE4A
2DE4B CJK UNIFIED IDEOGRAPH-#2DE4B
2DE4C CJK UNIFIED IDEOGRAPH-#2DE4C
2DE4D CJK UNIFIED IDEOGRAPH-#2DE4D
2DE4E CJK UNIFIED IDEOGRAPH-#2DE4E
2DE4F CJK UNIFIED IDEOGRAPH-#2DE4F
2DE50 CJK UNIFIED IDEOGRAPH-#2DE50
2DE51 CJK UNIFIED IDEOGRAPH-#2DE51
2DE52 CJK UNIFIED IDEOGRAPH-#2DE52
2DE53 CJK UNIFIED IDEOGRAPH-#2DE53
2DE54 CJK UNIFIED IDEOGRAPH-#2DE54
2DE55 CJK UNIFIED IDEOGRAPH-#2DE55
2DE56 CJK UNIFIED IDEOGRAPH-#2DE56
2DE57 CJK UNIFIED IDEOGRAPH-#2DE57
2DE58 CJK UNIFIED IDEOGRAPH-#2DE58
2DE59 CJK UNIFIED IDEOGRAPH-#2DE59
2DE5A CJK UNIFIED IDEOGRAPH-#2DE5A
2DE5B CJK UNIFIED IDEOGRAPH-#2DE5B
2DE5C CJK UNIFIED IDEOGRAPH-#2DE5C
2DE5D CJK UNIFIED IDEOGRAPH-#2DE5D
2DE5E CJK UNIFIED IDEOGRAPH-#2DE5E
2DE5F CJK UNIFIED IDEOGRAPH-#2DE5F
2DE60 CJK UNIFIED IDEOGRAPH-#2DE60
2DE61 CJK UNIFIED IDEOGRAPH-#2DE61
2DE62 CJK UNIFIED IDEOGRAPH-#2DE62
2DE63 CJK UNIFIED IDEOGRAPH-#2DE63
2DE64 CJK UNIFIED IDEOGRAPH-#2DE64
2DE65 CJK UNIFIED IDEOGRAPH-#2DE65
2DE66 CJK UNIFIED IDEOGRAPH-#2DE66
2DE67 CJK UNIFIED IDEOGRAPH-#2DE67
2DE68 CJK UNIFIED IDEOGRAPH-#2DE68
2DE69 CJK UNIFIED IDEOGRAPH-#2DE69
2DE6A CJK UNIFIED IDEOGRAPH-#2DE6A
2DE6B CJK UNIFIED IDEOGRAPH-#2DE6B
2DE6C CJK UNIFIED IDEOGRAPH-#2DE6C
2DE6D CJK UNIFIED IDEOGRAPH-#2DE6D
2DE6E CJK UNIFIED IDEOGRAPH-#2DE6E
2DE6F CJK UNIFIED IDEOGRAPH-#2DE6F
2DE70 CJK UNIFIED IDEOGRAPH-#2DE70
2DE71 CJK UNIFIED IDEOGRAPH-#2DE71
2DE72 CJK UNIFIED IDEOGRAPH-#2DE72
2DE73 CJK UNIFIED IDEOGRAPH-#2DE73
2DE74 CJK UNIFIED IDEOGRAPH-#2DE74
2DE75 CJK UNIFIED IDEOGRAPH-#2DE75
2DE76 CJK UNIFIED IDEOGRAPH-#2DE76
2DE77 CJK UNIFIED IDEOGRAPH-#2DE77
2DE78 CJK UNIFIED IDEOGRAPH-#2DE78
2DE79 CJK UNIFIED IDEOGRAPH-#2DE79
2DE7A CJK UNIFIED IDEOGRAPH-#2DE7A
2DE7B CJK UNIFIED IDEOGRAPH-#2DE7B
2DE7C CJK UNIFIED IDEOGRAPH-#2DE7C
2DE7D CJK UNIFIED IDEOGRAPH-#2DE7D
2DE7E CJK UNIFIED IDEOGRAPH-#2DE7E
2DE7F CJK UNIFIED IDEOGRAPH-#2DE7F
2DE80 CJK UNIFIED IDEOGRAPH-#2DE80
2DE81 CJK UNIFIED IDEOGRAPH-#2DE81
2DE82 CJK UNIFIED IDEOGRAPH-#2DE82
2DE83 CJK UNIFIED IDEOGRAPH-#2DE83
2DE84 CJK UNIFIED IDEOGRAPH-#2DE84
2DE85 CJK UNIFIED IDEOGRAPH-#2DE85
2DE86 CJK UNIFIED IDEOGRAPH-#2DE86
2DE87 CJK UNIFIED IDEOGRAPH-#2DE87
2DE88 CJK UNIFIED IDEOGRAPH-#2DE88
2DE89 CJK UNIFIED IDEOGRAPH-#2DE89
2DE8A CJK UNIFIED IDEOGRAPH-#2DE8A
2DE8B CJK UNIFIED IDEOGRAPH-#2DE8B
2DE8C CJK UNIFIED IDEOGRAPH-#2DE8C
2DE8D CJK UNIFIED IDEOGRAPH-#2DE8D
2DE8E CJK UNIFIED IDEOGRAPH-#2DE8E
2DE8F CJK UNIFIED IDEOGRAPH-#2DE8F
2DE90 CJK UNIFIED IDEOGRAPH-#2DE90
2DE91 CJK UNIFIED IDEOGRAPH-#2DE91
2DE92 CJK UNIFIED IDEOGRAPH-#2DE92
2DE93 CJK UNIFIED IDEOGRAPH-#2DE93
2DE94 CJK UNIFIED IDEOGRAPH-#2DE94
2DE95 CJK UNIFIED IDEOGRAPH-#2DE95
2DE96 CJK UNIFIED IDEOGRAPH-#2DE96
2DE97 CJK UNIFIED IDEOGRAPH-#2DE97
2DE98 CJK UNIFIED IDEOGRAPH-#2DE98
2DE99 CJK UNIFIED IDEOGRAPH-#2DE99
2DE9A CJK UNIFIED IDEOGRAPH-#2DE9A
2DE9B CJK UNIFIED IDEOGRAPH-#2DE9B
2DE9C CJK UNIFIED IDEOGRAPH-#2DE9C
2DE9D CJK UNIFIED IDEOGRAPH-#2DE9D
2DE9E CJK UNIFIED IDEOGRAPH-#2DE9E
2DE9F CJK UNIFIED IDEOGRAPH-#2DE9F
2DEA0 CJK UNIFIED IDEOGRAPH-#2DEA0
2DEA1 CJK UNIFIED IDEOGRAPH-#2DEA1
2DEA2 CJK UNIFIED IDEOGRAPH-#2DEA2
2DEA3 CJK UNIFIED IDEOGRAPH-#2DEA3
2DEA4 CJK UNIFIED IDEOGRAPH-#2DEA4
2DEA5 CJK UNIFIED IDEOGRAPH-#2DEA5
2DEA6 CJK UNIFIED IDEOGRAPH-#2DEA6
2DEA7 CJK UNIFIED IDEOGRAPH-#2DEA7
2DEA8 CJK UNIFIED IDEOGRAPH-#2DEA8
2DEA9 CJK UNIFIED IDEOGRAPH-#2DEA9
2DEAA CJK UNIFIED IDEOGRAPH-#2DEAA
2DEAB CJK UNIFIED IDEOGRAPH-#2DEAB
2DEAC CJK UNIFIED IDEOGRAPH-#2DEAC
2DEAD CJK UNIFIED IDEOGRAPH-#2DEAD
2DEAE CJK UNIFIED IDEOGRAPH-#2DEAE
2DEAF CJK UNIFIED IDEOGRAPH-#2DEAF
2DEB0 CJK UNIFIED IDEOGRAPH-#2DEB0
2DEB1 CJK UNIFIED IDEOGRAPH-#2DEB1
2DEB2 CJK UNIFIED IDEOGRAPH-#2DEB2
2DEB3 CJK UNIFIED IDEOGRAPH-#2DEB3
2DEB4 CJK UNIFIED IDEOGRAPH-#2DEB4
2DEB5 CJK UNIFIED IDEOGRAPH-#2DEB5
2DEB6 CJK UNIFIED IDEOGRAPH-#2DEB6
2DEB7 CJK UNIFIED IDEOGRAPH-#2DEB7
2DEB8 CJK UNIFIED IDEOGRAPH-#2DEB8
2DEB9 CJK UNIFIED IDEOGRAPH-#2DEB9
2DEBA CJK UNIFIED IDEOGRAPH-#2DEBA
2DEBB CJK UNIFIED IDEOGRAPH-#2DEBB
2DEBC CJK UNIFIED IDEOGRAPH-#2DEBC
2DEBD CJK UNIFIED IDEOGRAPH-#2DEBD
2DEBE CJK UNIFIED IDEOGRAPH-#2DEBE
2DEBF CJK UNIFIED IDEOGRAPH-#2DEBF
2DEC0 CJK UNIFIED IDEOGRAPH-#2DEC0
2DEC1 CJK UNIFIED IDEOGRAPH-#2DEC1
2DEC2 CJK UNIFIED IDEOGRAPH-#2DEC2
2DEC3 CJK UNIFIED IDEOGRAPH-#2DEC3
2DEC4 CJK UNIFIED IDEOGRAPH-#2DEC4
2DEC5 CJK UNIFIED IDEOGRAPH-#2DEC5
2DEC6 CJK UNIFIED IDEOGRAPH-#2DEC6
2DEC7 CJK UNIFIED IDEOGRAPH-#2DEC7
2DEC8 CJK UNIFIED IDEOGRAPH-#2DEC8
2DEC9 CJK UNIFIED IDEOGRAPH-#2DEC9
2DECA CJK UNIFIED IDEOGRAPH-#2DECA
2DECB CJK UNIFIED IDEOGRAPH-#2DECB
2DECC CJK UNIFIED IDEOGRAPH-#2DECC
2DECD CJK UNIFIED IDEOGRAPH-#2DECD
2DECE CJK UNIFIED IDEOGRAPH-#2DECE
2DECF CJK UNIFIED IDEOGRAPH-#2DECF
2DED0 CJK UNIFIED IDEOGRAPH-#2DED0
2DED1 CJK UNIFIED IDEOGRAPH-#2DED1
2DED2 CJK UNIFIED IDEOGRAPH-#2DED2
2DED3 CJK UNIFIED IDEOGRAPH-#2DED3
2DED4 CJK UNIFIED IDEOGRAPH-#2DED4
2DED5 CJK UNIFIED IDEOGRAPH-#2DED5
2DED6 CJK UNIFIED IDEOGRAPH-#2DED6
2DED7 CJK UNIFIED IDEOGRAPH-#2DED7
2DED8 CJK UNIFIED IDEOGRAPH-#2DED8
2DED9 CJK UNIFIED IDEOGRAPH-#2DED9
2DEDA CJK UNIFIED IDEOGRAPH-#2DEDA
2DEDB CJK UNIFIED IDEOGRAPH-#2DEDB
2DEDC CJK UNIFIED IDEOGRAPH-#2DEDC
2DEDD CJK UNIFIED IDEOGRAPH-#2DEDD
2DEDE CJK UNIFIED IDEOGRAPH-#2DEDE
2DEDF CJK UNIFIED IDEOGRAPH-#2DEDF
2DEE0 CJK UNIFIED IDEOGRAPH-#2DEE0
2DEE1 CJK UNIFIED IDEOGRAPH-#2DEE1
2DEE2 CJK UNIFIED IDEOGRAPH-#2DEE2
2DEE3 CJK UNIFIED IDEOGRAPH-#2DEE3
2DEE4 CJK UNIFIED IDEOGRAPH-#2DEE4
2DEE5 CJK UNIFIED IDEOGRAPH-#2DEE5
2DEE6 CJK UNIFIED IDEOGRAPH-#2DEE6
2DEE7 CJK UNIFIED IDEOGRAPH-#2DEE7
2DEE8 CJK UNIFIED IDEOGRAPH-#2DEE8
2DEE9 CJK UNIFIED IDEOGRAPH-#2DEE9
2DEEA CJK UNIFIED IDEOGRAPH-#2DEEA
2DEEB CJK UNIFIED IDEOGRAPH-#2DEEB
2DEEC CJK UNIFIED IDEOGRAPH-#2DEEC
2DEED CJK UNIFIED IDEOGRAPH-#2DEED
2DEEE CJK UNIFIED IDEOGRAPH-#2DEEE
2DEEF CJK UNIFIED IDEOGRAPH-#2DEEF
2DEF0 CJK UNIFIED IDEOGRAPH-#2DEF0
2DEF1 CJK UNIFIED IDEOGRAPH-#2DEF1
2DEF2 CJK UNIFIED IDEOGRAPH-#2DEF2
2DEF3 CJK UNIFIED IDEOGRAPH-#2DEF3
2DEF4 CJK UNIFIED IDEOGRAPH-#2DEF4
2DEF5 CJK UNIFIED IDEOGRAPH-#2DEF5
2DEF6 CJK UNIFIED IDEOGRAPH-#2DEF6
2DEF7 CJK UNIFIED IDEOGRAPH-#2DEF7
2DEF8 CJK UNIFIED IDEOGRAPH-#2DEF8
2DEF9 CJK UNIFIED IDEOGRAPH-#2DEF9
2DEFA CJK UNIFIED IDEOGRAPH-#2DEFA
2DEFB CJK UNIFIED IDEOGRAPH-#2DEFB
2DEFC CJK UNIFIED IDEOGRAPH-#2DEFC
2DEFD CJK UNIFIED IDEOGRAPH-#2DEFD
2DEFE CJK UNIFIED IDEOGRAPH-#2DEFE
2DEFF CJK UNIFIED IDEOGRAPH-#2DEFF
2DF00 CJK UNIFIED IDEOGRAPH-#2DF00
2DF01 CJK UNIFIED IDEOGRAPH-#2DF01
2DF02 CJK UNIFIED IDEOGRAPH-#2DF02
2DF03 CJK UNIFIED IDEOGRAPH-#2DF03
2DF04 CJK UNIFIED IDEOGRAPH-#2DF04
2DF05 CJK UNIFIED IDEOGRAPH-#2DF05
2DF06 CJK UNIFIED IDEOGRAPH-#2DF06
2DF07 CJK UNIFIED IDEOGRAPH-#2DF07
2DF08 CJK UNIFIED IDEOGRAPH-#2DF08
2DF09 CJK UNIFIED IDEOGRAPH-#2DF09
2DF0A CJK UNIFIED IDEOGRAPH-#2DF0A
2DF0B CJK UNIFIED IDEOGRAPH-#2DF0B
2DF0C CJK UNIFIED IDEOGRAPH-#2DF0C
2DF0D CJK UNIFIED IDEOGRAPH-#2DF0D
2DF0E CJK UNIFIED IDEOGRAPH-#2DF0E
2DF0F CJK UNIFIED IDEOGRAPH-#2DF0F
2DF10 CJK UNIFIED IDEOGRAPH-#2DF10
2DF11 CJK UNIFIED IDEOGRAPH-#2DF11
2DF12 CJK UNIFIED IDEOGRAPH-#2DF12
2DF13 CJK UNIFIED IDEOGRAPH-#2DF13
2DF14 CJK UNIFIED IDEOGRAPH-#2DF14
2DF15 CJK UNIFIED IDEOGRAPH-#2DF15
2DF16 CJK UNIFIED IDEOGRAPH-#2DF16
2DF17 CJK UNIFIED IDEOGRAPH-#2DF17
2DF18 CJK UNIFIED IDEOGRAPH-#2DF18
2DF19 CJK UNIFIED IDEOGRAPH-#2DF19
2DF1A CJK UNIFIED IDEOGRAPH-#2DF1A
2DF1B CJK UNIFIED IDEOGRAPH-#2DF1B
2DF1C CJK UNIFIED IDEOGRAPH-#2DF1C
2DF1D CJK UNIFIED IDEOGRAPH-#2DF1D
2DF1E CJK UNIFIED IDEOGRAPH-#2DF1E
2DF1F CJK UNIFIED IDEOGRAPH-#2DF1F
2DF20 CJK UNIFIED IDEOGRAPH-#2DF20
2DF21 CJK UNIFIED IDEOGRAPH-#2DF21
2DF22 CJK UNIFIED IDEOGRAPH-#2DF22
2DF23 CJK UNIFIED IDEOGRAPH-#2DF23
2DF24 CJK UNIFIED IDEOGRAPH-#2DF24
2DF25 CJK UNIFIED IDEOGRAPH-#2DF25
2DF26 CJK UNIFIED IDEOGRAPH-#2DF26
2DF27 CJK UNIFIED IDEOGRAPH-#2DF27
2DF28 CJK UNIFIED IDEOGRAPH-#2DF28
2DF29 CJK UNIFIED IDEOGRAPH-#2DF29
2DF2A CJK UNIFIED IDEOGRAPH-#2DF2A
2DF2B CJK UNIFIED IDEOGRAPH-#2DF2B
2DF2C CJK UNIFIED IDEOGRAPH-#2DF2C
2DF2D CJK UNIFIED IDEOGRAPH-#2DF2D
2DF2E CJK UNIFIED IDEOGRAPH-#2DF2E
2DF2F CJK UNIFIED IDEOGRAPH-#2DF2F
2DF30 CJK UNIFIED IDEOGRAPH-#2DF30
2DF31 CJK UNIFIED IDEOGRAPH-#2DF31
2DF32 CJK UNIFIED IDEOGRAPH-#2DF32
2DF33 CJK UNIFIED IDEOGRAPH-#2DF33
2DF34 CJK UNIFIED IDEOGRAPH-#2DF34
2DF35 CJK UNIFIED IDEOGRAPH-#2DF35
2DF36 CJK UNIFIED IDEOGRAPH-#2DF36
2DF37 CJK UNIFIED IDEOGRAPH-#2DF37
2DF38 CJK UNIFIED IDEOGRAPH-#2DF38
2DF39 CJK UNIFIED IDEOGRAPH-#2DF39
2DF3A CJK UNIFIED IDEOGRAPH-#2DF3A
2DF3B CJK UNIFIED IDEOGRAPH-#2DF3B
2DF3C CJK UNIFIED IDEOGRAPH-#2DF3C
2DF3D CJK UNIFIED IDEOGRAPH-#2DF3D
2DF3E CJK UNIFIED IDEOGRAPH-#2DF3E
2DF3F CJK UNIFIED IDEOGRAPH-#2DF3F
2DF40 CJK UNIFIED IDEOGRAPH-#2DF40
2DF41 CJK UNIFIED IDEOGRAPH-#2DF41
2DF42 CJK UNIFIED IDEOGRAPH-#2DF42
2DF43 CJK UNIFIED IDEOGRAPH-#2DF43
2DF44 CJK UNIFIED IDEOGRAPH-#2DF44
2DF45 CJK UNIFIED IDEOGRAPH-#2DF45
2DF46 CJK UNIFIED IDEOGRAPH-#2DF46
2DF47 CJK UNIFIED IDEOGRAPH-#2DF47
2DF48 CJK UNIFIED IDEOGRAPH-#2DF48
2DF49 CJK UNIFIED IDEOGRAPH-#2DF49
2DF4A CJK UNIFIED IDEOGRAPH-#2DF4A
2DF4B CJK UNIFIED IDEOGRAPH-#2DF4B
2DF4C CJK UNIFIED IDEOGRAPH-#2DF4C
2DF4D CJK UNIFIED IDEOGRAPH-#2DF4D
2DF4E CJK UNIFIED IDEOGRAPH-#2DF4E
2DF4F CJK UNIFIED IDEOGRAPH-#2DF4F
2DF50 CJK UNIFIED IDEOGRAPH-#2DF50
2DF51 CJK UNIFIED IDEOGRAPH-#2DF51
2DF52 CJK UNIFIED IDEOGRAPH-#2DF52
2DF53 CJK UNIFIED IDEOGRAPH-#2DF53
2DF54 CJK UNIFIED IDEOGRAPH-#2DF54
2DF55 CJK UNIFIED IDEOGRAPH-#2DF55
2DF56 CJK UNIFIED IDEOGRAPH-#2DF56
2DF57 CJK UNIFIED IDEOGRAPH-#2DF57
2DF58 CJK UNIFIED IDEOGRAPH-#2DF58
2DF59 CJK UNIFIED IDEOGRAPH-#2DF59
2DF5A CJK UNIFIED IDEOGRAPH-#2DF5A
2DF5B CJK UNIFIED IDEOGRAPH-#2DF5B
2DF5C CJK UNIFIED IDEOGRAPH-#2DF5C
2DF5D CJK UNIFIED IDEOGRAPH-#2DF5D
2DF5E CJK UNIFIED IDEOGRAPH-#2DF5E
2DF5F CJK UNIFIED IDEOGRAPH-#2DF5F
2DF60 CJK UNIFIED IDEOGRAPH-#2DF60
2DF61 CJK UNIFIED IDEOGRAPH-#2DF61
2DF62 CJK UNIFIED IDEOGRAPH-#2DF62
2DF63 CJK UNIFIED IDEOGRAPH-#2DF63
2DF64 CJK UNIFIED IDEOGRAPH-#2DF64
2DF65 CJK UNIFIED IDEOGRAPH-#2DF65
2DF66 CJK UNIFIED IDEOGRAPH-#2DF66
2DF67 CJK UNIFIED IDEOGRAPH-#2DF67
2DF68 CJK UNIFIED IDEOGRAPH-#2DF68
2DF69 CJK UNIFIED IDEOGRAPH-#2DF69
2DF6A CJK UNIFIED IDEOGRAPH-#2DF6A
2DF6B CJK UNIFIED IDEOGRAPH-#2DF6B
2DF6C CJK UNIFIED IDEOGRAPH-#2DF6C
2DF6D CJK UNIFIED IDEOGRAPH-#2DF6D
2DF6E CJK UNIFIED IDEOGRAPH-#2DF6E
2DF6F CJK UNIFIED IDEOGRAPH-#2DF6F
2DF70 CJK UNIFIED IDEOGRAPH-#2DF70
2DF71 CJK UNIFIED IDEOGRAPH-#2DF71
2DF72 CJK UNIFIED IDEOGRAPH-#2DF72
2DF73 CJK UNIFIED IDEOGRAPH-#2DF73
2DF74 CJK UNIFIED IDEOGRAPH-#2DF74
2DF75 CJK UNIFIED IDEOGRAPH-#2DF75
2DF76 CJK UNIFIED IDEOGRAPH-#2DF76
2DF77 CJK UNIFIED IDEOGRAPH-#2DF77
2DF78 CJK UNIFIED IDEOGRAPH-#2DF78
2DF79 CJK UNIFIED IDEOGRAPH-#2DF79
2DF7A CJK UNIFIED IDEOGRAPH-#2DF7A
2DF7B CJK UNIFIED IDEOGRAPH-#2DF7B
2DF7C CJK UNIFIED IDEOGRAPH-#2DF7C
2DF7D CJK UNIFIED IDEOGRAPH-#2DF7D
2DF7E CJK UNIFIED IDEOGRAPH-#2DF7E
2DF7F CJK UNIFIED IDEOGRAPH-#2DF7F
2DF80 CJK UNIFIED IDEOGRAPH-#2DF80
2DF81 CJK UNIFIED IDEOGRAPH-#2DF81
2DF82 CJK UNIFIED IDEOGRAPH-#2DF82
2DF83 CJK UNIFIED IDEOGRAPH-#2DF83
2DF84 CJK UNIFIED IDEOGRAPH-#2DF84
2DF85 CJK UNIFIED IDEOGRAPH-#2DF85
2DF86 CJK UNIFIED IDEOGRAPH-#2DF86
2DF87 CJK UNIFIED IDEOGRAPH-#2DF87
2DF88 CJK UNIFIED IDEOGRAPH-#2DF88
2DF89 CJK UNIFIED IDEOGRAPH-#2DF89
2DF8A CJK UNIFIED IDEOGRAPH-#2DF8A
2DF8B CJK UNIFIED IDEOGRAPH-#2DF8B
2DF8C CJK UNIFIED IDEOGRAPH-#2DF8C
2DF8D CJK UNIFIED IDEOGRAPH-#2DF8D
2DF8E CJK UNIFIED IDEOGRAPH-#2DF8E
2DF8F CJK UNIFIED IDEOGRAPH-#2DF8F
2DF90 CJK UNIFIED IDEOGRAPH-#2DF90
2DF91 CJK UNIFIED IDEOGRAPH-#2DF91
2DF92 CJK UNIFIED IDEOGRAPH-#2DF92
2DF93 CJK UNIFIED IDEOGRAPH-#2DF93
2DF94 CJK UNIFIED IDEOGRAPH-#2DF94
2DF95 CJK UNIFIED IDEOGRAPH-#2DF95
2DF96 CJK UNIFIED IDEOGRAPH-#2DF96
2DF97 CJK UNIFIED IDEOGRAPH-#2DF97
2DF98 CJK UNIFIED IDEOGRAPH-#2DF98
2DF99 CJK UNIFIED IDEOGRAPH-#2DF99
2DF9A CJK UNIFIED IDEOGRAPH-#2DF9A
2DF9B CJK UNIFIED IDEOGRAPH-#2DF9B
2DF9C CJK UNIFIED IDEOGRAPH-#2DF9C
2DF9D CJK UNIFIED IDEOGRAPH-#2DF9D
2DF9E CJK UNIFIED IDEOGRAPH-#2DF9E
2DF9F CJK UNIFIED IDEOGRAPH-#2DF9F
2DFA0 CJK UNIFIED IDEOGRAPH-#2DFA0
2DFA1 CJK UNIFIED IDEOGRAPH-#2DFA1
2DFA2 CJK UNIFIED IDEOGRAPH-#2DFA2
2DFA3 CJK UNIFIED IDEOGRAPH-#2DFA3
2DFA4 CJK UNIFIED IDEOGRAPH-#2DFA4
2DFA5 CJK UNIFIED IDEOGRAPH-#2DFA5
2DFA6 CJK UNIFIED IDEOGRAPH-#2DFA6
2DFA7 CJK UNIFIED IDEOGRAPH-#2DFA7
2DFA8 CJK UNIFIED IDEOGRAPH-#2DFA8
2DFA9 CJK UNIFIED IDEOGRAPH-#2DFA9
2DFAA CJK UNIFIED IDEOGRAPH-#2DFAA
2DFAB CJK UNIFIED IDEOGRAPH-#2DFAB
2DFAC CJK UNIFIED IDEOGRAPH-#2DFAC
2DFAD CJK UNIFIED IDEOGRAPH-#2DFAD
2DFAE CJK UNIFIED IDEOGRAPH-#2DFAE
2DFAF CJK UNIFIED IDEOGRAPH-#2DFAF
2DFB0 CJK UNIFIED IDEOGRAPH-#2DFB0
2DFB1 CJK UNIFIED IDEOGRAPH-#2DFB1
2DFB2 CJK UNIFIED IDEOGRAPH-#2DFB2
2DFB3 CJK UNIFIED IDEOGRAPH-#2DFB3
2DFB4 CJK UNIFIED IDEOGRAPH-#2DFB4
2DFB5 CJK UNIFIED IDEOGRAPH-#2DFB5
2DFB6 CJK UNIFIED IDEOGRAPH-#2DFB6
2DFB7 CJK UNIFIED IDEOGRAPH-#2DFB7
2DFB8 CJK UNIFIED IDEOGRAPH-#2DFB8
2DFB9 CJK UNIFIED IDEOGRAPH-#2DFB9
2DFBA CJK UNIFIED IDEOGRAPH-#2DFBA
2DFBB CJK UNIFIED IDEOGRAPH-#2DFBB
2DFBC CJK UNIFIED IDEOGRAPH-#2DFBC
2DFBD CJK UNIFIED IDEOGRAPH-#2DFBD
2DFBE CJK UNIFIED IDEOGRAPH-#2DFBE
2DFBF CJK UNIFIED IDEOGRAPH-#2DFBF
2DFC0 CJK UNIFIED IDEOGRAPH-#2DFC0
2DFC1 CJK UNIFIED IDEOGRAPH-#2DFC1
2DFC2 CJK UNIFIED IDEOGRAPH-#2DFC2
2DFC3 CJK UNIFIED IDEOGRAPH-#2DFC3
2DFC4 CJK UNIFIED IDEOGRAPH-#2DFC4
2DFC5 CJK UNIFIED IDEOGRAPH-#2DFC5
2DFC6 CJK UNIFIED IDEOGRAPH-#2DFC6
2DFC7 CJK UNIFIED IDEOGRAPH-#2DFC7
2DFC8 CJK UNIFIED IDEOGRAPH-#2DFC8
2DFC9 CJK UNIFIED IDEOGRAPH-#2DFC9
2DFCA CJK UNIFIED IDEOGRAPH-#2DFCA
2DFCB CJK UNIFIED IDEOGRAPH-#2DFCB
2DFCC CJK UNIFIED IDEOGRAPH-#2DFCC
2DFCD CJK UNIFIED IDEOGRAPH-#2DFCD
2DFCE CJK UNIFIED IDEOGRAPH-#2DFCE
2DFCF CJK UNIFIED IDEOGRAPH-#2DFCF
2DFD0 CJK UNIFIED IDEOGRAPH-#2DFD0
2DFD1 CJK UNIFIED IDEOGRAPH-#2DFD1
2DFD2 CJK UNIFIED IDEOGRAPH-#2DFD2
2DFD3 CJK UNIFIED IDEOGRAPH-#2DFD3
2DFD4 CJK UNIFIED IDEOGRAPH-#2DFD4
2DFD5 CJK UNIFIED IDEOGRAPH-#2DFD5
2DFD6 CJK UNIFIED IDEOGRAPH-#2DFD6
2DFD7 CJK UNIFIED IDEOGRAPH-#2DFD7
2DFD8 CJK UNIFIED IDEOGRAPH-#2DFD8
2DFD9 CJK UNIFIED IDEOGRAPH-#2DFD9
2DFDA CJK UNIFIED IDEOGRAPH-#2DFDA
2DFDB CJK UNIFIED IDEOGRAPH-#2DFDB
2DFDC CJK UNIFIED IDEOGRAPH-#2DFDC
2DFDD CJK UNIFIED IDEOGRAPH-#2DFDD
2DFDE CJK UNIFIED IDEOGRAPH-#2DFDE
2DFDF CJK UNIFIED IDEOGRAPH-#2DFDF
2DFE0 CJK UNIFIED IDEOGRAPH-#2DFE0
2DFE1 CJK UNIFIED IDEOGRAPH-#2DFE1
2DFE2 CJK UNIFIED IDEOGRAPH-#2DFE2
2DFE3 CJK UNIFIED IDEOGRAPH-#2DFE3
2DFE4 CJK UNIFIED IDEOGRAPH-#2DFE4
2DFE5 CJK UNIFIED IDEOGRAPH-#2DFE5
2DFE6 CJK UNIFIED IDEOGRAPH-#2DFE6
2DFE7 CJK UNIFIED IDEOGRAPH-#2DFE7
2DFE8 CJK UNIFIED IDEOGRAPH-#2DFE8
2DFE9 CJK UNIFIED IDEOGRAPH-#2DFE9
2DFEA CJK UNIFIED IDEOGRAPH-#2DFEA
2DFEB CJK UNIFIED IDEOGRAPH-#2DFEB
2DFEC CJK UNIFIED IDEOGRAPH-#2DFEC
2DFED CJK UNIFIED IDEOGRAPH-#2DFED
2DFEE CJK UNIFIED IDEOGRAPH-#2DFEE
2DFEF CJK UNIFIED IDEOGRAPH-#2DFEF
2DFF0 CJK UNIFIED IDEOGRAPH-#2DFF0
2DFF1 CJK UNIFIED IDEOGRAPH-#2DFF1
2DFF2 CJK UNIFIED IDEOGRAPH-#2DFF2
2DFF3 CJK UNIFIED IDEOGRAPH-#2DFF3
2DFF4 CJK UNIFIED IDEOGRAPH-#2DFF4
2DFF5 CJK UNIFIED IDEOGRAPH-#2DFF5
2DFF6 CJK UNIFIED IDEOGRAPH-#2DFF6
2DFF7 CJK UNIFIED IDEOGRAPH-#2DFF7
2DFF8 CJK UNIFIED IDEOGRAPH-#2DFF8
2DFF9 CJK UNIFIED IDEOGRAPH-#2DFF9
2DFFA CJK UNIFIED IDEOGRAPH-#2DFFA
2DFFB CJK UNIFIED IDEOGRAPH-#2DFFB
2DFFC CJK UNIFIED IDEOGRAPH-#2DFFC
2DFFD CJK UNIFIED IDEOGRAPH-#2DFFD
2DFFE CJK UNIFIED IDEOGRAPH-#2DFFE
2DFFF CJK UNIFIED IDEOGRAPH-#2DFFF
2E000 CJK UNIFIED IDEOGRAPH-#2E000
2E001 CJK UNIFIED IDEOGRAPH-#2E001
2E002 CJK UNIFIED IDEOGRAPH-#2E002
2E003 CJK UNIFIED IDEOGRAPH-#2E003
2E004 CJK UNIFIED IDEOGRAPH-#2E004
2E005 CJK UNIFIED IDEOGRAPH-#2E005
2E006 CJK UNIFIED IDEOGRAPH-#2E006
2E007 CJK UNIFIED IDEOGRAPH-#2E007
2E008 CJK UNIFIED IDEOGRAPH-#2E008
2E009 CJK UNIFIED IDEOGRAPH-#2E009
2E00A CJK UNIFIED IDEOGRAPH-#2E00A
2E00B CJK UNIFIED IDEOGRAPH-#2E00B
2E00C CJK UNIFIED IDEOGRAPH-#2E00C
2E00D CJK UNIFIED IDEOGRAPH-#2E00D
2E00E CJK UNIFIED IDEOGRAPH-#2E00E
2E00F CJK UNIFIED IDEOGRAPH-#2E00F
2E010 CJK UNIFIED IDEOGRAPH-#2E010
2E011 CJK UNIFIED IDEOGRAPH-#2E011
2E012 CJK UNIFIED IDEOGRAPH-#2E012
2E013 CJK UNIFIED IDEOGRAPH-#2E013
2E014 CJK UNIFIED IDEOGRAPH-#2E014
2E015 CJK UNIFIED IDEOGRAPH-#2E015
2E016 CJK UNIFIED IDEOGRAPH-#2E016
2E017 CJK UNIFIED IDEOGRAPH-#2E017
2E018 CJK UNIFIED IDEOGRAPH-#2E018
2E019 CJK UNIFIED IDEOGRAPH-#2E019
2E01A CJK UNIFIED IDEOGRAPH-#2E01A
2E01B CJK UNIFIED IDEOGRAPH-#2E01B
2E01C CJK UNIFIED IDEOGRAPH-#2E01C
2E01D CJK UNIFIED IDEOGRAPH-#2E01D
2E01E CJK UNIFIED IDEOGRAPH-#2E01E
2E01F CJK UNIFIED IDEOGRAPH-#2E01F
2E020 CJK UNIFIED IDEOGRAPH-#2E020
2E021 CJK UNIFIED IDEOGRAPH-#2E021
2E022 CJK UNIFIED IDEOGRAPH-#2E022
2E023 CJK UNIFIED IDEOGRAPH-#2E023
2E024 CJK UNIFIED IDEOGRAPH-#2E024
2E025 CJK UNIFIED IDEOGRAPH-#2E025
2E026 CJK UNIFIED IDEOGRAPH-#2E026
2E027 CJK UNIFIED IDEOGRAPH-#2E027
2E028 CJK UNIFIED IDEOGRAPH-#2E028
2E029 CJK UNIFIED IDEOGRAPH-#2E029
2E02A CJK UNIFIED IDEOGRAPH-#2E02A
2E02B CJK UNIFIED IDEOGRAPH-#2E02B
2E02C CJK UNIFIED IDEOGRAPH-#2E02C
2E02D CJK UNIFIED IDEOGRAPH-#2E02D
2E02E CJK UNIFIED IDEOGRAPH-#2E02E
2E02F CJK UNIFIED IDEOGRAPH-#2E02F
2E030 CJK UNIFIED IDEOGRAPH-#2E030
2E031 CJK UNIFIED IDEOGRAPH-#2E031
2E032 CJK UNIFIED IDEOGRAPH-#2E032
2E033 CJK UNIFIED IDEOGRAPH-#2E033
2E034 CJK UNIFIED IDEOGRAPH-#2E034
2E035 CJK UNIFIED IDEOGRAPH-#2E035
2E036 CJK UNIFIED IDEOGRAPH-#2E036
2E037 CJK UNIFIED IDEOGRAPH-#2E037
2E038 CJK UNIFIED IDEOGRAPH-#2E038
2E039 CJK UNIFIED IDEOGRAPH-#2E039
2E03A CJK UNIFIED IDEOGRAPH-#2E03A
2E03B CJK UNIFIED IDEOGRAPH-#2E03B
2E03C CJK UNIFIED IDEOGRAPH-#2E03C
2E03D CJK UNIFIED IDEOGRAPH-#2E03D
2E03E CJK UNIFIED IDEOGRAPH-#2E03E
2E03F CJK UNIFIED IDEOGRAPH-#2E03F
2E040 CJK UNIFIED IDEOGRAPH-#2E040
2E041 CJK UNIFIED IDEOGRAPH-#2E041
2E042 CJK UNIFIED IDEOGRAPH-#2E042
2E043 CJK UNIFIED IDEOGRAPH-#2E043
2E044 CJK UNIFIED IDEOGRAPH-#2E044
2E045 CJK UNIFIED IDEOGRAPH-#2E045
2E046 CJK UNIFIED IDEOGRAPH-#2E046
2E047 CJK UNIFIED IDEOGRAPH-#2E047
2E048 CJK UNIFIED IDEOGRAPH-#2E048
2E049 CJK UNIFIED IDEOGRAPH-#2E049
2E04A CJK UNIFIED IDEOGRAPH-#2E04A
2E04B CJK UNIFIED IDEOGRAPH-#2E04B
2E04C CJK UNIFIED IDEOGRAPH-#2E04C
2E04D CJK UNIFIED IDEOGRAPH-#2E04D
2E04E CJK UNIFIED IDEOGRAPH-#2E04E
2E04F CJK UNIFIED IDEOGRAPH-#2E04F
2E050 CJK UNIFIED IDEOGRAPH-#2E050
2E051 CJK UNIFIED IDEOGRAPH-#2E051
2E052 CJK UNIFIED IDEOGRAPH-#2E052
2E053 CJK UNIFIED IDEOGRAPH-#2E053
2E054 CJK UNIFIED IDEOGRAPH-#2E054
2E055 CJK UNIFIED IDEOGRAPH-#2E055
2E056 CJK UNIFIED IDEOGRAPH-#2E056
2E057 CJK UNIFIED IDEOGRAPH-#2E057
2E058 CJK UNIFIED IDEOGRAPH-#2E058
2E059 CJK UNIFIED IDEOGRAPH-#2E059
2E05A CJK UNIFIED IDEOGRAPH-#2E05A
2E05B CJK UNIFIED IDEOGRAPH-#2E05B
2E05C CJK UNIFIED IDEOGRAPH-#2E05C
2E05D CJK UNIFIED IDEOGRAPH-#2E05D
2E05E CJK UNIFIED IDEOGRAPH-#2E05E
2E05F CJK UNIFIED IDEOGRAPH-#2E05F
2E060 CJK UNIFIED IDEOGRAPH-#2E060
2E061 CJK UNIFIED IDEOGRAPH-#2E061
2E062 CJK UNIFIED IDEOGRAPH-#2E062
2E063 CJK UNIFIED IDEOGRAPH-#2E063
2E064 CJK UNIFIED IDEOGRAPH-#2E064
2E065 CJK UNIFIED IDEOGRAPH-#2E065
2E066 CJK UNIFIED IDEOGRAPH-#2E066
2E067 CJK UNIFIED IDEOGRAPH-#2E067
2E068 CJK UNIFIED IDEOGRAPH-#2E068
2E069 CJK UNIFIED IDEOGRAPH-#2E069
2E06A CJK UNIFIED IDEOGRAPH-#2E06A
2E06B CJK UNIFIED IDEOGRAPH-#2E06B
2E06C CJK UNIFIED IDEOGRAPH-#2E06C
2E06D CJK UNIFIED IDEOGRAPH-#2E06D
2E06E CJK UNIFIED IDEOGRAPH-#2E06E
2E06F CJK UNIFIED IDEOGRAPH-#2E06F
2E070 CJK UNIFIED IDEOGRAPH-#2E070
2E071 CJK UNIFIED IDEOGRAPH-#2E071
2E072 CJK UNIFIED IDEOGRAPH-#2E072
2E073 CJK UNIFIED IDEOGRAPH-#2E073
2E074 CJK UNIFIED IDEOGRAPH-#2E074
2E075 CJK UNIFIED IDEOGRAPH-#2E075
2E076 CJK UNIFIED IDEOGRAPH-#2E076
2E077 CJK UNIFIED IDEOGRAPH-#2E077
2E078 CJK UNIFIED IDEOGRAPH-#2E078
2E079 CJK UNIFIED IDEOGRAPH-#2E079
2E07A CJK UNIFIED IDEOGRAPH-#2E07A
2E07B CJK UNIFIED IDEOGRAPH-#2E07B
2E07C CJK UNIFIED IDEOGRAPH-#2E07C
2E07D CJK UNIFIED IDEOGRAPH-#2E07D
2E07E CJK UNIFIED IDEOGRAPH-#2E07E
2E07F CJK UNIFIED IDEOGRAPH-#2E07F
2E080 CJK UNIFIED IDEOGRAPH-#2E080
2E081 CJK UNIFIED IDEOGRAPH-#2E081
2E082 CJK UNIFIED IDEOGRAPH-#2E082
2E083 CJK UNIFIED IDEOGRAPH-#2E083
2E084 CJK UNIFIED IDEOGRAPH-#2E084
2E085 CJK UNIFIED IDEOGRAPH-#2E085
2E086 CJK UNIFIED IDEOGRAPH-#2E086
2E087 CJK UNIFIED IDEOGRAPH-#2E087
2E088 CJK UNIFIED IDEOGRAPH-#2E088
2E089 CJK UNIFIED IDEOGRAPH-#2E089
2E08A CJK UNIFIED IDEOGRAPH-#2E08A
2E08B CJK UNIFIED IDEOGRAPH-#2E08B
2E08C CJK UNIFIED IDEOGRAPH-#2E08C
2E08D CJK UNIFIED IDEOGRAPH-#2E08D
2E08E CJK UNIFIED IDEOGRAPH-#2E08E
2E08F CJK UNIFIED IDEOGRAPH-#2E08F
2E090 CJK UNIFIED IDEOGRAPH-#2E090
2E091 CJK UNIFIED IDEOGRAPH-#2E091
2E092 CJK UNIFIED IDEOGRAPH-#2E092
2E093 CJK UNIFIED IDEOGRAPH-#2E093
2E094 CJK UNIFIED IDEOGRAPH-#2E094
2E095 CJK UNIFIED IDEOGRAPH-#2E095
2E096 CJK UNIFIED IDEOGRAPH-#2E096
2E097 CJK UNIFIED IDEOGRAPH-#2E097
2E098 CJK UNIFIED IDEOGRAPH-#2E098
2E099 CJK UNIFIED IDEOGRAPH-#2E099
2E09A CJK UNIFIED IDEOGRAPH-#2E09A
2E09B CJK UNIFIED IDEOGRAPH-#2E09B
2E09C CJK UNIFIED IDEOGRAPH-#2E09C
2E09D CJK UNIFIED IDEOGRAPH-#2E09D
2E09E CJK UNIFIED IDEOGRAPH-#2E09E
2E09F CJK UNIFIED IDEOGRAPH-#2E09F
2E0A0 CJK UNIFIED IDEOGRAPH-#2E0A0
2E0A1 CJK UNIFIED IDEOGRAPH-#2E0A1
2E0A2 CJK UNIFIED IDEOGRAPH-#2E0A2
2E0A3 CJK UNIFIED IDEOGRAPH-#2E0A3
2E0A4 CJK UNIFIED IDEOGRAPH-#2E0A4
2E0A5 CJK UNIFIED IDEOGRAPH-#2E0A5
2E0A6 CJK UNIFIED IDEOGRAPH-#2E0A6
2E0A7 CJK UNIFIED IDEOGRAPH-#2E0A7
2E0A8 CJK UNIFIED IDEOGRAPH-#2E0A8
2E0A9 CJK UNIFIED IDEOGRAPH-#2E0A9
2E0AA CJK UNIFIED IDEOGRAPH-#2E0AA
2E0AB CJK UNIFIED IDEOGRAPH-#2E0AB
2E0AC CJK UNIFIED IDEOGRAPH-#2E0AC
2E0AD CJK UNIFIED IDEOGRAPH-#2E0AD
2E0AE CJK UNIFIED IDEOGRAPH-#2E0AE
2E0AF CJK UNIFIED IDEOGRAPH-#2E0AF
2E0B0 CJK UNIFIED IDEOGRAPH-#2E0B0
2E0B1 CJK UNIFIED IDEOGRAPH-#2E0B1
2E0B2 CJK UNIFIED IDEOGRAPH-#2E0B2
2E0B3 CJK UNIFIED IDEOGRAPH-#2E0B3
2E0B4 CJK UNIFIED IDEOGRAPH-#2E0B4
2E0B5 CJK UNIFIED IDEOGRAPH-#2E0B5
2E0B6 CJK UNIFIED IDEOGRAPH-#2E0B6
2E0B7 CJK UNIFIED IDEOGRAPH-#2E0B7
2E0B8 CJK UNIFIED IDEOGRAPH-#2E0B8
2E0B9 CJK UNIFIED IDEOGRAPH-#2E0B9
2E0BA CJK UNIFIED IDEOGRAPH-#2E0BA
2E0BB CJK UNIFIED IDEOGRAPH-#2E0BB
2E0BC CJK UNIFIED IDEOGRAPH-#2E0BC
2E0BD CJK UNIFIED IDEOGRAPH-#2E0BD
2E0BE CJK UNIFIED IDEOGRAPH-#2E0BE
2E0BF CJK UNIFIED IDEOGRAPH-#2E0BF
2E0C0 CJK UNIFIED IDEOGRAPH-#2E0C0
2E0C1 CJK UNIFIED IDEOGRAPH-#2E0C1
2E0C2 CJK UNIFIED IDEOGRAPH-#2E0C2
2E0C3 CJK UNIFIED IDEOGRAPH-#2E0C3
2E0C4 CJK UNIFIED IDEOGRAPH-#2E0C4
2E0C5 CJK UNIFIED IDEOGRAPH-#2E0C5
2E0C6 CJK UNIFIED IDEOGRAPH-#2E0C6
2E0C7 CJK UNIFIED IDEOGRAPH-#2E0C7
2E0C8 CJK UNIFIED IDEOGRAPH-#2E0C8
2E0C9 CJK UNIFIED IDEOGRAPH-#2E0C9
2E0CA CJK UNIFIED IDEOGRAPH-#2E0CA
2E0CB CJK UNIFIED IDEOGRAPH-#2E0CB
2E0CC CJK UNIFIED IDEOGRAPH-#2E0CC
2E0CD CJK UNIFIED IDEOGRAPH-#2E0CD
2E0CE CJK UNIFIED IDEOGRAPH-#2E0CE
2E0CF CJK UNIFIED IDEOGRAPH-#2E0CF
2E0D0 CJK UNIFIED IDEOGRAPH-#2E0D0
2E0D1 CJK UNIFIED IDEOGRAPH-#2E0D1
2E0D2 CJK UNIFIED IDEOGRAPH-#2E0D2
2E0D3 CJK UNIFIED IDEOGRAPH-#2E0D3
2E0D4 CJK UNIFIED IDEOGRAPH-#2E0D4
2E0D5 CJK UNIFIED IDEOGRAPH-#2E0D5
2E0D6 CJK UNIFIED IDEOGRAPH-#2E0D6
2E0D7 CJK UNIFIED IDEOGRAPH-#2E0D7
2E0D8 CJK UNIFIED IDEOGRAPH-#2E0D8
2E0D9 CJK UNIFIED IDEOGRAPH-#2E0D9
2E0DA CJK UNIFIED IDEOGRAPH-#2E0DA
2E0DB CJK UNIFIED IDEOGRAPH-#2E0DB
2E0DC CJK UNIFIED IDEOGRAPH-#2E0DC
2E0DD CJK UNIFIED IDEOGRAPH-#2E0DD
2E0DE CJK UNIFIED IDEOGRAPH-#2E0DE
2E0DF CJK UNIFIED IDEOGRAPH-#2E0DF
2E0E0 CJK UNIFIED IDEOGRAPH-#2E0E0
2E0E1 CJK UNIFIED IDEOGRAPH-#2E0E1
2E0E2 CJK UNIFIED IDEOGRAPH-#2E0E2
2E0E3 CJK UNIFIED IDEOGRAPH-#2E0E3
2E0E4 CJK UNIFIED IDEOGRAPH-#2E0E4
2E0E5 CJK UNIFIED IDEOGRAPH-#2E0E5
2E0E6 CJK UNIFIED IDEOGRAPH-#2E0E6
2E0E7 CJK UNIFIED IDEOGRAPH-#2E0E7
2E0E8 CJK UNIFIED IDEOGRAPH-#2E0E8
2E0E9 CJK UNIFIED IDEOGRAPH-#2E0E9
2E0EA CJK UNIFIED IDEOGRAPH-#2E0EA
2E0EB CJK UNIFIED IDEOGRAPH-#2E0EB
2E0EC CJK UNIFIED IDEOGRAPH-#2E0EC
2E0ED CJK UNIFIED IDEOGRAPH-#2E0ED
2E0EE CJK UNIFIED IDEOGRAPH-#2E0EE
2E0EF CJK UNIFIED IDEOGRAPH-#2E0EF
2E0F0 CJK UNIFIED IDEOGRAPH-#2E0F0
2E0F1 CJK UNIFIED IDEOGRAPH-#2E0F1
2E0F2 CJK UNIFIED IDEOGRAPH-#2E0F2
2E0F3 CJK UNIFIED IDEOGRAPH-#2E0F3
2E0F4 CJK UNIFIED IDEOGRAPH-#2E0F4
2E0F5 CJK UNIFIED IDEOGRAPH-#2E0F5
2E0F6 CJK UNIFIED IDEOGRAPH-#2E0F6
2E0F7 CJK UNIFIED IDEOGRAPH-#2E0F7
2E0F8 CJK UNIFIED IDEOGRAPH-#2E0F8
2E0F9 CJK UNIFIED IDEOGRAPH-#2E0F9
2E0FA CJK UNIFIED IDEOGRAPH-#2E0FA
2E0FB CJK UNIFIED IDEOGRAPH-#2E0FB
2E0FC CJK UNIFIED IDEOGRAPH-#2E0FC
2E0FD CJK UNIFIED IDEOGRAPH-#2E0FD
2E0FE CJK UNIFIED IDEOGRAPH-#2E0FE
2E0FF CJK UNIFIED IDEOGRAPH-#2E0FF
2E100 CJK UNIFIED IDEOGRAPH-#2E100
2E101 CJK UNIFIED IDEOGRAPH-#2E101
2E102 CJK UNIFIED IDEOGRAPH-#2E102
2E103 CJK UNIFIED IDEOGRAPH-#2E103
2E104 CJK UNIFIED IDEOGRAPH-#2E104
2E105 CJK UNIFIED IDEOGRAPH-#2E105
2E106 CJK UNIFIED IDEOGRAPH-#2E106
2E107 CJK UNIFIED IDEOGRAPH-#2E107
2E108 CJK UNIFIED IDEOGRAPH-#2E108
2E109 CJK UNIFIED IDEOGRAPH-#2E109
2E10A CJK UNIFIED IDEOGRAPH-#2E10A
2E10B CJK UNIFIED IDEOGRAPH-#2E10B
2E10C CJK UNIFIED IDEOGRAPH-#2E10C
2E10D CJK UNIFIED IDEOGRAPH-#2E10D
2E10E CJK UNIFIED IDEOGRAPH-#2E10E
2E10F CJK UNIFIED IDEOGRAPH-#2E10F
2E110 CJK UNIFIED IDEOGRAPH-#2E110
2E111 CJK UNIFIED IDEOGRAPH-#2E111
2E112 CJK UNIFIED IDEOGRAPH-#2E112
2E113 CJK UNIFIED IDEOGRAPH-#2E113
2E114 CJK UNIFIED IDEOGRAPH-#2E114
2E115 CJK UNIFIED IDEOGRAPH-#2E115
2E116 CJK UNIFIED IDEOGRAPH-#2E116
2E117 CJK UNIFIED IDEOGRAPH-#2E117
2E118 CJK UNIFIED IDEOGRAPH-#2E118
2E119 CJK UNIFIED IDEOGRAPH-#2E119
2E11A CJK UNIFIED IDEOGRAPH-#2E11A
2E11B CJK UNIFIED IDEOGRAPH-#2E11B
2E11C CJK UNIFIED IDEOGRAPH-#2E11C
2E11D CJK UNIFIED IDEOGRAPH-#2E11D
2E11E CJK UNIFIED IDEOGRAPH-#2E11E
2E11F CJK UNIFIED IDEOGRAPH-#2E11F
2E120 CJK UNIFIED IDEOGRAPH-#2E120
2E121 CJK UNIFIED IDEOGRAPH-#2E121
2E122 CJK UNIFIED IDEOGRAPH-#2E122
2E123 CJK UNIFIED IDEOGRAPH-#2E123
2E124 CJK UNIFIED IDEOGRAPH-#2E124
2E125 CJK UNIFIED IDEOGRAPH-#2E125
2E126 CJK UNIFIED IDEOGRAPH-#2E126
2E127 CJK UNIFIED IDEOGRAPH-#2E127
2E128 CJK UNIFIED IDEOGRAPH-#2E128
2E129 CJK UNIFIED IDEOGRAPH-#2E129
2E12A CJK UNIFIED IDEOGRAPH-#2E12A
2E12B CJK UNIFIED IDEOGRAPH-#2E12B
2E12C CJK UNIFIED IDEOGRAPH-#2E12C
2E12D CJK UNIFIED IDEOGRAPH-#2E12D
2E12E CJK UNIFIED IDEOGRAPH-#2E12E
2E12F CJK UNIFIED IDEOGRAPH-#2E12F
2E130 CJK UNIFIED IDEOGRAPH-#2E130
2E131 CJK UNIFIED IDEOGRAPH-#2E131
2E132 CJK UNIFIED IDEOGRAPH-#2E132
2E133 CJK UNIFIED IDEOGRAPH-#2E133
2E134 CJK UNIFIED IDEOGRAPH-#2E134
2E135 CJK UNIFIED IDEOGRAPH-#2E135
2E136 CJK UNIFIED IDEOGRAPH-#2E136
2E137 CJK UNIFIED IDEOGRAPH-#2E137
2E138 CJK UNIFIED IDEOGRAPH-#2E138
2E139 CJK UNIFIED IDEOGRAPH-#2E139
2E13A CJK UNIFIED IDEOGRAPH-#2E13A
2E13B CJK UNIFIED IDEOGRAPH-#2E13B
2E13C CJK UNIFIED IDEOGRAPH-#2E13C
2E13D CJK UNIFIED IDEOGRAPH-#2E13D
2E13E CJK UNIFIED IDEOGRAPH-#2E13E
2E13F CJK UNIFIED IDEOGRAPH-#2E13F
2E140 CJK UNIFIED IDEOGRAPH-#2E140
2E141 CJK UNIFIED IDEOGRAPH-#2E141
2E142 CJK UNIFIED IDEOGRAPH-#2E142
2E143 CJK UNIFIED IDEOGRAPH-#2E143
2E144 CJK UNIFIED IDEOGRAPH-#2E144
2E145 CJK UNIFIED IDEOGRAPH-#2E145
2E146 CJK UNIFIED IDEOGRAPH-#2E146
2E147 CJK UNIFIED IDEOGRAPH-#2E147
2E148 CJK UNIFIED IDEOGRAPH-#2E148
2E149 CJK UNIFIED IDEOGRAPH-#2E149
2E14A CJK UNIFIED IDEOGRAPH-#2E14A
2E14B CJK UNIFIED IDEOGRAPH-#2E14B
2E14C CJK UNIFIED IDEOGRAPH-#2E14C
2E14D CJK UNIFIED IDEOGRAPH-#2E14D
2E14E CJK UNIFIED IDEOGRAPH-#2E14E
2E14F CJK UNIFIED IDEOGRAPH-#2E14F
2E150 CJK UNIFIED IDEOGRAPH-#2E150
2E151 CJK UNIFIED IDEOGRAPH-#2E151
2E152 CJK UNIFIED IDEOGRAPH-#2E152
2E153 CJK UNIFIED IDEOGRAPH-#2E153
2E154 CJK UNIFIED IDEOGRAPH-#2E154
2E155 CJK UNIFIED IDEOGRAPH-#2E155
2E156 CJK UNIFIED IDEOGRAPH-#2E156
2E157 CJK UNIFIED IDEOGRAPH-#2E157
2E158 CJK UNIFIED IDEOGRAPH-#2E158
2E159 CJK UNIFIED IDEOGRAPH-#2E159
2E15A CJK UNIFIED IDEOGRAPH-#2E15A
2E15B CJK UNIFIED IDEOGRAPH-#2E15B
2E15C CJK UNIFIED IDEOGRAPH-#2E15C
2E15D CJK UNIFIED IDEOGRAPH-#2E15D
2E15E CJK UNIFIED IDEOGRAPH-#2E15E
2E15F CJK UNIFIED IDEOGRAPH-#2E15F
2E160 CJK UNIFIED IDEOGRAPH-#2E160
2E161 CJK UNIFIED IDEOGRAPH-#2E161
2E162 CJK UNIFIED IDEOGRAPH-#2E162
2E163 CJK UNIFIED IDEOGRAPH-#2E163
2E164 CJK UNIFIED IDEOGRAPH-#2E164
2E165 CJK UNIFIED IDEOGRAPH-#2E165
2E166 CJK UNIFIED IDEOGRAPH-#2E166
2E167 CJK UNIFIED IDEOGRAPH-#2E167
2E168 CJK UNIFIED IDEOGRAPH-#2E168
2E169 CJK UNIFIED IDEOGRAPH-#2E169
2E16A CJK UNIFIED IDEOGRAPH-#2E16A
2E16B CJK UNIFIED IDEOGRAPH-#2E16B
2E16C CJK UNIFIED IDEOGRAPH-#2E16C
2E16D CJK UNIFIED IDEOGRAPH-#2E16D
2E16E CJK UNIFIED IDEOGRAPH-#2E16E
2E16F CJK UNIFIED IDEOGRAPH-#2E16F
2E170 CJK UNIFIED IDEOGRAPH-#2E170
2E171 CJK UNIFIED IDEOGRAPH-#2E171
2E172 CJK UNIFIED IDEOGRAPH-#2E172
2E173 CJK UNIFIED IDEOGRAPH-#2E173
2E174 CJK UNIFIED IDEOGRAPH-#2E174
2E175 CJK UNIFIED IDEOGRAPH-#2E175
2E176 CJK UNIFIED IDEOGRAPH-#2E176
2E177 CJK UNIFIED IDEOGRAPH-#2E177
2E178 CJK UNIFIED IDEOGRAPH-#2E178
2E179 CJK UNIFIED IDEOGRAPH-#2E179
2E17A CJK UNIFIED IDEOGRAPH-#2E17A
2E17B CJK UNIFIED IDEOGRAPH-#2E17B
2E17C CJK UNIFIED IDEOGRAPH-#2E17C
2E17D CJK UNIFIED IDEOGRAPH-#2E17D
2E17E CJK UNIFIED IDEOGRAPH-#2E17E
2E17F CJK UNIFIED IDEOGRAPH-#2E17F
2E180 CJK UNIFIED IDEOGRAPH-#2E180
2E181 CJK UNIFIED IDEOGRAPH-#2E181
2E182 CJK UNIFIED IDEOGRAPH-#2E182
2E183 CJK UNIFIED IDEOGRAPH-#2E183
2E184 CJK UNIFIED IDEOGRAPH-#2E184
2E185 CJK UNIFIED IDEOGRAPH-#2E185
2E186 CJK UNIFIED IDEOGRAPH-#2E186
2E187 CJK UNIFIED IDEOGRAPH-#2E187
2E188 CJK UNIFIED IDEOGRAPH-#2E188
2E189 CJK UNIFIED IDEOGRAPH-#2E189
2E18A CJK UNIFIED IDEOGRAPH-#2E18A
2E18B CJK UNIFIED IDEOGRAPH-#2E18B
2E18C CJK UNIFIED IDEOGRAPH-#2E18C
2E18D CJK UNIFIED IDEOGRAPH-#2E18D
2E18E CJK UNIFIED IDEOGRAPH-#2E18E
2E18F CJK UNIFIED IDEOGRAPH-#2E18F
2E190 CJK UNIFIED IDEOGRAPH-#2E190
2E191 CJK UNIFIED IDEOGRAPH-#2E191
2E192 CJK UNIFIED IDEOGRAPH-#2E192
2E193 CJK UNIFIED IDEOGRAPH-#2E193
2E194 CJK UNIFIED IDEOGRAPH-#2E194
2E195 CJK UNIFIED IDEOGRAPH-#2E195
2E196 CJK UNIFIED IDEOGRAPH-#2E196
2E197 CJK UNIFIED IDEOGRAPH-#2E197
2E198 CJK UNIFIED IDEOGRAPH-#2E198
2E199 CJK UNIFIED IDEOGRAPH-#2E199
2E19A CJK UNIFIED IDEOGRAPH-#2E19A
2E19B CJK UNIFIED IDEOGRAPH-#2E19B
2E19C CJK UNIFIED IDEOGRAPH-#2E19C
2E19D CJK UNIFIED IDEOGRAPH-#2E19D
2E19E CJK UNIFIED IDEOGRAPH-#2E19E
2E19F CJK UNIFIED IDEOGRAPH-#2E19F
2E1A0 CJK UNIFIED IDEOGRAPH-#2E1A0
2E1A1 CJK UNIFIED IDEOGRAPH-#2E1A1
2E1A2 CJK UNIFIED IDEOGRAPH-#2E1A2
2E1A3 CJK UNIFIED IDEOGRAPH-#2E1A3
2E1A4 CJK UNIFIED IDEOGRAPH-#2E1A4
2E1A5 CJK UNIFIED IDEOGRAPH-#2E1A5
2E1A6 CJK UNIFIED IDEOGRAPH-#2E1A6
2E1A7 CJK UNIFIED IDEOGRAPH-#2E1A7
2E1A8 CJK UNIFIED IDEOGRAPH-#2E1A8
2E1A9 CJK UNIFIED IDEOGRAPH-#2E1A9
2E1AA CJK UNIFIED IDEOGRAPH-#2E1AA
2E1AB CJK UNIFIED IDEOGRAPH-#2E1AB
2E1AC CJK UNIFIED IDEOGRAPH-#2E1AC
2E1AD CJK UNIFIED IDEOGRAPH-#2E1AD
2E1AE CJK UNIFIED IDEOGRAPH-#2E1AE
2E1AF CJK UNIFIED IDEOGRAPH-#2E1AF
2E1B0 CJK UNIFIED IDEOGRAPH-#2E1B0
2E1B1 CJK UNIFIED IDEOGRAPH-#2E1B1
2E1B2 CJK UNIFIED IDEOGRAPH-#2E1B2
2E1B3 CJK UNIFIED IDEOGRAPH-#2E1B3
2E1B4 CJK UNIFIED IDEOGRAPH-#2E1B4
2E1B5 CJK UNIFIED IDEOGRAPH-#2E1B5
2E1B6 CJK UNIFIED IDEOGRAPH-#2E1B6
2E1B7 CJK UNIFIED IDEOGRAPH-#2E1B7
2E1B8 CJK UNIFIED IDEOGRAPH-#2E1B8
2E1B9 CJK UNIFIED IDEOGRAPH-#2E1B9
2E1BA CJK UNIFIED IDEOGRAPH-#2E1BA
2E1BB CJK UNIFIED IDEOGRAPH-#2E1BB
2E1BC CJK UNIFIED IDEOGRAPH-#2E1BC
2E1BD CJK UNIFIED IDEOGRAPH-#2E1BD
2E1BE CJK UNIFIED IDEOGRAPH-#2E1BE
2E1BF CJK UNIFIED IDEOGRAPH-#2E1BF
2E1C0 CJK UNIFIED IDEOGRAPH-#2E1C0
2E1C1 CJK UNIFIED IDEOGRAPH-#2E1C1
2E1C2 CJK UNIFIED IDEOGRAPH-#2E1C2
2E1C3 CJK UNIFIED IDEOGRAPH-#2E1C3
2E1C4 CJK UNIFIED IDEOGRAPH-#2E1C4
2E1C5 CJK UNIFIED IDEOGRAPH-#2E1C5
2E1C6 CJK UNIFIED IDEOGRAPH-#2E1C6
2E1C7 CJK UNIFIED IDEOGRAPH-#2E1C7
2E1C8 CJK UNIFIED IDEOGRAPH-#2E1C8
2E1C9 CJK UNIFIED IDEOGRAPH-#2E1C9
2E1CA CJK UNIFIED IDEOGRAPH-#2E1CA
2E1CB CJK UNIFIED IDEOGRAPH-#2E1CB
2E1CC CJK UNIFIED IDEOGRAPH-#2E1CC
2E1CD CJK UNIFIED IDEOGRAPH-#2E1CD
2E1CE CJK UNIFIED IDEOGRAPH-#2E1CE
2E1CF CJK UNIFIED IDEOGRAPH-#2E1CF
2E1D0 CJK UNIFIED IDEOGRAPH-#2E1D0
2E1D1 CJK UNIFIED IDEOGRAPH-#2E1D1
2E1D2 CJK UNIFIED IDEOGRAPH-#2E1D2
2E1D3 CJK UNIFIED IDEOGRAPH-#2E1D3
2E1D4 CJK UNIFIED IDEOGRAPH-#2E1D4
2E1D5 CJK UNIFIED IDEOGRAPH-#2E1D5
2E1D6 CJK UNIFIED IDEOGRAPH-#2E1D6
2E1D7 CJK UNIFIED IDEOGRAPH-#2E1D7
2E1D8 CJK UNIFIED IDEOGRAPH-#2E1D8
2E1D9 CJK UNIFIED IDEOGRAPH-#2E1D9
2E1DA CJK UNIFIED IDEOGRAPH-#2E1DA
2E1DB CJK UNIFIED IDEOGRAPH-#2E1DB
2E1DC CJK UNIFIED IDEOGRAPH-#2E1DC
2E1DD CJK UNIFIED IDEOGRAPH-#2E1DD
2E1DE CJK UNIFIED IDEOGRAPH-#2E1DE
2E1DF CJK UNIFIED IDEOGRAPH-#2E1DF
2E1E0 CJK UNIFIED IDEOGRAPH-#2E1E0
2E1E1 CJK UNIFIED IDEOGRAPH-#2E1E1
2E1E2 CJK UNIFIED IDEOGRAPH-#2E1E2
2E1E3 CJK UNIFIED IDEOGRAPH-#2E1E3
2E1E4 CJK UNIFIED IDEOGRAPH-#2E1E4
2E1E5 CJK UNIFIED IDEOGRAPH-#2E1E5
2E1E6 CJK UNIFIED IDEOGRAPH-#2E1E6
2E1E7 CJK UNIFIED IDEOGRAPH-#2E1E7
2E1E8 CJK UNIFIED IDEOGRAPH-#2E1E8
2E1E9 CJK UNIFIED IDEOGRAPH-#2E1E9
2E1EA CJK UNIFIED IDEOGRAPH-#2E1EA
2E1EB CJK UNIFIED IDEOGRAPH-#2E1EB
2E1EC CJK UNIFIED IDEOGRAPH-#2E1EC
2E1ED CJK UNIFIED IDEOGRAPH-#2E1ED
2E1EE CJK UNIFIED IDEOGRAPH-#2E1EE
2E1EF CJK UNIFIED IDEOGRAPH-#2E1EF
2E1F0 CJK UNIFIED IDEOGRAPH-#2E1F0
2E1F1 CJK UNIFIED IDEOGRAPH-#2E1F1
2E1F2 CJK UNIFIED IDEOGRAPH-#2E1F2
2E1F3 CJK UNIFIED IDEOGRAPH-#2E1F3
2E1F4 CJK UNIFIED IDEOGRAPH-#2E1F4
2E1F5 CJK UNIFIED IDEOGRAPH-#2E1F5
2E1F6 CJK UNIFIED IDEOGRAPH-#2E1F6
2E1F7 CJK UNIFIED IDEOGRAPH-#2E1F7
2E1F8 CJK UNIFIED IDEOGRAPH-#2E1F8
2E1F9 CJK UNIFIED IDEOGRAPH-#2E1F9
2E1FA CJK UNIFIED IDEOGRAPH-#2E1FA
2E1FB CJK UNIFIED IDEOGRAPH-#2E1FB
2E1FC CJK UNIFIED IDEOGRAPH-#2E1FC
2E1FD CJK UNIFIED IDEOGRAPH-#2E1FD
2E1FE CJK UNIFIED IDEOGRAPH-#2E1FE
2E1FF CJK UNIFIED IDEOGRAPH-#2E1FF
2E200 CJK UNIFIED IDEOGRAPH-#2E200
2E201 CJK UNIFIED IDEOGRAPH-#2E201
2E202 CJK UNIFIED IDEOGRAPH-#2E202
2E203 CJK UNIFIED IDEOGRAPH-#2E203
2E204 CJK UNIFIED IDEOGRAPH-#2E204
2E205 CJK UNIFIED IDEOGRAPH-#2E205
2E206 CJK UNIFIED IDEOGRAPH-#2E206
2E207 CJK UNIFIED IDEOGRAPH-#2E207
2E208 CJK UNIFIED IDEOGRAPH-#2E208
2E209 CJK UNIFIED IDEOGRAPH-#2E209
2E20A CJK UNIFIED IDEOGRAPH-#2E20A
2E20B CJK UNIFIED IDEOGRAPH-#2E20B
2E20C CJK UNIFIED IDEOGRAPH-#2E20C
2E20D CJK UNIFIED IDEOGRAPH-#2E20D
2E20E CJK UNIFIED IDEOGRAPH-#2E20E
2E20F CJK UNIFIED IDEOGRAPH-#2E20F
2E210 CJK UNIFIED IDEOGRAPH-#2E210
2E211 CJK UNIFIED IDEOGRAPH-#2E211
2E212 CJK UNIFIED IDEOGRAPH-#2E212
2E213 CJK UNIFIED IDEOGRAPH-#2E213
2E214 CJK UNIFIED IDEOGRAPH-#2E214
2E215 CJK UNIFIED IDEOGRAPH-#2E215
2E216 CJK UNIFIED IDEOGRAPH-#2E216
2E217 CJK UNIFIED IDEOGRAPH-#2E217
2E218 CJK UNIFIED IDEOGRAPH-#2E218
2E219 CJK UNIFIED IDEOGRAPH-#2E219
2E21A CJK UNIFIED IDEOGRAPH-#2E21A
2E21B CJK UNIFIED IDEOGRAPH-#2E21B
2E21C CJK UNIFIED IDEOGRAPH-#2E21C
2E21D CJK UNIFIED IDEOGRAPH-#2E21D
2E21E CJK UNIFIED IDEOGRAPH-#2E21E
2E21F CJK UNIFIED IDEOGRAPH-#2E21F
2E220 CJK UNIFIED IDEOGRAPH-#2E220
2E221 CJK UNIFIED IDEOGRAPH-#2E221
2E222 CJK UNIFIED IDEOGRAPH-#2E222
2E223 CJK UNIFIED IDEOGRAPH-#2E223
2E224 CJK UNIFIED IDEOGRAPH-#2E224
2E225 CJK UNIFIED IDEOGRAPH-#2E225
2E226 CJK UNIFIED IDEOGRAPH-#2E226
2E227 CJK UNIFIED IDEOGRAPH-#2E227
2E228 CJK UNIFIED IDEOGRAPH-#2E228
2E229 CJK UNIFIED IDEOGRAPH-#2E229
2E22A CJK UNIFIED IDEOGRAPH-#2E22A
2E22B CJK UNIFIED IDEOGRAPH-#2E22B
2E22C CJK UNIFIED IDEOGRAPH-#2E22C
2E22D CJK UNIFIED IDEOGRAPH-#2E22D
2E22E CJK UNIFIED IDEOGRAPH-#2E22E
2E22F CJK UNIFIED IDEOGRAPH-#2E22F
2E230 CJK UNIFIED IDEOGRAPH-#2E230
2E231 CJK UNIFIED IDEOGRAPH-#2E231
2E232 CJK UNIFIED IDEOGRAPH-#2E232
2E233 CJK UNIFIED IDEOGRAPH-#2E233
2E234 CJK UNIFIED IDEOGRAPH-#2E234
2E235 CJK UNIFIED IDEOGRAPH-#2E235
2E236 CJK UNIFIED IDEOGRAPH-#2E236
2E237 CJK UNIFIED IDEOGRAPH-#2E237
2E238 CJK UNIFIED IDEOGRAPH-#2E238
2E239 CJK UNIFIED IDEOGRAPH-#2E239
2E23A CJK UNIFIED IDEOGRAPH-#2E23A
2E23B CJK UNIFIED IDEOGRAPH-#2E23B
2E23C CJK UNIFIED IDEOGRAPH-#2E23C
2E23D CJK UNIFIED IDEOGRAPH-#2E23D
2E23E CJK UNIFIED IDEOGRAPH-#2E23E
2E23F CJK UNIFIED IDEOGRAPH-#2E23F
2E240 CJK UNIFIED IDEOGRAPH-#2E240
2E241 CJK UNIFIED IDEOGRAPH-#2E241
2E242 CJK UNIFIED IDEOGRAPH-#2E242
2E243 CJK UNIFIED IDEOGRAPH-#2E243
2E244 CJK UNIFIED IDEOGRAPH-#2E244
2E245 CJK UNIFIED IDEOGRAPH-#2E245
2E246 CJK UNIFIED IDEOGRAPH-#2E246
2E247 CJK UNIFIED IDEOGRAPH-#2E247
2E248 CJK UNIFIED IDEOGRAPH-#2E248
2E249 CJK UNIFIED IDEOGRAPH-#2E249
2E24A CJK UNIFIED IDEOGRAPH-#2E24A
2E24B CJK UNIFIED IDEOGRAPH-#2E24B
2E24C CJK UNIFIED IDEOGRAPH-#2E24C
2E24D CJK UNIFIED IDEOGRAPH-#2E24D
2E24E CJK UNIFIED IDEOGRAPH-#2E24E
2E24F CJK UNIFIED IDEOGRAPH-#2E24F
2E250 CJK UNIFIED IDEOGRAPH-#2E250
2E251 CJK UNIFIED IDEOGRAPH-#2E251
2E252 CJK UNIFIED IDEOGRAPH-#2E252
2E253 CJK UNIFIED IDEOGRAPH-#2E253
2E254 CJK UNIFIED IDEOGRAPH-#2E254
2E255 CJK UNIFIED IDEOGRAPH-#2E255
2E256 CJK UNIFIED IDEOGRAPH-#2E256
2E257 CJK UNIFIED IDEOGRAPH-#2E257
2E258 CJK UNIFIED IDEOGRAPH-#2E258
2E259 CJK UNIFIED IDEOGRAPH-#2E259
2E25A CJK UNIFIED IDEOGRAPH-#2E25A
2E25B CJK UNIFIED IDEOGRAPH-#2E25B
2E25C CJK UNIFIED IDEOGRAPH-#2E25C
2E25D CJK UNIFIED IDEOGRAPH-#2E25D
2E25E CJK UNIFIED IDEOGRAPH-#2E25E
2E25F CJK UNIFIED IDEOGRAPH-#2E25F
2E260 CJK UNIFIED IDEOGRAPH-#2E260
2E261 CJK UNIFIED IDEOGRAPH-#2E261
2E262 CJK UNIFIED IDEOGRAPH-#2E262
2E263 CJK UNIFIED IDEOGRAPH-#2E263
2E264 CJK UNIFIED IDEOGRAPH-#2E264
2E265 CJK UNIFIED IDEOGRAPH-#2E265
2E266 CJK UNIFIED IDEOGRAPH-#2E266
2E267 CJK UNIFIED IDEOGRAPH-#2E267
2E268 CJK UNIFIED IDEOGRAPH-#2E268
2E269 CJK UNIFIED IDEOGRAPH-#2E269
2E26A CJK UNIFIED IDEOGRAPH-#2E26A
2E26B CJK UNIFIED IDEOGRAPH-#2E26B
2E26C CJK UNIFIED IDEOGRAPH-#2E26C
2E26D CJK UNIFIED IDEOGRAPH-#2E26D
2E26E CJK UNIFIED IDEOGRAPH-#2E26E
2E26F CJK UNIFIED IDEOGRAPH-#2E26F
2E270 CJK UNIFIED IDEOGRAPH-#2E270
2E271 CJK UNIFIED IDEOGRAPH-#2E271
2E272 CJK UNIFIED IDEOGRAPH-#2E272
2E273 CJK UNIFIED IDEOGRAPH-#2E273
2E274 CJK UNIFIED IDEOGRAPH-#2E274
2E275 CJK UNIFIED IDEOGRAPH-#2E275
2E276 CJK UNIFIED IDEOGRAPH-#2E276
2E277 CJK UNIFIED IDEOGRAPH-#2E277
2E278 CJK UNIFIED IDEOGRAPH-#2E278
2E279 CJK UNIFIED IDEOGRAPH-#2E279
2E27A CJK UNIFIED IDEOGRAPH-#2E27A
2E27B CJK UNIFIED IDEOGRAPH-#2E27B
2E27C CJK UNIFIED IDEOGRAPH-#2E27C
2E27D CJK UNIFIED IDEOGRAPH-#2E27D
2E27E CJK UNIFIED IDEOGRAPH-#2E27E
2E27F CJK UNIFIED IDEOGRAPH-#2E27F
2E280 CJK UNIFIED IDEOGRAPH-#2E280
2E281 CJK UNIFIED IDEOGRAPH-#2E281
2E282 CJK UNIFIED IDEOGRAPH-#2E282
2E283 CJK UNIFIED IDEOGRAPH-#2E283
2E284 CJK UNIFIED IDEOGRAPH-#2E284
2E285 CJK UNIFIED IDEOGRAPH-#2E285
2E286 CJK UNIFIED IDEOGRAPH-#2E286
2E287 CJK UNIFIED IDEOGRAPH-#2E287
2E288 CJK UNIFIED IDEOGRAPH-#2E288
2E289 CJK UNIFIED IDEOGRAPH-#2E289
2E28A CJK UNIFIED IDEOGRAPH-#2E28A
2E28B CJK UNIFIED IDEOGRAPH-#2E28B
2E28C CJK UNIFIED IDEOGRAPH-#2E28C
2E28D CJK UNIFIED IDEOGRAPH-#2E28D
2E28E CJK UNIFIED IDEOGRAPH-#2E28E
2E28F CJK UNIFIED IDEOGRAPH-#2E28F
2E290 CJK UNIFIED IDEOGRAPH-#2E290
2E291 CJK UNIFIED IDEOGRAPH-#2E291
2E292 CJK UNIFIED IDEOGRAPH-#2E292
2E293 CJK UNIFIED IDEOGRAPH-#2E293
2E294 CJK UNIFIED IDEOGRAPH-#2E294
2E295 CJK UNIFIED IDEOGRAPH-#2E295
2E296 CJK UNIFIED IDEOGRAPH-#2E296
2E297 CJK UNIFIED IDEOGRAPH-#2E297
2E298 CJK UNIFIED IDEOGRAPH-#2E298
2E299 CJK UNIFIED IDEOGRAPH-#2E299
2E29A CJK UNIFIED IDEOGRAPH-#2E29A
2E29B CJK UNIFIED IDEOGRAPH-#2E29B
2E29C CJK UNIFIED IDEOGRAPH-#2E29C
2E29D CJK UNIFIED IDEOGRAPH-#2E29D
2E29E CJK UNIFIED IDEOGRAPH-#2E29E
2E29F CJK UNIFIED IDEOGRAPH-#2E29F
2E2A0 CJK UNIFIED IDEOGRAPH-#2E2A0
2E2A1 CJK UNIFIED IDEOGRAPH-#2E2A1
2E2A2 CJK UNIFIED IDEOGRAPH-#2E2A2
2E2A3 CJK UNIFIED IDEOGRAPH-#2E2A3
2E2A4 CJK UNIFIED IDEOGRAPH-#2E2A4
2E2A5 CJK UNIFIED IDEOGRAPH-#2E2A5
2E2A6 CJK UNIFIED IDEOGRAPH-#2E2A6
2E2A7 CJK UNIFIED IDEOGRAPH-#2E2A7
2E2A8 CJK UNIFIED IDEOGRAPH-#2E2A8
2E2A9 CJK UNIFIED IDEOGRAPH-#2E2A9
2E2AA CJK UNIFIED IDEOGRAPH-#2E2AA
2E2AB CJK UNIFIED IDEOGRAPH-#2E2AB
2E2AC CJK UNIFIED IDEOGRAPH-#2E2AC
2E2AD CJK UNIFIED IDEOGRAPH-#2E2AD
2E2AE CJK UNIFIED IDEOGRAPH-#2E2AE
2E2AF CJK UNIFIED IDEOGRAPH-#2E2AF
2E2B0 CJK UNIFIED IDEOGRAPH-#2E2B0
2E2B1 CJK UNIFIED IDEOGRAPH-#2E2B1
2E2B2 CJK UNIFIED IDEOGRAPH-#2E2B2
2E2B3 CJK UNIFIED IDEOGRAPH-#2E2B3
2E2B4 CJK UNIFIED IDEOGRAPH-#2E2B4
2E2B5 CJK UNIFIED IDEOGRAPH-#2E2B5
2E2B6 CJK UNIFIED IDEOGRAPH-#2E2B6
2E2B7 CJK UNIFIED IDEOGRAPH-#2E2B7
2E2B8 CJK UNIFIED IDEOGRAPH-#2E2B8
2E2B9 CJK UNIFIED IDEOGRAPH-#2E2B9
2E2BA CJK UNIFIED IDEOGRAPH-#2E2BA
2E2BB CJK UNIFIED IDEOGRAPH-#2E2BB
2E2BC CJK UNIFIED IDEOGRAPH-#2E2BC
2E2BD CJK UNIFIED IDEOGRAPH-#2E2BD
2E2BE CJK UNIFIED IDEOGRAPH-#2E2BE
2E2BF CJK UNIFIED IDEOGRAPH-#2E2BF
2E2C0 CJK UNIFIED IDEOGRAPH-#2E2C0
2E2C1 CJK UNIFIED IDEOGRAPH-#2E2C1
2E2C2 CJK UNIFIED IDEOGRAPH-#2E2C2
2E2C3 CJK UNIFIED IDEOGRAPH-#2E2C3
2E2C4 CJK UNIFIED IDEOGRAPH-#2E2C4
2E2C5 CJK UNIFIED IDEOGRAPH-#2E2C5
2E2C6 CJK UNIFIED IDEOGRAPH-#2E2C6
2E2C7 CJK UNIFIED IDEOGRAPH-#2E2C7
2E2C8 CJK UNIFIED IDEOGRAPH-#2E2C8
2E2C9 CJK UNIFIED IDEOGRAPH-#2E2C9
2E2CA CJK UNIFIED IDEOGRAPH-#2E2CA
2E2CB CJK UNIFIED IDEOGRAPH-#2E2CB
2E2CC CJK UNIFIED IDEOGRAPH-#2E2CC
2E2CD CJK UNIFIED IDEOGRAPH-#2E2CD
2E2CE CJK UNIFIED IDEOGRAPH-#2E2CE
2E2CF CJK UNIFIED IDEOGRAPH-#2E2CF
2E2D0 CJK UNIFIED IDEOGRAPH-#2E2D0
2E2D1 CJK UNIFIED IDEOGRAPH-#2E2D1
2E2D2 CJK UNIFIED IDEOGRAPH-#2E2D2
2E2D3 CJK UNIFIED IDEOGRAPH-#2E2D3
2E2D4 CJK UNIFIED IDEOGRAPH-#2E2D4
2E2D5 CJK UNIFIED IDEOGRAPH-#2E2D5
2E2D6 CJK UNIFIED IDEOGRAPH-#2E2D6
2E2D7 CJK UNIFIED IDEOGRAPH-#2E2D7
2E2D8 CJK UNIFIED IDEOGRAPH-#2E2D8
2E2D9 CJK UNIFIED IDEOGRAPH-#2E2D9
2E2DA CJK UNIFIED IDEOGRAPH-#2E2DA
2E2DB CJK UNIFIED IDEOGRAPH-#2E2DB
2E2DC CJK UNIFIED IDEOGRAPH-#2E2DC
2E2DD CJK UNIFIED IDEOGRAPH-#2E2DD
2E2DE CJK UNIFIED IDEOGRAPH-#2E2DE
2E2DF CJK UNIFIED IDEOGRAPH-#2E2DF
2E2E0 CJK UNIFIED IDEOGRAPH-#2E2E0
2E2E1 CJK UNIFIED IDEOGRAPH-#2E2E1
2E2E2 CJK UNIFIED IDEOGRAPH-#2E2E2
2E2E3 CJK UNIFIED IDEOGRAPH-#2E2E3
2E2E4 CJK UNIFIED IDEOGRAPH-#2E2E4
2E2E5 CJK UNIFIED IDEOGRAPH-#2E2E5
2E2E6 CJK UNIFIED IDEOGRAPH-#2E2E6
2E2E7 CJK UNIFIED IDEOGRAPH-#2E2E7
2E2E8 CJK UNIFIED IDEOGRAPH-#2E2E8
2E2E9 CJK UNIFIED IDEOGRAPH-#2E2E9
2E2EA CJK UNIFIED IDEOGRAPH-#2E2EA
2E2EB CJK UNIFIED IDEOGRAPH-#2E2EB
2E2EC CJK UNIFIED IDEOGRAPH-#2E2EC
2E2ED CJK UNIFIED IDEOGRAPH-#2E2ED
2E2EE CJK UNIFIED IDEOGRAPH-#2E2EE
2E2EF CJK UNIFIED IDEOGRAPH-#2E2EF
2E2F0 CJK UNIFIED IDEOGRAPH-#2E2F0
2E2F1 CJK UNIFIED IDEOGRAPH-#2E2F1
2E2F2 CJK UNIFIED IDEOGRAPH-#2E2F2
2E2F3 CJK UNIFIED IDEOGRAPH-#2E2F3
2E2F4 CJK UNIFIED IDEOGRAPH-#2E2F4
2E2F5 CJK UNIFIED IDEOGRAPH-#2E2F5
2E2F6 CJK UNIFIED IDEOGRAPH-#2E2F6
2E2F7 CJK UNIFIED IDEOGRAPH-#2E2F7
2E2F8 CJK UNIFIED IDEOGRAPH-#2E2F8
2E2F9 CJK UNIFIED IDEOGRAPH-#2E2F9
2E2FA CJK UNIFIED IDEOGRAPH-#2E2FA
2E2FB CJK UNIFIED IDEOGRAPH-#2E2FB
2E2FC CJK UNIFIED IDEOGRAPH-#2E2FC
2E2FD CJK UNIFIED IDEOGRAPH-#2E2FD
2E2FE CJK UNIFIED IDEOGRAPH-#2E2FE
2E2FF CJK UNIFIED IDEOGRAPH-#2E2FF
2E300 CJK UNIFIED IDEOGRAPH-#2E300
2E301 CJK UNIFIED IDEOGRAPH-#2E301
2E302 CJK UNIFIED IDEOGRAPH-#2E302
2E303 CJK UNIFIED IDEOGRAPH-#2E303
2E304 CJK UNIFIED IDEOGRAPH-#2E304
2E305 CJK UNIFIED IDEOGRAPH-#2E305
2E306 CJK UNIFIED IDEOGRAPH-#2E306
2E307 CJK UNIFIED IDEOGRAPH-#2E307
2E308 CJK UNIFIED IDEOGRAPH-#2E308
2E309 CJK UNIFIED IDEOGRAPH-#2E309
2E30A CJK UNIFIED IDEOGRAPH-#2E30A
2E30B CJK UNIFIED IDEOGRAPH-#2E30B
2E30C CJK UNIFIED IDEOGRAPH-#2E30C
2E30D CJK UNIFIED IDEOGRAPH-#2E30D
2E30E CJK UNIFIED IDEOGRAPH-#2E30E
2E30F CJK UNIFIED IDEOGRAPH-#2E30F
2E310 CJK UNIFIED IDEOGRAPH-#2E310
2E311 CJK UNIFIED IDEOGRAPH-#2E311
2E312 CJK UNIFIED IDEOGRAPH-#2E312
2E313 CJK UNIFIED IDEOGRAPH-#2E313
2E314 CJK UNIFIED IDEOGRAPH-#2E314
2E315 CJK UNIFIED IDEOGRAPH-#2E315
2E316 CJK UNIFIED IDEOGRAPH-#2E316
2E317 CJK UNIFIED IDEOGRAPH-#2E317
2E318 CJK UNIFIED IDEOGRAPH-#2E318
2E319 CJK UNIFIED IDEOGRAPH-#2E319
2E31A CJK UNIFIED IDEOGRAPH-#2E31A
2E31B CJK UNIFIED IDEOGRAPH-#2E31B
2E31C CJK UNIFIED IDEOGRAPH-#2E31C
2E31D CJK UNIFIED IDEOGRAPH-#2E31D
2E31E CJK UNIFIED IDEOGRAPH-#2E31E
2E31F CJK UNIFIED IDEOGRAPH-#2E31F
2E320 CJK UNIFIED IDEOGRAPH-#2E320
2E321 CJK UNIFIED IDEOGRAPH-#2E321
2E322 CJK UNIFIED IDEOGRAPH-#2E322
2E323 CJK UNIFIED IDEOGRAPH-#2E323
2E324 CJK UNIFIED IDEOGRAPH-#2E324
2E325 CJK UNIFIED IDEOGRAPH-#2E325
2E326 CJK UNIFIED IDEOGRAPH-#2E326
2E327 CJK UNIFIED IDEOGRAPH-#2E327
2E328 CJK UNIFIED IDEOGRAPH-#2E328
2E329 CJK UNIFIED IDEOGRAPH-#2E329
2E32A CJK UNIFIED IDEOGRAPH-#2E32A
2E32B CJK UNIFIED IDEOGRAPH-#2E32B
2E32C CJK UNIFIED IDEOGRAPH-#2E32C
2E32D CJK UNIFIED IDEOGRAPH-#2E32D
2E32E CJK UNIFIED IDEOGRAPH-#2E32E
2E32F CJK UNIFIED IDEOGRAPH-#2E32F
2E330 CJK UNIFIED IDEOGRAPH-#2E330
2E331 CJK UNIFIED IDEOGRAPH-#2E331
2E332 CJK UNIFIED IDEOGRAPH-#2E332
2E333 CJK UNIFIED IDEOGRAPH-#2E333
2E334 CJK UNIFIED IDEOGRAPH-#2E334
2E335 CJK UNIFIED IDEOGRAPH-#2E335
2E336 CJK UNIFIED IDEOGRAPH-#2E336
2E337 CJK UNIFIED IDEOGRAPH-#2E337
2E338 CJK UNIFIED IDEOGRAPH-#2E338
2E339 CJK UNIFIED IDEOGRAPH-#2E339
2E33A CJK UNIFIED IDEOGRAPH-#2E33A
2E33B CJK UNIFIED IDEOGRAPH-#2E33B
2E33C CJK UNIFIED IDEOGRAPH-#2E33C
2E33D CJK UNIFIED IDEOGRAPH-#2E33D
2E33E CJK UNIFIED IDEOGRAPH-#2E33E
2E33F CJK UNIFIED IDEOGRAPH-#2E33F
2E340 CJK UNIFIED IDEOGRAPH-#2E340
2E341 CJK UNIFIED IDEOGRAPH-#2E341
2E342 CJK UNIFIED IDEOGRAPH-#2E342
2E343 CJK UNIFIED IDEOGRAPH-#2E343
2E344 CJK UNIFIED IDEOGRAPH-#2E344
2E345 CJK UNIFIED IDEOGRAPH-#2E345
2E346 CJK UNIFIED IDEOGRAPH-#2E346
2E347 CJK UNIFIED IDEOGRAPH-#2E347
2E348 CJK UNIFIED IDEOGRAPH-#2E348
2E349 CJK UNIFIED IDEOGRAPH-#2E349
2E34A CJK UNIFIED IDEOGRAPH-#2E34A
2E34B CJK UNIFIED IDEOGRAPH-#2E34B
2E34C CJK UNIFIED IDEOGRAPH-#2E34C
2E34D CJK UNIFIED IDEOGRAPH-#2E34D
2E34E CJK UNIFIED IDEOGRAPH-#2E34E
2E34F CJK UNIFIED IDEOGRAPH-#2E34F
2E350 CJK UNIFIED IDEOGRAPH-#2E350
2E351 CJK UNIFIED IDEOGRAPH-#2E351
2E352 CJK UNIFIED IDEOGRAPH-#2E352
2E353 CJK UNIFIED IDEOGRAPH-#2E353
2E354 CJK UNIFIED IDEOGRAPH-#2E354
2E355 CJK UNIFIED IDEOGRAPH-#2E355
2E356 CJK UNIFIED IDEOGRAPH-#2E356
2E357 CJK UNIFIED IDEOGRAPH-#2E357
2E358 CJK UNIFIED IDEOGRAPH-#2E358
2E359 CJK UNIFIED IDEOGRAPH-#2E359
2E35A CJK UNIFIED IDEOGRAPH-#2E35A
2E35B CJK UNIFIED IDEOGRAPH-#2E35B
2E35C CJK UNIFIED IDEOGRAPH-#2E35C
2E35D CJK UNIFIED IDEOGRAPH-#2E35D
2E35E CJK UNIFIED IDEOGRAPH-#2E35E
2E35F CJK UNIFIED IDEOGRAPH-#2E35F
2E360 CJK UNIFIED IDEOGRAPH-#2E360
2E361 CJK UNIFIED IDEOGRAPH-#2E361
2E362 CJK UNIFIED IDEOGRAPH-#2E362
2E363 CJK UNIFIED IDEOGRAPH-#2E363
2E364 CJK UNIFIED IDEOGRAPH-#2E364
2E365 CJK UNIFIED IDEOGRAPH-#2E365
2E366 CJK UNIFIED IDEOGRAPH-#2E366
2E367 CJK UNIFIED IDEOGRAPH-#2E367
2E368 CJK UNIFIED IDEOGRAPH-#2E368
2E369 CJK UNIFIED IDEOGRAPH-#2E369
2E36A CJK UNIFIED IDEOGRAPH-#2E36A
2E36B CJK UNIFIED IDEOGRAPH-#2E36B
2E36C CJK UNIFIED IDEOGRAPH-#2E36C
2E36D CJK UNIFIED IDEOGRAPH-#2E36D
2E36E CJK UNIFIED IDEOGRAPH-#2E36E
2E36F CJK UNIFIED IDEOGRAPH-#2E36F
2E370 CJK UNIFIED IDEOGRAPH-#2E370
2E371 CJK UNIFIED IDEOGRAPH-#2E371
2E372 CJK UNIFIED IDEOGRAPH-#2E372
2E373 CJK UNIFIED IDEOGRAPH-#2E373
2E374 CJK UNIFIED IDEOGRAPH-#2E374
2E375 CJK UNIFIED IDEOGRAPH-#2E375
2E376 CJK UNIFIED IDEOGRAPH-#2E376
2E377 CJK UNIFIED IDEOGRAPH-#2E377
2E378 CJK UNIFIED IDEOGRAPH-#2E378
2E379 CJK UNIFIED IDEOGRAPH-#2E379
2E37A CJK UNIFIED IDEOGRAPH-#2E37A
2E37B CJK UNIFIED IDEOGRAPH-#2E37B
2E37C CJK UNIFIED IDEOGRAPH-#2E37C
2E37D CJK UNIFIED IDEOGRAPH-#2E37D
2E37E CJK UNIFIED IDEOGRAPH-#2E37E
2E37F CJK UNIFIED IDEOGRAPH-#2E37F
2E380 CJK UNIFIED IDEOGRAPH-#2E380
2E381 CJK UNIFIED IDEOGRAPH-#2E381
2E382 CJK UNIFIED IDEOGRAPH-#2E382
2E383 CJK UNIFIED IDEOGRAPH-#2E383
2E384 CJK UNIFIED IDEOGRAPH-#2E384
2E385 CJK UNIFIED IDEOGRAPH-#2E385
2E386 CJK UNIFIED IDEOGRAPH-#2E386
2E387 CJK UNIFIED IDEOGRAPH-#2E387
2E388 CJK UNIFIED IDEOGRAPH-#2E388
2E389 CJK UNIFIED IDEOGRAPH-#2E389
2E38A CJK UNIFIED IDEOGRAPH-#2E38A
2E38B CJK UNIFIED IDEOGRAPH-#2E38B
2E38C CJK UNIFIED IDEOGRAPH-#2E38C
2E38D CJK UNIFIED IDEOGRAPH-#2E38D
2E38E CJK UNIFIED IDEOGRAPH-#2E38E
2E38F CJK UNIFIED IDEOGRAPH-#2E38F
2E390 CJK UNIFIED IDEOGRAPH-#2E390
2E391 CJK UNIFIED IDEOGRAPH-#2E391
2E392 CJK UNIFIED IDEOGRAPH-#2E392
2E393 CJK UNIFIED IDEOGRAPH-#2E393
2E394 CJK UNIFIED IDEOGRAPH-#2E394
2E395 CJK UNIFIED IDEOGRAPH-#2E395
2E396 CJK UNIFIED IDEOGRAPH-#2E396
2E397 CJK UNIFIED IDEOGRAPH-#2E397
2E398 CJK UNIFIED IDEOGRAPH-#2E398
2E399 CJK UNIFIED IDEOGRAPH-#2E399
2E39A CJK UNIFIED IDEOGRAPH-#2E39A
2E39B CJK UNIFIED IDEOGRAPH-#2E39B
2E39C CJK UNIFIED IDEOGRAPH-#2E39C
2E39D CJK UNIFIED IDEOGRAPH-#2E39D
2E39E CJK UNIFIED IDEOGRAPH-#2E39E
2E39F CJK UNIFIED IDEOGRAPH-#2E39F
2E3A0 CJK UNIFIED IDEOGRAPH-#2E3A0
2E3A1 CJK UNIFIED IDEOGRAPH-#2E3A1
2E3A2 CJK UNIFIED IDEOGRAPH-#2E3A2
2E3A3 CJK UNIFIED IDEOGRAPH-#2E3A3
2E3A4 CJK UNIFIED IDEOGRAPH-#2E3A4
2E3A5 CJK UNIFIED IDEOGRAPH-#2E3A5
2E3A6 CJK UNIFIED IDEOGRAPH-#2E3A6
2E3A7 CJK UNIFIED IDEOGRAPH-#2E3A7
2E3A8 CJK UNIFIED IDEOGRAPH-#2E3A8
2E3A9 CJK UNIFIED IDEOGRAPH-#2E3A9
2E3AA CJK UNIFIED IDEOGRAPH-#2E3AA
2E3AB CJK UNIFIED IDEOGRAPH-#2E3AB
2E3AC CJK UNIFIED IDEOGRAPH-#2E3AC
2E3AD CJK UNIFIED IDEOGRAPH-#2E3AD
2E3AE CJK UNIFIED IDEOGRAPH-#2E3AE
2E3AF CJK UNIFIED IDEOGRAPH-#2E3AF
2E3B0 CJK UNIFIED IDEOGRAPH-#2E3B0
2E3B1 CJK UNIFIED IDEOGRAPH-#2E3B1
2E3B2 CJK UNIFIED IDEOGRAPH-#2E3B2
2E3B3 CJK UNIFIED IDEOGRAPH-#2E3B3
2E3B4 CJK UNIFIED IDEOGRAPH-#2E3B4
2E3B5 CJK UNIFIED IDEOGRAPH-#2E3B5
2E3B6 CJK UNIFIED IDEOGRAPH-#2E3B6
2E3B7 CJK UNIFIED IDEOGRAPH-#2E3B7
2E3B8 CJK UNIFIED IDEOGRAPH-#2E3B8
2E3B9 CJK UNIFIED IDEOGRAPH-#2E3B9
2E3BA CJK UNIFIED IDEOGRAPH-#2E3BA
2E3BB CJK UNIFIED IDEOGRAPH-#2E3BB
2E3BC CJK UNIFIED IDEOGRAPH-#2E3BC
2E3BD CJK UNIFIED IDEOGRAPH-#2E3BD
2E3BE CJK UNIFIED IDEOGRAPH-#2E3BE
2E3BF CJK UNIFIED IDEOGRAPH-#2E3BF
2E3C0 CJK UNIFIED IDEOGRAPH-#2E3C0
2E3C1 CJK UNIFIED IDEOGRAPH-#2E3C1
2E3C2 CJK UNIFIED IDEOGRAPH-#2E3C2
2E3C3 CJK UNIFIED IDEOGRAPH-#2E3C3
2E3C4 CJK UNIFIED IDEOGRAPH-#2E3C4
2E3C5 CJK UNIFIED IDEOGRAPH-#2E3C5
2E3C6 CJK UNIFIED IDEOGRAPH-#2E3C6
2E3C7 CJK UNIFIED IDEOGRAPH-#2E3C7
2E3C8 CJK UNIFIED IDEOGRAPH-#2E3C8
2E3C9 CJK UNIFIED IDEOGRAPH-#2E3C9
2E3CA CJK UNIFIED IDEOGRAPH-#2E3CA
2E3CB CJK UNIFIED IDEOGRAPH-#2E3CB
2E3CC CJK UNIFIED IDEOGRAPH-#2E3CC
2E3CD CJK UNIFIED IDEOGRAPH-#2E3CD
2E3CE CJK UNIFIED IDEOGRAPH-#2E3CE
2E3CF CJK UNIFIED IDEOGRAPH-#2E3CF
2E3D0 CJK UNIFIED IDEOGRAPH-#2E3D0
2E3D1 CJK UNIFIED IDEOGRAPH-#2E3D1
2E3D2 CJK UNIFIED IDEOGRAPH-#2E3D2
2E3D3 CJK UNIFIED IDEOGRAPH-#2E3D3
2E3D4 CJK UNIFIED IDEOGRAPH-#2E3D4
2E3D5 CJK UNIFIED IDEOGRAPH-#2E3D5
2E3D6 CJK UNIFIED IDEOGRAPH-#2E3D6
2E3D7 CJK UNIFIED IDEOGRAPH-#2E3D7
2E3D8 CJK UNIFIED IDEOGRAPH-#2E3D8
2E3D9 CJK UNIFIED IDEOGRAPH-#2E3D9
2E3DA CJK UNIFIED IDEOGRAPH-#2E3DA
2E3DB CJK UNIFIED IDEOGRAPH-#2E3DB
2E3DC CJK UNIFIED IDEOGRAPH-#2E3DC
2E3DD CJK UNIFIED IDEOGRAPH-#2E3DD
2E3DE CJK UNIFIED IDEOGRAPH-#2E3DE
2E3DF CJK UNIFIED IDEOGRAPH-#2E3DF
2E3E0 CJK UNIFIED IDEOGRAPH-#2E3E0
2E3E1 CJK UNIFIED IDEOGRAPH-#2E3E1
2E3E2 CJK UNIFIED IDEOGRAPH-#2E3E2
2E3E3 CJK UNIFIED IDEOGRAPH-#2E3E3
2E3E4 CJK UNIFIED IDEOGRAPH-#2E3E4
2E3E5 CJK UNIFIED IDEOGRAPH-#2E3E5
2E3E6 CJK UNIFIED IDEOGRAPH-#2E3E6
2E3E7 CJK UNIFIED IDEOGRAPH-#2E3E7
2E3E8 CJK UNIFIED IDEOGRAPH-#2E3E8
2E3E9 CJK UNIFIED IDEOGRAPH-#2E3E9
2E3EA CJK UNIFIED IDEOGRAPH-#2E3EA
2E3EB CJK UNIFIED IDEOGRAPH-#2E3EB
2E3EC CJK UNIFIED IDEOGRAPH-#2E3EC
2E3ED CJK UNIFIED IDEOGRAPH-#2E3ED
2E3EE CJK UNIFIED IDEOGRAPH-#2E3EE
2E3EF CJK UNIFIED IDEOGRAPH-#2E3EF
2E3F0 CJK UNIFIED IDEOGRAPH-#2E3F0
2E3F1 CJK UNIFIED IDEOGRAPH-#2E3F1
2E3F2 CJK UNIFIED IDEOGRAPH-#2E3F2
2E3F3 CJK UNIFIED IDEOGRAPH-#2E3F3
2E3F4 CJK UNIFIED IDEOGRAPH-#2E3F4
2E3F5 CJK UNIFIED IDEOGRAPH-#2E3F5
2E3F6 CJK UNIFIED IDEOGRAPH-#2E3F6
2E3F7 CJK UNIFIED IDEOGRAPH-#2E3F7
2E3F8 CJK UNIFIED IDEOGRAPH-#2E3F8
2E3F9 CJK UNIFIED IDEOGRAPH-#2E3F9
2E3FA CJK UNIFIED IDEOGRAPH-#2E3FA
2E3FB CJK UNIFIED IDEOGRAPH-#2E3FB
2E3FC CJK UNIFIED IDEOGRAPH-#2E3FC
2E3FD CJK UNIFIED IDEOGRAPH-#2E3FD
2E3FE CJK UNIFIED IDEOGRAPH-#2E3FE
2E3FF CJK UNIFIED IDEOGRAPH-#2E3FF
2E400 CJK UNIFIED IDEOGRAPH-#2E400
2E401 CJK UNIFIED IDEOGRAPH-#2E401
2E402 CJK UNIFIED IDEOGRAPH-#2E402
2E403 CJK UNIFIED IDEOGRAPH-#2E403
2E404 CJK UNIFIED IDEOGRAPH-#2E404
2E405 CJK UNIFIED IDEOGRAPH-#2E405
2E406 CJK UNIFIED IDEOGRAPH-#2E406
2E407 CJK UNIFIED IDEOGRAPH-#2E407
2E408 CJK UNIFIED IDEOGRAPH-#2E408
2E409 CJK UNIFIED IDEOGRAPH-#2E409
2E40A CJK UNIFIED IDEOGRAPH-#2E40A
2E40B CJK UNIFIED IDEOGRAPH-#2E40B
2E40C CJK UNIFIED IDEOGRAPH-#2E40C
2E40D CJK UNIFIED IDEOGRAPH-#2E40D
2E40E CJK UNIFIED IDEOGRAPH-#2E40E
2E40F CJK UNIFIED IDEOGRAPH-#2E40F
2E410 CJK UNIFIED IDEOGRAPH-#2E410
2E411 CJK UNIFIED IDEOGRAPH-#2E411
2E412 CJK UNIFIED IDEOGRAPH-#2E412
2E413 CJK UNIFIED IDEOGRAPH-#2E413
2E414 CJK UNIFIED IDEOGRAPH-#2E414
2E415 CJK UNIFIED IDEOGRAPH-#2E415
2E416 CJK UNIFIED IDEOGRAPH-#2E416
2E417 CJK UNIFIED IDEOGRAPH-#2E417
2E418 CJK UNIFIED IDEOGRAPH-#2E418
2E419 CJK UNIFIED IDEOGRAPH-#2E419
2E41A CJK UNIFIED IDEOGRAPH-#2E41A
2E41B CJK UNIFIED IDEOGRAPH-#2E41B
2E41C CJK UNIFIED IDEOGRAPH-#2E41C
2E41D CJK UNIFIED IDEOGRAPH-#2E41D
2E41E CJK UNIFIED IDEOGRAPH-#2E41E
2E41F CJK UNIFIED IDEOGRAPH-#2E41F
2E420 CJK UNIFIED IDEOGRAPH-#2E420
2E421 CJK UNIFIED IDEOGRAPH-#2E421
2E422 CJK UNIFIED IDEOGRAPH-#2E422
2E423 CJK UNIFIED IDEOGRAPH-#2E423
2E424 CJK UNIFIED IDEOGRAPH-#2E424
2E425 CJK UNIFIED IDEOGRAPH-#2E425
2E426 CJK UNIFIED IDEOGRAPH-#2E426
2E427 CJK UNIFIED IDEOGRAPH-#2E427
2E428 CJK UNIFIED IDEOGRAPH-#2E428
2E429 CJK UNIFIED IDEOGRAPH-#2E429
2E42A CJK UNIFIED IDEOGRAPH-#2E42A
2E42B CJK UNIFIED IDEOGRAPH-#2E42B
2E42C CJK UNIFIED IDEOGRAPH-#2E42C
2E42D CJK UNIFIED IDEOGRAPH-#2E42D
2E42E CJK UNIFIED IDEOGRAPH-#2E42E
2E42F CJK UNIFIED IDEOGRAPH-#2E42F
2E430 CJK UNIFIED IDEOGRAPH-#2E430
2E431 CJK UNIFIED IDEOGRAPH-#2E431
2E432 CJK UNIFIED IDEOGRAPH-#2E432
2E433 CJK UNIFIED IDEOGRAPH-#2E433
2E434 CJK UNIFIED IDEOGRAPH-#2E434
2E435 CJK UNIFIED IDEOGRAPH-#2E435
2E436 CJK UNIFIED IDEOGRAPH-#2E436
2E437 CJK UNIFIED IDEOGRAPH-#2E437
2E438 CJK UNIFIED IDEOGRAPH-#2E438
2E439 CJK UNIFIED IDEOGRAPH-#2E439
2E43A CJK UNIFIED IDEOGRAPH-#2E43A
2E43B CJK UNIFIED IDEOGRAPH-#2E43B
2E43C CJK UNIFIED IDEOGRAPH-#2E43C
2E43D CJK UNIFIED IDEOGRAPH-#2E43D
2E43E CJK UNIFIED IDEOGRAPH-#2E43E
2E43F CJK UNIFIED IDEOGRAPH-#2E43F
2E440 CJK UNIFIED IDEOGRAPH-#2E440
2E441 CJK UNIFIED IDEOGRAPH-#2E441
2E442 CJK UNIFIED IDEOGRAPH-#2E442
2E443 CJK UNIFIED IDEOGRAPH-#2E443
2E444 CJK UNIFIED IDEOGRAPH-#2E444
2E445 CJK UNIFIED IDEOGRAPH-#2E445
2E446 CJK UNIFIED IDEOGRAPH-#2E446
2E447 CJK UNIFIED IDEOGRAPH-#2E447
2E448 CJK UNIFIED IDEOGRAPH-#2E448
2E449 CJK UNIFIED IDEOGRAPH-#2E449
2E44A CJK UNIFIED IDEOGRAPH-#2E44A
2E44B CJK UNIFIED IDEOGRAPH-#2E44B
2E44C CJK UNIFIED IDEOGRAPH-#2E44C
2E44D CJK UNIFIED IDEOGRAPH-#2E44D
2E44E CJK UNIFIED IDEOGRAPH-#2E44E
2E44F CJK UNIFIED IDEOGRAPH-#2E44F
2E450 CJK UNIFIED IDEOGRAPH-#2E450
2E451 CJK UNIFIED IDEOGRAPH-#2E451
2E452 CJK UNIFIED IDEOGRAPH-#2E452
2E453 CJK UNIFIED IDEOGRAPH-#2E453
2E454 CJK UNIFIED IDEOGRAPH-#2E454
2E455 CJK UNIFIED IDEOGRAPH-#2E455
2E456 CJK UNIFIED IDEOGRAPH-#2E456
2E457 CJK UNIFIED IDEOGRAPH-#2E457
2E458 CJK UNIFIED IDEOGRAPH-#2E458
2E459 CJK UNIFIED IDEOGRAPH-#2E459
2E45A CJK UNIFIED IDEOGRAPH-#2E45A
2E45B CJK UNIFIED IDEOGRAPH-#2E45B
2E45C CJK UNIFIED IDEOGRAPH-#2E45C
2E45D CJK UNIFIED IDEOGRAPH-#2E45D
2E45E CJK UNIFIED IDEOGRAPH-#2E45E
2E45F CJK UNIFIED IDEOGRAPH-#2E45F
2E460 CJK UNIFIED IDEOGRAPH-#2E460
2E461 CJK UNIFIED IDEOGRAPH-#2E461
2E462 CJK UNIFIED IDEOGRAPH-#2E462
2E463 CJK UNIFIED IDEOGRAPH-#2E463
2E464 CJK UNIFIED IDEOGRAPH-#2E464
2E465 CJK UNIFIED IDEOGRAPH-#2E465
2E466 CJK UNIFIED IDEOGRAPH-#2E466
2E467 CJK UNIFIED IDEOGRAPH-#2E467
2E468 CJK UNIFIED IDEOGRAPH-#2E468
2E469 CJK UNIFIED IDEOGRAPH-#2E469
2E46A CJK UNIFIED IDEOGRAPH-#2E46A
2E46B CJK UNIFIED IDEOGRAPH-#2E46B
2E46C CJK UNIFIED IDEOGRAPH-#2E46C
2E46D CJK UNIFIED IDEOGRAPH-#2E46D
2E46E CJK UNIFIED IDEOGRAPH-#2E46E
2E46F CJK UNIFIED IDEOGRAPH-#2E46F
2E470 CJK UNIFIED IDEOGRAPH-#2E470
2E471 CJK UNIFIED IDEOGRAPH-#2E471
2E472 CJK UNIFIED IDEOGRAPH-#2E472
2E473 CJK UNIFIED IDEOGRAPH-#2E473
2E474 CJK UNIFIED IDEOGRAPH-#2E474
2E475 CJK UNIFIED IDEOGRAPH-#2E475
2E476 CJK UNIFIED IDEOGRAPH-#2E476
2E477 CJK UNIFIED IDEOGRAPH-#2E477
2E478 CJK UNIFIED IDEOGRAPH-#2E478
2E479 CJK UNIFIED IDEOGRAPH-#2E479
2E47A CJK UNIFIED IDEOGRAPH-#2E47A
2E47B CJK UNIFIED IDEOGRAPH-#2E47B
2E47C CJK UNIFIED IDEOGRAPH-#2E47C
2E47D CJK UNIFIED IDEOGRAPH-#2E47D
2E47E CJK UNIFIED IDEOGRAPH-#2E47E
2E47F CJK UNIFIED IDEOGRAPH-#2E47F
2E480 CJK UNIFIED IDEOGRAPH-#2E480
2E481 CJK UNIFIED IDEOGRAPH-#2E481
2E482 CJK UNIFIED IDEOGRAPH-#2E482
2E483 CJK UNIFIED IDEOGRAPH-#2E483
2E484 CJK UNIFIED IDEOGRAPH-#2E484
2E485 CJK UNIFIED IDEOGRAPH-#2E485
2E486 CJK UNIFIED IDEOGRAPH-#2E486
2E487 CJK UNIFIED IDEOGRAPH-#2E487
2E488 CJK UNIFIED IDEOGRAPH-#2E488
2E489 CJK UNIFIED IDEOGRAPH-#2E489
2E48A CJK UNIFIED IDEOGRAPH-#2E48A
2E48B CJK UNIFIED IDEOGRAPH-#2E48B
2E48C CJK UNIFIED IDEOGRAPH-#2E48C
2E48D CJK UNIFIED IDEOGRAPH-#2E48D
2E48E CJK UNIFIED IDEOGRAPH-#2E48E
2E48F CJK UNIFIED IDEOGRAPH-#2E48F
2E490 CJK UNIFIED IDEOGRAPH-#2E490
2E491 CJK UNIFIED IDEOGRAPH-#2E491
2E492 CJK UNIFIED IDEOGRAPH-#2E492
2E493 CJK UNIFIED IDEOGRAPH-#2E493
2E494 CJK UNIFIED IDEOGRAPH-#2E494
2E495 CJK UNIFIED IDEOGRAPH-#2E495
2E496 CJK UNIFIED IDEOGRAPH-#2E496
2E497 CJK UNIFIED IDEOGRAPH-#2E497
2E498 CJK UNIFIED IDEOGRAPH-#2E498
2E499 CJK UNIFIED IDEOGRAPH-#2E499
2E49A CJK UNIFIED IDEOGRAPH-#2E49A
2E49B CJK UNIFIED IDEOGRAPH-#2E49B
2E49C CJK UNIFIED IDEOGRAPH-#2E49C
2E49D CJK UNIFIED IDEOGRAPH-#2E49D
2E49E CJK UNIFIED IDEOGRAPH-#2E49E
2E49F CJK UNIFIED IDEOGRAPH-#2E49F
2E4A0 CJK UNIFIED IDEOGRAPH-#2E4A0
2E4A1 CJK UNIFIED IDEOGRAPH-#2E4A1
2E4A2 CJK UNIFIED IDEOGRAPH-#2E4A2
2E4A3 CJK UNIFIED IDEOGRAPH-#2E4A3
2E4A4 CJK UNIFIED IDEOGRAPH-#2E4A4
2E4A5 CJK UNIFIED IDEOGRAPH-#2E4A5
2E4A6 CJK UNIFIED IDEOGRAPH-#2E4A6
2E4A7 CJK UNIFIED IDEOGRAPH-#2E4A7
2E4A8 CJK UNIFIED IDEOGRAPH-#2E4A8
2E4A9 CJK UNIFIED IDEOGRAPH-#2E4A9
2E4AA CJK UNIFIED IDEOGRAPH-#2E4AA
2E4AB CJK UNIFIED IDEOGRAPH-#2E4AB
2E4AC CJK UNIFIED IDEOGRAPH-#2E4AC
2E4AD CJK UNIFIED IDEOGRAPH-#2E4AD
2E4AE CJK UNIFIED IDEOGRAPH-#2E4AE
2E4AF CJK UNIFIED IDEOGRAPH-#2E4AF
2E4B0 CJK UNIFIED IDEOGRAPH-#2E4B0
2E4B1 CJK UNIFIED IDEOGRAPH-#2E4B1
2E4B2 CJK UNIFIED IDEOGRAPH-#2E4B2
2E4B3 CJK UNIFIED IDEOGRAPH-#2E4B3
2E4B4 CJK UNIFIED IDEOGRAPH-#2E4B4
2E4B5 CJK UNIFIED IDEOGRAPH-#2E4B5
2E4B6 CJK UNIFIED IDEOGRAPH-#2E4B6
2E4B7 CJK UNIFIED IDEOGRAPH-#2E4B7
2E4B8 CJK UNIFIED IDEOGRAPH-#2E4B8
2E4B9 CJK UNIFIED IDEOGRAPH-#2E4B9
2E4BA CJK UNIFIED IDEOGRAPH-#2E4BA
2E4BB CJK UNIFIED IDEOGRAPH-#2E4BB
2E4BC CJK UNIFIED IDEOGRAPH-#2E4BC
2E4BD CJK UNIFIED IDEOGRAPH-#2E4BD
2E4BE CJK UNIFIED IDEOGRAPH-#2E4BE
2E4BF CJK UNIFIED IDEOGRAPH-#2E4BF
2E4C0 CJK UNIFIED IDEOGRAPH-#2E4C0
2E4C1 CJK UNIFIED IDEOGRAPH-#2E4C1
2E4C2 CJK UNIFIED IDEOGRAPH-#2E4C2
2E4C3 CJK UNIFIED IDEOGRAPH-#2E4C3
2E4C4 CJK UNIFIED IDEOGRAPH-#2E4C4
2E4C5 CJK UNIFIED IDEOGRAPH-#2E4C5
2E4C6 CJK UNIFIED IDEOGRAPH-#2E4C6
2E4C7 CJK UNIFIED IDEOGRAPH-#2E4C7
2E4C8 CJK UNIFIED IDEOGRAPH-#2E4C8
2E4C9 CJK UNIFIED IDEOGRAPH-#2E4C9
2E4CA CJK UNIFIED IDEOGRAPH-#2E4CA
2E4CB CJK UNIFIED IDEOGRAPH-#2E4CB
2E4CC CJK UNIFIED IDEOGRAPH-#2E4CC
2E4CD CJK UNIFIED IDEOGRAPH-#2E4CD
2E4CE CJK UNIFIED IDEOGRAPH-#2E4CE
2E4CF CJK UNIFIED IDEOGRAPH-#2E4CF
2E4D0 CJK UNIFIED IDEOGRAPH-#2E4D0
2E4D1 CJK UNIFIED IDEOGRAPH-#2E4D1
2E4D2 CJK UNIFIED IDEOGRAPH-#2E4D2
2E4D3 CJK UNIFIED IDEOGRAPH-#2E4D3
2E4D4 CJK UNIFIED IDEOGRAPH-#2E4D4
2E4D5 CJK UNIFIED IDEOGRAPH-#2E4D5
2E4D6 CJK UNIFIED IDEOGRAPH-#2E4D6
2E4D7 CJK UNIFIED IDEOGRAPH-#2E4D7
2E4D8 CJK UNIFIED IDEOGRAPH-#2E4D8
2E4D9 CJK UNIFIED IDEOGRAPH-#2E4D9
2E4DA CJK UNIFIED IDEOGRAPH-#2E4DA
2E4DB CJK UNIFIED IDEOGRAPH-#2E4DB
2E4DC CJK UNIFIED IDEOGRAPH-#2E4DC
2E4DD CJK UNIFIED IDEOGRAPH-#2E4DD
2E4DE CJK UNIFIED IDEOGRAPH-#2E4DE
2E4DF CJK UNIFIED IDEOGRAPH-#2E4DF
2E4E0 CJK UNIFIED IDEOGRAPH-#2E4E0
2E4E1 CJK UNIFIED IDEOGRAPH-#2E4E1
2E4E2 CJK UNIFIED IDEOGRAPH-#2E4E2
2E4E3 CJK UNIFIED IDEOGRAPH-#2E4E3
2E4E4 CJK UNIFIED IDEOGRAPH-#2E4E4
2E4E5 CJK UNIFIED IDEOGRAPH-#2E4E5
2E4E6 CJK UNIFIED IDEOGRAPH-#2E4E6
2E4E7 CJK UNIFIED IDEOGRAPH-#2E4E7
2E4E8 CJK UNIFIED IDEOGRAPH-#2E4E8
2E4E9 CJK UNIFIED IDEOGRAPH-#2E4E9
2E4EA CJK UNIFIED IDEOGRAPH-#2E4EA
2E4EB CJK UNIFIED IDEOGRAPH-#2E4EB
2E4EC CJK UNIFIED IDEOGRAPH-#2E4EC
2E4ED CJK UNIFIED IDEOGRAPH-#2E4ED
2E4EE CJK UNIFIED IDEOGRAPH-#2E4EE
2E4EF CJK UNIFIED IDEOGRAPH-#2E4EF
2E4F0 CJK UNIFIED IDEOGRAPH-#2E4F0
2E4F1 CJK UNIFIED IDEOGRAPH-#2E4F1
2E4F2 CJK UNIFIED IDEOGRAPH-#2E4F2
2E4F3 CJK UNIFIED IDEOGRAPH-#2E4F3
2E4F4 CJK UNIFIED IDEOGRAPH-#2E4F4
2E4F5 CJK UNIFIED IDEOGRAPH-#2E4F5
2E4F6 CJK UNIFIED IDEOGRAPH-#2E4F6
2E4F7 CJK UNIFIED IDEOGRAPH-#2E4F7
2E4F8 CJK UNIFIED IDEOGRAPH-#2E4F8
2E4F9 CJK UNIFIED IDEOGRAPH-#2E4F9
2E4FA CJK UNIFIED IDEOGRAPH-#2E4FA
2E4FB CJK UNIFIED IDEOGRAPH-#2E4FB
2E4FC CJK UNIFIED IDEOGRAPH-#2E4FC
2E4FD CJK UNIFIED IDEOGRAPH-#2E4FD
2E4FE CJK UNIFIED IDEOGRAPH-#2E4FE
2E4FF CJK UNIFIED IDEOGRAPH-#2E4FF
2E500 CJK UNIFIED IDEOGRAPH-#2E500
2E501 CJK UNIFIED IDEOGRAPH-#2E501
2E502 CJK UNIFIED IDEOGRAPH-#2E502
2E503 CJK UNIFIED IDEOGRAPH-#2E503
2E504 CJK UNIFIED IDEOGRAPH-#2E504
2E505 CJK UNIFIED IDEOGRAPH-#2E505
2E506 CJK UNIFIED IDEOGRAPH-#2E506
2E507 CJK UNIFIED IDEOGRAPH-#2E507
2E508 CJK UNIFIED IDEOGRAPH-#2E508
2E509 CJK UNIFIED IDEOGRAPH-#2E509
2E50A CJK UNIFIED IDEOGRAPH-#2E50A
2E50B CJK UNIFIED IDEOGRAPH-#2E50B
2E50C CJK UNIFIED IDEOGRAPH-#2E50C
2E50D CJK UNIFIED IDEOGRAPH-#2E50D
2E50E CJK UNIFIED IDEOGRAPH-#2E50E
2E50F CJK UNIFIED IDEOGRAPH-#2E50F
2E510 CJK UNIFIED IDEOGRAPH-#2E510
2E511 CJK UNIFIED IDEOGRAPH-#2E511
2E512 CJK UNIFIED IDEOGRAPH-#2E512
2E513 CJK UNIFIED IDEOGRAPH-#2E513
2E514 CJK UNIFIED IDEOGRAPH-#2E514
2E515 CJK UNIFIED IDEOGRAPH-#2E515
2E516 CJK UNIFIED IDEOGRAPH-#2E516
2E517 CJK UNIFIED IDEOGRAPH-#2E517
2E518 CJK UNIFIED IDEOGRAPH-#2E518
2E519 CJK UNIFIED IDEOGRAPH-#2E519
2E51A CJK UNIFIED IDEOGRAPH-#2E51A
2E51B CJK UNIFIED IDEOGRAPH-#2E51B
2E51C CJK UNIFIED IDEOGRAPH-#2E51C
2E51D CJK UNIFIED IDEOGRAPH-#2E51D
2E51E CJK UNIFIED IDEOGRAPH-#2E51E
2E51F CJK UNIFIED IDEOGRAPH-#2E51F
2E520 CJK UNIFIED IDEOGRAPH-#2E520
2E521 CJK UNIFIED IDEOGRAPH-#2E521
2E522 CJK UNIFIED IDEOGRAPH-#2E522
2E523 CJK UNIFIED IDEOGRAPH-#2E523
2E524 CJK UNIFIED IDEOGRAPH-#2E524
2E525 CJK UNIFIED IDEOGRAPH-#2E525
2E526 CJK UNIFIED IDEOGRAPH-#2E526
2E527 CJK UNIFIED IDEOGRAPH-#2E527
2E528 CJK UNIFIED IDEOGRAPH-#2E528
2E529 CJK UNIFIED IDEOGRAPH-#2E529
2E52A CJK UNIFIED IDEOGRAPH-#2E52A
2E52B CJK UNIFIED IDEOGRAPH-#2E52B
2E52C CJK UNIFIED IDEOGRAPH-#2E52C
2E52D CJK UNIFIED IDEOGRAPH-#2E52D
2E52E CJK UNIFIED IDEOGRAPH-#2E52E
2E52F CJK UNIFIED IDEOGRAPH-#2E52F
2E530 CJK UNIFIED IDEOGRAPH-#2E530
2E531 CJK UNIFIED IDEOGRAPH-#2E531
2E532 CJK UNIFIED IDEOGRAPH-#2E532
2E533 CJK UNIFIED IDEOGRAPH-#2E533
2E534 CJK UNIFIED IDEOGRAPH-#2E534
2E535 CJK UNIFIED IDEOGRAPH-#2E535
2E536 CJK UNIFIED IDEOGRAPH-#2E536
2E537 CJK UNIFIED IDEOGRAPH-#2E537
2E538 CJK UNIFIED IDEOGRAPH-#2E538
2E539 CJK UNIFIED IDEOGRAPH-#2E539
2E53A CJK UNIFIED IDEOGRAPH-#2E53A
2E53B CJK UNIFIED IDEOGRAPH-#2E53B
2E53C CJK UNIFIED IDEOGRAPH-#2E53C
2E53D CJK UNIFIED IDEOGRAPH-#2E53D
2E53E CJK UNIFIED IDEOGRAPH-#2E53E
2E53F CJK UNIFIED IDEOGRAPH-#2E53F
2E540 CJK UNIFIED IDEOGRAPH-#2E540
2E541 CJK UNIFIED IDEOGRAPH-#2E541
2E542 CJK UNIFIED IDEOGRAPH-#2E542
2E543 CJK UNIFIED IDEOGRAPH-#2E543
2E544 CJK UNIFIED IDEOGRAPH-#2E544
2E545 CJK UNIFIED IDEOGRAPH-#2E545
2E546 CJK UNIFIED IDEOGRAPH-#2E546
2E547 CJK UNIFIED IDEOGRAPH-#2E547
2E548 CJK UNIFIED IDEOGRAPH-#2E548
2E549 CJK UNIFIED IDEOGRAPH-#2E549
2E54A CJK UNIFIED IDEOGRAPH-#2E54A
2E54B CJK UNIFIED IDEOGRAPH-#2E54B
2E54C CJK UNIFIED IDEOGRAPH-#2E54C
2E54D CJK UNIFIED IDEOGRAPH-#2E54D
2E54E CJK UNIFIED IDEOGRAPH-#2E54E
2E54F CJK UNIFIED IDEOGRAPH-#2E54F
2E550 CJK UNIFIED IDEOGRAPH-#2E550
2E551 CJK UNIFIED IDEOGRAPH-#2E551
2E552 CJK UNIFIED IDEOGRAPH-#2E552
2E553 CJK UNIFIED IDEOGRAPH-#2E553
2E554 CJK UNIFIED IDEOGRAPH-#2E554
2E555 CJK UNIFIED IDEOGRAPH-#2E555
2E556 CJK UNIFIED IDEOGRAPH-#2E556
2E557 CJK UNIFIED IDEOGRAPH-#2E557
2E558 CJK UNIFIED IDEOGRAPH-#2E558
2E559 CJK UNIFIED IDEOGRAPH-#2E559
2E55A CJK UNIFIED IDEOGRAPH-#2E55A
2E55B CJK UNIFIED IDEOGRAPH-#2E55B
2E55C CJK UNIFIED IDEOGRAPH-#2E55C
2E55D CJK UNIFIED IDEOGRAPH-#2E55D
2E55E CJK UNIFIED IDEOGRAPH-#2E55E
2E55F CJK UNIFIED IDEOGRAPH-#2E55F
2E560 CJK UNIFIED IDEOGRAPH-#2E560
2E561 CJK UNIFIED IDEOGRAPH-#2E561
2E562 CJK UNIFIED IDEOGRAPH-#2E562
2E563 CJK UNIFIED IDEOGRAPH-#2E563
2E564 CJK UNIFIED IDEOGRAPH-#2E564
2E565 CJK UNIFIED IDEOGRAPH-#2E565
2E566 CJK UNIFIED IDEOGRAPH-#2E566
2E567 CJK UNIFIED IDEOGRAPH-#2E567
2E568 CJK UNIFIED IDEOGRAPH-#2E568
2E569 CJK UNIFIED IDEOGRAPH-#2E569
2E56A CJK UNIFIED IDEOGRAPH-#2E56A
2E56B CJK UNIFIED IDEOGRAPH-#2E56B
2E56C CJK UNIFIED IDEOGRAPH-#2E56C
2E56D CJK UNIFIED IDEOGRAPH-#2E56D
2E56E CJK UNIFIED IDEOGRAPH-#2E56E
2E56F CJK UNIFIED IDEOGRAPH-#2E56F
2E570 CJK UNIFIED IDEOGRAPH-#2E570
2E571 CJK UNIFIED IDEOGRAPH-#2E571
2E572 CJK UNIFIED IDEOGRAPH-#2E572
2E573 CJK UNIFIED IDEOGRAPH-#2E573
2E574 CJK UNIFIED IDEOGRAPH-#2E574
2E575 CJK UNIFIED IDEOGRAPH-#2E575
2E576 CJK UNIFIED IDEOGRAPH-#2E576
2E577 CJK UNIFIED IDEOGRAPH-#2E577
2E578 CJK UNIFIED IDEOGRAPH-#2E578
2E579 CJK UNIFIED IDEOGRAPH-#2E579
2E57A CJK UNIFIED IDEOGRAPH-#2E57A
2E57B CJK UNIFIED IDEOGRAPH-#2E57B
2E57C CJK UNIFIED IDEOGRAPH-#2E57C
2E57D CJK UNIFIED IDEOGRAPH-#2E57D
2E57E CJK UNIFIED IDEOGRAPH-#2E57E
2E57F CJK UNIFIED IDEOGRAPH-#2E57F
2E580 CJK UNIFIED IDEOGRAPH-#2E580
2E581 CJK UNIFIED IDEOGRAPH-#2E581
2E582 CJK UNIFIED IDEOGRAPH-#2E582
2E583 CJK UNIFIED IDEOGRAPH-#2E583
2E584 CJK UNIFIED IDEOGRAPH-#2E584
2E585 CJK UNIFIED IDEOGRAPH-#2E585
2E586 CJK UNIFIED IDEOGRAPH-#2E586
2E587 CJK UNIFIED IDEOGRAPH-#2E587
2E588 CJK UNIFIED IDEOGRAPH-#2E588
2E589 CJK UNIFIED IDEOGRAPH-#2E589
2E58A CJK UNIFIED IDEOGRAPH-#2E58A
2E58B CJK UNIFIED IDEOGRAPH-#2E58B
2E58C CJK UNIFIED IDEOGRAPH-#2E58C
2E58D CJK UNIFIED IDEOGRAPH-#2E58D
2E58E CJK UNIFIED IDEOGRAPH-#2E58E
2E58F CJK UNIFIED IDEOGRAPH-#2E58F
2E590 CJK UNIFIED IDEOGRAPH-#2E590
2E591 CJK UNIFIED IDEOGRAPH-#2E591
2E592 CJK UNIFIED IDEOGRAPH-#2E592
2E593 CJK UNIFIED IDEOGRAPH-#2E593
2E594 CJK UNIFIED IDEOGRAPH-#2E594
2E595 CJK UNIFIED IDEOGRAPH-#2E595
2E596 CJK UNIFIED IDEOGRAPH-#2E596
2E597 CJK UNIFIED IDEOGRAPH-#2E597
2E598 CJK UNIFIED IDEOGRAPH-#2E598
2E599 CJK UNIFIED IDEOGRAPH-#2E599
2E59A CJK UNIFIED IDEOGRAPH-#2E59A
2E59B CJK UNIFIED IDEOGRAPH-#2E59B
2E59C CJK UNIFIED IDEOGRAPH-#2E59C
2E59D CJK UNIFIED IDEOGRAPH-#2E59D
2E59E CJK UNIFIED IDEOGRAPH-#2E59E
2E59F CJK UNIFIED IDEOGRAPH-#2E59F
2E5A0 CJK UNIFIED IDEOGRAPH-#2E5A0
2E5A1 CJK UNIFIED IDEOGRAPH-#2E5A1
2E5A2 CJK UNIFIED IDEOGRAPH-#2E5A2
2E5A3 CJK UNIFIED IDEOGRAPH-#2E5A3
2E5A4 CJK UNIFIED IDEOGRAPH-#2E5A4
2E5A5 CJK UNIFIED IDEOGRAPH-#2E5A5
2E5A6 CJK UNIFIED IDEOGRAPH-#2E5A6
2E5A7 CJK UNIFIED IDEOGRAPH-#2E5A7
2E5A8 CJK UNIFIED IDEOGRAPH-#2E5A8
2E5A9 CJK UNIFIED IDEOGRAPH-#2E5A9
2E5AA CJK UNIFIED IDEOGRAPH-#2E5AA
2E5AB CJK UNIFIED IDEOGRAPH-#2E5AB
2E5AC CJK UNIFIED IDEOGRAPH-#2E5AC
2E5AD CJK UNIFIED IDEOGRAPH-#2E5AD
2E5AE CJK UNIFIED IDEOGRAPH-#2E5AE
2E5AF CJK UNIFIED IDEOGRAPH-#2E5AF
2E5B0 CJK UNIFIED IDEOGRAPH-#2E5B0
2E5B1 CJK UNIFIED IDEOGRAPH-#2E5B1
2E5B2 CJK UNIFIED IDEOGRAPH-#2E5B2
2E5B3 CJK UNIFIED IDEOGRAPH-#2E5B3
2E5B4 CJK UNIFIED IDEOGRAPH-#2E5B4
2E5B5 CJK UNIFIED IDEOGRAPH-#2E5B5
2E5B6 CJK UNIFIED IDEOGRAPH-#2E5B6
2E5B7 CJK UNIFIED IDEOGRAPH-#2E5B7
2E5B8 CJK UNIFIED IDEOGRAPH-#2E5B8
2E5B9 CJK UNIFIED IDEOGRAPH-#2E5B9
2E5BA CJK UNIFIED IDEOGRAPH-#2E5BA
2E5BB CJK UNIFIED IDEOGRAPH-#2E5BB
2E5BC CJK UNIFIED IDEOGRAPH-#2E5BC
2E5BD CJK UNIFIED IDEOGRAPH-#2E5BD
2E5BE CJK UNIFIED IDEOGRAPH-#2E5BE
2E5BF CJK UNIFIED IDEOGRAPH-#2E5BF
2E5C0 CJK UNIFIED IDEOGRAPH-#2E5C0
2E5C1 CJK UNIFIED IDEOGRAPH-#2E5C1
2E5C2 CJK UNIFIED IDEOGRAPH-#2E5C2
2E5C3 CJK UNIFIED IDEOGRAPH-#2E5C3
2E5C4 CJK UNIFIED IDEOGRAPH-#2E5C4
2E5C5 CJK UNIFIED IDEOGRAPH-#2E5C5
2E5C6 CJK UNIFIED IDEOGRAPH-#2E5C6
2E5C7 CJK UNIFIED IDEOGRAPH-#2E5C7
2E5C8 CJK UNIFIED IDEOGRAPH-#2E5C8
2E5C9 CJK UNIFIED IDEOGRAPH-#2E5C9
2E5CA CJK UNIFIED IDEOGRAPH-#2E5CA
2E5CB CJK UNIFIED IDEOGRAPH-#2E5CB
2E5CC CJK UNIFIED IDEOGRAPH-#2E5CC
2E5CD CJK UNIFIED IDEOGRAPH-#2E5CD
2E5CE CJK UNIFIED IDEOGRAPH-#2E5CE
2E5CF CJK UNIFIED IDEOGRAPH-#2E5CF
2E5D0 CJK UNIFIED IDEOGRAPH-#2E5D0
2E5D1 CJK UNIFIED IDEOGRAPH-#2E5D1
2E5D2 CJK UNIFIED IDEOGRAPH-#2E5D2
2E5D3 CJK UNIFIED IDEOGRAPH-#2E5D3
2E5D4 CJK UNIFIED IDEOGRAPH-#2E5D4
2E5D5 CJK UNIFIED IDEOGRAPH-#2E5D5
2E5D6 CJK UNIFIED IDEOGRAPH-#2E5D6
2E5D7 CJK UNIFIED IDEOGRAPH-#2E5D7
2E5D8 CJK UNIFIED IDEOGRAPH-#2E5D8
2E5D9 CJK UNIFIED IDEOGRAPH-#2E5D9
2E5DA CJK UNIFIED IDEOGRAPH-#2E5DA
2E5DB CJK UNIFIED IDEOGRAPH-#2E5DB
2E5DC CJK UNIFIED IDEOGRAPH-#2E5DC
2E5DD CJK UNIFIED IDEOGRAPH-#2E5DD
2E5DE CJK UNIFIED IDEOGRAPH-#2E5DE
2E5DF CJK UNIFIED IDEOGRAPH-#2E5DF
2E5E0 CJK UNIFIED IDEOGRAPH-#2E5E0
2E5E1 CJK UNIFIED IDEOGRAPH-#2E5E1
2E5E2 CJK UNIFIED IDEOGRAPH-#2E5E2
2E5E3 CJK UNIFIED IDEOGRAPH-#2E5E3
2E5E4 CJK UNIFIED IDEOGRAPH-#2E5E4
2E5E5 CJK UNIFIED IDEOGRAPH-#2E5E5
2E5E6 CJK UNIFIED IDEOGRAPH-#2E5E6
2E5E7 CJK UNIFIED IDEOGRAPH-#2E5E7
2E5E8 CJK UNIFIED IDEOGRAPH-#2E5E8
2E5E9 CJK UNIFIED IDEOGRAPH-#2E5E9
2E5EA CJK UNIFIED IDEOGRAPH-#2E5EA
2E5EB CJK UNIFIED IDEOGRAPH-#2E5EB
2E5EC CJK UNIFIED IDEOGRAPH-#2E5EC
2E5ED CJK UNIFIED IDEOGRAPH-#2E5ED
2E5EE CJK UNIFIED IDEOGRAPH-#2E5EE
2E5EF CJK UNIFIED IDEOGRAPH-#2E5EF
2E5F0 CJK UNIFIED IDEOGRAPH-#2E5F0
2E5F1 CJK UNIFIED IDEOGRAPH-#2E5F1
2E5F2 CJK UNIFIED IDEOGRAPH-#2E5F2
2E5F3 CJK UNIFIED IDEOGRAPH-#2E5F3
2E5F4 CJK UNIFIED IDEOGRAPH-#2E5F4
2E5F5 CJK UNIFIED IDEOGRAPH-#2E5F5
2E5F6 CJK UNIFIED IDEOGRAPH-#2E5F6
2E5F7 CJK UNIFIED IDEOGRAPH-#2E5F7
2E5F8 CJK UNIFIED IDEOGRAPH-#2E5F8
2E5F9 CJK UNIFIED IDEOGRAPH-#2E5F9
2E5FA CJK UNIFIED IDEOGRAPH-#2E5FA
2E5FB CJK UNIFIED IDEOGRAPH-#2E5FB
2E5FC CJK UNIFIED IDEOGRAPH-#2E5FC
2E5FD CJK UNIFIED IDEOGRAPH-#2E5FD
2E5FE CJK UNIFIED IDEOGRAPH-#2E5FE
2E5FF CJK UNIFIED IDEOGRAPH-#2E5FF
2E600 CJK UNIFIED IDEOGRAPH-#2E600
2E601 CJK UNIFIED IDEOGRAPH-#2E601
2E602 CJK UNIFIED IDEOGRAPH-#2E602
2E603 CJK UNIFIED IDEOGRAPH-#2E603
2E604 CJK UNIFIED IDEOGRAPH-#2E604
2E605 CJK UNIFIED IDEOGRAPH-#2E605
2E606 CJK UNIFIED IDEOGRAPH-#2E606
2E607 CJK UNIFIED IDEOGRAPH-#2E607
2E608 CJK UNIFIED IDEOGRAPH-#2E608
2E609 CJK UNIFIED IDEOGRAPH-#2E609
2E60A CJK UNIFIED IDEOGRAPH-#2E60A
2E60B CJK UNIFIED IDEOGRAPH-#2E60B
2E60C CJK UNIFIED IDEOGRAPH-#2E60C
2E60D CJK UNIFIED IDEOGRAPH-#2E60D
2E60E CJK UNIFIED IDEOGRAPH-#2E60E
2E60F CJK UNIFIED IDEOGRAPH-#2E60F
2E610 CJK UNIFIED IDEOGRAPH-#2E610
2E611 CJK UNIFIED IDEOGRAPH-#2E611
2E612 CJK UNIFIED IDEOGRAPH-#2E612
2E613 CJK UNIFIED IDEOGRAPH-#2E613
2E614 CJK UNIFIED IDEOGRAPH-#2E614
2E615 CJK UNIFIED IDEOGRAPH-#2E615
2E616 CJK UNIFIED IDEOGRAPH-#2E616
2E617 CJK UNIFIED IDEOGRAPH-#2E617
2E618 CJK UNIFIED IDEOGRAPH-#2E618
2E619 CJK UNIFIED IDEOGRAPH-#2E619
2E61A CJK UNIFIED IDEOGRAPH-#2E61A
2E61B CJK UNIFIED IDEOGRAPH-#2E61B
2E61C CJK UNIFIED IDEOGRAPH-#2E61C
2E61D CJK UNIFIED IDEOGRAPH-#2E61D
2E61E CJK UNIFIED IDEOGRAPH-#2E61E
2E61F CJK UNIFIED IDEOGRAPH-#2E61F
2E620 CJK UNIFIED IDEOGRAPH-#2E620
2E621 CJK UNIFIED IDEOGRAPH-#2E621
2E622 CJK UNIFIED IDEOGRAPH-#2E622
2E623 CJK UNIFIED IDEOGRAPH-#2E623
2E624 CJK UNIFIED IDEOGRAPH-#2E624
2E625 CJK UNIFIED IDEOGRAPH-#2E625
2E626 CJK UNIFIED IDEOGRAPH-#2E626
2E627 CJK UNIFIED IDEOGRAPH-#2E627
2E628 CJK UNIFIED IDEOGRAPH-#2E628
2E629 CJK UNIFIED IDEOGRAPH-#2E629
2E62A CJK UNIFIED IDEOGRAPH-#2E62A
2E62B CJK UNIFIED IDEOGRAPH-#2E62B
2E62C CJK UNIFIED IDEOGRAPH-#2E62C
2E62D CJK UNIFIED IDEOGRAPH-#2E62D
2E62E CJK UNIFIED IDEOGRAPH-#2E62E
2E62F CJK UNIFIED IDEOGRAPH-#2E62F
2E630 CJK UNIFIED IDEOGRAPH-#2E630
2E631 CJK UNIFIED IDEOGRAPH-#2E631
2E632 CJK UNIFIED IDEOGRAPH-#2E632
2E633 CJK UNIFIED IDEOGRAPH-#2E633
2E634 CJK UNIFIED IDEOGRAPH-#2E634
2E635 CJK UNIFIED IDEOGRAPH-#2E635
2E636 CJK UNIFIED IDEOGRAPH-#2E636
2E637 CJK UNIFIED IDEOGRAPH-#2E637
2E638 CJK UNIFIED IDEOGRAPH-#2E638
2E639 CJK UNIFIED IDEOGRAPH-#2E639
2E63A CJK UNIFIED IDEOGRAPH-#2E63A
2E63B CJK UNIFIED IDEOGRAPH-#2E63B
2E63C CJK UNIFIED IDEOGRAPH-#2E63C
2E63D CJK UNIFIED IDEOGRAPH-#2E63D
2E63E CJK UNIFIED IDEOGRAPH-#2E63E
2E63F CJK UNIFIED IDEOGRAPH-#2E63F
2E640 CJK UNIFIED IDEOGRAPH-#2E640
2E641 CJK UNIFIED IDEOGRAPH-#2E641
2E642 CJK UNIFIED IDEOGRAPH-#2E642
2E643 CJK UNIFIED IDEOGRAPH-#2E643
2E644 CJK UNIFIED IDEOGRAPH-#2E644
2E645 CJK UNIFIED IDEOGRAPH-#2E645
2E646 CJK UNIFIED IDEOGRAPH-#2E646
2E647 CJK UNIFIED IDEOGRAPH-#2E647
2E648 CJK UNIFIED IDEOGRAPH-#2E648
2E649 CJK UNIFIED IDEOGRAPH-#2E649
2E64A CJK UNIFIED IDEOGRAPH-#2E64A
2E64B CJK UNIFIED IDEOGRAPH-#2E64B
2E64C CJK UNIFIED IDEOGRAPH-#2E64C
2E64D CJK UNIFIED IDEOGRAPH-#2E64D
2E64E CJK UNIFIED IDEOGRAPH-#2E64E
2E64F CJK UNIFIED IDEOGRAPH-#2E64F
2E650 CJK UNIFIED IDEOGRAPH-#2E650
2E651 CJK UNIFIED IDEOGRAPH-#2E651
2E652 CJK UNIFIED IDEOGRAPH-#2E652
2E653 CJK UNIFIED IDEOGRAPH-#2E653
2E654 CJK UNIFIED IDEOGRAPH-#2E654
2E655 CJK UNIFIED IDEOGRAPH-#2E655
2E656 CJK UNIFIED IDEOGRAPH-#2E656
2E657 CJK UNIFIED IDEOGRAPH-#2E657
2E658 CJK UNIFIED IDEOGRAPH-#2E658
2E659 CJK UNIFIED IDEOGRAPH-#2E659
2E65A CJK UNIFIED IDEOGRAPH-#2E65A
2E65B CJK UNIFIED IDEOGRAPH-#2E65B
2E65C CJK UNIFIED IDEOGRAPH-#2E65C
2E65D CJK UNIFIED IDEOGRAPH-#2E65D
2E65E CJK UNIFIED IDEOGRAPH-#2E65E
2E65F CJK UNIFIED IDEOGRAPH-#2E65F
2E660 CJK UNIFIED IDEOGRAPH-#2E660
2E661 CJK UNIFIED IDEOGRAPH-#2E661
2E662 CJK UNIFIED IDEOGRAPH-#2E662
2E663 CJK UNIFIED IDEOGRAPH-#2E663
2E664 CJK UNIFIED IDEOGRAPH-#2E664
2E665 CJK UNIFIED IDEOGRAPH-#2E665
2E666 CJK UNIFIED IDEOGRAPH-#2E666
2E667 CJK UNIFIED IDEOGRAPH-#2E667
2E668 CJK UNIFIED IDEOGRAPH-#2E668
2E669 CJK UNIFIED IDEOGRAPH-#2E669
2E66A CJK UNIFIED IDEOGRAPH-#2E66A
2E66B CJK UNIFIED IDEOGRAPH-#2E66B
2E66C CJK UNIFIED IDEOGRAPH-#2E66C
2E66D CJK UNIFIED IDEOGRAPH-#2E66D
2E66E CJK UNIFIED IDEOGRAPH-#2E66E
2E66F CJK UNIFIED IDEOGRAPH-#2E66F
2E670 CJK UNIFIED IDEOGRAPH-#2E670
2E671 CJK UNIFIED IDEOGRAPH-#2E671
2E672 CJK UNIFIED IDEOGRAPH-#2E672
2E673 CJK UNIFIED IDEOGRAPH-#2E673
2E674 CJK UNIFIED IDEOGRAPH-#2E674
2E675 CJK UNIFIED IDEOGRAPH-#2E675
2E676 CJK UNIFIED IDEOGRAPH-#2E676
2E677 CJK UNIFIED IDEOGRAPH-#2E677
2E678 CJK UNIFIED IDEOGRAPH-#2E678
2E679 CJK UNIFIED IDEOGRAPH-#2E679
2E67A CJK UNIFIED IDEOGRAPH-#2E67A
2E67B CJK UNIFIED IDEOGRAPH-#2E67B
2E67C CJK UNIFIED IDEOGRAPH-#2E67C
2E67D CJK UNIFIED IDEOGRAPH-#2E67D
2E67E CJK UNIFIED IDEOGRAPH-#2E67E
2E67F CJK UNIFIED IDEOGRAPH-#2E67F
2E680 CJK UNIFIED IDEOGRAPH-#2E680
2E681 CJK UNIFIED IDEOGRAPH-#2E681
2E682 CJK UNIFIED IDEOGRAPH-#2E682
2E683 CJK UNIFIED IDEOGRAPH-#2E683
2E684 CJK UNIFIED IDEOGRAPH-#2E684
2E685 CJK UNIFIED IDEOGRAPH-#2E685
2E686 CJK UNIFIED IDEOGRAPH-#2E686
2E687 CJK UNIFIED IDEOGRAPH-#2E687
2E688 CJK UNIFIED IDEOGRAPH-#2E688
2E689 CJK UNIFIED IDEOGRAPH-#2E689
2E68A CJK UNIFIED IDEOGRAPH-#2E68A
2E68B CJK UNIFIED IDEOGRAPH-#2E68B
2E68C CJK UNIFIED IDEOGRAPH-#2E68C
2E68D CJK UNIFIED IDEOGRAPH-#2E68D
2E68E CJK UNIFIED IDEOGRAPH-#2E68E
2E68F CJK UNIFIED IDEOGRAPH-#2E68F
2E690 CJK UNIFIED IDEOGRAPH-#2E690
2E691 CJK UNIFIED IDEOGRAPH-#2E691
2E692 CJK UNIFIED IDEOGRAPH-#2E692
2E693 CJK UNIFIED IDEOGRAPH-#2E693
2E694 CJK UNIFIED IDEOGRAPH-#2E694
2E695 CJK UNIFIED IDEOGRAPH-#2E695
2E696 CJK UNIFIED IDEOGRAPH-#2E696
2E697 CJK UNIFIED IDEOGRAPH-#2E697
2E698 CJK UNIFIED IDEOGRAPH-#2E698
2E699 CJK UNIFIED IDEOGRAPH-#2E699
2E69A CJK UNIFIED IDEOGRAPH-#2E69A
2E69B CJK UNIFIED IDEOGRAPH-#2E69B
2E69C CJK UNIFIED IDEOGRAPH-#2E69C
2E69D CJK UNIFIED IDEOGRAPH-#2E69D
2E69E CJK UNIFIED IDEOGRAPH-#2E69E
2E69F CJK UNIFIED IDEOGRAPH-#2E69F
2E6A0 CJK UNIFIED IDEOGRAPH-#2E6A0
2E6A1 CJK UNIFIED IDEOGRAPH-#2E6A1
2E6A2 CJK UNIFIED IDEOGRAPH-#2E6A2
2E6A3 CJK UNIFIED IDEOGRAPH-#2E6A3
2E6A4 CJK UNIFIED IDEOGRAPH-#2E6A4
2E6A5 CJK UNIFIED IDEOGRAPH-#2E6A5
2E6A6 CJK UNIFIED IDEOGRAPH-#2E6A6
2E6A7 CJK UNIFIED IDEOGRAPH-#2E6A7
2E6A8 CJK UNIFIED IDEOGRAPH-#2E6A8
2E6A9 CJK UNIFIED IDEOGRAPH-#2E6A9
2E6AA CJK UNIFIED IDEOGRAPH-#2E6AA
2E6AB CJK UNIFIED IDEOGRAPH-#2E6AB
2E6AC CJK UNIFIED IDEOGRAPH-#2E6AC
2E6AD CJK UNIFIED IDEOGRAPH-#2E6AD
2E6AE CJK UNIFIED IDEOGRAPH-#2E6AE
2E6AF CJK UNIFIED IDEOGRAPH-#2E6AF
2E6B0 CJK UNIFIED IDEOGRAPH-#2E6B0
2E6B1 CJK UNIFIED IDEOGRAPH-#2E6B1
2E6B2 CJK UNIFIED IDEOGRAPH-#2E6B2
2E6B3 CJK UNIFIED IDEOGRAPH-#2E6B3
2E6B4 CJK UNIFIED IDEOGRAPH-#2E6B4
2E6B5 CJK UNIFIED IDEOGRAPH-#2E6B5
2E6B6 CJK UNIFIED IDEOGRAPH-#2E6B6
2E6B7 CJK UNIFIED IDEOGRAPH-#2E6B7
2E6B8 CJK UNIFIED IDEOGRAPH-#2E6B8
2E6B9 CJK UNIFIED IDEOGRAPH-#2E6B9
2E6BA CJK UNIFIED IDEOGRAPH-#2E6BA
2E6BB CJK UNIFIED IDEOGRAPH-#2E6BB
2E6BC CJK UNIFIED IDEOGRAPH-#2E6BC
2E6BD CJK UNIFIED IDEOGRAPH-#2E6BD
2E6BE CJK UNIFIED IDEOGRAPH-#2E6BE
2E6BF CJK UNIFIED IDEOGRAPH-#2E6BF
2E6C0 CJK UNIFIED IDEOGRAPH-#2E6C0
2E6C1 CJK UNIFIED IDEOGRAPH-#2E6C1
2E6C2 CJK UNIFIED IDEOGRAPH-#2E6C2
2E6C3 CJK UNIFIED IDEOGRAPH-#2E6C3
2E6C4 CJK UNIFIED IDEOGRAPH-#2E6C4
2E6C5 CJK UNIFIED IDEOGRAPH-#2E6C5
2E6C6 CJK UNIFIED IDEOGRAPH-#2E6C6
2E6C7 CJK UNIFIED IDEOGRAPH-#2E6C7
2E6C8 CJK UNIFIED IDEOGRAPH-#2E6C8
2E6C9 CJK UNIFIED IDEOGRAPH-#2E6C9
2E6CA CJK UNIFIED IDEOGRAPH-#2E6CA
2E6CB CJK UNIFIED IDEOGRAPH-#2E6CB
2E6CC CJK UNIFIED IDEOGRAPH-#2E6CC
2E6CD CJK UNIFIED IDEOGRAPH-#2E6CD
2E6CE CJK UNIFIED IDEOGRAPH-#2E6CE
2E6CF CJK UNIFIED IDEOGRAPH-#2E6CF
2E6D0 CJK UNIFIED IDEOGRAPH-#2E6D0
2E6D1 CJK UNIFIED IDEOGRAPH-#2E6D1
2E6D2 CJK UNIFIED IDEOGRAPH-#2E6D2
2E6D3 CJK UNIFIED IDEOGRAPH-#2E6D3
2E6D4 CJK UNIFIED IDEOGRAPH-#2E6D4
2E6D5 CJK UNIFIED IDEOGRAPH-#2E6D5
2E6D6 CJK UNIFIED IDEOGRAPH-#2E6D6
2E6D7 CJK UNIFIED IDEOGRAPH-#2E6D7
2E6D8 CJK UNIFIED IDEOGRAPH-#2E6D8
2E6D9 CJK UNIFIED IDEOGRAPH-#2E6D9
2E6DA CJK UNIFIED IDEOGRAPH-#2E6DA
2E6DB CJK UNIFIED IDEOGRAPH-#2E6DB
2E6DC CJK UNIFIED IDEOGRAPH-#2E6DC
2E6DD CJK UNIFIED IDEOGRAPH-#2E6DD
2E6DE CJK UNIFIED IDEOGRAPH-#2E6DE
2E6DF CJK UNIFIED IDEOGRAPH-#2E6DF
2E6E0 CJK UNIFIED IDEOGRAPH-#2E6E0
2E6E1 CJK UNIFIED IDEOGRAPH-#2E6E1
2E6E2 CJK UNIFIED IDEOGRAPH-#2E6E2
2E6E3 CJK UNIFIED IDEOGRAPH-#2E6E3
2E6E4 CJK UNIFIED IDEOGRAPH-#2E6E4
2E6E5 CJK UNIFIED IDEOGRAPH-#2E6E5
2E6E6 CJK UNIFIED IDEOGRAPH-#2E6E6
2E6E7 CJK UNIFIED IDEOGRAPH-#2E6E7
2E6E8 CJK UNIFIED IDEOGRAPH-#2E6E8
2E6E9 CJK UNIFIED IDEOGRAPH-#2E6E9
2E6EA CJK UNIFIED IDEOGRAPH-#2E6EA
2E6EB CJK UNIFIED IDEOGRAPH-#2E6EB
2E6EC CJK UNIFIED IDEOGRAPH-#2E6EC
2E6ED CJK UNIFIED IDEOGRAPH-#2E6ED
2E6EE CJK UNIFIED IDEOGRAPH-#2E6EE
2E6EF CJK UNIFIED IDEOGRAPH-#2E6EF
2E6F0 CJK UNIFIED IDEOGRAPH-#2E6F0
2E6F1 CJK UNIFIED IDEOGRAPH-#2E6F1
2E6F2 CJK UNIFIED IDEOGRAPH-#2E6F2
2E6F3 CJK UNIFIED IDEOGRAPH-#2E6F3
2E6F4 CJK UNIFIED IDEOGRAPH-#2E6F4
2E6F5 CJK UNIFIED IDEOGRAPH-#2E6F5
2E6F6 CJK UNIFIED IDEOGRAPH-#2E6F6
2E6F7 CJK UNIFIED IDEOGRAPH-#2E6F7
2E6F8 CJK UNIFIED IDEOGRAPH-#2E6F8
2E6F9 CJK UNIFIED IDEOGRAPH-#2E6F9
2E6FA CJK UNIFIED IDEOGRAPH-#2E6FA
2E6FB CJK UNIFIED IDEOGRAPH-#2E6FB
2E6FC CJK UNIFIED IDEOGRAPH-#2E6FC
2E6FD CJK UNIFIED IDEOGRAPH-#2E6FD
2E6FE CJK UNIFIED IDEOGRAPH-#2E6FE
2E6FF CJK UNIFIED IDEOGRAPH-#2E6FF
2E700 CJK UNIFIED IDEOGRAPH-#2E700
2E701 CJK UNIFIED IDEOGRAPH-#2E701
2E702 CJK UNIFIED IDEOGRAPH-#2E702
2E703 CJK UNIFIED IDEOGRAPH-#2E703
2E704 CJK UNIFIED IDEOGRAPH-#2E704
2E705 CJK UNIFIED IDEOGRAPH-#2E705
2E706 CJK UNIFIED IDEOGRAPH-#2E706
2E707 CJK UNIFIED IDEOGRAPH-#2E707
2E708 CJK UNIFIED IDEOGRAPH-#2E708
2E709 CJK UNIFIED IDEOGRAPH-#2E709
2E70A CJK UNIFIED IDEOGRAPH-#2E70A
2E70B CJK UNIFIED IDEOGRAPH-#2E70B
2E70C CJK UNIFIED IDEOGRAPH-#2E70C
2E70D CJK UNIFIED IDEOGRAPH-#2E70D
2E70E CJK UNIFIED IDEOGRAPH-#2E70E
2E70F CJK UNIFIED IDEOGRAPH-#2E70F
2E710 CJK UNIFIED IDEOGRAPH-#2E710
2E711 CJK UNIFIED IDEOGRAPH-#2E711
2E712 CJK UNIFIED IDEOGRAPH-#2E712
2E713 CJK UNIFIED IDEOGRAPH-#2E713
2E714 CJK UNIFIED IDEOGRAPH-#2E714
2E715 CJK UNIFIED IDEOGRAPH-#2E715
2E716 CJK UNIFIED IDEOGRAPH-#2E716
2E717 CJK UNIFIED IDEOGRAPH-#2E717
2E718 CJK UNIFIED IDEOGRAPH-#2E718
2E719 CJK UNIFIED IDEOGRAPH-#2E719
2E71A CJK UNIFIED IDEOGRAPH-#2E71A
2E71B CJK UNIFIED IDEOGRAPH-#2E71B
2E71C CJK UNIFIED IDEOGRAPH-#2E71C
2E71D CJK UNIFIED IDEOGRAPH-#2E71D
2E71E CJK UNIFIED IDEOGRAPH-#2E71E
2E71F CJK UNIFIED IDEOGRAPH-#2E71F
2E720 CJK UNIFIED IDEOGRAPH-#2E720
2E721 CJK UNIFIED IDEOGRAPH-#2E721
2E722 CJK UNIFIED IDEOGRAPH-#2E722
2E723 CJK UNIFIED IDEOGRAPH-#2E723
2E724 CJK UNIFIED IDEOGRAPH-#2E724
2E725 CJK UNIFIED IDEOGRAPH-#2E725
2E726 CJK UNIFIED IDEOGRAPH-#2E726
2E727 CJK UNIFIED IDEOGRAPH-#2E727
2E728 CJK UNIFIED IDEOGRAPH-#2E728
2E729 CJK UNIFIED IDEOGRAPH-#2E729
2E72A CJK UNIFIED IDEOGRAPH-#2E72A
2E72B CJK UNIFIED IDEOGRAPH-#2E72B
2E72C CJK UNIFIED IDEOGRAPH-#2E72C
2E72D CJK UNIFIED IDEOGRAPH-#2E72D
2E72E CJK UNIFIED IDEOGRAPH-#2E72E
2E72F CJK UNIFIED IDEOGRAPH-#2E72F
2E730 CJK UNIFIED IDEOGRAPH-#2E730
2E731 CJK UNIFIED IDEOGRAPH-#2E731
2E732 CJK UNIFIED IDEOGRAPH-#2E732
2E733 CJK UNIFIED IDEOGRAPH-#2E733
2E734 CJK UNIFIED IDEOGRAPH-#2E734
2E735 CJK UNIFIED IDEOGRAPH-#2E735
2E736 CJK UNIFIED IDEOGRAPH-#2E736
2E737 CJK UNIFIED IDEOGRAPH-#2E737
2E738 CJK UNIFIED IDEOGRAPH-#2E738
2E739 CJK UNIFIED IDEOGRAPH-#2E739
2E73A CJK UNIFIED IDEOGRAPH-#2E73A
2E73B CJK UNIFIED IDEOGRAPH-#2E73B
2E73C CJK UNIFIED IDEOGRAPH-#2E73C
2E73D CJK UNIFIED IDEOGRAPH-#2E73D
2E73E CJK UNIFIED IDEOGRAPH-#2E73E
2E73F CJK UNIFIED IDEOGRAPH-#2E73F
2E740 CJK UNIFIED IDEOGRAPH-#2E740
2E741 CJK UNIFIED IDEOGRAPH-#2E741
2E742 CJK UNIFIED IDEOGRAPH-#2E742
2E743 CJK UNIFIED IDEOGRAPH-#2E743
2E744 CJK UNIFIED IDEOGRAPH-#2E744
2E745 CJK UNIFIED IDEOGRAPH-#2E745
2E746 CJK UNIFIED IDEOGRAPH-#2E746
2E747 CJK UNIFIED IDEOGRAPH-#2E747
2E748 CJK UNIFIED IDEOGRAPH-#2E748
2E749 CJK UNIFIED IDEOGRAPH-#2E749
2E74A CJK UNIFIED IDEOGRAPH-#2E74A
2E74B CJK UNIFIED IDEOGRAPH-#2E74B
2E74C CJK UNIFIED IDEOGRAPH-#2E74C
2E74D CJK UNIFIED IDEOGRAPH-#2E74D
2E74E CJK UNIFIED IDEOGRAPH-#2E74E
2E74F CJK UNIFIED IDEOGRAPH-#2E74F
2E750 CJK UNIFIED IDEOGRAPH-#2E750
2E751 CJK UNIFIED IDEOGRAPH-#2E751
2E752 CJK UNIFIED IDEOGRAPH-#2E752
2E753 CJK UNIFIED IDEOGRAPH-#2E753
2E754 CJK UNIFIED IDEOGRAPH-#2E754
2E755 CJK UNIFIED IDEOGRAPH-#2E755
2E756 CJK UNIFIED IDEOGRAPH-#2E756
2E757 CJK UNIFIED IDEOGRAPH-#2E757
2E758 CJK UNIFIED IDEOGRAPH-#2E758
2E759 CJK UNIFIED IDEOGRAPH-#2E759
2E75A CJK UNIFIED IDEOGRAPH-#2E75A
2E75B CJK UNIFIED IDEOGRAPH-#2E75B
2E75C CJK UNIFIED IDEOGRAPH-#2E75C
2E75D CJK UNIFIED IDEOGRAPH-#2E75D
2E75E CJK UNIFIED IDEOGRAPH-#2E75E
2E75F CJK UNIFIED IDEOGRAPH-#2E75F
2E760 CJK UNIFIED IDEOGRAPH-#2E760
2E761 CJK UNIFIED IDEOGRAPH-#2E761
2E762 CJK UNIFIED IDEOGRAPH-#2E762
2E763 CJK UNIFIED IDEOGRAPH-#2E763
2E764 CJK UNIFIED IDEOGRAPH-#2E764
2E765 CJK UNIFIED IDEOGRAPH-#2E765
2E766 CJK UNIFIED IDEOGRAPH-#2E766
2E767 CJK UNIFIED IDEOGRAPH-#2E767
2E768 CJK UNIFIED IDEOGRAPH-#2E768
2E769 CJK UNIFIED IDEOGRAPH-#2E769
2E76A CJK UNIFIED IDEOGRAPH-#2E76A
2E76B CJK UNIFIED IDEOGRAPH-#2E76B
2E76C CJK UNIFIED IDEOGRAPH-#2E76C
2E76D CJK UNIFIED IDEOGRAPH-#2E76D
2E76E CJK UNIFIED IDEOGRAPH-#2E76E
2E76F CJK UNIFIED IDEOGRAPH-#2E76F
2E770 CJK UNIFIED IDEOGRAPH-#2E770
2E771 CJK UNIFIED IDEOGRAPH-#2E771
2E772 CJK UNIFIED IDEOGRAPH-#2E772
2E773 CJK UNIFIED IDEOGRAPH-#2E773
2E774 CJK UNIFIED IDEOGRAPH-#2E774
2E775 CJK UNIFIED IDEOGRAPH-#2E775
2E776 CJK UNIFIED IDEOGRAPH-#2E776
2E777 CJK UNIFIED IDEOGRAPH-#2E777
2E778 CJK UNIFIED IDEOGRAPH-#2E778
2E779 CJK UNIFIED IDEOGRAPH-#2E779
2E77A CJK UNIFIED IDEOGRAPH-#2E77A
2E77B CJK UNIFIED IDEOGRAPH-#2E77B
2E77C CJK UNIFIED IDEOGRAPH-#2E77C
2E77D CJK UNIFIED IDEOGRAPH-#2E77D
2E77E CJK UNIFIED IDEOGRAPH-#2E77E
2E77F CJK UNIFIED IDEOGRAPH-#2E77F
2E780 CJK UNIFIED IDEOGRAPH-#2E780
2E781 CJK UNIFIED IDEOGRAPH-#2E781
2E782 CJK UNIFIED IDEOGRAPH-#2E782
2E783 CJK UNIFIED IDEOGRAPH-#2E783
2E784 CJK UNIFIED IDEOGRAPH-#2E784
2E785 CJK UNIFIED IDEOGRAPH-#2E785
2E786 CJK UNIFIED IDEOGRAPH-#2E786
2E787 CJK UNIFIED IDEOGRAPH-#2E787
2E788 CJK UNIFIED IDEOGRAPH-#2E788
2E789 CJK UNIFIED IDEOGRAPH-#2E789
2E78A CJK UNIFIED IDEOGRAPH-#2E78A
2E78B CJK UNIFIED IDEOGRAPH-#2E78B
2E78C CJK UNIFIED IDEOGRAPH-#2E78C
2E78D CJK UNIFIED IDEOGRAPH-#2E78D
2E78E CJK UNIFIED IDEOGRAPH-#2E78E
2E78F CJK UNIFIED IDEOGRAPH-#2E78F
2E790 CJK UNIFIED IDEOGRAPH-#2E790
2E791 CJK UNIFIED IDEOGRAPH-#2E791
2E792 CJK UNIFIED IDEOGRAPH-#2E792
2E793 CJK UNIFIED IDEOGRAPH-#2E793
2E794 CJK UNIFIED IDEOGRAPH-#2E794
2E795 CJK UNIFIED IDEOGRAPH-#2E795
2E796 CJK UNIFIED IDEOGRAPH-#2E796
2E797 CJK UNIFIED IDEOGRAPH-#2E797
2E798 CJK UNIFIED IDEOGRAPH-#2E798
2E799 CJK UNIFIED IDEOGRAPH-#2E799
2E79A CJK UNIFIED IDEOGRAPH-#2E79A
2E79B CJK UNIFIED IDEOGRAPH-#2E79B
2E79C CJK UNIFIED IDEOGRAPH-#2E79C
2E79D CJK UNIFIED IDEOGRAPH-#2E79D
2E79E CJK UNIFIED IDEOGRAPH-#2E79E
2E79F CJK UNIFIED IDEOGRAPH-#2E79F
2E7A0 CJK UNIFIED IDEOGRAPH-#2E7A0
2E7A1 CJK UNIFIED IDEOGRAPH-#2E7A1
2E7A2 CJK UNIFIED IDEOGRAPH-#2E7A2
2E7A3 CJK UNIFIED IDEOGRAPH-#2E7A3
2E7A4 CJK UNIFIED IDEOGRAPH-#2E7A4
2E7A5 CJK UNIFIED IDEOGRAPH-#2E7A5
2E7A6 CJK UNIFIED IDEOGRAPH-#2E7A6
2E7A7 CJK UNIFIED IDEOGRAPH-#2E7A7
2E7A8 CJK UNIFIED IDEOGRAPH-#2E7A8
2E7A9 CJK UNIFIED IDEOGRAPH-#2E7A9
2E7AA CJK UNIFIED IDEOGRAPH-#2E7AA
2E7AB CJK UNIFIED IDEOGRAPH-#2E7AB
2E7AC CJK UNIFIED IDEOGRAPH-#2E7AC
2E7AD CJK UNIFIED IDEOGRAPH-#2E7AD
2E7AE CJK UNIFIED IDEOGRAPH-#2E7AE
2E7AF CJK UNIFIED IDEOGRAPH-#2E7AF
2E7B0 CJK UNIFIED IDEOGRAPH-#2E7B0
2E7B1 CJK UNIFIED IDEOGRAPH-#2E7B1
2E7B2 CJK UNIFIED IDEOGRAPH-#2E7B2
2E7B3 CJK UNIFIED IDEOGRAPH-#2E7B3
2E7B4 CJK UNIFIED IDEOGRAPH-#2E7B4
2E7B5 CJK UNIFIED IDEOGRAPH-#2E7B5
2E7B6 CJK UNIFIED IDEOGRAPH-#2E7B6
2E7B7 CJK UNIFIED IDEOGRAPH-#2E7B7
2E7B8 CJK UNIFIED IDEOGRAPH-#2E7B8
2E7B9 CJK UNIFIED IDEOGRAPH-#2E7B9
2E7BA CJK UNIFIED IDEOGRAPH-#2E7BA
2E7BB CJK UNIFIED IDEOGRAPH-#2E7BB
2E7BC CJK UNIFIED IDEOGRAPH-#2E7BC
2E7BD CJK UNIFIED IDEOGRAPH-#2E7BD
2E7BE CJK UNIFIED IDEOGRAPH-#2E7BE
2E7BF CJK UNIFIED IDEOGRAPH-#2E7BF
2E7C0 CJK UNIFIED IDEOGRAPH-#2E7C0
2E7C1 CJK UNIFIED IDEOGRAPH-#2E7C1
2E7C2 CJK UNIFIED IDEOGRAPH-#2E7C2
2E7C3 CJK UNIFIED IDEOGRAPH-#2E7C3
2E7C4 CJK UNIFIED IDEOGRAPH-#2E7C4
2E7C5 CJK UNIFIED IDEOGRAPH-#2E7C5
2E7C6 CJK UNIFIED IDEOGRAPH-#2E7C6
2E7C7 CJK UNIFIED IDEOGRAPH-#2E7C7
2E7C8 CJK UNIFIED IDEOGRAPH-#2E7C8
2E7C9 CJK UNIFIED IDEOGRAPH-#2E7C9
2E7CA CJK UNIFIED IDEOGRAPH-#2E7CA
2E7CB CJK UNIFIED IDEOGRAPH-#2E7CB
2E7CC CJK UNIFIED IDEOGRAPH-#2E7CC
2E7CD CJK UNIFIED IDEOGRAPH-#2E7CD
2E7CE CJK UNIFIED IDEOGRAPH-#2E7CE
2E7CF CJK UNIFIED IDEOGRAPH-#2E7CF
2E7D0 CJK UNIFIED IDEOGRAPH-#2E7D0
2E7D1 CJK UNIFIED IDEOGRAPH-#2E7D1
2E7D2 CJK UNIFIED IDEOGRAPH-#2E7D2
2E7D3 CJK UNIFIED IDEOGRAPH-#2E7D3
2E7D4 CJK UNIFIED IDEOGRAPH-#2E7D4
2E7D5 CJK UNIFIED IDEOGRAPH-#2E7D5
2E7D6 CJK UNIFIED IDEOGRAPH-#2E7D6
2E7D7 CJK UNIFIED IDEOGRAPH-#2E7D7
2E7D8 CJK UNIFIED IDEOGRAPH-#2E7D8
2E7D9 CJK UNIFIED IDEOGRAPH-#2E7D9
2E7DA CJK UNIFIED IDEOGRAPH-#2E7DA
2E7DB CJK UNIFIED IDEOGRAPH-#2E7DB
2E7DC CJK UNIFIED IDEOGRAPH-#2E7DC
2E7DD CJK UNIFIED IDEOGRAPH-#2E7DD
2E7DE CJK UNIFIED IDEOGRAPH-#2E7DE
2E7DF CJK UNIFIED IDEOGRAPH-#2E7DF
2E7E0 CJK UNIFIED IDEOGRAPH-#2E7E0
2E7E1 CJK UNIFIED IDEOGRAPH-#2E7E1
2E7E2 CJK UNIFIED IDEOGRAPH-#2E7E2
2E7E3 CJK UNIFIED IDEOGRAPH-#2E7E3
2E7E4 CJK UNIFIED IDEOGRAPH-#2E7E4
2E7E5 CJK UNIFIED IDEOGRAPH-#2E7E5
2E7E6 CJK UNIFIED IDEOGRAPH-#2E7E6
2E7E7 CJK UNIFIED IDEOGRAPH-#2E7E7
2E7E8 CJK UNIFIED IDEOGRAPH-#2E7E8
2E7E9 CJK UNIFIED IDEOGRAPH-#2E7E9
2E7EA CJK UNIFIED IDEOGRAPH-#2E7EA
2E7EB CJK UNIFIED IDEOGRAPH-#2E7EB
2E7EC CJK UNIFIED IDEOGRAPH-#2E7EC
2E7ED CJK UNIFIED IDEOGRAPH-#2E7ED
2E7EE CJK UNIFIED IDEOGRAPH-#2E7EE
2E7EF CJK UNIFIED IDEOGRAPH-#2E7EF
2E7F0 CJK UNIFIED IDEOGRAPH-#2E7F0
2E7F1 CJK UNIFIED IDEOGRAPH-#2E7F1
2E7F2 CJK UNIFIED IDEOGRAPH-#2E7F2
2E7F3 CJK UNIFIED IDEOGRAPH-#2E7F3
2E7F4 CJK UNIFIED IDEOGRAPH-#2E7F4
2E7F5 CJK UNIFIED IDEOGRAPH-#2E7F5
2E7F6 CJK UNIFIED IDEOGRAPH-#2E7F6
2E7F7 CJK UNIFIED IDEOGRAPH-#2E7F7
2E7F8 CJK UNIFIED IDEOGRAPH-#2E7F8
2E7F9 CJK UNIFIED IDEOGRAPH-#2E7F9
2E7FA CJK UNIFIED IDEOGRAPH-#2E7FA
2E7FB CJK UNIFIED IDEOGRAPH-#2E7FB
2E7FC CJK UNIFIED IDEOGRAPH-#2E7FC
2E7FD CJK UNIFIED IDEOGRAPH-#2E7FD
2E7FE CJK UNIFIED IDEOGRAPH-#2E7FE
2E7FF CJK UNIFIED IDEOGRAPH-#2E7FF
2E800 CJK UNIFIED IDEOGRAPH-#2E800
2E801 CJK UNIFIED IDEOGRAPH-#2E801
2E802 CJK UNIFIED IDEOGRAPH-#2E802
2E803 CJK UNIFIED IDEOGRAPH-#2E803
2E804 CJK UNIFIED IDEOGRAPH-#2E804
2E805 CJK UNIFIED IDEOGRAPH-#2E805
2E806 CJK UNIFIED IDEOGRAPH-#2E806
2E807 CJK UNIFIED IDEOGRAPH-#2E807
2E808 CJK UNIFIED IDEOGRAPH-#2E808
2E809 CJK UNIFIED IDEOGRAPH-#2E809
2E80A CJK UNIFIED IDEOGRAPH-#2E80A
2E80B CJK UNIFIED IDEOGRAPH-#2E80B
2E80C CJK UNIFIED IDEOGRAPH-#2E80C
2E80D CJK UNIFIED IDEOGRAPH-#2E80D
2E80E CJK UNIFIED IDEOGRAPH-#2E80E
2E80F CJK UNIFIED IDEOGRAPH-#2E80F
2E810 CJK UNIFIED IDEOGRAPH-#2E810
2E811 CJK UNIFIED IDEOGRAPH-#2E811
2E812 CJK UNIFIED IDEOGRAPH-#2E812
2E813 CJK UNIFIED IDEOGRAPH-#2E813
2E814 CJK UNIFIED IDEOGRAPH-#2E814
2E815 CJK UNIFIED IDEOGRAPH-#2E815
2E816 CJK UNIFIED IDEOGRAPH-#2E816
2E817 CJK UNIFIED IDEOGRAPH-#2E817
2E818 CJK UNIFIED IDEOGRAPH-#2E818
2E819 CJK UNIFIED IDEOGRAPH-#2E819
2E81A CJK UNIFIED IDEOGRAPH-#2E81A
2E81B CJK UNIFIED IDEOGRAPH-#2E81B
2E81C CJK UNIFIED IDEOGRAPH-#2E81C
2E81D CJK UNIFIED IDEOGRAPH-#2E81D
2E81E CJK UNIFIED IDEOGRAPH-#2E81E
2E81F CJK UNIFIED IDEOGRAPH-#2E81F
2E820 CJK UNIFIED IDEOGRAPH-#2E820
2E821 CJK UNIFIED IDEOGRAPH-#2E821
2E822 CJK UNIFIED IDEOGRAPH-#2E822
2E823 CJK UNIFIED IDEOGRAPH-#2E823
2E824 CJK UNIFIED IDEOGRAPH-#2E824
2E825 CJK UNIFIED IDEOGRAPH-#2E825
2E826 CJK UNIFIED IDEOGRAPH-#2E826
2E827 CJK UNIFIED IDEOGRAPH-#2E827
2E828 CJK UNIFIED IDEOGRAPH-#2E828
2E829 CJK UNIFIED IDEOGRAPH-#2E829
2E82A CJK UNIFIED IDEOGRAPH-#2E82A
2E82B CJK UNIFIED IDEOGRAPH-#2E82B
2E82C CJK UNIFIED IDEOGRAPH-#2E82C
2E82D CJK UNIFIED IDEOGRAPH-#2E82D
2E82E CJK UNIFIED IDEOGRAPH-#2E82E
2E82F CJK UNIFIED IDEOGRAPH-#2E82F
2E830 CJK UNIFIED IDEOGRAPH-#2E830
2E831 CJK UNIFIED IDEOGRAPH-#2E831
2E832 CJK UNIFIED IDEOGRAPH-#2E832
2E833 CJK UNIFIED IDEOGRAPH-#2E833
2E834 CJK UNIFIED IDEOGRAPH-#2E834
2E835 CJK UNIFIED IDEOGRAPH-#2E835
2E836 CJK UNIFIED IDEOGRAPH-#2E836
2E837 CJK UNIFIED IDEOGRAPH-#2E837
2E838 CJK UNIFIED IDEOGRAPH-#2E838
2E839 CJK UNIFIED IDEOGRAPH-#2E839
2E83A CJK UNIFIED IDEOGRAPH-#2E83A
2E83B CJK UNIFIED IDEOGRAPH-#2E83B
2E83C CJK UNIFIED IDEOGRAPH-#2E83C
2E83D CJK UNIFIED IDEOGRAPH-#2E83D
2E83E CJK UNIFIED IDEOGRAPH-#2E83E
2E83F CJK UNIFIED IDEOGRAPH-#2E83F
2E840 CJK UNIFIED IDEOGRAPH-#2E840
2E841 CJK UNIFIED IDEOGRAPH-#2E841
2E842 CJK UNIFIED IDEOGRAPH-#2E842
2E843 CJK UNIFIED IDEOGRAPH-#2E843
2E844 CJK UNIFIED IDEOGRAPH-#2E844
2E845 CJK UNIFIED IDEOGRAPH-#2E845
2E846 CJK UNIFIED IDEOGRAPH-#2E846
2E847 CJK UNIFIED IDEOGRAPH-#2E847
2E848 CJK UNIFIED IDEOGRAPH-#2E848
2E849 CJK UNIFIED IDEOGRAPH-#2E849
2E84A CJK UNIFIED IDEOGRAPH-#2E84A
2E84B CJK UNIFIED IDEOGRAPH-#2E84B
2E84C CJK UNIFIED IDEOGRAPH-#2E84C
2E84D CJK UNIFIED IDEOGRAPH-#2E84D
2E84E CJK UNIFIED IDEOGRAPH-#2E84E
2E84F CJK UNIFIED IDEOGRAPH-#2E84F
2E850 CJK UNIFIED IDEOGRAPH-#2E850
2E851 CJK UNIFIED IDEOGRAPH-#2E851
2E852 CJK UNIFIED IDEOGRAPH-#2E852
2E853 CJK UNIFIED IDEOGRAPH-#2E853
2E854 CJK UNIFIED IDEOGRAPH-#2E854
2E855 CJK UNIFIED IDEOGRAPH-#2E855
2E856 CJK UNIFIED IDEOGRAPH-#2E856
2E857 CJK UNIFIED IDEOGRAPH-#2E857
2E858 CJK UNIFIED IDEOGRAPH-#2E858
2E859 CJK UNIFIED IDEOGRAPH-#2E859
2E85A CJK UNIFIED IDEOGRAPH-#2E85A
2E85B CJK UNIFIED IDEOGRAPH-#2E85B
2E85C CJK UNIFIED IDEOGRAPH-#2E85C
2E85D CJK UNIFIED IDEOGRAPH-#2E85D
2E85E CJK UNIFIED IDEOGRAPH-#2E85E
2E85F CJK UNIFIED IDEOGRAPH-#2E85F
2E860 CJK UNIFIED IDEOGRAPH-#2E860
2E861 CJK UNIFIED IDEOGRAPH-#2E861
2E862 CJK UNIFIED IDEOGRAPH-#2E862
2E863 CJK UNIFIED IDEOGRAPH-#2E863
2E864 CJK UNIFIED IDEOGRAPH-#2E864
2E865 CJK UNIFIED IDEOGRAPH-#2E865
2E866 CJK UNIFIED IDEOGRAPH-#2E866
2E867 CJK UNIFIED IDEOGRAPH-#2E867
2E868 CJK UNIFIED IDEOGRAPH-#2E868
2E869 CJK UNIFIED IDEOGRAPH-#2E869
2E86A CJK UNIFIED IDEOGRAPH-#2E86A
2E86B CJK UNIFIED IDEOGRAPH-#2E86B
2E86C CJK UNIFIED IDEOGRAPH-#2E86C
2E86D CJK UNIFIED IDEOGRAPH-#2E86D
2E86E CJK UNIFIED IDEOGRAPH-#2E86E
2E86F CJK UNIFIED IDEOGRAPH-#2E86F
2E870 CJK UNIFIED IDEOGRAPH-#2E870
2E871 CJK UNIFIED IDEOGRAPH-#2E871
2E872 CJK UNIFIED IDEOGRAPH-#2E872
2E873 CJK UNIFIED IDEOGRAPH-#2E873
2E874 CJK UNIFIED IDEOGRAPH-#2E874
2E875 CJK UNIFIED IDEOGRAPH-#2E875
2E876 CJK UNIFIED IDEOGRAPH-#2E876
2E877 CJK UNIFIED IDEOGRAPH-#2E877
2E878 CJK UNIFIED IDEOGRAPH-#2E878
2E879 CJK UNIFIED IDEOGRAPH-#2E879
2E87A CJK UNIFIED IDEOGRAPH-#2E87A
2E87B CJK UNIFIED IDEOGRAPH-#2E87B
2E87C CJK UNIFIED IDEOGRAPH-#2E87C
2E87D CJK UNIFIED IDEOGRAPH-#2E87D
2E87E CJK UNIFIED IDEOGRAPH-#2E87E
2E87F CJK UNIFIED IDEOGRAPH-#2E87F
2E880 CJK UNIFIED IDEOGRAPH-#2E880
2E881 CJK UNIFIED IDEOGRAPH-#2E881
2E882 CJK UNIFIED IDEOGRAPH-#2E882
2E883 CJK UNIFIED IDEOGRAPH-#2E883
2E884 CJK UNIFIED IDEOGRAPH-#2E884
2E885 CJK UNIFIED IDEOGRAPH-#2E885
2E886 CJK UNIFIED IDEOGRAPH-#2E886
2E887 CJK UNIFIED IDEOGRAPH-#2E887
2E888 CJK UNIFIED IDEOGRAPH-#2E888
2E889 CJK UNIFIED IDEOGRAPH-#2E889
2E88A CJK UNIFIED IDEOGRAPH-#2E88A
2E88B CJK UNIFIED IDEOGRAPH-#2E88B
2E88C CJK UNIFIED IDEOGRAPH-#2E88C
2E88D CJK UNIFIED IDEOGRAPH-#2E88D
2E88E CJK UNIFIED IDEOGRAPH-#2E88E
2E88F CJK UNIFIED IDEOGRAPH-#2E88F
2E890 CJK UNIFIED IDEOGRAPH-#2E890
2E891 CJK UNIFIED IDEOGRAPH-#2E891
2E892 CJK UNIFIED IDEOGRAPH-#2E892
2E893 CJK UNIFIED IDEOGRAPH-#2E893
2E894 CJK UNIFIED IDEOGRAPH-#2E894
2E895 CJK UNIFIED IDEOGRAPH-#2E895
2E896 CJK UNIFIED IDEOGRAPH-#2E896
2E897 CJK UNIFIED IDEOGRAPH-#2E897
2E898 CJK UNIFIED IDEOGRAPH-#2E898
2E899 CJK UNIFIED IDEOGRAPH-#2E899
2E89A CJK UNIFIED IDEOGRAPH-#2E89A
2E89B CJK UNIFIED IDEOGRAPH-#2E89B
2E89C CJK UNIFIED IDEOGRAPH-#2E89C
2E89D CJK UNIFIED IDEOGRAPH-#2E89D
2E89E CJK UNIFIED IDEOGRAPH-#2E89E
2E89F CJK UNIFIED IDEOGRAPH-#2E89F
2E8A0 CJK UNIFIED IDEOGRAPH-#2E8A0
2E8A1 CJK UNIFIED IDEOGRAPH-#2E8A1
2E8A2 CJK UNIFIED IDEOGRAPH-#2E8A2
2E8A3 CJK UNIFIED IDEOGRAPH-#2E8A3
2E8A4 CJK UNIFIED IDEOGRAPH-#2E8A4
2E8A5 CJK UNIFIED IDEOGRAPH-#2E8A5
2E8A6 CJK UNIFIED IDEOGRAPH-#2E8A6
2E8A7 CJK UNIFIED IDEOGRAPH-#2E8A7
2E8A8 CJK UNIFIED IDEOGRAPH-#2E8A8
2E8A9 CJK UNIFIED IDEOGRAPH-#2E8A9
2E8AA CJK UNIFIED IDEOGRAPH-#2E8AA
2E8AB CJK UNIFIED IDEOGRAPH-#2E8AB
2E8AC CJK UNIFIED IDEOGRAPH-#2E8AC
2E8AD CJK UNIFIED IDEOGRAPH-#2E8AD
2E8AE CJK UNIFIED IDEOGRAPH-#2E8AE
2E8AF CJK UNIFIED IDEOGRAPH-#2E8AF
2E8B0 CJK UNIFIED IDEOGRAPH-#2E8B0
2E8B1 CJK UNIFIED IDEOGRAPH-#2E8B1
2E8B2 CJK UNIFIED IDEOGRAPH-#2E8B2
2E8B3 CJK UNIFIED IDEOGRAPH-#2E8B3
2E8B4 CJK UNIFIED IDEOGRAPH-#2E8B4
2E8B5 CJK UNIFIED IDEOGRAPH-#2E8B5
2E8B6 CJK UNIFIED IDEOGRAPH-#2E8B6
2E8B7 CJK UNIFIED IDEOGRAPH-#2E8B7
2E8B8 CJK UNIFIED IDEOGRAPH-#2E8B8
2E8B9 CJK UNIFIED IDEOGRAPH-#2E8B9
2E8BA CJK UNIFIED IDEOGRAPH-#2E8BA
2E8BB CJK UNIFIED IDEOGRAPH-#2E8BB
2E8BC CJK UNIFIED IDEOGRAPH-#2E8BC
2E8BD CJK UNIFIED IDEOGRAPH-#2E8BD
2E8BE CJK UNIFIED IDEOGRAPH-#2E8BE
2E8BF CJK UNIFIED IDEOGRAPH-#2E8BF
2E8C0 CJK UNIFIED IDEOGRAPH-#2E8C0
2E8C1 CJK UNIFIED IDEOGRAPH-#2E8C1
2E8C2 CJK UNIFIED IDEOGRAPH-#2E8C2
2E8C3 CJK UNIFIED IDEOGRAPH-#2E8C3
2E8C4 CJK UNIFIED IDEOGRAPH-#2E8C4
2E8C5 CJK UNIFIED IDEOGRAPH-#2E8C5
2E8C6 CJK UNIFIED IDEOGRAPH-#2E8C6
2E8C7 CJK UNIFIED IDEOGRAPH-#2E8C7
2E8C8 CJK UNIFIED IDEOGRAPH-#2E8C8
2E8C9 CJK UNIFIED IDEOGRAPH-#2E8C9
2E8CA CJK UNIFIED IDEOGRAPH-#2E8CA
2E8CB CJK UNIFIED IDEOGRAPH-#2E8CB
2E8CC CJK UNIFIED IDEOGRAPH-#2E8CC
2E8CD CJK UNIFIED IDEOGRAPH-#2E8CD
2E8CE CJK UNIFIED IDEOGRAPH-#2E8CE
2E8CF CJK UNIFIED IDEOGRAPH-#2E8CF
2E8D0 CJK UNIFIED IDEOGRAPH-#2E8D0
2E8D1 CJK UNIFIED IDEOGRAPH-#2E8D1
2E8D2 CJK UNIFIED IDEOGRAPH-#2E8D2
2E8D3 CJK UNIFIED IDEOGRAPH-#2E8D3
2E8D4 CJK UNIFIED IDEOGRAPH-#2E8D4
2E8D5 CJK UNIFIED IDEOGRAPH-#2E8D5
2E8D6 CJK UNIFIED IDEOGRAPH-#2E8D6
2E8D7 CJK UNIFIED IDEOGRAPH-#2E8D7
2E8D8 CJK UNIFIED IDEOGRAPH-#2E8D8
2E8D9 CJK UNIFIED IDEOGRAPH-#2E8D9
2E8DA CJK UNIFIED IDEOGRAPH-#2E8DA
2E8DB CJK UNIFIED IDEOGRAPH-#2E8DB
2E8DC CJK UNIFIED IDEOGRAPH-#2E8DC
2E8DD CJK UNIFIED IDEOGRAPH-#2E8DD
2E8DE CJK UNIFIED IDEOGRAPH-#2E8DE
2E8DF CJK UNIFIED IDEOGRAPH-#2E8DF
2E8E0 CJK UNIFIED IDEOGRAPH-#2E8E0
2E8E1 CJK UNIFIED IDEOGRAPH-#2E8E1
2E8E2 CJK UNIFIED IDEOGRAPH-#2E8E2
2E8E3 CJK UNIFIED IDEOGRAPH-#2E8E3
2E8E4 CJK UNIFIED IDEOGRAPH-#2E8E4
2E8E5 CJK UNIFIED IDEOGRAPH-#2E8E5
2E8E6 CJK UNIFIED IDEOGRAPH-#2E8E6
2E8E7 CJK UNIFIED IDEOGRAPH-#2E8E7
2E8E8 CJK UNIFIED IDEOGRAPH-#2E8E8
2E8E9 CJK UNIFIED IDEOGRAPH-#2E8E9
2E8EA CJK UNIFIED IDEOGRAPH-#2E8EA
2E8EB CJK UNIFIED IDEOGRAPH-#2E8EB
2E8EC CJK UNIFIED IDEOGRAPH-#2E8EC
2E8ED CJK UNIFIED IDEOGRAPH-#2E8ED
2E8EE CJK UNIFIED IDEOGRAPH-#2E8EE
2E8EF CJK UNIFIED IDEOGRAPH-#2E8EF
2E8F0 CJK UNIFIED IDEOGRAPH-#2E8F0
2E8F1 CJK UNIFIED IDEOGRAPH-#2E8F1
2E8F2 CJK UNIFIED IDEOGRAPH-#2E8F2
2E8F3 CJK UNIFIED IDEOGRAPH-#2E8F3
2E8F4 CJK UNIFIED IDEOGRAPH-#2E8F4
2E8F5 CJK UNIFIED IDEOGRAPH-#2E8F5
2E8F6 CJK UNIFIED IDEOGRAPH-#2E8F6
2E8F7 CJK UNIFIED IDEOGRAPH-#2E8F7
2E8F8 CJK UNIFIED IDEOGRAPH-#2E8F8
2E8F9 CJK UNIFIED IDEOGRAPH-#2E8F9
2E8FA CJK UNIFIED IDEOGRAPH-#2E8FA
2E8FB CJK UNIFIED IDEOGRAPH-#2E8FB
2E8FC CJK UNIFIED IDEOGRAPH-#2E8FC
2E8FD CJK UNIFIED IDEOGRAPH-#2E8FD
2E8FE CJK UNIFIED IDEOGRAPH-#2E8FE
2E8FF CJK UNIFIED IDEOGRAPH-#2E8FF
2E900 CJK UNIFIED IDEOGRAPH-#2E900
2E901 CJK UNIFIED IDEOGRAPH-#2E901
2E902 CJK UNIFIED IDEOGRAPH-#2E902
2E903 CJK UNIFIED IDEOGRAPH-#2E903
2E904 CJK UNIFIED IDEOGRAPH-#2E904
2E905 CJK UNIFIED IDEOGRAPH-#2E905
2E906 CJK UNIFIED IDEOGRAPH-#2E906
2E907 CJK UNIFIED IDEOGRAPH-#2E907
2E908 CJK UNIFIED IDEOGRAPH-#2E908
2E909 CJK UNIFIED IDEOGRAPH-#2E909
2E90A CJK UNIFIED IDEOGRAPH-#2E90A
2E90B CJK UNIFIED IDEOGRAPH-#2E90B
2E90C CJK UNIFIED IDEOGRAPH-#2E90C
2E90D CJK UNIFIED IDEOGRAPH-#2E90D
2E90E CJK UNIFIED IDEOGRAPH-#2E90E
2E90F CJK UNIFIED IDEOGRAPH-#2E90F
2E910 CJK UNIFIED IDEOGRAPH-#2E910
2E911 CJK UNIFIED IDEOGRAPH-#2E911
2E912 CJK UNIFIED IDEOGRAPH-#2E912
2E913 CJK UNIFIED IDEOGRAPH-#2E913
2E914 CJK UNIFIED IDEOGRAPH-#2E914
2E915 CJK UNIFIED IDEOGRAPH-#2E915
2E916 CJK UNIFIED IDEOGRAPH-#2E916
2E917 CJK UNIFIED IDEOGRAPH-#2E917
2E918 CJK UNIFIED IDEOGRAPH-#2E918
2E919 CJK UNIFIED IDEOGRAPH-#2E919
2E91A CJK UNIFIED IDEOGRAPH-#2E91A
2E91B CJK UNIFIED IDEOGRAPH-#2E91B
2E91C CJK UNIFIED IDEOGRAPH-#2E91C
2E91D CJK UNIFIED IDEOGRAPH-#2E91D
2E91E CJK UNIFIED IDEOGRAPH-#2E91E
2E91F CJK UNIFIED IDEOGRAPH-#2E91F
2E920 CJK UNIFIED IDEOGRAPH-#2E920
2E921 CJK UNIFIED IDEOGRAPH-#2E921
2E922 CJK UNIFIED IDEOGRAPH-#2E922
2E923 CJK UNIFIED IDEOGRAPH-#2E923
2E924 CJK UNIFIED IDEOGRAPH-#2E924
2E925 CJK UNIFIED IDEOGRAPH-#2E925
2E926 CJK UNIFIED IDEOGRAPH-#2E926
2E927 CJK UNIFIED IDEOGRAPH-#2E927
2E928 CJK UNIFIED IDEOGRAPH-#2E928
2E929 CJK UNIFIED IDEOGRAPH-#2E929
2E92A CJK UNIFIED IDEOGRAPH-#2E92A
2E92B CJK UNIFIED IDEOGRAPH-#2E92B
2E92C CJK UNIFIED IDEOGRAPH-#2E92C
2E92D CJK UNIFIED IDEOGRAPH-#2E92D
2E92E CJK UNIFIED IDEOGRAPH-#2E92E
2E92F CJK UNIFIED IDEOGRAPH-#2E92F
2E930 CJK UNIFIED IDEOGRAPH-#2E930
2E931 CJK UNIFIED IDEOGRAPH-#2E931
2E932 CJK UNIFIED IDEOGRAPH-#2E932
2E933 CJK UNIFIED IDEOGRAPH-#2E933
2E934 CJK UNIFIED IDEOGRAPH-#2E934
2E935 CJK UNIFIED IDEOGRAPH-#2E935
2E936 CJK UNIFIED IDEOGRAPH-#2E936
2E937 CJK UNIFIED IDEOGRAPH-#2E937
2E938 CJK UNIFIED IDEOGRAPH-#2E938
2E939 CJK UNIFIED IDEOGRAPH-#2E939
2E93A CJK UNIFIED IDEOGRAPH-#2E93A
2E93B CJK UNIFIED IDEOGRAPH-#2E93B
2E93C CJK UNIFIED IDEOGRAPH-#2E93C
2E93D CJK UNIFIED IDEOGRAPH-#2E93D
2E93E CJK UNIFIED IDEOGRAPH-#2E93E
2E93F CJK UNIFIED IDEOGRAPH-#2E93F
2E940 CJK UNIFIED IDEOGRAPH-#2E940
2E941 CJK UNIFIED IDEOGRAPH-#2E941
2E942 CJK UNIFIED IDEOGRAPH-#2E942
2E943 CJK UNIFIED IDEOGRAPH-#2E943
2E944 CJK UNIFIED IDEOGRAPH-#2E944
2E945 CJK UNIFIED IDEOGRAPH-#2E945
2E946 CJK UNIFIED IDEOGRAPH-#2E946
2E947 CJK UNIFIED IDEOGRAPH-#2E947
2E948 CJK UNIFIED IDEOGRAPH-#2E948
2E949 CJK UNIFIED IDEOGRAPH-#2E949
2E94A CJK UNIFIED IDEOGRAPH-#2E94A
2E94B CJK UNIFIED IDEOGRAPH-#2E94B
2E94C CJK UNIFIED IDEOGRAPH-#2E94C
2E94D CJK UNIFIED IDEOGRAPH-#2E94D
2E94E CJK UNIFIED IDEOGRAPH-#2E94E
2E94F CJK UNIFIED IDEOGRAPH-#2E94F
2E950 CJK UNIFIED IDEOGRAPH-#2E950
2E951 CJK UNIFIED IDEOGRAPH-#2E951
2E952 CJK UNIFIED IDEOGRAPH-#2E952
2E953 CJK UNIFIED IDEOGRAPH-#2E953
2E954 CJK UNIFIED IDEOGRAPH-#2E954
2E955 CJK UNIFIED IDEOGRAPH-#2E955
2E956 CJK UNIFIED IDEOGRAPH-#2E956
2E957 CJK UNIFIED IDEOGRAPH-#2E957
2E958 CJK UNIFIED IDEOGRAPH-#2E958
2E959 CJK UNIFIED IDEOGRAPH-#2E959
2E95A CJK UNIFIED IDEOGRAPH-#2E95A
2E95B CJK UNIFIED IDEOGRAPH-#2E95B
2E95C CJK UNIFIED IDEOGRAPH-#2E95C
2E95D CJK UNIFIED IDEOGRAPH-#2E95D
2E95E CJK UNIFIED IDEOGRAPH-#2E95E
2E95F CJK UNIFIED IDEOGRAPH-#2E95F
2E960 CJK UNIFIED IDEOGRAPH-#2E960
2E961 CJK UNIFIED IDEOGRAPH-#2E961
2E962 CJK UNIFIED IDEOGRAPH-#2E962
2E963 CJK UNIFIED IDEOGRAPH-#2E963
2E964 CJK UNIFIED IDEOGRAPH-#2E964
2E965 CJK UNIFIED IDEOGRAPH-#2E965
2E966 CJK UNIFIED IDEOGRAPH-#2E966
2E967 CJK UNIFIED IDEOGRAPH-#2E967
2E968 CJK UNIFIED IDEOGRAPH-#2E968
2E969 CJK UNIFIED IDEOGRAPH-#2E969
2E96A CJK UNIFIED IDEOGRAPH-#2E96A
2E96B CJK UNIFIED IDEOGRAPH-#2E96B
2E96C CJK UNIFIED IDEOGRAPH-#2E96C
2E96D CJK UNIFIED IDEOGRAPH-#2E96D
2E96E CJK UNIFIED IDEOGRAPH-#2E96E
2E96F CJK UNIFIED IDEOGRAPH-#2E96F
2E970 CJK UNIFIED IDEOGRAPH-#2E970
2E971 CJK UNIFIED IDEOGRAPH-#2E971
2E972 CJK UNIFIED IDEOGRAPH-#2E972
2E973 CJK UNIFIED IDEOGRAPH-#2E973
2E974 CJK UNIFIED IDEOGRAPH-#2E974
2E975 CJK UNIFIED IDEOGRAPH-#2E975
2E976 CJK UNIFIED IDEOGRAPH-#2E976
2E977 CJK UNIFIED IDEOGRAPH-#2E977
2E978 CJK UNIFIED IDEOGRAPH-#2E978
2E979 CJK UNIFIED IDEOGRAPH-#2E979
2E97A CJK UNIFIED IDEOGRAPH-#2E97A
2E97B CJK UNIFIED IDEOGRAPH-#2E97B
2E97C CJK UNIFIED IDEOGRAPH-#2E97C
2E97D CJK UNIFIED IDEOGRAPH-#2E97D
2E97E CJK UNIFIED IDEOGRAPH-#2E97E
2E97F CJK UNIFIED IDEOGRAPH-#2E97F
2E980 CJK UNIFIED IDEOGRAPH-#2E980
2E981 CJK UNIFIED IDEOGRAPH-#2E981
2E982 CJK UNIFIED IDEOGRAPH-#2E982
2E983 CJK UNIFIED IDEOGRAPH-#2E983
2E984 CJK UNIFIED IDEOGRAPH-#2E984
2E985 CJK UNIFIED IDEOGRAPH-#2E985
2E986 CJK UNIFIED IDEOGRAPH-#2E986
2E987 CJK UNIFIED IDEOGRAPH-#2E987
2E988 CJK UNIFIED IDEOGRAPH-#2E988
2E989 CJK UNIFIED IDEOGRAPH-#2E989
2E98A CJK UNIFIED IDEOGRAPH-#2E98A
2E98B CJK UNIFIED IDEOGRAPH-#2E98B
2E98C CJK UNIFIED IDEOGRAPH-#2E98C
2E98D CJK UNIFIED IDEOGRAPH-#2E98D
2E98E CJK UNIFIED IDEOGRAPH-#2E98E
2E98F CJK UNIFIED IDEOGRAPH-#2E98F
2E990 CJK UNIFIED IDEOGRAPH-#2E990
2E991 CJK UNIFIED IDEOGRAPH-#2E991
2E992 CJK UNIFIED IDEOGRAPH-#2E992
2E993 CJK UNIFIED IDEOGRAPH-#2E993
2E994 CJK UNIFIED IDEOGRAPH-#2E994
2E995 CJK UNIFIED IDEOGRAPH-#2E995
2E996 CJK UNIFIED IDEOGRAPH-#2E996
2E997 CJK UNIFIED IDEOGRAPH-#2E997
2E998 CJK UNIFIED IDEOGRAPH-#2E998
2E999 CJK UNIFIED IDEOGRAPH-#2E999
2E99A CJK UNIFIED IDEOGRAPH-#2E99A
2E99B CJK UNIFIED IDEOGRAPH-#2E99B
2E99C CJK UNIFIED IDEOGRAPH-#2E99C
2E99D CJK UNIFIED IDEOGRAPH-#2E99D
2E99E CJK UNIFIED IDEOGRAPH-#2E99E
2E99F CJK UNIFIED IDEOGRAPH-#2E99F
2E9A0 CJK UNIFIED IDEOGRAPH-#2E9A0
2E9A1 CJK UNIFIED IDEOGRAPH-#2E9A1
2E9A2 CJK UNIFIED IDEOGRAPH-#2E9A2
2E9A3 CJK UNIFIED IDEOGRAPH-#2E9A3
2E9A4 CJK UNIFIED IDEOGRAPH-#2E9A4
2E9A5 CJK UNIFIED IDEOGRAPH-#2E9A5
2E9A6 CJK UNIFIED IDEOGRAPH-#2E9A6
2E9A7 CJK UNIFIED IDEOGRAPH-#2E9A7
2E9A8 CJK UNIFIED IDEOGRAPH-#2E9A8
2E9A9 CJK UNIFIED IDEOGRAPH-#2E9A9
2E9AA CJK UNIFIED IDEOGRAPH-#2E9AA
2E9AB CJK UNIFIED IDEOGRAPH-#2E9AB
2E9AC CJK UNIFIED IDEOGRAPH-#2E9AC
2E9AD CJK UNIFIED IDEOGRAPH-#2E9AD
2E9AE CJK UNIFIED IDEOGRAPH-#2E9AE
2E9AF CJK UNIFIED IDEOGRAPH-#2E9AF
2E9B0 CJK UNIFIED IDEOGRAPH-#2E9B0
2E9B1 CJK UNIFIED IDEOGRAPH-#2E9B1
2E9B2 CJK UNIFIED IDEOGRAPH-#2E9B2
2E9B3 CJK UNIFIED IDEOGRAPH-#2E9B3
2E9B4 CJK UNIFIED IDEOGRAPH-#2E9B4
2E9B5 CJK UNIFIED IDEOGRAPH-#2E9B5
2E9B6 CJK UNIFIED IDEOGRAPH-#2E9B6
2E9B7 CJK UNIFIED IDEOGRAPH-#2E9B7
2E9B8 CJK UNIFIED IDEOGRAPH-#2E9B8
2E9B9 CJK UNIFIED IDEOGRAPH-#2E9B9
2E9BA CJK UNIFIED IDEOGRAPH-#2E9BA
2E9BB CJK UNIFIED IDEOGRAPH-#2E9BB
2E9BC CJK UNIFIED IDEOGRAPH-#2E9BC
2E9BD CJK UNIFIED IDEOGRAPH-#2E9BD
2E9BE CJK UNIFIED IDEOGRAPH-#2E9BE
2E9BF CJK UNIFIED IDEOGRAPH-#2E9BF
2E9C0 CJK UNIFIED IDEOGRAPH-#2E9C0
2E9C1 CJK UNIFIED IDEOGRAPH-#2E9C1
2E9C2 CJK UNIFIED IDEOGRAPH-#2E9C2
2E9C3 CJK UNIFIED IDEOGRAPH-#2E9C3
2E9C4 CJK UNIFIED IDEOGRAPH-#2E9C4
2E9C5 CJK UNIFIED IDEOGRAPH-#2E9C5
2E9C6 CJK UNIFIED IDEOGRAPH-#2E9C6
2E9C7 CJK UNIFIED IDEOGRAPH-#2E9C7
2E9C8 CJK UNIFIED IDEOGRAPH-#2E9C8
2E9C9 CJK UNIFIED IDEOGRAPH-#2E9C9
2E9CA CJK UNIFIED IDEOGRAPH-#2E9CA
2E9CB CJK UNIFIED IDEOGRAPH-#2E9CB
2E9CC CJK UNIFIED IDEOGRAPH-#2E9CC
2E9CD CJK UNIFIED IDEOGRAPH-#2E9CD
2E9CE CJK UNIFIED IDEOGRAPH-#2E9CE
2E9CF CJK UNIFIED IDEOGRAPH-#2E9CF
2E9D0 CJK UNIFIED IDEOGRAPH-#2E9D0
2E9D1 CJK UNIFIED IDEOGRAPH-#2E9D1
2E9D2 CJK UNIFIED IDEOGRAPH-#2E9D2
2E9D3 CJK UNIFIED IDEOGRAPH-#2E9D3
2E9D4 CJK UNIFIED IDEOGRAPH-#2E9D4
2E9D5 CJK UNIFIED IDEOGRAPH-#2E9D5
2E9D6 CJK UNIFIED IDEOGRAPH-#2E9D6
2E9D7 CJK UNIFIED IDEOGRAPH-#2E9D7
2E9D8 CJK UNIFIED IDEOGRAPH-#2E9D8
2E9D9 CJK UNIFIED IDEOGRAPH-#2E9D9
2E9DA CJK UNIFIED IDEOGRAPH-#2E9DA
2E9DB CJK UNIFIED IDEOGRAPH-#2E9DB
2E9DC CJK UNIFIED IDEOGRAPH-#2E9DC
2E9DD CJK UNIFIED IDEOGRAPH-#2E9DD
2E9DE CJK UNIFIED IDEOGRAPH-#2E9DE
2E9DF CJK UNIFIED IDEOGRAPH-#2E9DF
2E9E0 CJK UNIFIED IDEOGRAPH-#2E9E0
2E9E1 CJK UNIFIED IDEOGRAPH-#2E9E1
2E9E2 CJK UNIFIED IDEOGRAPH-#2E9E2
2E9E3 CJK UNIFIED IDEOGRAPH-#2E9E3
2E9E4 CJK UNIFIED IDEOGRAPH-#2E9E4
2E9E5 CJK UNIFIED IDEOGRAPH-#2E9E5
2E9E6 CJK UNIFIED IDEOGRAPH-#2E9E6
2E9E7 CJK UNIFIED IDEOGRAPH-#2E9E7
2E9E8 CJK UNIFIED IDEOGRAPH-#2E9E8
2E9E9 CJK UNIFIED IDEOGRAPH-#2E9E9
2E9EA CJK UNIFIED IDEOGRAPH-#2E9EA
2E9EB CJK UNIFIED IDEOGRAPH-#2E9EB
2E9EC CJK UNIFIED IDEOGRAPH-#2E9EC
2E9ED CJK UNIFIED IDEOGRAPH-#2E9ED
2E9EE CJK UNIFIED IDEOGRAPH-#2E9EE
2E9EF CJK UNIFIED IDEOGRAPH-#2E9EF
2E9F0 CJK UNIFIED IDEOGRAPH-#2E9F0
2E9F1 CJK UNIFIED IDEOGRAPH-#2E9F1
2E9F2 CJK UNIFIED IDEOGRAPH-#2E9F2
2E9F3 CJK UNIFIED IDEOGRAPH-#2E9F3
2E9F4 CJK UNIFIED IDEOGRAPH-#2E9F4
2E9F5 CJK UNIFIED IDEOGRAPH-#2E9F5
2E9F6 CJK UNIFIED IDEOGRAPH-#2E9F6
2E9F7 CJK UNIFIED IDEOGRAPH-#2E9F7
2E9F8 CJK UNIFIED IDEOGRAPH-#2E9F8
2E9F9 CJK UNIFIED IDEOGRAPH-#2E9F9
2E9FA CJK UNIFIED IDEOGRAPH-#2E9FA
2E9FB CJK UNIFIED IDEOGRAPH-#2E9FB
2E9FC CJK UNIFIED IDEOGRAPH-#2E9FC
2E9FD CJK UNIFIED IDEOGRAPH-#2E9FD
2E9FE CJK UNIFIED IDEOGRAPH-#2E9FE
2E9FF CJK UNIFIED IDEOGRAPH-#2E9FF
2EA00 CJK UNIFIED IDEOGRAPH-#2EA00
2EA01 CJK UNIFIED IDEOGRAPH-#2EA01
2EA02 CJK UNIFIED IDEOGRAPH-#2EA02
2EA03 CJK UNIFIED IDEOGRAPH-#2EA03
2EA04 CJK UNIFIED IDEOGRAPH-#2EA04
2EA05 CJK UNIFIED IDEOGRAPH-#2EA05
2EA06 CJK UNIFIED IDEOGRAPH-#2EA06
2EA07 CJK UNIFIED IDEOGRAPH-#2EA07
2EA08 CJK UNIFIED IDEOGRAPH-#2EA08
2EA09 CJK UNIFIED IDEOGRAPH-#2EA09
2EA0A CJK UNIFIED IDEOGRAPH-#2EA0A
2EA0B CJK UNIFIED IDEOGRAPH-#2EA0B
2EA0C CJK UNIFIED IDEOGRAPH-#2EA0C
2EA0D CJK UNIFIED IDEOGRAPH-#2EA0D
2EA0E CJK UNIFIED IDEOGRAPH-#2EA0E
2EA0F CJK UNIFIED IDEOGRAPH-#2EA0F
2EA10 CJK UNIFIED IDEOGRAPH-#2EA10
2EA11 CJK UNIFIED IDEOGRAPH-#2EA11
2EA12 CJK UNIFIED IDEOGRAPH-#2EA12
2EA13 CJK UNIFIED IDEOGRAPH-#2EA13
2EA14 CJK UNIFIED IDEOGRAPH-#2EA14
2EA15 CJK UNIFIED IDEOGRAPH-#2EA15
2EA16 CJK UNIFIED IDEOGRAPH-#2EA16
2EA17 CJK UNIFIED IDEOGRAPH-#2EA17
2EA18 CJK UNIFIED IDEOGRAPH-#2EA18
2EA19 CJK UNIFIED IDEOGRAPH-#2EA19
2EA1A CJK UNIFIED IDEOGRAPH-#2EA1A
2EA1B CJK UNIFIED IDEOGRAPH-#2EA1B
2EA1C CJK UNIFIED IDEOGRAPH-#2EA1C
2EA1D CJK UNIFIED IDEOGRAPH-#2EA1D
2EA1E CJK UNIFIED IDEOGRAPH-#2EA1E
2EA1F CJK UNIFIED IDEOGRAPH-#2EA1F
2EA20 CJK UNIFIED IDEOGRAPH-#2EA20
2EA21 CJK UNIFIED IDEOGRAPH-#2EA21
2EA22 CJK UNIFIED IDEOGRAPH-#2EA22
2EA23 CJK UNIFIED IDEOGRAPH-#2EA23
2EA24 CJK UNIFIED IDEOGRAPH-#2EA24
2EA25 CJK UNIFIED IDEOGRAPH-#2EA25
2EA26 CJK UNIFIED IDEOGRAPH-#2EA26
2EA27 CJK UNIFIED IDEOGRAPH-#2EA27
2EA28 CJK UNIFIED IDEOGRAPH-#2EA28
2EA29 CJK UNIFIED IDEOGRAPH-#2EA29
2EA2A CJK UNIFIED IDEOGRAPH-#2EA2A
2EA2B CJK UNIFIED IDEOGRAPH-#2EA2B
2EA2C CJK UNIFIED IDEOGRAPH-#2EA2C
2EA2D CJK UNIFIED IDEOGRAPH-#2EA2D
2EA2E CJK UNIFIED IDEOGRAPH-#2EA2E
2EA2F CJK UNIFIED IDEOGRAPH-#2EA2F
2EA30 CJK UNIFIED IDEOGRAPH-#2EA30
2EA31 CJK UNIFIED IDEOGRAPH-#2EA31
2EA32 CJK UNIFIED IDEOGRAPH-#2EA32
2EA33 CJK UNIFIED IDEOGRAPH-#2EA33
2EA34 CJK UNIFIED IDEOGRAPH-#2EA34
2EA35 CJK UNIFIED IDEOGRAPH-#2EA35
2EA36 CJK UNIFIED IDEOGRAPH-#2EA36
2EA37 CJK UNIFIED IDEOGRAPH-#2EA37
2EA38 CJK UNIFIED IDEOGRAPH-#2EA38
2EA39 CJK UNIFIED IDEOGRAPH-#2EA39
2EA3A CJK UNIFIED IDEOGRAPH-#2EA3A
2EA3B CJK UNIFIED IDEOGRAPH-#2EA3B
2EA3C CJK UNIFIED IDEOGRAPH-#2EA3C
2EA3D CJK UNIFIED IDEOGRAPH-#2EA3D
2EA3E CJK UNIFIED IDEOGRAPH-#2EA3E
2EA3F CJK UNIFIED IDEOGRAPH-#2EA3F
2EA40 CJK UNIFIED IDEOGRAPH-#2EA40
2EA41 CJK UNIFIED IDEOGRAPH-#2EA41
2EA42 CJK UNIFIED IDEOGRAPH-#2EA42
2EA43 CJK UNIFIED IDEOGRAPH-#2EA43
2EA44 CJK UNIFIED IDEOGRAPH-#2EA44
2EA45 CJK UNIFIED IDEOGRAPH-#2EA45
2EA46 CJK UNIFIED IDEOGRAPH-#2EA46
2EA47 CJK UNIFIED IDEOGRAPH-#2EA47
2EA48 CJK UNIFIED IDEOGRAPH-#2EA48
2EA49 CJK UNIFIED IDEOGRAPH-#2EA49
2EA4A CJK UNIFIED IDEOGRAPH-#2EA4A
2EA4B CJK UNIFIED IDEOGRAPH-#2EA4B
2EA4C CJK UNIFIED IDEOGRAPH-#2EA4C
2EA4D CJK UNIFIED IDEOGRAPH-#2EA4D
2EA4E CJK UNIFIED IDEOGRAPH-#2EA4E
2EA4F CJK UNIFIED IDEOGRAPH-#2EA4F
2EA50 CJK UNIFIED IDEOGRAPH-#2EA50
2EA51 CJK UNIFIED IDEOGRAPH-#2EA51
2EA52 CJK UNIFIED IDEOGRAPH-#2EA52
2EA53 CJK UNIFIED IDEOGRAPH-#2EA53
2EA54 CJK UNIFIED IDEOGRAPH-#2EA54
2EA55 CJK UNIFIED IDEOGRAPH-#2EA55
2EA56 CJK UNIFIED IDEOGRAPH-#2EA56
2EA57 CJK UNIFIED IDEOGRAPH-#2EA57
2EA58 CJK UNIFIED IDEOGRAPH-#2EA58
2EA59 CJK UNIFIED IDEOGRAPH-#2EA59
2EA5A CJK UNIFIED IDEOGRAPH-#2EA5A
2EA5B CJK UNIFIED IDEOGRAPH-#2EA5B
2EA5C CJK UNIFIED IDEOGRAPH-#2EA5C
2EA5D CJK UNIFIED IDEOGRAPH-#2EA5D
2EA5E CJK UNIFIED IDEOGRAPH-#2EA5E
2EA5F CJK UNIFIED IDEOGRAPH-#2EA5F
2EA60 CJK UNIFIED IDEOGRAPH-#2EA60
2EA61 CJK UNIFIED IDEOGRAPH-#2EA61
2EA62 CJK UNIFIED IDEOGRAPH-#2EA62
2EA63 CJK UNIFIED IDEOGRAPH-#2EA63
2EA64 CJK UNIFIED IDEOGRAPH-#2EA64
2EA65 CJK UNIFIED IDEOGRAPH-#2EA65
2EA66 CJK UNIFIED IDEOGRAPH-#2EA66
2EA67 CJK UNIFIED IDEOGRAPH-#2EA67
2EA68 CJK UNIFIED IDEOGRAPH-#2EA68
2EA69 CJK UNIFIED IDEOGRAPH-#2EA69
2EA6A CJK UNIFIED IDEOGRAPH-#2EA6A
2EA6B CJK UNIFIED IDEOGRAPH-#2EA6B
2EA6C CJK UNIFIED IDEOGRAPH-#2EA6C
2EA6D CJK UNIFIED IDEOGRAPH-#2EA6D
2EA6E CJK UNIFIED IDEOGRAPH-#2EA6E
2EA6F CJK UNIFIED IDEOGRAPH-#2EA6F
2EA70 CJK UNIFIED IDEOGRAPH-#2EA70
2EA71 CJK UNIFIED IDEOGRAPH-#2EA71
2EA72 CJK UNIFIED IDEOGRAPH-#2EA72
2EA73 CJK UNIFIED IDEOGRAPH-#2EA73
2EA74 CJK UNIFIED IDEOGRAPH-#2EA74
2EA75 CJK UNIFIED IDEOGRAPH-#2EA75
2EA76 CJK UNIFIED IDEOGRAPH-#2EA76
2EA77 CJK UNIFIED IDEOGRAPH-#2EA77
2EA78 CJK UNIFIED IDEOGRAPH-#2EA78
2EA79 CJK UNIFIED IDEOGRAPH-#2EA79
2EA7A CJK UNIFIED IDEOGRAPH-#2EA7A
2EA7B CJK UNIFIED IDEOGRAPH-#2EA7B
2EA7C CJK UNIFIED IDEOGRAPH-#2EA7C
2EA7D CJK UNIFIED IDEOGRAPH-#2EA7D
2EA7E CJK UNIFIED IDEOGRAPH-#2EA7E
2EA7F CJK UNIFIED IDEOGRAPH-#2EA7F
2EA80 CJK UNIFIED IDEOGRAPH-#2EA80
2EA81 CJK UNIFIED IDEOGRAPH-#2EA81
2EA82 CJK UNIFIED IDEOGRAPH-#2EA82
2EA83 CJK UNIFIED IDEOGRAPH-#2EA83
2EA84 CJK UNIFIED IDEOGRAPH-#2EA84
2EA85 CJK UNIFIED IDEOGRAPH-#2EA85
2EA86 CJK UNIFIED IDEOGRAPH-#2EA86
2EA87 CJK UNIFIED IDEOGRAPH-#2EA87
2EA88 CJK UNIFIED IDEOGRAPH-#2EA88
2EA89 CJK UNIFIED IDEOGRAPH-#2EA89
2EA8A CJK UNIFIED IDEOGRAPH-#2EA8A
2EA8B CJK UNIFIED IDEOGRAPH-#2EA8B
2EA8C CJK UNIFIED IDEOGRAPH-#2EA8C
2EA8D CJK UNIFIED IDEOGRAPH-#2EA8D
2EA8E CJK UNIFIED IDEOGRAPH-#2EA8E
2EA8F CJK UNIFIED IDEOGRAPH-#2EA8F
2EA90 CJK UNIFIED IDEOGRAPH-#2EA90
2EA91 CJK UNIFIED IDEOGRAPH-#2EA91
2EA92 CJK UNIFIED IDEOGRAPH-#2EA92
2EA93 CJK UNIFIED IDEOGRAPH-#2EA93
2EA94 CJK UNIFIED IDEOGRAPH-#2EA94
2EA95 CJK UNIFIED IDEOGRAPH-#2EA95
2EA96 CJK UNIFIED IDEOGRAPH-#2EA96
2EA97 CJK UNIFIED IDEOGRAPH-#2EA97
2EA98 CJK UNIFIED IDEOGRAPH-#2EA98
2EA99 CJK UNIFIED IDEOGRAPH-#2EA99
2EA9A CJK UNIFIED IDEOGRAPH-#2EA9A
2EA9B CJK UNIFIED IDEOGRAPH-#2EA9B
2EA9C CJK UNIFIED IDEOGRAPH-#2EA9C
2EA9D CJK UNIFIED IDEOGRAPH-#2EA9D
2EA9E CJK UNIFIED IDEOGRAPH-#2EA9E
2EA9F CJK UNIFIED IDEOGRAPH-#2EA9F
2EAA0 CJK UNIFIED IDEOGRAPH-#2EAA0
2EAA1 CJK UNIFIED IDEOGRAPH-#2EAA1
2EAA2 CJK UNIFIED IDEOGRAPH-#2EAA2
2EAA3 CJK UNIFIED IDEOGRAPH-#2EAA3
2EAA4 CJK UNIFIED IDEOGRAPH-#2EAA4
2EAA5 CJK UNIFIED IDEOGRAPH-#2EAA5
2EAA6 CJK UNIFIED IDEOGRAPH-#2EAA6
2EAA7 CJK UNIFIED IDEOGRAPH-#2EAA7
2EAA8 CJK UNIFIED IDEOGRAPH-#2EAA8
2EAA9 CJK UNIFIED IDEOGRAPH-#2EAA9
2EAAA CJK UNIFIED IDEOGRAPH-#2EAAA
2EAAB CJK UNIFIED IDEOGRAPH-#2EAAB
2EAAC CJK UNIFIED IDEOGRAPH-#2EAAC
2EAAD CJK UNIFIED IDEOGRAPH-#2EAAD
2EAAE CJK UNIFIED IDEOGRAPH-#2EAAE
2EAAF CJK UNIFIED IDEOGRAPH-#2EAAF
2EAB0 CJK UNIFIED IDEOGRAPH-#2EAB0
2EAB1 CJK UNIFIED IDEOGRAPH-#2EAB1
2EAB2 CJK UNIFIED IDEOGRAPH-#2EAB2
2EAB3 CJK UNIFIED IDEOGRAPH-#2EAB3
2EAB4 CJK UNIFIED IDEOGRAPH-#2EAB4
2EAB5 CJK UNIFIED IDEOGRAPH-#2EAB5
2EAB6 CJK UNIFIED IDEOGRAPH-#2EAB6
2EAB7 CJK UNIFIED IDEOGRAPH-#2EAB7
2EAB8 CJK UNIFIED IDEOGRAPH-#2EAB8
2EAB9 CJK UNIFIED IDEOGRAPH-#2EAB9
2EABA CJK UNIFIED IDEOGRAPH-#2EABA
2EABB CJK UNIFIED IDEOGRAPH-#2EABB
2EABC CJK UNIFIED IDEOGRAPH-#2EABC
2EABD CJK UNIFIED IDEOGRAPH-#2EABD
2EABE CJK UNIFIED IDEOGRAPH-#2EABE
2EABF CJK UNIFIED IDEOGRAPH-#2EABF
2EAC0 CJK UNIFIED IDEOGRAPH-#2EAC0
2EAC1 CJK UNIFIED IDEOGRAPH-#2EAC1
2EAC2 CJK UNIFIED IDEOGRAPH-#2EAC2
2EAC3 CJK UNIFIED IDEOGRAPH-#2EAC3
2EAC4 CJK UNIFIED IDEOGRAPH-#2EAC4
2EAC5 CJK UNIFIED IDEOGRAPH-#2EAC5
2EAC6 CJK UNIFIED IDEOGRAPH-#2EAC6
2EAC7 CJK UNIFIED IDEOGRAPH-#2EAC7
2EAC8 CJK UNIFIED IDEOGRAPH-#2EAC8
2EAC9 CJK UNIFIED IDEOGRAPH-#2EAC9
2EACA CJK UNIFIED IDEOGRAPH-#2EACA
2EACB CJK UNIFIED IDEOGRAPH-#2EACB
2EACC CJK UNIFIED IDEOGRAPH-#2EACC
2EACD CJK UNIFIED IDEOGRAPH-#2EACD
2EACE CJK UNIFIED IDEOGRAPH-#2EACE
2EACF CJK UNIFIED IDEOGRAPH-#2EACF
2EAD0 CJK UNIFIED IDEOGRAPH-#2EAD0
2EAD1 CJK UNIFIED IDEOGRAPH-#2EAD1
2EAD2 CJK UNIFIED IDEOGRAPH-#2EAD2
2EAD3 CJK UNIFIED IDEOGRAPH-#2EAD3
2EAD4 CJK UNIFIED IDEOGRAPH-#2EAD4
2EAD5 CJK UNIFIED IDEOGRAPH-#2EAD5
2EAD6 CJK UNIFIED IDEOGRAPH-#2EAD6
2EAD7 CJK UNIFIED IDEOGRAPH-#2EAD7
2EAD8 CJK UNIFIED IDEOGRAPH-#2EAD8
2EAD9 CJK UNIFIED IDEOGRAPH-#2EAD9
2EADA CJK UNIFIED IDEOGRAPH-#2EADA
2EADB CJK UNIFIED IDEOGRAPH-#2EADB
2EADC CJK UNIFIED IDEOGRAPH-#2EADC
2EADD CJK UNIFIED IDEOGRAPH-#2EADD
2EADE CJK UNIFIED IDEOGRAPH-#2EADE
2EADF CJK UNIFIED IDEOGRAPH-#2EADF
2EAE0 CJK UNIFIED IDEOGRAPH-#2EAE0
2EAE1 CJK UNIFIED IDEOGRAPH-#2EAE1
2EAE2 CJK UNIFIED IDEOGRAPH-#2EAE2
2EAE3 CJK UNIFIED IDEOGRAPH-#2EAE3
2EAE4 CJK UNIFIED IDEOGRAPH-#2EAE4
2EAE5 CJK UNIFIED IDEOGRAPH-#2EAE5
2EAE6 CJK UNIFIED IDEOGRAPH-#2EAE6
2EAE7 CJK UNIFIED IDEOGRAPH-#2EAE7
2EAE8 CJK UNIFIED IDEOGRAPH-#2EAE8
2EAE9 CJK UNIFIED IDEOGRAPH-#2EAE9
2EAEA CJK UNIFIED IDEOGRAPH-#2EAEA
2EAEB CJK UNIFIED IDEOGRAPH-#2EAEB
2EAEC CJK UNIFIED IDEOGRAPH-#2EAEC
2EAED CJK UNIFIED IDEOGRAPH-#2EAED
2EAEE CJK UNIFIED IDEOGRAPH-#2EAEE
2EAEF CJK UNIFIED IDEOGRAPH-#2EAEF
2EAF0 CJK UNIFIED IDEOGRAPH-#2EAF0
2EAF1 CJK UNIFIED IDEOGRAPH-#2EAF1
2EAF2 CJK UNIFIED IDEOGRAPH-#2EAF2
2EAF3 CJK UNIFIED IDEOGRAPH-#2EAF3
2EAF4 CJK UNIFIED IDEOGRAPH-#2EAF4
2EAF5 CJK UNIFIED IDEOGRAPH-#2EAF5
2EAF6 CJK UNIFIED IDEOGRAPH-#2EAF6
2EAF7 CJK UNIFIED IDEOGRAPH-#2EAF7
2EAF8 CJK UNIFIED IDEOGRAPH-#2EAF8
2EAF9 CJK UNIFIED IDEOGRAPH-#2EAF9
2EAFA CJK UNIFIED IDEOGRAPH-#2EAFA
2EAFB CJK UNIFIED IDEOGRAPH-#2EAFB
2EAFC CJK UNIFIED IDEOGRAPH-#2EAFC
2EAFD CJK UNIFIED IDEOGRAPH-#2EAFD
2EAFE CJK UNIFIED IDEOGRAPH-#2EAFE
2EAFF CJK UNIFIED IDEOGRAPH-#2EAFF
2EB00 CJK UNIFIED IDEOGRAPH-#2EB00
2EB01 CJK UNIFIED IDEOGRAPH-#2EB01
2EB02 CJK UNIFIED IDEOGRAPH-#2EB02
2EB03 CJK UNIFIED IDEOGRAPH-#2EB03
2EB04 CJK UNIFIED IDEOGRAPH-#2EB04
2EB05 CJK UNIFIED IDEOGRAPH-#2EB05
2EB06 CJK UNIFIED IDEOGRAPH-#2EB06
2EB07 CJK UNIFIED IDEOGRAPH-#2EB07
2EB08 CJK UNIFIED IDEOGRAPH-#2EB08
2EB09 CJK UNIFIED IDEOGRAPH-#2EB09
2EB0A CJK UNIFIED IDEOGRAPH-#2EB0A
2EB0B CJK UNIFIED IDEOGRAPH-#2EB0B
2EB0C CJK UNIFIED IDEOGRAPH-#2EB0C
2EB0D CJK UNIFIED IDEOGRAPH-#2EB0D
2EB0E CJK UNIFIED IDEOGRAPH-#2EB0E
2EB0F CJK UNIFIED IDEOGRAPH-#2EB0F
2EB10 CJK UNIFIED IDEOGRAPH-#2EB10
2EB11 CJK UNIFIED IDEOGRAPH-#2EB11
2EB12 CJK UNIFIED IDEOGRAPH-#2EB12
2EB13 CJK UNIFIED IDEOGRAPH-#2EB13
2EB14 CJK UNIFIED IDEOGRAPH-#2EB14
2EB15 CJK UNIFIED IDEOGRAPH-#2EB15
2EB16 CJK UNIFIED IDEOGRAPH-#2EB16
2EB17 CJK UNIFIED IDEOGRAPH-#2EB17
2EB18 CJK UNIFIED IDEOGRAPH-#2EB18
2EB19 CJK UNIFIED IDEOGRAPH-#2EB19
2EB1A CJK UNIFIED IDEOGRAPH-#2EB1A
2EB1B CJK UNIFIED IDEOGRAPH-#2EB1B
2EB1C CJK UNIFIED IDEOGRAPH-#2EB1C
2EB1D CJK UNIFIED IDEOGRAPH-#2EB1D
2EB1E CJK UNIFIED IDEOGRAPH-#2EB1E
2EB1F CJK UNIFIED IDEOGRAPH-#2EB1F
2EB20 CJK UNIFIED IDEOGRAPH-#2EB20
2EB21 CJK UNIFIED IDEOGRAPH-#2EB21
2EB22 CJK UNIFIED IDEOGRAPH-#2EB22
2EB23 CJK UNIFIED IDEOGRAPH-#2EB23
2EB24 CJK UNIFIED IDEOGRAPH-#2EB24
2EB25 CJK UNIFIED IDEOGRAPH-#2EB25
2EB26 CJK UNIFIED IDEOGRAPH-#2EB26
2EB27 CJK UNIFIED IDEOGRAPH-#2EB27
2EB28 CJK UNIFIED IDEOGRAPH-#2EB28
2EB29 CJK UNIFIED IDEOGRAPH-#2EB29
2EB2A CJK UNIFIED IDEOGRAPH-#2EB2A
2EB2B CJK UNIFIED IDEOGRAPH-#2EB2B
2EB2C CJK UNIFIED IDEOGRAPH-#2EB2C
2EB2D CJK UNIFIED IDEOGRAPH-#2EB2D
2EB2E CJK UNIFIED IDEOGRAPH-#2EB2E
2EB2F CJK UNIFIED IDEOGRAPH-#2EB2F
2EB30 CJK UNIFIED IDEOGRAPH-#2EB30
2EB31 CJK UNIFIED IDEOGRAPH-#2EB31
2EB32 CJK UNIFIED IDEOGRAPH-#2EB32
2EB33 CJK UNIFIED IDEOGRAPH-#2EB33
2EB34 CJK UNIFIED IDEOGRAPH-#2EB34
2EB35 CJK UNIFIED IDEOGRAPH-#2EB35
2EB36 CJK UNIFIED IDEOGRAPH-#2EB36
2EB37 CJK UNIFIED IDEOGRAPH-#2EB37
2EB38 CJK UNIFIED IDEOGRAPH-#2EB38
2EB39 CJK UNIFIED IDEOGRAPH-#2EB39
2EB3A CJK UNIFIED IDEOGRAPH-#2EB3A
2EB3B CJK UNIFIED IDEOGRAPH-#2EB3B
2EB3C CJK UNIFIED IDEOGRAPH-#2EB3C
2EB3D CJK UNIFIED IDEOGRAPH-#2EB3D
2EB3E CJK UNIFIED IDEOGRAPH-#2EB3E
2EB3F CJK UNIFIED IDEOGRAPH-#2EB3F
2EB40 CJK UNIFIED IDEOGRAPH-#2EB40
2EB41 CJK UNIFIED IDEOGRAPH-#2EB41
2EB42 CJK UNIFIED IDEOGRAPH-#2EB42
2EB43 CJK UNIFIED IDEOGRAPH-#2EB43
2EB44 CJK UNIFIED IDEOGRAPH-#2EB44
2EB45 CJK UNIFIED IDEOGRAPH-#2EB45
2EB46 CJK UNIFIED IDEOGRAPH-#2EB46
2EB47 CJK UNIFIED IDEOGRAPH-#2EB47
2EB48 CJK UNIFIED IDEOGRAPH-#2EB48
2EB49 CJK UNIFIED IDEOGRAPH-#2EB49
2EB4A CJK UNIFIED IDEOGRAPH-#2EB4A
2EB4B CJK UNIFIED IDEOGRAPH-#2EB4B
2EB4C CJK UNIFIED IDEOGRAPH-#2EB4C
2EB4D CJK UNIFIED IDEOGRAPH-#2EB4D
2EB4E CJK UNIFIED IDEOGRAPH-#2EB4E
2EB4F CJK UNIFIED IDEOGRAPH-#2EB4F
2EB50 CJK UNIFIED IDEOGRAPH-#2EB50
2EB51 CJK UNIFIED IDEOGRAPH-#2EB51
2EB52 CJK UNIFIED IDEOGRAPH-#2EB52
2EB53 CJK UNIFIED IDEOGRAPH-#2EB53
2EB54 CJK UNIFIED IDEOGRAPH-#2EB54
2EB55 CJK UNIFIED IDEOGRAPH-#2EB55
2EB56 CJK UNIFIED IDEOGRAPH-#2EB56
2EB57 CJK UNIFIED IDEOGRAPH-#2EB57
2EB58 CJK UNIFIED IDEOGRAPH-#2EB58
2EB59 CJK UNIFIED IDEOGRAPH-#2EB59
2EB5A CJK UNIFIED IDEOGRAPH-#2EB5A
2EB5B CJK UNIFIED IDEOGRAPH-#2EB5B
2EB5C CJK UNIFIED IDEOGRAPH-#2EB5C
2EB5D CJK UNIFIED IDEOGRAPH-#2EB5D
2EB5E CJK UNIFIED IDEOGRAPH-#2EB5E
2EB5F CJK UNIFIED IDEOGRAPH-#2EB5F
2EB60 CJK UNIFIED IDEOGRAPH-#2EB60
2EB61 CJK UNIFIED IDEOGRAPH-#2EB61
2EB62 CJK UNIFIED IDEOGRAPH-#2EB62
2EB63 CJK UNIFIED IDEOGRAPH-#2EB63
2EB64 CJK UNIFIED IDEOGRAPH-#2EB64
2EB65 CJK UNIFIED IDEOGRAPH-#2EB65
2EB66 CJK UNIFIED IDEOGRAPH-#2EB66
2EB67 CJK UNIFIED IDEOGRAPH-#2EB67
2EB68 CJK UNIFIED IDEOGRAPH-#2EB68
2EB69 CJK UNIFIED IDEOGRAPH-#2EB69
2EB6A CJK UNIFIED IDEOGRAPH-#2EB6A
2EB6B CJK UNIFIED IDEOGRAPH-#2EB6B
2EB6C CJK UNIFIED IDEOGRAPH-#2EB6C
2EB6D CJK UNIFIED IDEOGRAPH-#2EB6D
2EB6E CJK UNIFIED IDEOGRAPH-#2EB6E
2EB6F CJK UNIFIED IDEOGRAPH-#2EB6F
2EB70 CJK UNIFIED IDEOGRAPH-#2EB70
2EB71 CJK UNIFIED IDEOGRAPH-#2EB71
2EB72 CJK UNIFIED IDEOGRAPH-#2EB72
2EB73 CJK UNIFIED IDEOGRAPH-#2EB73
2EB74 CJK UNIFIED IDEOGRAPH-#2EB74
2EB75 CJK UNIFIED IDEOGRAPH-#2EB75
2EB76 CJK UNIFIED IDEOGRAPH-#2EB76
2EB77 CJK UNIFIED IDEOGRAPH-#2EB77
2EB78 CJK UNIFIED IDEOGRAPH-#2EB78
2EB79 CJK UNIFIED IDEOGRAPH-#2EB79
2EB7A CJK UNIFIED IDEOGRAPH-#2EB7A
2EB7B CJK UNIFIED IDEOGRAPH-#2EB7B
2EB7C CJK UNIFIED IDEOGRAPH-#2EB7C
2EB7D CJK UNIFIED IDEOGRAPH-#2EB7D
2EB7E CJK UNIFIED IDEOGRAPH-#2EB7E
2EB7F CJK UNIFIED IDEOGRAPH-#2EB7F
2EB80 CJK UNIFIED IDEOGRAPH-#2EB80
2EB81 CJK UNIFIED IDEOGRAPH-#2EB81
2EB82 CJK UNIFIED IDEOGRAPH-#2EB82
2EB83 CJK UNIFIED IDEOGRAPH-#2EB83
2EB84 CJK UNIFIED IDEOGRAPH-#2EB84
2EB85 CJK UNIFIED IDEOGRAPH-#2EB85
2EB86 CJK UNIFIED IDEOGRAPH-#2EB86
2EB87 CJK UNIFIED IDEOGRAPH-#2EB87
2EB88 CJK UNIFIED IDEOGRAPH-#2EB88
2EB89 CJK UNIFIED IDEOGRAPH-#2EB89
2EB8A CJK UNIFIED IDEOGRAPH-#2EB8A
2EB8B CJK UNIFIED IDEOGRAPH-#2EB8B
2EB8C CJK UNIFIED IDEOGRAPH-#2EB8C
2EB8D CJK UNIFIED IDEOGRAPH-#2EB8D
2EB8E CJK UNIFIED IDEOGRAPH-#2EB8E
2EB8F CJK UNIFIED IDEOGRAPH-#2EB8F
2EB90 CJK UNIFIED IDEOGRAPH-#2EB90
2EB91 CJK UNIFIED IDEOGRAPH-#2EB91
2EB92 CJK UNIFIED IDEOGRAPH-#2EB92
2EB93 CJK UNIFIED IDEOGRAPH-#2EB93
2EB94 CJK UNIFIED IDEOGRAPH-#2EB94
2EB95 CJK UNIFIED IDEOGRAPH-#2EB95
2EB96 CJK UNIFIED IDEOGRAPH-#2EB96
2EB97 CJK UNIFIED IDEOGRAPH-#2EB97
2EB98 CJK UNIFIED IDEOGRAPH-#2EB98
2EB99 CJK UNIFIED IDEOGRAPH-#2EB99
2EB9A CJK UNIFIED IDEOGRAPH-#2EB9A
2EB9B CJK UNIFIED IDEOGRAPH-#2EB9B
2EB9C CJK UNIFIED IDEOGRAPH-#2EB9C
2EB9D CJK UNIFIED IDEOGRAPH-#2EB9D
2EB9E CJK UNIFIED IDEOGRAPH-#2EB9E
2EB9F CJK UNIFIED IDEOGRAPH-#2EB9F
2EBA0 CJK UNIFIED IDEOGRAPH-#2EBA0
2EBA1 CJK UNIFIED IDEOGRAPH-#2EBA1
2EBA2 CJK UNIFIED IDEOGRAPH-#2EBA2
2EBA3 CJK UNIFIED IDEOGRAPH-#2EBA3
2EBA4 CJK UNIFIED IDEOGRAPH-#2EBA4
2EBA5 CJK UNIFIED IDEOGRAPH-#2EBA5
2EBA6 CJK UNIFIED IDEOGRAPH-#2EBA6
2EBA7 CJK UNIFIED IDEOGRAPH-#2EBA7
2EBA8 CJK UNIFIED IDEOGRAPH-#2EBA8
2EBA9 CJK UNIFIED IDEOGRAPH-#2EBA9
2EBAA CJK UNIFIED IDEOGRAPH-#2EBAA
2EBAB CJK UNIFIED IDEOGRAPH-#2EBAB
2EBAC CJK UNIFIED IDEOGRAPH-#2EBAC
2EBAD CJK UNIFIED IDEOGRAPH-#2EBAD
2EBAE CJK UNIFIED IDEOGRAPH-#2EBAE
2EBAF CJK UNIFIED IDEOGRAPH-#2EBAF
2EBB0 CJK UNIFIED IDEOGRAPH-#2EBB0
2EBB1 CJK UNIFIED IDEOGRAPH-#2EBB1
2EBB2 CJK UNIFIED IDEOGRAPH-#2EBB2
2EBB3 CJK UNIFIED IDEOGRAPH-#2EBB3
2EBB4 CJK UNIFIED IDEOGRAPH-#2EBB4
2EBB5 CJK UNIFIED IDEOGRAPH-#2EBB5
2EBB6 CJK UNIFIED IDEOGRAPH-#2EBB6
2EBB7 CJK UNIFIED IDEOGRAPH-#2EBB7
2EBB8 CJK UNIFIED IDEOGRAPH-#2EBB8
2EBB9 CJK UNIFIED IDEOGRAPH-#2EBB9
2EBBA CJK UNIFIED IDEOGRAPH-#2EBBA
2EBBB CJK UNIFIED IDEOGRAPH-#2EBBB
2EBBC CJK UNIFIED IDEOGRAPH-#2EBBC
2EBBD CJK UNIFIED IDEOGRAPH-#2EBBD
2EBBE CJK UNIFIED IDEOGRAPH-#2EBBE
2EBBF CJK UNIFIED IDEOGRAPH-#2EBBF
2EBC0 CJK UNIFIED IDEOGRAPH-#2EBC0
2EBC1 CJK UNIFIED IDEOGRAPH-#2EBC1
2EBC2 CJK UNIFIED IDEOGRAPH-#2EBC2
2EBC3 CJK UNIFIED IDEOGRAPH-#2EBC3
2EBC4 CJK UNIFIED IDEOGRAPH-#2EBC4
2EBC5 CJK UNIFIED IDEOGRAPH-#2EBC5
2EBC6 CJK UNIFIED IDEOGRAPH-#2EBC6
2EBC7 CJK UNIFIED IDEOGRAPH-#2EBC7
2EBC8 CJK UNIFIED IDEOGRAPH-#2EBC8
2EBC9 CJK UNIFIED IDEOGRAPH-#2EBC9
2EBCA CJK UNIFIED IDEOGRAPH-#2EBCA
2EBCB CJK UNIFIED IDEOGRAPH-#2EBCB
2EBCC CJK UNIFIED IDEOGRAPH-#2EBCC
2EBCD CJK UNIFIED IDEOGRAPH-#2EBCD
2EBCE CJK UNIFIED IDEOGRAPH-#2EBCE
2EBCF CJK UNIFIED IDEOGRAPH-#2EBCF
2EBD0 CJK UNIFIED IDEOGRAPH-#2EBD0
2EBD1 CJK UNIFIED IDEOGRAPH-#2EBD1
2EBD2 CJK UNIFIED IDEOGRAPH-#2EBD2
2EBD3 CJK UNIFIED IDEOGRAPH-#2EBD3
2EBD4 CJK UNIFIED IDEOGRAPH-#2EBD4
2EBD5 CJK UNIFIED IDEOGRAPH-#2EBD5
2EBD6 CJK UNIFIED IDEOGRAPH-#2EBD6
2EBD7 CJK UNIFIED IDEOGRAPH-#2EBD7
2EBD8 CJK UNIFIED IDEOGRAPH-#2EBD8
2EBD9 CJK UNIFIED IDEOGRAPH-#2EBD9
2EBDA CJK UNIFIED IDEOGRAPH-#2EBDA
2EBDB CJK UNIFIED IDEOGRAPH-#2EBDB
2EBDC CJK UNIFIED IDEOGRAPH-#2EBDC
2EBDD CJK UNIFIED IDEOGRAPH-#2EBDD
2EBDE CJK UNIFIED IDEOGRAPH-#2EBDE
2EBDF CJK UNIFIED IDEOGRAPH-#2EBDF
2EBE0 CJK UNIFIED IDEOGRAPH-#2EBE0
2F800 CJK COMPATIBILITY IDEOGRAPH-#2F800
2F801 CJK COMPATIBILITY IDEOGRAPH-#2F801
2F802 CJK COMPATIBILITY IDEOGRAPH-#2F802
2F803 CJK COMPATIBILITY IDEOGRAPH-#2F803
2F804 CJK COMPATIBILITY IDEOGRAPH-#2F804
2F805 CJK COMPATIBILITY IDEOGRAPH-#2F805
2F806 CJK COMPATIBILITY IDEOGRAPH-#2F806
2F807 CJK COMPATIBILITY IDEOGRAPH-#2F807
2F808 CJK COMPATIBILITY IDEOGRAPH-#2F808
2F809 CJK COMPATIBILITY IDEOGRAPH-#2F809
2F80A CJK COMPATIBILITY IDEOGRAPH-#2F80A
2F80B CJK COMPATIBILITY IDEOGRAPH-#2F80B
2F80C CJK COMPATIBILITY IDEOGRAPH-#2F80C
2F80D CJK COMPATIBILITY IDEOGRAPH-#2F80D
2F80E CJK COMPATIBILITY IDEOGRAPH-#2F80E
2F80F CJK COMPATIBILITY IDEOGRAPH-#2F80F
2F810 CJK COMPATIBILITY IDEOGRAPH-#2F810
2F811 CJK COMPATIBILITY IDEOGRAPH-#2F811
2F812 CJK COMPATIBILITY IDEOGRAPH-#2F812
2F813 CJK COMPATIBILITY IDEOGRAPH-#2F813
2F814 CJK COMPATIBILITY IDEOGRAPH-#2F814
2F815 CJK COMPATIBILITY IDEOGRAPH-#2F815
2F816 CJK COMPATIBILITY IDEOGRAPH-#2F816
2F817 CJK COMPATIBILITY IDEOGRAPH-#2F817
2F818 CJK COMPATIBILITY IDEOGRAPH-#2F818
2F819 CJK COMPATIBILITY IDEOGRAPH-#2F819
2F81A CJK COMPATIBILITY IDEOGRAPH-#2F81A
2F81B CJK COMPATIBILITY IDEOGRAPH-#2F81B
2F81C CJK COMPATIBILITY IDEOGRAPH-#2F81C
2F81D CJK COMPATIBILITY IDEOGRAPH-#2F81D
2F81E CJK COMPATIBILITY IDEOGRAPH-#2F81E
2F81F CJK COMPATIBILITY IDEOGRAPH-#2F81F
2F820 CJK COMPATIBILITY IDEOGRAPH-#2F820
2F821 CJK COMPATIBILITY IDEOGRAPH-#2F821
2F822 CJK COMPATIBILITY IDEOGRAPH-#2F822
2F823 CJK COMPATIBILITY IDEOGRAPH-#2F823
2F824 CJK COMPATIBILITY IDEOGRAPH-#2F824
2F825 CJK COMPATIBILITY IDEOGRAPH-#2F825
2F826 CJK COMPATIBILITY IDEOGRAPH-#2F826
2F827 CJK COMPATIBILITY IDEOGRAPH-#2F827
2F828 CJK COMPATIBILITY IDEOGRAPH-#2F828
2F829 CJK COMPATIBILITY IDEOGRAPH-#2F829
2F82A CJK COMPATIBILITY IDEOGRAPH-#2F82A
2F82B CJK COMPATIBILITY IDEOGRAPH-#2F82B
2F82C CJK COMPATIBILITY IDEOGRAPH-#2F82C
2F82D CJK COMPATIBILITY IDEOGRAPH-#2F82D
2F82E CJK COMPATIBILITY IDEOGRAPH-#2F82E
2F82F CJK COMPATIBILITY IDEOGRAPH-#2F82F
2F830 CJK COMPATIBILITY IDEOGRAPH-#2F830
2F831 CJK COMPATIBILITY IDEOGRAPH-#2F831
2F832 CJK COMPATIBILITY IDEOGRAPH-#2F832
2F833 CJK COMPATIBILITY IDEOGRAPH-#2F833
2F834 CJK COMPATIBILITY IDEOGRAPH-#2F834
2F835 CJK COMPATIBILITY IDEOGRAPH-#2F835, Def{ashes, lime}
2F836 CJK COMPATIBILITY IDEOGRAPH-#2F836
2F837 CJK COMPATIBILITY IDEOGRAPH-#2F837
2F838 CJK COMPATIBILITY IDEOGRAPH-#2F838
2F839 CJK COMPATIBILITY IDEOGRAPH-#2F839
2F83A CJK COMPATIBILITY IDEOGRAPH-#2F83A
2F83B CJK COMPATIBILITY IDEOGRAPH-#2F83B
2F83C CJK COMPATIBILITY IDEOGRAPH-#2F83C
2F83D CJK COMPATIBILITY IDEOGRAPH-#2F83D
2F83E CJK COMPATIBILITY IDEOGRAPH-#2F83E
2F83F CJK COMPATIBILITY IDEOGRAPH-#2F83F
2F840 CJK COMPATIBILITY IDEOGRAPH-#2F840
2F841 CJK COMPATIBILITY IDEOGRAPH-#2F841
2F842 CJK COMPATIBILITY IDEOGRAPH-#2F842
2F843 CJK COMPATIBILITY IDEOGRAPH-#2F843
2F844 CJK COMPATIBILITY IDEOGRAPH-#2F844
2F845 CJK COMPATIBILITY IDEOGRAPH-#2F845
2F846 CJK COMPATIBILITY IDEOGRAPH-#2F846
2F847 CJK COMPATIBILITY IDEOGRAPH-#2F847
2F848 CJK COMPATIBILITY IDEOGRAPH-#2F848
2F849 CJK COMPATIBILITY IDEOGRAPH-#2F849
2F84A CJK COMPATIBILITY IDEOGRAPH-#2F84A
2F84B CJK COMPATIBILITY IDEOGRAPH-#2F84B
2F84C CJK COMPATIBILITY IDEOGRAPH-#2F84C
2F84D CJK COMPATIBILITY IDEOGRAPH-#2F84D
2F84E CJK COMPATIBILITY IDEOGRAPH-#2F84E
2F84F CJK COMPATIBILITY IDEOGRAPH-#2F84F
2F850 CJK COMPATIBILITY IDEOGRAPH-#2F850
2F851 CJK COMPATIBILITY IDEOGRAPH-#2F851
2F852 CJK COMPATIBILITY IDEOGRAPH-#2F852
2F853 CJK COMPATIBILITY IDEOGRAPH-#2F853
2F854 CJK COMPATIBILITY IDEOGRAPH-#2F854
2F855 CJK COMPATIBILITY IDEOGRAPH-#2F855
2F856 CJK COMPATIBILITY IDEOGRAPH-#2F856
2F857 CJK COMPATIBILITY IDEOGRAPH-#2F857
2F858 CJK COMPATIBILITY IDEOGRAPH-#2F858
2F859 CJK COMPATIBILITY IDEOGRAPH-#2F859
2F85A CJK COMPATIBILITY IDEOGRAPH-#2F85A
2F85B CJK COMPATIBILITY IDEOGRAPH-#2F85B
2F85C CJK COMPATIBILITY IDEOGRAPH-#2F85C
2F85D CJK COMPATIBILITY IDEOGRAPH-#2F85D
2F85E CJK COMPATIBILITY IDEOGRAPH-#2F85E
2F85F CJK COMPATIBILITY IDEOGRAPH-#2F85F
2F860 CJK COMPATIBILITY IDEOGRAPH-#2F860
2F861 CJK COMPATIBILITY IDEOGRAPH-#2F861
2F862 CJK COMPATIBILITY IDEOGRAPH-#2F862
2F863 CJK COMPATIBILITY IDEOGRAPH-#2F863
2F864 CJK COMPATIBILITY IDEOGRAPH-#2F864
2F865 CJK COMPATIBILITY IDEOGRAPH-#2F865
2F866 CJK COMPATIBILITY IDEOGRAPH-#2F866
2F867 CJK COMPATIBILITY IDEOGRAPH-#2F867
2F868 CJK COMPATIBILITY IDEOGRAPH-#2F868
2F869 CJK COMPATIBILITY IDEOGRAPH-#2F869
2F86A CJK COMPATIBILITY IDEOGRAPH-#2F86A
2F86B CJK COMPATIBILITY IDEOGRAPH-#2F86B
2F86C CJK COMPATIBILITY IDEOGRAPH-#2F86C
2F86D CJK COMPATIBILITY IDEOGRAPH-#2F86D
2F86E CJK COMPATIBILITY IDEOGRAPH-#2F86E
2F86F CJK COMPATIBILITY IDEOGRAPH-#2F86F
2F870 CJK COMPATIBILITY IDEOGRAPH-#2F870
2F871 CJK COMPATIBILITY IDEOGRAPH-#2F871
2F872 CJK COMPATIBILITY IDEOGRAPH-#2F872
2F873 CJK COMPATIBILITY IDEOGRAPH-#2F873
2F874 CJK COMPATIBILITY IDEOGRAPH-#2F874
2F875 CJK COMPATIBILITY IDEOGRAPH-#2F875
2F876 CJK COMPATIBILITY IDEOGRAPH-#2F876
2F877 CJK COMPATIBILITY IDEOGRAPH-#2F877
2F878 CJK COMPATIBILITY IDEOGRAPH-#2F878
2F879 CJK COMPATIBILITY IDEOGRAPH-#2F879
2F87A CJK COMPATIBILITY IDEOGRAPH-#2F87A
2F87B CJK COMPATIBILITY IDEOGRAPH-#2F87B
2F87C CJK COMPATIBILITY IDEOGRAPH-#2F87C
2F87D CJK COMPATIBILITY IDEOGRAPH-#2F87D
2F87E CJK COMPATIBILITY IDEOGRAPH-#2F87E
2F87F CJK COMPATIBILITY IDEOGRAPH-#2F87F
2F880 CJK COMPATIBILITY IDEOGRAPH-#2F880
2F881 CJK COMPATIBILITY IDEOGRAPH-#2F881
2F882 CJK COMPATIBILITY IDEOGRAPH-#2F882
2F883 CJK COMPATIBILITY IDEOGRAPH-#2F883
2F884 CJK COMPATIBILITY IDEOGRAPH-#2F884
2F885 CJK COMPATIBILITY IDEOGRAPH-#2F885
2F886 CJK COMPATIBILITY IDEOGRAPH-#2F886
2F887 CJK COMPATIBILITY IDEOGRAPH-#2F887
2F888 CJK COMPATIBILITY IDEOGRAPH-#2F888
2F889 CJK COMPATIBILITY IDEOGRAPH-#2F889
2F88A CJK COMPATIBILITY IDEOGRAPH-#2F88A
2F88B CJK COMPATIBILITY IDEOGRAPH-#2F88B
2F88C CJK COMPATIBILITY IDEOGRAPH-#2F88C
2F88D CJK COMPATIBILITY IDEOGRAPH-#2F88D
2F88E CJK COMPATIBILITY IDEOGRAPH-#2F88E
2F88F CJK COMPATIBILITY IDEOGRAPH-#2F88F
2F890 CJK COMPATIBILITY IDEOGRAPH-#2F890
2F891 CJK COMPATIBILITY IDEOGRAPH-#2F891
2F892 CJK COMPATIBILITY IDEOGRAPH-#2F892
2F893 CJK COMPATIBILITY IDEOGRAPH-#2F893
2F894 CJK COMPATIBILITY IDEOGRAPH-#2F894
2F895 CJK COMPATIBILITY IDEOGRAPH-#2F895
2F896 CJK COMPATIBILITY IDEOGRAPH-#2F896
2F897 CJK COMPATIBILITY IDEOGRAPH-#2F897
2F898 CJK COMPATIBILITY IDEOGRAPH-#2F898
2F899 CJK COMPATIBILITY IDEOGRAPH-#2F899
2F89A CJK COMPATIBILITY IDEOGRAPH-#2F89A
2F89B CJK COMPATIBILITY IDEOGRAPH-#2F89B
2F89C CJK COMPATIBILITY IDEOGRAPH-#2F89C
2F89D CJK COMPATIBILITY IDEOGRAPH-#2F89D
2F89E CJK COMPATIBILITY IDEOGRAPH-#2F89E
2F89F CJK COMPATIBILITY IDEOGRAPH-#2F89F
2F8A0 CJK COMPATIBILITY IDEOGRAPH-#2F8A0
2F8A1 CJK COMPATIBILITY IDEOGRAPH-#2F8A1
2F8A2 CJK COMPATIBILITY IDEOGRAPH-#2F8A2
2F8A3 CJK COMPATIBILITY IDEOGRAPH-#2F8A3
2F8A4 CJK COMPATIBILITY IDEOGRAPH-#2F8A4
2F8A5 CJK COMPATIBILITY IDEOGRAPH-#2F8A5
2F8A6 CJK COMPATIBILITY IDEOGRAPH-#2F8A6
2F8A7 CJK COMPATIBILITY IDEOGRAPH-#2F8A7
2F8A8 CJK COMPATIBILITY IDEOGRAPH-#2F8A8
2F8A9 CJK COMPATIBILITY IDEOGRAPH-#2F8A9
2F8AA CJK COMPATIBILITY IDEOGRAPH-#2F8AA
2F8AB CJK COMPATIBILITY IDEOGRAPH-#2F8AB
2F8AC CJK COMPATIBILITY IDEOGRAPH-#2F8AC
2F8AD CJK COMPATIBILITY IDEOGRAPH-#2F8AD
2F8AE CJK COMPATIBILITY IDEOGRAPH-#2F8AE
2F8AF CJK COMPATIBILITY IDEOGRAPH-#2F8AF
2F8B0 CJK COMPATIBILITY IDEOGRAPH-#2F8B0
2F8B1 CJK COMPATIBILITY IDEOGRAPH-#2F8B1
2F8B2 CJK COMPATIBILITY IDEOGRAPH-#2F8B2
2F8B3 CJK COMPATIBILITY IDEOGRAPH-#2F8B3
2F8B4 CJK COMPATIBILITY IDEOGRAPH-#2F8B4
2F8B5 CJK COMPATIBILITY IDEOGRAPH-#2F8B5
2F8B6 CJK COMPATIBILITY IDEOGRAPH-#2F8B6
2F8B7 CJK COMPATIBILITY IDEOGRAPH-#2F8B7
2F8B8 CJK COMPATIBILITY IDEOGRAPH-#2F8B8
2F8B9 CJK COMPATIBILITY IDEOGRAPH-#2F8B9
2F8BA CJK COMPATIBILITY IDEOGRAPH-#2F8BA
2F8BB CJK COMPATIBILITY IDEOGRAPH-#2F8BB
2F8BC CJK COMPATIBILITY IDEOGRAPH-#2F8BC
2F8BD CJK COMPATIBILITY IDEOGRAPH-#2F8BD
2F8BE CJK COMPATIBILITY IDEOGRAPH-#2F8BE
2F8BF CJK COMPATIBILITY IDEOGRAPH-#2F8BF
2F8C0 CJK COMPATIBILITY IDEOGRAPH-#2F8C0
2F8C1 CJK COMPATIBILITY IDEOGRAPH-#2F8C1
2F8C2 CJK COMPATIBILITY IDEOGRAPH-#2F8C2
2F8C3 CJK COMPATIBILITY IDEOGRAPH-#2F8C3
2F8C4 CJK COMPATIBILITY IDEOGRAPH-#2F8C4
2F8C5 CJK COMPATIBILITY IDEOGRAPH-#2F8C5
2F8C6 CJK COMPATIBILITY IDEOGRAPH-#2F8C6
2F8C7 CJK COMPATIBILITY IDEOGRAPH-#2F8C7
2F8C8 CJK COMPATIBILITY IDEOGRAPH-#2F8C8
2F8C9 CJK COMPATIBILITY IDEOGRAPH-#2F8C9
2F8CA CJK COMPATIBILITY IDEOGRAPH-#2F8CA
2F8CB CJK COMPATIBILITY IDEOGRAPH-#2F8CB
2F8CC CJK COMPATIBILITY IDEOGRAPH-#2F8CC
2F8CD CJK COMPATIBILITY IDEOGRAPH-#2F8CD
2F8CE CJK COMPATIBILITY IDEOGRAPH-#2F8CE
2F8CF CJK COMPATIBILITY IDEOGRAPH-#2F8CF
2F8D0 CJK COMPATIBILITY IDEOGRAPH-#2F8D0
2F8D1 CJK COMPATIBILITY IDEOGRAPH-#2F8D1
2F8D2 CJK COMPATIBILITY IDEOGRAPH-#2F8D2
2F8D3 CJK COMPATIBILITY IDEOGRAPH-#2F8D3
2F8D4 CJK COMPATIBILITY IDEOGRAPH-#2F8D4
2F8D5 CJK COMPATIBILITY IDEOGRAPH-#2F8D5
2F8D6 CJK COMPATIBILITY IDEOGRAPH-#2F8D6
2F8D7 CJK COMPATIBILITY IDEOGRAPH-#2F8D7
2F8D8 CJK COMPATIBILITY IDEOGRAPH-#2F8D8
2F8D9 CJK COMPATIBILITY IDEOGRAPH-#2F8D9
2F8DA CJK COMPATIBILITY IDEOGRAPH-#2F8DA
2F8DB CJK COMPATIBILITY IDEOGRAPH-#2F8DB
2F8DC CJK COMPATIBILITY IDEOGRAPH-#2F8DC
2F8DD CJK COMPATIBILITY IDEOGRAPH-#2F8DD
2F8DE CJK COMPATIBILITY IDEOGRAPH-#2F8DE
2F8DF CJK COMPATIBILITY IDEOGRAPH-#2F8DF
2F8E0 CJK COMPATIBILITY IDEOGRAPH-#2F8E0
2F8E1 CJK COMPATIBILITY IDEOGRAPH-#2F8E1
2F8E2 CJK COMPATIBILITY IDEOGRAPH-#2F8E2
2F8E3 CJK COMPATIBILITY IDEOGRAPH-#2F8E3
2F8E4 CJK COMPATIBILITY IDEOGRAPH-#2F8E4
2F8E5 CJK COMPATIBILITY IDEOGRAPH-#2F8E5
2F8E6 CJK COMPATIBILITY IDEOGRAPH-#2F8E6
2F8E7 CJK COMPATIBILITY IDEOGRAPH-#2F8E7
2F8E8 CJK COMPATIBILITY IDEOGRAPH-#2F8E8
2F8E9 CJK COMPATIBILITY IDEOGRAPH-#2F8E9
2F8EA CJK COMPATIBILITY IDEOGRAPH-#2F8EA
2F8EB CJK COMPATIBILITY IDEOGRAPH-#2F8EB
2F8EC CJK COMPATIBILITY IDEOGRAPH-#2F8EC
2F8ED CJK COMPATIBILITY IDEOGRAPH-#2F8ED
2F8EE CJK COMPATIBILITY IDEOGRAPH-#2F8EE
2F8EF CJK COMPATIBILITY IDEOGRAPH-#2F8EF
2F8F0 CJK COMPATIBILITY IDEOGRAPH-#2F8F0
2F8F1 CJK COMPATIBILITY IDEOGRAPH-#2F8F1
2F8F2 CJK COMPATIBILITY IDEOGRAPH-#2F8F2
2F8F3 CJK COMPATIBILITY IDEOGRAPH-#2F8F3
2F8F4 CJK COMPATIBILITY IDEOGRAPH-#2F8F4
2F8F5 CJK COMPATIBILITY IDEOGRAPH-#2F8F5
2F8F6 CJK COMPATIBILITY IDEOGRAPH-#2F8F6
2F8F7 CJK COMPATIBILITY IDEOGRAPH-#2F8F7
2F8F8 CJK COMPATIBILITY IDEOGRAPH-#2F8F8
2F8F9 CJK COMPATIBILITY IDEOGRAPH-#2F8F9
2F8FA CJK COMPATIBILITY IDEOGRAPH-#2F8FA
2F8FB CJK COMPATIBILITY IDEOGRAPH-#2F8FB
2F8FC CJK COMPATIBILITY IDEOGRAPH-#2F8FC
2F8FD CJK COMPATIBILITY IDEOGRAPH-#2F8FD
2F8FE CJK COMPATIBILITY IDEOGRAPH-#2F8FE
2F8FF CJK COMPATIBILITY IDEOGRAPH-#2F8FF
2F900 CJK COMPATIBILITY IDEOGRAPH-#2F900
2F901 CJK COMPATIBILITY IDEOGRAPH-#2F901
2F902 CJK COMPATIBILITY IDEOGRAPH-#2F902
2F903 CJK COMPATIBILITY IDEOGRAPH-#2F903
2F904 CJK COMPATIBILITY IDEOGRAPH-#2F904
2F905 CJK COMPATIBILITY IDEOGRAPH-#2F905
2F906 CJK COMPATIBILITY IDEOGRAPH-#2F906
2F907 CJK COMPATIBILITY IDEOGRAPH-#2F907, Def{(Cant.) mud, mire}
2F908 CJK COMPATIBILITY IDEOGRAPH-#2F908
2F909 CJK COMPATIBILITY IDEOGRAPH-#2F909
2F90A CJK COMPATIBILITY IDEOGRAPH-#2F90A
2F90B CJK COMPATIBILITY IDEOGRAPH-#2F90B
2F90C CJK COMPATIBILITY IDEOGRAPH-#2F90C
2F90D CJK COMPATIBILITY IDEOGRAPH-#2F90D
2F90E CJK COMPATIBILITY IDEOGRAPH-#2F90E
2F90F CJK COMPATIBILITY IDEOGRAPH-#2F90F
2F910 CJK COMPATIBILITY IDEOGRAPH-#2F910
2F911 CJK COMPATIBILITY IDEOGRAPH-#2F911
2F912 CJK COMPATIBILITY IDEOGRAPH-#2F912
2F913 CJK COMPATIBILITY IDEOGRAPH-#2F913
2F914 CJK COMPATIBILITY IDEOGRAPH-#2F914
2F915 CJK COMPATIBILITY IDEOGRAPH-#2F915
2F916 CJK COMPATIBILITY IDEOGRAPH-#2F916
2F917 CJK COMPATIBILITY IDEOGRAPH-#2F917
2F918 CJK COMPATIBILITY IDEOGRAPH-#2F918
2F919 CJK COMPATIBILITY IDEOGRAPH-#2F919
2F91A CJK COMPATIBILITY IDEOGRAPH-#2F91A
2F91B CJK COMPATIBILITY IDEOGRAPH-#2F91B
2F91C CJK COMPATIBILITY IDEOGRAPH-#2F91C
2F91D CJK COMPATIBILITY IDEOGRAPH-#2F91D
2F91E CJK COMPATIBILITY IDEOGRAPH-#2F91E
2F91F CJK COMPATIBILITY IDEOGRAPH-#2F91F
2F920 CJK COMPATIBILITY IDEOGRAPH-#2F920
2F921 CJK COMPATIBILITY IDEOGRAPH-#2F921
2F922 CJK COMPATIBILITY IDEOGRAPH-#2F922
2F923 CJK COMPATIBILITY IDEOGRAPH-#2F923
2F924 CJK COMPATIBILITY IDEOGRAPH-#2F924
2F925 CJK COMPATIBILITY IDEOGRAPH-#2F925
2F926 CJK COMPATIBILITY IDEOGRAPH-#2F926
2F927 CJK COMPATIBILITY IDEOGRAPH-#2F927
2F928 CJK COMPATIBILITY IDEOGRAPH-#2F928
2F929 CJK COMPATIBILITY IDEOGRAPH-#2F929
2F92A CJK COMPATIBILITY IDEOGRAPH-#2F92A
2F92B CJK COMPATIBILITY IDEOGRAPH-#2F92B
2F92C CJK COMPATIBILITY IDEOGRAPH-#2F92C
2F92D CJK COMPATIBILITY IDEOGRAPH-#2F92D
2F92E CJK COMPATIBILITY IDEOGRAPH-#2F92E
2F92F CJK COMPATIBILITY IDEOGRAPH-#2F92F
2F930 CJK COMPATIBILITY IDEOGRAPH-#2F930
2F931 CJK COMPATIBILITY IDEOGRAPH-#2F931
2F932 CJK COMPATIBILITY IDEOGRAPH-#2F932
2F933 CJK COMPATIBILITY IDEOGRAPH-#2F933
2F934 CJK COMPATIBILITY IDEOGRAPH-#2F934
2F935 CJK COMPATIBILITY IDEOGRAPH-#2F935
2F936 CJK COMPATIBILITY IDEOGRAPH-#2F936
2F937 CJK COMPATIBILITY IDEOGRAPH-#2F937
2F938 CJK COMPATIBILITY IDEOGRAPH-#2F938
2F939 CJK COMPATIBILITY IDEOGRAPH-#2F939
2F93A CJK COMPATIBILITY IDEOGRAPH-#2F93A
2F93B CJK COMPATIBILITY IDEOGRAPH-#2F93B
2F93C CJK COMPATIBILITY IDEOGRAPH-#2F93C
2F93D CJK COMPATIBILITY IDEOGRAPH-#2F93D
2F93E CJK COMPATIBILITY IDEOGRAPH-#2F93E
2F93F CJK COMPATIBILITY IDEOGRAPH-#2F93F
2F940 CJK COMPATIBILITY IDEOGRAPH-#2F940
2F941 CJK COMPATIBILITY IDEOGRAPH-#2F941
2F942 CJK COMPATIBILITY IDEOGRAPH-#2F942
2F943 CJK COMPATIBILITY IDEOGRAPH-#2F943
2F944 CJK COMPATIBILITY IDEOGRAPH-#2F944
2F945 CJK COMPATIBILITY IDEOGRAPH-#2F945
2F946 CJK COMPATIBILITY IDEOGRAPH-#2F946
2F947 CJK COMPATIBILITY IDEOGRAPH-#2F947
2F948 CJK COMPATIBILITY IDEOGRAPH-#2F948
2F949 CJK COMPATIBILITY IDEOGRAPH-#2F949
2F94A CJK COMPATIBILITY IDEOGRAPH-#2F94A
2F94B CJK COMPATIBILITY IDEOGRAPH-#2F94B
2F94C CJK COMPATIBILITY IDEOGRAPH-#2F94C
2F94D CJK COMPATIBILITY IDEOGRAPH-#2F94D
2F94E CJK COMPATIBILITY IDEOGRAPH-#2F94E
2F94F CJK COMPATIBILITY IDEOGRAPH-#2F94F
2F950 CJK COMPATIBILITY IDEOGRAPH-#2F950
2F951 CJK COMPATIBILITY IDEOGRAPH-#2F951
2F952 CJK COMPATIBILITY IDEOGRAPH-#2F952
2F953 CJK COMPATIBILITY IDEOGRAPH-#2F953
2F954 CJK COMPATIBILITY IDEOGRAPH-#2F954
2F955 CJK COMPATIBILITY IDEOGRAPH-#2F955
2F956 CJK COMPATIBILITY IDEOGRAPH-#2F956
2F957 CJK COMPATIBILITY IDEOGRAPH-#2F957
2F958 CJK COMPATIBILITY IDEOGRAPH-#2F958
2F959 CJK COMPATIBILITY IDEOGRAPH-#2F959
2F95A CJK COMPATIBILITY IDEOGRAPH-#2F95A
2F95B CJK COMPATIBILITY IDEOGRAPH-#2F95B
2F95C CJK COMPATIBILITY IDEOGRAPH-#2F95C
2F95D CJK COMPATIBILITY IDEOGRAPH-#2F95D
2F95E CJK COMPATIBILITY IDEOGRAPH-#2F95E
2F95F CJK COMPATIBILITY IDEOGRAPH-#2F95F
2F960 CJK COMPATIBILITY IDEOGRAPH-#2F960
2F961 CJK COMPATIBILITY IDEOGRAPH-#2F961
2F962 CJK COMPATIBILITY IDEOGRAPH-#2F962
2F963 CJK COMPATIBILITY IDEOGRAPH-#2F963
2F964 CJK COMPATIBILITY IDEOGRAPH-#2F964
2F965 CJK COMPATIBILITY IDEOGRAPH-#2F965
2F966 CJK COMPATIBILITY IDEOGRAPH-#2F966
2F967 CJK COMPATIBILITY IDEOGRAPH-#2F967
2F968 CJK COMPATIBILITY IDEOGRAPH-#2F968
2F969 CJK COMPATIBILITY IDEOGRAPH-#2F969
2F96A CJK COMPATIBILITY IDEOGRAPH-#2F96A
2F96B CJK COMPATIBILITY IDEOGRAPH-#2F96B
2F96C CJK COMPATIBILITY IDEOGRAPH-#2F96C
2F96D CJK COMPATIBILITY IDEOGRAPH-#2F96D
2F96E CJK COMPATIBILITY IDEOGRAPH-#2F96E
2F96F CJK COMPATIBILITY IDEOGRAPH-#2F96F
2F970 CJK COMPATIBILITY IDEOGRAPH-#2F970
2F971 CJK COMPATIBILITY IDEOGRAPH-#2F971
2F972 CJK COMPATIBILITY IDEOGRAPH-#2F972
2F973 CJK COMPATIBILITY IDEOGRAPH-#2F973
2F974 CJK COMPATIBILITY IDEOGRAPH-#2F974
2F975 CJK COMPATIBILITY IDEOGRAPH-#2F975
2F976 CJK COMPATIBILITY IDEOGRAPH-#2F976
2F977 CJK COMPATIBILITY IDEOGRAPH-#2F977
2F978 CJK COMPATIBILITY IDEOGRAPH-#2F978
2F979 CJK COMPATIBILITY IDEOGRAPH-#2F979
2F97A CJK COMPATIBILITY IDEOGRAPH-#2F97A
2F97B CJK COMPATIBILITY IDEOGRAPH-#2F97B
2F97C CJK COMPATIBILITY IDEOGRAPH-#2F97C
2F97D CJK COMPATIBILITY IDEOGRAPH-#2F97D
2F97E CJK COMPATIBILITY IDEOGRAPH-#2F97E
2F97F CJK COMPATIBILITY IDEOGRAPH-#2F97F
2F980 CJK COMPATIBILITY IDEOGRAPH-#2F980
2F981 CJK COMPATIBILITY IDEOGRAPH-#2F981
2F982 CJK COMPATIBILITY IDEOGRAPH-#2F982
2F983 CJK COMPATIBILITY IDEOGRAPH-#2F983
2F984 CJK COMPATIBILITY IDEOGRAPH-#2F984
2F985 CJK COMPATIBILITY IDEOGRAPH-#2F985
2F986 CJK COMPATIBILITY IDEOGRAPH-#2F986
2F987 CJK COMPATIBILITY IDEOGRAPH-#2F987
2F988 CJK COMPATIBILITY IDEOGRAPH-#2F988
2F989 CJK COMPATIBILITY IDEOGRAPH-#2F989
2F98A CJK COMPATIBILITY IDEOGRAPH-#2F98A
2F98B CJK COMPATIBILITY IDEOGRAPH-#2F98B
2F98C CJK COMPATIBILITY IDEOGRAPH-#2F98C
2F98D CJK COMPATIBILITY IDEOGRAPH-#2F98D
2F98E CJK COMPATIBILITY IDEOGRAPH-#2F98E
2F98F CJK COMPATIBILITY IDEOGRAPH-#2F98F
2F990 CJK COMPATIBILITY IDEOGRAPH-#2F990
2F991 CJK COMPATIBILITY IDEOGRAPH-#2F991
2F992 CJK COMPATIBILITY IDEOGRAPH-#2F992
2F993 CJK COMPATIBILITY IDEOGRAPH-#2F993
2F994 CJK COMPATIBILITY IDEOGRAPH-#2F994
2F995 CJK COMPATIBILITY IDEOGRAPH-#2F995
2F996 CJK COMPATIBILITY IDEOGRAPH-#2F996
2F997 CJK COMPATIBILITY IDEOGRAPH-#2F997
2F998 CJK COMPATIBILITY IDEOGRAPH-#2F998
2F999 CJK COMPATIBILITY IDEOGRAPH-#2F999
2F99A CJK COMPATIBILITY IDEOGRAPH-#2F99A
2F99B CJK COMPATIBILITY IDEOGRAPH-#2F99B
2F99C CJK COMPATIBILITY IDEOGRAPH-#2F99C
2F99D CJK COMPATIBILITY IDEOGRAPH-#2F99D
2F99E CJK COMPATIBILITY IDEOGRAPH-#2F99E
2F99F CJK COMPATIBILITY IDEOGRAPH-#2F99F
2F9A0 CJK COMPATIBILITY IDEOGRAPH-#2F9A0
2F9A1 CJK COMPATIBILITY IDEOGRAPH-#2F9A1
2F9A2 CJK COMPATIBILITY IDEOGRAPH-#2F9A2
2F9A3 CJK COMPATIBILITY IDEOGRAPH-#2F9A3
2F9A4 CJK COMPATIBILITY IDEOGRAPH-#2F9A4
2F9A5 CJK COMPATIBILITY IDEOGRAPH-#2F9A5
2F9A6 CJK COMPATIBILITY IDEOGRAPH-#2F9A6
2F9A7 CJK COMPATIBILITY IDEOGRAPH-#2F9A7
2F9A8 CJK COMPATIBILITY IDEOGRAPH-#2F9A8
2F9A9 CJK COMPATIBILITY IDEOGRAPH-#2F9A9
2F9AA CJK COMPATIBILITY IDEOGRAPH-#2F9AA
2F9AB CJK COMPATIBILITY IDEOGRAPH-#2F9AB
2F9AC CJK COMPATIBILITY IDEOGRAPH-#2F9AC
2F9AD CJK COMPATIBILITY IDEOGRAPH-#2F9AD
2F9AE CJK COMPATIBILITY IDEOGRAPH-#2F9AE
2F9AF CJK COMPATIBILITY IDEOGRAPH-#2F9AF
2F9B0 CJK COMPATIBILITY IDEOGRAPH-#2F9B0
2F9B1 CJK COMPATIBILITY IDEOGRAPH-#2F9B1
2F9B2 CJK COMPATIBILITY IDEOGRAPH-#2F9B2
2F9B3 CJK COMPATIBILITY IDEOGRAPH-#2F9B3
2F9B4 CJK COMPATIBILITY IDEOGRAPH-#2F9B4
2F9B5 CJK COMPATIBILITY IDEOGRAPH-#2F9B5
2F9B6 CJK COMPATIBILITY IDEOGRAPH-#2F9B6
2F9B7 CJK COMPATIBILITY IDEOGRAPH-#2F9B7
2F9B8 CJK COMPATIBILITY IDEOGRAPH-#2F9B8
2F9B9 CJK COMPATIBILITY IDEOGRAPH-#2F9B9
2F9BA CJK COMPATIBILITY IDEOGRAPH-#2F9BA
2F9BB CJK COMPATIBILITY IDEOGRAPH-#2F9BB
2F9BC CJK COMPATIBILITY IDEOGRAPH-#2F9BC
2F9BD CJK COMPATIBILITY IDEOGRAPH-#2F9BD
2F9BE CJK COMPATIBILITY IDEOGRAPH-#2F9BE
2F9BF CJK COMPATIBILITY IDEOGRAPH-#2F9BF
2F9C0 CJK COMPATIBILITY IDEOGRAPH-#2F9C0
2F9C1 CJK COMPATIBILITY IDEOGRAPH-#2F9C1
2F9C2 CJK COMPATIBILITY IDEOGRAPH-#2F9C2
2F9C3 CJK COMPATIBILITY IDEOGRAPH-#2F9C3
2F9C4 CJK COMPATIBILITY IDEOGRAPH-#2F9C4
2F9C5 CJK COMPATIBILITY IDEOGRAPH-#2F9C5
2F9C6 CJK COMPATIBILITY IDEOGRAPH-#2F9C6
2F9C7 CJK COMPATIBILITY IDEOGRAPH-#2F9C7
2F9C8 CJK COMPATIBILITY IDEOGRAPH-#2F9C8
2F9C9 CJK COMPATIBILITY IDEOGRAPH-#2F9C9
2F9CA CJK COMPATIBILITY IDEOGRAPH-#2F9CA
2F9CB CJK COMPATIBILITY IDEOGRAPH-#2F9CB
2F9CC CJK COMPATIBILITY IDEOGRAPH-#2F9CC
2F9CD CJK COMPATIBILITY IDEOGRAPH-#2F9CD
2F9CE CJK COMPATIBILITY IDEOGRAPH-#2F9CE
2F9CF CJK COMPATIBILITY IDEOGRAPH-#2F9CF
2F9D0 CJK COMPATIBILITY IDEOGRAPH-#2F9D0
2F9D1 CJK COMPATIBILITY IDEOGRAPH-#2F9D1
2F9D2 CJK COMPATIBILITY IDEOGRAPH-#2F9D2
2F9D3 CJK COMPATIBILITY IDEOGRAPH-#2F9D3
2F9D4 CJK COMPATIBILITY IDEOGRAPH-#2F9D4
2F9D5 CJK COMPATIBILITY IDEOGRAPH-#2F9D5
2F9D6 CJK COMPATIBILITY IDEOGRAPH-#2F9D6
2F9D7 CJK COMPATIBILITY IDEOGRAPH-#2F9D7
2F9D8 CJK COMPATIBILITY IDEOGRAPH-#2F9D8
2F9D9 CJK COMPATIBILITY IDEOGRAPH-#2F9D9
2F9DA CJK COMPATIBILITY IDEOGRAPH-#2F9DA
2F9DB CJK COMPATIBILITY IDEOGRAPH-#2F9DB
2F9DC CJK COMPATIBILITY IDEOGRAPH-#2F9DC
2F9DD CJK COMPATIBILITY IDEOGRAPH-#2F9DD
2F9DE CJK COMPATIBILITY IDEOGRAPH-#2F9DE
2F9DF CJK COMPATIBILITY IDEOGRAPH-#2F9DF
2F9E0 CJK COMPATIBILITY IDEOGRAPH-#2F9E0
2F9E1 CJK COMPATIBILITY IDEOGRAPH-#2F9E1
2F9E2 CJK COMPATIBILITY IDEOGRAPH-#2F9E2
2F9E3 CJK COMPATIBILITY IDEOGRAPH-#2F9E3
2F9E4 CJK COMPATIBILITY IDEOGRAPH-#2F9E4
2F9E5 CJK COMPATIBILITY IDEOGRAPH-#2F9E5
2F9E6 CJK COMPATIBILITY IDEOGRAPH-#2F9E6
2F9E7 CJK COMPATIBILITY IDEOGRAPH-#2F9E7
2F9E8 CJK COMPATIBILITY IDEOGRAPH-#2F9E8
2F9E9 CJK COMPATIBILITY IDEOGRAPH-#2F9E9
2F9EA CJK COMPATIBILITY IDEOGRAPH-#2F9EA
2F9EB CJK COMPATIBILITY IDEOGRAPH-#2F9EB
2F9EC CJK COMPATIBILITY IDEOGRAPH-#2F9EC
2F9ED CJK COMPATIBILITY IDEOGRAPH-#2F9ED
2F9EE CJK COMPATIBILITY IDEOGRAPH-#2F9EE
2F9EF CJK COMPATIBILITY IDEOGRAPH-#2F9EF
2F9F0 CJK COMPATIBILITY IDEOGRAPH-#2F9F0
2F9F1 CJK COMPATIBILITY IDEOGRAPH-#2F9F1
2F9F2 CJK COMPATIBILITY IDEOGRAPH-#2F9F2
2F9F3 CJK COMPATIBILITY IDEOGRAPH-#2F9F3
2F9F4 CJK COMPATIBILITY IDEOGRAPH-#2F9F4
2F9F5 CJK COMPATIBILITY IDEOGRAPH-#2F9F5
2F9F6 CJK COMPATIBILITY IDEOGRAPH-#2F9F6
2F9F7 CJK COMPATIBILITY IDEOGRAPH-#2F9F7
2F9F8 CJK COMPATIBILITY IDEOGRAPH-#2F9F8
2F9F9 CJK COMPATIBILITY IDEOGRAPH-#2F9F9
2F9FA CJK COMPATIBILITY IDEOGRAPH-#2F9FA
2F9FB CJK COMPATIBILITY IDEOGRAPH-#2F9FB
2F9FC CJK COMPATIBILITY IDEOGRAPH-#2F9FC
2F9FD CJK COMPATIBILITY IDEOGRAPH-#2F9FD
2F9FE CJK COMPATIBILITY IDEOGRAPH-#2F9FE
2F9FF CJK COMPATIBILITY IDEOGRAPH-#2F9FF
2FA00 CJK COMPATIBILITY IDEOGRAPH-#2FA00
2FA01 CJK COMPATIBILITY IDEOGRAPH-#2FA01
2FA02 CJK COMPATIBILITY IDEOGRAPH-#2FA02
2FA03 CJK COMPATIBILITY IDEOGRAPH-#2FA03
2FA04 CJK COMPATIBILITY IDEOGRAPH-#2FA04
2FA05 CJK COMPATIBILITY IDEOGRAPH-#2FA05
2FA06 CJK COMPATIBILITY IDEOGRAPH-#2FA06
2FA07 CJK COMPATIBILITY IDEOGRAPH-#2FA07
2FA08 CJK COMPATIBILITY IDEOGRAPH-#2FA08
2FA09 CJK COMPATIBILITY IDEOGRAPH-#2FA09
2FA0A CJK COMPATIBILITY IDEOGRAPH-#2FA0A
2FA0B CJK COMPATIBILITY IDEOGRAPH-#2FA0B
2FA0C CJK COMPATIBILITY IDEOGRAPH-#2FA0C
2FA0D CJK COMPATIBILITY IDEOGRAPH-#2FA0D
2FA0E CJK COMPATIBILITY IDEOGRAPH-#2FA0E, RSKangXi=196.9
2FA0F CJK COMPATIBILITY IDEOGRAPH-#2FA0F
2FA10 CJK COMPATIBILITY IDEOGRAPH-#2FA10
2FA11 CJK COMPATIBILITY IDEOGRAPH-#2FA11
2FA12 CJK COMPATIBILITY IDEOGRAPH-#2FA12
2FA13 CJK COMPATIBILITY IDEOGRAPH-#2FA13
2FA14 CJK COMPATIBILITY IDEOGRAPH-#2FA14
2FA15 CJK COMPATIBILITY IDEOGRAPH-#2FA15
2FA16 CJK COMPATIBILITY IDEOGRAPH-#2FA16
2FA17 CJK COMPATIBILITY IDEOGRAPH-#2FA17
2FA18 CJK COMPATIBILITY IDEOGRAPH-#2FA18
2FA19 CJK COMPATIBILITY IDEOGRAPH-#2FA19
2FA1A CJK COMPATIBILITY IDEOGRAPH-#2FA1A
2FA1B CJK COMPATIBILITY IDEOGRAPH-#2FA1B
2FA1C CJK COMPATIBILITY IDEOGRAPH-#2FA1C
2FA1D CJK COMPATIBILITY IDEOGRAPH-#2FA1D
E0001 LANGUAGE TAG
E0020 TAG SPACE
E0021 TAG EXCLAMATION MARK
E0022 TAG QUOTATION MARK
E0023 TAG NUMBER SIGN
E0024 TAG DOLLAR SIGN
E0025 TAG PERCENT SIGN
E0026 TAG AMPERSAND
E0027 TAG APOSTROPHE
E0028 TAG LEFT PARENTHESIS
E0029 TAG RIGHT PARENTHESIS
E002A TAG ASTERISK
E002B TAG PLUS SIGN
E002C TAG COMMA
E002D TAG HYPHEN-MINUS
E002E TAG FULL STOP
E002F TAG SOLIDUS
E0030 TAG DIGIT ZERO
E0031 TAG DIGIT ONE
E0032 TAG DIGIT TWO
E0033 TAG DIGIT THREE
E0034 TAG DIGIT FOUR
E0035 TAG DIGIT FIVE
E0036 TAG DIGIT SIX
E0037 TAG DIGIT SEVEN
E0038 TAG DIGIT EIGHT
E0039 TAG DIGIT NINE
E003A TAG COLON
E003B TAG SEMICOLON
E003C TAG LESS-THAN SIGN
E003D TAG EQUALS SIGN
E003E TAG GREATER-THAN SIGN
E003F TAG QUESTION MARK
E0040 TAG COMMERCIAL AT
E0041 TAG LATIN CAPITAL LETTER A
E0042 TAG LATIN CAPITAL LETTER B
E0043 TAG LATIN CAPITAL LETTER C
E0044 TAG LATIN CAPITAL LETTER D
E0045 TAG LATIN CAPITAL LETTER E
E0046 TAG LATIN CAPITAL LETTER F
E0047 TAG LATIN CAPITAL LETTER G
E0048 TAG LATIN CAPITAL LETTER H
E0049 TAG LATIN CAPITAL LETTER I
E004A TAG LATIN CAPITAL LETTER J
E004B TAG LATIN CAPITAL LETTER K
E004C TAG LATIN CAPITAL LETTER L
E004D TAG LATIN CAPITAL LETTER M
E004E TAG LATIN CAPITAL LETTER N
E004F TAG LATIN CAPITAL LETTER O
E0050 TAG LATIN CAPITAL LETTER P
E0051 TAG LATIN CAPITAL LETTER Q
E0052 TAG LATIN CAPITAL LETTER R
E0053 TAG LATIN CAPITAL LETTER S
E0054 TAG LATIN CAPITAL LETTER T
E0055 TAG LATIN CAPITAL LETTER U
E0056 TAG LATIN CAPITAL LETTER V
E0057 TAG LATIN CAPITAL LETTER W
E0058 TAG LATIN CAPITAL LETTER X
E0059 TAG LATIN CAPITAL LETTER Y
E005A TAG LATIN CAPITAL LETTER Z
E005B TAG LEFT SQUARE BRACKET
E005C TAG REVERSE SOLIDUS
E005D TAG RIGHT SQUARE BRACKET
E005E TAG CIRCUMFLEX ACCENT
E005F TAG LOW LINE
E0060 TAG GRAVE ACCENT
E0061 TAG LATIN SMALL LETTER A
E0062 TAG LATIN SMALL LETTER B
E0063 TAG LATIN SMALL LETTER C
E0064 TAG LATIN SMALL LETTER D
E0065 TAG LATIN SMALL LETTER E
E0066 TAG LATIN SMALL LETTER F
E0067 TAG LATIN SMALL LETTER G
E0068 TAG LATIN SMALL LETTER H
E0069 TAG LATIN SMALL LETTER I
E006A TAG LATIN SMALL LETTER J
E006B TAG LATIN SMALL LETTER K
E006C TAG LATIN SMALL LETTER L
E006D TAG LATIN SMALL LETTER M
E006E TAG LATIN SMALL LETTER N
E006F TAG LATIN SMALL LETTER O
E0070 TAG LATIN SMALL LETTER P
E0071 TAG LATIN SMALL LETTER Q
E0072 TAG LATIN SMALL LETTER R
E0073 TAG LATIN SMALL LETTER S
E0074 TAG LATIN SMALL LETTER T
E0075 TAG LATIN SMALL LETTER U
E0076 TAG LATIN SMALL LETTER V
E0077 TAG LATIN SMALL LETTER W
E0078 TAG LATIN SMALL LETTER X
E0079 TAG LATIN SMALL LETTER Y
E007A TAG LATIN SMALL LETTER Z
E007B TAG LEFT CURLY BRACKET
E007C TAG VERTICAL LINE
E007D TAG RIGHT CURLY BRACKET
E007E TAG TILDE
E007F CANCEL TAG
E0100 VARIATION SELECTOR-17, VS17
E0101 VARIATION SELECTOR-18, VS18
E0102 VARIATION SELECTOR-19, VS19
E0103 VARIATION SELECTOR-20, VS20
E0104 VARIATION SELECTOR-21, VS21
E0105 VARIATION SELECTOR-22, VS22
E0106 VARIATION SELECTOR-23, VS23
E0107 VARIATION SELECTOR-24, VS24
E0108 VARIATION SELECTOR-25, VS25
E0109 VARIATION SELECTOR-26, VS26
E010A VARIATION SELECTOR-27, VS27
E010B VARIATION SELECTOR-28, VS28
E010C VARIATION SELECTOR-29, VS29
E010D VARIATION SELECTOR-30, VS30
E010E VARIATION SELECTOR-31, VS31
E010F VARIATION SELECTOR-32, VS32
E0110 VARIATION SELECTOR-33, VS33
E0111 VARIATION SELECTOR-34, VS34
E0112 VARIATION SELECTOR-35, VS35
E0113 VARIATION SELECTOR-36, VS36
E0114 VARIATION SELECTOR-37, VS37
E0115 VARIATION SELECTOR-38, VS38
E0116 VARIATION SELECTOR-39, VS39
E0117 VARIATION SELECTOR-40, VS40
E0118 VARIATION SELECTOR-41, VS41
E0119 VARIATION SELECTOR-42, VS42
E011A VARIATION SELECTOR-43, VS43
E011B VARIATION SELECTOR-44, VS44
E011C VARIATION SELECTOR-45, VS45
E011D VARIATION SELECTOR-46, VS46
E011E VARIATION SELECTOR-47, VS47
E011F VARIATION SELECTOR-48, VS48
E0120 VARIATION SELECTOR-49, VS49
E0121 VARIATION SELECTOR-50, VS50
E0122 VARIATION SELECTOR-51, VS51
E0123 VARIATION SELECTOR-52, VS52
E0124 VARIATION SELECTOR-53, VS53
E0125 VARIATION SELECTOR-54, VS54
E0126 VARIATION SELECTOR-55, VS55
E0127 VARIATION SELECTOR-56, VS56
E0128 VARIATION SELECTOR-57, VS57
E0129 VARIATION SELECTOR-58, VS58
E012A VARIATION SELECTOR-59, VS59
E012B VARIATION SELECTOR-60, VS60
E012C VARIATION SELECTOR-61, VS61
E012D VARIATION SELECTOR-62, VS62
E012E VARIATION SELECTOR-63, VS63
E012F VARIATION SELECTOR-64, VS64
E0130 VARIATION SELECTOR-65, VS65
E0131 VARIATION SELECTOR-66, VS66
E0132 VARIATION SELECTOR-67, VS67
E0133 VARIATION SELECTOR-68, VS68
E0134 VARIATION SELECTOR-69, VS69
E0135 VARIATION SELECTOR-70, VS70
E0136 VARIATION SELECTOR-71, VS71
E0137 VARIATION SELECTOR-72, VS72
E0138 VARIATION SELECTOR-73, VS73
E0139 VARIATION SELECTOR-74, VS74
E013A VARIATION SELECTOR-75, VS75
E013B VARIATION SELECTOR-76, VS76
E013C VARIATION SELECTOR-77, VS77
E013D VARIATION SELECTOR-78, VS78
E013E VARIATION SELECTOR-79, VS79
E013F VARIATION SELECTOR-80, VS80
E0140 VARIATION SELECTOR-81, VS81
E0141 VARIATION SELECTOR-82, VS82
E0142 VARIATION SELECTOR-83, VS83
E0143 VARIATION SELECTOR-84, VS84
E0144 VARIATION SELECTOR-85, VS85
E0145 VARIATION SELECTOR-86, VS86
E0146 VARIATION SELECTOR-87, VS87
E0147 VARIATION SELECTOR-88, VS88
E0148 VARIATION SELECTOR-89, VS89
E0149 VARIATION SELECTOR-90, VS90
E014A VARIATION SELECTOR-91, VS91
E014B VARIATION SELECTOR-92, VS92
E014C VARIATION SELECTOR-93, VS93
E014D VARIATION SELECTOR-94, VS94
E014E VARIATION SELECTOR-95, VS95
E014F VARIATION SELECTOR-96, VS96
E0150 VARIATION SELECTOR-97, VS97
E0151 VARIATION SELECTOR-98, VS98
E0152 VARIATION SELECTOR-99, VS99
E0153 VARIATION SELECTOR-100, VS100
E0154 VARIATION SELECTOR-101, VS101
E0155 VARIATION SELECTOR-102, VS102
E0156 VARIATION SELECTOR-103, VS103
E0157 VARIATION SELECTOR-104, VS104
E0158 VARIATION SELECTOR-105, VS105
E0159 VARIATION SELECTOR-106, VS106
E015A VARIATION SELECTOR-107, VS107
E015B VARIATION SELECTOR-108, VS108
E015C VARIATION SELECTOR-109, VS109
E015D VARIATION SELECTOR-110, VS110
E015E VARIATION SELECTOR-111, VS111
E015F VARIATION SELECTOR-112, VS112
E0160 VARIATION SELECTOR-113, VS113
E0161 VARIATION SELECTOR-114, VS114
E0162 VARIATION SELECTOR-115, VS115
E0163 VARIATION SELECTOR-116, VS116
E0164 VARIATION SELECTOR-117, VS117
E0165 VARIATION SELECTOR-118, VS118
E0166 VARIATION SELECTOR-119, VS119
E0167 VARIATION SELECTOR-120, VS120
E0168 VARIATION SELECTOR-121, VS121
E0169 VARIATION SELECTOR-122, VS122
E016A VARIATION SELECTOR-123, VS123
E016B VARIATION SELECTOR-124, VS124
E016C VARIATION SELECTOR-125, VS125
E016D VARIATION SELECTOR-126, VS126
E016E VARIATION SELECTOR-127, VS127
E016F VARIATION SELECTOR-128, VS128
E0170 VARIATION SELECTOR-129, VS129
E0171 VARIATION SELECTOR-130, VS130
E0172 VARIATION SELECTOR-131, VS131
E0173 VARIATION SELECTOR-132, VS132
E0174 VARIATION SELECTOR-133, VS133
E0175 VARIATION SELECTOR-134, VS134
E0176 VARIATION SELECTOR-135, VS135
E0177 VARIATION SELECTOR-136, VS136
E0178 VARIATION SELECTOR-137, VS137
E0179 VARIATION SELECTOR-138, VS138
E017A VARIATION SELECTOR-139, VS139
E017B VARIATION SELECTOR-140, VS140
E017C VARIATION SELECTOR-141, VS141
E017D VARIATION SELECTOR-142, VS142
E017E VARIATION SELECTOR-143, VS143
E017F VARIATION SELECTOR-144, VS144
E0180 VARIATION SELECTOR-145, VS145
E0181 VARIATION SELECTOR-146, VS146
E0182 VARIATION SELECTOR-147, VS147
E0183 VARIATION SELECTOR-148, VS148
E0184 VARIATION SELECTOR-149, VS149
E0185 VARIATION SELECTOR-150, VS150
E0186 VARIATION SELECTOR-151, VS151
E0187 VARIATION SELECTOR-152, VS152
E0188 VARIATION SELECTOR-153, VS153
E0189 VARIATION SELECTOR-154, VS154
E018A VARIATION SELECTOR-155, VS155
E018B VARIATION SELECTOR-156, VS156
E018C VARIATION SELECTOR-157, VS157
E018D VARIATION SELECTOR-158, VS158
E018E VARIATION SELECTOR-159, VS159
E018F VARIATION SELECTOR-160, VS160
E0190 VARIATION SELECTOR-161, VS161
E0191 VARIATION SELECTOR-162, VS162
E0192 VARIATION SELECTOR-163, VS163
E0193 VARIATION SELECTOR-164, VS164
E0194 VARIATION SELECTOR-165, VS165
E0195 VARIATION SELECTOR-166, VS166
E0196 VARIATION SELECTOR-167, VS167
E0197 VARIATION SELECTOR-168, VS168
E0198 VARIATION SELECTOR-169, VS169
E0199 VARIATION SELECTOR-170, VS170
E019A VARIATION SELECTOR-171, VS171
E019B VARIATION SELECTOR-172, VS172
E019C VARIATION SELECTOR-173, VS173
E019D VARIATION SELECTOR-174, VS174
E019E VARIATION SELECTOR-175, VS175
E019F VARIATION SELECTOR-176, VS176
E01A0 VARIATION SELECTOR-177, VS177
E01A1 VARIATION SELECTOR-178, VS178
E01A2 VARIATION SELECTOR-179, VS179
E01A3 VARIATION SELECTOR-180, VS180
E01A4 VARIATION SELECTOR-181, VS181
E01A5 VARIATION SELECTOR-182, VS182
E01A6 VARIATION SELECTOR-183, VS183
E01A7 VARIATION SELECTOR-184, VS184
E01A8 VARIATION SELECTOR-185, VS185
E01A9 VARIATION SELECTOR-186, VS186
E01AA VARIATION SELECTOR-187, VS187
E01AB VARIATION SELECTOR-188, VS188
E01AC VARIATION SELECTOR-189, VS189
E01AD VARIATION SELECTOR-190, VS190
E01AE VARIATION SELECTOR-191, VS191
E01AF VARIATION SELECTOR-192, VS192
E01B0 VARIATION SELECTOR-193, VS193
E01B1 VARIATION SELECTOR-194, VS194
E01B2 VARIATION SELECTOR-195, VS195
E01B3 VARIATION SELECTOR-196, VS196
E01B4 VARIATION SELECTOR-197, VS197
E01B5 VARIATION SELECTOR-198, VS198
E01B6 VARIATION SELECTOR-199, VS199
E01B7 VARIATION SELECTOR-200, VS200
E01B8 VARIATION SELECTOR-201, VS201
E01B9 VARIATION SELECTOR-202, VS202
E01BA VARIATION SELECTOR-203, VS203
E01BB VARIATION SELECTOR-204, VS204
E01BC VARIATION SELECTOR-205, VS205
E01BD VARIATION SELECTOR-206, VS206
E01BE VARIATION SELECTOR-207, VS207
E01BF VARIATION SELECTOR-208, VS208
E01C0 VARIATION SELECTOR-209, VS209
E01C1 VARIATION SELECTOR-210, VS210
E01C2 VARIATION SELECTOR-211, VS211
E01C3 VARIATION SELECTOR-212, VS212
E01C4 VARIATION SELECTOR-213, VS213
E01C5 VARIATION SELECTOR-214, VS214
E01C6 VARIATION SELECTOR-215, VS215
E01C7 VARIATION SELECTOR-216, VS216
E01C8 VARIATION SELECTOR-217, VS217
E01C9 VARIATION SELECTOR-218, VS218
E01CA VARIATION SELECTOR-219, VS219
E01CB VARIATION SELECTOR-220, VS220
E01CC VARIATION SELECTOR-221, VS221
E01CD VARIATION SELECTOR-222, VS222
E01CE VARIATION SELECTOR-223, VS223
E01CF VARIATION SELECTOR-224, VS224
E01D0 VARIATION SELECTOR-225, VS225
E01D1 VARIATION SELECTOR-226, VS226
E01D2 VARIATION SELECTOR-227, VS227
E01D3 VARIATION SELECTOR-228, VS228
E01D4 VARIATION SELECTOR-229, VS229
E01D5 VARIATION SELECTOR-230, VS230
E01D6 VARIATION SELECTOR-231, VS231
E01D7 VARIATION SELECTOR-232, VS232
E01D8 VARIATION SELECTOR-233, VS233
E01D9 VARIATION SELECTOR-234, VS234
E01DA VARIATION SELECTOR-235, VS235
E01DB VARIATION SELECTOR-236, VS236
E01DC VARIATION SELECTOR-237, VS237
E01DD VARIATION SELECTOR-238, VS238
E01DE VARIATION SELECTOR-239, VS239
E01DF VARIATION SELECTOR-240, VS240
E01E0 VARIATION SELECTOR-241, VS241
E01E1 VARIATION SELECTOR-242, VS242
E01E2 VARIATION SELECTOR-243, VS243
E01E3 VARIATION SELECTOR-244, VS244
E01E4 VARIATION SELECTOR-245, VS245
E01E5 VARIATION SELECTOR-246, VS246
E01E6 VARIATION SELECTOR-247, VS247
E01E7 VARIATION SELECTOR-248, VS248
E01E8 VARIATION SELECTOR-249, VS249
E01E9 VARIATION SELECTOR-250, VS250
E01EA VARIATION SELECTOR-251, VS251
E01EB VARIATION SELECTOR-252, VS252
E01EC VARIATION SELECTOR-253, VS253
E01ED VARIATION SELECTOR-254, VS254
E01EE VARIATION SELECTOR-255, VS255
E01EF VARIATION SELECTOR-256, VS256
